#ifndef __VMLINUX_H__
#define __VMLINUX_H__

#ifndef BPF_NO_PRESERVE_ACCESS_INDEX
#pragma clang attribute push (__attribute__((preserve_access_index)), apply_to = record)
#endif

typedef signed char __s8;

typedef unsigned char __u8;

typedef short int __s16;

typedef short unsigned int __u16;

typedef int __s32;

typedef unsigned int __u32;

typedef long long int __s64;

typedef long long unsigned int __u64;

typedef __s8 s8;

typedef __u8 u8;

typedef __s16 s16;

typedef __u16 u16;

typedef __s32 s32;

typedef __u32 u32;

typedef __s64 s64;

typedef __u64 u64;

enum {
	false = 0,
	true = 1,
};

typedef long int __kernel_long_t;

typedef long unsigned int __kernel_ulong_t;

typedef int __kernel_pid_t;

typedef unsigned int __kernel_uid32_t;

typedef unsigned int __kernel_gid32_t;

typedef __kernel_ulong_t __kernel_size_t;

typedef __kernel_long_t __kernel_ssize_t;

typedef long long int __kernel_loff_t;

typedef __kernel_long_t __kernel_time_t;

typedef __kernel_long_t __kernel_clock_t;

typedef int __kernel_timer_t;

typedef int __kernel_clockid_t;

typedef __u32 __le32;

typedef unsigned int __poll_t;

typedef u32 __kernel_dev_t;

typedef __kernel_dev_t dev_t;

typedef short unsigned int umode_t;

typedef __kernel_pid_t pid_t;

typedef __kernel_clockid_t clockid_t;

typedef _Bool bool;

typedef __kernel_uid32_t uid_t;

typedef __kernel_gid32_t gid_t;

typedef __kernel_loff_t loff_t;

typedef __kernel_size_t size_t;

typedef __kernel_ssize_t ssize_t;

typedef s32 int32_t;

typedef u32 uint32_t;

typedef u64 sector_t;

typedef u64 blkcnt_t;

typedef unsigned int gfp_t;

typedef unsigned int fmode_t;

typedef u64 phys_addr_t;

typedef phys_addr_t resource_size_t;

typedef struct {
	int counter;
} atomic_t;

typedef struct {
	long int counter;
} atomic64_t;

struct list_head {
	struct list_head *next;
	struct list_head *prev;
};

struct hlist_node;

struct hlist_head {
	struct hlist_node *first;
};

struct hlist_node {
	struct hlist_node *next;
	struct hlist_node **pprev;
};

struct callback_head {
	struct callback_head *next;
	void (*func)(struct callback_head *);
};

struct kernel_symbol {
	long unsigned int value;
	const char *name;
};

typedef int (*initcall_t)();

struct obs_kernel_param {
	const char *str;
	int (*setup_func)(char *);
	int early;
};

typedef u64 jump_label_t;

struct jump_entry {
	jump_label_t code;
	jump_label_t target;
	jump_label_t key;
};

struct static_key_mod;

struct static_key {
	atomic_t enabled;
	union {
		long unsigned int type;
		struct jump_entry *entries;
		struct static_key_mod *next;
	};
};

typedef bool pstate_check_t(long unsigned int);

struct static_key_true {
	struct static_key key;
};

struct static_key_false {
	struct static_key key;
};

struct _ddebug {
	const char *modname;
	const char *function;
	const char *filename;
	const char *format;
	unsigned int lineno: 18;
	unsigned int flags: 8;
	union {
		struct static_key_true dd_key_true;
		struct static_key_false dd_key_false;
	} key;
};

typedef void *fl_owner_t;

struct module;

struct file;

struct kiocb;

struct iov_iter;

struct dir_context;

struct poll_table_struct;

struct vm_area_struct;

struct inode;

struct file_lock;

struct page;

struct pipe_inode_info;

struct seq_file;

struct file_operations {
	struct module *owner;
	loff_t (*llseek)(struct file *, loff_t, int);
	ssize_t (*read)(struct file *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb *, struct iov_iter *);
	ssize_t (*write_iter)(struct kiocb *, struct iov_iter *);
	int (*iopoll)(struct kiocb *, bool);
	int (*iterate)(struct file *, struct dir_context *);
	int (*iterate_shared)(struct file *, struct dir_context *);
	__poll_t (*poll)(struct file *, struct poll_table_struct *);
	long int (*unlocked_ioctl)(struct file *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file *, unsigned int, long unsigned int);
	int (*mmap)(struct file *, struct vm_area_struct *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode *, struct file *);
	int (*flush)(struct file *, fl_owner_t);
	int (*release)(struct inode *, struct file *);
	int (*fsync)(struct file *, loff_t, loff_t, int);
	int (*fasync)(int, struct file *, int);
	int (*lock)(struct file *, int, struct file_lock *);
	ssize_t (*sendpage)(struct file *, struct page *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file *, int, struct file_lock *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file *, long int, struct file_lock **, void **);
	long int (*fallocate)(struct file *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file *, struct file *);
	ssize_t (*copy_file_range)(struct file *, loff_t, struct file *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file *, loff_t, struct file *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct qspinlock {
	union {
		atomic_t val;
		struct {
			u8 locked;
			u8 pending;
		};
		struct {
			u16 locked_pending;
			u16 tail;
		};
	};
};

typedef struct qspinlock arch_spinlock_t;

struct raw_spinlock {
	arch_spinlock_t raw_lock;
};

struct spinlock {
	union {
		struct raw_spinlock rlock;
	};
};

typedef struct spinlock spinlock_t;

struct notifier_block;

struct atomic_notifier_head {
	spinlock_t lock;
	struct notifier_block *head;
};

enum system_states {
	SYSTEM_BOOTING = 0,
	SYSTEM_SCHEDULING = 1,
	SYSTEM_RUNNING = 2,
	SYSTEM_HALT = 3,
	SYSTEM_POWER_OFF = 4,
	SYSTEM_RESTART = 5,
	SYSTEM_SUSPEND = 6,
};

struct taint_flag {
	char c_true;
	char c_false;
	bool module;
};

enum ftrace_dump_mode {
	DUMP_NONE = 0,
	DUMP_ALL = 1,
	DUMP_ORIG = 2,
};

struct bug_entry {
	int bug_addr_disp;
	int file_disp;
	short unsigned int line;
	short unsigned int flags;
};

typedef __s64 time64_t;

struct timespec {
	__kernel_time_t tv_sec;
	long int tv_nsec;
};

struct timezone {
	int tz_minuteswest;
	int tz_dsttime;
};

struct timespec64 {
	time64_t tv_sec;
	long int tv_nsec;
};

enum timespec_type {
	TT_NONE = 0,
	TT_NATIVE = 1,
	TT_COMPAT = 2,
};

typedef s32 compat_time_t;

struct compat_timespec {
	compat_time_t tv_sec;
	s32 tv_nsec;
};

struct pollfd {
	int fd;
	short int events;
	short int revents;
};

struct restart_block {
	long int (*fn)(struct restart_block *);
	union {
		struct {
			u32 *uaddr;
			u32 val;
			u32 flags;
			u32 bitset;
			u64 time;
			u32 *uaddr2;
		} futex;
		struct {
			clockid_t clockid;
			enum timespec_type type;
			union {
				struct timespec *rmtp;
				struct compat_timespec *compat_rmtp;
			};
			u64 expires;
		} nanosleep;
		struct {
			struct pollfd *ufds;
			int nfds;
			int has_timeout;
			long unsigned int tv_sec;
			long unsigned int tv_nsec;
		} poll;
	};
};

typedef long unsigned int mm_segment_t;

struct thread_info {
	long unsigned int flags;
	mm_segment_t addr_limit;
	int preempt_count;
};

struct llist_node {
	struct llist_node *next;
};

struct load_weight {
	long unsigned int weight;
	u32 inv_weight;
};

struct rb_node {
	long unsigned int __rb_parent_color;
	struct rb_node *rb_right;
	struct rb_node *rb_left;
};

struct sched_statistics {
	u64 wait_start;
	u64 wait_max;
	u64 wait_count;
	u64 wait_sum;
	u64 iowait_count;
	u64 iowait_sum;
	u64 sleep_start;
	u64 sleep_max;
	s64 sum_sleep_runtime;
	u64 block_start;
	u64 block_max;
	u64 exec_max;
	u64 slice_max;
	u64 nr_migrations_cold;
	u64 nr_failed_migrations_affine;
	u64 nr_failed_migrations_running;
	u64 nr_failed_migrations_hot;
	u64 nr_forced_migrations;
	u64 nr_wakeups;
	u64 nr_wakeups_sync;
	u64 nr_wakeups_migrate;
	u64 nr_wakeups_local;
	u64 nr_wakeups_remote;
	u64 nr_wakeups_affine;
	u64 nr_wakeups_affine_attempts;
	u64 nr_wakeups_passive;
	u64 nr_wakeups_idle;
};

struct util_est {
	unsigned int enqueued;
	unsigned int ewma;
};

struct sched_avg {
	u64 last_update_time;
	u64 load_sum;
	u64 runnable_load_sum;
	u32 util_sum;
	u32 period_contrib;
	long unsigned int load_avg;
	long unsigned int runnable_load_avg;
	long unsigned int util_avg;
	struct util_est util_est;
};

struct cfs_rq;

struct sched_entity {
	struct load_weight load;
	long unsigned int runnable_weight;
	struct rb_node run_node;
	struct list_head group_node;
	unsigned int on_rq;
	u64 exec_start;
	u64 sum_exec_runtime;
	u64 vruntime;
	u64 prev_sum_exec_runtime;
	u64 nr_migrations;
	struct sched_statistics statistics;
	int depth;
	struct sched_entity *parent;
	struct cfs_rq *cfs_rq;
	struct cfs_rq *my_q;
	long: 64;
	long: 64;
	long: 64;
	struct sched_avg avg;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rt_rq;

struct sched_rt_entity {
	struct list_head run_list;
	long unsigned int timeout;
	long unsigned int watchdog_stamp;
	unsigned int time_slice;
	short unsigned int on_rq;
	short unsigned int on_list;
	struct sched_rt_entity *back;
	struct sched_rt_entity *parent;
	struct rt_rq *rt_rq;
	struct rt_rq *my_q;
};

typedef s64 ktime_t;

struct timerqueue_node {
	struct rb_node node;
	ktime_t expires;
};

enum hrtimer_restart {
	HRTIMER_NORESTART = 0,
	HRTIMER_RESTART = 1,
};

struct hrtimer_clock_base;

struct hrtimer_rh;

struct hrtimer {
	struct timerqueue_node node;
	ktime_t _softexpires;
	enum hrtimer_restart (*function)(struct hrtimer *);
	struct hrtimer_clock_base *base;
	u8 state;
	u8 is_rel;
	u8 is_soft;
	size_t hrtimer_size_rh;
	struct hrtimer_rh *hrtimer_rh;
};

struct sched_dl_entity {
	struct rb_node rb_node;
	u64 dl_runtime;
	u64 dl_deadline;
	u64 dl_period;
	u64 dl_bw;
	u64 dl_density;
	s64 runtime;
	u64 deadline;
	unsigned int flags;
	unsigned int dl_throttled: 1;
	unsigned int dl_boosted: 1;
	unsigned int dl_yielded: 1;
	unsigned int dl_non_contending: 1;
	unsigned int dl_overrun: 1;
	struct hrtimer dl_timer;
	struct hrtimer inactive_timer;
};

struct cpumask {
	long unsigned int bits[64];
};

typedef struct cpumask cpumask_t;

struct sched_info {
	long unsigned int pcount;
	long long unsigned int run_delay;
	long long unsigned int last_arrival;
	long long unsigned int last_queued;
};

struct plist_node {
	int prio;
	struct list_head prio_list;
	struct list_head node_list;
};

struct vmacache {
	u64 seqnum;
	struct vm_area_struct *vmas[4];
};

struct task_rss_stat {
	int events;
	int count[4];
};

typedef struct raw_spinlock raw_spinlock_t;

struct prev_cputime {
	u64 utime;
	u64 stime;
	raw_spinlock_t lock;
};

struct seqcount {
	unsigned int sequence;
};

typedef struct seqcount seqcount_t;

enum vtime_state {
	VTIME_INACTIVE = 0,
	VTIME_USER = 1,
	VTIME_SYS = 2,
};

struct vtime {
	seqcount_t seqcount;
	long long unsigned int starttime;
	enum vtime_state state;
	u64 utime;
	u64 stime;
	u64 gtime;
};

struct task_cputime {
	u64 utime;
	u64 stime;
	long long unsigned int sum_exec_runtime;
};

struct nameidata;

struct sem_undo_list;

struct sysv_sem {
	struct sem_undo_list *undo_list;
};

struct sysv_shm {
	struct list_head shm_clist;
};

typedef struct {
	long unsigned int sig[1];
} sigset_t;

struct sigpending {
	struct list_head list;
	sigset_t signal;
};

typedef struct {
	uid_t val;
} kuid_t;

struct seccomp_filter;

struct seccomp {
	int mode;
	struct seccomp_filter *filter;
};

struct wake_q_node {
	struct wake_q_node *next;
};

struct rb_root {
	struct rb_node *rb_node;
};

struct rb_root_cached {
	struct rb_root rb_root;
	struct rb_node *rb_leftmost;
};

struct task_io_accounting {
	u64 rchar;
	u64 wchar;
	u64 syscr;
	u64 syscw;
	u64 read_bytes;
	u64 write_bytes;
	u64 cancelled_write_bytes;
};

typedef struct {
	long unsigned int bits[1];
} nodemask_t;

struct futex_pi_state;

typedef atomic64_t atomic_long_t;

struct optimistic_spin_queue {
	atomic_t tail;
};

struct mutex {
	atomic_long_t owner;
	spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct list_head wait_list;
};

struct tlbflush_unmap_batch {};

struct page_frag {
	struct page *page;
	__u32 offset;
	__u32 size;
};

struct cpu_context {
	long unsigned int x19;
	long unsigned int x20;
	long unsigned int x21;
	long unsigned int x22;
	long unsigned int x23;
	long unsigned int x24;
	long unsigned int x25;
	long unsigned int x26;
	long unsigned int x27;
	long unsigned int x28;
	long unsigned int fp;
	long unsigned int sp;
	long unsigned int pc;
};

struct user_fpsimd_state {
	__int128 unsigned vregs[32];
	__u32 fpsr;
	__u32 fpcr;
	__u32 __reserved[2];
};

struct perf_event;

struct debug_info {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event *hbp_break[16];
	struct perf_event *hbp_watch[16];
};

struct thread_struct {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info debug;
	long: 64;
};

struct sched_class;

struct task_group;

struct mm_struct;

struct mem_cgroup;

struct pid;

struct completion;

struct cred;

struct fs_struct;

struct files_struct;

struct nsproxy;

struct signal_struct;

struct sighand_struct;

struct audit_context;

struct rt_mutex_waiter;

struct bio_list;

struct blk_plug;

struct reclaim_state;

struct backing_dev_info;

struct io_context;

struct kernel_siginfo;

typedef struct kernel_siginfo kernel_siginfo_t;

struct siginfo;

typedef struct siginfo siginfo_t;

struct css_set;

struct robust_list_head;

struct perf_event_context;

struct mempolicy;

struct numa_group;

struct rseq;

struct task_delay_info;

struct ftrace_ret_stack;

struct request_queue;

struct uprobe_task;

struct vm_struct;

struct task_struct {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct *mm;
	struct mm_struct *active_mm;
	struct vmacache vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct *real_parent;
	struct task_struct *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup *active_memcg;
	long int rh_reserved2;
	struct pid *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred *ptracer_cred;
	const struct cred *real_cred;
	const struct cred *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy *nsproxy;
	struct signal_struct *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct *oom_reaper_list;
	struct vm_struct *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct user_pt_regs {
	__u64 regs[31];
	__u64 sp;
	__u64 pc;
	__u64 pstate;
};

struct pt_regs {
	union {
		struct user_pt_regs user_regs;
		struct {
			u64 regs[31];
			u64 sp;
			u64 pc;
			u64 pstate;
		};
	};
	u64 orig_x0;
	s32 syscallno;
	u32 unused2;
	u64 orig_addr_limit;
	u64 unused;
	u64 stackframe[2];
};

struct qrwlock {
	union {
		atomic_t cnts;
		struct {
			u8 wlocked;
			u8 __lstate[3];
		};
	};
	arch_spinlock_t wait_lock;
};

typedef struct qrwlock arch_rwlock_t;

struct lock_class_key {};

struct lockdep_map {};

typedef struct {
	arch_rwlock_t raw_lock;
} rwlock_t;

enum ftr_type {
	FTR_EXACT = 0,
	FTR_LOWER_SAFE = 1,
	FTR_HIGHER_SAFE = 2,
};

struct arm64_ftr_bits {
	bool sign;
	bool visible;
	bool strict;
	enum ftr_type type;
	u8 shift;
	u8 width;
	s64 safe_val;
};

struct arm64_ftr_reg {
	const char *name;
	u64 strict_mask;
	u64 user_mask;
	u64 sys_val;
	u64 user_val;
	const struct arm64_ftr_bits *ftr_bits;
};

struct arch_hw_breakpoint_ctrl {
	u32 __reserved: 19;
	u32 len: 8;
	u32 type: 2;
	u32 privilege: 2;
	u32 enabled: 1;
};

struct arch_hw_breakpoint {
	u64 address;
	u64 trigger;
	struct arch_hw_breakpoint_ctrl ctrl;
};

enum perf_event_state {
	PERF_EVENT_STATE_DEAD = 4294967292,
	PERF_EVENT_STATE_EXIT = 4294967293,
	PERF_EVENT_STATE_ERROR = 4294967294,
	PERF_EVENT_STATE_OFF = 4294967295,
	PERF_EVENT_STATE_INACTIVE = 0,
	PERF_EVENT_STATE_ACTIVE = 1,
};

typedef struct {
	atomic_long_t a;
} local_t;

typedef struct {
	local_t a;
} local64_t;

struct perf_event_attr {
	__u32 type;
	__u32 size;
	__u64 config;
	union {
		__u64 sample_period;
		__u64 sample_freq;
	};
	__u64 sample_type;
	__u64 read_format;
	__u64 disabled: 1;
	__u64 inherit: 1;
	__u64 pinned: 1;
	__u64 exclusive: 1;
	__u64 exclude_user: 1;
	__u64 exclude_kernel: 1;
	__u64 exclude_hv: 1;
	__u64 exclude_idle: 1;
	__u64 mmap: 1;
	__u64 comm: 1;
	__u64 freq: 1;
	__u64 inherit_stat: 1;
	__u64 enable_on_exec: 1;
	__u64 task: 1;
	__u64 watermark: 1;
	__u64 precise_ip: 2;
	__u64 mmap_data: 1;
	__u64 sample_id_all: 1;
	__u64 exclude_host: 1;
	__u64 exclude_guest: 1;
	__u64 exclude_callchain_kernel: 1;
	__u64 exclude_callchain_user: 1;
	__u64 mmap2: 1;
	__u64 comm_exec: 1;
	__u64 use_clockid: 1;
	__u64 context_switch: 1;
	__u64 write_backward: 1;
	__u64 namespaces: 1;
	__u64 __reserved_1: 35;
	union {
		__u32 wakeup_events;
		__u32 wakeup_watermark;
	};
	__u32 bp_type;
	union {
		__u64 bp_addr;
		__u64 kprobe_func;
		__u64 uprobe_path;
		__u64 config1;
	};
	union {
		__u64 bp_len;
		__u64 kprobe_addr;
		__u64 probe_offset;
		__u64 config2;
	};
	__u64 branch_sample_type;
	__u64 sample_regs_user;
	__u32 sample_stack_user;
	__s32 clockid;
	__u64 sample_regs_intr;
	__u32 aux_watermark;
	__u16 sample_max_stack;
	__u16 __reserved_2;
};

struct hw_perf_event_extra {
	u64 config;
	unsigned int reg;
	int alloc;
	int idx;
};

struct hw_perf_event {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

struct wait_queue_head {
	spinlock_t lock;
	struct list_head head;
};

typedef struct wait_queue_head wait_queue_head_t;

struct irq_work {
	long unsigned int flags;
	struct llist_node llnode;
	void (*func)(struct irq_work *);
};

struct perf_addr_filters_head {
	struct list_head list;
	raw_spinlock_t lock;
	unsigned int nr_file_filters;
};

struct perf_sample_data;

typedef void (*perf_overflow_handler_t)(struct perf_event *, struct perf_sample_data *, struct pt_regs *);

struct ftrace_ops;

typedef void (*ftrace_func_t)(long unsigned int, long unsigned int, struct ftrace_ops *, struct pt_regs *);

struct ftrace_hash;

struct ftrace_ops_hash {
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex regex_lock;
};

struct ftrace_ops {
	ftrace_func_t func;
	struct ftrace_ops *next;
	long unsigned int flags;
	void *private;
	ftrace_func_t saved_func;
	struct ftrace_ops_hash local_hash;
	struct ftrace_ops_hash *func_hash;
	struct ftrace_ops_hash old_hash;
	long unsigned int trampoline;
	long unsigned int trampoline_size;
};

struct pmu;

struct ring_buffer;

struct fasync_struct;

struct pid_namespace;

struct bpf_prog;

struct trace_event_call;

struct event_filter;

struct perf_cgroup;

struct perf_event {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event *group_leader;
	struct pmu *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event hw;
	struct perf_event_context *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event *);
	struct callback_head callback_head;
	struct pid_namespace *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup *cgrp;
	struct list_head sb_list;
};

typedef struct {
	struct seqcount seqcount;
	spinlock_t lock;
} seqlock_t;

struct uid_gid_extent {
	u32 first;
	u32 lower_first;
	u32 count;
};

struct uid_gid_map {
	u32 nr_extents;
	union {
		struct uid_gid_extent extent[5];
		struct {
			struct uid_gid_extent *forward;
			struct uid_gid_extent *reverse;
		};
	};
};

typedef struct {
	gid_t val;
} kgid_t;

struct proc_ns_operations;

struct ns_common {
	atomic_long_t stashed;
	const struct proc_ns_operations *ops;
	unsigned int inum;
};

struct rw_semaphore {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct *owner;
};

struct work_struct;

typedef void (*work_func_t)(struct work_struct *);

struct work_struct {
	atomic_long_t data;
	struct list_head entry;
	work_func_t func;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct ctl_table;

struct ctl_table_root;

struct ctl_table_set;

struct ctl_dir;

struct ctl_node;

struct ctl_table_header {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root *root;
	struct ctl_table_set *set;
	struct ctl_dir *parent;
	struct ctl_node *node;
	struct hlist_head inodes;
};

struct ctl_dir {
	struct ctl_table_header header;
	struct rb_root root;
};

struct ctl_table_set {
	int (*is_seen)(struct ctl_table_set *);
	struct ctl_dir dir;
};

struct key;

struct ucounts;

struct user_namespace {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common ns;
	long unsigned int flags;
	struct key *persistent_keyring_register;
	struct rw_semaphore persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kstat {
	u32 result_mask;
	umode_t mode;
	unsigned int nlink;
	uint32_t blksize;
	u64 attributes;
	u64 attributes_mask;
	u64 ino;
	dev_t dev;
	dev_t rdev;
	kuid_t uid;
	kgid_t gid;
	loff_t size;
	struct timespec64 atime;
	struct timespec64 mtime;
	struct timespec64 ctime;
	struct timespec64 btime;
	u64 blocks;
};

enum node_states {
	N_POSSIBLE = 0,
	N_ONLINE = 1,
	N_NORMAL_MEMORY = 2,
	N_HIGH_MEMORY = 2,
	N_MEMORY = 3,
	N_CPU = 4,
	NR_NODE_STATES = 5,
};

typedef u64 pteval_t;

typedef u64 pmdval_t;

typedef u64 pgdval_t;

typedef struct {
	pteval_t pte;
} pte_t;

typedef struct {
	pmdval_t pmd;
} pmd_t;

typedef struct {
	pgdval_t pgd;
} pgd_t;

typedef struct {
	pteval_t pgprot;
} pgprot_t;

typedef struct {
	pgd_t pgd;
} pud_t;

typedef struct page *pgtable_t;

struct address_space;

struct kmem_cache;

struct dev_pagemap;

struct page {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup *mem_cgroup;
};

struct free_area {
	struct list_head free_list[5];
	long unsigned int nr_free;
};

struct zone_padding {
	char x[0];
};

enum numa_stat_item {
	NUMA_HIT = 0,
	NUMA_MISS = 1,
	NUMA_FOREIGN = 2,
	NUMA_INTERLEAVE_HIT = 3,
	NUMA_LOCAL = 4,
	NUMA_OTHER = 5,
	NR_VM_NUMA_STAT_ITEMS = 6,
};

enum zone_stat_item {
	NR_FREE_PAGES = 0,
	NR_ZONE_LRU_BASE = 1,
	NR_ZONE_INACTIVE_ANON = 1,
	NR_ZONE_ACTIVE_ANON = 2,
	NR_ZONE_INACTIVE_FILE = 3,
	NR_ZONE_ACTIVE_FILE = 4,
	NR_ZONE_UNEVICTABLE = 5,
	NR_ZONE_WRITE_PENDING = 6,
	NR_MLOCK = 7,
	NR_PAGETABLE = 8,
	NR_KERNEL_STACK_KB = 9,
	NR_BOUNCE = 10,
	NR_ZSPAGES = 11,
	NR_FREE_CMA_PAGES = 12,
	NR_VM_ZONE_STAT_ITEMS = 13,
};

enum node_stat_item {
	NR_LRU_BASE = 0,
	NR_INACTIVE_ANON = 0,
	NR_ACTIVE_ANON = 1,
	NR_INACTIVE_FILE = 2,
	NR_ACTIVE_FILE = 3,
	NR_UNEVICTABLE = 4,
	NR_SLAB_RECLAIMABLE = 5,
	NR_SLAB_UNRECLAIMABLE = 6,
	NR_ISOLATED_ANON = 7,
	NR_ISOLATED_FILE = 8,
	WORKINGSET_REFAULT = 9,
	WORKINGSET_ACTIVATE = 10,
	WORKINGSET_NODERECLAIM = 11,
	NR_ANON_MAPPED = 12,
	NR_FILE_MAPPED = 13,
	NR_FILE_PAGES = 14,
	NR_FILE_DIRTY = 15,
	NR_WRITEBACK = 16,
	NR_WRITEBACK_TEMP = 17,
	NR_SHMEM = 18,
	NR_SHMEM_THPS = 19,
	NR_SHMEM_PMDMAPPED = 20,
	NR_ANON_THPS = 21,
	NR_UNSTABLE_NFS = 22,
	NR_VMSCAN_WRITE = 23,
	NR_VMSCAN_IMMEDIATE = 24,
	NR_DIRTIED = 25,
	NR_WRITTEN = 26,
	NR_KERNEL_MISC_RECLAIMABLE = 27,
	WORKINGSET_RESTORE = 28,
	NR_VM_NODE_STAT_ITEMS = 29,
};

enum lru_list {
	LRU_INACTIVE_ANON = 0,
	LRU_ACTIVE_ANON = 1,
	LRU_INACTIVE_FILE = 2,
	LRU_ACTIVE_FILE = 3,
	LRU_UNEVICTABLE = 4,
	NR_LRU_LISTS = 5,
};

struct zone_reclaim_stat {
	long unsigned int recent_rotated[2];
	long unsigned int recent_scanned[2];
};

struct pglist_data;

struct lruvec {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data *pgdat;
};

struct per_cpu_pageset;

struct zone {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref {
	struct zone *zone;
	int zone_idx;
};

struct zonelist {
	struct zoneref _zonerefs[25];
};

enum zone_type {
	ZONE_DMA32 = 0,
	ZONE_NORMAL = 1,
	ZONE_MOVABLE = 2,
	__MAX_NR_ZONES = 3,
};

struct per_cpu_nodestat;

struct pglist_data {
	struct zone node_zones[3];
	struct zonelist node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

typedef unsigned int isolate_mode_t;

struct per_cpu_pages {
	int count;
	int high;
	int batch;
	struct list_head lists[3];
};

struct per_cpu_pageset {
	struct per_cpu_pages pcp;
	s8 expire;
	u16 vm_numa_stat_diff[6];
	s8 stat_threshold;
	s8 vm_stat_diff[13];
};

struct per_cpu_nodestat {
	s8 stat_threshold;
	s8 vm_node_stat_diff[29];
};

typedef struct cpumask cpumask_var_t[1];

typedef void (*smp_call_func_t)(void *);

struct __call_single_data {
	struct llist_node llist;
	smp_call_func_t func;
	void *info;
	unsigned int flags;
};

struct secondary_data {
	void *stack;
	struct task_struct *task;
	long int status;
};

enum arch_timer_erratum_match_type {
	ate_match_dt = 0,
	ate_match_local_cap_id = 1,
	ate_match_acpi_oem_info = 2,
};

struct clock_event_device;

struct arch_timer_erratum_workaround {
	enum arch_timer_erratum_match_type match_type;
	const void *id;
	const char *desc;
	u32 (*read_cntp_tval_el0)();
	u32 (*read_cntv_tval_el0)();
	u64 (*read_cntpct_el0)();
	u64 (*read_cntvct_el0)();
	int (*set_next_event_phys)(long unsigned int, struct clock_event_device *);
	int (*set_next_event_virt)(long unsigned int, struct clock_event_device *);
};

enum clock_event_state {
	CLOCK_EVT_STATE_DETACHED = 0,
	CLOCK_EVT_STATE_SHUTDOWN = 1,
	CLOCK_EVT_STATE_PERIODIC = 2,
	CLOCK_EVT_STATE_ONESHOT = 3,
	CLOCK_EVT_STATE_ONESHOT_STOPPED = 4,
};

struct clock_event_device {
	void (*event_handler)(struct clock_event_device *);
	int (*set_next_event)(long unsigned int, struct clock_event_device *);
	int (*set_next_ktime)(ktime_t, struct clock_event_device *);
	ktime_t next_event;
	u64 max_delta_ns;
	u64 min_delta_ns;
	u32 mult;
	u32 shift;
	enum clock_event_state state_use_accessors;
	unsigned int features;
	long unsigned int retries;
	int (*set_state_periodic)(struct clock_event_device *);
	int (*set_state_oneshot)(struct clock_event_device *);
	int (*set_state_oneshot_stopped)(struct clock_event_device *);
	int (*set_state_shutdown)(struct clock_event_device *);
	int (*tick_resume)(struct clock_event_device *);
	void (*broadcast)(const struct cpumask *);
	void (*suspend)(struct clock_event_device *);
	void (*resume)(struct clock_event_device *);
	long unsigned int min_delta_ticks;
	long unsigned int max_delta_ticks;
	const char *name;
	int rating;
	int irq;
	int bound_on;
	const struct cpumask *cpumask;
	struct list_head list;
	struct module *owner;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct timer_list {
	struct hlist_node entry;
	long unsigned int expires;
	void (*function)(struct timer_list *);
	u32 flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct workqueue_struct;

struct delayed_work {
	struct work_struct work;
	struct timer_list timer;
	struct workqueue_struct *wq;
	int cpu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct rcu_work {
	struct work_struct work;
	struct callback_head rcu;
	struct workqueue_struct *wq;
};

struct completion {
	unsigned int done;
	wait_queue_head_t wait;
};

typedef int (*notifier_fn_t)(struct notifier_block *, long unsigned int, void *);

struct notifier_block {
	notifier_fn_t notifier_call;
	struct notifier_block *next;
	int priority;
};

struct blocking_notifier_head {
	struct rw_semaphore rwsem;
	struct notifier_block *head;
};

struct cpu_topology {
	int thread_id;
	int core_id;
	int package_id;
	int llc_id;
	cpumask_t thread_sibling;
	cpumask_t core_sibling;
	cpumask_t llc_sibling;
};

enum pcpu_fc {
	PCPU_FC_AUTO = 0,
	PCPU_FC_EMBED = 1,
	PCPU_FC_PAGE = 2,
	PCPU_FC_NR = 3,
};

struct mem_section {
	long unsigned int section_mem_map;
	long unsigned int *pageblock_flags;
};

typedef int proc_handler(struct ctl_table *, int, void *, size_t *, loff_t *);

struct ctl_table_poll;

struct ctl_table {
	const char *procname;
	void *data;
	int maxlen;
	umode_t mode;
	struct ctl_table *child;
	proc_handler *proc_handler;
	struct ctl_table_poll *poll;
	void *extra1;
	void *extra2;
};

struct ctl_table_poll {
	atomic_t event;
	wait_queue_head_t wait;
};

struct ctl_node {
	struct rb_node node;
	struct ctl_table_header *header;
};

struct ctl_table_root {
	struct ctl_table_set default_set;
	struct ctl_table_set * (*lookup)(struct ctl_table_root *);
	void (*set_ownership)(struct ctl_table_header *, struct ctl_table *, kuid_t *, kgid_t *);
	int (*permissions)(struct ctl_table_header *, struct ctl_table *);
};

struct vfsmount;

struct dentry;

struct path {
	struct vfsmount *mnt;
	struct dentry *dentry;
};

enum rw_hint {
	WRITE_LIFE_NOT_SET = 0,
	WRITE_LIFE_NONE = 1,
	WRITE_LIFE_SHORT = 2,
	WRITE_LIFE_MEDIUM = 3,
	WRITE_LIFE_LONG = 4,
	WRITE_LIFE_EXTREME = 5,
};

enum pid_type {
	PIDTYPE_PID = 0,
	PIDTYPE_PGID = 1,
	PIDTYPE_SID = 2,
	PIDTYPE_TGID = 3,
	PIDTYPE_MAX = 4,
};

struct fown_struct {
	rwlock_t lock;
	struct pid *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file_ra_state {
	long unsigned int start;
	unsigned int size;
	unsigned int async_size;
	unsigned int ra_pages;
	unsigned int mmap_miss;
	loff_t prev_pos;
};

typedef u32 errseq_t;

struct file {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path f_path;
	struct inode *f_inode;
	const struct file_operations *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space *f_mapping;
	errseq_t f_wb_err;
};

struct kernel_cap_struct {
	__u32 cap[2];
};

typedef struct kernel_cap_struct kernel_cap_t;

struct user_struct;

struct group_info;

struct cred {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key *session_keyring;
	struct key *process_keyring;
	struct key *thread_keyring;
	struct key *request_key_auth;
	void *security;
	struct user_struct *user;
	struct user_namespace *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

enum umh_disable_depth {
	UMH_ENABLED = 0,
	UMH_FREEZING = 1,
	UMH_DISABLED = 2,
};

typedef __u64 Elf64_Addr;

typedef __u16 Elf64_Half;

typedef __u64 Elf64_Off;

typedef __u32 Elf64_Word;

typedef __u64 Elf64_Xword;

typedef __s64 Elf64_Sxword;

typedef struct {
	Elf64_Sxword d_tag;
	union {
		Elf64_Xword d_val;
		Elf64_Addr d_ptr;
	} d_un;
} Elf64_Dyn;

struct elf64_sym {
	Elf64_Word st_name;
	unsigned char st_info;
	unsigned char st_other;
	Elf64_Half st_shndx;
	Elf64_Addr st_value;
	Elf64_Xword st_size;
};

typedef struct elf64_sym Elf64_Sym;

struct elf64_shdr {
	Elf64_Word sh_name;
	Elf64_Word sh_type;
	Elf64_Xword sh_flags;
	Elf64_Addr sh_addr;
	Elf64_Off sh_offset;
	Elf64_Xword sh_size;
	Elf64_Word sh_link;
	Elf64_Word sh_info;
	Elf64_Xword sh_addralign;
	Elf64_Xword sh_entsize;
};

struct xarray_rh {};

struct xarray {
	spinlock_t xa_lock;
	gfp_t xa_flags;
	void *xa_head;
	size_t xarray_size_rh;
	struct xarray_rh xarray_rh;
};

struct idr {
	struct xarray idr_rt;
	unsigned int idr_base;
	unsigned int idr_next;
};

struct kernfs_root;

struct kernfs_elem_dir {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root *root;
};

struct kernfs_node;

struct kernfs_syscall_ops;

struct kernfs_root {
	struct kernfs_node *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink {
	struct kernfs_node *target_kn;
};

struct kernfs_ops;

struct kernfs_open_node;

struct kernfs_elem_attr {
	const struct kernfs_ops *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node *notify_next;
};

union kernfs_node_id {
	struct {
		u32 ino;
		u32 generation;
	};
	u64 id;
};

struct kernfs_iattrs;

struct kernfs_node {
	atomic_t count;
	atomic_t active;
	struct kernfs_node *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir dir;
		struct kernfs_elem_symlink symlink;
		struct kernfs_elem_attr attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file;

struct kernfs_ops {
	int (*open)(struct kernfs_open_file *);
	void (*release)(struct kernfs_open_file *);
	int (*seq_show)(struct seq_file *, void *);
	void * (*seq_start)(struct seq_file *, loff_t *);
	void * (*seq_next)(struct seq_file *, void *, loff_t *);
	void (*seq_stop)(struct seq_file *, void *);
	ssize_t (*read)(struct kernfs_open_file *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file *, struct vm_area_struct *);
	union {
		__poll_t (*poll)(struct kernfs_open_file *, struct poll_table_struct *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops {
	int (*remount_fs)(struct kernfs_root *, int *, char *);
	int (*show_options)(struct seq_file *, struct kernfs_root *);
	int (*mkdir)(struct kernfs_node *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node *);
	int (*rename)(struct kernfs_node *, struct kernfs_node *, const char *);
	int (*show_path)(struct seq_file *, struct kernfs_node *, struct kernfs_root *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations;

struct seq_file {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations *op;
	int poll_event;
	const struct file *file;
	void *private;
};

struct vm_operations_struct;

struct kernfs_open_file {
	struct kernfs_node *kn;
	struct file *file;
	struct seq_file *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct *vm_ops;
};

typedef int vm_fault_t;

enum page_entry_size {
	PE_SIZE_PTE = 0,
	PE_SIZE_PMD = 1,
	PE_SIZE_PUD = 2,
};

struct vm_fault;

struct vm_operations_struct {
	void (*open)(struct vm_area_struct *);
	void (*close)(struct vm_area_struct *);
	int (*split)(struct vm_area_struct *, long unsigned int);
	int (*mremap)(struct vm_area_struct *);
	vm_fault_t (*fault)(struct vm_fault *);
	vm_fault_t (*huge_fault)(struct vm_fault *, enum page_entry_size);
	void (*map_pages)(struct vm_fault *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct *);
	vm_fault_t (*page_mkwrite)(struct vm_fault *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault *);
	int (*access)(struct vm_area_struct *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct *);
	int (*set_policy)(struct vm_area_struct *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct *, long unsigned int);
	struct page * (*find_special_page)(struct vm_area_struct *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc)(struct file *, wait_queue_head_t *, struct poll_table_struct *);

struct poll_table_struct {
	poll_queue_proc _qproc;
	__poll_t _key;
};

struct userfaultfd_ctx;

struct vm_userfaultfd_ctx {
	struct userfaultfd_ctx *ctx;
};

struct anon_vma;

struct vm_area_struct {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct *vm_next;
	struct vm_area_struct *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct *vm_ops;
	long unsigned int vm_pgoff;
	struct file *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

enum kobj_ns_type {
	KOBJ_NS_TYPE_NONE = 0,
	KOBJ_NS_TYPE_NET = 1,
	KOBJ_NS_TYPES = 2,
};

struct sock;

struct kobj_ns_type_operations {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct attribute {
	const char *name;
	umode_t mode;
};

struct kobject;

struct bin_attribute;

struct attribute_group {
	const char *name;
	umode_t (*is_visible)(struct kobject *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject *, struct bin_attribute *, int);
	struct attribute **attrs;
	struct bin_attribute **bin_attrs;
};

struct refcount_struct {
	atomic_t refs;
};

typedef struct refcount_struct refcount_t;

struct kref {
	refcount_t refcount;
};

struct kset;

struct kobj_type;

struct kobject {
	const char *name;
	struct list_head entry;
	struct kobject *parent;
	struct kset *kset;
	struct kobj_type *ktype;
	struct kernfs_node *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file *, struct kobject *, struct bin_attribute *, char *, loff_t, size_t);
	ssize_t (*write)(struct file *, struct kobject *, struct bin_attribute *, char *, loff_t, size_t);
	int (*mmap)(struct file *, struct kobject *, struct bin_attribute *, struct vm_area_struct *);
};

struct sysfs_ops {
	ssize_t (*show)(struct kobject *, struct attribute *, char *);
	ssize_t (*store)(struct kobject *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops;

struct kset {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject kobj;
	const struct kset_uevent_ops *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type {
	void (*release)(struct kobject *);
	const struct sysfs_ops *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject *);
	const void * (*namespace)(struct kobject *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_uevent_env {
	char *argv[3];
	char *envp[32];
	int envp_idx;
	char buf[2048];
	int buflen;
};

struct kset_uevent_ops {
	int (* const filter)(struct kset *, struct kobject *);
	const char * (* const name)(struct kset *, struct kobject *);
	int (* const uevent)(struct kset *, struct kobject *, struct kobj_uevent_env *);
};

struct kobj_attribute {
	struct attribute attr;
	ssize_t (*show)(struct kobject *, struct kobj_attribute *, char *);
	ssize_t (*store)(struct kobject *, struct kobj_attribute *, const char *, size_t);
};

struct kernel_param;

struct kernel_param_ops {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param *);
	int (*get)(char *, const struct kernel_param *);
	void (*free)(void *);
};

struct kparam_string;

struct kparam_array;

struct kernel_param {
	const char *name;
	struct module *mod;
	const struct kernel_param_ops *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array *arr;
	};
};

struct kparam_string {
	unsigned int maxlen;
	char *string;
};

struct kparam_array {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops *ops;
	void *elem;
};

enum module_state {
	MODULE_STATE_LIVE = 0,
	MODULE_STATE_COMING = 1,
	MODULE_STATE_GOING = 2,
	MODULE_STATE_UNFORMED = 3,
};

struct module_param_attrs;

struct module_kobject {
	struct kobject kobj;
	struct module *mod;
	struct kobject *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct latch_tree_node {
	struct rb_node node[2];
};

struct mod_tree_node {
	struct module *mod;
	struct latch_tree_node node;
};

struct module_layout {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node mtn;
};

struct mod_plt_sec {
	struct elf64_shdr *plt;
	int plt_num_entries;
	int plt_max_entries;
};

struct plt_entry;

struct mod_arch_specific {
	struct mod_plt_sec core;
	struct mod_plt_sec init;
	struct plt_entry *ftrace_trampoline;
};

struct mod_kallsyms {
	Elf64_Sym *symtab;
	unsigned int num_symtab;
	char *strtab;
};

struct module_sect_attrs;

struct module_notes_attrs;

struct module_attribute;

struct exception_table_entry;

struct tracepoint;

struct trace_eval_map;

struct bpf_raw_event_map;

struct module {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject mkobj;
	struct module_attribute *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout core_layout;
	struct module_layout init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct plt_entry {
	__le32 mov0;
	__le32 mov1;
	__le32 mov2;
	__le32 br;
};

struct module_attribute {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute *, struct module_kobject *, char *);
	ssize_t (*store)(struct module_attribute *, struct module_kobject *, const char *, size_t);
	void (*setup)(struct module *, const char *);
	int (*test)(struct module *);
	void (*free)(struct module *);
};

struct bpf_raw_event_map {
	struct tracepoint *tp;
	void *bpf_func;
	u32 num_args;
	long: 32;
	long: 64;
};

struct exception_table_entry {
	int insn;
	int fixup;
};

struct tracepoint_func;

struct tracepoint {
	const char *name;
	struct static_key key;
	int (*regfunc)();
	void (*unregfunc)();
	struct tracepoint_func *funcs;
};

struct trace_event_functions;

struct trace_event {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions *funcs;
};

struct trace_event_class;

struct bpf_prog_array;

struct trace_event_call {
	struct list_head list;
	struct trace_event_class *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array *prog_array;
	int (*perf_perm)(struct trace_event_call *, struct perf_event *);
};

struct trace_eval_map {
	const char *system;
	const char *eval_string;
	long unsigned int eval_value;
};

struct hlist_bl_node;

struct hlist_bl_head {
	struct hlist_bl_node *first;
};

struct hlist_bl_node {
	struct hlist_bl_node *next;
	struct hlist_bl_node **pprev;
};

struct lockref {
	union {
		__u64 lock_count;
		struct {
			spinlock_t lock;
			int count;
		};
	};
};

struct qstr {
	union {
		struct {
			u32 hash;
			u32 len;
		};
		u64 hash_len;
	};
	const unsigned char *name;
};

struct dentry_stat_t {
	long int nr_dentry;
	long int nr_unused;
	long int age_limit;
	long int want_pages;
	long int nr_negative;
	long int dummy;
};

struct dentry_operations;

struct super_block;

struct dentry {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry *d_parent;
	struct qstr d_name;
	struct inode *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations *d_op;
	struct super_block *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations;

struct address_space {
	struct inode *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct posix_acl;

struct inode_operations;

struct bdi_writeback;

struct file_lock_context;

struct block_device;

struct cdev;

struct fsnotify_mark_connector;

struct inode {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations *i_op;
	struct super_block *i_sb;
	struct address_space *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device *i_bdev;
		struct cdev *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations {
	int (*d_revalidate)(struct dentry *, unsigned int);
	int (*d_weak_revalidate)(struct dentry *, unsigned int);
	int (*d_hash)(const struct dentry *, struct qstr *);
	int (*d_compare)(const struct dentry *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry *);
	int (*d_init)(struct dentry *);
	void (*d_release)(struct dentry *);
	void (*d_prune)(struct dentry *);
	void (*d_iput)(struct dentry *, struct inode *);
	char * (*d_dname)(struct dentry *, char *, int);
	struct vfsmount * (*d_automount)(struct path *);
	int (*d_manage)(const struct path *, bool);
	struct dentry * (*d_real)(struct dentry *, const struct inode *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct mtd_info;

typedef long long int qsize_t;

struct quota_format_type;

struct mem_dqinfo {
	struct quota_format_type *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops;

struct quota_info {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode *files[3];
	struct mem_dqinfo info[3];
	const struct quota_format_ops *ops[3];
};

enum rcu_sync_type {
	RCU_SYNC = 0,
	RCU_SCHED_SYNC = 1,
	RCU_BH_SYNC = 2,
};

struct rcu_sync {
	int gp_state;
	int gp_count;
	wait_queue_head_t gp_wait;
	int cb_state;
	struct callback_head cb_head;
	enum rcu_sync_type gp_type;
};

struct rcuwait {
	struct task_struct *task;
};

struct percpu_rw_semaphore {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore rw_sem;
	struct rcuwait writer;
	int readers_block;
};

struct sb_writers {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore rw_sem[3];
};

typedef struct {
	__u8 b[16];
} uuid_t;

struct shrink_control;

struct shrinker {
	long unsigned int (*count_objects)(struct shrinker *, struct shrink_control *);
	long unsigned int (*scan_objects)(struct shrinker *, struct shrink_control *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct list_lru_node;

struct list_lru {
	struct list_lru_node *node;
	struct list_head list;
	int shrinker_id;
};

struct file_system_type;

struct super_operations;

struct dquot_operations;

struct quotactl_ops;

struct export_operations;

struct xattr_handler;

struct super_block {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type *s_type;
	const struct super_operations *s_op;
	const struct dquot_operations *dq_op;
	const struct quotactl_ops *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info s_dquot;
	struct sb_writers s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup *memcg;
};

struct percpu_ref;

typedef void percpu_ref_func_t(struct percpu_ref *);

struct percpu_ref {
	atomic_long_t count;
	long unsigned int percpu_count_ptr;
	percpu_ref_func_t *release;
	percpu_ref_func_t *confirm_switch;
	bool force_atomic: 1;
	struct callback_head rcu;
};

struct cgroup;

struct cgroup_subsys;

struct cgroup_subsys_state {
	struct cgroup *cgroup;
	struct cgroup_subsys *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state *parent;
};

struct mem_cgroup_id {
	int id;
	union {
		refcount_t ref;
		struct {
			atomic_t ref;
		} __UNIQUE_ID_rh_kabi_hide36;
		union {		};
	};
};

struct page_counter {
	atomic_long_t usage;
	long unsigned int min;
	long unsigned int low;
	long unsigned int max;
	struct page_counter *parent;
	long unsigned int emin;
	atomic_long_t min_usage;
	atomic_long_t children_min_usage;
	long unsigned int elow;
	atomic_long_t low_usage;
	atomic_long_t children_low_usage;
	long unsigned int watermark;
	long unsigned int failcnt;
};

struct vmpressure {
	long unsigned int scanned;
	long unsigned int reclaimed;
	long unsigned int tree_scanned;
	long unsigned int tree_reclaimed;
	struct spinlock sr_lock;
	struct list_head events;
	struct mutex events_lock;
	struct work_struct work;
};

struct cgroup_file {
	struct kernfs_node *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_threshold_ary;

struct mem_cgroup_thresholds {
	struct mem_cgroup_threshold_ary *primary;
	struct mem_cgroup_threshold_ary *spare;
};

struct memcg_padding {
	char x[0];
};

enum memcg_kmem_state {
	KMEM_NONE = 0,
	KMEM_ALLOCATED = 1,
	KMEM_ONLINE = 2,
};

struct percpu_counter {
	raw_spinlock_t lock;
	s64 count;
	struct list_head list;
	s32 *counters;
};

struct fprop_global {
	struct percpu_counter events;
	unsigned int period;
	seqcount_t sequence;
};

struct wb_domain {
	spinlock_t lock;
	struct fprop_global completions;
	struct timer_list period_timer;
	long unsigned int period_time;
	long unsigned int dirty_limit_tstamp;
	long unsigned int dirty_limit;
};

struct mem_cgroup_stat_cpu;

struct mem_cgroup_per_node;

struct mem_cgroup {
	struct cgroup_subsys_state css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file events_file;
	struct cgroup_file swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct list_lru_one {
	struct list_head list;
	long int nr_items;
};

struct list_lru_memcg {
	struct callback_head rcu;
	struct list_lru_one *lru[0];
};

struct list_lru_node {
	spinlock_t lock;
	struct list_lru_one lru;
	struct list_lru_memcg *memcg_lrus;
	long int nr_items;
	long: 64;
	long: 64;
};

struct upid {
	int nr;
	struct pid_namespace *ns;
};

struct fs_pin;

struct pid_namespace {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace *parent;
	struct vfsmount *proc_mnt;
	struct dentry *proc_self;
	struct dentry *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common ns;
};

struct pid {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid numbers[1];
};

struct mm_rss_stat {
	atomic_long_t count[4];
};

typedef struct {
	atomic64_t id;
	void *vdso;
	long unsigned int flags;
} mm_context_t;

struct kioctx_table;

struct xol_area;

struct uprobes_state {
	struct xol_area *xol_area;
};

struct linux_binfmt;

struct core_state;

struct mmu_notifier_mm;

struct mm_struct {
	struct {
		struct vm_area_struct *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct *owner;
		struct user_namespace *user_ns;
		struct file *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct arch_uprobe_task {};

enum uprobe_task_state {
	UTASK_RUNNING = 0,
	UTASK_SSTEP = 1,
	UTASK_SSTEP_ACK = 2,
	UTASK_SSTEP_TRAPPED = 3,
};

struct uprobe;

struct return_instance;

struct uprobe_task {
	enum uprobe_task_state state;
	union {
		struct {
			struct arch_uprobe_task autask;
			long unsigned int vaddr;
		};
		struct {
			struct callback_head dup_xol_work;
			long unsigned int dup_xol_addr;
		};
	};
	struct uprobe *active_uprobe;
	long unsigned int xol_vaddr;
	struct return_instance *return_instances;
	unsigned int depth;
};

struct return_instance {
	struct uprobe *uprobe;
	long unsigned int func;
	long unsigned int stack;
	long unsigned int orig_ret_vaddr;
	bool chained;
	struct return_instance *next;
};

typedef void (*bp_hardening_cb_t)();

struct bp_hardening_data {
	int hyp_vectors_slot;
	bp_hardening_cb_t fn;
};

typedef int (*dev_page_fault_t)(struct vm_area_struct *, long unsigned int, const struct page *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t)(struct page *, void *);

struct vmem_altmap {
	const long unsigned int base_pfn;
	const long unsigned int reserve;
	long unsigned int free;
	long unsigned int align;
	long unsigned int alloc;
};

struct resource {
	resource_size_t start;
	resource_size_t end;
	const char *name;
	long unsigned int flags;
	long unsigned int desc;
	struct resource *parent;
	struct resource *sibling;
	struct resource *child;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

enum memory_type {
	MEMORY_DEVICE_PRIVATE = 1,
	MEMORY_DEVICE_PUBLIC = 2,
	MEMORY_DEVICE_FS_DAX = 3,
	MEMORY_DEVICE_PCI_P2PDMA = 4,
};

struct device;

struct dev_pagemap {
	dev_page_fault_t page_fault;
	dev_page_free_t page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct anon_vma {
	struct anon_vma *root;
	struct rw_semaphore rwsem;
	atomic_t refcount;
	unsigned int degree;
	struct anon_vma *parent;
	struct rb_root_cached rb_root;
};

struct mempolicy {
	atomic_t refcnt;
	short unsigned int mode;
	short unsigned int flags;
	union {
		short int preferred_node;
		nodemask_t nodes;
	} v;
	union {
		nodemask_t cpuset_mems_allowed;
		nodemask_t user_nodemask;
	} w;
};

struct core_thread {
	struct task_struct *task;
	struct core_thread *next;
};

struct core_state {
	atomic_t nr_threads;
	struct core_thread dumper;
	struct completion startup;
};

struct linux_binprm;

struct coredump_params;

struct linux_binfmt {
	struct list_head lh;
	struct module *module;
	int (*load_binary)(struct linux_binprm *);
	int (*load_shlib)(struct file *);
	int (*core_dump)(struct coredump_params *);
	long unsigned int min_coredump;
};

struct vm_fault {
	struct vm_area_struct *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page *cow_page;
	struct mem_cgroup *memcg;
	struct page *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t prealloc_pte;
};

struct fiemap_extent {
	__u64 fe_logical;
	__u64 fe_physical;
	__u64 fe_length;
	__u64 fe_reserved64[2];
	__u32 fe_flags;
	__u32 fe_reserved[3];
};

enum migrate_mode {
	MIGRATE_ASYNC = 0,
	MIGRATE_SYNC_LIGHT = 1,
	MIGRATE_SYNC = 2,
	MIGRATE_SYNC_NO_COPY = 3,
};

struct delayed_call {
	void (*fn)(void *);
	void *arg;
};

typedef struct {
	__u8 b[16];
} guid_t;

struct timerqueue_head {
	struct rb_root head;
	struct timerqueue_node *next;
};

struct hrtimer_rh {};

struct hrtimer_cpu_base;

struct hrtimer_clock_base {
	struct hrtimer_cpu_base *cpu_base;
	unsigned int index;
	clockid_t clockid;
	seqcount_t seq;
	struct hrtimer *running;
	struct timerqueue_head active;
	ktime_t (*get_time)();
	ktime_t offset;
};

struct hrtimer_cpu_base {
	raw_spinlock_t lock;
	unsigned int cpu;
	unsigned int active_bases;
	unsigned int clock_was_set_seq;
	unsigned int hres_active: 1;
	unsigned int in_hrtirq: 1;
	unsigned int hang_detected: 1;
	unsigned int softirq_activated: 1;
	unsigned int nr_events;
	short unsigned int nr_retries;
	short unsigned int nr_hangs;
	unsigned int max_hang_time;
	ktime_t expires_next;
	struct hrtimer *next_timer;
	ktime_t softirq_expires_next;
	struct hrtimer *softirq_next_timer;
	struct hrtimer_clock_base clock_base[8];
};

struct tick_device;

struct rlimit {
	__kernel_ulong_t rlim_cur;
	__kernel_ulong_t rlim_max;
};

typedef void __signalfn_t(int);

typedef __signalfn_t *__sighandler_t;

typedef void __restorefn_t();

typedef __restorefn_t *__sigrestore_t;

union sigval {
	int sival_int;
	void *sival_ptr;
};

typedef union sigval sigval_t;

union __sifields {
	struct {
		__kernel_pid_t _pid;
		__kernel_uid32_t _uid;
	} _kill;
	struct {
		__kernel_timer_t _tid;
		int _overrun;
		sigval_t _sigval;
		int _sys_private;
	} _timer;
	struct {
		__kernel_pid_t _pid;
		__kernel_uid32_t _uid;
		sigval_t _sigval;
	} _rt;
	struct {
		__kernel_pid_t _pid;
		__kernel_uid32_t _uid;
		int _status;
		__kernel_clock_t _utime;
		__kernel_clock_t _stime;
	} _sigchld;
	struct {
		void *_addr;
		union {
			short int _addr_lsb;
			struct {
				char _dummy_bnd[8];
				void *_lower;
				void *_upper;
			} _addr_bnd;
			struct {
				char _dummy_pkey[8];
				__u32 _pkey;
			} _addr_pkey;
		};
	} _sigfault;
	struct {
		long int _band;
		int _fd;
	} _sigpoll;
	struct {
		void *_call_addr;
		int _syscall;
		unsigned int _arch;
	} _sigsys;
};

struct siginfo {
	union {
		struct {
			int si_signo;
			int si_errno;
			int si_code;
			union __sifields _sifields;
		};
		int _si_pad[32];
	};
};

struct kernel_siginfo {
	struct {
		int si_signo;
		int si_errno;
		int si_code;
		union __sifields _sifields;
	};
};

struct ratelimit_state {
	raw_spinlock_t lock;
	int interval;
	int burst;
	int printed;
	int missed;
	long unsigned int begin;
	long unsigned int flags;
};

struct user_struct {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key *uid_keyring;
	struct key *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct sigaction {
	__sighandler_t sa_handler;
	long unsigned int sa_flags;
	__sigrestore_t sa_restorer;
	sigset_t sa_mask;
};

struct k_sigaction {
	struct sigaction sa;
};

struct rseq {
	__u32 cpu_id_start;
	__u32 cpu_id;
	union {
		__u64 ptr64;
		__u64 ptr;
	} rseq_cs;
	__u32 flags;
	long: 32;
	long: 64;
};

struct rq;

struct task_struct___2;

struct rq_flags;

struct sched_class {
	const struct sched_class *next;
	void (*enqueue_task)(struct rq *, struct task_struct___2 *, int);
	void (*dequeue_task)(struct rq *, struct task_struct___2 *, int);
	void (*yield_task)(struct rq *);
	bool (*yield_to_task)(struct rq *, struct task_struct___2 *, bool);
	void (*check_preempt_curr)(struct rq *, struct task_struct___2 *, int);
	struct task_struct___2 * (*pick_next_task)(struct rq *, struct task_struct___2 *, struct rq_flags *);
	void (*put_prev_task)(struct rq *, struct task_struct___2 *);
	int (*select_task_rq)(struct task_struct___2 *, int, int, int);
	union {
		void (*migrate_task_rq)(struct task_struct___2 *, int);
		struct {
			void (*migrate_task_rq)(struct task_struct___2 *);
		} __UNIQUE_ID_rh_kabi_hide71;
		union {		};
	};
	void (*task_woken)(struct rq *, struct task_struct___2 *);
	void (*set_cpus_allowed)(struct task_struct___2 *, const struct cpumask *);
	void (*rq_online)(struct rq *);
	void (*rq_offline)(struct rq *);
	void (*set_curr_task)(struct rq *);
	void (*task_tick)(struct rq *, struct task_struct___2 *, int);
	void (*task_fork)(struct task_struct___2 *);
	void (*task_dead)(struct task_struct___2 *);
	void (*switched_from)(struct rq *, struct task_struct___2 *);
	void (*switched_to)(struct rq *, struct task_struct___2 *);
	void (*prio_changed)(struct rq *, struct task_struct___2 *, int);
	unsigned int (*get_rr_interval)(struct rq *, struct task_struct___2 *);
	void (*update_curr)(struct rq *);
	void (*task_change_group)(struct task_struct___2 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct uts_namespace;

struct ipc_namespace;

struct mnt_namespace;

struct net;

struct cgroup_namespace;

struct nsproxy {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace *cgroup_ns;
};

struct cpu_itimer {
	u64 expires;
	u64 incr;
};

struct task_cputime_atomic {
	atomic64_t utime;
	atomic64_t stime;
	atomic64_t sum_exec_runtime;
};

struct thread_group_cputimer {
	struct task_cputime_atomic cputime_atomic;
	bool running;
	bool checking_timer;
};

struct pacct_struct {
	int ac_flag;
	long int ac_exitcode;
	long unsigned int ac_mem;
	u64 ac_utime;
	u64 ac_stime;
	long unsigned int ac_minflt;
	long unsigned int ac_majflt;
};

struct tty_struct;

struct autogroup;

struct taskstats;

struct tty_audit_buf;

struct signal_struct {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sighand_struct {
	atomic_t count;
	struct k_sigaction action[64];
	spinlock_t siglock;
	wait_queue_head_t signalfd_wqh;
};

struct bio;

struct bio_list {
	struct bio *head;
	struct bio *tail;
};

struct blk_plug {
	struct list_head mq_list;
	struct list_head cb_list;
	short unsigned int rq_count;
	bool multiple_queues;
};

struct reclaim_state {
	long unsigned int reclaimed_slab;
};

typedef int congested_fn(void *, int);

struct fprop_local_percpu {
	struct percpu_counter events;
	unsigned int period;
	raw_spinlock_t lock;
};

enum wb_reason {
	WB_REASON_BACKGROUND = 0,
	WB_REASON_VMSCAN = 1,
	WB_REASON_SYNC = 2,
	WB_REASON_PERIODIC = 3,
	WB_REASON_LAPTOP_TIMER = 4,
	WB_REASON_FREE_MORE_MEM = 5,
	WB_REASON_FS_FREE_SPACE = 6,
	WB_REASON_FORKER_THREAD = 7,
	WB_REASON_MAX = 8,
};

struct bdi_writeback_congested;

struct bdi_writeback {
	struct backing_dev_info *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state *memcg_css;
	struct cgroup_subsys_state *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device *dev;
	struct device *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry *debug_dir;
	struct dentry *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq;

struct io_context {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set {
	struct cgroup_subsys_state *subsys[13];
	refcount_t refcount;
	struct css_set *dom_cset;
	struct cgroup *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup *mg_src_cgrp;
	struct cgroup *mg_dst_cgrp;
	struct css_set *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_groups {
	struct rb_root tree;
	u64 index;
};

struct perf_event_context {
	struct pmu *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct task_delay_info {
	raw_spinlock_t lock;
	unsigned int flags;
	u64 blkio_start;
	u64 blkio_delay;
	u64 swapin_delay;
	u32 blkio_count;
	u32 swapin_count;
	u64 freepages_start;
	u64 freepages_delay;
	u32 freepages_count;
	u32 thrashing_count;
	u64 thrashing_start;
	u64 thrashing_delay;
};

struct ftrace_ret_stack {
	long unsigned int ret;
	long unsigned int func;
	long long unsigned int calltime;
};

typedef unsigned int blk_qc_t;

typedef blk_qc_t make_request_fn(struct request_queue *, struct bio *);

struct request;

typedef int dma_drain_needed_fn(struct request *);

struct blk_integrity_profile;

struct blk_integrity {
	const struct blk_integrity_profile *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct blk_rq_stat {
	u64 mean;
	u64 min;
	u64 max;
	u32 nr_samples;
	u64 batch;
};

enum blk_zoned_model {
	BLK_ZONED_NONE = 0,
	BLK_ZONED_HA = 1,
	BLK_ZONED_HM = 2,
};

struct queue_limits {
	long unsigned int bounce_pfn;
	long unsigned int seg_boundary_mask;
	long unsigned int virt_boundary_mask;
	unsigned int max_hw_sectors;
	unsigned int max_dev_sectors;
	unsigned int chunk_sectors;
	unsigned int max_sectors;
	unsigned int max_segment_size;
	unsigned int physical_block_size;
	unsigned int alignment_offset;
	unsigned int io_min;
	unsigned int io_opt;
	unsigned int max_discard_sectors;
	unsigned int max_hw_discard_sectors;
	unsigned int max_write_same_sectors;
	unsigned int max_write_zeroes_sectors;
	unsigned int discard_granularity;
	unsigned int discard_alignment;
	short unsigned int logical_block_size;
	short unsigned int max_segments;
	short unsigned int max_integrity_segments;
	short unsigned int max_discard_segments;
	unsigned char misaligned;
	unsigned char discard_misaligned;
	unsigned char cluster;
	unsigned char raid_partial_stripes_expensive;
	enum blk_zoned_model zoned;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct bsg_ops;

struct bsg_class_device {
	struct device *class_dev;
	int minor;
	struct request_queue *queue;
	const struct bsg_ops *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void *mempool_alloc_t(gfp_t, void *);

typedef void mempool_free_t(void *, void *);

struct mempool_s {
	spinlock_t lock;
	int min_nr;
	int curr_nr;
	void **elements;
	void *pool_data;
	mempool_alloc_t *alloc;
	mempool_free_t *free;
	wait_queue_head_t wait;
};

typedef struct mempool_s mempool_t;

struct bio_set {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue;

struct blk_queue_stats;

struct rq_qos;

struct blk_mq_ops;

struct blk_mq_ctx;

struct blk_mq_hw_ctx;

struct blk_stat_callback;

struct blkcg_gq;

struct blk_trace;

struct blk_flush_queue;

struct throtl_data;

struct blk_mq_tag_set;

struct request_queue {
	struct list_head queue_head;
	struct request *last_merge;
	struct elevator_queue *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn *make_request_fn;
	dma_drain_needed_fn *dma_drain_needed;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject kobj;
	struct kobject *mq_kobj;
	struct blk_integrity integrity;
	struct device *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide38;
		union {		};
	};
	struct bsg_class_device bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set bio_split;
	struct dentry *debugfs_dir;
	struct dentry *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct {
	struct vm_struct *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union {
	struct task_struct task;
	long unsigned int stack[8192];
};

struct io_cq {
	struct request_queue *q;
	struct io_context *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct files_stat_struct {
	long unsigned int nr_files;
	long unsigned int nr_free_files;
	long unsigned int max_files;
};

struct inodes_stat_t {
	long int nr_inodes;
	long int nr_unused;
	long int dummy[5];
};

struct kiocb {
	struct file *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file *ia_file;
};

typedef __kernel_uid32_t projid_t;

typedef struct {
	projid_t val;
} kprojid_t;

enum quota_type {
	USRQUOTA = 0,
	GRPQUOTA = 1,
	PRJQUOTA = 2,
};

struct kqid {
	union {
		kuid_t uid;
		kgid_t gid;
		kprojid_t projid;
	};
	enum quota_type type;
};

struct mem_dqblk {
	qsize_t dqb_bhardlimit;
	qsize_t dqb_bsoftlimit;
	qsize_t dqb_curspace;
	qsize_t dqb_rsvspace;
	qsize_t dqb_ihardlimit;
	qsize_t dqb_isoftlimit;
	qsize_t dqb_curinodes;
	time64_t dqb_btime;
	time64_t dqb_itime;
};

struct dquot {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type {
	int qf_fmt_id;
	const struct quota_format_ops *qf_ops;
	struct module *qf_owner;
	struct quota_format_type *qf_next;
};

struct dqstats {
	int stat[8];
	struct percpu_counter counter[8];
};

struct quota_format_ops {
	int (*check_quota_file)(struct super_block *, int);
	int (*read_file_info)(struct super_block *, int);
	int (*write_file_info)(struct super_block *, int);
	int (*free_file_info)(struct super_block *, int);
	int (*read_dqblk)(struct dquot *);
	int (*commit_dqblk)(struct dquot *);
	int (*release_dqblk)(struct dquot *);
	int (*get_next_id)(struct super_block *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations {
	int (*write_dquot)(struct dquot *);
	struct dquot * (*alloc_dquot)(struct super_block *, int);
	void (*destroy_dquot)(struct dquot *);
	int (*acquire_dquot)(struct dquot *);
	int (*release_dquot)(struct dquot *);
	int (*mark_dirty)(struct dquot *);
	int (*write_info)(struct super_block *, int);
	qsize_t * (*get_reserved_space)(struct inode *);
	int (*get_projid)(struct inode *, kprojid_t *);
	int (*get_inode_usage)(struct inode *, qsize_t *);
	int (*get_next_id)(struct super_block *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct qc_dqblk {
	int d_fieldmask;
	u64 d_spc_hardlimit;
	u64 d_spc_softlimit;
	u64 d_ino_hardlimit;
	u64 d_ino_softlimit;
	u64 d_space;
	u64 d_ino_count;
	s64 d_ino_timer;
	s64 d_spc_timer;
	int d_ino_warns;
	int d_spc_warns;
	u64 d_rt_spc_hardlimit;
	u64 d_rt_spc_softlimit;
	u64 d_rt_space;
	s64 d_rt_spc_timer;
	int d_rt_spc_warns;
};

struct qc_type_state {
	unsigned int flags;
	unsigned int spc_timelimit;
	unsigned int ino_timelimit;
	unsigned int rt_spc_timelimit;
	unsigned int spc_warnlimit;
	unsigned int ino_warnlimit;
	unsigned int rt_spc_warnlimit;
	long long unsigned int ino;
	blkcnt_t blocks;
	blkcnt_t nextents;
};

struct qc_state {
	unsigned int s_incoredqs;
	struct qc_type_state s_state[3];
};

struct qc_info {
	int i_fieldmask;
	unsigned int i_flags;
	unsigned int i_spc_timelimit;
	unsigned int i_ino_timelimit;
	unsigned int i_rt_spc_timelimit;
	unsigned int i_spc_warnlimit;
	unsigned int i_ino_warnlimit;
	unsigned int i_rt_spc_warnlimit;
};

struct quotactl_ops {
	int (*quota_on)(struct super_block *, int, int, const struct path *);
	int (*quota_off)(struct super_block *, int);
	int (*quota_enable)(struct super_block *, unsigned int);
	int (*quota_disable)(struct super_block *, unsigned int);
	int (*quota_sync)(struct super_block *, int);
	int (*set_info)(struct super_block *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block *, struct qc_state *);
	int (*rm_xquota)(struct super_block *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control;

struct swap_info_struct;

struct address_space_operations {
	int (*writepage)(struct page *, struct writeback_control *);
	int (*readpage)(struct file *, struct page *);
	int (*writepages)(struct address_space *, struct writeback_control *);
	int (*set_page_dirty)(struct page *);
	int (*readpages)(struct file *, struct address_space *, struct list_head *, unsigned int);
	int (*write_begin)(struct file *, struct address_space *, loff_t, unsigned int, unsigned int, struct page **, void **);
	int (*write_end)(struct file *, struct address_space *, loff_t, unsigned int, unsigned int, struct page *, void *);
	sector_t (*bmap)(struct address_space *, sector_t);
	void (*invalidatepage)(struct page *, unsigned int, unsigned int);
	int (*releasepage)(struct page *, gfp_t);
	void (*freepage)(struct page *);
	ssize_t (*direct_IO)(struct kiocb *, struct iov_iter *);
	int (*migratepage)(struct address_space *, struct page *, struct page *, enum migrate_mode);
	bool (*isolate_page)(struct page *, isolate_mode_t);
	void (*putback_page)(struct page *);
	int (*launder_page)(struct page *);
	int (*is_partially_uptodate)(struct page *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page *, bool *, bool *);
	int (*error_remove_page)(struct address_space *, struct page *);
	int (*swap_activate)(struct swap_info_struct *, struct file *, sector_t *);
	void (*swap_deactivate)(struct file *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

enum writeback_sync_modes {
	WB_SYNC_NONE = 0,
	WB_SYNC_ALL = 1,
};

struct writeback_control {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback *wb;
	struct inode *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct iovec;

struct kvec;

struct bio_vec;

struct iov_iter {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct swap_cluster_info {
	spinlock_t lock;
	unsigned int data: 24;
	unsigned int flags: 8;
};

struct swap_cluster_list {
	struct swap_cluster_info head;
	struct swap_cluster_info tail;
};

struct swap_extent {
	struct list_head list;
	long unsigned int start_page;
	long unsigned int nr_pages;
	sector_t start_block;
};

struct percpu_cluster;

struct swap_info_struct {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device *bdev;
	struct file *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct hd_struct;

struct gendisk;

struct block_device {
	dev_t bd_dev;
	int bd_openers;
	struct inode *bd_inode;
	struct super_block *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk *bd_disk;
	struct request_queue *bd_queue;
	struct backing_dev_info *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

enum dl_dev_state {
	DL_DEV_NO_DRIVER = 0,
	DL_DEV_PROBING = 1,
	DL_DEV_DRIVER_BOUND = 2,
	DL_DEV_UNBINDING = 3,
};

struct dev_links_info {
	struct list_head suppliers;
	struct list_head consumers;
	enum dl_dev_state status;
};

struct pm_message {
	int event;
};

typedef struct pm_message pm_message_t;

enum rpm_request {
	RPM_REQ_NONE = 0,
	RPM_REQ_IDLE = 1,
	RPM_REQ_SUSPEND = 2,
	RPM_REQ_AUTOSUSPEND = 3,
	RPM_REQ_RESUME = 4,
};

enum rpm_status {
	RPM_ACTIVE = 0,
	RPM_RESUMING = 1,
	RPM_SUSPENDED = 2,
	RPM_SUSPENDING = 3,
};

struct wakeup_source;

struct wake_irq;

struct pm_subsys_data;

struct dev_pm_qos;

struct dev_pm_info {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device *, s32);
	struct dev_pm_qos *qos;
};

struct dev_archdata {
	void *iommu;
};

struct klist_node {
	void *n_klist;
	struct list_head n_node;
	struct kref n_ref;
};

struct device_private;

struct device_type;

struct bus_type;

struct device_driver;

struct dev_pm_domain;

struct irq_domain;

struct dev_pin_info;

struct dma_map_ops;

struct device_dma_parameters;

struct dma_coherent_mem;

struct device_node;

struct fwnode_handle;

struct class;

struct iommu_group;

struct iommu_fwspec;

struct device_extended_rh;

struct device {
	struct device *parent;
	struct device_private *p;
	struct kobject kobj;
	const char *init_name;
	const struct device_type *type;
	struct mutex mutex;
	struct bus_type *bus;
	struct device_driver *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info power;
	struct dev_pm_domain *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node *of_node;
	struct fwnode_handle *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class *class;
	const struct attribute_group **groups;
	void (*release)(struct device *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct partition_meta_info;

struct disk_stats;

struct hd_struct {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device __dev;
	struct kobject *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct timer_rand_state;

struct disk_part_tbl;

struct block_device_operations;

struct disk_events;

struct badblocks;

struct gendisk {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl *part_tbl;
	struct hd_struct part0;
	const struct block_device_operations *fops;
	struct request_queue *queue;
	void *private_data;
	int flags;
	struct rw_semaphore lookup_sem;
	struct kobject *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev {
	struct kobject kobj;
	struct module *owner;
	const struct file_operations *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct fiemap_extent_info;

struct inode_operations {
	struct dentry * (*lookup)(struct inode *, struct dentry *, unsigned int);
	const char * (*get_link)(struct dentry *, struct inode *, struct delayed_call *);
	int (*permission)(struct inode *, int);
	struct posix_acl * (*get_acl)(struct inode *, int);
	int (*readlink)(struct dentry *, char *, int);
	int (*create)(struct inode *, struct dentry *, umode_t, bool);
	int (*link)(struct dentry *, struct inode *, struct dentry *);
	int (*unlink)(struct inode *, struct dentry *);
	int (*symlink)(struct inode *, struct dentry *, const char *);
	int (*mkdir)(struct inode *, struct dentry *, umode_t);
	int (*rmdir)(struct inode *, struct dentry *);
	int (*mknod)(struct inode *, struct dentry *, umode_t, dev_t);
	int (*rename)(struct inode *, struct dentry *, struct inode *, struct dentry *, unsigned int);
	int (*setattr)(struct dentry *, struct iattr *);
	int (*getattr)(const struct path *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry *, char *, size_t);
	int (*fiemap)(struct inode *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode *, struct timespec64 *, int);
	int (*atomic_open)(struct inode *, struct dentry *, struct file *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode *, struct dentry *, umode_t);
	int (*set_acl)(struct inode *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_context {
	spinlock_t flc_lock;
	struct list_head flc_flock;
	struct list_head flc_posix;
	struct list_head flc_lease;
};

struct file_lock_operations {
	void (*fl_copy_lock)(struct file_lock *, struct file_lock *);
	void (*fl_release_private)(struct file_lock *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct nlm_lockowner;

struct nfs_lock_info {
	u32 state;
	struct nlm_lockowner *owner;
	struct list_head list;
};

struct nfs4_lock_state;

struct nfs4_lock_info {
	struct nfs4_lock_state *owner;
};

struct lock_manager_operations;

struct file_lock {
	struct file_lock *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations *fl_ops;
	const struct lock_manager_operations *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations {
	int (*lm_compare_owner)(struct file_lock *, struct file_lock *);
	long unsigned int (*lm_owner_key)(struct file_lock *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock *);
	int (*lm_grant)(struct file_lock *, int);
	bool (*lm_break)(struct file_lock *);
	int (*lm_change)(struct file_lock *, int, struct list_head *);
	void (*lm_setup)(struct file_lock *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct *fa_next;
	struct file *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type {
	const char *name;
	int fs_flags;
	struct dentry * (*mount)(struct file_system_type *, int, const char *, void *);
	void (*kill_sb)(struct super_block *);
	struct module *owner;
	struct file_system_type *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kstatfs;

struct super_operations {
	struct inode * (*alloc_inode)(struct super_block *);
	void (*destroy_inode)(struct inode *);
	void (*dirty_inode)(struct inode *, int);
	int (*write_inode)(struct inode *, struct writeback_control *);
	int (*drop_inode)(struct inode *);
	void (*evict_inode)(struct inode *);
	void (*put_super)(struct super_block *);
	int (*sync_fs)(struct super_block *, int);
	int (*freeze_super)(struct super_block *);
	int (*freeze_fs)(struct super_block *);
	int (*thaw_super)(struct super_block *);
	int (*unfreeze_fs)(struct super_block *);
	int (*statfs)(struct dentry *, struct kstatfs *);
	int (*remount_fs)(struct super_block *, int *, char *);
	void (*umount_begin)(struct super_block *);
	int (*show_options)(struct seq_file *, struct dentry *);
	int (*show_devname)(struct seq_file *, struct dentry *);
	int (*show_path)(struct seq_file *, struct dentry *);
	int (*show_stats)(struct seq_file *, struct dentry *);
	ssize_t (*quota_read)(struct super_block *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block *, int, const char *, size_t, loff_t);
	struct dquot ** (*get_dquots)(struct inode *);
	int (*bdev_try_to_free_page)(struct super_block *, struct page *, gfp_t);
	long int (*nr_cached_objects)(struct super_block *, struct shrink_control *);
	long int (*free_cached_objects)(struct super_block *, struct shrink_control *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct iomap;

struct inode___2;

struct dentry___2;

struct super_block___2;

struct fid;

struct iattr___2;

struct export_operations {
	int (*encode_fh)(struct inode___2 *, __u32 *, int *, struct inode___2 *);
	struct dentry___2 * (*fh_to_dentry)(struct super_block___2 *, struct fid *, int, int);
	struct dentry___2 * (*fh_to_parent)(struct super_block___2 *, struct fid *, int, int);
	int (*get_name)(struct dentry___2 *, char *, struct dentry___2 *);
	struct dentry___2 * (*get_parent)(struct dentry___2 *);
	int (*commit_metadata)(struct inode___2 *);
	int (*get_uuid)(struct super_block___2 *, u8 *, u32 *, u64 *);
	int (*map_blocks)(struct inode___2 *, loff_t, u64, struct iomap *, bool, u32 *);
	int (*commit_blocks)(struct inode___2 *, struct iomap *, int, struct iattr___2 *);
};

struct xattr_handler {
	const char *name;
	const char *prefix;
	int flags;
	bool (*list)(struct dentry *);
	int (*get)(const struct xattr_handler *, struct dentry *, struct inode *, const char *, void *, size_t);
	int (*set)(const struct xattr_handler *, struct dentry *, struct inode *, const char *, const void *, size_t, int);
};

struct fiemap_extent_info {
	unsigned int fi_flags;
	unsigned int fi_extents_mapped;
	unsigned int fi_extents_max;
	struct fiemap_extent *fi_extents_start;
};

typedef int (*filldir_t)(struct dir_context *, const char *, int, loff_t, u64, unsigned int);

struct dir_context {
	filldir_t actor;
	loff_t pos;
};

typedef u8 blk_status_t;

struct bvec_iter {
	sector_t bi_sector;
	unsigned int bi_size;
	unsigned int bi_idx;
	unsigned int bi_bvec_done;
	unsigned int rh_bi_reserved;
};

typedef void bio_end_io_t(struct bio *);

struct bio_issue {
	u64 value;
};

struct bio_vec {
	struct page *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload;

struct bio {
	struct bio *bi_next;
	struct gendisk *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec *bi_io_vec;
	struct bio_set *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec bi_inline_vecs[0];
};

struct linux_binprm {
	char buf[256];
	struct vm_area_struct *vma;
	long unsigned int vma_pages;
	struct mm_struct *mm;
	long unsigned int p;
	unsigned int called_set_creds: 1;
	unsigned int cap_elevated: 1;
	unsigned int secureexec: 1;
	unsigned int recursion_depth;
	struct file *file;
	struct cred *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
};

struct coredump_params {
	union {
		const kernel_siginfo_t *siginfo;
		struct {
			const siginfo_t *siginfo;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	struct pt_regs *regs;
	struct file *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
};

struct assoc_array_ptr;

struct assoc_array {
	struct assoc_array_ptr *root;
	long unsigned int nr_leaves_on_tree;
};

typedef int32_t key_serial_t;

typedef uint32_t key_perm_t;

struct key_type;

struct keyring_index_key {
	struct key_type *type;
	const char *description;
	size_t desc_len;
};

struct key_construction;

typedef int (*request_key_actor_t)(struct key_construction *, const char *, void *);

struct key_preparsed_payload;

struct key___2;

struct key_match_data;

struct seq_file___2;

struct key_restriction;

struct key_type {
	const char *name;
	size_t def_datalen;
	int (*vet_description)(const char *);
	int (*preparse)(struct key_preparsed_payload *);
	void (*free_preparse)(struct key_preparsed_payload *);
	int (*instantiate)(struct key___2 *, struct key_preparsed_payload *);
	int (*update)(struct key___2 *, struct key_preparsed_payload *);
	int (*match_preparse)(struct key_match_data *);
	void (*match_free)(struct key_match_data *);
	void (*revoke)(struct key___2 *);
	void (*destroy)(struct key___2 *);
	void (*describe)(const struct key___2 *, struct seq_file___2 *);
	long int (*read)(const struct key___2 *, char *, size_t);
	request_key_actor_t request_key;
	struct key_restriction * (*lookup_restriction)(const char *);
	struct list_head link;
	struct lock_class_key lock_class;
};

union key_payload {
	void *rcu_data0;
	void *data[4];
};

typedef int (*key_restrict_link_func_t)(struct key *, const struct key_type *, const union key_payload *, struct key *);

struct key_user;

struct key_restriction___2;

struct key {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___2 *restrict_link;
};

struct key_restriction___2 {
	key_restrict_link_func_t check;
	struct key *key;
	struct key_type *keytype;
};

struct tracepoint_func {
	void *func;
	void *data;
	int prio;
};

struct stack_trace {
	unsigned int nr_entries;
	unsigned int max_entries;
	long unsigned int *entries;
	int skip;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct page_ext_operations {
	size_t offset;
	size_t size;
	bool (*need)();
	void (*init)();
};

typedef void compound_page_dtor(struct page *);

enum vm_event_item {
	PGPGIN = 0,
	PGPGOUT = 1,
	PSWPIN = 2,
	PSWPOUT = 3,
	PGALLOC_DMA32 = 4,
	PGALLOC_NORMAL = 5,
	PGALLOC_MOVABLE = 6,
	ALLOCSTALL_DMA32 = 7,
	ALLOCSTALL_NORMAL = 8,
	ALLOCSTALL_MOVABLE = 9,
	PGSCAN_SKIP_DMA32 = 10,
	PGSCAN_SKIP_NORMAL = 11,
	PGSCAN_SKIP_MOVABLE = 12,
	PGFREE = 13,
	PGACTIVATE = 14,
	PGDEACTIVATE = 15,
	PGLAZYFREE = 16,
	PGFAULT = 17,
	PGMAJFAULT = 18,
	PGLAZYFREED = 19,
	PGREFILL = 20,
	PGSTEAL_KSWAPD = 21,
	PGSTEAL_DIRECT = 22,
	PGSCAN_KSWAPD = 23,
	PGSCAN_DIRECT = 24,
	PGSCAN_DIRECT_THROTTLE = 25,
	PGSCAN_ZONE_RECLAIM_FAILED = 26,
	PGINODESTEAL = 27,
	SLABS_SCANNED = 28,
	KSWAPD_INODESTEAL = 29,
	KSWAPD_LOW_WMARK_HIT_QUICKLY = 30,
	KSWAPD_HIGH_WMARK_HIT_QUICKLY = 31,
	PAGEOUTRUN = 32,
	PGROTATED = 33,
	DROP_PAGECACHE = 34,
	DROP_SLAB = 35,
	OOM_KILL = 36,
	NUMA_PTE_UPDATES = 37,
	NUMA_HUGE_PTE_UPDATES = 38,
	NUMA_HINT_FAULTS = 39,
	NUMA_HINT_FAULTS_LOCAL = 40,
	NUMA_PAGE_MIGRATE = 41,
	PGMIGRATE_SUCCESS = 42,
	PGMIGRATE_FAIL = 43,
	COMPACTMIGRATE_SCANNED = 44,
	COMPACTFREE_SCANNED = 45,
	COMPACTISOLATED = 46,
	COMPACTSTALL = 47,
	COMPACTFAIL = 48,
	COMPACTSUCCESS = 49,
	KCOMPACTD_WAKE = 50,
	KCOMPACTD_MIGRATE_SCANNED = 51,
	KCOMPACTD_FREE_SCANNED = 52,
	HTLB_BUDDY_PGALLOC = 53,
	HTLB_BUDDY_PGALLOC_FAIL = 54,
	UNEVICTABLE_PGCULLED = 55,
	UNEVICTABLE_PGSCANNED = 56,
	UNEVICTABLE_PGRESCUED = 57,
	UNEVICTABLE_PGMLOCKED = 58,
	UNEVICTABLE_PGMUNLOCKED = 59,
	UNEVICTABLE_PGCLEARED = 60,
	UNEVICTABLE_PGSTRANDED = 61,
	THP_FAULT_ALLOC = 62,
	THP_FAULT_FALLBACK = 63,
	THP_COLLAPSE_ALLOC = 64,
	THP_COLLAPSE_ALLOC_FAILED = 65,
	THP_FILE_ALLOC = 66,
	THP_FILE_MAPPED = 67,
	THP_SPLIT_PAGE = 68,
	THP_SPLIT_PAGE_FAILED = 69,
	THP_DEFERRED_SPLIT_PAGE = 70,
	THP_SPLIT_PMD = 71,
	THP_ZERO_PAGE_ALLOC = 72,
	THP_ZERO_PAGE_ALLOC_FAILED = 73,
	THP_SWPOUT = 74,
	THP_SWPOUT_FALLBACK = 75,
	BALLOON_INFLATE = 76,
	BALLOON_DEFLATE = 77,
	BALLOON_MIGRATE = 78,
	SWAP_RA = 79,
	SWAP_RA_HIT = 80,
	NR_VM_EVENT_ITEMS = 81,
};

struct vm_event_state {
	long unsigned int event[81];
};

struct group_info {
	atomic_t usage;
	int ngroups;
	kgid_t gid[0];
};

struct seq_operations {
	void * (*start)(struct seq_file *, loff_t *);
	void (*stop)(struct seq_file *, void *);
	void * (*next)(struct seq_file *, void *, loff_t *);
	int (*show)(struct seq_file *, void *);
};

struct ring_buffer_event {
	u32 type_len: 5;
	u32 time_delta: 27;
	u32 array[0];
};

struct seq_buf {
	char *buffer;
	size_t size;
	size_t len;
	loff_t readpos;
};

struct trace_seq {
	unsigned char buffer[65536];
	struct seq_buf seq;
	int full;
};

enum ctx_state {
	CONTEXT_DISABLED = 4294967295,
	CONTEXT_KERNEL = 0,
	CONTEXT_USER = 1,
	CONTEXT_GUEST = 2,
};

struct context_tracking {
	bool active;
	int recursion;
	enum ctx_state state;
};

typedef struct {
	unsigned int __softirq_pending;
	unsigned int ipi_irqs[7];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
} irq_cpustat_t;

enum perf_sw_ids {
	PERF_COUNT_SW_CPU_CLOCK = 0,
	PERF_COUNT_SW_TASK_CLOCK = 1,
	PERF_COUNT_SW_PAGE_FAULTS = 2,
	PERF_COUNT_SW_CONTEXT_SWITCHES = 3,
	PERF_COUNT_SW_CPU_MIGRATIONS = 4,
	PERF_COUNT_SW_PAGE_FAULTS_MIN = 5,
	PERF_COUNT_SW_PAGE_FAULTS_MAJ = 6,
	PERF_COUNT_SW_ALIGNMENT_FAULTS = 7,
	PERF_COUNT_SW_EMULATION_FAULTS = 8,
	PERF_COUNT_SW_DUMMY = 9,
	PERF_COUNT_SW_BPF_OUTPUT = 10,
	PERF_COUNT_SW_MAX = 11,
};

enum perf_branch_sample_type_shift {
	PERF_SAMPLE_BRANCH_USER_SHIFT = 0,
	PERF_SAMPLE_BRANCH_KERNEL_SHIFT = 1,
	PERF_SAMPLE_BRANCH_HV_SHIFT = 2,
	PERF_SAMPLE_BRANCH_ANY_SHIFT = 3,
	PERF_SAMPLE_BRANCH_ANY_CALL_SHIFT = 4,
	PERF_SAMPLE_BRANCH_ANY_RETURN_SHIFT = 5,
	PERF_SAMPLE_BRANCH_IND_CALL_SHIFT = 6,
	PERF_SAMPLE_BRANCH_ABORT_TX_SHIFT = 7,
	PERF_SAMPLE_BRANCH_IN_TX_SHIFT = 8,
	PERF_SAMPLE_BRANCH_NO_TX_SHIFT = 9,
	PERF_SAMPLE_BRANCH_COND_SHIFT = 10,
	PERF_SAMPLE_BRANCH_CALL_STACK_SHIFT = 11,
	PERF_SAMPLE_BRANCH_IND_JUMP_SHIFT = 12,
	PERF_SAMPLE_BRANCH_CALL_SHIFT = 13,
	PERF_SAMPLE_BRANCH_NO_FLAGS_SHIFT = 14,
	PERF_SAMPLE_BRANCH_NO_CYCLES_SHIFT = 15,
	PERF_SAMPLE_BRANCH_TYPE_SAVE_SHIFT = 16,
	PERF_SAMPLE_BRANCH_MAX_SHIFT = 17,
};

union perf_mem_data_src {
	__u64 val;
	struct {
		__u64 mem_op: 5;
		__u64 mem_lvl: 14;
		__u64 mem_snoop: 5;
		__u64 mem_lock: 2;
		__u64 mem_dtlb: 7;
		__u64 mem_lvl_num: 4;
		__u64 mem_remote: 1;
		__u64 mem_snoopx: 2;
		__u64 mem_rsvd: 24;
	};
};

struct perf_branch_entry {
	__u64 from;
	__u64 to;
	__u64 mispred: 1;
	__u64 predicted: 1;
	__u64 in_tx: 1;
	__u64 abort: 1;
	__u64 cycles: 16;
	__u64 type: 4;
	__u64 reserved: 40;
};

struct perf_guest_info_callbacks {
	int (*is_in_guest)();
	int (*is_user_mode)();
	long unsigned int (*get_guest_ip)();
};

struct new_utsname {
	char sysname[65];
	char nodename[65];
	char release[65];
	char version[65];
	char machine[65];
	char domainname[65];
};

struct uts_namespace {
	struct kref kref;
	struct new_utsname name;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	struct ns_common ns;
};

struct cgroup_namespace {
	refcount_t count;
	struct ns_common ns;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	struct css_set *root_cset;
};

struct proc_ns_operations {
	const char *name;
	const char *real_ns_name;
	int type;
	struct ns_common * (*get)(struct task_struct *);
	void (*put)(struct ns_common *);
	int (*install)(struct nsproxy *, struct ns_common *);
	struct user_namespace * (*owner)(struct ns_common *);
	struct ns_common * (*get_parent)(struct ns_common *);
};

struct ucounts {
	struct hlist_node node;
	struct user_namespace *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct taskstats {
	__u16 version;
	__u32 ac_exitcode;
	__u8 ac_flag;
	__u8 ac_nice;
	__u64 cpu_count;
	__u64 cpu_delay_total;
	__u64 blkio_count;
	__u64 blkio_delay_total;
	__u64 swapin_count;
	__u64 swapin_delay_total;
	__u64 cpu_run_real_total;
	__u64 cpu_run_virtual_total;
	char ac_comm[32];
	__u8 ac_sched;
	__u8 ac_pad[3];
	int: 32;
	__u32 ac_uid;
	__u32 ac_gid;
	__u32 ac_pid;
	__u32 ac_ppid;
	__u32 ac_btime;
	__u64 ac_etime;
	__u64 ac_utime;
	__u64 ac_stime;
	__u64 ac_minflt;
	__u64 ac_majflt;
	__u64 coremem;
	__u64 virtmem;
	__u64 hiwater_rss;
	__u64 hiwater_vm;
	__u64 read_char;
	__u64 write_char;
	__u64 read_syscalls;
	__u64 write_syscalls;
	__u64 read_bytes;
	__u64 write_bytes;
	__u64 cancelled_write_bytes;
	__u64 nvcsw;
	__u64 nivcsw;
	__u64 ac_utimescaled;
	__u64 ac_stimescaled;
	__u64 cpu_scaled_run_real_total;
	__u64 freepages_count;
	__u64 freepages_delay_total;
	__u64 thrashing_count;
	__u64 thrashing_delay_total;
};

enum kmalloc_cache_type {
	KMALLOC_NORMAL = 0,
	KMALLOC_RECLAIM = 1,
	NR_KMALLOC_TYPES = 2,
};

struct iovec {
	void *iov_base;
	__kernel_size_t iov_len;
};

struct kvec {
	void *iov_base;
	size_t iov_len;
};

enum ftrace_tracing_type_t {
	FTRACE_TYPE_ENTER = 0,
	FTRACE_TYPE_RETURN = 1,
};

enum ftrace_bug_type {
	FTRACE_BUG_UNKNOWN = 0,
	FTRACE_BUG_INIT = 1,
	FTRACE_BUG_NOP = 2,
	FTRACE_BUG_CALL = 3,
	FTRACE_BUG_UPDATE = 4,
};

struct ftrace_graph_ent {
	long unsigned int func;
	int depth;
} __attribute__((packed));

struct ftrace_graph_ret {
	long unsigned int func;
	long unsigned int overrun;
	long long unsigned int calltime;
	long long unsigned int rettime;
	int depth;
} __attribute__((packed));

typedef void (*trace_func_graph_ret_t)(struct ftrace_graph_ret *);

typedef int (*trace_func_graph_ent_t)(struct ftrace_graph_ent *);

enum {
	TSK_TRACE_FL_TRACE_BIT = 0,
	TSK_TRACE_FL_GRAPH_BIT = 1,
};

struct dev_pm_ops {
	int (*prepare)(struct device *);
	void (*complete)(struct device *);
	int (*suspend)(struct device *);
	int (*resume)(struct device *);
	int (*freeze)(struct device *);
	int (*thaw)(struct device *);
	int (*poweroff)(struct device *);
	int (*restore)(struct device *);
	int (*suspend_late)(struct device *);
	int (*resume_early)(struct device *);
	int (*freeze_late)(struct device *);
	int (*thaw_early)(struct device *);
	int (*poweroff_late)(struct device *);
	int (*restore_early)(struct device *);
	int (*suspend_noirq)(struct device *);
	int (*resume_noirq)(struct device *);
	int (*freeze_noirq)(struct device *);
	int (*thaw_noirq)(struct device *);
	int (*poweroff_noirq)(struct device *);
	int (*restore_noirq)(struct device *);
	int (*runtime_suspend)(struct device *);
	int (*runtime_resume)(struct device *);
	int (*runtime_idle)(struct device *);
};

struct pm_domain_data;

struct pm_subsys_data {
	spinlock_t lock;
	unsigned int refcount;
	struct list_head clock_list;
	struct pm_domain_data *domain_data;
};

struct wakeup_source {
	const char *name;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	bool active: 1;
	bool autosleep_enabled: 1;
};

struct dev_pm_domain {
	struct dev_pm_ops ops;
	void (*detach)(struct device *, bool);
	int (*activate)(struct device *);
	void (*sync)(struct device *);
	void (*dismiss)(struct device *);
};

struct iommu_ops;

struct subsys_private;

struct bus_type {
	const char *name;
	const char *dev_name;
	struct device *dev_root;
	const struct attribute_group **bus_groups;
	const struct attribute_group **dev_groups;
	const struct attribute_group **drv_groups;
	int (*match)(struct device *, struct device_driver *);
	int (*uevent)(struct device *, struct kobj_uevent_env *);
	int (*probe)(struct device *);
	int (*remove)(struct device *);
	void (*shutdown)(struct device *);
	int (*online)(struct device *);
	int (*offline)(struct device *);
	int (*suspend)(struct device *, pm_message_t);
	int (*resume)(struct device *);
	int (*num_vf)(struct device *);
	int (*dma_configure)(struct device *);
	const struct dev_pm_ops *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

enum probe_type {
	PROBE_DEFAULT_STRATEGY = 0,
	PROBE_PREFER_ASYNCHRONOUS = 1,
	PROBE_FORCE_SYNCHRONOUS = 2,
};

struct of_device_id;

struct acpi_device_id;

struct driver_private;

struct device_driver_rh;

struct device_driver {
	const char *name;
	struct bus_type *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device *);
	int (*remove)(struct device *);
	void (*shutdown)(struct device *);
	int (*suspend)(struct device *, pm_message_t);
	int (*resume)(struct device *);
	const struct attribute_group **groups;
	const struct dev_pm_ops *pm;
	void (*coredump)(struct device *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

enum iommu_cap {
	IOMMU_CAP_CACHE_COHERENCY = 0,
	IOMMU_CAP_INTR_REMAP = 1,
	IOMMU_CAP_NOEXEC = 2,
};

typedef u64 dma_addr_t;

enum iommu_attr {
	DOMAIN_ATTR_GEOMETRY = 0,
	DOMAIN_ATTR_PAGING = 1,
	DOMAIN_ATTR_WINDOWS = 2,
	DOMAIN_ATTR_FSL_PAMU_STASH = 3,
	DOMAIN_ATTR_FSL_PAMU_ENABLE = 4,
	DOMAIN_ATTR_FSL_PAMUV1 = 5,
	DOMAIN_ATTR_NESTING = 6,
	DOMAIN_ATTR_DMA_USE_FLUSH_QUEUE = 7,
	DOMAIN_ATTR_MAX = 8,
};

struct iommu_domain;

struct device___2;

struct iommu_resv_region;

struct of_phandle_args;

struct iommu_ops {
	bool (*capable)(enum iommu_cap);
	struct iommu_domain * (*domain_alloc)(unsigned int);
	void (*domain_free)(struct iommu_domain *);
	int (*attach_dev)(struct iommu_domain *, struct device___2 *);
	void (*detach_dev)(struct iommu_domain *, struct device___2 *);
	int (*map)(struct iommu_domain *, long unsigned int, phys_addr_t, size_t, int);
	size_t (*unmap)(struct iommu_domain *, long unsigned int, size_t);
	void (*flush_iotlb_all)(struct iommu_domain *);
	void (*iotlb_range_add)(struct iommu_domain *, long unsigned int, size_t);
	void (*iotlb_sync)(struct iommu_domain *);
	phys_addr_t (*iova_to_phys)(struct iommu_domain *, dma_addr_t);
	int (*add_device)(struct device___2 *);
	void (*remove_device)(struct device___2 *);
	struct iommu_group * (*device_group)(struct device___2 *);
	int (*domain_get_attr)(struct iommu_domain *, enum iommu_attr, void *);
	int (*domain_set_attr)(struct iommu_domain *, enum iommu_attr, void *);
	void (*get_resv_regions)(struct device___2 *, struct list_head *);
	void (*put_resv_regions)(struct device___2 *, struct list_head *);
	void (*apply_resv_region)(struct device___2 *, struct iommu_domain *, struct iommu_resv_region *);
	int (*domain_window_enable)(struct iommu_domain *, u32, phys_addr_t, u64, int);
	void (*domain_window_disable)(struct iommu_domain *, u32);
	int (*domain_set_windows)(struct iommu_domain *, u32);
	u32 (*domain_get_windows)(struct iommu_domain *);
	int (*of_xlate)(struct device___2 *, struct of_phandle_args *);
	bool (*is_attach_deferred)(struct iommu_domain *, struct device___2 *);
	long unsigned int pgsize_bitmap;
};

struct device_type {
	const char *name;
	const struct attribute_group **groups;
	int (*uevent)(struct device *, struct kobj_uevent_env *);
	char * (*devnode)(struct device *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device *);
	const struct dev_pm_ops *pm;
};

struct device_driver_rh {};

struct of_device_id {
	char name[32];
	char type[32];
	char compatible[128];
	const void *data;
};

typedef long unsigned int kernel_ulong_t;

struct acpi_device_id {
	__u8 id[9];
	kernel_ulong_t driver_data;
	__u32 cls;
	__u32 cls_msk;
};

struct class_rh {};

struct class {
	const char *name;
	struct module *owner;
	const struct attribute_group **class_groups;
	const struct attribute_group **dev_groups;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device *, struct kobj_uevent_env *);
	char * (*devnode)(struct device *, umode_t *);
	void (*class_release)(struct class *);
	void (*dev_release)(struct device *);
	int (*shutdown_pre)(struct device *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device *);
	const struct dev_pm_ops *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct device_dma_parameters {
	unsigned int max_segment_size;
	long unsigned int segment_boundary_mask;
};

struct device_extended_rh {};

enum dma_data_direction {
	DMA_BIDIRECTIONAL = 0,
	DMA_TO_DEVICE = 1,
	DMA_FROM_DEVICE = 2,
	DMA_NONE = 3,
};

struct dma_map_ops_extended_rh {};

struct vm_area_struct___2;

struct sg_table;

struct page___2;

struct scatterlist;

struct dma_map_ops {
	void * (*alloc)(struct device___2 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___2 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___2 *, struct vm_area_struct___2 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___2 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___2 *, struct page___2 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___2 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___2 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___2 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___2 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___2 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___2 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___2 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___2 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___2 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___2 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___2 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___2 *, u64);
	u64 (*get_required_mask)(struct device___2 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

typedef u32 phandle;

struct fwnode_operations;

struct fwnode_handle {
	struct fwnode_handle *secondary;
	const struct fwnode_operations *ops;
};

struct property;

struct device_node {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle fwnode;
	struct property *properties;
	struct property *deadprops;
	struct device_node *parent;
	struct device_node *child;
	struct device_node *sibling;
	struct kobject kobj;
	long unsigned int _flags;
	void *data;
};

struct node {
	struct device dev;
};

enum cpuhp_state {
	CPUHP_INVALID = 4294967295,
	CPUHP_OFFLINE = 0,
	CPUHP_CREATE_THREADS = 1,
	CPUHP_PERF_PREPARE = 2,
	CPUHP_PERF_X86_PREPARE = 3,
	CPUHP_PERF_X86_AMD_UNCORE_PREP = 4,
	CPUHP_PERF_POWER = 5,
	CPUHP_PERF_SUPERH = 6,
	CPUHP_X86_HPET_DEAD = 7,
	CPUHP_X86_APB_DEAD = 8,
	CPUHP_X86_MCE_DEAD = 9,
	CPUHP_VIRT_NET_DEAD = 10,
	CPUHP_SLUB_DEAD = 11,
	CPUHP_MM_WRITEBACK_DEAD = 12,
	CPUHP_MM_VMSTAT_DEAD = 13,
	CPUHP_SOFTIRQ_DEAD = 14,
	CPUHP_NET_MVNETA_DEAD = 15,
	CPUHP_CPUIDLE_DEAD = 16,
	CPUHP_ARM64_FPSIMD_DEAD = 17,
	CPUHP_ARM_OMAP_WAKE_DEAD = 18,
	CPUHP_IRQ_POLL_DEAD = 19,
	CPUHP_BLOCK_SOFTIRQ_DEAD = 20,
	CPUHP_ACPI_CPUDRV_DEAD = 21,
	CPUHP_S390_PFAULT_DEAD = 22,
	CPUHP_BLK_MQ_DEAD = 23,
	CPUHP_FS_BUFF_DEAD = 24,
	CPUHP_PRINTK_DEAD = 25,
	CPUHP_MM_MEMCQ_DEAD = 26,
	CPUHP_PERCPU_CNT_DEAD = 27,
	CPUHP_RADIX_DEAD = 28,
	CPUHP_PAGE_ALLOC_DEAD = 29,
	CPUHP_NET_DEV_DEAD = 30,
	CPUHP_PCI_XGENE_DEAD = 31,
	CPUHP_IOMMU_INTEL_DEAD = 32,
	CPUHP_LUSTRE_CFS_DEAD = 33,
	CPUHP_AP_ARM_CACHE_B15_RAC_DEAD = 34,
	CPUHP_WORKQUEUE_PREP = 35,
	CPUHP_POWER_NUMA_PREPARE = 36,
	CPUHP_HRTIMERS_PREPARE = 37,
	CPUHP_PROFILE_PREPARE = 38,
	CPUHP_X2APIC_PREPARE = 39,
	CPUHP_SMPCFD_PREPARE = 40,
	CPUHP_RELAY_PREPARE = 41,
	CPUHP_SLAB_PREPARE = 42,
	CPUHP_MD_RAID5_PREPARE = 43,
	CPUHP_RCUTREE_PREP = 44,
	CPUHP_CPUIDLE_COUPLED_PREPARE = 45,
	CPUHP_POWERPC_PMAC_PREPARE = 46,
	CPUHP_POWERPC_MMU_CTX_PREPARE = 47,
	CPUHP_XEN_PREPARE = 48,
	CPUHP_XEN_EVTCHN_PREPARE = 49,
	CPUHP_ARM_SHMOBILE_SCU_PREPARE = 50,
	CPUHP_SH_SH3X_PREPARE = 51,
	CPUHP_NET_FLOW_PREPARE = 52,
	CPUHP_TOPOLOGY_PREPARE = 53,
	CPUHP_NET_IUCV_PREPARE = 54,
	CPUHP_ARM_BL_PREPARE = 55,
	CPUHP_TRACE_RB_PREPARE = 56,
	CPUHP_MM_ZS_PREPARE = 57,
	CPUHP_MM_ZSWP_MEM_PREPARE = 58,
	CPUHP_MM_ZSWP_POOL_PREPARE = 59,
	CPUHP_KVM_PPC_BOOK3S_PREPARE = 60,
	CPUHP_ZCOMP_PREPARE = 61,
	CPUHP_TIMERS_PREPARE = 62,
	CPUHP_MIPS_SOC_PREPARE = 63,
	CPUHP_BP_PREPARE_DYN = 64,
	CPUHP_BP_PREPARE_DYN_END = 84,
	CPUHP_BRINGUP_CPU = 85,
	CPUHP_AP_IDLE_DEAD = 86,
	CPUHP_AP_OFFLINE = 87,
	CPUHP_AP_SCHED_STARTING = 88,
	CPUHP_AP_RCUTREE_DYING = 89,
	CPUHP_AP_IRQ_GIC_STARTING = 90,
	CPUHP_AP_IRQ_HIP04_STARTING = 91,
	CPUHP_AP_IRQ_ARMADA_XP_STARTING = 92,
	CPUHP_AP_IRQ_BCM2836_STARTING = 93,
	CPUHP_AP_IRQ_MIPS_GIC_STARTING = 94,
	CPUHP_AP_ARM_MVEBU_COHERENCY = 95,
	CPUHP_AP_PERF_X86_AMD_UNCORE_STARTING = 96,
	CPUHP_AP_PERF_X86_STARTING = 97,
	CPUHP_AP_PERF_X86_AMD_IBS_STARTING = 98,
	CPUHP_AP_PERF_X86_CQM_STARTING = 99,
	CPUHP_AP_PERF_X86_CSTATE_STARTING = 100,
	CPUHP_AP_PERF_XTENSA_STARTING = 101,
	CPUHP_AP_MIPS_OP_LOONGSON3_STARTING = 102,
	CPUHP_AP_ARM_SDEI_STARTING = 103,
	CPUHP_AP_ARM_VFP_STARTING = 104,
	CPUHP_AP_ARM64_DEBUG_MONITORS_STARTING = 105,
	CPUHP_AP_PERF_ARM_HW_BREAKPOINT_STARTING = 106,
	CPUHP_AP_PERF_ARM_ACPI_STARTING = 107,
	CPUHP_AP_PERF_ARM_STARTING = 108,
	CPUHP_AP_ARM_L2X0_STARTING = 109,
	CPUHP_AP_ARM_ARCH_TIMER_STARTING = 110,
	CPUHP_AP_ARM_GLOBAL_TIMER_STARTING = 111,
	CPUHP_AP_JCORE_TIMER_STARTING = 112,
	CPUHP_AP_EXYNOS4_MCT_TIMER_STARTING = 113,
	CPUHP_AP_ARM_TWD_STARTING = 114,
	CPUHP_AP_QCOM_TIMER_STARTING = 115,
	CPUHP_AP_ARMADA_TIMER_STARTING = 116,
	CPUHP_AP_MARCO_TIMER_STARTING = 117,
	CPUHP_AP_MIPS_GIC_TIMER_STARTING = 118,
	CPUHP_AP_ARC_TIMER_STARTING = 119,
	CPUHP_AP_KVM_STARTING = 120,
	CPUHP_AP_KVM_ARM_VGIC_INIT_STARTING = 121,
	CPUHP_AP_KVM_ARM_VGIC_STARTING = 122,
	CPUHP_AP_KVM_ARM_TIMER_STARTING = 123,
	CPUHP_AP_DUMMY_TIMER_STARTING = 124,
	CPUHP_AP_ARM_XEN_STARTING = 125,
	CPUHP_AP_ARM_CORESIGHT_STARTING = 126,
	CPUHP_AP_ARM64_ISNDEP_STARTING = 127,
	CPUHP_AP_SMPCFD_DYING = 128,
	CPUHP_AP_X86_TBOOT_DYING = 129,
	CPUHP_AP_ARM_CACHE_B15_RAC_DYING = 130,
	CPUHP_AP_ONLINE = 131,
	CPUHP_TEARDOWN_CPU = 132,
	CPUHP_AP_ONLINE_IDLE = 133,
	CPUHP_AP_SMPBOOT_THREADS = 134,
	CPUHP_AP_X86_VDSO_VMA_ONLINE = 135,
	CPUHP_AP_IRQ_AFFINITY_ONLINE = 136,
	CPUHP_AP_PERF_ONLINE = 137,
	CPUHP_AP_PERF_X86_ONLINE = 138,
	CPUHP_AP_PERF_X86_UNCORE_ONLINE = 139,
	CPUHP_AP_PERF_X86_AMD_UNCORE_ONLINE = 140,
	CPUHP_AP_PERF_X86_AMD_POWER_ONLINE = 141,
	CPUHP_AP_PERF_X86_RAPL_ONLINE = 142,
	CPUHP_AP_PERF_X86_CQM_ONLINE = 143,
	CPUHP_AP_PERF_X86_CSTATE_ONLINE = 144,
	CPUHP_AP_PERF_S390_CF_ONLINE = 145,
	CPUHP_AP_PERF_S390_SF_ONLINE = 146,
	CPUHP_AP_PERF_ARM_CCI_ONLINE = 147,
	CPUHP_AP_PERF_ARM_CCN_ONLINE = 148,
	CPUHP_AP_PERF_ARM_HISI_DDRC_ONLINE = 149,
	CPUHP_AP_PERF_ARM_HISI_HHA_ONLINE = 150,
	CPUHP_AP_PERF_ARM_HISI_L3_ONLINE = 151,
	CPUHP_AP_PERF_ARM_L2X0_ONLINE = 152,
	CPUHP_AP_PERF_ARM_QCOM_L2_ONLINE = 153,
	CPUHP_AP_PERF_ARM_QCOM_L3_ONLINE = 154,
	CPUHP_AP_PERF_ARM_APM_XGENE_ONLINE = 155,
	CPUHP_AP_PERF_POWERPC_NEST_IMC_ONLINE = 156,
	CPUHP_AP_PERF_POWERPC_CORE_IMC_ONLINE = 157,
	CPUHP_AP_PERF_POWERPC_THREAD_IMC_ONLINE = 158,
	CPUHP_AP_WORKQUEUE_ONLINE = 159,
	CPUHP_AP_RCUTREE_ONLINE = 160,
	CPUHP_AP_ONLINE_DYN = 161,
	CPUHP_AP_ONLINE_DYN_END = 191,
	CPUHP_AP_X86_HPET_ONLINE = 192,
	CPUHP_AP_X86_KVM_CLK_ONLINE = 193,
	CPUHP_AP_ACTIVE = 194,
	CPUHP_ONLINE = 195,
};

struct perf_regs {
	__u64 abi;
	struct pt_regs *regs;
};

enum {
	TASKSTATS_CMD_UNSPEC = 0,
	TASKSTATS_CMD_GET = 1,
	TASKSTATS_CMD_NEW = 2,
	__TASKSTATS_CMD_MAX = 3,
};

enum ucount_type {
	UCOUNT_USER_NAMESPACES = 0,
	UCOUNT_PID_NAMESPACES = 1,
	UCOUNT_UTS_NAMESPACES = 2,
	UCOUNT_IPC_NAMESPACES = 3,
	UCOUNT_NET_NAMESPACES = 4,
	UCOUNT_MNT_NAMESPACES = 5,
	UCOUNT_CGROUP_NAMESPACES = 6,
	UCOUNT_INOTIFY_INSTANCES = 7,
	UCOUNT_INOTIFY_WATCHES = 8,
	UCOUNT_KABI_RESERVE_1 = 9,
	UCOUNT_KABI_RESERVE_2 = 10,
	UCOUNT_KABI_RESERVE_3 = 11,
	UCOUNT_KABI_RESERVE_4 = 12,
	UCOUNT_KABI_RESERVE_5 = 13,
	UCOUNT_KABI_RESERVE_6 = 14,
	UCOUNT_KABI_RESERVE_7 = 15,
	UCOUNT_KABI_RESERVE_8 = 16,
	UCOUNT_KABI_RESERVE_9 = 17,
	UCOUNT_KABI_RESERVE_10 = 18,
	UCOUNT_KABI_RESERVE_11 = 19,
	UCOUNT_KABI_RESERVE_12 = 20,
	UCOUNT_KABI_RESERVE_13 = 21,
	UCOUNT_KABI_RESERVE_14 = 22,
	UCOUNT_KABI_RESERVE_15 = 23,
	UCOUNT_COUNTS = 24,
};

enum {
	HI_SOFTIRQ = 0,
	TIMER_SOFTIRQ = 1,
	NET_TX_SOFTIRQ = 2,
	NET_RX_SOFTIRQ = 3,
	BLOCK_SOFTIRQ = 4,
	IRQ_POLL_SOFTIRQ = 5,
	TASKLET_SOFTIRQ = 6,
	SCHED_SOFTIRQ = 7,
	HRTIMER_SOFTIRQ = 8,
	RCU_SOFTIRQ = 9,
	NR_SOFTIRQS = 10,
};

enum cpu_usage_stat {
	CPUTIME_USER = 0,
	CPUTIME_NICE = 1,
	CPUTIME_SYSTEM = 2,
	CPUTIME_SOFTIRQ = 3,
	CPUTIME_IRQ = 4,
	CPUTIME_IDLE = 5,
	CPUTIME_IOWAIT = 6,
	CPUTIME_STEAL = 7,
	CPUTIME_GUEST = 8,
	CPUTIME_GUEST_NICE = 9,
	NR_STATS = 10,
};

struct kernel_cpustat {
	u64 cpustat[10];
};

struct kernel_stat {
	long unsigned int irqs_sum;
	unsigned int softirqs[10];
};

struct u64_stats_sync {};

struct bpf_insn {
	__u8 code;
	__u8 dst_reg: 4;
	__u8 src_reg: 4;
	__s16 off;
	__s32 imm;
};

struct bpf_cgroup_storage_key {
	__u64 cgroup_inode_id;
	__u32 attach_type;
};

enum bpf_map_type {
	BPF_MAP_TYPE_UNSPEC = 0,
	BPF_MAP_TYPE_HASH = 1,
	BPF_MAP_TYPE_ARRAY = 2,
	BPF_MAP_TYPE_PROG_ARRAY = 3,
	BPF_MAP_TYPE_PERF_EVENT_ARRAY = 4,
	BPF_MAP_TYPE_PERCPU_HASH = 5,
	BPF_MAP_TYPE_PERCPU_ARRAY = 6,
	BPF_MAP_TYPE_STACK_TRACE = 7,
	BPF_MAP_TYPE_CGROUP_ARRAY = 8,
	BPF_MAP_TYPE_LRU_HASH = 9,
	BPF_MAP_TYPE_LRU_PERCPU_HASH = 10,
	BPF_MAP_TYPE_LPM_TRIE = 11,
	BPF_MAP_TYPE_ARRAY_OF_MAPS = 12,
	BPF_MAP_TYPE_HASH_OF_MAPS = 13,
	BPF_MAP_TYPE_DEVMAP = 14,
	BPF_MAP_TYPE_SOCKMAP = 15,
	BPF_MAP_TYPE_CPUMAP = 16,
	BPF_MAP_TYPE_XSKMAP = 17,
	BPF_MAP_TYPE_SOCKHASH = 18,
	BPF_MAP_TYPE_CGROUP_STORAGE = 19,
	BPF_MAP_TYPE_REUSEPORT_SOCKARRAY = 20,
	BPF_MAP_TYPE_PERCPU_CGROUP_STORAGE = 21,
	BPF_MAP_TYPE_QUEUE = 22,
	BPF_MAP_TYPE_STACK = 23,
};

union bpf_attr {
	struct {
		__u32 map_type;
		__u32 key_size;
		__u32 value_size;
		__u32 max_entries;
		__u32 map_flags;
		__u32 inner_map_fd;
		__u32 numa_node;
		char map_name[16];
		__u32 map_ifindex;
		__u32 btf_fd;
		__u32 btf_key_type_id;
		__u32 btf_value_type_id;
	};
	struct {
		__u32 map_fd;
		__u64 key;
		union {
			__u64 value;
			__u64 next_key;
		};
		__u64 flags;
	};
	struct {
		__u32 prog_type;
		__u32 insn_cnt;
		__u64 insns;
		__u64 license;
		__u32 log_level;
		__u32 log_size;
		__u64 log_buf;
		__u32 kern_version;
		__u32 prog_flags;
		char prog_name[16];
		__u32 prog_ifindex;
		__u32 expected_attach_type;
		__u32 prog_btf_fd;
		__u32 func_info_rec_size;
		__u64 func_info;
		__u32 func_info_cnt;
		__u32 line_info_rec_size;
		__u64 line_info;
		__u32 line_info_cnt;
	};
	struct {
		__u64 pathname;
		__u32 bpf_fd;
		__u32 file_flags;
	};
	struct {
		__u32 target_fd;
		__u32 attach_bpf_fd;
		__u32 attach_type;
		__u32 attach_flags;
	};
	struct {
		__u32 prog_fd;
		__u32 retval;
		__u32 data_size_in;
		__u32 data_size_out;
		__u64 data_in;
		__u64 data_out;
		__u32 repeat;
		__u32 duration;
	} test;
	struct {
		union {
			__u32 start_id;
			__u32 prog_id;
			__u32 map_id;
			__u32 btf_id;
		};
		__u32 next_id;
		__u32 open_flags;
	};
	struct {
		__u32 bpf_fd;
		__u32 info_len;
		__u64 info;
	} info;
	struct {
		__u32 target_fd;
		__u32 attach_type;
		__u32 query_flags;
		__u32 attach_flags;
		__u64 prog_ids;
		__u32 prog_cnt;
	} query;
	struct {
		__u64 name;
		__u32 prog_fd;
	} raw_tracepoint;
	struct {
		__u64 btf;
		__u64 btf_log_buf;
		__u32 btf_size;
		__u32 btf_log_size;
		__u32 btf_log_level;
	};
	struct {
		__u32 pid;
		__u32 fd;
		__u32 flags;
		__u32 buf_len;
		__u64 buf;
		__u32 prog_id;
		__u32 fd_type;
		__u64 probe_offset;
		__u64 probe_addr;
	} task_fd_query;
};

enum bpf_func_id {
	BPF_FUNC_unspec = 0,
	BPF_FUNC_map_lookup_elem = 1,
	BPF_FUNC_map_update_elem = 2,
	BPF_FUNC_map_delete_elem = 3,
	BPF_FUNC_probe_read = 4,
	BPF_FUNC_ktime_get_ns = 5,
	BPF_FUNC_trace_printk = 6,
	BPF_FUNC_get_prandom_u32 = 7,
	BPF_FUNC_get_smp_processor_id = 8,
	BPF_FUNC_skb_store_bytes = 9,
	BPF_FUNC_l3_csum_replace = 10,
	BPF_FUNC_l4_csum_replace = 11,
	BPF_FUNC_tail_call = 12,
	BPF_FUNC_clone_redirect = 13,
	BPF_FUNC_get_current_pid_tgid = 14,
	BPF_FUNC_get_current_uid_gid = 15,
	BPF_FUNC_get_current_comm = 16,
	BPF_FUNC_get_cgroup_classid = 17,
	BPF_FUNC_skb_vlan_push = 18,
	BPF_FUNC_skb_vlan_pop = 19,
	BPF_FUNC_skb_get_tunnel_key = 20,
	BPF_FUNC_skb_set_tunnel_key = 21,
	BPF_FUNC_perf_event_read = 22,
	BPF_FUNC_redirect = 23,
	BPF_FUNC_get_route_realm = 24,
	BPF_FUNC_perf_event_output = 25,
	BPF_FUNC_skb_load_bytes = 26,
	BPF_FUNC_get_stackid = 27,
	BPF_FUNC_csum_diff = 28,
	BPF_FUNC_skb_get_tunnel_opt = 29,
	BPF_FUNC_skb_set_tunnel_opt = 30,
	BPF_FUNC_skb_change_proto = 31,
	BPF_FUNC_skb_change_type = 32,
	BPF_FUNC_skb_under_cgroup = 33,
	BPF_FUNC_get_hash_recalc = 34,
	BPF_FUNC_get_current_task = 35,
	BPF_FUNC_probe_write_user = 36,
	BPF_FUNC_current_task_under_cgroup = 37,
	BPF_FUNC_skb_change_tail = 38,
	BPF_FUNC_skb_pull_data = 39,
	BPF_FUNC_csum_update = 40,
	BPF_FUNC_set_hash_invalid = 41,
	BPF_FUNC_get_numa_node_id = 42,
	BPF_FUNC_skb_change_head = 43,
	BPF_FUNC_xdp_adjust_head = 44,
	BPF_FUNC_probe_read_str = 45,
	BPF_FUNC_get_socket_cookie = 46,
	BPF_FUNC_get_socket_uid = 47,
	BPF_FUNC_set_hash = 48,
	BPF_FUNC_setsockopt = 49,
	BPF_FUNC_skb_adjust_room = 50,
	BPF_FUNC_redirect_map = 51,
	BPF_FUNC_sk_redirect_map = 52,
	BPF_FUNC_sock_map_update = 53,
	BPF_FUNC_xdp_adjust_meta = 54,
	BPF_FUNC_perf_event_read_value = 55,
	BPF_FUNC_perf_prog_read_value = 56,
	BPF_FUNC_getsockopt = 57,
	BPF_FUNC_override_return = 58,
	BPF_FUNC_sock_ops_cb_flags_set = 59,
	BPF_FUNC_msg_redirect_map = 60,
	BPF_FUNC_msg_apply_bytes = 61,
	BPF_FUNC_msg_cork_bytes = 62,
	BPF_FUNC_msg_pull_data = 63,
	BPF_FUNC_bind = 64,
	BPF_FUNC_xdp_adjust_tail = 65,
	BPF_FUNC_skb_get_xfrm_state = 66,
	BPF_FUNC_get_stack = 67,
	BPF_FUNC_skb_load_bytes_relative = 68,
	BPF_FUNC_fib_lookup = 69,
	BPF_FUNC_sock_hash_update = 70,
	BPF_FUNC_msg_redirect_hash = 71,
	BPF_FUNC_sk_redirect_hash = 72,
	BPF_FUNC_lwt_push_encap = 73,
	BPF_FUNC_lwt_seg6_store_bytes = 74,
	BPF_FUNC_lwt_seg6_adjust_srh = 75,
	BPF_FUNC_lwt_seg6_action = 76,
	BPF_FUNC_rc_repeat = 77,
	BPF_FUNC_rc_keydown = 78,
	BPF_FUNC_skb_cgroup_id = 79,
	BPF_FUNC_get_current_cgroup_id = 80,
	BPF_FUNC_get_local_storage = 81,
	BPF_FUNC_sk_select_reuseport = 82,
	BPF_FUNC_skb_ancestor_cgroup_id = 83,
	BPF_FUNC_sk_lookup_tcp = 84,
	BPF_FUNC_sk_lookup_udp = 85,
	BPF_FUNC_sk_release = 86,
	BPF_FUNC_map_push_elem = 87,
	BPF_FUNC_map_pop_elem = 88,
	BPF_FUNC_map_peek_elem = 89,
	BPF_FUNC_msg_push_data = 90,
	BPF_FUNC_msg_pop_data = 91,
	BPF_FUNC_rc_pointer_rel = 92,
	__BPF_FUNC_MAX_ID = 93,
};

struct bpf_map;

struct btf;

struct btf_type;

struct bpf_map_ops {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map *, struct file *);
	void (*map_free)(struct bpf_map *);
	int (*map_get_next_key)(struct bpf_map *, void *, void *);
	void (*map_release_uref)(struct bpf_map *);
	void * (*map_lookup_elem)(struct bpf_map *, void *);
	int (*map_update_elem)(struct bpf_map *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map *, void *);
	int (*map_push_elem)(struct bpf_map *, void *, u64);
	int (*map_pop_elem)(struct bpf_map *, void *);
	int (*map_peek_elem)(struct bpf_map *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map *, struct file *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map *, void *, struct seq_file *);
	int (*map_check_btf)(const struct bpf_map *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map {
	const struct bpf_map_ops *ops;
	struct bpf_map *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct btf_header {
	__u16 magic;
	__u8 version;
	__u8 flags;
	__u32 hdr_len;
	__u32 type_off;
	__u32 type_len;
	__u32 str_off;
	__u32 str_len;
};

struct btf {
	void *data;
	struct btf_type **types;
	u32 *resolved_ids;
	u32 *resolved_sizes;
	const char *strings;
	void *nohdr_data;
	struct btf_header hdr;
	u32 nr_types;
	u32 types_size;
	u32 data_size;
	refcount_t refcnt;
	u32 id;
	struct callback_head rcu;
};

struct btf_type {
	__u32 name_off;
	__u32 info;
	union {
		__u32 size;
		__u32 type;
	};
};

enum bpf_arg_type {
	ARG_DONTCARE = 0,
	ARG_CONST_MAP_PTR = 1,
	ARG_PTR_TO_MAP_KEY = 2,
	ARG_PTR_TO_MAP_VALUE = 3,
	ARG_PTR_TO_UNINIT_MAP_VALUE = 4,
	ARG_PTR_TO_MEM = 5,
	ARG_PTR_TO_MEM_OR_NULL = 6,
	ARG_PTR_TO_UNINIT_MEM = 7,
	ARG_CONST_SIZE = 8,
	ARG_CONST_SIZE_OR_ZERO = 9,
	ARG_PTR_TO_CTX = 10,
	ARG_ANYTHING = 11,
	ARG_PTR_TO_SOCKET = 12,
};

enum bpf_return_type {
	RET_INTEGER = 0,
	RET_VOID = 1,
	RET_PTR_TO_MAP_VALUE = 2,
	RET_PTR_TO_MAP_VALUE_OR_NULL = 3,
	RET_PTR_TO_SOCKET_OR_NULL = 4,
};

struct bpf_func_proto {
	u64 (*func)(u64, u64, u64, u64, u64);
	bool gpl_only;
	bool pkt_access;
	enum bpf_return_type ret_type;
	enum bpf_arg_type arg1_type;
	enum bpf_arg_type arg2_type;
	enum bpf_arg_type arg3_type;
	enum bpf_arg_type arg4_type;
	enum bpf_arg_type arg5_type;
};

enum bpf_access_type {
	BPF_READ = 1,
	BPF_WRITE = 2,
};

enum bpf_reg_type {
	NOT_INIT = 0,
	SCALAR_VALUE = 1,
	PTR_TO_CTX = 2,
	CONST_PTR_TO_MAP = 3,
	PTR_TO_MAP_VALUE = 4,
	PTR_TO_MAP_VALUE_OR_NULL = 5,
	PTR_TO_STACK = 6,
	PTR_TO_PACKET_META = 7,
	PTR_TO_PACKET = 8,
	PTR_TO_PACKET_END = 9,
	PTR_TO_FLOW_KEYS = 10,
	PTR_TO_SOCKET = 11,
	PTR_TO_SOCKET_OR_NULL = 12,
};

struct bpf_insn_access_aux {
	enum bpf_reg_type reg_type;
	int ctx_field_size;
};

struct bpf_prog_ops {
	int (*test_run)(struct bpf_prog *, const union bpf_attr *, union bpf_attr *);
};

enum bpf_prog_type {
	BPF_PROG_TYPE_UNSPEC = 0,
	BPF_PROG_TYPE_SOCKET_FILTER = 1,
	BPF_PROG_TYPE_KPROBE = 2,
	BPF_PROG_TYPE_SCHED_CLS = 3,
	BPF_PROG_TYPE_SCHED_ACT = 4,
	BPF_PROG_TYPE_TRACEPOINT = 5,
	BPF_PROG_TYPE_XDP = 6,
	BPF_PROG_TYPE_PERF_EVENT = 7,
	BPF_PROG_TYPE_CGROUP_SKB = 8,
	BPF_PROG_TYPE_CGROUP_SOCK = 9,
	BPF_PROG_TYPE_LWT_IN = 10,
	BPF_PROG_TYPE_LWT_OUT = 11,
	BPF_PROG_TYPE_LWT_XMIT = 12,
	BPF_PROG_TYPE_SOCK_OPS = 13,
	BPF_PROG_TYPE_SK_SKB = 14,
	BPF_PROG_TYPE_CGROUP_DEVICE = 15,
	BPF_PROG_TYPE_SK_MSG = 16,
	BPF_PROG_TYPE_RAW_TRACEPOINT = 17,
	BPF_PROG_TYPE_CGROUP_SOCK_ADDR = 18,
	BPF_PROG_TYPE_LWT_SEG6LOCAL = 19,
	BPF_PROG_TYPE_LIRC_MODE2 = 20,
	BPF_PROG_TYPE_SK_REUSEPORT = 21,
	BPF_PROG_TYPE_FLOW_DISSECTOR = 22,
};

enum bpf_attach_type {
	BPF_CGROUP_INET_INGRESS = 0,
	BPF_CGROUP_INET_EGRESS = 1,
	BPF_CGROUP_INET_SOCK_CREATE = 2,
	BPF_CGROUP_SOCK_OPS = 3,
	BPF_SK_SKB_STREAM_PARSER = 4,
	BPF_SK_SKB_STREAM_VERDICT = 5,
	BPF_CGROUP_DEVICE = 6,
	BPF_SK_MSG_VERDICT = 7,
	BPF_CGROUP_INET4_BIND = 8,
	BPF_CGROUP_INET6_BIND = 9,
	BPF_CGROUP_INET4_CONNECT = 10,
	BPF_CGROUP_INET6_CONNECT = 11,
	BPF_CGROUP_INET4_POST_BIND = 12,
	BPF_CGROUP_INET6_POST_BIND = 13,
	BPF_CGROUP_UDP4_SENDMSG = 14,
	BPF_CGROUP_UDP6_SENDMSG = 15,
	BPF_LIRC_MODE2 = 16,
	BPF_FLOW_DISSECTOR = 17,
	__MAX_BPF_ATTACH_TYPE = 18,
};

struct sock_filter {
	__u16 code;
	__u8 jt;
	__u8 jf;
	__u32 k;
};

struct bpf_prog_aux;

struct sock_fprog_kern;

struct bpf_prog {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

struct bpf_verifier_ops {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog *, u32 *);
};

enum bpf_cgroup_storage_type {
	BPF_CGROUP_STORAGE_SHARED = 0,
	BPF_CGROUP_STORAGE_PERCPU = 1,
	__BPF_CGROUP_STORAGE_MAX = 2,
};

struct bpf_cgroup_storage;

struct bpf_prog_array_item {
	struct bpf_prog *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_storage_buffer;

struct bpf_cgroup_storage_map;

struct bpf_cgroup_storage {
	union {
		struct bpf_storage_buffer *buf;
		void *percpu_buf;
	};
	struct bpf_cgroup_storage_map *map;
	struct bpf_cgroup_storage_key key;
	struct list_head list;
	struct rb_node node;
	struct callback_head rcu;
};

struct bpf_prog_array {
	struct callback_head rcu;
	struct bpf_prog_array_item items[0];
};

struct bpf_storage_buffer {
	struct callback_head rcu;
	char data[0];
};

struct cgroup_bpf {
	struct bpf_prog_array *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work;

typedef void (*kthread_work_func_t)(struct kthread_work *);

struct kthread_worker;

struct kthread_work {
	struct list_head node;
	kthread_work_func_t func;
	struct kthread_worker *worker;
	int canceling;
};

struct kthread_worker {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct *task;
	struct kthread_work *current_work;
};

struct kthread_delayed_work {
	struct kthread_work work;
	struct timer_list timer;
};

enum psi_task_count {
	NR_IOWAIT = 0,
	NR_MEMSTALL = 1,
	NR_RUNNING = 2,
	NR_PSI_TASK_COUNTS = 3,
};

enum psi_states {
	PSI_IO_SOME = 0,
	PSI_IO_FULL = 1,
	PSI_MEM_SOME = 2,
	PSI_MEM_FULL = 3,
	PSI_CPU_SOME = 4,
	PSI_NONIDLE = 5,
	NR_PSI_STATES = 6,
};

enum psi_aggregators {
	PSI_AVGS = 0,
	PSI_POLL = 1,
	NR_PSI_AGGREGATORS = 2,
};

struct psi_group_cpu {
	seqcount_t seq;
	unsigned int tasks[3];
	u32 state_mask;
	u32 times[6];
	u64 state_start;
	long: 64;
	u32 times_prev[12];
	long: 64;
	long: 64;
};

struct psi_group {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker *poll_kworker;
	struct kthread_delayed_work poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

enum cgroup_subsys_id {
	cpuset_cgrp_id = 0,
	cpu_cgrp_id = 1,
	cpuacct_cgrp_id = 2,
	io_cgrp_id = 3,
	memory_cgrp_id = 4,
	devices_cgrp_id = 5,
	freezer_cgrp_id = 6,
	net_cls_cgrp_id = 7,
	perf_event_cgrp_id = 8,
	net_prio_cgrp_id = 9,
	hugetlb_cgrp_id = 10,
	pids_cgrp_id = 11,
	rdma_cgrp_id = 12,
	CGROUP_SUBSYS_COUNT = 13,
};

struct cgroup_base_stat {
	struct task_cputime cputime;
};

struct cgroup_freezer_state {
	bool freeze;
	int e_freeze;
	int nr_frozen_descendants;
	int nr_frozen_tasks;
};

struct cgroup_root;

struct cgroup_rstat_cpu;

struct cgroup {
	struct cgroup_subsys_state self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node *kn;
	struct cgroup_file procs_file;
	struct cgroup_file events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state *subsys[13];
	struct cgroup_root *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup *dom_cgrp;
	struct cgroup_rstat_cpu *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf bpf;
	atomic_t congestion_count;
	struct cgroup *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group psi;
	int ancestor_ids[0];
};

struct cgroup_taskset;

struct cftype;

struct cgroup_subsys {
	struct cgroup_subsys_state * (*css_alloc)(struct cgroup_subsys_state *);
	int (*css_online)(struct cgroup_subsys_state *);
	void (*css_offline)(struct cgroup_subsys_state *);
	void (*css_released)(struct cgroup_subsys_state *);
	void (*css_free)(struct cgroup_subsys_state *);
	void (*css_reset)(struct cgroup_subsys_state *);
	void (*css_rstat_flush)(struct cgroup_subsys_state *, int);
	int (*css_extra_stat_show)(struct seq_file *, struct cgroup_subsys_state *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct *);
	void (*cancel_fork)(struct task_struct *);
	void (*fork)(struct task_struct *);
	void (*exit)(struct task_struct *);
	void (*free)(struct task_struct *);
	void (*bind)(struct cgroup_subsys_state *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype *dfl_cftypes;
	struct cftype *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup *updated_children;
	struct cgroup *updated_next;
};

struct cgroup_root {
	struct kernfs_root *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys *ss;
	struct list_head node;
	struct kernfs_ops *kf_ops;
	int (*open)(struct kernfs_open_file *);
	void (*release)(struct kernfs_open_file *);
	u64 (*read_u64)(struct cgroup_subsys_state *, struct cftype *);
	s64 (*read_s64)(struct cgroup_subsys_state *, struct cftype *);
	int (*seq_show)(struct seq_file *, void *);
	void * (*seq_start)(struct seq_file *, loff_t *);
	void * (*seq_next)(struct seq_file *, void *, loff_t *);
	void (*seq_stop)(struct seq_file *, void *);
	int (*write_u64)(struct cgroup_subsys_state *, struct cftype *, u64);
	int (*write_s64)(struct cgroup_subsys_state *, struct cftype *, s64);
	ssize_t (*write)(struct kernfs_open_file *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file *, struct poll_table_struct *);
};

struct perf_callchain_entry {
	__u64 nr;
	__u64 ip[0];
};

typedef long unsigned int (*perf_copy_f)(void *, const void *, long unsigned int, long unsigned int);

struct perf_raw_frag {
	union {
		struct perf_raw_frag *next;
		long unsigned int pad;
	};
	perf_copy_f copy;
	void *data;
	u32 size;
} __attribute__((packed));

struct perf_raw_record {
	struct perf_raw_frag frag;
	u32 size;
};

struct perf_branch_stack {
	__u64 nr;
	struct perf_branch_entry entries[0];
};

struct perf_cpu_context;

struct pmu {
	struct list_head entry;
	struct module *module;
	struct device *dev;
	const struct attribute_group **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu *);
	void (*pmu_disable)(struct pmu *);
	int (*event_init)(struct perf_event *);
	void (*event_mapped)(struct perf_event *, struct mm_struct *);
	void (*event_unmapped)(struct perf_event *, struct mm_struct *);
	int (*add)(struct perf_event *, int);
	void (*del)(struct perf_event *, int);
	void (*start)(struct perf_event *, int);
	void (*stop)(struct perf_event *, int);
	void (*read)(struct perf_event *);
	void (*start_txn)(struct pmu *, unsigned int);
	int (*commit_txn)(struct pmu *);
	void (*cancel_txn)(struct pmu *);
	int (*event_idx)(struct perf_event *);
	void (*sched_task)(struct perf_event_context *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event *);
	int (*filter_match)(struct perf_event *);
	int (*check_period)(struct perf_event *, u64);
};

struct perf_cpu_context {
	struct perf_event_context ctx;
	struct perf_event_context *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_sample_data {
	u64 addr;
	struct perf_raw_record *raw;
	struct perf_branch_stack *br_stack;
	u64 period;
	u64 weight;
	u64 txn;
	union perf_mem_data_src data_src;
	u64 type;
	u64 ip;
	struct {
		u32 pid;
		u32 tid;
	} tid_entry;
	u64 time;
	u64 id;
	u64 stream_id;
	struct {
		u32 cpu;
		u32 reserved;
	} cpu_entry;
	struct perf_callchain_entry *callchain;
	struct perf_regs regs_user;
	struct pt_regs regs_user_copy;
	struct perf_regs regs_intr;
	u64 stack_user_size;
	u64 phys_addr;
	long: 64;
	long: 64;
	long: 64;
};

struct perf_cgroup_info;

struct perf_cgroup {
	struct cgroup_subsys_state css;
	struct perf_cgroup_info *info;
};

struct perf_cgroup_info {
	u64 time;
	u64 timestamp;
};

struct trace_entry {
	short unsigned int type;
	unsigned char flags;
	unsigned char preempt_count;
	int pid;
};

struct trace_array;

struct tracer;

struct trace_buffer;

struct ring_buffer_iter;

struct trace_iterator {
	struct trace_array *tr;
	struct tracer *trace;
	struct trace_buffer *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

enum print_line_t {
	TRACE_TYPE_PARTIAL_LINE = 0,
	TRACE_TYPE_HANDLED = 1,
	TRACE_TYPE_UNHANDLED = 2,
	TRACE_TYPE_NO_CONSUME = 3,
};

typedef enum print_line_t (*trace_print_func)(struct trace_iterator *, int, struct trace_event *);

struct trace_event_functions {
	trace_print_func trace;
	trace_print_func raw;
	trace_print_func hex;
	trace_print_func binary;
};

enum trace_reg {
	TRACE_REG_REGISTER = 0,
	TRACE_REG_UNREGISTER = 1,
	TRACE_REG_PERF_REGISTER = 2,
	TRACE_REG_PERF_UNREGISTER = 3,
	TRACE_REG_PERF_OPEN = 4,
	TRACE_REG_PERF_CLOSE = 5,
	TRACE_REG_PERF_ADD = 6,
	TRACE_REG_PERF_DEL = 7,
};

struct trace_event_class {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call *);
	struct list_head * (*get_fields)(struct trace_event_call *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call *);
};

struct trace_event_file;

struct trace_event_buffer {
	struct ring_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file *trace_file;
	void *entry;
	long unsigned int flags;
	int pc;
};

struct trace_subsystem_dir;

struct trace_event_file {
	struct list_head list;
	struct trace_event_call *event_call;
	struct event_filter *filter;
	struct dentry *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

enum {
	TRACE_EVENT_FL_FILTERED_BIT = 0,
	TRACE_EVENT_FL_CAP_ANY_BIT = 1,
	TRACE_EVENT_FL_NO_SET_FILTER_BIT = 2,
	TRACE_EVENT_FL_IGNORE_ENABLE_BIT = 3,
	TRACE_EVENT_FL_TRACEPOINT_BIT = 4,
	TRACE_EVENT_FL_KPROBE_BIT = 5,
	TRACE_EVENT_FL_UPROBE_BIT = 6,
};

enum {
	TRACE_EVENT_FL_FILTERED = 1,
	TRACE_EVENT_FL_CAP_ANY = 2,
	TRACE_EVENT_FL_NO_SET_FILTER = 4,
	TRACE_EVENT_FL_IGNORE_ENABLE = 8,
	TRACE_EVENT_FL_TRACEPOINT = 16,
	TRACE_EVENT_FL_KPROBE = 32,
	TRACE_EVENT_FL_UPROBE = 64,
};

enum {
	EVENT_FILE_FL_ENABLED_BIT = 0,
	EVENT_FILE_FL_RECORDED_CMD_BIT = 1,
	EVENT_FILE_FL_RECORDED_TGID_BIT = 2,
	EVENT_FILE_FL_FILTERED_BIT = 3,
	EVENT_FILE_FL_NO_SET_FILTER_BIT = 4,
	EVENT_FILE_FL_SOFT_MODE_BIT = 5,
	EVENT_FILE_FL_SOFT_DISABLED_BIT = 6,
	EVENT_FILE_FL_TRIGGER_MODE_BIT = 7,
	EVENT_FILE_FL_TRIGGER_COND_BIT = 8,
	EVENT_FILE_FL_PID_FILTER_BIT = 9,
	EVENT_FILE_FL_WAS_ENABLED_BIT = 10,
};

enum {
	EVENT_FILE_FL_ENABLED = 1,
	EVENT_FILE_FL_RECORDED_CMD = 2,
	EVENT_FILE_FL_RECORDED_TGID = 4,
	EVENT_FILE_FL_FILTERED = 8,
	EVENT_FILE_FL_NO_SET_FILTER = 16,
	EVENT_FILE_FL_SOFT_MODE = 32,
	EVENT_FILE_FL_SOFT_DISABLED = 64,
	EVENT_FILE_FL_TRIGGER_MODE = 128,
	EVENT_FILE_FL_TRIGGER_COND = 256,
	EVENT_FILE_FL_PID_FILTER = 512,
	EVENT_FILE_FL_WAS_ENABLED = 1024,
};

enum {
	FILTER_OTHER = 0,
	FILTER_STATIC_STRING = 1,
	FILTER_DYN_STRING = 2,
	FILTER_PTR_STRING = 3,
	FILTER_TRACE_FN = 4,
	FILTER_COMM = 5,
	FILTER_CPU = 6,
};

struct fwnode_reference_args;

struct fwnode_endpoint;

struct fwnode_operations {
	struct fwnode_handle * (*get)(struct fwnode_handle *);
	void (*put)(struct fwnode_handle *);
	bool (*device_is_available)(const struct fwnode_handle *);
	const void * (*device_get_match_data)(const struct fwnode_handle *, const struct device *);
	bool (*property_present)(const struct fwnode_handle *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle *, const char *, const char **, size_t);
	struct fwnode_handle * (*get_parent)(const struct fwnode_handle *);
	struct fwnode_handle * (*get_next_child_node)(const struct fwnode_handle *, struct fwnode_handle *);
	struct fwnode_handle * (*get_named_child_node)(const struct fwnode_handle *, const char *);
	int (*get_reference_args)(const struct fwnode_handle *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args *);
	struct fwnode_handle * (*graph_get_next_endpoint)(const struct fwnode_handle *, struct fwnode_handle *);
	struct fwnode_handle * (*graph_get_remote_endpoint)(const struct fwnode_handle *);
	struct fwnode_handle * (*graph_get_port_parent)(struct fwnode_handle *);
	int (*graph_parse_endpoint)(const struct fwnode_handle *, struct fwnode_endpoint *);
};

struct fwnode_endpoint {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle *local_fwnode;
};

struct fwnode_reference_args {
	struct fwnode_handle *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct acpi_table_header {
	char signature[4];
	u32 length;
	u8 revision;
	u8 checksum;
	char oem_id[6];
	char oem_table_id[8];
	u32 oem_revision;
	char asl_compiler_id[4];
	u32 asl_compiler_revision;
};

struct acpi_generic_address {
	u8 space_id;
	u8 bit_width;
	u8 bit_offset;
	u8 access_width;
	u64 address;
} __attribute__((packed));

struct acpi_table_fadt {
	struct acpi_table_header header;
	u32 facs;
	u32 dsdt;
	u8 model;
	u8 preferred_profile;
	u16 sci_interrupt;
	u32 smi_command;
	u8 acpi_enable;
	u8 acpi_disable;
	u8 s4_bios_request;
	u8 pstate_control;
	u32 pm1a_event_block;
	u32 pm1b_event_block;
	u32 pm1a_control_block;
	u32 pm1b_control_block;
	u32 pm2_control_block;
	u32 pm_timer_block;
	u32 gpe0_block;
	u32 gpe1_block;
	u8 pm1_event_length;
	u8 pm1_control_length;
	u8 pm2_control_length;
	u8 pm_timer_length;
	u8 gpe0_block_length;
	u8 gpe1_block_length;
	u8 gpe1_base;
	u8 cst_control;
	u16 c2_latency;
	u16 c3_latency;
	u16 flush_size;
	u16 flush_stride;
	u8 duty_offset;
	u8 duty_width;
	u8 day_alarm;
	u8 month_alarm;
	u8 century;
	u16 boot_flags;
	u8 reserved;
	u32 flags;
	struct acpi_generic_address reset_register;
	u8 reset_value;
	u16 arm_boot_flags;
	u8 minor_revision;
	u64 Xfacs;
	u64 Xdsdt;
	struct acpi_generic_address xpm1a_event_block;
	struct acpi_generic_address xpm1b_event_block;
	struct acpi_generic_address xpm1a_control_block;
	struct acpi_generic_address xpm1b_control_block;
	struct acpi_generic_address xpm2_control_block;
	struct acpi_generic_address xpm_timer_block;
	struct acpi_generic_address xgpe0_block;
	struct acpi_generic_address xgpe1_block;
	struct acpi_generic_address sleep_control;
	struct acpi_generic_address sleep_status;
	u64 hypervisor_id;
} __attribute__((packed));

enum reboot_mode {
	REBOOT_COLD = 0,
	REBOOT_WARM = 1,
	REBOOT_HARD = 2,
	REBOOT_SOFT = 3,
	REBOOT_GPIO = 4,
};

enum reboot_type {
	BOOT_TRIPLE = 116,
	BOOT_KBD = 107,
	BOOT_BIOS = 98,
	BOOT_ACPI = 97,
	BOOT_EFI = 101,
	BOOT_CF9_FORCE = 112,
	BOOT_CF9_SAFE = 113,
};

struct screen_info {
	__u8 orig_x;
	__u8 orig_y;
	__u16 ext_mem_k;
	__u16 orig_video_page;
	__u8 orig_video_mode;
	__u8 orig_video_cols;
	__u8 flags;
	__u8 unused2;
	__u16 orig_video_ega_bx;
	__u16 unused3;
	__u8 orig_video_lines;
	__u8 orig_video_isVGA;
	__u16 orig_video_points;
	__u16 lfb_width;
	__u16 lfb_height;
	__u16 lfb_depth;
	__u32 lfb_base;
	__u32 lfb_size;
	__u16 cl_magic;
	__u16 cl_offset;
	__u16 lfb_linelength;
	__u8 red_size;
	__u8 red_pos;
	__u8 green_size;
	__u8 green_pos;
	__u8 blue_size;
	__u8 blue_pos;
	__u8 rsvd_size;
	__u8 rsvd_pos;
	__u16 vesapm_seg;
	__u16 vesapm_off;
	__u16 pages;
	__u16 vesa_attributes;
	__u32 capabilities;
	__u32 ext_lfb_base;
	__u8 _reserved[2];
} __attribute__((packed));

typedef long unsigned int efi_status_t;

typedef u8 efi_bool_t;

typedef u16 efi_char16_t;

typedef u64 efi_physical_addr_t;

typedef void *efi_handle_t;

typedef guid_t efi_guid_t;

typedef struct {
	u64 signature;
	u32 revision;
	u32 headersize;
	u32 crc32;
	u32 reserved;
} efi_table_hdr_t;

typedef struct {
	u32 type;
	u32 pad;
	u64 phys_addr;
	u64 virt_addr;
	u64 num_pages;
	u64 attribute;
} efi_memory_desc_t;

typedef struct {
	efi_guid_t guid;
	u32 headersize;
	u32 flags;
	u32 imagesize;
} efi_capsule_header_t;

typedef struct {
	u16 year;
	u8 month;
	u8 day;
	u8 hour;
	u8 minute;
	u8 second;
	u8 pad1;
	u32 nanosecond;
	s16 timezone;
	u8 daylight;
	u8 pad2;
} efi_time_t;

typedef struct {
	u32 resolution;
	u32 accuracy;
	u8 sets_to_zero;
} efi_time_cap_t;

typedef struct {
	efi_table_hdr_t hdr;
	void *raise_tpl;
	void *restore_tpl;
	efi_status_t (*allocate_pages)(int, int, long unsigned int, efi_physical_addr_t *);
	efi_status_t (*free_pages)(efi_physical_addr_t, long unsigned int);
	efi_status_t (*get_memory_map)(long unsigned int *, void *, long unsigned int *, long unsigned int *, u32 *);
	efi_status_t (*allocate_pool)(int, long unsigned int, void **);
	efi_status_t (*free_pool)(void *);
	void *create_event;
	void *set_timer;
	void *wait_for_event;
	void *signal_event;
	void *close_event;
	void *check_event;
	void *install_protocol_interface;
	void *reinstall_protocol_interface;
	void *uninstall_protocol_interface;
	efi_status_t (*handle_protocol)(efi_handle_t, efi_guid_t *, void **);
	void *__reserved;
	void *register_protocol_notify;
	efi_status_t (*locate_handle)(int, efi_guid_t *, void *, long unsigned int *, efi_handle_t *);
	void *locate_device_path;
	efi_status_t (*install_configuration_table)(efi_guid_t *, void *);
	void *load_image;
	void *start_image;
	void *exit;
	void *unload_image;
	efi_status_t (*exit_boot_services)(efi_handle_t, long unsigned int);
	void *get_next_monotonic_count;
	void *stall;
	void *set_watchdog_timer;
	void *connect_controller;
	void *disconnect_controller;
	void *open_protocol;
	void *close_protocol;
	void *open_protocol_information;
	void *protocols_per_handle;
	void *locate_handle_buffer;
	efi_status_t (*locate_protocol)(efi_guid_t *, void *, void **);
	void *install_multiple_protocol_interfaces;
	void *uninstall_multiple_protocol_interfaces;
	void *calculate_crc32;
	void *copy_mem;
	void *set_mem;
	void *create_event_ex;
} efi_boot_services_t;

typedef efi_status_t efi_get_time_t(efi_time_t *, efi_time_cap_t *);

typedef efi_status_t efi_set_time_t(efi_time_t *);

typedef efi_status_t efi_get_wakeup_time_t(efi_bool_t *, efi_bool_t *, efi_time_t *);

typedef efi_status_t efi_set_wakeup_time_t(efi_bool_t, efi_time_t *);

typedef efi_status_t efi_get_variable_t(efi_char16_t *, efi_guid_t *, u32 *, long unsigned int *, void *);

typedef efi_status_t efi_get_next_variable_t(long unsigned int *, efi_char16_t *, efi_guid_t *);

typedef efi_status_t efi_set_variable_t(efi_char16_t *, efi_guid_t *, u32, long unsigned int, void *);

typedef efi_status_t efi_get_next_high_mono_count_t(u32 *);

typedef void efi_reset_system_t(int, efi_status_t, long unsigned int, efi_char16_t *);

typedef efi_status_t efi_set_virtual_address_map_t(long unsigned int, long unsigned int, u32, efi_memory_desc_t *);

typedef efi_status_t efi_query_variable_info_t(u32, u64 *, u64 *, u64 *);

typedef efi_status_t efi_update_capsule_t(efi_capsule_header_t **, long unsigned int, long unsigned int);

typedef efi_status_t efi_query_capsule_caps_t(efi_capsule_header_t **, long unsigned int, u64 *, int *);

typedef struct {
	efi_table_hdr_t hdr;
	efi_get_time_t *get_time;
	efi_set_time_t *set_time;
	efi_get_wakeup_time_t *get_wakeup_time;
	efi_set_wakeup_time_t *set_wakeup_time;
	efi_set_virtual_address_map_t *set_virtual_address_map;
	void *convert_pointer;
	efi_get_variable_t *get_variable;
	efi_get_next_variable_t *get_next_variable;
	efi_set_variable_t *set_variable;
	efi_get_next_high_mono_count_t *get_next_high_mono_count;
	efi_reset_system_t *reset_system;
	efi_update_capsule_t *update_capsule;
	efi_query_capsule_caps_t *query_capsule_caps;
	efi_query_variable_info_t *query_variable_info;
} efi_runtime_services_t;

typedef struct {
	efi_table_hdr_t hdr;
	long unsigned int fw_vendor;
	u32 fw_revision;
	long unsigned int con_in_handle;
	long unsigned int con_in;
	long unsigned int con_out_handle;
	long unsigned int con_out;
	long unsigned int stderr_handle;
	long unsigned int stderr;
	efi_runtime_services_t *runtime;
	efi_boot_services_t *boottime;
	long unsigned int nr_tables;
	long unsigned int tables;
} efi_system_table_t;

struct efi_memory_map {
	phys_addr_t phys_map;
	void *map;
	void *map_end;
	int nr_map;
	long unsigned int desc_version;
	long unsigned int desc_size;
	bool late;
};

struct efi {
	efi_system_table_t *systab;
	unsigned int runtime_version;
	long unsigned int mps;
	long unsigned int acpi;
	long unsigned int acpi20;
	long unsigned int smbios;
	long unsigned int smbios3;
	long unsigned int sal_systab;
	long unsigned int boot_info;
	long unsigned int hcdp;
	long unsigned int uga;
	long unsigned int uv_systab;
	long unsigned int fw_vendor;
	long unsigned int runtime;
	long unsigned int config_table;
	long unsigned int esrt;
	long unsigned int properties_table;
	long unsigned int mem_attr_table;
	long unsigned int rng_seed;
	long unsigned int tpm_log;
	long unsigned int mem_reserve;
	efi_get_time_t *get_time;
	efi_set_time_t *set_time;
	efi_get_wakeup_time_t *get_wakeup_time;
	efi_set_wakeup_time_t *set_wakeup_time;
	efi_get_variable_t *get_variable;
	efi_get_next_variable_t *get_next_variable;
	efi_set_variable_t *set_variable;
	efi_set_variable_t *set_variable_nonblocking;
	efi_query_variable_info_t *query_variable_info;
	efi_query_variable_info_t *query_variable_info_nonblocking;
	efi_update_capsule_t *update_capsule;
	efi_query_capsule_caps_t *query_capsule_caps;
	efi_get_next_high_mono_count_t *get_next_high_mono_count;
	efi_reset_system_t *reset_system;
	efi_set_virtual_address_map_t *set_virtual_address_map;
	struct efi_memory_map memmap;
	long unsigned int flags;
};

enum efi_rts_ids {
	NONE = 0,
	GET_TIME = 1,
	SET_TIME = 2,
	GET_WAKEUP_TIME = 3,
	SET_WAKEUP_TIME = 4,
	GET_VARIABLE = 5,
	GET_NEXT_VARIABLE = 6,
	SET_VARIABLE = 7,
	QUERY_VARIABLE_INFO = 8,
	GET_NEXT_HIGH_MONO_COUNT = 9,
	RESET_SYSTEM = 10,
	UPDATE_CAPSULE = 11,
	QUERY_CAPSULE_CAPS = 12,
};

struct efi_runtime_work {
	void *arg1;
	void *arg2;
	void *arg3;
	void *arg4;
	void *arg5;
	efi_status_t status;
	struct work_struct work;
	enum efi_rts_ids efi_rts_id;
	struct completion efi_rts_comp;
};

enum memblock_flags {
	MEMBLOCK_NONE = 0,
	MEMBLOCK_HOTPLUG = 1,
	MEMBLOCK_MIRROR = 2,
	MEMBLOCK_NOMAP = 4,
};

struct memblock_region {
	phys_addr_t base;
	phys_addr_t size;
	enum memblock_flags flags;
	int nid;
};

struct memblock_type {
	long unsigned int cnt;
	long unsigned int max;
	phys_addr_t total_size;
	struct memblock_region *regions;
	char *name;
};

struct memblock {
	bool bottom_up;
	phys_addr_t current_limit;
	struct memblock_type memory;
	struct memblock_type reserved;
};

enum psci_conduit {
	PSCI_CONDUIT_NONE = 0,
	PSCI_CONDUIT_SMC = 1,
	PSCI_CONDUIT_HVC = 2,
};

enum smccc_version {
	SMCCC_VERSION_1_0 = 0,
	SMCCC_VERSION_1_1 = 1,
};

struct psci_operations {
	u32 (*get_version)();
	int (*cpu_suspend)(u32, long unsigned int);
	int (*cpu_off)(u32);
	int (*cpu_on)(long unsigned int, long unsigned int);
	int (*migrate)(long unsigned int);
	int (*affinity_info)(long unsigned int, long unsigned int);
	int (*migrate_info_type)();
	enum psci_conduit conduit;
	enum smccc_version smccc_version;
};

struct mpidr_hash {
	u64 mask;
	u32 shift_aff[4];
	u32 bits;
};

enum acpi_irq_model_id {
	ACPI_IRQ_MODEL_PIC = 0,
	ACPI_IRQ_MODEL_IOAPIC = 1,
	ACPI_IRQ_MODEL_IOSAPIC = 2,
	ACPI_IRQ_MODEL_PLATFORM = 3,
	ACPI_IRQ_MODEL_GIC = 4,
	ACPI_IRQ_MODEL_COUNT = 5,
};

enum con_scroll {
	SM_UP = 0,
	SM_DOWN = 1,
};

struct vc_data;

struct console_font;

struct consw {
	struct module *owner;
	const char * (*con_startup)();
	void (*con_init)(struct vc_data *, int);
	void (*con_deinit)(struct vc_data *);
	void (*con_clear)(struct vc_data *, int, int, int, int);
	void (*con_putc)(struct vc_data *, int, int, int);
	void (*con_putcs)(struct vc_data *, const short unsigned int *, int, int, int);
	void (*con_cursor)(struct vc_data *, int);
	bool (*con_scroll)(struct vc_data *, unsigned int, unsigned int, enum con_scroll, unsigned int);
	int (*con_switch)(struct vc_data *);
	int (*con_blank)(struct vc_data *, int, int);
	int (*con_font_set)(struct vc_data *, struct console_font *, unsigned int);
	int (*con_font_get)(struct vc_data *, struct console_font *);
	int (*con_font_default)(struct vc_data *, struct console_font *, char *);
	int (*con_font_copy)(struct vc_data *, int);
	int (*con_resize)(struct vc_data *, unsigned int, unsigned int, unsigned int);
	void (*con_set_palette)(struct vc_data *, const unsigned char *);
	void (*con_scrolldelta)(struct vc_data *, int);
	int (*con_set_origin)(struct vc_data *);
	void (*con_save_screen)(struct vc_data *);
	u8 (*con_build_attr)(struct vc_data *, u8, u8, u8, u8, u8, u8);
	void (*con_invert_region)(struct vc_data *, u16 *, int);
	u16 * (*con_screen_pos)(struct vc_data *, int);
	long unsigned int (*con_getxy)(struct vc_data *, long unsigned int, int *, int *);
	void (*con_flush_scrollback)(struct vc_data *);
	int (*con_debug_enter)(struct vc_data *);
	int (*con_debug_leave)(struct vc_data *);
};

struct tty_driver;

struct console {
	char name[16];
	void (*write)(struct console *, const char *, unsigned int);
	int (*read)(struct console *, char *, unsigned int);
	struct tty_driver * (*device)(struct console *, int *);
	void (*unblank)();
	int (*setup)(struct console *, char *);
	int (*match)(struct console *, char *, int, char *);
	short int flags;
	short int index;
	int cflag;
	void *data;
	struct console *next;
};

enum wb_stat_item {
	WB_RECLAIMABLE = 0,
	WB_WRITEBACK = 1,
	WB_DIRTIED = 2,
	WB_WRITTEN = 3,
	NR_WB_STAT_ITEMS = 4,
};

struct bdi_writeback_congested {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload {
	struct bio *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec bip_inline_vecs[0];
};

enum stat_group {
	STAT_READ = 0,
	STAT_WRITE = 1,
	STAT_DISCARD = 2,
	NR_STAT_GROUPS = 3,
};

enum cpu_idle_type {
	CPU_IDLE = 0,
	CPU_NOT_IDLE = 1,
	CPU_NEWLY_IDLE = 2,
	CPU_MAX_IDLE_TYPES = 3,
};

struct property {
	char *name;
	int length;
	void *value;
	struct property *next;
	long unsigned int _flags;
	struct bin_attribute attr;
};

enum memcg_stat_item {
	MEMCG_CACHE = 29,
	MEMCG_RSS = 30,
	MEMCG_RSS_HUGE = 31,
	MEMCG_SWAP = 32,
	MEMCG_SOCK = 33,
	MEMCG_KERNEL_STACK_KB = 34,
	MEMCG_NR_STAT = 35,
};

enum memcg_memory_event {
	MEMCG_LOW = 0,
	MEMCG_HIGH = 1,
	MEMCG_MAX = 2,
	MEMCG_OOM = 3,
	MEMCG_OOM_KILL = 4,
	MEMCG_SWAP_MAX = 5,
	MEMCG_SWAP_FAIL = 6,
	MEMCG_NR_MEMORY_EVENTS = 7,
};

enum mem_cgroup_events_target {
	MEM_CGROUP_TARGET_THRESH = 0,
	MEM_CGROUP_TARGET_SOFTLIMIT = 1,
	MEM_CGROUP_TARGET_NUMAINFO = 2,
	MEM_CGROUP_NTARGETS = 3,
};

struct mem_cgroup_stat_cpu {
	long int count[35];
	long unsigned int events[81];
	long unsigned int nr_page_events;
	long unsigned int targets[3];
};

struct mem_cgroup_reclaim_iter {
	struct mem_cgroup *position;
	unsigned int generation;
};

struct lruvec_stat {
	long int count[29];
};

struct memcg_shrinker_map {
	struct callback_head rcu;
	long unsigned int map[0];
};

struct mem_cgroup_per_node {
	struct lruvec lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct eventfd_ctx;

struct mem_cgroup_threshold {
	struct eventfd_ctx *eventfd;
	long unsigned int threshold;
};

struct mem_cgroup_threshold_ary {
	int current_threshold;
	unsigned int size;
	struct mem_cgroup_threshold entries[0];
};

enum kgdb_bptype {
	BP_BREAKPOINT = 0,
	BP_HARDWARE_BREAKPOINT = 1,
	BP_WRITE_WATCHPOINT = 2,
	BP_READ_WATCHPOINT = 3,
	BP_ACCESS_WATCHPOINT = 4,
	BP_POKE_BREAKPOINT = 5,
};

struct dbg_reg_def_t {
	char *name;
	int size;
	int offset;
};

struct kgdb_arch {
	unsigned char gdb_bpt_instr[4];
	long unsigned int flags;
	int (*set_breakpoint)(long unsigned int, char *);
	int (*remove_breakpoint)(long unsigned int, char *);
	int (*set_hw_breakpoint)(long unsigned int, int, enum kgdb_bptype);
	int (*remove_hw_breakpoint)(long unsigned int, int, enum kgdb_bptype);
	void (*disable_hw_break)(struct pt_regs *);
	void (*remove_all_hw_break)();
	void (*correct_hw_break)();
	void (*enable_nmi)(bool);
};

struct kgdb_io {
	const char *name;
	int (*read_char)();
	void (*write_char)(u8);
	void (*flush)();
	int (*init)();
	void (*pre_exception)();
	void (*post_exception)();
	int is_console;
};

struct percpu_cluster {
	struct swap_cluster_info index;
	unsigned int next;
};

struct disk_stats {
	u64 nsecs[3];
	long unsigned int sectors[3];
	long unsigned int ios[3];
	long unsigned int merges[3];
	long unsigned int io_ticks;
	long unsigned int time_in_queue;
	local_t in_flight[2];
};

struct partition_meta_info {
	char uuid[37];
	u8 volname[64];
};

struct disk_part_tbl {
	struct callback_head callback_head;
	int len;
	struct hd_struct *last_lookup;
	struct hd_struct *part[0];
};

struct blk_integrity_iter;

typedef blk_status_t integrity_processing_fn(struct blk_integrity_iter *);

struct blk_integrity_profile {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	const char *name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct hd_geometry;

struct blk_zone;

struct pr_ops;

struct block_device_operations {
	int (*open)(struct block_device *, fmode_t);
	void (*release)(struct gendisk *, fmode_t);
	int (*rw_page)(struct block_device *, sector_t, struct page *, unsigned int);
	int (*ioctl)(struct block_device *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk *, unsigned int);
	int (*media_changed)(struct gendisk *);
	void (*unlock_native_capacity)(struct gendisk *);
	int (*revalidate_disk)(struct gendisk *);
	int (*getgeo)(struct block_device *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device *, long unsigned int);
	int (*report_zones)(struct gendisk *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sg_io_v4 {
	__s32 guard;
	__u32 protocol;
	__u32 subprotocol;
	__u32 request_len;
	__u64 request;
	__u64 request_tag;
	__u32 request_attr;
	__u32 request_priority;
	__u32 request_extra;
	__u32 max_response_len;
	__u64 response;
	__u32 dout_iovec_count;
	__u32 dout_xfer_len;
	__u32 din_iovec_count;
	__u32 din_xfer_len;
	__u64 dout_xferp;
	__u64 din_xferp;
	__u32 timeout;
	__u32 flags;
	__u64 usr_ptr;
	__u32 spare_in;
	__u32 driver_status;
	__u32 transport_status;
	__u32 device_status;
	__u32 retry_delay;
	__u32 info;
	__u32 duration;
	__u32 response_len;
	__s32 din_resid;
	__s32 dout_resid;
	__u64 generated_tag;
	__u32 spare_out;
	__u32 padding;
};

struct bsg_ops {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request *, struct sg_io_v4 *);
	void (*free_rq)(struct request *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef __u32 req_flags_t;

typedef void rq_end_io_fn(struct request *, blk_status_t);

enum mq_rq_state {
	MQ_RQ_IDLE = 0,
	MQ_RQ_IN_FLIGHT = 1,
	MQ_RQ_COMPLETE = 2,
};

struct request {
	struct request_queue *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio *bio;
	struct bio *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn *saved_end_io;
		} flush;
	};
	struct gendisk *rq_disk;
	struct hd_struct *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn *end_io;
	void *end_io_data;
	struct request *next_rq;
};

struct blk_zone {
	__u64 start;
	__u64 len;
	__u64 wp;
	__u8 type;
	__u8 cond;
	__u8 non_seq;
	__u8 reset;
	__u8 reserved[36];
};

enum elv_merge {
	ELEVATOR_NO_MERGE = 0,
	ELEVATOR_FRONT_MERGE = 1,
	ELEVATOR_BACK_MERGE = 2,
	ELEVATOR_DISCARD_MERGE = 3,
};

struct elevator_type;

struct blk_mq_alloc_data;

struct elevator_mq_ops {
	int (*init_sched)(struct request_queue *, struct elevator_type *);
	void (*exit_sched)(struct elevator_queue *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	bool (*allow_merge)(struct request_queue *, struct request *, struct bio *);
	bool (*bio_merge)(struct blk_mq_hw_ctx *, struct bio *);
	int (*request_merge)(struct request_queue *, struct request **, struct bio *);
	void (*request_merged)(struct request_queue *, struct request *, enum elv_merge);
	void (*requests_merged)(struct request_queue *, struct request *, struct request *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request *, struct bio *);
	void (*finish_request)(struct request *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request *, u64);
	void (*started_request)(struct request *);
	void (*requeue_request)(struct request *);
	struct request * (*former_request)(struct request_queue *, struct request *);
	struct request * (*next_request)(struct request_queue *, struct request *);
	void (*init_icq)(struct io_cq *);
	void (*exit_icq)(struct io_cq *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide37;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry;

struct blk_mq_debugfs_attr;

struct elevator_type {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue {
	struct elevator_type *type;
	void *elevator_data;
	struct kobject kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue *, char *);
	ssize_t (*store)(struct elevator_queue *, const char *, size_t);
};

struct seq_file___3;

struct seq_operations___2;

struct blk_mq_debugfs_attr {
	const char *name;
	umode_t mode;
	int (*show)(void *, struct seq_file___3 *);
	ssize_t (*write)(void *, const char *, size_t, loff_t *);
	const struct seq_operations___2 *seq_ops;
};

struct blk_mq_hw_ctx___2;

struct blk_mq_queue_data;

typedef blk_status_t queue_rq_fn(struct blk_mq_hw_ctx___2 *, const struct blk_mq_queue_data *);

typedef void commit_rqs_fn(struct blk_mq_hw_ctx___2 *);

typedef bool get_budget_fn(struct blk_mq_hw_ctx___2 *);

typedef void put_budget_fn(struct blk_mq_hw_ctx___2 *);

enum blk_eh_timer_return {
	BLK_EH_DONE = 0,
	BLK_EH_RESET_TIMER = 1,
};

struct request___2;

typedef enum blk_eh_timer_return timeout_fn(struct request___2 *, bool);

typedef int poll_fn(struct blk_mq_hw_ctx___2 *);

typedef void complete_fn(struct request___2 *);

typedef int init_hctx_fn(struct blk_mq_hw_ctx___2 *, void *, unsigned int);

typedef void exit_hctx_fn(struct blk_mq_hw_ctx___2 *, unsigned int);

typedef int init_request_fn(struct blk_mq_tag_set *, struct request___2 *, unsigned int, unsigned int);

typedef void exit_request_fn(struct blk_mq_tag_set *, struct request___2 *, unsigned int);

struct request_queue___2;

typedef bool busy_fn(struct request_queue___2 *);

typedef int map_queues_fn(struct blk_mq_tag_set *);

typedef void cleanup_rq_fn(struct request___2 *);

struct seq_file___4;

struct blk_mq_ops {
	queue_rq_fn *queue_rq;
	commit_rqs_fn *commit_rqs;
	get_budget_fn *get_budget;
	put_budget_fn *put_budget;
	timeout_fn *timeout;
	poll_fn *poll;
	complete_fn *complete;
	init_hctx_fn *init_hctx;
	exit_hctx_fn *exit_hctx;
	init_request_fn *init_request;
	exit_request_fn *exit_request;
	void (*initialize_rq_fn)(struct request___2 *);
	busy_fn *busy;
	map_queues_fn *map_queues;
	void (*show_rq)(struct seq_file___4 *, struct request___2 *);
	union {
		cleanup_rq_fn *cleanup_rq;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide44;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct blk_integrity_iter {
	void *prot_buf;
	void *data_buf;
	sector_t seed;
	unsigned int data_size;
	short unsigned int interval;
	const char *disk_name;
};

enum pr_type {
	PR_WRITE_EXCLUSIVE = 1,
	PR_EXCLUSIVE_ACCESS = 2,
	PR_WRITE_EXCLUSIVE_REG_ONLY = 3,
	PR_EXCLUSIVE_ACCESS_REG_ONLY = 4,
	PR_WRITE_EXCLUSIVE_ALL_REGS = 5,
	PR_EXCLUSIVE_ACCESS_ALL_REGS = 6,
};

struct block_device___2;

struct pr_ops {
	int (*pr_register)(struct block_device___2 *, u64, u64, u32);
	int (*pr_reserve)(struct block_device___2 *, u64, enum pr_type, u32);
	int (*pr_release)(struct block_device___2 *, u64, enum pr_type);
	int (*pr_preempt)(struct block_device___2 *, u64, u64, enum pr_type, bool);
	int (*pr_clear)(struct block_device___2 *, u64);
};

struct trace_event_raw_initcall_level {
	struct trace_entry ent;
	u32 __data_loc_level;
	char __data[0];
};

struct trace_event_raw_initcall_start {
	struct trace_entry ent;
	initcall_t func;
	char __data[0];
};

struct trace_event_raw_initcall_finish {
	struct trace_entry ent;
	initcall_t func;
	int ret;
	char __data[0];
};

struct trace_event_data_offsets_initcall_level {
	u32 level;
};

struct trace_event_data_offsets_initcall_start {};

struct trace_event_data_offsets_initcall_finish {};

struct blacklist_entry {
	struct list_head next;
	char *buf;
};

struct module___2;

struct file___2;

struct kiocb___2;

struct iov_iter___2;

struct poll_table_struct___2;

struct vm_area_struct___3;

struct inode___3;

struct file_lock___2;

struct page___3;

struct seq_file___5;

struct file_operations___2 {
	struct module___2 *owner;
	loff_t (*llseek)(struct file___2 *, loff_t, int);
	ssize_t (*read)(struct file___2 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___2 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___2 *, struct iov_iter___2 *);
	ssize_t (*write_iter)(struct kiocb___2 *, struct iov_iter___2 *);
	int (*iopoll)(struct kiocb___2 *, bool);
	int (*iterate)(struct file___2 *, struct dir_context *);
	int (*iterate_shared)(struct file___2 *, struct dir_context *);
	__poll_t (*poll)(struct file___2 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___2 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___2 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___2 *, struct vm_area_struct___3 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___3 *, struct file___2 *);
	int (*flush)(struct file___2 *, fl_owner_t);
	int (*release)(struct inode___3 *, struct file___2 *);
	int (*fsync)(struct file___2 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___2 *, int);
	int (*lock)(struct file___2 *, int, struct file_lock___2 *);
	ssize_t (*sendpage)(struct file___2 *, struct page___3 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___2 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___2 *, int, struct file_lock___2 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___2 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___2 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___2 *, long int, struct file_lock___2 **, void **);
	long int (*fallocate)(struct file___2 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___5 *, struct file___2 *);
	ssize_t (*copy_file_range)(struct file___2 *, loff_t, struct file___2 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___2 *, loff_t, struct file___2 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___2 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct atomic_notifier_head___2;

struct mm_struct___2;

struct mem_cgroup___2;

struct cred___2;

struct nsproxy___2;

struct signal_struct___2;

struct bio_list___2;

struct backing_dev_info___2;

struct io_context___2;

struct css_set___2;

struct perf_event_context___2;

struct request_queue___3;

struct vm_struct___2;

struct task_struct___3 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___3 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___2 *mm;
	struct mm_struct___2 *active_mm;
	struct vmacache vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___3 *real_parent;
	struct task_struct___3 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___3 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___2 *ptracer_cred;
	const struct cred___2 *real_cred;
	const struct cred___2 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___2 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___3 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___2 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___3 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct secondary_data___2 {
	void *stack;
	struct task_struct___3 *task;
	long int status;
};

enum {
	UNAME26 = 131072,
	ADDR_NO_RANDOMIZE = 262144,
	FDPIC_FUNCPTRS = 524288,
	MMAP_PAGE_ZERO = 1048576,
	ADDR_COMPAT_LAYOUT = 2097152,
	READ_IMPLIES_EXEC = 4194304,
	ADDR_LIMIT_32BIT = 8388608,
	SHORT_INODE = 16777216,
	WHOLE_SECONDS = 33554432,
	STICKY_TIMEOUTS = 67108864,
	ADDR_LIMIT_3GB = 134217728,
};

enum hrtimer_base_type {
	HRTIMER_BASE_MONOTONIC = 0,
	HRTIMER_BASE_REALTIME = 1,
	HRTIMER_BASE_BOOTTIME = 2,
	HRTIMER_BASE_TAI = 3,
	HRTIMER_BASE_MONOTONIC_SOFT = 4,
	HRTIMER_BASE_REALTIME_SOFT = 5,
	HRTIMER_BASE_BOOTTIME_SOFT = 6,
	HRTIMER_BASE_TAI_SOFT = 7,
	HRTIMER_MAX_CLOCK_BASES = 8,
};

enum {
	MM_FILEPAGES = 0,
	MM_ANONPAGES = 1,
	MM_SWAPENTS = 2,
	MM_SHMEMPAGES = 3,
	NR_MM_COUNTERS = 4,
};

enum rseq_cs_flags_bit {
	RSEQ_CS_FLAG_NO_RESTART_ON_PREEMPT_BIT = 0,
	RSEQ_CS_FLAG_NO_RESTART_ON_SIGNAL_BIT = 1,
	RSEQ_CS_FLAG_NO_RESTART_ON_MIGRATE_BIT = 2,
};

enum perf_event_task_context {
	perf_invalid_context = 4294967295,
	perf_hw_context = 0,
	perf_sw_context = 1,
	perf_nr_task_contexts = 2,
};

struct key___3;

struct user_struct___2;

struct user_namespace___2;

struct cred___2 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___3 *session_keyring;
	struct key___3 *process_keyring;
	struct key___3 *thread_keyring;
	struct key___3 *request_key_auth;
	void *security;
	struct user_struct___2 *user;
	struct user_namespace___2 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct uts_namespace___2;

struct cgroup_namespace___2;

struct nsproxy___2 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___2 *cgroup_ns;
};

enum rseq_event_mask_bits {
	RSEQ_EVENT_PREEMPT_BIT = 0,
	RSEQ_EVENT_SIGNAL_BIT = 1,
	RSEQ_EVENT_MIGRATE_BIT = 2,
};

struct proc_ns_operations___2;

struct ns_common___2 {
	atomic_long_t stashed;
	const struct proc_ns_operations___2 *ops;
	unsigned int inum;
};

struct user_namespace___3;

struct ucounts___2;

struct uts_namespace___2 {
	struct kref kref;
	struct new_utsname name;
	struct user_namespace___3 *user_ns;
	struct ucounts___2 *ucounts;
	struct ns_common___2 ns;
};

struct proc_ns_operations___2 {
	const char *name;
	const char *real_ns_name;
	int type;
	struct ns_common___2 * (*get)(struct task_struct___3 *);
	void (*put)(struct ns_common___2 *);
	int (*install)(struct nsproxy___2 *, struct ns_common___2 *);
	struct user_namespace___3 * (*owner)(struct ns_common___2 *);
	struct ns_common___2 * (*get_parent)(struct ns_common___2 *);
};

struct rw_semaphore___2;

enum {
	PROC_ROOT_INO = 1,
	PROC_IPC_INIT_INO = 4026531839,
	PROC_UTS_INIT_INO = 4026531838,
	PROC_USER_INIT_INO = 4026531837,
	PROC_PID_INIT_INO = 4026531836,
	PROC_CGROUP_INIT_INO = 4026531835,
};

typedef __u16 __le16;

typedef __u16 __be16;

typedef __u32 __be32;

typedef __u64 __be64;

typedef __u32 __wsum;

typedef u64 uint64_t;

typedef unsigned int slab_flags_t;

struct module___3;

struct file___3;

struct kiocb___3;

struct iov_iter___3;

struct poll_table_struct___3;

struct vm_area_struct___4;

struct inode___4;

struct file_lock___3;

struct page___4;

struct pipe_inode_info___2;

struct seq_file___6;

struct file_operations___3 {
	struct module___3 *owner;
	loff_t (*llseek)(struct file___3 *, loff_t, int);
	ssize_t (*read)(struct file___3 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___3 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___3 *, struct iov_iter___3 *);
	ssize_t (*write_iter)(struct kiocb___3 *, struct iov_iter___3 *);
	int (*iopoll)(struct kiocb___3 *, bool);
	int (*iterate)(struct file___3 *, struct dir_context *);
	int (*iterate_shared)(struct file___3 *, struct dir_context *);
	__poll_t (*poll)(struct file___3 *, struct poll_table_struct___3 *);
	long int (*unlocked_ioctl)(struct file___3 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___3 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___3 *, struct vm_area_struct___4 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___4 *, struct file___3 *);
	int (*flush)(struct file___3 *, fl_owner_t);
	int (*release)(struct inode___4 *, struct file___3 *);
	int (*fsync)(struct file___3 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___3 *, int);
	int (*lock)(struct file___3 *, int, struct file_lock___3 *);
	ssize_t (*sendpage)(struct file___3 *, struct page___4 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___3 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___3 *, int, struct file_lock___3 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___3 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___3 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___3 *, long int, struct file_lock___3 **, void **);
	long int (*fallocate)(struct file___3 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___6 *, struct file___3 *);
	ssize_t (*copy_file_range)(struct file___3 *, loff_t, struct file___3 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___3 *, loff_t, struct file___3 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___3 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___2 {
	u64 seqnum;
	struct vm_area_struct___4 *vmas[4];
};

struct page_frag___2 {
	struct page___4 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___2;

struct debug_info___2 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___2 *hbp_break[16];
	struct perf_event___2 *hbp_watch[16];
};

struct thread_struct___2 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___2 debug;
	long: 64;
};

struct mm_struct___3;

struct pid___2;

struct cred___3;

struct nsproxy___3;

struct signal_struct___3;

struct bio_list___3;

struct backing_dev_info___3;

struct io_context___3;

struct css_set___3;

struct perf_event_context___3;

struct request_queue___4;

struct vm_struct___3;

struct task_struct___4 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___4 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___3 *mm;
	struct mm_struct___3 *active_mm;
	struct vmacache___2 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___4 *real_parent;
	struct task_struct___4 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___4 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___2 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___2 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___2 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___3 *ptracer_cred;
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___3 *nsproxy;
	struct signal_struct___3 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___4 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___3 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___3 *backing_dev_info;
	struct io_context___3 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___3 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___3 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___2 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___4 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___4 *oom_reaper_list;
	struct vm_struct___3 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___2 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___2 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___4 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___2)(struct perf_event___2 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___2;

struct fasync_struct___2;

struct pid_namespace___2;

struct trace_event_call___2;

struct perf_cgroup___2;

struct perf_event___2 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___2 *group_leader;
	struct pmu___2 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___2 hw;
	struct perf_event_context___3 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___2 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___4 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___2 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___2 *);
	struct callback_head callback_head;
	struct pid_namespace___2 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___2 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___2 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___2 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___2 *cgrp;
	struct list_head sb_list;
};

struct rw_semaphore___3 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___4 *owner;
};

struct key___4;

struct user_namespace___3 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___3 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___2 ns;
	long unsigned int flags;
	struct key___4 *persistent_keyring_register;
	struct rw_semaphore___3 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___2 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___4 *pgtable_t___2;

struct address_space___2;

struct dev_pagemap___2;

struct page___4 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___2 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___4 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___2 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___3 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___2 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___2;

struct lruvec___2 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___2 *pgdat;
};

struct zone___2 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___2 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___2 {
	struct zone___2 *zone;
	int zone_idx;
};

struct zonelist___2 {
	struct zoneref___2 _zonerefs[25];
};

struct pglist_data___2 {
	struct zone___2 node_zones[3];
	struct zonelist___2 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___4 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___4 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___2 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct llist_head {
	struct llist_node *first;
};

typedef struct __call_single_data call_single_data_t;

struct secondary_data___3 {
	void *stack;
	struct task_struct___4 *task;
	long int status;
};

struct blocking_notifier_head___2 {
	struct rw_semaphore___3 rwsem;
	struct notifier_block *head;
};

struct vfsmount___2;

struct dentry___3;

struct path___2 {
	struct vfsmount___2 *mnt;
	struct dentry___3 *dentry;
};

struct fown_struct___2 {
	rwlock_t lock;
	struct pid___2 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___3 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___2 f_path;
	struct inode___4 *f_inode;
	const struct file_operations___3 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___2 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___2 *f_mapping;
	errseq_t f_wb_err;
};

struct user_struct___3;

struct cred___3 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___4 *session_keyring;
	struct key___4 *process_keyring;
	struct key___4 *thread_keyring;
	struct key___4 *request_key_auth;
	void *security;
	struct user_struct___3 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct ida {
	struct xarray xa;
};

struct kernfs_root___2;

struct kernfs_elem_dir___2 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___2 *root;
};

struct kernfs_node___2;

struct kernfs_syscall_ops___2;

struct kernfs_root___2 {
	struct kernfs_node___2 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___2 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___2 {
	struct kernfs_node___2 *target_kn;
};

struct kernfs_ops___2;

struct kernfs_elem_attr___2 {
	const struct kernfs_ops___2 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___2 *notify_next;
};

struct kernfs_node___2 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___2 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___2 dir;
		struct kernfs_elem_symlink___2 symlink;
		struct kernfs_elem_attr___2 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___2;

struct kernfs_ops___2 {
	int (*open)(struct kernfs_open_file___2 *);
	void (*release)(struct kernfs_open_file___2 *);
	int (*seq_show)(struct seq_file___6 *, void *);
	void * (*seq_start)(struct seq_file___6 *, loff_t *);
	void * (*seq_next)(struct seq_file___6 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___6 *, void *);
	ssize_t (*read)(struct kernfs_open_file___2 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___2 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___2 *, struct vm_area_struct___4 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___2 *, struct poll_table_struct___3 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___2 {
	int (*remount_fs)(struct kernfs_root___2 *, int *, char *);
	int (*show_options)(struct seq_file___6 *, struct kernfs_root___2 *);
	int (*mkdir)(struct kernfs_node___2 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___2 *);
	int (*rename)(struct kernfs_node___2 *, struct kernfs_node___2 *, const char *);
	int (*show_path)(struct seq_file___6 *, struct kernfs_node___2 *, struct kernfs_root___2 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___3;

struct seq_file___6 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___3 *op;
	int poll_event;
	const struct file___3 *file;
	void *private;
};

struct vm_operations_struct___2;

struct kernfs_open_file___2 {
	struct kernfs_node___2 *kn;
	struct file___3 *file;
	struct seq_file___6 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___2 *vm_ops;
};

struct vm_fault___2;

struct vm_operations_struct___2 {
	void (*open)(struct vm_area_struct___4 *);
	void (*close)(struct vm_area_struct___4 *);
	int (*split)(struct vm_area_struct___4 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___4 *);
	vm_fault_t (*fault)(struct vm_fault___2 *);
	vm_fault_t (*huge_fault)(struct vm_fault___2 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___2 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___4 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___2 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___2 *);
	int (*access)(struct vm_area_struct___4 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___4 *);
	int (*set_policy)(struct vm_area_struct___4 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___4 *, long unsigned int);
	struct page___4 * (*find_special_page)(struct vm_area_struct___4 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___2)(struct file___3 *, wait_queue_head_t *, struct poll_table_struct___3 *);

struct poll_table_struct___3 {
	poll_queue_proc___2 _qproc;
	__poll_t _key;
};

struct vm_area_struct___4 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___4 *vm_next;
	struct vm_area_struct___4 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___3 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___2 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___3 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef __u64 __addrpair;

typedef __u32 __portpair;

struct net___2;

typedef struct {
	struct net___2 *net;
} possible_net_t;

struct in6_addr {
	union {
		__u8 u6_addr8[16];
		__be16 u6_addr16[8];
		__be32 u6_addr32[4];
	} in6_u;
};

struct hlist_nulls_node {
	struct hlist_nulls_node *next;
	struct hlist_nulls_node **pprev;
};

struct proto;

struct inet_timewait_death_row;

struct sock_common {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto *skc_prot;
	possible_net_t skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

typedef struct {
	spinlock_t slock;
	int owned;
	wait_queue_head_t wq;
} socket_lock_t;

struct sk_buff;

struct sk_buff_head {
	struct sk_buff *next;
	struct sk_buff *prev;
	__u32 qlen;
	spinlock_t lock;
};

typedef u64 netdev_features_t;

struct sock_cgroup_data {
	union {
		struct {
			u8 is_data;
			u8 padding;
			u16 prioidx;
			u32 classid;
		};
		u64 val;
	};
};

struct sk_filter;

struct socket_wq;

struct xfrm_policy;

struct dst_entry;

struct socket;

struct net_device;

struct sock_reuseport;

struct sock {
	struct sock_common __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head sk_error_queue;
	struct sk_buff_head sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff *head;
		struct sk_buff *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter *sk_filter;
	union {
		struct socket_wq *sk_wq;
		struct socket_wq *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry *sk_rx_dst;
	struct dst_entry *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___2 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___2 *sk_peer_pid;
	const struct cred___3 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___2 *sk_memcg;
	void (*sk_state_change)(struct sock *);
	void (*sk_data_ready)(struct sock *);
	void (*sk_write_space)(struct sock *);
	void (*sk_error_report)(struct sock *);
	int (*sk_backlog_rcv)(struct sock *, struct sk_buff *);
	struct sk_buff * (*sk_validate_xmit_skb)(struct sock *, struct net_device *, struct sk_buff *);
	void (*sk_destruct)(struct sock *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kobject___2;

struct bin_attribute___2;

struct attribute_group___2 {
	const char *name;
	umode_t (*is_visible)(struct kobject___2 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___2 *, struct bin_attribute___2 *, int);
	struct attribute **attrs;
	struct bin_attribute___2 **bin_attrs;
};

struct kset___2;

struct kobj_type___2;

struct kobject___2 {
	const char *name;
	struct list_head entry;
	struct kobject___2 *parent;
	struct kset___2 *kset;
	struct kobj_type___2 *ktype;
	struct kernfs_node___2 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___2 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___3 *, struct kobject___2 *, struct bin_attribute___2 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___3 *, struct kobject___2 *, struct bin_attribute___2 *, char *, loff_t, size_t);
	int (*mmap)(struct file___3 *, struct kobject___2 *, struct bin_attribute___2 *, struct vm_area_struct___4 *);
};

struct sysfs_ops___2 {
	ssize_t (*show)(struct kobject___2 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___2 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___2;

struct kset___2 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___2 kobj;
	const struct kset_uevent_ops___2 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___2 {
	void (*release)(struct kobject___2 *);
	const struct sysfs_ops___2 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___2 *);
	const void * (*namespace)(struct kobject___2 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___2 {
	int (* const filter)(struct kset___2 *, struct kobject___2 *);
	const char * (* const name)(struct kset___2 *, struct kobject___2 *);
	int (* const uevent)(struct kset___2 *, struct kobject___2 *, struct kobj_uevent_env *);
};

struct kobj_attribute___2 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___2 *, struct kobj_attribute___2 *, char *);
	ssize_t (*store)(struct kobject___2 *, struct kobj_attribute___2 *, const char *, size_t);
};

struct kernel_param___2;

struct kernel_param_ops___2 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___2 *);
	int (*get)(char *, const struct kernel_param___2 *);
	void (*free)(void *);
};

struct kparam_array___2;

struct kernel_param___2 {
	const char *name;
	struct module___3 *mod;
	const struct kernel_param_ops___2 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___2 *arr;
	};
};

struct kparam_array___2 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___2 *ops;
	void *elem;
};

struct module_kobject___2 {
	struct kobject___2 kobj;
	struct module___3 *mod;
	struct kobject___2 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___2 {
	struct module___3 *mod;
	struct latch_tree_node node;
};

struct module_layout___2 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___2 mtn;
};

struct module_attribute___2;

struct module___3 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___2 mkobj;
	struct module_attribute___2 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___2 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___2 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___2 core_layout;
	struct module_layout___2 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___2 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___2 *, struct module_kobject___2 *, char *);
	ssize_t (*store)(struct module_attribute___2 *, struct module_kobject___2 *, const char *, size_t);
	void (*setup)(struct module___3 *, const char *);
	int (*test)(struct module___3 *);
	void (*free)(struct module___3 *);
};

struct trace_event_class___2;

struct trace_event_call___2 {
	struct list_head list;
	struct trace_event_class___2 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array *prog_array;
	int (*perf_perm)(struct trace_event_call___2 *, struct perf_event___2 *);
};

struct upid___2 {
	int nr;
	struct pid_namespace___2 *ns;
};

struct pid_namespace___2 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___4 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___2 *parent;
	struct vfsmount___2 *proc_mnt;
	struct dentry___3 *proc_self;
	struct dentry___3 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___3 *user_ns;
	struct ucounts___2 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___2 ns;
};

struct pid___2 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___2 numbers[1];
};

struct rhash_head {
	struct rhash_head *next;
};

struct rhashtable;

struct rhashtable_compare_arg {
	struct rhashtable *ht;
	const void *key;
};

typedef u32 (*rht_hashfn_t)(const void *, u32, u32);

typedef u32 (*rht_obj_hashfn_t)(const void *, u32, u32);

typedef int (*rht_obj_cmpfn_t)(struct rhashtable_compare_arg *, const void *);

struct rhashtable_params {
	u16 nelem_hint;
	u16 key_len;
	u16 key_offset;
	u16 head_offset;
	unsigned int max_size;
	u16 min_size;
	bool automatic_shrinking;
	u8 locks_mul;
	u32 rh_reserved_nulls_base;
	rht_hashfn_t hashfn;
	rht_obj_hashfn_t obj_hashfn;
	rht_obj_cmpfn_t obj_cmpfn;
};

struct bucket_table;

struct rhashtable {
	struct bucket_table *tbl;
	unsigned int key_len;
	unsigned int max_elems;
	struct rhashtable_params p;
	bool rhlist;
	struct work_struct run_work;
	struct mutex mutex;
	spinlock_t lock;
	atomic_t nelems;
};

struct user_struct___3 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___4 *uid_keyring;
	struct key___4 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct linux_binfmt___2;

struct core_state___2;

struct mm_struct___3 {
	struct {
		struct vm_area_struct___4 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___3 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___3 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___2 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___4 *owner;
		struct user_namespace___3 *user_ns;
		struct file___3 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___2 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup___2;

struct cgroup_subsys___2;

struct cgroup_subsys_state___2 {
	struct cgroup___2 *cgroup;
	struct cgroup_subsys___2 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___2 *parent;
};

struct mem_cgroup_id___2 {
	int id;
	union {
		refcount_t ref;
		struct {
			atomic_t ref;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
};

struct cgroup_file___2 {
	struct kernfs_node___2 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___2;

struct mem_cgroup___2 {
	struct cgroup_subsys_state___2 css;
	struct mem_cgroup_id___2 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___2 events_file;
	struct cgroup_file___2 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___4 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___2 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fs_struct {
	int users;
	spinlock_t lock;
	seqcount_t seq;
	int umask;
	int in_exec;
	struct path___2 root;
	struct path___2 pwd;
};

struct cgroup_namespace___3;

struct nsproxy___3 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___2 *pid_ns_for_children;
	struct net___2 *net_ns;
	struct cgroup_namespace___3 *cgroup_ns;
};

struct signal_struct___3 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___4 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___4 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___2 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___2 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___3 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___2 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___2;

struct bio_list___3 {
	struct bio___2 *head;
	struct bio___2 *tail;
};

struct bdi_writeback_congested___2;

struct bdi_writeback___2 {
	struct backing_dev_info___3 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___2 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___2 *memcg_css;
	struct cgroup_subsys_state___2 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___3;

struct backing_dev_info___3 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___2 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___3 *dev;
	struct device___3 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___3 *debug_dir;
	struct dentry___3 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___2;

struct io_context___3 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___2 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___3 {
	struct cgroup_subsys_state___2 *subsys[13];
	refcount_t refcount;
	struct css_set___3 *dom_cset;
	struct cgroup___2 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___2 *mg_src_cgrp;
	struct cgroup___2 *mg_dst_cgrp;
	struct css_set___3 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___3 {
	struct pmu___2 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___4 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___3 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer;

struct pipe_inode_info___2 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___4 *tmp_page;
	struct fasync_struct___2 *fasync_readers;
	struct fasync_struct___2 *fasync_writers;
	struct pipe_buffer *bufs;
	struct user_struct___3 *user;
};

typedef blk_qc_t make_request_fn___2(struct request_queue___4 *, struct bio___2 *);

struct request___3;

typedef int dma_drain_needed_fn___2(struct request___3 *);

struct bsg_ops___2;

struct bsg_class_device___2 {
	struct device___3 *class_dev;
	int minor;
	struct request_queue___4 *queue;
	const struct bsg_ops___2 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___2 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___3 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___2;

struct request_queue___4 {
	struct list_head queue_head;
	struct request___3 *last_merge;
	struct elevator_queue___2 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___2 *make_request_fn;
	dma_drain_needed_fn___2 *dma_drain_needed;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___3 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___2 kobj;
	struct kobject___2 *mq_kobj;
	struct blk_integrity integrity;
	struct device___3 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide78;
		union {		};
	};
	struct bsg_class_device___2 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___2 bio_split;
	struct dentry___3 *debugfs_dir;
	struct dentry___3 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___3 {
	struct vm_struct___3 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___4 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___2 {
	struct task_struct___4 task;
	long unsigned int stack[8192];
};

struct dentry_operations___2;

struct super_block___3;

struct dentry___3 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___3 *d_parent;
	struct qstr d_name;
	struct inode___4 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___2 *d_op;
	struct super_block___3 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___2;

struct address_space___2 {
	struct inode___4 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___3 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___2 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___2;

struct block_device___3;

struct cdev___2;

struct inode___4 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___2 *i_op;
	struct super_block___3 *i_sb;
	struct address_space___2 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___3 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___2 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___3 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___2 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct block_device___3 *i_bdev;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___2 {
	int (*d_revalidate)(struct dentry___3 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___3 *, unsigned int);
	int (*d_hash)(const struct dentry___3 *, struct qstr *);
	int (*d_compare)(const struct dentry___3 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___3 *);
	int (*d_init)(struct dentry___3 *);
	void (*d_release)(struct dentry___3 *);
	void (*d_prune)(struct dentry___3 *);
	void (*d_iput)(struct dentry___3 *, struct inode___4 *);
	char * (*d_dname)(struct dentry___3 *, char *, int);
	struct vfsmount___2 * (*d_automount)(struct path___2 *);
	int (*d_manage)(const struct path___2 *, bool);
	struct dentry___3 * (*d_real)(struct dentry___3 *, const struct inode___4 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___2;

struct mem_dqinfo___2 {
	struct quota_format_type___2 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___2;

struct quota_info___2 {
	unsigned int flags;
	struct rw_semaphore___3 dqio_sem;
	struct inode___4 *files[3];
	struct mem_dqinfo___2 info[3];
	const struct quota_format_ops___2 *ops[3];
};

struct rcuwait___2 {
	struct task_struct___4 *task;
};

struct percpu_rw_semaphore___2 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___3 rw_sem;
	struct rcuwait___2 writer;
	int readers_block;
};

struct sb_writers___2 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___2 rw_sem[3];
};

struct shrink_control___2;

struct shrinker___2 {
	long unsigned int (*count_objects)(struct shrinker___2 *, struct shrink_control___2 *);
	long unsigned int (*scan_objects)(struct shrinker___2 *, struct shrink_control___2 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___2;

struct super_operations___2;

struct dquot_operations___2;

struct quotactl_ops___2;

struct xattr_handler___2;

struct super_block___3 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___2 *s_type;
	const struct super_operations___2 *s_op;
	const struct dquot_operations___2 *dq_op;
	const struct quotactl_ops___2 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___3 *s_root;
	struct rw_semaphore___3 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___3 *s_bdev;
	struct backing_dev_info___3 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___2 s_dquot;
	struct sb_writers___2 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___2 *s_d_op;
	int cleancache_poolid;
	struct shrinker___2 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___2 {
	struct dentry___3 *mnt_root;
	struct super_block___3 *mnt_sb;
	int mnt_flags;
};

struct shrink_control___2 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___2 *memcg;
};

typedef int (*dev_page_fault_t___2)(struct vm_area_struct___4 *, long unsigned int, const struct page___4 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___2)(struct page___4 *, void *);

struct dev_pagemap___2 {
	dev_page_fault_t___2 page_fault;
	dev_page_free_t___2 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___3 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___2 {
	struct task_struct___4 *task;
	struct core_thread___2 *next;
};

struct core_state___2 {
	atomic_t nr_threads;
	struct core_thread___2 dumper;
	struct completion startup;
};

struct vm_fault___2 {
	struct vm_area_struct___4 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___4 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___4 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___2 prealloc_pte;
};

struct io_cq___2 {
	struct request_queue___4 *q;
	struct io_context___3 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___3 {
	struct file___3 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___3 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___3 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___3 *ia_file;
};

struct dquot___2 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___3 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___2 {
	int qf_fmt_id;
	const struct quota_format_ops___2 *qf_ops;
	struct module___3 *qf_owner;
	struct quota_format_type___2 *qf_next;
};

struct quota_format_ops___2 {
	int (*check_quota_file)(struct super_block___3 *, int);
	int (*read_file_info)(struct super_block___3 *, int);
	int (*write_file_info)(struct super_block___3 *, int);
	int (*free_file_info)(struct super_block___3 *, int);
	int (*read_dqblk)(struct dquot___2 *);
	int (*commit_dqblk)(struct dquot___2 *);
	int (*release_dqblk)(struct dquot___2 *);
	int (*get_next_id)(struct super_block___3 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___2 {
	int (*write_dquot)(struct dquot___2 *);
	struct dquot___2 * (*alloc_dquot)(struct super_block___3 *, int);
	void (*destroy_dquot)(struct dquot___2 *);
	int (*acquire_dquot)(struct dquot___2 *);
	int (*release_dquot)(struct dquot___2 *);
	int (*mark_dirty)(struct dquot___2 *);
	int (*write_info)(struct super_block___3 *, int);
	qsize_t * (*get_reserved_space)(struct inode___4 *);
	int (*get_projid)(struct inode___4 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___4 *, qsize_t *);
	int (*get_next_id)(struct super_block___3 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___2 {
	int (*quota_on)(struct super_block___3 *, int, int, const struct path___2 *);
	int (*quota_off)(struct super_block___3 *, int);
	int (*quota_enable)(struct super_block___3 *, unsigned int);
	int (*quota_disable)(struct super_block___3 *, unsigned int);
	int (*quota_sync)(struct super_block___3 *, int);
	int (*set_info)(struct super_block___3 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___3 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___3 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___3 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___3 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___3 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct {
	size_t written;
	size_t count;
	union {
		char *buf;
		void *data;
	} arg;
	int error;
} read_descriptor_t;

struct writeback_control___2;

struct swap_info_struct___2;

struct address_space_operations___2 {
	int (*writepage)(struct page___4 *, struct writeback_control___2 *);
	int (*readpage)(struct file___3 *, struct page___4 *);
	int (*writepages)(struct address_space___2 *, struct writeback_control___2 *);
	int (*set_page_dirty)(struct page___4 *);
	int (*readpages)(struct file___3 *, struct address_space___2 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___3 *, struct address_space___2 *, loff_t, unsigned int, unsigned int, struct page___4 **, void **);
	int (*write_end)(struct file___3 *, struct address_space___2 *, loff_t, unsigned int, unsigned int, struct page___4 *, void *);
	sector_t (*bmap)(struct address_space___2 *, sector_t);
	void (*invalidatepage)(struct page___4 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___4 *, gfp_t);
	void (*freepage)(struct page___4 *);
	ssize_t (*direct_IO)(struct kiocb___3 *, struct iov_iter___3 *);
	int (*migratepage)(struct address_space___2 *, struct page___4 *, struct page___4 *, enum migrate_mode);
	bool (*isolate_page)(struct page___4 *, isolate_mode_t);
	void (*putback_page)(struct page___4 *);
	int (*launder_page)(struct page___4 *);
	int (*is_partially_uptodate)(struct page___4 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___4 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___2 *, struct page___4 *);
	int (*swap_activate)(struct swap_info_struct___2 *, struct file___3 *, sector_t *);
	void (*swap_deactivate)(struct file___3 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___2 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___2 *wb;
	struct inode___4 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___2;

struct iov_iter___3 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___2 *bvec;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct swap_info_struct___2 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___3 *bdev;
	struct file___3 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct hd_struct___2;

struct gendisk___2;

struct block_device___3 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___4 *bd_inode;
	struct super_block___3 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___3 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___2 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___2 *bd_disk;
	struct request_queue___4 *bd_queue;
	struct backing_dev_info___3 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___2 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___3 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___2;

struct bus_type___2;

struct device_driver___2;

struct dev_pm_domain___2;

struct dma_map_ops___2;

struct device_node___2;

struct fwnode_handle___2;

struct class___2;

struct device___3 {
	struct device___3 *parent;
	struct device_private *p;
	struct kobject___2 kobj;
	const char *init_name;
	const struct device_type___2 *type;
	struct mutex mutex;
	struct bus_type___2 *bus;
	struct device_driver___2 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___2 power;
	struct dev_pm_domain___2 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___2 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___2 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___2 *class;
	const struct attribute_group___2 **groups;
	void (*release)(struct device___3 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___2 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___3 __dev;
	struct kobject___2 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___2;

struct block_device_operations___2;

struct gendisk___2 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___2 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___2 *part_tbl;
	struct hd_struct___2 part0;
	const struct block_device_operations___2 *fops;
	struct request_queue___4 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___3 lookup_sem;
	struct kobject___2 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___2 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___2 {
	struct kobject___2 kobj;
	struct module___3 *owner;
	const struct file_operations___3 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct posix_acl_entry {
	short int e_tag;
	short unsigned int e_perm;
	union {
		kuid_t e_uid;
		kgid_t e_gid;
	};
};

struct posix_acl {
	refcount_t a_refcount;
	struct callback_head a_rcu;
	unsigned int a_count;
	struct posix_acl_entry a_entries[0];
};

struct inode_operations___2 {
	struct dentry___3 * (*lookup)(struct inode___4 *, struct dentry___3 *, unsigned int);
	const char * (*get_link)(struct dentry___3 *, struct inode___4 *, struct delayed_call *);
	int (*permission)(struct inode___4 *, int);
	struct posix_acl * (*get_acl)(struct inode___4 *, int);
	int (*readlink)(struct dentry___3 *, char *, int);
	int (*create)(struct inode___4 *, struct dentry___3 *, umode_t, bool);
	int (*link)(struct dentry___3 *, struct inode___4 *, struct dentry___3 *);
	int (*unlink)(struct inode___4 *, struct dentry___3 *);
	int (*symlink)(struct inode___4 *, struct dentry___3 *, const char *);
	int (*mkdir)(struct inode___4 *, struct dentry___3 *, umode_t);
	int (*rmdir)(struct inode___4 *, struct dentry___3 *);
	int (*mknod)(struct inode___4 *, struct dentry___3 *, umode_t, dev_t);
	int (*rename)(struct inode___4 *, struct dentry___3 *, struct inode___4 *, struct dentry___3 *, unsigned int);
	int (*setattr)(struct dentry___3 *, struct iattr___3 *);
	int (*getattr)(const struct path___2 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___3 *, char *, size_t);
	int (*fiemap)(struct inode___4 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___4 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___4 *, struct dentry___3 *, struct file___3 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___4 *, struct dentry___3 *, umode_t);
	int (*set_acl)(struct inode___4 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___2 {
	void (*fl_copy_lock)(struct file_lock___3 *, struct file_lock___3 *);
	void (*fl_release_private)(struct file_lock___3 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___2;

struct file_lock___3 {
	struct file_lock___3 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___3 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___2 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___2 *fl_ops;
	const struct lock_manager_operations___2 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___2 {
	int (*lm_compare_owner)(struct file_lock___3 *, struct file_lock___3 *);
	long unsigned int (*lm_owner_key)(struct file_lock___3 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___3 *);
	int (*lm_grant)(struct file_lock___3 *, int);
	bool (*lm_break)(struct file_lock___3 *);
	int (*lm_change)(struct file_lock___3 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___3 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___2 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___2 *fa_next;
	struct file___3 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___2 {
	const char *name;
	int fs_flags;
	struct dentry___3 * (*mount)(struct file_system_type___2 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___3 *);
	struct module___3 *owner;
	struct file_system_type___2 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___2 {
	struct inode___4 * (*alloc_inode)(struct super_block___3 *);
	void (*destroy_inode)(struct inode___4 *);
	void (*dirty_inode)(struct inode___4 *, int);
	int (*write_inode)(struct inode___4 *, struct writeback_control___2 *);
	int (*drop_inode)(struct inode___4 *);
	void (*evict_inode)(struct inode___4 *);
	void (*put_super)(struct super_block___3 *);
	int (*sync_fs)(struct super_block___3 *, int);
	int (*freeze_super)(struct super_block___3 *);
	int (*freeze_fs)(struct super_block___3 *);
	int (*thaw_super)(struct super_block___3 *);
	int (*unfreeze_fs)(struct super_block___3 *);
	int (*statfs)(struct dentry___3 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___3 *, int *, char *);
	void (*umount_begin)(struct super_block___3 *);
	int (*show_options)(struct seq_file___6 *, struct dentry___3 *);
	int (*show_devname)(struct seq_file___6 *, struct dentry___3 *);
	int (*show_path)(struct seq_file___6 *, struct dentry___3 *);
	int (*show_stats)(struct seq_file___6 *, struct dentry___3 *);
	ssize_t (*quota_read)(struct super_block___3 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___3 *, int, const char *, size_t, loff_t);
	struct dquot___2 ** (*get_dquots)(struct inode___4 *);
	int (*bdev_try_to_free_page)(struct super_block___3 *, struct page___4 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___3 *, struct shrink_control___2 *);
	long int (*free_cached_objects)(struct super_block___3 *, struct shrink_control___2 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct xattr_handler___2 {
	const char *name;
	const char *prefix;
	int flags;
	bool (*list)(struct dentry___3 *);
	int (*get)(const struct xattr_handler___2 *, struct dentry___3 *, struct inode___4 *, const char *, void *, size_t);
	int (*set)(const struct xattr_handler___2 *, struct dentry___3 *, struct inode___4 *, const char *, const void *, size_t, int);
};

typedef void bio_end_io_t___2(struct bio___2 *);

struct bio_vec___2 {
	struct page___4 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___2;

struct bio___2 {
	struct bio___2 *bi_next;
	struct gendisk___2 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___2 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___2 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___2 *bi_io_vec;
	struct bio_set___2 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___2 bi_inline_vecs[0];
};

typedef unsigned char cc_t;

typedef unsigned int speed_t;

typedef unsigned int tcflag_t;

struct ktermios {
	tcflag_t c_iflag;
	tcflag_t c_oflag;
	tcflag_t c_cflag;
	tcflag_t c_lflag;
	cc_t c_line;
	cc_t c_cc[19];
	speed_t c_ispeed;
	speed_t c_ospeed;
};

struct winsize {
	short unsigned int ws_row;
	short unsigned int ws_col;
	short unsigned int ws_xpixel;
	short unsigned int ws_ypixel;
};

struct termiox {
	__u16 x_hflag;
	__u16 x_cflag;
	__u16 x_rflag[5];
	__u16 x_sflag;
};

struct dev_pm_ops___2 {
	int (*prepare)(struct device___3 *);
	void (*complete)(struct device___3 *);
	int (*suspend)(struct device___3 *);
	int (*resume)(struct device___3 *);
	int (*freeze)(struct device___3 *);
	int (*thaw)(struct device___3 *);
	int (*poweroff)(struct device___3 *);
	int (*restore)(struct device___3 *);
	int (*suspend_late)(struct device___3 *);
	int (*resume_early)(struct device___3 *);
	int (*freeze_late)(struct device___3 *);
	int (*thaw_early)(struct device___3 *);
	int (*poweroff_late)(struct device___3 *);
	int (*restore_early)(struct device___3 *);
	int (*suspend_noirq)(struct device___3 *);
	int (*resume_noirq)(struct device___3 *);
	int (*freeze_noirq)(struct device___3 *);
	int (*thaw_noirq)(struct device___3 *);
	int (*poweroff_noirq)(struct device___3 *);
	int (*restore_noirq)(struct device___3 *);
	int (*runtime_suspend)(struct device___3 *);
	int (*runtime_resume)(struct device___3 *);
	int (*runtime_idle)(struct device___3 *);
};

struct dev_pm_domain___2 {
	struct dev_pm_ops___2 ops;
	void (*detach)(struct device___3 *, bool);
	int (*activate)(struct device___3 *);
	void (*sync)(struct device___3 *);
	void (*dismiss)(struct device___3 *);
};

struct bus_type___2 {
	const char *name;
	const char *dev_name;
	struct device___3 *dev_root;
	const struct attribute_group___2 **bus_groups;
	const struct attribute_group___2 **dev_groups;
	const struct attribute_group___2 **drv_groups;
	int (*match)(struct device___3 *, struct device_driver___2 *);
	int (*uevent)(struct device___3 *, struct kobj_uevent_env *);
	int (*probe)(struct device___3 *);
	int (*remove)(struct device___3 *);
	void (*shutdown)(struct device___3 *);
	int (*online)(struct device___3 *);
	int (*offline)(struct device___3 *);
	int (*suspend)(struct device___3 *, pm_message_t);
	int (*resume)(struct device___3 *);
	int (*num_vf)(struct device___3 *);
	int (*dma_configure)(struct device___3 *);
	const struct dev_pm_ops___2 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___2 {
	const char *name;
	struct bus_type___2 *bus;
	struct module___3 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___3 *);
	int (*remove)(struct device___3 *);
	void (*shutdown)(struct device___3 *);
	int (*suspend)(struct device___3 *, pm_message_t);
	int (*resume)(struct device___3 *);
	const struct attribute_group___2 **groups;
	const struct dev_pm_ops___2 *pm;
	void (*coredump)(struct device___3 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___2 {
	const char *name;
	const struct attribute_group___2 **groups;
	int (*uevent)(struct device___3 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___3 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___3 *);
	const struct dev_pm_ops___2 *pm;
};

struct class___2 {
	const char *name;
	struct module___3 *owner;
	const struct attribute_group___2 **class_groups;
	const struct attribute_group___2 **dev_groups;
	struct kobject___2 *dev_kobj;
	int (*dev_uevent)(struct device___3 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___3 *, umode_t *);
	void (*class_release)(struct class___2 *);
	void (*dev_release)(struct device___3 *);
	int (*shutdown_pre)(struct device___3 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___3 *);
	const struct dev_pm_ops___2 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___2 {
	void * (*alloc)(struct device___3 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___3 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___3 *, struct vm_area_struct___4 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___3 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___3 *, struct page___4 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___3 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___3 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___3 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___3 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___3 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___3 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___3 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___3 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___3 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___3 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___3 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___3 *, u64);
	u64 (*get_required_mask)(struct device___3 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___2;

struct fwnode_handle___2 {
	struct fwnode_handle___2 *secondary;
	const struct fwnode_operations___2 *ops;
};

typedef int (*key_restrict_link_func_t___2)(struct key___4 *, const struct key_type *, const union key_payload *, struct key___4 *);

struct key_restriction___3;

struct key___4 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___3 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___3 *restrict_link;
};

struct key_restriction___3 {
	key_restrict_link_func_t___2 check;
	struct key___4 *key;
	struct key_type *keytype;
};

struct seq_operations___3 {
	void * (*start)(struct seq_file___6 *, loff_t *);
	void (*stop)(struct seq_file___6 *, void *);
	void * (*next)(struct seq_file___6 *, void *, loff_t *);
	int (*show)(struct seq_file___6 *, void *);
};

struct tty_driver___2;

struct serial_icounter_struct;

struct tty_operations {
	struct tty_struct * (*lookup)(struct tty_driver___2 *, struct file___3 *, int);
	int (*install)(struct tty_driver___2 *, struct tty_struct *);
	void (*remove)(struct tty_driver___2 *, struct tty_struct *);
	int (*open)(struct tty_struct *, struct file___3 *);
	void (*close)(struct tty_struct *, struct file___3 *);
	void (*shutdown)(struct tty_struct *);
	void (*cleanup)(struct tty_struct *);
	int (*write)(struct tty_struct *, const unsigned char *, int);
	int (*put_char)(struct tty_struct *, unsigned char);
	void (*flush_chars)(struct tty_struct *);
	int (*write_room)(struct tty_struct *);
	int (*chars_in_buffer)(struct tty_struct *);
	int (*ioctl)(struct tty_struct *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct *, struct ktermios *);
	void (*throttle)(struct tty_struct *);
	void (*unthrottle)(struct tty_struct *);
	void (*stop)(struct tty_struct *);
	void (*start)(struct tty_struct *);
	void (*hangup)(struct tty_struct *);
	int (*break_ctl)(struct tty_struct *, int);
	void (*flush_buffer)(struct tty_struct *);
	void (*set_ldisc)(struct tty_struct *);
	void (*wait_until_sent)(struct tty_struct *, int);
	void (*send_xchar)(struct tty_struct *, char);
	int (*tiocmget)(struct tty_struct *);
	int (*tiocmset)(struct tty_struct *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct *, struct winsize *);
	int (*set_termiox)(struct tty_struct *, struct termiox *);
	int (*get_icount)(struct tty_struct *, struct serial_icounter_struct *);
	void (*show_fdinfo)(struct tty_struct *, struct seq_file___6 *);
	int (*poll_init)(struct tty_driver___2 *, int, char *);
	int (*poll_get_char)(struct tty_driver___2 *, int);
	void (*poll_put_char)(struct tty_driver___2 *, int, char);
	int (*proc_show)(struct seq_file___6 *, void *);
};

struct ld_semaphore {
	long int count;
	raw_spinlock_t wait_lock;
	unsigned int wait_readers;
	struct list_head read_wait;
	struct list_head write_wait;
};

struct tty_ldisc;

struct tty_port;

struct tty_struct {
	int magic;
	struct kref kref;
	struct device___3 *dev;
	struct tty_driver___2 *driver;
	const struct tty_operations *ops;
	int index;
	struct ld_semaphore ldisc_sem;
	struct tty_ldisc *ldisc;
	struct mutex atomic_write_lock;
	struct mutex legacy_mutex;
	struct mutex throttle_mutex;
	struct rw_semaphore___3 termios_rwsem;
	struct mutex winsize_mutex;
	spinlock_t ctrl_lock;
	spinlock_t flow_lock;
	struct ktermios termios;
	struct ktermios termios_locked;
	struct termiox *termiox;
	char name[64];
	struct pid___2 *pgrp;
	struct pid___2 *session;
	long unsigned int flags;
	int count;
	struct winsize winsize;
	long unsigned int stopped: 1;
	long unsigned int flow_stopped: 1;
	int: 30;
	long unsigned int unused: 62;
	int hw_stopped;
	long unsigned int ctrl_status: 8;
	long unsigned int packet: 1;
	int: 23;
	long unsigned int unused_ctrl: 55;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct *link;
	struct fasync_struct___2 *fasync;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	spinlock_t files_lock;
	struct list_head tty_files;
	int closing;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port *port;
};

struct proc_dir_entry;

struct tty_driver___2 {
	int magic;
	struct kref kref;
	struct cdev___2 **cdevs;
	struct module___3 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___2 *other;
	struct tty_struct **ttys;
	struct tty_port **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations *ops;
	struct list_head tty_drivers;
};

struct tty_buffer {
	union {
		struct tty_buffer *next;
		struct llist_node free;
	};
	int used;
	int size;
	int commit;
	int read;
	int flags;
	long unsigned int data[0];
};

struct tty_bufhead {
	struct tty_buffer *head;
	struct work_struct work;
	struct mutex lock;
	atomic_t priority;
	struct tty_buffer sentinel;
	struct llist_head free;
	atomic_t mem_used;
	int mem_limit;
	struct tty_buffer *tail;
};

struct tty_port_operations;

struct tty_port_client_operations;

struct tty_port {
	struct tty_bufhead buf;
	struct tty_struct *tty;
	struct tty_struct *itty;
	const struct tty_port_operations *ops;
	const struct tty_port_client_operations *client_ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	unsigned char low_latency: 1;
	struct mutex mutex;
	struct mutex buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
	void *client_data;
};

struct tty_ldisc_ops {
	int magic;
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct *);
	void (*close)(struct tty_struct *);
	void (*flush_buffer)(struct tty_struct *);
	ssize_t (*read)(struct tty_struct *, struct file___3 *, unsigned char *, size_t);
	ssize_t (*write)(struct tty_struct *, struct file___3 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct *, struct file___3 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct *, struct file___3 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct *, struct ktermios *);
	__poll_t (*poll)(struct tty_struct *, struct file___3 *, struct poll_table_struct___3 *);
	int (*hangup)(struct tty_struct *);
	void (*receive_buf)(struct tty_struct *, const unsigned char *, char *, int);
	void (*write_wakeup)(struct tty_struct *);
	void (*dcd_change)(struct tty_struct *, unsigned int);
	int (*receive_buf2)(struct tty_struct *, const unsigned char *, char *, int);
	struct module___3 *owner;
	int refcount;
};

struct tty_ldisc {
	struct tty_ldisc_ops *ops;
	struct tty_struct *tty;
};

struct tty_port_operations {
	int (*carrier_raised)(struct tty_port *);
	void (*dtr_rts)(struct tty_port *, int);
	void (*shutdown)(struct tty_port *);
	int (*activate)(struct tty_port *, struct tty_struct *);
	void (*destruct)(struct tty_port *);
};

struct tty_port_client_operations {
	int (*receive_buf)(struct tty_port *, const unsigned char *, const unsigned char *, size_t);
	void (*write_wakeup)(struct tty_port *);
};

struct uevent_sock;

struct prot_inuse;

struct netns_core {
	struct ctl_table_header *sysctl_hdr;
	int sysctl_somaxconn;
	int *sock_inuse;
	struct prot_inuse *prot_inuse;
};

struct tcp_mib;

struct ipstats_mib;

struct linux_mib;

struct udp_mib;

struct icmp_mib;

struct icmpmsg_mib;

struct icmpv6_mib;

struct icmpv6msg_mib;

struct linux_xfrm_mib;

struct netns_mib {
	struct tcp_mib *tcp_statistics;
	struct ipstats_mib *ip_statistics;
	struct linux_mib *net_statistics;
	struct udp_mib *udp_statistics;
	struct udp_mib *udplite_statistics;
	struct icmp_mib *icmp_statistics;
	struct icmpmsg_mib *icmpmsg_statistics;
	struct proc_dir_entry *proc_net_devsnmp6;
	struct udp_mib *udp_stats_in6;
	struct udp_mib *udplite_stats_in6;
	struct ipstats_mib *ipv6_statistics;
	struct icmpv6_mib *icmpv6_statistics;
	struct icmpv6msg_mib *icmpv6msg_statistics;
	struct linux_xfrm_mib *xfrm_statistics;
};

struct netns_packet {
	struct mutex sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header *ctl;
};

struct inet_frags;

struct netns_frags {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xt_table;

struct local_ports {
	seqlock_t lock;
	int range[2];
	bool warned;
};

struct inet_hashinfo;

struct inet_timewait_death_row {
	atomic_t tw_count;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct inet_hashinfo *hashinfo;
	int sysctl_max_tw_buckets;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ping_group_range {
	seqlock_t lock;
	kgid_t range[2];
};

struct ipv4_devconf;

struct ip_ra_chain;

struct fib_rules_ops;

struct fib_table;

struct inet_peer_base;

struct tcp_congestion_ops;

struct tcp_fastopen_context;

struct fib_notifier_ops;

struct netns_ipv4 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct sock *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock **tcp_sk;
	struct netns_frags frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6 {
	struct ctl_table_header *hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *icmp_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *xfrm6_hdr;
	int bindv6only;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	int multipath_hash_policy;
	int flowlabel_consistency;
	int auto_flowlabels;
	int icmpv6_time;
	int anycast_src_echo_reply;
	int ip_nonlocal_bind;
	int fwmark_reflect;
	int idgen_retries;
	int idgen_delay;
	int flowlabel_state_ranges;
	int flowlabel_reflect;
	int max_dst_opts_cnt;
	int max_hbh_opts_cnt;
	int max_dst_opts_len;
	int max_hbh_opts_len;
	int seg6_flowlabel;
};

struct neighbour;

struct dst_ops {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops *);
	struct dst_entry * (*check)(struct dst_entry *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry *);
	unsigned int (*mtu)(const struct dst_entry *);
	u32 * (*cow_metrics)(struct dst_entry *, long unsigned int);
	void (*destroy)(struct dst_entry *);
	void (*ifdown)(struct dst_entry *, struct net_device *, int);
	struct dst_entry * (*negative_advice)(struct dst_entry *);
	void (*link_failure)(struct sk_buff *);
	void (*update_pmtu)(struct dst_entry *, struct sock *, struct sk_buff *, u32);
	void (*redirect)(struct dst_entry *, struct sock *, struct sk_buff *);
	int (*local_out)(struct net___2 *, struct sock *, struct sk_buff *);
	struct neighbour * (*neigh_lookup)(const struct dst_entry *, struct sk_buff *, const void *);
	void (*confirm_neigh)(const struct dst_entry *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct ipv6_devconf;

struct fib6_info;

struct rt6_info;

struct rt6_statistics;

struct fib6_table;

struct seg6_pernet_data;

struct netns_ipv6 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct sock *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops *notifier_ops;
	struct fib_notifier_ops *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct sctp_mib;

struct netns_sctp {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct nf_queue_handler;

struct nf_logger;

struct nf_hook_entries;

struct netns_nf {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_queue_handler *queue_handler;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header *nf_log_dir_header;
	struct nf_hook_entries *hooks_ipv4[5];
	struct nf_hook_entries *hooks_ipv6[5];
	struct nf_hook_entries *hooks_arp[3];
	struct nf_hook_entries *hooks_bridge[5];
	bool defrag_ipv4;
	bool defrag_ipv6;
};

struct ebt_table;

struct netns_xt {
	struct list_head tables[13];
	bool notrack_deprecated_warning;
	bool clusterip_deprecated_warning;
	struct ebt_table *broute_table;
	struct ebt_table *frame_filter;
	struct ebt_table *frame_nat;
};

struct nf_ct_event_notifier;

struct nf_exp_event_notifier;

struct nf_proto_net {
	struct ctl_table_header *ctl_table_header;
	struct ctl_table *ctl_table;
	unsigned int users;
};

struct nf_generic_net {
	struct nf_proto_net pn;
	unsigned int timeout;
};

struct nf_tcp_net {
	struct nf_proto_net pn;
	unsigned int timeouts[14];
	unsigned int tcp_loose;
	unsigned int tcp_be_liberal;
	unsigned int tcp_max_retrans;
};

struct nf_udp_net {
	struct nf_proto_net pn;
	unsigned int timeouts[2];
};

struct nf_icmp_net {
	struct nf_proto_net pn;
	unsigned int timeout;
};

struct nf_dccp_net {
	struct nf_proto_net pn;
	int dccp_loose;
	unsigned int dccp_timeout[10];
};

struct nf_sctp_net {
	struct nf_proto_net pn;
	unsigned int timeouts[10];
};

struct nf_ip_net {
	struct nf_generic_net generic;
	struct nf_tcp_net tcp;
	struct nf_udp_net udp;
	struct nf_icmp_net icmp;
	struct nf_icmp_net icmpv6;
	struct nf_dccp_net dccp;
	struct nf_sctp_net sctp;
};

struct ct_pcpu;

struct ip_conntrack_stat;

struct netns_ct {
	atomic_t count;
	unsigned int expect_count;
	struct delayed_work ecache_dwork;
	bool ecache_dwork_pending;
	struct ctl_table_header *sysctl_header;
	struct ctl_table_header *acct_sysctl_header;
	struct ctl_table_header *tstamp_sysctl_header;
	struct ctl_table_header *event_sysctl_header;
	struct ctl_table_header *helper_sysctl_header;
	unsigned int sysctl_log_invalid;
	int sysctl_events;
	int sysctl_acct;
	int sysctl_auto_assign_helper;
	bool auto_assign_helper_warned;
	int sysctl_tstamp;
	int sysctl_checksum;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_exp_event_notifier *nf_expect_event_cb;
	struct nf_ip_net nf_ct_proto;
	unsigned int labels_used;
};

struct netns_nftables {
	struct list_head tables;
	struct list_head commit_list;
	unsigned int base_seq;
	u8 gencursor;
	u8 validate_state;
};

struct netns_nf_frag {
	struct netns_frags frags;
};

struct xfrm_policy_hash {
	struct hlist_head *table;
	unsigned int hmask;
	u8 dbits4;
	u8 sbits4;
	u8 dbits6;
	u8 sbits6;
};

struct xfrm_policy_hthresh {
	struct work_struct work;
	seqlock_t lock;
	u8 lbits4;
	u8 rbits4;
	u8 lbits6;
	u8 rbits6;
};

struct netns_xfrm {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops xfrm4_dst_ops;
	struct dst_ops xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipvs;

struct mpls_route;

struct netns_mpls {
	int ip_ttl_propagate;
	int default_ttl;
	size_t platform_labels;
	struct mpls_route **platform_label;
	struct ctl_table_header *ctl;
};

struct can_dev_rcv_lists;

struct s_stats;

struct s_pstats;

struct netns_can {
	struct proc_dir_entry *proc_dir;
	struct proc_dir_entry *pde_version;
	struct proc_dir_entry *pde_stats;
	struct proc_dir_entry *pde_reset_stats;
	struct proc_dir_entry *pde_rcvlist_all;
	struct proc_dir_entry *pde_rcvlist_fil;
	struct proc_dir_entry *pde_rcvlist_inv;
	struct proc_dir_entry *pde_rcvlist_sff;
	struct proc_dir_entry *pde_rcvlist_eff;
	struct proc_dir_entry *pde_rcvlist_err;
	struct proc_dir_entry *bcmproc_dir;
	struct can_dev_rcv_lists *can_rx_alldev_list;
	spinlock_t can_rcvlists_lock;
	struct timer_list can_stattimer;
	struct s_stats *can_stats;
	struct s_pstats *can_pstats;
	struct hlist_head cgw_list;
};

typedef struct {
	u64 key[2];
} siphash_key_t;

struct net_generic;

struct net___2 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___3 *user_ns;
	struct ucounts___2 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___2 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4 ipv4;
	struct netns_ipv6 ipv6;
	struct netns_sctp sctp;
	struct netns_nf nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock *nfnl;
	struct sock *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cgroup_namespace___3 {
	refcount_t count;
	struct ns_common___2 ns;
	struct user_namespace___3 *user_ns;
	struct ucounts___2 *ucounts;
	struct css_set___3 *root_cset;
};

struct ucounts___2 {
	struct hlist_node node;
	struct user_namespace___3 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_func_info {
	__u32 insn_off;
	__u32 type_id;
};

struct bpf_line_info {
	__u32 insn_off;
	__u32 file_name_off;
	__u32 line_off;
	__u32 line_col;
};

struct bpf_map___2;

struct bpf_map_ops___2 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___2 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___2 *, struct file___3 *);
	void (*map_free)(struct bpf_map___2 *);
	int (*map_get_next_key)(struct bpf_map___2 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___2 *);
	void * (*map_lookup_elem)(struct bpf_map___2 *, void *);
	int (*map_update_elem)(struct bpf_map___2 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___2 *, void *);
	int (*map_push_elem)(struct bpf_map___2 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___2 *, void *);
	int (*map_peek_elem)(struct bpf_map___2 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___2 *, struct file___3 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___2 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___2 *, void *, struct seq_file___6 *);
	int (*map_check_btf)(const struct bpf_map___2 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___2 {
	const struct bpf_map_ops___2 *ops;
	struct bpf_map___2 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___3 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map;

struct bpf_map_dev_ops {
	int (*map_get_next_key)(struct bpf_offloaded_map *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map *, void *);
};

struct bpf_offloaded_map {
	struct bpf_map___2 map;
	struct net_device *netdev;
	const struct bpf_map_dev_ops *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_stats {
	long unsigned int rx_packets;
	long unsigned int tx_packets;
	long unsigned int rx_bytes;
	long unsigned int tx_bytes;
	long unsigned int rx_errors;
	long unsigned int tx_errors;
	long unsigned int rx_dropped;
	long unsigned int tx_dropped;
	long unsigned int multicast;
	long unsigned int collisions;
	long unsigned int rx_length_errors;
	long unsigned int rx_over_errors;
	long unsigned int rx_crc_errors;
	long unsigned int rx_frame_errors;
	long unsigned int rx_fifo_errors;
	long unsigned int rx_missed_errors;
	long unsigned int tx_aborted_errors;
	long unsigned int tx_carrier_errors;
	long unsigned int tx_fifo_errors;
	long unsigned int tx_heartbeat_errors;
	long unsigned int tx_window_errors;
	long unsigned int rx_compressed;
	long unsigned int tx_compressed;
};

struct netdev_hw_addr_list {
	struct list_head list;
	int count;
};

struct tipc_bearer;

struct wireless_dev;

struct wpan_dev;

enum rx_handler_result {
	RX_HANDLER_CONSUMED = 0,
	RX_HANDLER_ANOTHER = 1,
	RX_HANDLER_EXACT = 2,
	RX_HANDLER_PASS = 3,
};

typedef enum rx_handler_result rx_handler_result_t;

typedef rx_handler_result_t rx_handler_func_t(struct sk_buff **);

struct cpu_rmap;

struct pcpu_dstats;

struct pcpu_vstats;

struct garp_port;

struct mrp_port;

struct netdev_tc_txq {
	u16 count;
	u16 offset;
};

struct sfp_bus;

struct mpls_dev;

struct dev_ifalias;

struct net_device_ops;

struct ethtool_ops;

struct switchdev_ops;

struct l3mdev_ops;

struct ndisc_ops;

struct xfrmdev_ops;

struct tlsdev_ops;

struct header_ops;

struct vlan_info;

struct in_device;

struct inet6_dev;

struct netdev_rx_queue;

struct mini_Qdisc;

struct netdev_queue;

struct Qdisc;

struct xps_dev_maps;

struct netpoll_info;

struct pcpu_lstats;

struct pcpu_sw_netstats;

struct rtnl_link_ops;

struct dcbnl_rtnl_ops;

struct netprio_map;

struct phy_device;

struct net_device_extended_rh;

struct net_device {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops *netdev_ops;
	const struct ethtool_ops *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops *l3mdev_ops;
	const struct ndisc_ops *ndisc_ops;
	const struct xfrmdev_ops *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___2 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc *miniq_ingress;
	struct netdev_queue *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED = 0,
		NETREG_REGISTERED = 1,
		NETREG_UNREGISTERING = 2,
		NETREG_UNREGISTERED = 3,
		NETREG_RELEASED = 4,
		NETREG_DUMMY = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED = 0,
		RTNL_LINK_INITIALIZING = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device *);
	struct netpoll_info *npinfo;
	possible_net_t nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___3 dev;
	const struct attribute_group___2 *sysfs_groups[4];
	const struct attribute_group___2 *sysfs_rx_queue_group;
	const struct rtnl_link_ops *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide50;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct bpf_verifier_env;

struct bpf_prog_offload_ops {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog *);
	int (*translate)(struct bpf_prog *);
	void (*destroy)(struct bpf_prog *);
};

struct bpf_offload_dev;

struct bpf_prog_offload {
	struct bpf_prog *prog;
	struct net_device *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops *ops;
	struct bpf_map___2 **used_maps;
	struct bpf_prog *prog;
	struct user_struct___3 *user;
	u64 load_time;
	struct bpf_map___2 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct kthread_work___2;

typedef void (*kthread_work_func_t___2)(struct kthread_work___2 *);

struct kthread_worker___2;

struct kthread_work___2 {
	struct list_head node;
	kthread_work_func_t___2 func;
	struct kthread_worker___2 *worker;
	int canceling;
};

struct kthread_worker___2 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___4 *task;
	struct kthread_work___2 *current_work;
};

struct kthread_delayed_work___2 {
	struct kthread_work___2 work;
	struct timer_list timer;
};

struct psi_group___2 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___2 *poll_kworker;
	struct kthread_delayed_work___2 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___2;

struct cgroup_rstat_cpu___2;

struct cgroup___2 {
	struct cgroup_subsys_state___2 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___2 *kn;
	struct cgroup_file___2 procs_file;
	struct cgroup_file___2 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___2 *subsys[13];
	struct cgroup_root___2 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___2 *dom_cgrp;
	struct cgroup_rstat_cpu___2 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf bpf;
	atomic_t congestion_count;
	struct cgroup___2 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___2 psi;
	int ancestor_ids[0];
};

struct cftype___2;

struct cgroup_subsys___2 {
	struct cgroup_subsys_state___2 * (*css_alloc)(struct cgroup_subsys_state___2 *);
	int (*css_online)(struct cgroup_subsys_state___2 *);
	void (*css_offline)(struct cgroup_subsys_state___2 *);
	void (*css_released)(struct cgroup_subsys_state___2 *);
	void (*css_free)(struct cgroup_subsys_state___2 *);
	void (*css_reset)(struct cgroup_subsys_state___2 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___2 *, int);
	int (*css_extra_stat_show)(struct seq_file___6 *, struct cgroup_subsys_state___2 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___4 *);
	void (*cancel_fork)(struct task_struct___4 *);
	void (*fork)(struct task_struct___4 *);
	void (*exit)(struct task_struct___4 *);
	void (*free)(struct task_struct___4 *);
	void (*bind)(struct cgroup_subsys_state___2 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___2 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___2 *dfl_cftypes;
	struct cftype___2 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___2 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___2 *updated_children;
	struct cgroup___2 *updated_next;
};

struct cgroup_root___2 {
	struct kernfs_root___2 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___2 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___2 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___2 *ss;
	struct list_head node;
	struct kernfs_ops___2 *kf_ops;
	int (*open)(struct kernfs_open_file___2 *);
	void (*release)(struct kernfs_open_file___2 *);
	u64 (*read_u64)(struct cgroup_subsys_state___2 *, struct cftype___2 *);
	s64 (*read_s64)(struct cgroup_subsys_state___2 *, struct cftype___2 *);
	int (*seq_show)(struct seq_file___6 *, void *);
	void * (*seq_start)(struct seq_file___6 *, loff_t *);
	void * (*seq_next)(struct seq_file___6 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___6 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___2 *, struct cftype___2 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___2 *, struct cftype___2 *, s64);
	ssize_t (*write)(struct kernfs_open_file___2 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___2 *, struct poll_table_struct___3 *);
};

typedef void compound_page_dtor___2(struct page___4 *);

struct bdi_writeback_congested___2 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___3 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___2 {
	struct bio___2 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___2 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___2 bip_inline_vecs[0];
};

struct blkg_rwstat {
	struct percpu_counter cpu_cnt[5];
	atomic64_t aux_cnt[5];
};

struct blkcg;

struct blkg_policy_data;

struct blkcg_gq {
	struct request_queue___4 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg *blkcg;
	struct bdi_writeback_congested___2 *wb_congested;
	struct blkcg_gq *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_rwstat stat_bytes;
	struct blkg_rwstat stat_ios;
	struct blkg_policy_data *pd[5];
	struct callback_head callback_head;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
};

struct mem_cgroup_reclaim_iter___2 {
	struct mem_cgroup___2 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___2 {
	struct lruvec___2 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___2 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___2 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct node___2 {
	struct device___3 dev;
};

typedef int suspend_state_t;

enum suspend_stat_step {
	SUSPEND_FREEZE = 1,
	SUSPEND_PREPARE = 2,
	SUSPEND_SUSPEND = 3,
	SUSPEND_SUSPEND_LATE = 4,
	SUSPEND_SUSPEND_NOIRQ = 5,
	SUSPEND_RESUME_NOIRQ = 6,
	SUSPEND_RESUME_EARLY = 7,
	SUSPEND_RESUME = 8,
};

struct suspend_stats {
	int success;
	int fail;
	int failed_freeze;
	int failed_prepare;
	int failed_suspend;
	int failed_suspend_late;
	int failed_suspend_noirq;
	int failed_resume;
	int failed_resume_early;
	int failed_resume_noirq;
	int last_failed_dev;
	char failed_devs[80];
	int last_failed_errno;
	int errno[2];
	int last_failed_step;
	enum suspend_stat_step failed_steps[2];
};

enum s2idle_states {
	S2IDLE_STATE_NONE = 0,
	S2IDLE_STATE_ENTER = 1,
	S2IDLE_STATE_WAKE = 2,
};

struct pbe {
	void *address;
	void *orig_address;
	struct pbe *next;
};

enum {
	Root_NFS = 255,
	Root_RAM0 = 1048576,
	Root_RAM1 = 1048577,
	Root_FD0 = 2097152,
	Root_HDA1 = 3145729,
	Root_HDA2 = 3145730,
	Root_SDA1 = 8388609,
	Root_SDA2 = 8388610,
	Root_HDC1 = 23068673,
	Root_SR0 = 11534336,
};

struct disk_part_tbl___2 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___2 *last_lookup;
	struct hd_struct___2 *part[0];
};

struct block_device_operations___2 {
	int (*open)(struct block_device___3 *, fmode_t);
	void (*release)(struct gendisk___2 *, fmode_t);
	int (*rw_page)(struct block_device___3 *, sector_t, struct page___4 *, unsigned int);
	int (*ioctl)(struct block_device___3 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___3 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___2 *, unsigned int);
	int (*media_changed)(struct gendisk___2 *);
	void (*unlock_native_capacity)(struct gendisk___2 *);
	int (*revalidate_disk)(struct gendisk___2 *);
	int (*getgeo)(struct block_device___3 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___3 *, long unsigned int);
	int (*report_zones)(struct gendisk___2 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___3 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct scatterlist {
	long unsigned int page_link;
	unsigned int offset;
	unsigned int length;
	dma_addr_t dma_address;
	unsigned int dma_length;
};

typedef short unsigned int __kernel_sa_family_t;

struct __kernel_sockaddr_storage {
	__kernel_sa_family_t ss_family;
	char __data[126];
};

typedef __kernel_sa_family_t sa_family_t;

struct sockaddr {
	sa_family_t sa_family;
	char sa_data[14];
};

struct msghdr {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___3 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___3 *msg_iocb;
};

struct fwnode_reference_args___2;

struct fwnode_endpoint___2;

struct fwnode_operations___2 {
	struct fwnode_handle___2 * (*get)(struct fwnode_handle___2 *);
	void (*put)(struct fwnode_handle___2 *);
	bool (*device_is_available)(const struct fwnode_handle___2 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___2 *, const struct device___3 *);
	bool (*property_present)(const struct fwnode_handle___2 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___2 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___2 *, const char *, const char **, size_t);
	struct fwnode_handle___2 * (*get_parent)(const struct fwnode_handle___2 *);
	struct fwnode_handle___2 * (*get_next_child_node)(const struct fwnode_handle___2 *, struct fwnode_handle___2 *);
	struct fwnode_handle___2 * (*get_named_child_node)(const struct fwnode_handle___2 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___2 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___2 *);
	struct fwnode_handle___2 * (*graph_get_next_endpoint)(const struct fwnode_handle___2 *, struct fwnode_handle___2 *);
	struct fwnode_handle___2 * (*graph_get_remote_endpoint)(const struct fwnode_handle___2 *);
	struct fwnode_handle___2 * (*graph_get_port_parent)(struct fwnode_handle___2 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___2 *, struct fwnode_endpoint___2 *);
};

struct fwnode_endpoint___2 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___2 *local_fwnode;
};

struct fwnode_reference_args___2 {
	struct fwnode_handle___2 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct sg_table {
	struct scatterlist *sgl;
	unsigned int nents;
	unsigned int orig_nents;
};

struct xdr_buf {
	struct kvec head[1];
	struct kvec tail[1];
	struct page___4 **pages;
	unsigned int page_base;
	unsigned int page_len;
	unsigned int flags;
	unsigned int buflen;
	unsigned int len;
};

typedef unsigned int sk_buff_data_t;

struct sec_path;

struct nf_bridge_info;

struct sk_buff {
	union {
		struct {
			struct sk_buff *next;
			struct sk_buff *prev;
			union {
				struct net_device *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct xdr_stream {
	__be32 *p;
	struct xdr_buf *buf;
	__be32 *end;
	struct kvec *iov;
	struct kvec scratch;
	struct page___4 **page_ptr;
	unsigned int nwords;
};

struct rpc_rqst;

typedef void (*kxdreproc_t)(struct rpc_rqst *, struct xdr_stream *, const void *);

struct rpc_xprt;

struct rpc_task;

struct rpc_cred;

struct rpc_rqst {
	struct rpc_xprt *rq_xprt;
	struct xdr_buf rq_snd_buf;
	struct xdr_buf rq_rcv_buf;
	struct rpc_task *rq_task;
	struct rpc_cred *rq_cred;
	__be32 rq_xid;
	int rq_cong;
	u32 rq_seqno;
	int rq_enc_pages_num;
	struct page___4 **rq_enc_pages;
	void (*rq_release_snd_buf)(struct rpc_rqst *);
	struct list_head rq_list;
	void *rq_buffer;
	size_t rq_callsize;
	void *rq_rbuffer;
	size_t rq_rcvsize;
	size_t rq_xmit_bytes_sent;
	size_t rq_reply_bytes_recvd;
	struct xdr_buf rq_private_buf;
	long unsigned int rq_majortimeo;
	long unsigned int rq_timeout;
	ktime_t rq_rtt;
	unsigned int rq_retries;
	unsigned int rq_connect_cookie;
	u32 rq_bytes_sent;
	ktime_t rq_xtime;
	int rq_ntrans;
	struct list_head rq_bc_list;
	long unsigned int rq_bc_pa_state;
	struct list_head rq_bc_pa_list;
};

typedef int (*kxdrdproc_t)(struct rpc_rqst *, struct xdr_stream *, void *);

struct rpc_procinfo;

struct rpc_message {
	const struct rpc_procinfo *rpc_proc;
	void *rpc_argp;
	void *rpc_resp;
	struct rpc_cred *rpc_cred;
};

struct rpc_procinfo {
	u32 p_proc;
	kxdreproc_t p_encode;
	kxdrdproc_t p_decode;
	unsigned int p_arglen;
	unsigned int p_replen;
	unsigned int p_timer;
	u32 p_statidx;
	const char *p_name;
};

struct rpc_auth;

struct rpc_credops;

struct rpc_cred {
	struct hlist_node cr_hash;
	struct list_head cr_lru;
	struct callback_head cr_rcu;
	struct rpc_auth *cr_auth;
	const struct rpc_credops *cr_ops;
	long unsigned int cr_expire;
	long unsigned int cr_flags;
	atomic_t cr_count;
	kuid_t cr_uid;
};

struct rpc_wait {
	struct list_head list;
	struct list_head links;
	struct list_head timer_list;
	long unsigned int expires;
};

struct rpc_wait_queue;

struct rpc_call_ops;

struct rpc_clnt;

struct rpc_task {
	atomic_t tk_count;
	int tk_status;
	struct list_head tk_task;
	void (*tk_callback)(struct rpc_task *);
	void (*tk_action)(struct rpc_task *);
	long unsigned int tk_timeout;
	long unsigned int tk_runstate;
	struct rpc_wait_queue *tk_waitqueue;
	union {
		struct work_struct tk_work;
		struct rpc_wait tk_wait;
	} u;
	struct rpc_message tk_msg;
	void *tk_calldata;
	const struct rpc_call_ops *tk_ops;
	struct rpc_clnt *tk_client;
	struct rpc_xprt *tk_xprt;
	struct rpc_rqst *tk_rqstp;
	struct workqueue_struct *tk_workqueue;
	ktime_t tk_start;
	pid_t tk_owner;
	short unsigned int tk_flags;
	short unsigned int tk_timeouts;
	short unsigned int tk_pid;
	unsigned char tk_priority: 2;
	unsigned char tk_garb_retry: 2;
	unsigned char tk_cred_retry: 2;
	unsigned char tk_rebind_retry: 2;
};

struct rpc_timer {
	struct timer_list timer;
	struct list_head list;
	long unsigned int expires;
};

struct rpc_wait_queue {
	spinlock_t lock;
	struct list_head tasks[4];
	pid_t owner;
	unsigned char maxpriority;
	unsigned char priority;
	unsigned char nr;
	short unsigned int qlen;
	struct rpc_timer timer_list;
	const char *name;
};

struct rpc_call_ops {
	void (*rpc_call_prepare)(struct rpc_task *, void *);
	void (*rpc_call_done)(struct rpc_task *, void *);
	void (*rpc_count_stats)(struct rpc_task *, void *);
	void (*rpc_release)(void *);
};

struct rpc_iostats;

struct rpc_pipe_dir_head {
	struct list_head pdh_entries;
	struct dentry___3 *pdh_dentry;
};

struct rpc_rtt {
	long unsigned int timeo;
	long unsigned int srtt[5];
	long unsigned int sdrtt[5];
	int ntimeouts[5];
};

struct rpc_timeout {
	long unsigned int to_initval;
	long unsigned int to_maxval;
	long unsigned int to_increment;
	unsigned int to_retries;
	unsigned char to_exponential;
};

struct rpc_xprt_switch;

struct rpc_xprt_iter_ops;

struct rpc_xprt_iter {
	struct rpc_xprt_switch *xpi_xpswitch;
	struct rpc_xprt *xpi_cursor;
	const struct rpc_xprt_iter_ops *xpi_ops;
};

struct rpc_stat;

struct rpc_program;

struct rpc_clnt {
	atomic_t cl_count;
	unsigned int cl_clid;
	struct list_head cl_clients;
	struct list_head cl_tasks;
	spinlock_t cl_lock;
	struct rpc_xprt *cl_xprt;
	const struct rpc_procinfo *cl_procinfo;
	u32 cl_prog;
	u32 cl_vers;
	u32 cl_maxproc;
	struct rpc_auth *cl_auth;
	struct rpc_stat *cl_stats;
	struct rpc_iostats *cl_metrics;
	unsigned int cl_softrtry: 1;
	unsigned int cl_discrtry: 1;
	unsigned int cl_noretranstimeo: 1;
	unsigned int cl_autobind: 1;
	unsigned int cl_chatty: 1;
	struct rpc_rtt *cl_rtt;
	const struct rpc_timeout *cl_timeout;
	atomic_t cl_swapper;
	int cl_nodelen;
	char cl_nodename[65];
	struct rpc_pipe_dir_head cl_pipedir_objects;
	struct rpc_clnt *cl_parent;
	struct rpc_rtt cl_rtt_default;
	struct rpc_timeout cl_timeout_default;
	const struct rpc_program *cl_program;
	struct dentry___3 *cl_debugfs;
	struct rpc_xprt_iter cl_xpi;
};

struct svc_xprt;

struct svc_serv;

struct rpc_xprt_ops;

struct rpc_xprt {
	struct kref kref;
	const struct rpc_xprt_ops *ops;
	const struct rpc_timeout *timeout;
	struct __kernel_sockaddr_storage addr;
	size_t addrlen;
	int prot;
	long unsigned int cong;
	long unsigned int cwnd;
	size_t max_payload;
	unsigned int tsh_size;
	struct rpc_wait_queue binding;
	struct rpc_wait_queue sending;
	struct rpc_wait_queue pending;
	struct rpc_wait_queue backlog;
	struct list_head free;
	unsigned int max_reqs;
	unsigned int min_reqs;
	unsigned int num_reqs;
	long unsigned int state;
	unsigned char resvport: 1;
	atomic_t swapper;
	unsigned int bind_index;
	struct list_head xprt_switch;
	long unsigned int bind_timeout;
	long unsigned int reestablish_timeout;
	unsigned int connect_cookie;
	struct work_struct task_cleanup;
	struct timer_list timer;
	long unsigned int last_used;
	long unsigned int idle_timeout;
	long unsigned int connect_timeout;
	long unsigned int max_reconnect_timeout;
	spinlock_t transport_lock;
	spinlock_t reserve_lock;
	spinlock_t recv_lock;
	u32 xid;
	struct rpc_task *snd_task;
	struct svc_xprt *bc_xprt;
	struct svc_serv *bc_serv;
	int bc_alloc_count;
	atomic_t bc_free_slots;
	spinlock_t bc_pa_lock;
	struct list_head bc_pa_list;
	struct list_head recv;
	struct {
		long unsigned int bind_count;
		long unsigned int connect_count;
		long unsigned int connect_start;
		long unsigned int connect_time;
		long unsigned int sends;
		long unsigned int recvs;
		long unsigned int bad_xids;
		long unsigned int max_slots;
		long long unsigned int req_u;
		long long unsigned int bklog_u;
		long long unsigned int sending_u;
		long long unsigned int pending_u;
	} stat;
	struct net___2 *xprt_net;
	const char *servername;
	const char *address_strings[6];
	struct dentry___3 *debugfs;
	atomic_t inject_disconnect;
	struct callback_head rcu;
};

typedef u32 rpc_authflavor_t;

struct ethhdr {
	unsigned char h_dest[6];
	unsigned char h_source[6];
	__be16 h_proto;
};

struct flow_dissector {
	unsigned int used_keys;
	short unsigned int offset[24];
};

struct flowi_tunnel {
	__be64 tun_id;
};

struct flowi_common {
	int flowic_oif;
	int flowic_iif;
	__u32 flowic_mark;
	__u8 flowic_tos;
	__u8 flowic_scope;
	__u8 flowic_proto;
	__u8 flowic_flags;
	__u32 flowic_secid;
	struct flowi_tunnel flowic_tun_key;
	kuid_t flowic_uid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

union flowi_uli {
	struct {
		__be16 dport;
		__be16 sport;
	} ports;
	struct {
		__u8 type;
		__u8 code;
	} icmpt;
	struct {
		__le16 dport;
		__le16 sport;
	} dnports;
	__be32 spi;
	__be32 gre_key;
	struct {
		__u8 type;
	} mht;
};

struct flowi4 {
	struct flowi_common __fl_common;
	__be32 saddr;
	__be32 daddr;
	union flowi_uli uli;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct flowi6 {
	struct flowi_common __fl_common;
	struct in6_addr daddr;
	struct in6_addr saddr;
	__be32 flowlabel;
	union flowi_uli uli;
	__u32 mp_hash;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct flowidn {
	struct flowi_common __fl_common;
	__le16 daddr;
	__le16 saddr;
	union flowi_uli uli;
};

struct flowi {
	union {
		struct flowi_common __fl_common;
		struct flowi4 ip4;
		struct flowi6 ip6;
		struct flowidn dn;
	} u;
};

struct ipstats_mib {
	u64 mibs[37];
	struct u64_stats_sync syncp;
};

struct icmp_mib {
	long unsigned int mibs[28];
};

struct icmpmsg_mib {
	atomic_long_t mibs[512];
};

struct icmpv6_mib {
	long unsigned int mibs[6];
};

struct icmpv6_mib_device {
	atomic_long_t mibs[6];
};

struct icmpv6msg_mib {
	atomic_long_t mibs[512];
};

struct icmpv6msg_mib_device {
	atomic_long_t mibs[512];
};

struct tcp_mib {
	long unsigned int mibs[16];
};

struct udp_mib {
	long unsigned int mibs[9];
};

struct linux_mib {
	long unsigned int mibs[116];
};

struct linux_xfrm_mib {
	long unsigned int mibs[29];
};

struct inet_frag_queue;

struct inet_frags {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue *, const void *);
	void (*destructor)(struct inet_frag_queue *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct frag_v4_compare_key {
	__be32 saddr;
	__be32 daddr;
	u32 user;
	u32 vif;
	__be16 id;
	u16 protocol;
};

struct frag_v6_compare_key {
	struct in6_addr saddr;
	struct in6_addr daddr;
	u32 user;
	__be32 id;
	u32 iif;
};

struct inet_frag_queue {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff *fragments;
	struct rb_root rb_fragments;
	struct sk_buff *fragments_tail;
	struct sk_buff *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags *net;
	struct callback_head rcu;
};

struct fib_rule;

struct fib_lookup_arg;

struct fib_rule_hdr;

struct nlattr;

struct netlink_ext_ack;

struct nla_policy;

struct fib_rules_ops {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule *, struct flowi *, int, struct fib_lookup_arg *);
	bool (*suppress)(struct fib_rule *, struct fib_lookup_arg *);
	int (*match)(struct fib_rule *, struct flowi *, int);
	int (*configure)(struct fib_rule *, struct sk_buff *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule *);
	int (*compare)(struct fib_rule *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule *, struct sk_buff *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule *);
	void (*flush_cache)(struct fib_rules_ops *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___3 *owner;
	struct net___2 *fro_net;
	struct callback_head rcu;
};

enum tcp_ca_event {
	CA_EVENT_TX_START = 0,
	CA_EVENT_CWND_RESTART = 1,
	CA_EVENT_COMPLETE_CWR = 2,
	CA_EVENT_LOSS = 3,
	CA_EVENT_ECN_NO_CE = 4,
	CA_EVENT_ECN_IS_CE = 5,
};

union tcp_cc_info;

struct sock___2;

struct ack_sample;

struct rate_sample;

struct module___4;

struct tcp_congestion_ops {
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___2 *);
	void (*release)(struct sock___2 *);
	u32 (*ssthresh)(struct sock___2 *);
	void (*cong_avoid)(struct sock___2 *, u32, u32);
	void (*set_state)(struct sock___2 *, u8);
	void (*cwnd_event)(struct sock___2 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___2 *, u32);
	u32 (*undo_cwnd)(struct sock___2 *);
	void (*pkts_acked)(struct sock___2 *, const struct ack_sample *);
	u32 (*min_tso_segs)(struct sock___2 *);
	u32 (*sndbuf_expand)(struct sock___2 *);
	void (*cong_control)(struct sock___2 *, const struct rate_sample *);
	size_t (*get_info)(struct sock___2 *, u32, int *, union tcp_cc_info *);
	char name[16];
	struct module___4 *owner;
};

struct fib_notifier_ops {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___2 *);
	int (*fib_dump)(struct net___2 *, struct notifier_block *);
	struct module___3 *owner;
	struct callback_head rcu;
};

struct xfrm_state;

struct lwtunnel_state;

struct dst_entry {
	struct net_device *dev;
	struct dst_ops *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff *);
	int (*output)(struct net___2 *, struct sock *, struct sk_buff *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct hh_cache {
	unsigned int hh_len;
	seqlock_t hh_lock;
	long unsigned int hh_data[4];
};

struct neigh_table;

struct neigh_parms;

struct neigh_ops;

struct neighbour {
	struct neighbour *next;
	struct neigh_table *tbl;
	struct neigh_parms *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour *, struct sk_buff *);
	const struct neigh_ops *ops;
	struct callback_head rcu;
	struct net_device *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct ipv6_stable_secret {
	bool initialized;
	struct in6_addr secret;
};

struct ipv6_devconf {
	__s32 forwarding;
	__s32 hop_limit;
	__s32 mtu6;
	__s32 accept_ra;
	__s32 accept_redirects;
	__s32 autoconf;
	__s32 dad_transmits;
	__s32 rtr_solicits;
	__s32 rtr_solicit_interval;
	__s32 rtr_solicit_max_interval;
	__s32 rtr_solicit_delay;
	__s32 force_mld_version;
	__s32 mldv1_unsolicited_report_interval;
	__s32 mldv2_unsolicited_report_interval;
	__s32 use_tempaddr;
	__s32 temp_valid_lft;
	__s32 temp_prefered_lft;
	__s32 regen_max_retry;
	__s32 max_desync_factor;
	__s32 max_addresses;
	__s32 accept_ra_defrtr;
	__s32 accept_ra_min_hop_limit;
	__s32 accept_ra_pinfo;
	__s32 ignore_routes_with_linkdown;
	__s32 accept_ra_rtr_pref;
	__s32 rtr_probe_interval;
	__s32 accept_ra_rt_info_min_plen;
	__s32 accept_ra_rt_info_max_plen;
	__s32 proxy_ndp;
	__s32 accept_source_route;
	__s32 accept_ra_from_local;
	__s32 optimistic_dad;
	__s32 use_optimistic;
	__s32 mc_forwarding;
	__s32 disable_ipv6;
	__s32 drop_unicast_in_l2_multicast;
	__s32 accept_dad;
	__s32 force_tllao;
	__s32 ndisc_notify;
	__s32 suppress_frag_ndisc;
	__s32 accept_ra_mtu;
	__s32 drop_unsolicited_na;
	struct ipv6_stable_secret stable_secret;
	__s32 use_oif_addrs_only;
	__s32 keep_addr_on_down;
	__s32 seg6_enabled;
	__u32 enhanced_dad;
	__u32 addr_gen_mode;
	__s32 disable_policy;
	__s32 ndisc_tclass;
	struct ctl_table_header *sysctl_header;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct nf_queue_entry;

struct net___3;

struct nf_queue_handler {
	int (*outfn)(struct nf_queue_entry *, unsigned int);
	void (*nf_hook_drop)(struct net___3 *);
};

enum nf_log_type {
	NF_LOG_TYPE_LOG = 0,
	NF_LOG_TYPE_ULOG = 1,
	NF_LOG_TYPE_MAX = 2,
};

typedef u8 u_int8_t;

struct sk_buff___2;

struct net_device___2;

struct nf_loginfo;

typedef void nf_logfn(struct net___3 *, u_int8_t, unsigned int, const struct sk_buff___2 *, const struct net_device___2 *, const struct net_device___2 *, const struct nf_loginfo *, const char *);

struct module___5;

struct nf_logger {
	char *name;
	enum nf_log_type type;
	nf_logfn *logfn;
	struct module___5 *me;
};

struct hlist_nulls_head {
	struct hlist_nulls_node *first;
};

struct ip_conntrack_stat {
	unsigned int found;
	unsigned int invalid;
	unsigned int ignore;
	unsigned int insert;
	unsigned int insert_failed;
	unsigned int drop;
	unsigned int early_drop;
	unsigned int error;
	unsigned int expect_new;
	unsigned int expect_create;
	unsigned int expect_delete;
	unsigned int search_restart;
};

struct ct_pcpu {
	spinlock_t lock;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
};

typedef enum {
	SS_FREE = 0,
	SS_UNCONNECTED = 1,
	SS_CONNECTING = 2,
	SS_CONNECTED = 3,
	SS_DISCONNECTING = 4,
} socket_state;

struct socket_wq {
	wait_queue_head_t wait;
	struct fasync_struct___2 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops;

struct socket {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq *wq;
	struct file___3 *file;
	struct sock *sk;
	const struct proto_ops *ops;
};

typedef int (*sk_read_actor_t)(read_descriptor_t *, struct sk_buff *, unsigned int, size_t);

struct proto_ops_extended_rh {};

struct proto_ops {
	int family;
	struct module___3 *owner;
	int (*release)(struct socket *);
	int (*bind)(struct socket *, struct sockaddr *, int);
	int (*connect)(struct socket *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket *, struct socket *);
	int (*accept)(struct socket *, struct socket *, int, bool);
	int (*getname)(struct socket *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___3 *, struct socket *, struct poll_table_struct___3 *);
	int (*ioctl)(struct socket *, unsigned int, long unsigned int);
	int (*listen)(struct socket *, int);
	int (*shutdown)(struct socket *, int);
	int (*setsockopt)(struct socket *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket *, int, int, char *, int *);
	int (*sendmsg)(struct socket *, struct msghdr *, size_t);
	int (*recvmsg)(struct socket *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___3 *, struct socket *, struct vm_area_struct___4 *);
	ssize_t (*sendpage)(struct socket *, struct page___4 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock *, int);
	int (*peek_len)(struct socket *);
	int (*read_sock)(struct sock *, read_descriptor_t *, sk_read_actor_t);
	int (*sendpage_locked)(struct sock *, struct page___4 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock *, struct msghdr *, size_t);
	int (*set_rcvlowat)(struct sock *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct shared_info;

struct start_info;

struct pipe_buf_operations;

struct pipe_buffer {
	struct page___4 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___2 *, struct pipe_buffer *);
	void (*release)(struct pipe_inode_info___2 *, struct pipe_buffer *);
	int (*steal)(struct pipe_inode_info___2 *, struct pipe_buffer *);
	union {
		bool (*get)(struct pipe_inode_info___2 *, struct pipe_buffer *);
		struct {
			void (*get)(struct pipe_inode_info___2 *, struct pipe_buffer *);
		} __UNIQUE_ID_rh_kabi_hide37;
		union {		};
	};
};

struct nf_bridge_info {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED = 0,
		BRNF_PROTO_8021Q = 1,
		BRNF_PROTO_PPPOE = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device *physindev;
	struct net_device *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

struct skb_checksum_ops {
	__wsum (*update)(const void *, int, __wsum);
	__wsum (*combine)(__wsum, __wsum, int, int);
};

struct pernet_operations {
	struct list_head list;
	int (*init)(struct net___2 *);
	void (*exit)(struct net___2 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct auth_cred {
	kuid_t uid;
	kgid_t gid;
	struct group_info *group_info;
	const char *principal;
	long unsigned int ac_flags;
	unsigned char machine_cred: 1;
};

struct rpc_cred_cache;

struct rpc_authops;

struct rpc_auth {
	unsigned int au_cslack;
	unsigned int au_rslack;
	unsigned int au_verfsize;
	unsigned int au_flags;
	const struct rpc_authops *au_ops;
	rpc_authflavor_t au_flavor;
	atomic_t au_count;
	struct rpc_cred_cache *au_credcache;
};

struct rpc_credops {
	const char *cr_name;
	int (*cr_init)(struct rpc_auth *, struct rpc_cred *);
	void (*crdestroy)(struct rpc_cred *);
	int (*crmatch)(struct auth_cred *, struct rpc_cred *, int);
	struct rpc_cred * (*crbind)(struct rpc_task *, struct rpc_cred *, int);
	__be32 * (*crmarshal)(struct rpc_task *, __be32 *);
	int (*crrefresh)(struct rpc_task *);
	__be32 * (*crvalidate)(struct rpc_task *, __be32 *);
	int (*crwrap_req)(struct rpc_task *, kxdreproc_t, void *, __be32 *, void *);
	int (*crunwrap_resp)(struct rpc_task *, kxdrdproc_t, void *, __be32 *, void *);
	int (*crkey_timeout)(struct rpc_cred *);
	bool (*crkey_to_expire)(struct rpc_cred *);
	char * (*crstringify_acceptor)(struct rpc_cred *);
};

struct rpc_auth_create_args;

struct rpcsec_gss_info;

struct rpc_authops {
	struct module___3 *owner;
	rpc_authflavor_t au_flavor;
	char *au_name;
	struct rpc_auth * (*create)(struct rpc_auth_create_args *, struct rpc_clnt *);
	void (*destroy)(struct rpc_auth *);
	int (*hash_cred)(struct auth_cred *, unsigned int);
	struct rpc_cred * (*lookup_cred)(struct rpc_auth *, struct auth_cred *, int);
	struct rpc_cred * (*crcreate)(struct rpc_auth *, struct auth_cred *, int, gfp_t);
	int (*list_pseudoflavors)(rpc_authflavor_t *, int);
	rpc_authflavor_t (*info2flavor)(struct rpcsec_gss_info *);
	int (*flavor2info)(rpc_authflavor_t, struct rpcsec_gss_info *);
	int (*key_timeout)(struct rpc_auth *, struct rpc_cred *);
};

struct rpc_auth_create_args {
	rpc_authflavor_t pseudoflavor;
	const char *target_name;
};

struct rpcsec_gss_oid {
	unsigned int len;
	u8 data[32];
};

struct rpcsec_gss_info {
	struct rpcsec_gss_oid oid;
	u32 qop;
	u32 service;
};

struct rpc_xprt_ops {
	void (*set_buffer_size)(struct rpc_xprt *, size_t, size_t);
	int (*reserve_xprt)(struct rpc_xprt *, struct rpc_task *);
	void (*release_xprt)(struct rpc_xprt *, struct rpc_task *);
	void (*alloc_slot)(struct rpc_xprt *, struct rpc_task *);
	void (*free_slot)(struct rpc_xprt *, struct rpc_rqst *);
	void (*rpcbind)(struct rpc_task *);
	void (*set_port)(struct rpc_xprt *, short unsigned int);
	void (*connect)(struct rpc_xprt *, struct rpc_task *);
	int (*buf_alloc)(struct rpc_task *);
	void (*buf_free)(struct rpc_task *);
	int (*send_request)(struct rpc_task *);
	void (*set_retrans_timeout)(struct rpc_task *);
	void (*timer)(struct rpc_xprt *, struct rpc_task *);
	void (*release_request)(struct rpc_task *);
	void (*close)(struct rpc_xprt *);
	void (*destroy)(struct rpc_xprt *);
	void (*set_connect_timeout)(struct rpc_xprt *, long unsigned int, long unsigned int);
	void (*print_stats)(struct rpc_xprt *, struct seq_file___6 *);
	int (*enable_swap)(struct rpc_xprt *);
	void (*disable_swap)(struct rpc_xprt *);
	void (*inject_disconnect)(struct rpc_xprt *);
	int (*bc_setup)(struct rpc_xprt *, unsigned int);
	int (*bc_up)(struct svc_serv *, struct net___2 *);
	size_t (*bc_maxpayload)(struct rpc_xprt *);
	void (*bc_free_rqst)(struct rpc_rqst *);
	void (*bc_destroy)(struct rpc_xprt *, unsigned int);
};

struct rpc_xprt_switch {
	spinlock_t xps_lock;
	struct kref xps_kref;
	unsigned int xps_nxprts;
	struct list_head xps_xprt_list;
	struct net___2 *xps_net;
	const struct rpc_xprt_iter_ops *xps_iter_ops;
	struct callback_head xps_rcu;
};

struct rpc_stat {
	const struct rpc_program *program;
	unsigned int netcnt;
	unsigned int netudpcnt;
	unsigned int nettcpcnt;
	unsigned int nettcpconn;
	unsigned int netreconn;
	unsigned int rpccnt;
	unsigned int rpcretrans;
	unsigned int rpcauthrefresh;
	unsigned int rpcgarbage;
};

struct rpc_version;

struct rpc_program {
	const char *name;
	u32 number;
	unsigned int nrvers;
	const struct rpc_version **version;
	struct rpc_stat *stats;
	const char *pipe_dir_name;
};

struct ipv6_params {
	__s32 disable_ipv6;
	__s32 autoconf;
};

struct dql {
	unsigned int num_queued;
	unsigned int adj_limit;
	unsigned int last_obj_cnt;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int limit;
	unsigned int num_completed;
	unsigned int prev_ovlimit;
	unsigned int prev_num_queued;
	unsigned int prev_last_obj_cnt;
	unsigned int lowest_slack;
	long unsigned int slack_start_time;
	unsigned int max_limit;
	unsigned int min_limit;
	unsigned int slack_hold_time;
	long: 32;
	long: 64;
	long: 64;
};

typedef struct {
	unsigned int clock_rate;
	unsigned int clock_type;
	short unsigned int loopback;
} sync_serial_settings;

typedef struct {
	unsigned int clock_rate;
	unsigned int clock_type;
	short unsigned int loopback;
	unsigned int slot_map;
} te1_settings;

typedef struct {
	short unsigned int encoding;
	short unsigned int parity;
} raw_hdlc_proto;

typedef struct {
	unsigned int t391;
	unsigned int t392;
	unsigned int n391;
	unsigned int n392;
	unsigned int n393;
	short unsigned int lmi;
	short unsigned int dce;
} fr_proto;

typedef struct {
	unsigned int dlci;
} fr_proto_pvc;

typedef struct {
	unsigned int dlci;
	char master[16];
} fr_proto_pvc_info;

typedef struct {
	unsigned int interval;
	unsigned int timeout;
} cisco_proto;

struct ifmap {
	long unsigned int mem_start;
	long unsigned int mem_end;
	short unsigned int base_addr;
	unsigned char irq;
	unsigned char dma;
	unsigned char port;
};

struct if_settings {
	unsigned int type;
	unsigned int size;
	union {
		raw_hdlc_proto *raw_hdlc;
		cisco_proto *cisco;
		fr_proto *fr;
		fr_proto_pvc *fr_pvc;
		fr_proto_pvc_info *fr_pvc_info;
		sync_serial_settings *sync;
		te1_settings *te1;
	} ifs_ifsu;
};

struct ifreq {
	union {
		char ifrn_name[16];
	} ifr_ifrn;
	union {
		struct sockaddr ifru_addr;
		struct sockaddr ifru_dstaddr;
		struct sockaddr ifru_broadaddr;
		struct sockaddr ifru_netmask;
		struct sockaddr ifru_hwaddr;
		short int ifru_flags;
		int ifru_ivalue;
		int ifru_mtu;
		struct ifmap ifru_map;
		char ifru_slave[16];
		char ifru_newname[16];
		void *ifru_data;
		struct if_settings ifru_settings;
	} ifr_ifru;
};

struct ethtool_cmd {
	__u32 cmd;
	__u32 supported;
	__u32 advertising;
	__u16 speed;
	__u8 duplex;
	__u8 port;
	__u8 phy_address;
	__u8 transceiver;
	__u8 autoneg;
	__u8 mdio_support;
	__u32 maxtxpkt;
	__u32 maxrxpkt;
	__u16 speed_hi;
	__u8 eth_tp_mdix;
	__u8 eth_tp_mdix_ctrl;
	__u32 lp_advertising;
	__u32 reserved[2];
};

struct ethtool_drvinfo {
	__u32 cmd;
	char driver[32];
	char version[32];
	char fw_version[32];
	char bus_info[32];
	char erom_version[32];
	char reserved2[12];
	__u32 n_priv_flags;
	__u32 n_stats;
	__u32 testinfo_len;
	__u32 eedump_len;
	__u32 regdump_len;
};

struct ethtool_wolinfo {
	__u32 cmd;
	__u32 supported;
	__u32 wolopts;
	__u8 sopass[6];
};

struct ethtool_tunable {
	__u32 cmd;
	__u32 id;
	__u32 type_id;
	__u32 len;
	void *data[0];
};

struct ethtool_regs {
	__u32 cmd;
	__u32 version;
	__u32 len;
	__u8 data[0];
};

struct ethtool_eeprom {
	__u32 cmd;
	__u32 magic;
	__u32 offset;
	__u32 len;
	__u8 data[0];
};

struct ethtool_eee {
	__u32 cmd;
	__u32 supported;
	__u32 advertised;
	__u32 lp_advertised;
	__u32 eee_active;
	__u32 eee_enabled;
	__u32 tx_lpi_enabled;
	__u32 tx_lpi_timer;
	__u32 reserved[2];
};

struct ethtool_modinfo {
	__u32 cmd;
	__u32 type;
	__u32 eeprom_len;
	__u32 reserved[8];
};

struct ethtool_coalesce {
	__u32 cmd;
	__u32 rx_coalesce_usecs;
	__u32 rx_max_coalesced_frames;
	__u32 rx_coalesce_usecs_irq;
	__u32 rx_max_coalesced_frames_irq;
	__u32 tx_coalesce_usecs;
	__u32 tx_max_coalesced_frames;
	__u32 tx_coalesce_usecs_irq;
	__u32 tx_max_coalesced_frames_irq;
	__u32 stats_block_coalesce_usecs;
	__u32 use_adaptive_rx_coalesce;
	__u32 use_adaptive_tx_coalesce;
	__u32 pkt_rate_low;
	__u32 rx_coalesce_usecs_low;
	__u32 rx_max_coalesced_frames_low;
	__u32 tx_coalesce_usecs_low;
	__u32 tx_max_coalesced_frames_low;
	__u32 pkt_rate_high;
	__u32 rx_coalesce_usecs_high;
	__u32 rx_max_coalesced_frames_high;
	__u32 tx_coalesce_usecs_high;
	__u32 tx_max_coalesced_frames_high;
	__u32 rate_sample_interval;
};

struct ethtool_ringparam {
	__u32 cmd;
	__u32 rx_max_pending;
	__u32 rx_mini_max_pending;
	__u32 rx_jumbo_max_pending;
	__u32 tx_max_pending;
	__u32 rx_pending;
	__u32 rx_mini_pending;
	__u32 rx_jumbo_pending;
	__u32 tx_pending;
};

struct ethtool_channels {
	__u32 cmd;
	__u32 max_rx;
	__u32 max_tx;
	__u32 max_other;
	__u32 max_combined;
	__u32 rx_count;
	__u32 tx_count;
	__u32 other_count;
	__u32 combined_count;
};

struct ethtool_pauseparam {
	__u32 cmd;
	__u32 autoneg;
	__u32 rx_pause;
	__u32 tx_pause;
};

struct ethtool_test {
	__u32 cmd;
	__u32 flags;
	__u32 reserved;
	__u32 len;
	__u64 data[0];
};

struct ethtool_stats {
	__u32 cmd;
	__u32 n_stats;
	__u64 data[0];
};

struct ethtool_tcpip4_spec {
	__be32 ip4src;
	__be32 ip4dst;
	__be16 psrc;
	__be16 pdst;
	__u8 tos;
};

struct ethtool_ah_espip4_spec {
	__be32 ip4src;
	__be32 ip4dst;
	__be32 spi;
	__u8 tos;
};

struct ethtool_usrip4_spec {
	__be32 ip4src;
	__be32 ip4dst;
	__be32 l4_4_bytes;
	__u8 tos;
	__u8 ip_ver;
	__u8 proto;
};

struct ethtool_tcpip6_spec {
	__be32 ip6src[4];
	__be32 ip6dst[4];
	__be16 psrc;
	__be16 pdst;
	__u8 tclass;
};

struct ethtool_ah_espip6_spec {
	__be32 ip6src[4];
	__be32 ip6dst[4];
	__be32 spi;
	__u8 tclass;
};

struct ethtool_usrip6_spec {
	__be32 ip6src[4];
	__be32 ip6dst[4];
	__be32 l4_4_bytes;
	__u8 tclass;
	__u8 l4_proto;
};

union ethtool_flow_union {
	struct ethtool_tcpip4_spec tcp_ip4_spec;
	struct ethtool_tcpip4_spec udp_ip4_spec;
	struct ethtool_tcpip4_spec sctp_ip4_spec;
	struct ethtool_ah_espip4_spec ah_ip4_spec;
	struct ethtool_ah_espip4_spec esp_ip4_spec;
	struct ethtool_usrip4_spec usr_ip4_spec;
	struct ethtool_tcpip6_spec tcp_ip6_spec;
	struct ethtool_tcpip6_spec udp_ip6_spec;
	struct ethtool_tcpip6_spec sctp_ip6_spec;
	struct ethtool_ah_espip6_spec ah_ip6_spec;
	struct ethtool_ah_espip6_spec esp_ip6_spec;
	struct ethtool_usrip6_spec usr_ip6_spec;
	struct ethhdr ether_spec;
	__u8 hdata[52];
};

struct ethtool_flow_ext {
	__u8 padding[2];
	unsigned char h_dest[6];
	__be16 vlan_etype;
	__be16 vlan_tci;
	__be32 data[2];
};

struct ethtool_rx_flow_spec {
	__u32 flow_type;
	union ethtool_flow_union h_u;
	struct ethtool_flow_ext h_ext;
	union ethtool_flow_union m_u;
	struct ethtool_flow_ext m_ext;
	__u64 ring_cookie;
	__u32 location;
};

struct ethtool_rxnfc {
	__u32 cmd;
	__u32 flow_type;
	__u64 data;
	struct ethtool_rx_flow_spec fs;
	union {
		__u32 rule_cnt;
		__u32 rss_context;
	};
	__u32 rule_locs[0];
};

struct ethtool_flash {
	__u32 cmd;
	__u32 region;
	char data[128];
};

struct ethtool_dump {
	__u32 cmd;
	__u32 version;
	__u32 flag;
	__u32 len;
	__u8 data[0];
};

struct ethtool_ts_info {
	__u32 cmd;
	__u32 so_timestamping;
	__s32 phc_index;
	__u32 tx_types;
	__u32 tx_reserved[3];
	__u32 rx_filters;
	__u32 rx_reserved[3];
};

struct ethtool_fecparam {
	__u32 cmd;
	__u32 active_fec;
	__u32 fec;
	__u32 reserved;
};

struct ethtool_link_settings {
	__u32 cmd;
	__u32 speed;
	__u8 duplex;
	__u8 port;
	__u8 phy_address;
	__u8 autoneg;
	__u8 mdio_support;
	__u8 eth_tp_mdix;
	__u8 eth_tp_mdix_ctrl;
	__s8 link_mode_masks_nwords;
	__u8 transceiver;
	__u8 reserved1[3];
	__u32 reserved[7];
	__u32 link_mode_masks[0];
};

enum ethtool_phys_id_state {
	ETHTOOL_ID_INACTIVE = 0,
	ETHTOOL_ID_ACTIVE = 1,
	ETHTOOL_ID_ON = 2,
	ETHTOOL_ID_OFF = 3,
};

struct ethtool_link_ksettings {
	struct ethtool_link_settings base;
	struct {
		long unsigned int supported[2];
		long unsigned int advertising[2];
		long unsigned int lp_advertising[2];
	} link_modes;
};

struct ethtool_ops_extended_rh {};

struct ethtool_link_ksettings_rh80 {
	struct ethtool_link_settings base;
	struct {
		long unsigned int supported[1];
		long unsigned int advertising[1];
		long unsigned int lp_advertising[1];
	} link_modes;
};

struct ethtool_ops {
	int (*get_settings)(struct net_device *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device *);
	void (*get_regs)(struct net_device *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device *);
	void (*set_msglevel)(struct net_device *, u32);
	int (*nway_reset)(struct net_device *);
	u32 (*get_link)(struct net_device *);
	int (*get_eeprom_len)(struct net_device *);
	int (*get_eeprom)(struct net_device *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device *, u32, u8 *);
	int (*set_phys_id)(struct net_device *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device *);
	void (*complete)(struct net_device *);
	u32 (*get_priv_flags)(struct net_device *);
	int (*set_priv_flags)(struct net_device *, u32);
	int (*get_sset_count)(struct net_device *, int);
	int (*get_rxnfc)(struct net_device *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device *, struct ethtool_flash *);
	int (*reset)(struct net_device *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device *);
	u32 (*get_rxfh_indir_size)(struct net_device *);
	int (*get_rxfh)(struct net_device *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device *, struct ethtool_channels *);
	int (*set_channels)(struct net_device *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device *, struct ethtool_eee *);
	int (*set_eee)(struct net_device *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide40;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide41;
		union {		};
	};
	int (*get_fecparam)(struct net_device *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide42;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide43;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct ieee_ets {
	__u8 willing;
	__u8 ets_cap;
	__u8 cbs;
	__u8 tc_tx_bw[8];
	__u8 tc_rx_bw[8];
	__u8 tc_tsa[8];
	__u8 prio_tc[8];
	__u8 tc_reco_bw[8];
	__u8 tc_reco_tsa[8];
	__u8 reco_prio_tc[8];
};

struct ieee_maxrate {
	__u64 tc_maxrate[8];
};

struct ieee_qcn {
	__u8 rpg_enable[8];
	__u32 rppp_max_rps[8];
	__u32 rpg_time_reset[8];
	__u32 rpg_byte_reset[8];
	__u32 rpg_threshold[8];
	__u32 rpg_max_rate[8];
	__u32 rpg_ai_rate[8];
	__u32 rpg_hai_rate[8];
	__u32 rpg_gd[8];
	__u32 rpg_min_dec_fac[8];
	__u32 rpg_min_rate[8];
	__u32 cndd_state_machine[8];
};

struct ieee_qcn_stats {
	__u64 rppp_rp_centiseconds[8];
	__u32 rppp_created_rps[8];
};

struct ieee_pfc {
	__u8 pfc_cap;
	__u8 pfc_en;
	__u8 mbc;
	__u16 delay;
	__u64 requests[8];
	__u64 indications[8];
};

struct dcbnl_buffer {
	__u8 prio2buffer[8];
	__u32 buffer_size[8];
	__u32 total_size;
};

struct cee_pg {
	__u8 willing;
	__u8 error;
	__u8 pg_en;
	__u8 tcs_supported;
	__u8 pg_bw[8];
	__u8 prio_pg[8];
};

struct cee_pfc {
	__u8 willing;
	__u8 error;
	__u8 pfc_en;
	__u8 tcs_supported;
};

struct dcb_app {
	__u8 selector;
	__u8 priority;
	__u16 protocol;
};

struct dcb_peer_app_info {
	__u8 willing;
	__u8 error;
};

struct dcbnl_rtnl_ops_extended_rh {};

struct dcbnl_rtnl_ops {
	int (*ieee_getets)(struct net_device *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device *);
	u8 (*setstate)(struct net_device *, u8);
	void (*getpermhwaddr)(struct net_device *, u8 *);
	void (*setpgtccfgtx)(struct net_device *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device *, int, u8);
	void (*setpgtccfgrx)(struct net_device *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device *, int, u8);
	void (*getpgtccfgtx)(struct net_device *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device *, int, u8 *);
	void (*setpfccfg)(struct net_device *, int, u8);
	void (*getpfccfg)(struct net_device *, int, u8 *);
	u8 (*setall)(struct net_device *);
	u8 (*getcap)(struct net_device *, int, u8 *);
	int (*getnumtcs)(struct net_device *, int, u8 *);
	int (*setnumtcs)(struct net_device *, int, u8);
	u8 (*getpfcstate)(struct net_device *);
	void (*setpfcstate)(struct net_device *, u8);
	void (*getbcncfg)(struct net_device *, int, u32 *);
	void (*setbcncfg)(struct net_device *, int, u32);
	void (*getbcnrp)(struct net_device *, int, u8 *);
	void (*setbcnrp)(struct net_device *, int, u8);
	int (*setapp)(struct net_device *, u8, u16, u8);
	int (*getapp)(struct net_device *, u8, u16);
	u8 (*getfeatcfg)(struct net_device *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device *, int, u8);
	u8 (*getdcbx)(struct net_device *);
	u8 (*setdcbx)(struct net_device *, u8);
	int (*peer_getappinfo)(struct net_device *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct netprio_map {
	struct callback_head rcu;
	u32 priomap_len;
	u32 priomap[0];
};

struct xdp_mem_info {
	u32 type;
	u32 id;
};

struct xdp_rxq_info {
	struct net_device *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device *dev_rx;
};

struct nlmsghdr {
	__u32 nlmsg_len;
	__u16 nlmsg_type;
	__u16 nlmsg_flags;
	__u32 nlmsg_seq;
	__u32 nlmsg_pid;
};

struct nlattr {
	__u16 nla_len;
	__u16 nla_type;
};

struct netlink_ext_ack {
	const char *_msg;
	const struct nlattr *bad_attr;
	u8 cookie[20];
	u8 cookie_len;
};

struct netlink_callback {
	struct sk_buff *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback *);
	int (*dump)(struct sk_buff *, struct netlink_callback *);
	int (*done)(struct netlink_callback *);
	void *data;
	struct module___3 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct ndmsg {
	__u8 ndm_family;
	__u8 ndm_pad1;
	__u16 ndm_pad2;
	__s32 ndm_ifindex;
	__u16 ndm_state;
	__u8 ndm_flags;
	__u8 ndm_type;
};

struct rtnl_link_stats64 {
	__u64 rx_packets;
	__u64 tx_packets;
	__u64 rx_bytes;
	__u64 tx_bytes;
	__u64 rx_errors;
	__u64 tx_errors;
	__u64 rx_dropped;
	__u64 tx_dropped;
	__u64 multicast;
	__u64 collisions;
	__u64 rx_length_errors;
	__u64 rx_over_errors;
	__u64 rx_crc_errors;
	__u64 rx_frame_errors;
	__u64 rx_fifo_errors;
	__u64 rx_missed_errors;
	__u64 tx_aborted_errors;
	__u64 tx_carrier_errors;
	__u64 tx_fifo_errors;
	__u64 tx_heartbeat_errors;
	__u64 tx_window_errors;
	__u64 rx_compressed;
	__u64 tx_compressed;
	__u64 rx_nohandler;
	char __rh_tail[0];
	__u64 __rh_reserved_1;
	__u64 __rh_reserved_2;
	__u64 __rh_reserved_3;
	__u64 __rh_reserved_4;
};

struct ifla_vf_stats {
	__u64 rx_packets;
	__u64 tx_packets;
	__u64 rx_bytes;
	__u64 tx_bytes;
	__u64 broadcast;
	__u64 multicast;
	__u64 rx_dropped;
	__u64 tx_dropped;
};

struct ifla_vf_info {
	__u32 vf;
	__u8 mac[32];
	__u32 vlan;
	__u32 qos;
	__u32 spoofchk;
	__u32 linkstate;
	__u32 min_tx_rate;
	__u32 max_tx_rate;
	__u32 rss_query_en;
	__u32 trusted;
	__be16 vlan_proto;
};

struct tc_stats {
	__u64 bytes;
	__u32 packets;
	__u32 drops;
	__u32 overlimits;
	__u32 bps;
	__u32 pps;
	__u32 qlen;
	__u32 backlog;
};

struct tc_sizespec {
	unsigned char cell_log;
	unsigned char size_log;
	short int cell_align;
	int overhead;
	unsigned int linklayer;
	unsigned int mpu;
	unsigned int mtu;
	unsigned int tsize;
};

enum netdev_tx {
	__NETDEV_TX_MIN = 2147483648,
	NETDEV_TX_OK = 0,
	NETDEV_TX_BUSY = 16,
};

typedef enum netdev_tx netdev_tx_t;

struct header_ops {
	int (*create)(struct sk_buff *, struct net_device *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff *, unsigned char *);
	int (*cache)(const struct neighbour *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct_extended_rh {};

struct napi_struct {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct *, int);
	int poll_owner;
	struct net_device *dev;
	struct sk_buff *gro_list;
	struct sk_buff *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct xdp_umem;

struct netdev_queue {
	struct net_device *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___2 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide44;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct net_rate_estimator;

struct qdisc_skb_head {
	struct sk_buff *head;
	struct sk_buff *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct gnet_stats_basic_packed {
	__u64 bytes;
	__u32 packets;
} __attribute__((packed));

struct gnet_stats_queue {
	__u32 qlen;
	__u32 backlog;
	__u32 drops;
	__u32 requeues;
	__u32 overlimits;
};

struct Qdisc_ops;

struct qdisc_size_table;

struct gnet_stats_basic_cpu;

struct Qdisc {
	int (*enqueue)(struct sk_buff *, struct Qdisc *, struct sk_buff **);
	struct sk_buff * (*dequeue)(struct Qdisc *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head gso_skb;
	struct qdisc_skb_head q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc *next_sched;
	struct sk_buff_head skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rps_map {
	unsigned int len;
	struct callback_head rcu;
	u16 cpus[0];
};

struct rps_dev_flow {
	u16 cpu;
	u16 filter;
	unsigned int last_qtail;
};

struct rps_dev_flow_table {
	unsigned int mask;
	struct callback_head rcu;
	struct rps_dev_flow flows[0];
};

struct rps_sock_flow_table {
	u32 mask;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ents[0];
};

struct netdev_rx_queue {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___2 kobj;
	struct net_device *dev;
	long: 64;
	struct xdp_rxq_info xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide45;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct xps_map {
	unsigned int len;
	unsigned int alloc_len;
	struct callback_head rcu;
	u16 queues[0];
};

struct xps_dev_maps {
	struct callback_head rcu;
	struct xps_map *attr_map[0];
};

struct netdev_phys_item_id {
	unsigned char id[32];
	unsigned char id_len;
};

typedef u16 (*select_queue_fallback_t)(struct net_device *, struct sk_buff *, struct net_device *);

enum tc_setup_type {
	TC_SETUP_QDISC_MQPRIO = 0,
	TC_SETUP_CLSU32 = 1,
	TC_SETUP_CLSFLOWER = 2,
	TC_SETUP_CLSMATCHALL = 3,
	TC_SETUP_CLSBPF = 4,
	TC_SETUP_BLOCK = 5,
	TC_SETUP_QDISC_CBS = 6,
	TC_SETUP_QDISC_RED = 7,
	TC_SETUP_QDISC_PRIO = 8,
	TC_SETUP_QDISC_MQ = 9,
	TC_SETUP_QDISC_ETF = 10,
	TC_SETUP_ROOT_QDISC = 11,
	TC_SETUP_QDISC_GRED = 12,
};

enum bpf_netdev_command {
	XDP_SETUP_PROG = 0,
	XDP_SETUP_PROG_HW = 1,
	XDP_QUERY_PROG = 2,
	XDP_QUERY_PROG_HW = 3,
	BPF_OFFLOAD_VERIFIER_PREP = 4,
	BPF_OFFLOAD_TRANSLATE = 5,
	BPF_OFFLOAD_DESTROY = 6,
	BPF_OFFLOAD_MAP_ALLOC = 7,
	BPF_OFFLOAD_MAP_FREE = 8,
	XDP_QUERY_XSK_UMEM = 9,
	XDP_SETUP_XSK_UMEM = 10,
};

struct netdev_bpf {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog *prog;
			const struct bpf_prog_offload_ops *ops;
		} verifier;
		struct {
			struct bpf_prog *prog;
		} offload;
		struct {
			struct bpf_offloaded_map *offmap;
		};
		struct {
			struct xdp_umem *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops_extended_rh {};

struct xfrmdev_ops {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

enum tls_offload_ctx_dir {
	TLS_OFFLOAD_CTX_DIR_RX = 0,
	TLS_OFFLOAD_CTX_DIR_TX = 1,
};

struct tlsdev_ops_extended_rh {};

struct tls_crypto_info;

struct tls_context;

struct tlsdev_ops {
	int (*tls_dev_add)(struct net_device *, struct sock *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device *, struct sock *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide46;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct dev_ifalias {
	struct callback_head rcuhead;
	char ifalias[0];
};

struct net_device_ops_extended_rh {};

struct udp_tunnel_info;

struct net_device_ops {
	int (*ndo_init)(struct net_device *);
	void (*ndo_uninit)(struct net_device *);
	int (*ndo_open)(struct net_device *);
	int (*ndo_stop)(struct net_device *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff *, struct net_device *);
	netdev_features_t (*ndo_features_check)(struct sk_buff *, struct net_device *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device *, struct sk_buff *, struct net_device *, select_queue_fallback_t);
	void (*ndo_change_rx_flags)(struct net_device *, int);
	void (*ndo_set_rx_mode)(struct net_device *);
	int (*ndo_set_mac_address)(struct net_device *, void *);
	int (*ndo_validate_addr)(struct net_device *);
	int (*ndo_do_ioctl)(struct net_device *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device *, int);
	int (*ndo_neigh_setup)(struct net_device *, struct neigh_parms *);
	void (*ndo_tx_timeout)(struct net_device *);
	void (*ndo_get_stats64)(struct net_device *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device *);
	int (*ndo_vlan_rx_add_vid)(struct net_device *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device *);
	int (*ndo_netpoll_setup)(struct net_device *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device *);
	int (*ndo_set_vf_mac)(struct net_device *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device *, int, bool);
	int (*ndo_get_vf_config)(struct net_device *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device *, int, int);
	int (*ndo_get_vf_stats)(struct net_device *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device *, int, struct sk_buff *);
	int (*ndo_set_vf_guid)(struct net_device *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device *, int, bool);
	int (*ndo_setup_tc)(struct net_device *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device *, const struct sk_buff *, u16, u32);
	int (*ndo_add_slave)(struct net_device *, struct net_device *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device *, struct net_device *);
	netdev_features_t (*ndo_fix_features)(struct net_device *, netdev_features_t);
	int (*ndo_set_features)(struct net_device *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device *, struct neighbour *);
	void (*ndo_neigh_destroy)(struct net_device *, struct neighbour *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide47;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff *, struct netlink_callback *, struct net_device *, struct net_device *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide48;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff *, u32, u32, struct net_device *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device *, bool);
	int (*ndo_get_phys_port_id)(struct net_device *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device *, struct net_device *);
	void (*ndo_dfwd_del_station)(struct net_device *, void *);
	int (*ndo_get_lock_subclass)(struct net_device *);
	int (*ndo_set_tx_maxrate)(struct net_device *, int, u32);
	int (*ndo_get_iflink)(const struct net_device *);
	int (*ndo_change_proto_down)(struct net_device *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device *, struct sk_buff *);
	void (*ndo_set_rx_headroom)(struct net_device *, int);
	int (*ndo_bpf)(struct net_device *, struct netdev_bpf *);
	int (*ndo_xdp_xmit)(struct net_device *, int, struct xdp_frame **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide49;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms {
	possible_net_t net;
	struct net_device *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour *);
	void (*neigh_cleanup)(struct neighbour *);
	struct neigh_table *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct net_device_extended_rh {};

struct pcpu_lstats {
	u64 packets;
	u64 bytes;
	struct u64_stats_sync syncp;
};

struct pcpu_sw_netstats {
	u64 rx_packets;
	u64 rx_bytes;
	u64 tx_packets;
	u64 tx_bytes;
	struct u64_stats_sync syncp;
};

struct switchdev_ops_extended_rh {};

struct net_device___3;

struct switchdev_attr;

struct switchdev_trans;

struct switchdev_obj;

struct switchdev_ops {
	int (*switchdev_port_attr_get)(struct net_device___3 *, struct switchdev_attr *);
	int (*switchdev_port_attr_set)(struct net_device___3 *, const struct switchdev_attr *, struct switchdev_trans *);
	int (*rh_reserved_switchdev_port_obj_add)(struct net_device___3 *, const struct switchdev_obj *, struct switchdev_trans *);
	int (*rh_reserved_switchdev_port_obj_del)(struct net_device___3 *, const struct switchdev_obj *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t switchdev_ops_extended_size_rh;
	struct switchdev_ops_extended_rh switchdev_ops_extended_rh;
};

struct l3mdev_ops_extended_rh {};

struct l3mdev_ops {
	u32 (*l3mdev_fib_table)(const struct net_device *);
	struct sk_buff * (*l3mdev_l3_rcv)(struct net_device *, struct sk_buff *, u16);
	struct sk_buff * (*l3mdev_l3_out)(struct net_device *, struct sock *, struct sk_buff *, u16);
	struct dst_entry * (*l3mdev_link_scope_lookup)(const struct net_device *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct nd_opt_hdr;

struct ndisc_options;

struct prefix_info;

struct ndisc_ops {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device *, struct neighbour *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device *, u8, struct neighbour *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device *, struct sk_buff *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___2 *, struct net_device *, const struct prefix_info *, struct inet6_dev *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ipv6_devstat {
	struct proc_dir_entry *proc_dir_entry;
	struct ipstats_mib *ipv6;
	struct icmpv6_mib_device *icmpv6dev;
	struct icmpv6msg_mib_device *icmpv6msgdev;
};

struct ifmcaddr6;

struct ifacaddr6;

struct inet6_dev {
	struct net_device *dev;
	struct list_head addr_list;
	struct ifmcaddr6 *mc_list;
	struct ifmcaddr6 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	u8 rndid[8];
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
};

struct tcf_proto;

struct mini_Qdisc {
	struct tcf_proto *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops_extended_rh {};

struct rtnl_link_ops {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___2 *, struct net_device *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device *, struct list_head *);
	size_t (*get_size)(const struct net_device *);
	int (*fill_info)(struct sk_buff *, const struct net_device *);
	size_t (*get_xstats_size)(const struct net_device *);
	int (*fill_xstats)(struct sk_buff *, const struct net_device *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device *, struct net_device *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device *, const struct net_device *);
	int (*fill_slave_info)(struct sk_buff *, const struct net_device *, const struct net_device *);
	struct net___2 * (*get_link_net)(const struct net_device *);
	size_t (*get_linkxstats_size)(const struct net_device *, int);
	int (*fill_linkxstats)(struct sk_buff *, const struct net_device *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct sd_flow_limit {
	u64 count;
	unsigned int num_buckets;
	unsigned int history_head;
	u16 history[128];
	u8 buckets[0];
};

struct softnet_data {
	struct list_head poll_list;
	struct sk_buff_head process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc *output_queue;
	struct Qdisc **output_queue_tailp;
	struct sk_buff *completion_queue;
	struct sk_buff_head xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head input_pkt_queue;
	struct napi_struct backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

enum {
	RTAX_UNSPEC = 0,
	RTAX_LOCK = 1,
	RTAX_MTU = 2,
	RTAX_WINDOW = 3,
	RTAX_RTT = 4,
	RTAX_RTTVAR = 5,
	RTAX_SSTHRESH = 6,
	RTAX_CWND = 7,
	RTAX_ADVMSS = 8,
	RTAX_REORDERING = 9,
	RTAX_HOPLIMIT = 10,
	RTAX_INITCWND = 11,
	RTAX_FEATURES = 12,
	RTAX_RTO_MIN = 13,
	RTAX_INITRWND = 14,
	RTAX_QUICKACK = 15,
	RTAX_CC_ALGO = 16,
	RTAX_FASTOPEN_NO_COOKIE = 17,
	__RTAX_MAX = 18,
};

struct tcmsg {
	unsigned char tcm_family;
	unsigned char tcm__pad1;
	short unsigned int tcm__pad2;
	int tcm_ifindex;
	__u32 tcm_handle;
	__u32 tcm_parent;
	__u32 tcm_info;
};

struct gnet_stats_basic_cpu {
	struct gnet_stats_basic_packed bstats;
	struct u64_stats_sync syncp;
} __attribute__((packed));

struct gnet_dump {
	spinlock_t *lock;
	struct sk_buff *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct nla_policy {
	u16 type;
	u16 len;
	const void *validation_data;
};

typedef int tc_setup_cb_t(enum tc_setup_type, void *, void *);

struct qdisc_size_table {
	struct callback_head rcu;
	struct list_head list;
	struct tc_sizespec szopts;
	int refcnt;
	u16 data[0];
};

struct Qdisc_class_ops;

struct Qdisc_ops {
	struct Qdisc_ops *next;
	const struct Qdisc_class_ops *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff *, struct Qdisc *, struct sk_buff **);
	struct sk_buff * (*dequeue)(struct Qdisc *);
	struct sk_buff * (*peek)(struct Qdisc *);
	int (*init)(struct Qdisc *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc *);
	void (*destroy)(struct Qdisc *);
	int (*change)(struct Qdisc *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc *);
	int (*change_tx_queue_len)(struct Qdisc *, unsigned int);
	int (*dump)(struct Qdisc *, struct sk_buff *);
	int (*dump_stats)(struct Qdisc *, struct gnet_dump *);
	void (*ingress_block_set)(struct Qdisc *, u32);
	void (*egress_block_set)(struct Qdisc *, u32);
	u32 (*ingress_block_get)(struct Qdisc *);
	u32 (*egress_block_get)(struct Qdisc *);
	struct module___3 *owner;
};

struct qdisc_walker;

struct tcf_block;

struct Qdisc_class_ops {
	unsigned int flags;
	struct netdev_queue * (*select_queue)(struct Qdisc *, struct tcmsg *);
	int (*graft)(struct Qdisc *, long unsigned int, struct Qdisc *, struct Qdisc **, struct netlink_ext_ack *);
	struct Qdisc * (*leaf)(struct Qdisc *, long unsigned int);
	void (*qlen_notify)(struct Qdisc *, long unsigned int);
	long unsigned int (*find)(struct Qdisc *, u32);
	int (*change)(struct Qdisc *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc *, long unsigned int);
	void (*walk)(struct Qdisc *, struct qdisc_walker *);
	struct tcf_block * (*tcf_block)(struct Qdisc *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc *, long unsigned int);
	int (*dump)(struct Qdisc *, long unsigned int, struct sk_buff *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc *, long unsigned int, struct gnet_dump *);
};

struct tcf_chain;

struct tcf_block {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___2 *net;
	struct Qdisc *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result;

struct tcf_proto_ops;

struct tcf_proto {
	struct tcf_proto *next;
	void *root;
	int (*classify)(struct sk_buff *, const struct tcf_proto *, struct tcf_result *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops *ops;
	struct tcf_chain *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_walker;

struct tcf_proto_ops {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff *, const struct tcf_proto *, struct tcf_result *);
	int (*init)(struct tcf_proto *);
	void (*destroy)(struct tcf_proto *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto *, u32);
	void (*put)(struct tcf_proto *, void *);
	int (*change)(struct net___2 *, struct sk_buff *, struct tcf_proto *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___2 *, struct tcf_chain *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___2 *, struct tcf_proto *, void *, struct sk_buff *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff *, struct net___2 *, void *);
	struct module___3 *owner;
	int flags;
};

struct tcf_chain {
	struct mutex filter_chain_lock;
	struct tcf_proto *filter_chain;
	struct list_head list;
	struct tcf_block *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sock_fprog_kern {
	u16 len;
	struct sock_filter *filter;
};

struct sk_filter {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog *prog;
};

struct bpf_redirect_info {
	u32 ifindex;
	u32 flags;
	struct bpf_map___2 *map;
	struct bpf_map___2 *map_to_flush;
	u32 kern_flags;
};

enum {
	NEIGH_VAR_MCAST_PROBES = 0,
	NEIGH_VAR_UCAST_PROBES = 1,
	NEIGH_VAR_APP_PROBES = 2,
	NEIGH_VAR_MCAST_REPROBES = 3,
	NEIGH_VAR_RETRANS_TIME = 4,
	NEIGH_VAR_BASE_REACHABLE_TIME = 5,
	NEIGH_VAR_DELAY_PROBE_TIME = 6,
	NEIGH_VAR_GC_STALETIME = 7,
	NEIGH_VAR_QUEUE_LEN_BYTES = 8,
	NEIGH_VAR_PROXY_QLEN = 9,
	NEIGH_VAR_ANYCAST_DELAY = 10,
	NEIGH_VAR_PROXY_DELAY = 11,
	NEIGH_VAR_LOCKTIME = 12,
	NEIGH_VAR_QUEUE_LEN = 13,
	NEIGH_VAR_RETRANS_TIME_MS = 14,
	NEIGH_VAR_BASE_REACHABLE_TIME_MS = 15,
	NEIGH_VAR_GC_INTERVAL = 16,
	NEIGH_VAR_GC_THRESH1 = 17,
	NEIGH_VAR_GC_THRESH2 = 18,
	NEIGH_VAR_GC_THRESH3 = 19,
	NEIGH_VAR_MAX = 20,
};

struct pneigh_entry;

struct neigh_statistics;

struct neigh_hash_table;

struct neigh_table {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device *, __u32 *);
	bool (*key_eq)(const struct neighbour *, const void *);
	int (*constructor)(struct neighbour *);
	int (*pconstructor)(struct pneigh_entry *);
	void (*pdestructor)(struct pneigh_entry *);
	void (*proxy_redo)(struct sk_buff *);
	char *id;
	struct neigh_parms parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table *nht;
	struct pneigh_entry **phash_buckets;
};

struct neigh_statistics {
	long unsigned int allocs;
	long unsigned int destroys;
	long unsigned int hash_grows;
	long unsigned int res_failed;
	long unsigned int lookups;
	long unsigned int hits;
	long unsigned int rcv_probes_mcast;
	long unsigned int rcv_probes_ucast;
	long unsigned int periodic_gc_runs;
	long unsigned int forced_gc_runs;
	long unsigned int unres_discards;
	long unsigned int table_fulls;
};

struct neigh_ops {
	int family;
	void (*solicit)(struct neighbour *, struct sk_buff *);
	void (*error_report)(struct neighbour *, struct sk_buff *);
	int (*output)(struct neighbour *, struct sk_buff *);
	int (*connected_output)(struct neighbour *, struct sk_buff *);
};

struct pneigh_entry {
	struct pneigh_entry *next;
	possible_net_t net;
	struct net_device *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table {
	struct neighbour **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct dst_metrics {
	u32 metrics[17];
	refcount_t refcnt;
};

enum {
	TCP_ESTABLISHED = 1,
	TCP_SYN_SENT = 2,
	TCP_SYN_RECV = 3,
	TCP_FIN_WAIT1 = 4,
	TCP_FIN_WAIT2 = 5,
	TCP_TIME_WAIT = 6,
	TCP_CLOSE = 7,
	TCP_CLOSE_WAIT = 8,
	TCP_LAST_ACK = 9,
	TCP_LISTEN = 10,
	TCP_CLOSING = 11,
	TCP_NEW_SYN_RECV = 12,
	TCP_MAX_STATES = 13,
};

struct smc_hashinfo {
	rwlock_t lock;
	struct hlist_head ht;
};

struct fib_rule_hdr {
	__u8 family;
	__u8 dst_len;
	__u8 src_len;
	__u8 tos;
	__u8 table;
	__u8 res1;
	__u8 res2;
	__u8 action;
	__u32 flags;
};

struct fib_rule_port_range {
	__u16 start;
	__u16 end;
};

struct fib_kuid_range {
	kuid_t start;
	kuid_t end;
};

struct fib_rule {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule *ctarget;
	struct net___2 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule *rule;
	u32 table;
	int flags;
};

struct request_sock_ops;

struct timewait_sock_ops;

struct udp_table;

struct raw_hashinfo;

struct proto {
	void (*close)(struct sock *, long int);
	int (*pre_connect)(struct sock *, struct sockaddr *, int);
	int (*connect)(struct sock *, struct sockaddr *, int);
	int (*disconnect)(struct sock *, int);
	struct sock * (*accept)(struct sock *, int, int *, bool);
	int (*ioctl)(struct sock *, int, long unsigned int);
	int (*init)(struct sock *);
	void (*destroy)(struct sock *);
	void (*shutdown)(struct sock *, int);
	int (*setsockopt)(struct sock *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock *, int, int, char *, int *);
	void (*keepalive)(struct sock *, int);
	int (*sendmsg)(struct sock *, struct msghdr *, size_t);
	int (*recvmsg)(struct sock *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock *, struct page___4 *, int, size_t, int);
	int (*bind)(struct sock *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock *, struct sk_buff *);
	void (*release_cb)(struct sock *);
	int (*hash)(struct sock *);
	void (*unhash)(struct sock *);
	void (*rehash)(struct sock *);
	int (*get_port)(struct sock *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock *);
	bool (*stream_memory_read)(const struct sock *);
	void (*enter_memory_pressure)(struct sock *);
	void (*leave_memory_pressure)(struct sock *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops *rsk_prot;
	struct timewait_sock_ops *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___3 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct request_sock;

struct request_sock_ops {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock *, struct request_sock *);
	void (*send_ack)(const struct sock *, struct sk_buff *, struct request_sock *);
	void (*send_reset)(const struct sock *, struct sk_buff *);
	void (*destructor)(struct request_sock *);
	void (*syn_ack_timeout)(const struct request_sock *);
};

struct timewait_sock_ops {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock *, struct sock *, void *);
	void (*twsk_destructor)(struct sock *);
};

struct request_sock {
	struct sock_common __req_common;
	struct request_sock *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops *rsk_ops;
	struct sock *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

enum tsq_enum {
	TSQ_THROTTLED = 0,
	TSQ_QUEUED = 1,
	TCP_TSQ_DEFERRED = 2,
	TCP_WRITE_TIMER_DEFERRED = 3,
	TCP_DELACK_TIMER_DEFERRED = 4,
	TCP_MTU_REDUCED_DEFERRED = 5,
};

struct ip6_sf_list {
	struct ip6_sf_list *sf_next;
	struct in6_addr sf_addr;
	long unsigned int sf_count[2];
	unsigned char sf_gsresp;
	unsigned char sf_oldin;
	unsigned char sf_crcount;
};

struct ifmcaddr6 {
	struct in6_addr mca_addr;
	struct inet6_dev *idev;
	struct ifmcaddr6 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6 {
	struct in6_addr aca_addr;
	struct fib6_info *aca_rt;
	struct ifacaddr6 *aca_next;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

enum {
	__ND_OPT_PREFIX_INFO_END = 0,
	ND_OPT_SOURCE_LL_ADDR = 1,
	ND_OPT_TARGET_LL_ADDR = 2,
	ND_OPT_PREFIX_INFO = 3,
	ND_OPT_REDIRECT_HDR = 4,
	ND_OPT_MTU = 5,
	ND_OPT_NONCE = 14,
	__ND_OPT_ARRAY_MAX = 15,
	ND_OPT_ROUTE_INFO = 24,
	ND_OPT_RDNSS = 25,
	ND_OPT_DNSSL = 31,
	ND_OPT_6CO = 34,
	__ND_OPT_MAX = 35,
};

struct nd_opt_hdr {
	__u8 nd_opt_type;
	__u8 nd_opt_len;
};

struct ndisc_options {
	struct nd_opt_hdr *nd_opt_array[15];
	struct nd_opt_hdr *nd_opts_ri;
	struct nd_opt_hdr *nd_opts_ri_end;
	struct nd_opt_hdr *nd_useropts;
	struct nd_opt_hdr *nd_useropts_end;
};

struct prefix_info {
	__u8 type;
	__u8 length;
	__u8 prefix_len;
	__u8 reserved: 6;
	__u8 autoconf: 1;
	__u8 onlink: 1;
	__be32 valid;
	__be32 prefered;
	__be32 reserved2;
	struct in6_addr prefix;
};

struct ip6_ra_chain {
	struct ip6_ra_chain *next;
	struct sock *sk;
	int sel;
	void (*destructor)(struct sock *);
};

struct rpc_xprt_iter_ops {
	void (*xpi_rewind)(struct rpc_xprt_iter *);
	struct rpc_xprt * (*xpi_xprt)(struct rpc_xprt_iter *);
	struct rpc_xprt * (*xpi_next)(struct rpc_xprt_iter *);
};

struct rpc_version {
	u32 number;
	unsigned int nrprocs;
	const struct rpc_procinfo *procs;
	unsigned int *counts;
};

struct nfs_fh {
	short unsigned int size;
	unsigned char data[128];
};

enum nfs3_stable_how {
	NFS_UNSTABLE = 0,
	NFS_DATA_SYNC = 1,
	NFS_FILE_SYNC = 2,
	NFS_INVALID_STABLE_HOW = 4294967295,
};

struct nfs4_label {
	uint32_t lfs;
	uint32_t pi;
	u32 len;
	char *label;
};

typedef struct {
	char data[8];
} nfs4_verifier;

struct nfs4_stateid_struct {
	union {
		char data[16];
		struct {
			__be32 seqid;
			char other[12];
		};
	};
	enum {
		NFS4_INVALID_STATEID_TYPE = 0,
		NFS4_SPECIAL_STATEID_TYPE = 1,
		NFS4_OPEN_STATEID_TYPE = 2,
		NFS4_LOCK_STATEID_TYPE = 3,
		NFS4_DELEGATION_STATEID_TYPE = 4,
		NFS4_LAYOUT_STATEID_TYPE = 5,
		NFS4_PNFS_DS_STATEID_TYPE = 6,
		NFS4_REVOKED_STATEID_TYPE = 7,
	} type;
};

typedef struct nfs4_stateid_struct nfs4_stateid;

enum nfs_opnum4 {
	OP_ACCESS = 3,
	OP_CLOSE = 4,
	OP_COMMIT = 5,
	OP_CREATE = 6,
	OP_DELEGPURGE = 7,
	OP_DELEGRETURN = 8,
	OP_GETATTR = 9,
	OP_GETFH = 10,
	OP_LINK = 11,
	OP_LOCK = 12,
	OP_LOCKT = 13,
	OP_LOCKU = 14,
	OP_LOOKUP = 15,
	OP_LOOKUPP = 16,
	OP_NVERIFY = 17,
	OP_OPEN = 18,
	OP_OPENATTR = 19,
	OP_OPEN_CONFIRM = 20,
	OP_OPEN_DOWNGRADE = 21,
	OP_PUTFH = 22,
	OP_PUTPUBFH = 23,
	OP_PUTROOTFH = 24,
	OP_READ = 25,
	OP_READDIR = 26,
	OP_READLINK = 27,
	OP_REMOVE = 28,
	OP_RENAME = 29,
	OP_RENEW = 30,
	OP_RESTOREFH = 31,
	OP_SAVEFH = 32,
	OP_SECINFO = 33,
	OP_SETATTR = 34,
	OP_SETCLIENTID = 35,
	OP_SETCLIENTID_CONFIRM = 36,
	OP_VERIFY = 37,
	OP_WRITE = 38,
	OP_RELEASE_LOCKOWNER = 39,
	OP_BACKCHANNEL_CTL = 40,
	OP_BIND_CONN_TO_SESSION = 41,
	OP_EXCHANGE_ID = 42,
	OP_CREATE_SESSION = 43,
	OP_DESTROY_SESSION = 44,
	OP_FREE_STATEID = 45,
	OP_GET_DIR_DELEGATION = 46,
	OP_GETDEVICEINFO = 47,
	OP_GETDEVICELIST = 48,
	OP_LAYOUTCOMMIT = 49,
	OP_LAYOUTGET = 50,
	OP_LAYOUTRETURN = 51,
	OP_SECINFO_NO_NAME = 52,
	OP_SEQUENCE = 53,
	OP_SET_SSV = 54,
	OP_TEST_STATEID = 55,
	OP_WANT_DELEGATION = 56,
	OP_DESTROY_CLIENTID = 57,
	OP_RECLAIM_COMPLETE = 58,
	OP_ALLOCATE = 59,
	OP_COPY = 60,
	OP_COPY_NOTIFY = 61,
	OP_DEALLOCATE = 62,
	OP_IO_ADVISE = 63,
	OP_LAYOUTERROR = 64,
	OP_LAYOUTSTATS = 65,
	OP_OFFLOAD_CANCEL = 66,
	OP_OFFLOAD_STATUS = 67,
	OP_READ_PLUS = 68,
	OP_SEEK = 69,
	OP_WRITE_SAME = 70,
	OP_CLONE = 71,
	OP_ILLEGAL = 10044,
};

struct nfs4_string {
	unsigned int len;
	char *data;
};

struct nfs_fsid {
	uint64_t major;
	uint64_t minor;
};

struct nfs4_threshold {
	__u32 bm;
	__u32 l_type;
	__u64 rd_sz;
	__u64 wr_sz;
	__u64 rd_io_sz;
	__u64 wr_io_sz;
};

struct nfs_fattr {
	unsigned int valid;
	umode_t mode;
	__u32 nlink;
	kuid_t uid;
	kgid_t gid;
	dev_t rdev;
	__u64 size;
	union {
		struct {
			__u32 blocksize;
			__u32 blocks;
		} nfs2;
		struct {
			__u64 used;
		} nfs3;
	} du;
	struct nfs_fsid fsid;
	__u64 fileid;
	__u64 mounted_on_fileid;
	struct timespec atime;
	struct timespec mtime;
	struct timespec ctime;
	__u64 change_attr;
	__u64 pre_change_attr;
	__u64 pre_size;
	struct timespec pre_mtime;
	struct timespec pre_ctime;
	long unsigned int time_start;
	long unsigned int gencount;
	struct nfs4_string *owner_name;
	struct nfs4_string *group_name;
	struct nfs4_threshold *mdsthreshold;
};

struct nfs_fsinfo {
	struct nfs_fattr *fattr;
	__u32 rtmax;
	__u32 rtpref;
	__u32 rtmult;
	__u32 wtmax;
	__u32 wtpref;
	__u32 wtmult;
	__u32 dtpref;
	__u64 maxfilesize;
	struct timespec time_delta;
	__u32 lease_time;
	__u32 nlayouttypes;
	__u32 layouttype[8];
	__u32 blksize;
	__u32 clone_blksize;
};

struct nfs_fsstat {
	struct nfs_fattr *fattr;
	__u64 tbytes;
	__u64 fbytes;
	__u64 abytes;
	__u64 tfiles;
	__u64 ffiles;
	__u64 afiles;
};

struct nfs_pathconf {
	struct nfs_fattr *fattr;
	__u32 max_link;
	__u32 max_namelen;
};

struct nfs4_change_info {
	u32 atomic;
	u64 before;
	u64 after;
};

struct nfs4_slot;

struct nfs4_sequence_args {
	struct nfs4_slot *sa_slot;
	u8 sa_cache_this: 1;
	u8 sa_privileged: 1;
};

struct nfs4_sequence_res {
	struct nfs4_slot *sr_slot;
	long unsigned int sr_timestamp;
	int sr_status;
	u32 sr_status_flags;
	u32 sr_highest_slotid;
	u32 sr_target_highest_slotid;
};

struct nfs_open_context;

struct nfs_lock_context {
	refcount_t count;
	struct list_head list;
	struct nfs_open_context *open_context;
	fl_owner_t lockowner;
	atomic_t io_count;
};

struct nfs4_state;

struct nfs_open_context {
	struct nfs_lock_context lock_context;
	fl_owner_t flock_owner;
	struct dentry___3 *dentry;
	struct rpc_cred *cred;
	struct nfs4_state *state;
	fmode_t mode;
	long unsigned int flags;
	int error;
	struct list_head list;
	struct nfs4_threshold *mdsthreshold;
};

struct nlm_host;

struct nfs_iostats;

struct nfs_auth_info {
	unsigned int flavor_len;
	rpc_authflavor_t flavors[12];
};

struct nfs_fscache_key;

struct fscache_cookie;

struct pnfs_layoutdriver_type;

struct nfs_client;

struct nfs_server {
	struct nfs_client *nfs_client;
	struct list_head client_link;
	struct list_head master_link;
	struct rpc_clnt *client;
	struct rpc_clnt *client_acl;
	struct nlm_host *nlm_host;
	struct nfs_iostats *io_stats;
	atomic_long_t writeback;
	int flags;
	unsigned int caps;
	unsigned int rsize;
	unsigned int rpages;
	unsigned int wsize;
	unsigned int wpages;
	unsigned int wtmult;
	unsigned int dtsize;
	short unsigned int port;
	unsigned int bsize;
	unsigned int acregmin;
	unsigned int acregmax;
	unsigned int acdirmin;
	unsigned int acdirmax;
	unsigned int namelen;
	unsigned int options;
	unsigned int clone_blksize;
	struct nfs_fsid fsid;
	__u64 maxfilesize;
	struct timespec time_delta;
	long unsigned int mount_time;
	struct super_block___3 *super;
	dev_t s_dev;
	struct nfs_auth_info auth_info;
	struct nfs_fscache_key *fscache_key;
	struct fscache_cookie *fscache;
	u32 pnfs_blksize;
	u32 attr_bitmask[3];
	u32 attr_bitmask_nl[3];
	u32 exclcreat_bitmask[3];
	u32 cache_consistency_bitmask[3];
	u32 acl_bitmask;
	u32 fh_expire_type;
	struct pnfs_layoutdriver_type *pnfs_curr_ld;
	struct rpc_wait_queue roc_rpcwaitq;
	void *pnfs_ld_data;
	struct rb_root state_owners;
	struct ida openowner_id;
	struct ida lockowner_id;
	struct list_head state_owners_lru;
	struct list_head layouts;
	struct list_head delegations;
	long unsigned int mig_gen;
	long unsigned int mig_status;
	void (*destroy)(struct nfs_server *);
	atomic_t active;
	int: 32;
	struct __kernel_sockaddr_storage mountd_address;
	size_t mountd_addrlen;
	u32 mountd_version;
	short unsigned int mountd_port;
	short unsigned int mountd_protocol;
	struct rpc_wait_queue uoc_rpcwaitq;
};

struct nfs_subversion;

struct idmap;

struct nfs4_minor_version_ops;

struct nfs4_slot_table;

struct nfs4_session;

struct nfs_rpc_ops;

struct nfs41_server_owner;

struct nfs41_server_scope;

struct nfs41_impl_id;

struct nfs_client {
	refcount_t cl_count;
	atomic_t cl_mds_count;
	seqcount_t cl_callback_count;
	int cl_cons_state;
	long unsigned int cl_res_state;
	long unsigned int cl_flags;
	struct __kernel_sockaddr_storage cl_addr;
	size_t cl_addrlen;
	char *cl_hostname;
	char *cl_acceptor;
	struct list_head cl_share_link;
	struct list_head cl_superblocks;
	struct rpc_clnt *cl_rpcclient;
	const struct nfs_rpc_ops *rpc_ops;
	int cl_proto;
	struct nfs_subversion *cl_nfs_mod;
	u32 cl_minorversion;
	struct rpc_cred *cl_machine_cred;
	struct list_head cl_ds_clients;
	u64 cl_clientid;
	nfs4_verifier cl_confirm;
	long unsigned int cl_state;
	spinlock_t cl_lock;
	long unsigned int cl_lease_time;
	long unsigned int cl_last_renewal;
	struct delayed_work cl_renewd;
	struct rpc_wait_queue cl_rpcwaitq;
	struct idmap *cl_idmap;
	const char *cl_owner_id;
	u32 cl_cb_ident;
	const struct nfs4_minor_version_ops *cl_mvops;
	long unsigned int cl_mig_gen;
	struct nfs4_slot_table *cl_slot_tbl;
	u32 cl_seqid;
	u32 cl_exchange_flags;
	struct nfs4_session *cl_session;
	bool cl_preserve_clid;
	struct nfs41_server_owner *cl_serverowner;
	struct nfs41_server_scope *cl_serverscope;
	struct nfs41_impl_id *cl_implid;
	long unsigned int cl_sp4_flags;
	wait_queue_head_t cl_lock_waitq;
	char cl_ipaddr[48];
	struct fscache_cookie *fscache;
	struct net___2 *cl_net;
};

struct nfs_write_verifier {
	char data[8];
};

struct nfs_writeverf {
	struct nfs_write_verifier verifier;
	enum nfs3_stable_how committed;
};

struct nfs_pgio_args {
	struct nfs4_sequence_args seq_args;
	struct nfs_fh *fh;
	struct nfs_open_context *context;
	struct nfs_lock_context *lock_context;
	nfs4_stateid stateid;
	__u64 offset;
	__u32 count;
	unsigned int pgbase;
	struct page___4 **pages;
	const u32 *bitmask;
	enum nfs3_stable_how stable;
};

struct nfs_pgio_res {
	struct nfs4_sequence_res seq_res;
	struct nfs_fattr *fattr;
	__u32 count;
	__u32 op_status;
	int eof;
	struct nfs_writeverf *verf;
	const struct nfs_server *server;
};

struct nfs_commitargs {
	struct nfs4_sequence_args seq_args;
	struct nfs_fh *fh;
	__u64 offset;
	__u32 count;
	const u32 *bitmask;
};

struct nfs_commitres {
	struct nfs4_sequence_res seq_res;
	__u32 op_status;
	struct nfs_fattr *fattr;
	struct nfs_writeverf *verf;
	const struct nfs_server *server;
};

struct nfs_removeargs {
	struct nfs4_sequence_args seq_args;
	const struct nfs_fh *fh;
	struct qstr name;
};

struct nfs_removeres {
	struct nfs4_sequence_res seq_res;
	struct nfs_server *server;
	struct nfs_fattr *dir_attr;
	struct nfs4_change_info cinfo;
};

struct nfs_renameargs {
	struct nfs4_sequence_args seq_args;
	const struct nfs_fh *old_dir;
	const struct nfs_fh *new_dir;
	const struct qstr *old_name;
	const struct qstr *new_name;
};

struct nfs_renameres {
	struct nfs4_sequence_res seq_res;
	struct nfs_server *server;
	struct nfs4_change_info old_cinfo;
	struct nfs_fattr *old_fattr;
	struct nfs4_change_info new_cinfo;
	struct nfs_fattr *new_fattr;
};

struct nfs_entry {
	__u64 ino;
	__u64 cookie;
	__u64 prev_cookie;
	const char *name;
	unsigned int len;
	int eof;
	struct nfs_fh *fh;
	struct nfs_fattr *fattr;
	struct nfs4_label *label;
	unsigned char d_type;
	struct nfs_server *server;
};

struct nfstime4 {
	u64 seconds;
	u32 nseconds;
};

struct pnfs_layout_segment;

struct pnfs_commit_bucket {
	struct list_head written;
	struct list_head committing;
	struct pnfs_layout_segment *wlseg;
	struct pnfs_layout_segment *clseg;
	struct nfs_writeverf direct_verf;
};

struct pnfs_ds_commit_info {
	int nwritten;
	int ncommitting;
	int nbuckets;
	struct pnfs_commit_bucket *buckets;
};

struct nfs41_server_owner {
	uint64_t minor_id;
	uint32_t major_id_sz;
	char major_id[1024];
};

struct nfs41_server_scope {
	uint32_t server_scope_sz;
	char server_scope[1024];
};

struct nfs41_impl_id {
	char domain[1025];
	char name[1025];
	struct nfstime4 date;
};

struct nfs_page_array {
	struct page___4 **pagevec;
	unsigned int npages;
	struct page___4 *page_array[8];
};

struct nfs_page;

struct nfs_rw_ops;

struct nfs_io_completion;

struct nfs_direct_req;

struct nfs_pgio_completion_ops;

struct nfs_pgio_header {
	struct inode___4 *inode;
	struct rpc_cred *cred;
	struct list_head pages;
	struct nfs_page *req;
	struct nfs_writeverf verf;
	fmode_t rw_mode;
	struct pnfs_layout_segment *lseg;
	loff_t io_start;
	const struct rpc_call_ops *mds_ops;
	void (*release)(struct nfs_pgio_header *);
	const struct nfs_pgio_completion_ops *completion_ops;
	const struct nfs_rw_ops *rw_ops;
	struct nfs_io_completion *io_completion;
	struct nfs_direct_req *dreq;
	spinlock_t lock;
	int pnfs_error;
	int error;
	long unsigned int good_bytes;
	long unsigned int flags;
	struct rpc_task task;
	struct nfs_fattr fattr;
	struct nfs_pgio_args args;
	struct nfs_pgio_res res;
	long unsigned int timestamp;
	int (*pgio_done_cb)(struct rpc_task *, struct nfs_pgio_header *);
	__u64 mds_offset;
	struct nfs_page_array page_array;
	struct nfs_client *ds_clp;
	int ds_commit_idx;
	int pgio_mirror_idx;
};

struct nfs_pgio_completion_ops {
	void (*error_cleanup)(struct list_head *);
	void (*init_hdr)(struct nfs_pgio_header *);
	void (*completion)(struct nfs_pgio_header *);
	void (*reschedule_io)(struct nfs_pgio_header *);
};

struct nfs_mds_commit_info {
	atomic_t rpcs_out;
	atomic_long_t ncommit;
	struct list_head list;
};

struct nfs_commit_data;

struct nfs_commit_info;

struct nfs_commit_completion_ops {
	void (*completion)(struct nfs_commit_data *);
	void (*resched_write)(struct nfs_commit_info *, struct nfs_page *);
};

struct nfs_commit_data {
	struct rpc_task task;
	struct inode___4 *inode;
	struct rpc_cred *cred;
	struct nfs_fattr fattr;
	struct nfs_writeverf verf;
	struct list_head pages;
	struct list_head list;
	struct nfs_direct_req *dreq;
	struct nfs_commitargs args;
	struct nfs_commitres res;
	struct nfs_open_context *context;
	struct pnfs_layout_segment *lseg;
	struct nfs_client *ds_clp;
	int ds_commit_index;
	loff_t lwb;
	const struct rpc_call_ops *mds_ops;
	const struct nfs_commit_completion_ops *completion_ops;
	int (*commit_done_cb)(struct rpc_task *, struct nfs_commit_data *);
	long unsigned int flags;
};

struct nfs_commit_info {
	struct inode___4 *inode;
	struct nfs_mds_commit_info *mds;
	struct pnfs_ds_commit_info *ds;
	struct nfs_direct_req *dreq;
	const struct nfs_commit_completion_ops *completion_ops;
};

struct nfs_unlinkdata {
	struct nfs_removeargs args;
	struct nfs_removeres res;
	struct dentry___3 *dentry;
	wait_queue_head_t wq;
	struct rpc_cred *cred;
	struct nfs_fattr dir_attr;
	long int timeout;
};

struct nfs_renamedata {
	struct nfs_renameargs args;
	struct nfs_renameres res;
	struct rpc_cred *cred;
	struct inode___4 *old_dir;
	struct dentry___3 *old_dentry;
	struct nfs_fattr old_fattr;
	struct inode___4 *new_dir;
	struct dentry___3 *new_dentry;
	struct nfs_fattr new_fattr;
	void (*complete)(struct rpc_task *, struct nfs_renamedata *);
	long int timeout;
	bool cancelled;
};

struct nlmclnt_operations;

struct nfs_mount_info;

struct nfs_client_initdata;

struct nfs_access_entry;

struct nfs_rpc_ops {
	u32 version;
	const struct dentry_operations___2 *dentry_ops;
	const struct inode_operations___2 *dir_inode_ops;
	const struct inode_operations___2 *file_inode_ops;
	const struct file_operations___3 *file_ops;
	const struct nlmclnt_operations *nlmclnt_ops;
	int (*getroot)(struct nfs_server *, struct nfs_fh *, struct nfs_fsinfo *);
	struct vfsmount___2 * (*submount)(struct nfs_server *, struct dentry___3 *, struct nfs_fh *, struct nfs_fattr *);
	struct dentry___3 * (*try_mount)(int, const char *, struct nfs_mount_info *, struct nfs_subversion *);
	int (*getattr)(struct nfs_server *, struct nfs_fh *, struct nfs_fattr *, struct nfs4_label *, struct inode___4 *);
	int (*setattr)(struct dentry___3 *, struct nfs_fattr *, struct iattr___3 *);
	int (*lookup)(struct inode___4 *, const struct qstr *, struct nfs_fh *, struct nfs_fattr *, struct nfs4_label *);
	int (*lookupp)(struct inode___4 *, struct nfs_fh *, struct nfs_fattr *, struct nfs4_label *);
	int (*access)(struct inode___4 *, struct nfs_access_entry *);
	int (*readlink)(struct inode___4 *, struct page___4 *, unsigned int, unsigned int);
	int (*create)(struct inode___4 *, struct dentry___3 *, struct iattr___3 *, int);
	int (*remove)(struct inode___4 *, struct dentry___3 *);
	void (*unlink_setup)(struct rpc_message *, struct dentry___3 *, struct inode___4 *);
	void (*unlink_rpc_prepare)(struct rpc_task *, struct nfs_unlinkdata *);
	int (*unlink_done)(struct rpc_task *, struct inode___4 *);
	void (*rename_setup)(struct rpc_message *, struct dentry___3 *, struct dentry___3 *);
	void (*rename_rpc_prepare)(struct rpc_task *, struct nfs_renamedata *);
	int (*rename_done)(struct rpc_task *, struct inode___4 *, struct inode___4 *);
	int (*link)(struct inode___4 *, struct inode___4 *, const struct qstr *);
	int (*symlink)(struct inode___4 *, struct dentry___3 *, struct page___4 *, unsigned int, struct iattr___3 *);
	int (*mkdir)(struct inode___4 *, struct dentry___3 *, struct iattr___3 *);
	int (*rmdir)(struct inode___4 *, const struct qstr *);
	int (*readdir)(struct dentry___3 *, struct rpc_cred *, u64, struct page___4 **, unsigned int, bool);
	int (*mknod)(struct inode___4 *, struct dentry___3 *, struct iattr___3 *, dev_t);
	int (*statfs)(struct nfs_server *, struct nfs_fh *, struct nfs_fsstat *);
	int (*fsinfo)(struct nfs_server *, struct nfs_fh *, struct nfs_fsinfo *);
	int (*pathconf)(struct nfs_server *, struct nfs_fh *, struct nfs_pathconf *);
	int (*set_capabilities)(struct nfs_server *, struct nfs_fh *);
	int (*decode_dirent)(struct xdr_stream *, struct nfs_entry *, bool);
	int (*pgio_rpc_prepare)(struct rpc_task *, struct nfs_pgio_header *);
	void (*read_setup)(struct nfs_pgio_header *, struct rpc_message *);
	int (*read_done)(struct rpc_task *, struct nfs_pgio_header *);
	void (*write_setup)(struct nfs_pgio_header *, struct rpc_message *, struct rpc_clnt **);
	int (*write_done)(struct rpc_task *, struct nfs_pgio_header *);
	void (*commit_setup)(struct nfs_commit_data *, struct rpc_message *, struct rpc_clnt **);
	void (*commit_rpc_prepare)(struct rpc_task *, struct nfs_commit_data *);
	int (*commit_done)(struct rpc_task *, struct nfs_commit_data *);
	int (*lock)(struct file___3 *, int, struct file_lock___3 *);
	int (*lock_check_bounds)(const struct file_lock___3 *);
	void (*clear_acl_cache)(struct inode___4 *);
	void (*close_context)(struct nfs_open_context *, int);
	struct inode___4 * (*open_context)(struct inode___4 *, struct nfs_open_context *, int, struct iattr___3 *, int *);
	int (*have_delegation)(struct inode___4 *, fmode_t);
	struct nfs_client * (*alloc_client)(const struct nfs_client_initdata *);
	struct nfs_client * (*init_client)(struct nfs_client *, const struct nfs_client_initdata *);
	void (*free_client)(struct nfs_client *);
	struct nfs_server * (*create_server)(struct nfs_mount_info *, struct nfs_subversion *);
	struct nfs_server * (*clone_server)(struct nfs_server *, struct nfs_fh *, struct nfs_fattr *, rpc_authflavor_t);
};

struct nfs_access_entry {
	struct rb_node rb_node;
	struct list_head lru;
	struct rpc_cred *cred;
	__u32 mask;
	struct callback_head callback_head;
};

struct bsg_ops___2 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___3 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___3 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___3 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___2(struct request___3 *, blk_status_t);

struct request___3 {
	struct request_queue___4 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___2 *bio;
	struct bio___2 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___2 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___2 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___2 *saved_end_io;
		} flush;
	};
	struct gendisk___2 *rq_disk;
	struct hd_struct___2 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___2 *end_io;
	void *end_io_data;
	struct request___3 *next_rq;
};

struct elevator_type___2;

struct elevator_mq_ops___2 {
	int (*init_sched)(struct request_queue___4 *, struct elevator_type___2 *);
	void (*exit_sched)(struct elevator_queue___2 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	bool (*allow_merge)(struct request_queue___4 *, struct request___3 *, struct bio___2 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx *, struct bio___2 *);
	int (*request_merge)(struct request_queue___4 *, struct request___3 **, struct bio___2 *);
	void (*request_merged)(struct request_queue___4 *, struct request___3 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___4 *, struct request___3 *, struct request___3 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___3 *, struct bio___2 *);
	void (*finish_request)(struct request___3 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___3 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___3 *, u64);
	void (*started_request)(struct request___3 *);
	void (*requeue_request)(struct request___3 *);
	struct request___3 * (*former_request)(struct request_queue___4 *, struct request___3 *);
	struct request___3 * (*next_request)(struct request_queue___4 *, struct request___3 *);
	void (*init_icq)(struct io_cq___2 *);
	void (*exit_icq)(struct io_cq___2 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide77;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___2;

struct elevator_type___2 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___2 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___2 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___3 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___2 {
	struct elevator_type___2 *type;
	void *elevator_data;
	struct kobject___2 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___2 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___2 *, char *);
	ssize_t (*store)(struct elevator_queue___2 *, const char *, size_t);
};

enum blkg_rwstat_type {
	BLKG_RWSTAT_READ = 0,
	BLKG_RWSTAT_WRITE = 1,
	BLKG_RWSTAT_SYNC = 2,
	BLKG_RWSTAT_ASYNC = 3,
	BLKG_RWSTAT_DISCARD = 4,
	BLKG_RWSTAT_NR = 5,
	BLKG_RWSTAT_TOTAL = 5,
};

struct blkcg_policy_data;

struct blkcg {
	struct cgroup_subsys_state___2 css;
	spinlock_t lock;
	struct xarray blkg_tree;
	struct blkcg_gq *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data *cpd[5];
	struct list_head all_blkcgs_node;
	struct list_head cgwb_list;
	refcount_t cgwb_refcnt;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct blkcg_policy_data {
	struct blkcg *blkcg;
	int plid;
};

struct blkg_policy_data {
	struct blkcg_gq *blkg;
	int plid;
};

struct perf_cpu_context___2;

struct pmu___2 {
	struct list_head entry;
	struct module___3 *module;
	struct device___3 *dev;
	const struct attribute_group___2 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___2 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___2 *);
	void (*pmu_disable)(struct pmu___2 *);
	int (*event_init)(struct perf_event___2 *);
	void (*event_mapped)(struct perf_event___2 *, struct mm_struct___3 *);
	void (*event_unmapped)(struct perf_event___2 *, struct mm_struct___3 *);
	int (*add)(struct perf_event___2 *, int);
	void (*del)(struct perf_event___2 *, int);
	void (*start)(struct perf_event___2 *, int);
	void (*stop)(struct perf_event___2 *, int);
	void (*read)(struct perf_event___2 *);
	void (*start_txn)(struct pmu___2 *, unsigned int);
	int (*commit_txn)(struct pmu___2 *);
	void (*cancel_txn)(struct pmu___2 *);
	int (*event_idx)(struct perf_event___2 *);
	void (*sched_task)(struct perf_event_context___3 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___2 *);
	int (*filter_match)(struct perf_event___2 *);
	int (*check_period)(struct perf_event___2 *, u64);
};

struct perf_cpu_context___2 {
	struct perf_event_context___3 ctx;
	struct perf_event_context___3 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___2 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___2 {
	struct cgroup_subsys_state___2 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___2 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___2 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___2 *);
	struct list_head * (*get_fields)(struct trace_event_call___2 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___2 *);
};

struct uuidcmp {
	const char *uuid;
	int len;
};

struct module___6;

struct file___4;

struct kiocb___4;

struct iov_iter___4;

struct poll_table_struct___4;

struct vm_area_struct___5;

struct inode___5;

struct file_lock___4;

struct page___5;

struct seq_file___7;

struct file_operations___4 {
	struct module___6 *owner;
	loff_t (*llseek)(struct file___4 *, loff_t, int);
	ssize_t (*read)(struct file___4 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___4 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___4 *, struct iov_iter___4 *);
	ssize_t (*write_iter)(struct kiocb___4 *, struct iov_iter___4 *);
	int (*iopoll)(struct kiocb___4 *, bool);
	int (*iterate)(struct file___4 *, struct dir_context *);
	int (*iterate_shared)(struct file___4 *, struct dir_context *);
	__poll_t (*poll)(struct file___4 *, struct poll_table_struct___4 *);
	long int (*unlocked_ioctl)(struct file___4 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___4 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___4 *, struct vm_area_struct___5 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___5 *, struct file___4 *);
	int (*flush)(struct file___4 *, fl_owner_t);
	int (*release)(struct inode___5 *, struct file___4 *);
	int (*fsync)(struct file___4 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___4 *, int);
	int (*lock)(struct file___4 *, int, struct file_lock___4 *);
	ssize_t (*sendpage)(struct file___4 *, struct page___5 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___4 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___4 *, int, struct file_lock___4 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___4 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___4 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___4 *, long int, struct file_lock___4 **, void **);
	long int (*fallocate)(struct file___4 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___7 *, struct file___4 *);
	ssize_t (*copy_file_range)(struct file___4 *, loff_t, struct file___4 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___4 *, loff_t, struct file___4 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___4 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___3 {
	u64 seqnum;
	struct vm_area_struct___5 *vmas[4];
};

struct page_frag___3 {
	struct page___5 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___3;

struct debug_info___3 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___3 *hbp_break[16];
	struct perf_event___3 *hbp_watch[16];
};

struct thread_struct___3 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___3 debug;
	long: 64;
};

struct mm_struct___4;

struct pid___3;

struct cred___4;

struct nsproxy___4;

struct signal_struct___4;

struct bio_list___4;

struct backing_dev_info___4;

struct io_context___4;

struct css_set___4;

struct perf_event_context___4;

struct vm_struct___4;

struct task_struct___5 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___5 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___4 *mm;
	struct mm_struct___4 *active_mm;
	struct vmacache___3 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___5 *real_parent;
	struct task_struct___5 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___5 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___3 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___3 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___3 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___4 *ptracer_cred;
	const struct cred___4 *real_cred;
	const struct cred___4 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___4 *nsproxy;
	struct signal_struct___4 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___5 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___4 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___4 *backing_dev_info;
	struct io_context___4 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___4 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___4 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___3 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___5 *oom_reaper_list;
	struct vm_struct___4 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___3 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___3 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___5 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___3)(struct perf_event___3 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___3;

struct fasync_struct___3;

struct pid_namespace___3;

struct trace_event_call___3;

struct perf_cgroup___3;

struct perf_event___3 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___3 *group_leader;
	struct pmu___3 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___3 hw;
	struct perf_event_context___4 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___3 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___5 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___3 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___3 *);
	struct callback_head callback_head;
	struct pid_namespace___3 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___3 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___3 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___3 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___3 *cgrp;
	struct list_head sb_list;
};

struct dentry_operations___3;

struct super_block___4;

struct dentry___4 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___4 *d_parent;
	struct qstr d_name;
	struct inode___5 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___3 *d_op;
	struct super_block___4 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct rw_semaphore___4 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___5 *owner;
};

struct address_space_operations___3;

struct address_space___3 {
	struct inode___5 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___4 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___3 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___3;

struct bdi_writeback___3;

struct block_device___4;

struct cdev___3;

struct inode___5 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___3 *i_op;
	struct super_block___4 *i_sb;
	struct address_space___3 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___4 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___4 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___3 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___4 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vfsmount___3;

struct path___3;

struct dentry_operations___3 {
	int (*d_revalidate)(struct dentry___4 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___4 *, unsigned int);
	int (*d_hash)(const struct dentry___4 *, struct qstr *);
	int (*d_compare)(const struct dentry___4 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___4 *);
	int (*d_init)(struct dentry___4 *);
	void (*d_release)(struct dentry___4 *);
	void (*d_prune)(struct dentry___4 *);
	void (*d_iput)(struct dentry___4 *, struct inode___5 *);
	char * (*d_dname)(struct dentry___4 *, char *, int);
	struct vfsmount___3 * (*d_automount)(struct path___3 *);
	int (*d_manage)(const struct path___3 *, bool);
	struct dentry___4 * (*d_real)(struct dentry___4 *, const struct inode___5 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___3;

struct mem_dqinfo___3 {
	struct quota_format_type___3 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___3;

struct quota_info___3 {
	unsigned int flags;
	struct rw_semaphore___4 dqio_sem;
	struct inode___5 *files[3];
	struct mem_dqinfo___3 info[3];
	const struct quota_format_ops___3 *ops[3];
};

struct rcuwait___3 {
	struct task_struct___5 *task;
};

struct percpu_rw_semaphore___3 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___4 rw_sem;
	struct rcuwait___3 writer;
	int readers_block;
};

struct sb_writers___3 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___3 rw_sem[3];
};

struct file_system_type___3;

struct super_operations___3;

struct dquot_operations___3;

struct quotactl_ops___3;

struct xattr_handler___3;

struct user_namespace___4;

struct super_block___4 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___3 *s_type;
	const struct super_operations___3 *s_op;
	const struct dquot_operations___3 *dq_op;
	const struct quotactl_ops___3 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___4 *s_root;
	struct rw_semaphore___4 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___4 *s_bdev;
	struct backing_dev_info___4 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___3 s_dquot;
	struct sb_writers___3 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___3 *s_d_op;
	int cleancache_poolid;
	struct shrinker___2 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___4 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___3 {
	struct dentry___4 *mnt_root;
	struct super_block___4 *mnt_sb;
	int mnt_flags;
};

struct path___3 {
	struct vfsmount___3 *mnt;
	struct dentry___4 *dentry;
};

struct key___5;

struct ucounts___3;

struct user_namespace___4 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___4 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common ns;
	long unsigned int flags;
	struct key___5 *persistent_keyring_register;
	struct rw_semaphore___4 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___3 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___5 *pgtable_t___3;

struct dev_pagemap___3;

struct page___5 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___3 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___5 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___3 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___4 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___3 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___3;

struct lruvec___3 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___3 *pgdat;
};

struct zone___3 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___3 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___3 {
	struct zone___3 *zone;
	int zone_idx;
};

struct zonelist___3 {
	struct zoneref___3 _zonerefs[25];
};

struct pglist_data___3 {
	struct zone___3 node_zones[3];
	struct zonelist___3 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___5 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___5 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___3 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___4 {
	void *stack;
	struct task_struct___5 *task;
	long int status;
};

struct blocking_notifier_head___3 {
	struct rw_semaphore___4 rwsem;
	struct notifier_block *head;
};

struct upid___3 {
	int nr;
	struct pid_namespace___3 *ns;
};

struct pid_namespace___3 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___5 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___3 *parent;
	struct vfsmount___3 *proc_mnt;
	struct dentry___4 *proc_self;
	struct dentry___4 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___4 *user_ns;
	struct ucounts___3 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common ns;
};

struct pid___3 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___3 numbers[1];
};

struct vm_operations_struct___3;

struct vm_area_struct___5 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___5 *vm_next;
	struct vm_area_struct___5 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___4 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___3 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___4 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___3;

struct mm_struct___4 {
	struct {
		struct vm_area_struct___5 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___4 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___4 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___3 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___5 *owner;
		struct user_namespace___4 *user_ns;
		struct file___4 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___3 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___3)(struct vm_area_struct___5 *, long unsigned int, const struct page___5 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___3)(struct page___5 *, void *);

struct device___4;

struct dev_pagemap___3 {
	dev_page_fault_t___3 page_fault;
	dev_page_free_t___3 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___4 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct fown_struct___3 {
	rwlock_t lock;
	struct pid___3 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___4 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___3 f_path;
	struct inode___5 *f_inode;
	const struct file_operations___4 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___3 f_owner;
	const struct cred___4 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___3 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___3;

struct vm_operations_struct___3 {
	void (*open)(struct vm_area_struct___5 *);
	void (*close)(struct vm_area_struct___5 *);
	int (*split)(struct vm_area_struct___5 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___5 *);
	vm_fault_t (*fault)(struct vm_fault___3 *);
	vm_fault_t (*huge_fault)(struct vm_fault___3 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___3 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___5 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___3 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___3 *);
	int (*access)(struct vm_area_struct___5 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___5 *);
	int (*set_policy)(struct vm_area_struct___5 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___5 *, long unsigned int);
	struct page___5 * (*find_special_page)(struct vm_area_struct___5 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___3 {
	struct task_struct___5 *task;
	struct core_thread___3 *next;
};

struct core_state___3 {
	atomic_t nr_threads;
	struct core_thread___3 dumper;
	struct completion startup;
};

struct vm_fault___3 {
	struct vm_area_struct___5 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___5 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___5 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___3 prealloc_pte;
};

struct user_struct___4 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___5 *uid_keyring;
	struct key___5 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___4 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___5 *session_keyring;
	struct key___5 *process_keyring;
	struct key___5 *thread_keyring;
	struct key___5 *request_key_auth;
	void *security;
	struct user_struct___4 *user;
	struct user_namespace___4 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct uts_namespace___3;

struct cgroup_namespace___4;

struct nsproxy___4 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___3 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___4 *cgroup_ns;
};

struct signal_struct___4 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___5 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___5 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___3 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___3 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___4 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___3 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide44;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___3;

struct bio_list___4 {
	struct bio___3 *head;
	struct bio___3 *tail;
};

struct bdi_writeback_congested___3;

struct cgroup_subsys_state___3;

struct bdi_writeback___3 {
	struct backing_dev_info___4 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___3 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___3 *memcg_css;
	struct cgroup_subsys_state___3 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___4 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___3 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___4 *dev;
	struct device___4 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___4 *debug_dir;
	struct dentry___4 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___3;

struct io_context___4 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___3 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___3;

struct css_set___4 {
	struct cgroup_subsys_state___3 *subsys[13];
	refcount_t refcount;
	struct css_set___4 *dom_cset;
	struct cgroup___3 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___3 *mg_src_cgrp;
	struct cgroup___3 *mg_dst_cgrp;
	struct css_set___4 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___4 {
	struct pmu___3 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___5 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___4 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

typedef blk_qc_t make_request_fn___3(struct request_queue___3 *, struct bio___3 *);

struct request___4;

typedef int dma_drain_needed_fn___3(struct request___4 *);

struct kset___3;

struct kobj_type___3;

struct kernfs_node___3;

struct kobject___3 {
	const char *name;
	struct list_head entry;
	struct kobject___3 *parent;
	struct kset___3 *kset;
	struct kobj_type___3 *ktype;
	struct kernfs_node___3 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___3;

struct bsg_class_device___3 {
	struct device___4 *class_dev;
	int minor;
	struct request_queue___3 *queue;
	const struct bsg_ops___3 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___3 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___4 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___3;

struct request_queue___3 {
	struct list_head queue_head;
	struct request___4 *last_merge;
	struct elevator_queue___3 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___3 *make_request_fn;
	dma_drain_needed_fn___3 *dma_drain_needed;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___4 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___3 kobj;
	struct kobject___3 *mq_kobj;
	struct blk_integrity integrity;
	struct device___4 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	struct bsg_class_device___3 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___3 bio_split;
	struct dentry___4 *debugfs_dir;
	struct dentry___4 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___4 {
	struct vm_struct___4 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___5 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___3 {
	struct task_struct___5 task;
	long unsigned int stack[8192];
};

struct io_cq___3 {
	struct request_queue___3 *q;
	struct io_context___4 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___4 {
	struct file___4 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___4 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___4 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___4 *ia_file;
};

struct dquot___3 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___4 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___3 {
	int qf_fmt_id;
	const struct quota_format_ops___3 *qf_ops;
	struct module___6 *qf_owner;
	struct quota_format_type___3 *qf_next;
};

struct quota_format_ops___3 {
	int (*check_quota_file)(struct super_block___4 *, int);
	int (*read_file_info)(struct super_block___4 *, int);
	int (*write_file_info)(struct super_block___4 *, int);
	int (*free_file_info)(struct super_block___4 *, int);
	int (*read_dqblk)(struct dquot___3 *);
	int (*commit_dqblk)(struct dquot___3 *);
	int (*release_dqblk)(struct dquot___3 *);
	int (*get_next_id)(struct super_block___4 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___3 {
	int (*write_dquot)(struct dquot___3 *);
	struct dquot___3 * (*alloc_dquot)(struct super_block___4 *, int);
	void (*destroy_dquot)(struct dquot___3 *);
	int (*acquire_dquot)(struct dquot___3 *);
	int (*release_dquot)(struct dquot___3 *);
	int (*mark_dirty)(struct dquot___3 *);
	int (*write_info)(struct super_block___4 *, int);
	qsize_t * (*get_reserved_space)(struct inode___5 *);
	int (*get_projid)(struct inode___5 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___5 *, qsize_t *);
	int (*get_next_id)(struct super_block___4 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___3 {
	int (*quota_on)(struct super_block___4 *, int, int, const struct path___3 *);
	int (*quota_off)(struct super_block___4 *, int);
	int (*quota_enable)(struct super_block___4 *, unsigned int);
	int (*quota_disable)(struct super_block___4 *, unsigned int);
	int (*quota_sync)(struct super_block___4 *, int);
	int (*set_info)(struct super_block___4 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___4 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___4 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___4 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___4 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___4 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___3 {
	struct kobject___3 kobj;
	struct module___6 *mod;
	struct kobject___3 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___3 {
	struct module___6 *mod;
	struct latch_tree_node node;
};

struct module_layout___3 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___3 mtn;
};

struct module_attribute___3;

struct kernel_param___3;

struct module___6 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___3 mkobj;
	struct module_attribute___3 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___3 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___3 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___3 core_layout;
	struct module_layout___3 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___3 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide42;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide43;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___3;

struct swap_info_struct___3;

struct address_space_operations___3 {
	int (*writepage)(struct page___5 *, struct writeback_control___3 *);
	int (*readpage)(struct file___4 *, struct page___5 *);
	int (*writepages)(struct address_space___3 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___5 *);
	int (*readpages)(struct file___4 *, struct address_space___3 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___4 *, struct address_space___3 *, loff_t, unsigned int, unsigned int, struct page___5 **, void **);
	int (*write_end)(struct file___4 *, struct address_space___3 *, loff_t, unsigned int, unsigned int, struct page___5 *, void *);
	sector_t (*bmap)(struct address_space___3 *, sector_t);
	void (*invalidatepage)(struct page___5 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___5 *, gfp_t);
	void (*freepage)(struct page___5 *);
	ssize_t (*direct_IO)(struct kiocb___4 *, struct iov_iter___4 *);
	int (*migratepage)(struct address_space___3 *, struct page___5 *, struct page___5 *, enum migrate_mode);
	bool (*isolate_page)(struct page___5 *, isolate_mode_t);
	void (*putback_page)(struct page___5 *);
	int (*launder_page)(struct page___5 *);
	int (*is_partially_uptodate)(struct page___5 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___5 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___3 *, struct page___5 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___4 *, sector_t *);
	void (*swap_deactivate)(struct file___4 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio_vec___3;

struct iov_iter___4 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___3 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct hd_struct___3;

struct gendisk___3;

struct block_device___4 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___5 *bd_inode;
	struct super_block___4 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___4 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___3 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___3 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___4 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___3 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___4 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___3;

struct bus_type___3;

struct device_driver___3;

struct dev_pm_domain___3;

struct fwnode_handle___3;

struct class___3;

struct attribute_group___3;

struct device___4 {
	struct device___4 *parent;
	struct device_private *p;
	struct kobject___3 kobj;
	const char *init_name;
	const struct device_type___3 *type;
	struct mutex mutex;
	struct bus_type___3 *bus;
	struct device_driver___3 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___3 power;
	struct dev_pm_domain___3 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___3 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___3 *class;
	const struct attribute_group___3 **groups;
	void (*release)(struct device___4 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___3 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___4 __dev;
	struct kobject___3 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___3;

struct block_device_operations___3;

struct gendisk___3 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___3 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___3 *part_tbl;
	struct hd_struct___3 part0;
	const struct block_device_operations___3 *fops;
	struct request_queue___3 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___4 lookup_sem;
	struct kobject___3 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___3 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___3 {
	struct dentry___4 * (*lookup)(struct inode___5 *, struct dentry___4 *, unsigned int);
	const char * (*get_link)(struct dentry___4 *, struct inode___5 *, struct delayed_call *);
	int (*permission)(struct inode___5 *, int);
	struct posix_acl * (*get_acl)(struct inode___5 *, int);
	int (*readlink)(struct dentry___4 *, char *, int);
	int (*create)(struct inode___5 *, struct dentry___4 *, umode_t, bool);
	int (*link)(struct dentry___4 *, struct inode___5 *, struct dentry___4 *);
	int (*unlink)(struct inode___5 *, struct dentry___4 *);
	int (*symlink)(struct inode___5 *, struct dentry___4 *, const char *);
	int (*mkdir)(struct inode___5 *, struct dentry___4 *, umode_t);
	int (*rmdir)(struct inode___5 *, struct dentry___4 *);
	int (*mknod)(struct inode___5 *, struct dentry___4 *, umode_t, dev_t);
	int (*rename)(struct inode___5 *, struct dentry___4 *, struct inode___5 *, struct dentry___4 *, unsigned int);
	int (*setattr)(struct dentry___4 *, struct iattr___4 *);
	int (*getattr)(const struct path___3 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___4 *, char *, size_t);
	int (*fiemap)(struct inode___5 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___5 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___5 *, struct dentry___4 *, struct file___4 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___5 *, struct dentry___4 *, umode_t);
	int (*set_acl)(struct inode___5 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___3 {
	void (*fl_copy_lock)(struct file_lock___4 *, struct file_lock___4 *);
	void (*fl_release_private)(struct file_lock___4 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___3;

struct file_lock___4 {
	struct file_lock___4 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___4 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___3 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___3 *fl_ops;
	const struct lock_manager_operations___3 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___3 {
	int (*lm_compare_owner)(struct file_lock___4 *, struct file_lock___4 *);
	long unsigned int (*lm_owner_key)(struct file_lock___4 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___4 *);
	int (*lm_grant)(struct file_lock___4 *, int);
	bool (*lm_break)(struct file_lock___4 *);
	int (*lm_change)(struct file_lock___4 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___4 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___3 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___3 *fa_next;
	struct file___4 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___3 {
	const char *name;
	int fs_flags;
	struct dentry___4 * (*mount)(struct file_system_type___3 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___4 *);
	struct module___6 *owner;
	struct file_system_type___3 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___3 {
	struct inode___5 * (*alloc_inode)(struct super_block___4 *);
	void (*destroy_inode)(struct inode___5 *);
	void (*dirty_inode)(struct inode___5 *, int);
	int (*write_inode)(struct inode___5 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___5 *);
	void (*evict_inode)(struct inode___5 *);
	void (*put_super)(struct super_block___4 *);
	int (*sync_fs)(struct super_block___4 *, int);
	int (*freeze_super)(struct super_block___4 *);
	int (*freeze_fs)(struct super_block___4 *);
	int (*thaw_super)(struct super_block___4 *);
	int (*unfreeze_fs)(struct super_block___4 *);
	int (*statfs)(struct dentry___4 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___4 *, int *, char *);
	void (*umount_begin)(struct super_block___4 *);
	int (*show_options)(struct seq_file___7 *, struct dentry___4 *);
	int (*show_devname)(struct seq_file___7 *, struct dentry___4 *);
	int (*show_path)(struct seq_file___7 *, struct dentry___4 *);
	int (*show_stats)(struct seq_file___7 *, struct dentry___4 *);
	ssize_t (*quota_read)(struct super_block___4 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___4 *, int, const char *, size_t, loff_t);
	struct dquot___3 ** (*get_dquots)(struct inode___5 *);
	int (*bdev_try_to_free_page)(struct super_block___4 *, struct page___5 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___4 *, struct shrink_control___2 *);
	long int (*free_cached_objects)(struct super_block___4 *, struct shrink_control___2 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dentry___5;

struct inode___6;

struct xattr_handler___3 {
	const char *name;
	const char *prefix;
	int flags;
	bool (*list)(struct dentry___5 *);
	int (*get)(const struct xattr_handler___3 *, struct dentry___5 *, struct inode___6 *, const char *, void *, size_t);
	int (*set)(const struct xattr_handler___3 *, struct dentry___5 *, struct inode___6 *, const char *, const void *, size_t, int);
};

typedef void (*poll_queue_proc___3)(struct file___4 *, wait_queue_head_t *, struct poll_table_struct___4 *);

struct poll_table_struct___4 {
	poll_queue_proc___3 _qproc;
	__poll_t _key;
};

struct seq_operations___4;

struct seq_file___7 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___4 *op;
	int poll_event;
	const struct file___4 *file;
	void *private;
};

typedef void bio_end_io_t___3(struct bio___3 *);

struct bio_vec___3 {
	struct page___5 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___3;

struct bio___3 {
	struct bio___3 *bi_next;
	struct gendisk___3 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___3 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___3 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___3 *bi_io_vec;
	struct bio_set___3 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___3 bi_inline_vecs[0];
};

struct subprocess_info {
	struct work_struct work;
	struct completion *complete;
	const char *path;
	char **argv;
	char **envp;
	struct file___4 *file;
	int wait;
	int retval;
	pid_t pid;
	int (*init)(struct subprocess_info *, struct cred___4 *);
	void (*cleanup)(struct subprocess_info *);
	void *data;
};

struct bio_integrity_payload___3 {
	struct bio___3 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___3 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___3 bip_inline_vecs[0];
};

struct dev_pm_ops___3;

struct device_type___3 {
	const char *name;
	const struct attribute_group___3 **groups;
	int (*uevent)(struct device___4 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___4 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___4 *);
	const struct dev_pm_ops___3 *pm;
};

struct class___3 {
	const char *name;
	struct module___6 *owner;
	const struct attribute_group___3 **class_groups;
	const struct attribute_group___3 **dev_groups;
	struct kobject___3 *dev_kobj;
	int (*dev_uevent)(struct device___4 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___4 *, umode_t *);
	void (*class_release)(struct class___3 *);
	void (*dev_release)(struct device___4 *);
	int (*shutdown_pre)(struct device___4 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___4 *);
	const struct dev_pm_ops___3 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct kernfs_root___3;

struct kernfs_elem_dir___3 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___3 *root;
};

struct kernfs_syscall_ops___3;

struct kernfs_root___3 {
	struct kernfs_node___3 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___3 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___3 {
	struct kernfs_node___3 *target_kn;
};

struct kernfs_ops___3;

struct kernfs_elem_attr___3 {
	const struct kernfs_ops___3 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___3 *notify_next;
};

struct kernfs_node___3 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___3 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___3 dir;
		struct kernfs_elem_symlink___3 symlink;
		struct kernfs_elem_attr___3 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___3;

struct kernfs_ops___3 {
	int (*open)(struct kernfs_open_file___3 *);
	void (*release)(struct kernfs_open_file___3 *);
	int (*seq_show)(struct seq_file___7 *, void *);
	void * (*seq_start)(struct seq_file___7 *, loff_t *);
	void * (*seq_next)(struct seq_file___7 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___7 *, void *);
	ssize_t (*read)(struct kernfs_open_file___3 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___3 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___3 *, struct vm_area_struct___5 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___3 *, struct poll_table_struct___4 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___3 {
	int (*remount_fs)(struct kernfs_root___3 *, int *, char *);
	int (*show_options)(struct seq_file___7 *, struct kernfs_root___3 *);
	int (*mkdir)(struct kernfs_node___3 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___3 *);
	int (*rename)(struct kernfs_node___3 *, struct kernfs_node___3 *, const char *);
	int (*show_path)(struct seq_file___7 *, struct kernfs_node___3 *, struct kernfs_root___3 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___3 {
	struct kernfs_node___3 *kn;
	struct file___4 *file;
	struct seq_file___7 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___3 *vm_ops;
};

struct bin_attribute___3;

struct attribute_group___3 {
	const char *name;
	umode_t (*is_visible)(struct kobject___3 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___3 *, struct bin_attribute___3 *, int);
	struct attribute **attrs;
	struct bin_attribute___3 **bin_attrs;
};

struct bin_attribute___3 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___4 *, struct kobject___3 *, struct bin_attribute___3 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___4 *, struct kobject___3 *, struct bin_attribute___3 *, char *, loff_t, size_t);
	int (*mmap)(struct file___4 *, struct kobject___3 *, struct bin_attribute___3 *, struct vm_area_struct___5 *);
};

struct sysfs_ops___3 {
	ssize_t (*show)(struct kobject___3 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___3 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___3;

struct kset___3 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___3 kobj;
	const struct kset_uevent_ops___3 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___3 {
	void (*release)(struct kobject___3 *);
	const struct sysfs_ops___3 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___3 *);
	const void * (*namespace)(struct kobject___3 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___3 {
	int (* const filter)(struct kset___3 *, struct kobject___3 *);
	const char * (* const name)(struct kset___3 *, struct kobject___3 *);
	int (* const uevent)(struct kset___3 *, struct kobject___3 *, struct kobj_uevent_env *);
};

struct kobj_attribute___3 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___3 *, struct kobj_attribute___3 *, char *);
	ssize_t (*store)(struct kobject___3 *, struct kobj_attribute___3 *, const char *, size_t);
};

struct dev_pm_ops___3 {
	int (*prepare)(struct device___4 *);
	void (*complete)(struct device___4 *);
	int (*suspend)(struct device___4 *);
	int (*resume)(struct device___4 *);
	int (*freeze)(struct device___4 *);
	int (*thaw)(struct device___4 *);
	int (*poweroff)(struct device___4 *);
	int (*restore)(struct device___4 *);
	int (*suspend_late)(struct device___4 *);
	int (*resume_early)(struct device___4 *);
	int (*freeze_late)(struct device___4 *);
	int (*thaw_early)(struct device___4 *);
	int (*poweroff_late)(struct device___4 *);
	int (*restore_early)(struct device___4 *);
	int (*suspend_noirq)(struct device___4 *);
	int (*resume_noirq)(struct device___4 *);
	int (*freeze_noirq)(struct device___4 *);
	int (*thaw_noirq)(struct device___4 *);
	int (*poweroff_noirq)(struct device___4 *);
	int (*restore_noirq)(struct device___4 *);
	int (*runtime_suspend)(struct device___4 *);
	int (*runtime_resume)(struct device___4 *);
	int (*runtime_idle)(struct device___4 *);
};

struct dev_pm_domain___3 {
	struct dev_pm_ops___3 ops;
	void (*detach)(struct device___4 *, bool);
	int (*activate)(struct device___4 *);
	void (*sync)(struct device___4 *);
	void (*dismiss)(struct device___4 *);
};

struct bus_type___3 {
	const char *name;
	const char *dev_name;
	struct device___4 *dev_root;
	const struct attribute_group___3 **bus_groups;
	const struct attribute_group___3 **dev_groups;
	const struct attribute_group___3 **drv_groups;
	int (*match)(struct device___4 *, struct device_driver___3 *);
	int (*uevent)(struct device___4 *, struct kobj_uevent_env *);
	int (*probe)(struct device___4 *);
	int (*remove)(struct device___4 *);
	void (*shutdown)(struct device___4 *);
	int (*online)(struct device___4 *);
	int (*offline)(struct device___4 *);
	int (*suspend)(struct device___4 *, pm_message_t);
	int (*resume)(struct device___4 *);
	int (*num_vf)(struct device___4 *);
	int (*dma_configure)(struct device___4 *);
	const struct dev_pm_ops___3 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___3 {
	const char *name;
	struct bus_type___3 *bus;
	struct module___6 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___4 *);
	int (*remove)(struct device___4 *);
	void (*shutdown)(struct device___4 *);
	int (*suspend)(struct device___4 *, pm_message_t);
	int (*resume)(struct device___4 *);
	const struct attribute_group___3 **groups;
	const struct dev_pm_ops___3 *pm;
	void (*coredump)(struct device___4 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct fwnode_operations___3;

struct fwnode_handle___3 {
	struct fwnode_handle___3 *secondary;
	const struct fwnode_operations___3 *ops;
};

struct disk_part_tbl___3 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___3 *last_lookup;
	struct hd_struct___3 *part[0];
};

struct block_device_operations___3 {
	int (*open)(struct block_device___4 *, fmode_t);
	void (*release)(struct gendisk___3 *, fmode_t);
	int (*rw_page)(struct block_device___4 *, sector_t, struct page___5 *, unsigned int);
	int (*ioctl)(struct block_device___4 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___4 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___3 *, unsigned int);
	int (*media_changed)(struct gendisk___3 *);
	void (*unlock_native_capacity)(struct gendisk___3 *);
	int (*revalidate_disk)(struct gendisk___3 *);
	int (*getgeo)(struct block_device___4 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___4 *, long unsigned int);
	int (*report_zones)(struct gendisk___3 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___6 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___3(struct page___5 *);

struct bdi_writeback_congested___3 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___4 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct cgroup_subsys___3;

struct cgroup_subsys_state___3 {
	struct cgroup___3 *cgroup;
	struct cgroup_subsys___3 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___3 *parent;
};

struct bsg_ops___3 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___4 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___4 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___4 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___3(struct request___4 *, blk_status_t);

struct request___4 {
	struct request_queue___3 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___3 *bio;
	struct bio___3 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___3 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___3 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___3 *saved_end_io;
		} flush;
	};
	struct gendisk___3 *rq_disk;
	struct hd_struct___3 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___3 *end_io;
	void *end_io_data;
	struct request___4 *next_rq;
};

struct fwnode_reference_args___3;

struct fwnode_endpoint___3;

struct fwnode_operations___3 {
	struct fwnode_handle___3 * (*get)(struct fwnode_handle___3 *);
	void (*put)(struct fwnode_handle___3 *);
	bool (*device_is_available)(const struct fwnode_handle___3 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___3 *, const struct device___4 *);
	bool (*property_present)(const struct fwnode_handle___3 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___3 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___3 *, const char *, const char **, size_t);
	struct fwnode_handle___3 * (*get_parent)(const struct fwnode_handle___3 *);
	struct fwnode_handle___3 * (*get_next_child_node)(const struct fwnode_handle___3 *, struct fwnode_handle___3 *);
	struct fwnode_handle___3 * (*get_named_child_node)(const struct fwnode_handle___3 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___3 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___3 *);
	struct fwnode_handle___3 * (*graph_get_next_endpoint)(const struct fwnode_handle___3 *, struct fwnode_handle___3 *);
	struct fwnode_handle___3 * (*graph_get_remote_endpoint)(const struct fwnode_handle___3 *);
	struct fwnode_handle___3 * (*graph_get_port_parent)(struct fwnode_handle___3 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___3 *, struct fwnode_endpoint___3 *);
};

struct fwnode_endpoint___3 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___3 *local_fwnode;
};

struct fwnode_reference_args___3 {
	struct fwnode_handle___3 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct elevator_type___3;

struct elevator_mq_ops___3 {
	int (*init_sched)(struct request_queue___3 *, struct elevator_type___3 *);
	void (*exit_sched)(struct elevator_queue___3 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	bool (*allow_merge)(struct request_queue___3 *, struct request___4 *, struct bio___3 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx *, struct bio___3 *);
	int (*request_merge)(struct request_queue___3 *, struct request___4 **, struct bio___3 *);
	void (*request_merged)(struct request_queue___3 *, struct request___4 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___3 *, struct request___4 *, struct request___4 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___4 *, struct bio___3 *);
	void (*finish_request)(struct request___4 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___4 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___4 *, u64);
	void (*started_request)(struct request___4 *);
	void (*requeue_request)(struct request___4 *);
	struct request___4 * (*former_request)(struct request_queue___3 *, struct request___4 *);
	struct request___4 * (*next_request)(struct request_queue___3 *, struct request___4 *);
	void (*init_icq)(struct io_cq___3 *);
	void (*exit_icq)(struct io_cq___3 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___3;

struct elevator_type___3 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___3 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___3 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___6 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___3 {
	struct elevator_type___3 *type;
	void *elevator_data;
	struct kobject___3 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___3 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___3 *, char *);
	ssize_t (*store)(struct elevator_queue___3 *, const char *, size_t);
};

typedef int (*key_restrict_link_func_t___3)(struct key___5 *, const struct key_type *, const union key_payload *, struct key___5 *);

struct key_restriction___4;

struct key___5 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___4 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___4 *restrict_link;
};

struct key_restriction___4 {
	key_restrict_link_func_t___3 check;
	struct key___5 *key;
	struct key_type *keytype;
};

struct seq_operations___4 {
	void * (*start)(struct seq_file___7 *, loff_t *);
	void (*stop)(struct seq_file___7 *, void *);
	void * (*next)(struct seq_file___7 *, void *, loff_t *);
	int (*show)(struct seq_file___7 *, void *);
};

struct cgroup_namespace___4 {
	refcount_t count;
	struct ns_common ns;
	struct user_namespace___4 *user_ns;
	struct ucounts___3 *ucounts;
	struct css_set___4 *root_cset;
};

struct ucounts___3 {
	struct hlist_node node;
	struct user_namespace___4 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct kernel_param_ops___3 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___3 *);
	int (*get)(char *, const struct kernel_param___3 *);
	void (*free)(void *);
};

struct kparam_array___3;

struct kernel_param___3 {
	const char *name;
	struct module___6 *mod;
	const struct kernel_param_ops___3 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___3 *arr;
	};
};

struct kparam_array___3 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___3 *ops;
	void *elem;
};

struct module_attribute___3 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___3 *, struct module_kobject___3 *, char *);
	ssize_t (*store)(struct module_attribute___3 *, struct module_kobject___3 *, const char *, size_t);
	void (*setup)(struct module___6 *, const char *);
	int (*test)(struct module___6 *);
	void (*free)(struct module___6 *);
};

struct trace_event_class___3;

struct trace_event_call___3 {
	struct list_head list;
	struct trace_event_class___3 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array *prog_array;
	int (*perf_perm)(struct trace_event_call___3 *, struct perf_event___3 *);
};

struct node___3 {
	struct device___4 dev;
};

struct bpf_map___3;

struct bpf_map_ops___3 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___3 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___3 *, struct file___4 *);
	void (*map_free)(struct bpf_map___3 *);
	int (*map_get_next_key)(struct bpf_map___3 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___3 *);
	void * (*map_lookup_elem)(struct bpf_map___3 *, void *);
	int (*map_update_elem)(struct bpf_map___3 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___3 *, void *);
	int (*map_push_elem)(struct bpf_map___3 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___3 *, void *);
	int (*map_peek_elem)(struct bpf_map___3 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___3 *, struct file___4 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___3 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___3 *, void *, struct seq_file___7 *);
	int (*map_check_btf)(const struct bpf_map___3 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___3 {
	const struct bpf_map_ops___3 *ops;
	struct bpf_map___3 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___4 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___3;

typedef void (*kthread_work_func_t___3)(struct kthread_work___3 *);

struct kthread_worker___3;

struct kthread_work___3 {
	struct list_head node;
	kthread_work_func_t___3 func;
	struct kthread_worker___3 *worker;
	int canceling;
};

struct kthread_worker___3 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___5 *task;
	struct kthread_work___3 *current_work;
};

struct kthread_delayed_work___3 {
	struct kthread_work___3 work;
	struct timer_list timer;
};

struct psi_group___3 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___3 *poll_kworker;
	struct kthread_delayed_work___3 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___3 {
	struct kernfs_node___3 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_root___3;

struct cgroup_rstat_cpu___3;

struct cgroup___3 {
	struct cgroup_subsys_state___3 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___3 *kn;
	struct cgroup_file___3 procs_file;
	struct cgroup_file___3 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___3 *subsys[13];
	struct cgroup_root___3 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___3 *dom_cgrp;
	struct cgroup_rstat_cpu___3 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf bpf;
	atomic_t congestion_count;
	struct cgroup___3 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___3 psi;
	int ancestor_ids[0];
};

struct cftype___3;

struct cgroup_subsys___3 {
	struct cgroup_subsys_state___3 * (*css_alloc)(struct cgroup_subsys_state___3 *);
	int (*css_online)(struct cgroup_subsys_state___3 *);
	void (*css_offline)(struct cgroup_subsys_state___3 *);
	void (*css_released)(struct cgroup_subsys_state___3 *);
	void (*css_free)(struct cgroup_subsys_state___3 *);
	void (*css_reset)(struct cgroup_subsys_state___3 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___3 *, int);
	int (*css_extra_stat_show)(struct seq_file___7 *, struct cgroup_subsys_state___3 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___5 *);
	void (*cancel_fork)(struct task_struct___5 *);
	void (*fork)(struct task_struct___5 *);
	void (*exit)(struct task_struct___5 *);
	void (*free)(struct task_struct___5 *);
	void (*bind)(struct cgroup_subsys_state___3 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___3 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___3 *dfl_cftypes;
	struct cftype___3 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___3 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___3 *updated_children;
	struct cgroup___3 *updated_next;
};

struct cgroup_root___3 {
	struct kernfs_root___3 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___3 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___3 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___3 *ss;
	struct list_head node;
	struct kernfs_ops___3 *kf_ops;
	int (*open)(struct kernfs_open_file___3 *);
	void (*release)(struct kernfs_open_file___3 *);
	u64 (*read_u64)(struct cgroup_subsys_state___3 *, struct cftype___3 *);
	s64 (*read_s64)(struct cgroup_subsys_state___3 *, struct cftype___3 *);
	int (*seq_show)(struct seq_file___7 *, void *);
	void * (*seq_start)(struct seq_file___7 *, loff_t *);
	void * (*seq_next)(struct seq_file___7 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___7 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___3 *, struct cftype___3 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___3 *, struct cftype___3 *, s64);
	ssize_t (*write)(struct kernfs_open_file___3 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___3 *, struct poll_table_struct___4 *);
};

struct perf_cpu_context___3;

struct pmu___3 {
	struct list_head entry;
	struct module___6 *module;
	struct device___4 *dev;
	const struct attribute_group___3 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___3 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___3 *);
	void (*pmu_disable)(struct pmu___3 *);
	int (*event_init)(struct perf_event___3 *);
	void (*event_mapped)(struct perf_event___3 *, struct mm_struct___4 *);
	void (*event_unmapped)(struct perf_event___3 *, struct mm_struct___4 *);
	int (*add)(struct perf_event___3 *, int);
	void (*del)(struct perf_event___3 *, int);
	void (*start)(struct perf_event___3 *, int);
	void (*stop)(struct perf_event___3 *, int);
	void (*read)(struct perf_event___3 *);
	void (*start_txn)(struct pmu___3 *, unsigned int);
	int (*commit_txn)(struct pmu___3 *);
	void (*cancel_txn)(struct pmu___3 *);
	int (*event_idx)(struct perf_event___3 *);
	void (*sched_task)(struct perf_event_context___4 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___3 *);
	int (*filter_match)(struct perf_event___3 *);
	int (*check_period)(struct perf_event___3 *, u64);
};

struct perf_cpu_context___3 {
	struct perf_event_context___4 ctx;
	struct perf_event_context___4 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___3 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___3 {
	struct cgroup_subsys_state___3 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___3 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___3 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___3 *);
	struct list_head * (*get_fields)(struct trace_event_call___3 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___3 *);
};

struct mdu_array_info_s {
	int major_version;
	int minor_version;
	int patch_version;
	unsigned int ctime;
	int level;
	int size;
	int nr_disks;
	int raid_disks;
	int md_minor;
	int not_persistent;
	unsigned int utime;
	int state;
	int active_disks;
	int working_disks;
	int failed_disks;
	int spare_disks;
	int layout;
	int chunk_size;
};

typedef struct mdu_array_info_s mdu_array_info_t;

struct mdu_disk_info_s {
	int number;
	int major;
	int minor;
	int raid_disk;
	int state;
};

typedef struct mdu_disk_info_s mdu_disk_info_t;

struct module___7;

struct file___5;

struct kiocb___5;

struct poll_table_struct___5;

struct vm_area_struct___6;

struct inode___7;

struct file_lock___5;

struct page___6;

struct seq_file___8;

struct file_operations___5 {
	struct module___7 *owner;
	loff_t (*llseek)(struct file___5 *, loff_t, int);
	ssize_t (*read)(struct file___5 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___5 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___5 *, struct iov_iter___4 *);
	ssize_t (*write_iter)(struct kiocb___5 *, struct iov_iter___4 *);
	int (*iopoll)(struct kiocb___5 *, bool);
	int (*iterate)(struct file___5 *, struct dir_context *);
	int (*iterate_shared)(struct file___5 *, struct dir_context *);
	__poll_t (*poll)(struct file___5 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___5 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___5 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___5 *, struct vm_area_struct___6 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___7 *, struct file___5 *);
	int (*flush)(struct file___5 *, fl_owner_t);
	int (*release)(struct inode___7 *, struct file___5 *);
	int (*fsync)(struct file___5 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___5 *, int);
	int (*lock)(struct file___5 *, int, struct file_lock___5 *);
	ssize_t (*sendpage)(struct file___5 *, struct page___6 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___5 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___5 *, int, struct file_lock___5 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___5 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___5 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___5 *, long int, struct file_lock___5 **, void **);
	long int (*fallocate)(struct file___5 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___8 *, struct file___5 *);
	ssize_t (*copy_file_range)(struct file___5 *, loff_t, struct file___5 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___5 *, loff_t, struct file___5 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___5 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___4 {
	u64 seqnum;
	struct vm_area_struct___6 *vmas[4];
};

struct page_frag___4 {
	struct page___6 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___4;

struct debug_info___4 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___4 *hbp_break[16];
	struct perf_event___4 *hbp_watch[16];
};

struct thread_struct___4 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___4 debug;
	long: 64;
};

struct mm_struct___5;

struct pid___4;

struct cred___5;

struct nsproxy___5;

struct signal_struct___5;

struct css_set___5;

struct perf_event_context___5;

struct task_struct___6 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___6 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___5 *mm;
	struct mm_struct___5 *active_mm;
	struct vmacache___4 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___6 *real_parent;
	struct task_struct___6 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___6 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___4 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___4 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___4 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___5 *ptracer_cred;
	const struct cred___5 *real_cred;
	const struct cred___5 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___5 *nsproxy;
	struct signal_struct___5 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___6 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___4 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___5 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___5 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___4 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___6 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___4 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___4 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___6 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___4)(struct perf_event___4 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___4;

struct fasync_struct___4;

struct pid_namespace___4;

struct trace_event_call___4;

struct perf_cgroup___4;

struct perf_event___4 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___4 *group_leader;
	struct pmu___4 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___4 hw;
	struct perf_event_context___5 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___4 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___6 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___4 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___4 *);
	struct callback_head callback_head;
	struct pid_namespace___4 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___4 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___4 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___4 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___4 *cgrp;
	struct list_head sb_list;
};

struct dentry_operations___4;

struct super_block___5;

struct dentry___6 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___6 *d_parent;
	struct qstr d_name;
	struct inode___7 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___4 *d_op;
	struct super_block___5 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct rw_semaphore___5 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___6 *owner;
};

struct address_space_operations___4;

struct address_space___4 {
	struct inode___7 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___5 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___4 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___4;

struct bdi_writeback___4;

struct block_device___5;

struct inode___7 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___4 *i_op;
	struct super_block___5 *i_sb;
	struct address_space___4 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___5 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___5 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___4 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___5 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___4;

struct dentry_operations___4 {
	int (*d_revalidate)(struct dentry___6 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___6 *, unsigned int);
	int (*d_hash)(const struct dentry___6 *, struct qstr *);
	int (*d_compare)(const struct dentry___6 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___6 *);
	int (*d_init)(struct dentry___6 *);
	void (*d_release)(struct dentry___6 *);
	void (*d_prune)(struct dentry___6 *);
	void (*d_iput)(struct dentry___6 *, struct inode___7 *);
	char * (*d_dname)(struct dentry___6 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___4 *);
	int (*d_manage)(const struct path___4 *, bool);
	struct dentry___6 * (*d_real)(struct dentry___6 *, const struct inode___7 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___4;

struct mem_dqinfo___4 {
	struct quota_format_type___4 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___4;

struct quota_info___4 {
	unsigned int flags;
	struct rw_semaphore___5 dqio_sem;
	struct inode___7 *files[3];
	struct mem_dqinfo___4 info[3];
	const struct quota_format_ops___4 *ops[3];
};

struct rcuwait___4 {
	struct task_struct___6 *task;
};

struct percpu_rw_semaphore___4 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___5 rw_sem;
	struct rcuwait___4 writer;
	int readers_block;
};

struct sb_writers___4 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___4 rw_sem[3];
};

struct file_system_type___4;

struct super_operations___4;

struct dquot_operations___4;

struct quotactl_ops___4;

struct user_namespace___5;

struct super_block___5 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___4 *s_type;
	const struct super_operations___4 *s_op;
	const struct dquot_operations___4 *dq_op;
	const struct quotactl_ops___4 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___6 *s_root;
	struct rw_semaphore___5 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___4 s_dquot;
	struct sb_writers___4 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___4 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___5 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct path___4 {
	struct vfsmount *mnt;
	struct dentry___6 *dentry;
};

struct key___6;

struct ucounts___4;

struct user_namespace___5 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___5 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common ns;
	long unsigned int flags;
	struct key___6 *persistent_keyring_register;
	struct rw_semaphore___5 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___4 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___6 *pgtable_t___4;

struct dev_pagemap___4;

struct page___6 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___4 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___6 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___4 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___5 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___4 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___4;

struct lruvec___4 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___4 *pgdat;
};

struct zone___4 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___4 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___4 {
	struct zone___4 *zone;
	int zone_idx;
};

struct zonelist___4 {
	struct zoneref___4 _zonerefs[25];
};

struct pglist_data___4 {
	struct zone___4 node_zones[3];
	struct zonelist___4 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___6 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___6 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___4 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___5 {
	void *stack;
	struct task_struct___6 *task;
	long int status;
};

struct blocking_notifier_head___4 {
	struct rw_semaphore___5 rwsem;
	struct notifier_block *head;
};

struct upid___4 {
	int nr;
	struct pid_namespace___4 *ns;
};

struct pid_namespace___4 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___6 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___4 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___6 *proc_self;
	struct dentry___6 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___5 *user_ns;
	struct ucounts___4 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common ns;
};

struct pid___4 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___4 numbers[1];
};

struct vm_operations_struct___4;

struct vm_area_struct___6 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___6 *vm_next;
	struct vm_area_struct___6 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___5 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___4 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___5 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___4;

struct mm_struct___5 {
	struct {
		struct vm_area_struct___6 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___5 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___5 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___4 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___6 *owner;
		struct user_namespace___5 *user_ns;
		struct file___5 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___4 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___4)(struct vm_area_struct___6 *, long unsigned int, const struct page___6 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___4)(struct page___6 *, void *);

struct device___5;

struct dev_pagemap___4 {
	dev_page_fault_t___4 page_fault;
	dev_page_free_t___4 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___5 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct fown_struct___4 {
	rwlock_t lock;
	struct pid___4 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___5 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___4 f_path;
	struct inode___7 *f_inode;
	const struct file_operations___5 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___4 f_owner;
	const struct cred___5 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___4 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___4;

struct vm_operations_struct___4 {
	void (*open)(struct vm_area_struct___6 *);
	void (*close)(struct vm_area_struct___6 *);
	int (*split)(struct vm_area_struct___6 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___6 *);
	vm_fault_t (*fault)(struct vm_fault___4 *);
	vm_fault_t (*huge_fault)(struct vm_fault___4 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___4 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___6 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___4 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___4 *);
	int (*access)(struct vm_area_struct___6 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___6 *);
	int (*set_policy)(struct vm_area_struct___6 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___6 *, long unsigned int);
	struct page___6 * (*find_special_page)(struct vm_area_struct___6 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___4 {
	struct task_struct___6 *task;
	struct core_thread___4 *next;
};

struct core_state___4 {
	atomic_t nr_threads;
	struct core_thread___4 dumper;
	struct completion startup;
};

struct vm_fault___4 {
	struct vm_area_struct___6 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___6 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___6 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___4 prealloc_pte;
};

struct user_struct___5 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___6 *uid_keyring;
	struct key___6 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___5 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___6 *session_keyring;
	struct key___6 *process_keyring;
	struct key___6 *thread_keyring;
	struct key___6 *request_key_auth;
	void *security;
	struct user_struct___5 *user;
	struct user_namespace___5 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___5;

struct nsproxy___5 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___4 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___5 *cgroup_ns;
};

struct signal_struct___5 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___6 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___6 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___4 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___4 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___5 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___4 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___4;

struct cgroup___4;

struct css_set___5 {
	struct cgroup_subsys_state___4 *subsys[13];
	refcount_t refcount;
	struct css_set___5 *dom_cset;
	struct cgroup___4 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___4 *mg_src_cgrp;
	struct cgroup___4 *mg_dst_cgrp;
	struct css_set___5 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___5 {
	struct pmu___4 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___6 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___5 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___2 {
	struct vm_struct___2 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___6 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___4 {
	struct task_struct___6 task;
	long unsigned int stack[8192];
};

struct kiocb___5 {
	struct file___5 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___5 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___5 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___5 *ia_file;
};

struct dquot___4 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___5 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___4 {
	int qf_fmt_id;
	const struct quota_format_ops___4 *qf_ops;
	struct module___7 *qf_owner;
	struct quota_format_type___4 *qf_next;
};

struct quota_format_ops___4 {
	int (*check_quota_file)(struct super_block___5 *, int);
	int (*read_file_info)(struct super_block___5 *, int);
	int (*write_file_info)(struct super_block___5 *, int);
	int (*free_file_info)(struct super_block___5 *, int);
	int (*read_dqblk)(struct dquot___4 *);
	int (*commit_dqblk)(struct dquot___4 *);
	int (*release_dqblk)(struct dquot___4 *);
	int (*get_next_id)(struct super_block___5 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___4 {
	int (*write_dquot)(struct dquot___4 *);
	struct dquot___4 * (*alloc_dquot)(struct super_block___5 *, int);
	void (*destroy_dquot)(struct dquot___4 *);
	int (*acquire_dquot)(struct dquot___4 *);
	int (*release_dquot)(struct dquot___4 *);
	int (*mark_dirty)(struct dquot___4 *);
	int (*write_info)(struct super_block___5 *, int);
	qsize_t * (*get_reserved_space)(struct inode___7 *);
	int (*get_projid)(struct inode___7 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___7 *, qsize_t *);
	int (*get_next_id)(struct super_block___5 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___4 {
	int (*quota_on)(struct super_block___5 *, int, int, const struct path___4 *);
	int (*quota_off)(struct super_block___5 *, int);
	int (*quota_enable)(struct super_block___5 *, unsigned int);
	int (*quota_disable)(struct super_block___5 *, unsigned int);
	int (*quota_sync)(struct super_block___5 *, int);
	int (*set_info)(struct super_block___5 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___5 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___5 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___5 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___5 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___5 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___4;

struct kobj_type___4;

struct kernfs_node___4;

struct kobject___4 {
	const char *name;
	struct list_head entry;
	struct kobject___4 *parent;
	struct kset___4 *kset;
	struct kobj_type___4 *ktype;
	struct kernfs_node___4 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___4 {
	struct kobject___4 kobj;
	struct module___7 *mod;
	struct kobject___4 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___4 {
	struct module___7 *mod;
	struct latch_tree_node node;
};

struct module_layout___4 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___4 mtn;
};

struct module_attribute___4;

struct kernel_param___4;

struct module___7 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___4 mkobj;
	struct module_attribute___4 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___4 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___4 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___4 core_layout;
	struct module_layout___4 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___4 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___4 {
	int (*writepage)(struct page___6 *, struct writeback_control___3 *);
	int (*readpage)(struct file___5 *, struct page___6 *);
	int (*writepages)(struct address_space___4 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___6 *);
	int (*readpages)(struct file___5 *, struct address_space___4 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___5 *, struct address_space___4 *, loff_t, unsigned int, unsigned int, struct page___6 **, void **);
	int (*write_end)(struct file___5 *, struct address_space___4 *, loff_t, unsigned int, unsigned int, struct page___6 *, void *);
	sector_t (*bmap)(struct address_space___4 *, sector_t);
	void (*invalidatepage)(struct page___6 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___6 *, gfp_t);
	void (*freepage)(struct page___6 *);
	ssize_t (*direct_IO)(struct kiocb___5 *, struct iov_iter___4 *);
	int (*migratepage)(struct address_space___4 *, struct page___6 *, struct page___6 *, enum migrate_mode);
	bool (*isolate_page)(struct page___6 *, isolate_mode_t);
	void (*putback_page)(struct page___6 *);
	int (*launder_page)(struct page___6 *);
	int (*is_partially_uptodate)(struct page___6 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___6 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___4 *, struct page___6 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___5 *, sector_t *);
	void (*swap_deactivate)(struct file___5 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct hd_struct___4;

struct gendisk___4;

struct block_device___5 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___7 *bd_inode;
	struct super_block___5 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___5 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___4 {
	struct dentry___6 * (*lookup)(struct inode___7 *, struct dentry___6 *, unsigned int);
	const char * (*get_link)(struct dentry___6 *, struct inode___7 *, struct delayed_call *);
	int (*permission)(struct inode___7 *, int);
	struct posix_acl * (*get_acl)(struct inode___7 *, int);
	int (*readlink)(struct dentry___6 *, char *, int);
	int (*create)(struct inode___7 *, struct dentry___6 *, umode_t, bool);
	int (*link)(struct dentry___6 *, struct inode___7 *, struct dentry___6 *);
	int (*unlink)(struct inode___7 *, struct dentry___6 *);
	int (*symlink)(struct inode___7 *, struct dentry___6 *, const char *);
	int (*mkdir)(struct inode___7 *, struct dentry___6 *, umode_t);
	int (*rmdir)(struct inode___7 *, struct dentry___6 *);
	int (*mknod)(struct inode___7 *, struct dentry___6 *, umode_t, dev_t);
	int (*rename)(struct inode___7 *, struct dentry___6 *, struct inode___7 *, struct dentry___6 *, unsigned int);
	int (*setattr)(struct dentry___6 *, struct iattr___5 *);
	int (*getattr)(const struct path___4 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___6 *, char *, size_t);
	int (*fiemap)(struct inode___7 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___7 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___7 *, struct dentry___6 *, struct file___5 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___7 *, struct dentry___6 *, umode_t);
	int (*set_acl)(struct inode___7 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___4 {
	void (*fl_copy_lock)(struct file_lock___5 *, struct file_lock___5 *);
	void (*fl_release_private)(struct file_lock___5 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___4;

struct file_lock___5 {
	struct file_lock___5 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___5 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___4 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___4 *fl_ops;
	const struct lock_manager_operations___4 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___4 {
	int (*lm_compare_owner)(struct file_lock___5 *, struct file_lock___5 *);
	long unsigned int (*lm_owner_key)(struct file_lock___5 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___5 *);
	int (*lm_grant)(struct file_lock___5 *, int);
	bool (*lm_break)(struct file_lock___5 *);
	int (*lm_change)(struct file_lock___5 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___5 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___4 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___4 *fa_next;
	struct file___5 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___4 {
	const char *name;
	int fs_flags;
	struct dentry___6 * (*mount)(struct file_system_type___4 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___5 *);
	struct module___7 *owner;
	struct file_system_type___4 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___4 {
	struct inode___7 * (*alloc_inode)(struct super_block___5 *);
	void (*destroy_inode)(struct inode___7 *);
	void (*dirty_inode)(struct inode___7 *, int);
	int (*write_inode)(struct inode___7 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___7 *);
	void (*evict_inode)(struct inode___7 *);
	void (*put_super)(struct super_block___5 *);
	int (*sync_fs)(struct super_block___5 *, int);
	int (*freeze_super)(struct super_block___5 *);
	int (*freeze_fs)(struct super_block___5 *);
	int (*thaw_super)(struct super_block___5 *);
	int (*unfreeze_fs)(struct super_block___5 *);
	int (*statfs)(struct dentry___6 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___5 *, int *, char *);
	void (*umount_begin)(struct super_block___5 *);
	int (*show_options)(struct seq_file___8 *, struct dentry___6 *);
	int (*show_devname)(struct seq_file___8 *, struct dentry___6 *);
	int (*show_path)(struct seq_file___8 *, struct dentry___6 *);
	int (*show_stats)(struct seq_file___8 *, struct dentry___6 *);
	ssize_t (*quota_read)(struct super_block___5 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___5 *, int, const char *, size_t, loff_t);
	struct dquot___4 ** (*get_dquots)(struct inode___7 *);
	int (*bdev_try_to_free_page)(struct super_block___5 *, struct page___6 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___5 *, struct shrink_control *);
	long int (*free_cached_objects)(struct super_block___5 *, struct shrink_control *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___4)(struct file___5 *, wait_queue_head_t *, struct poll_table_struct___5 *);

struct poll_table_struct___5 {
	poll_queue_proc___4 _qproc;
	__poll_t _key;
};

struct seq_operations___5;

struct seq_file___8 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___5 *op;
	int poll_event;
	const struct file___5 *file;
	void *private;
};

typedef int (*key_restrict_link_func_t___4)(struct key___6 *, const struct key_type *, const union key_payload *, struct key___6 *);

struct key_restriction___5;

struct key___6 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___5 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___5 *restrict_link;
};

struct key_restriction___5 {
	key_restrict_link_func_t___4 check;
	struct key___6 *key;
	struct key_type *keytype;
};

struct dev_pm_info___4 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___5 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___4;

struct bus_type___4;

struct device_driver___4;

struct dev_pm_domain___4;

struct fwnode_handle___4;

struct class___4;

struct attribute_group___4;

struct device___5 {
	struct device___5 *parent;
	struct device_private *p;
	struct kobject___4 kobj;
	const char *init_name;
	const struct device_type___4 *type;
	struct mutex mutex;
	struct bus_type___4 *bus;
	struct device_driver___4 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___4 power;
	struct dev_pm_domain___4 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___4 *class;
	const struct attribute_group___4 **groups;
	void (*release)(struct device___5 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct kobj_attribute___4 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___4 *, struct kobj_attribute___4 *, char *);
	ssize_t (*store)(struct kobject___4 *, struct kobj_attribute___4 *, const char *, size_t);
};

typedef void compound_page_dtor___4(struct page___6 *);

struct seq_operations___5 {
	void * (*start)(struct seq_file___8 *, loff_t *);
	void (*stop)(struct seq_file___8 *, void *);
	void * (*next)(struct seq_file___8 *, void *, loff_t *);
	int (*show)(struct seq_file___8 *, void *);
};

struct cgroup_namespace___5 {
	refcount_t count;
	struct ns_common ns;
	struct user_namespace___5 *user_ns;
	struct ucounts___4 *ucounts;
	struct css_set___5 *root_cset;
};

struct ucounts___4 {
	struct hlist_node node;
	struct user_namespace___5 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct elf64_hdr {
	unsigned char e_ident[16];
	Elf64_Half e_type;
	Elf64_Half e_machine;
	Elf64_Word e_version;
	Elf64_Addr e_entry;
	Elf64_Off e_phoff;
	Elf64_Off e_shoff;
	Elf64_Word e_flags;
	Elf64_Half e_ehsize;
	Elf64_Half e_phentsize;
	Elf64_Half e_phnum;
	Elf64_Half e_shentsize;
	Elf64_Half e_shnum;
	Elf64_Half e_shstrndx;
};

typedef struct elf64_hdr Elf64_Ehdr;

typedef struct elf64_shdr Elf64_Shdr;

struct kernfs_root___4;

struct kernfs_elem_dir___4 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___4 *root;
};

struct kernfs_syscall_ops___4;

struct kernfs_root___4 {
	struct kernfs_node___4 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___4 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___4 {
	struct kernfs_node___4 *target_kn;
};

struct kernfs_ops___4;

struct kernfs_elem_attr___4 {
	const struct kernfs_ops___4 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___4 *notify_next;
};

struct kernfs_node___4 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___4 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___4 dir;
		struct kernfs_elem_symlink___4 symlink;
		struct kernfs_elem_attr___4 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___4;

struct kernfs_ops___4 {
	int (*open)(struct kernfs_open_file___4 *);
	void (*release)(struct kernfs_open_file___4 *);
	int (*seq_show)(struct seq_file___8 *, void *);
	void * (*seq_start)(struct seq_file___8 *, loff_t *);
	void * (*seq_next)(struct seq_file___8 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___8 *, void *);
	ssize_t (*read)(struct kernfs_open_file___4 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___4 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___4 *, struct vm_area_struct___6 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___4 *, struct poll_table_struct___5 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___4 {
	int (*remount_fs)(struct kernfs_root___4 *, int *, char *);
	int (*show_options)(struct seq_file___8 *, struct kernfs_root___4 *);
	int (*mkdir)(struct kernfs_node___4 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___4 *);
	int (*rename)(struct kernfs_node___4 *, struct kernfs_node___4 *, const char *);
	int (*show_path)(struct seq_file___8 *, struct kernfs_node___4 *, struct kernfs_root___4 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___4 {
	struct kernfs_node___4 *kn;
	struct file___5 *file;
	struct seq_file___8 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___4 *vm_ops;
};

struct bin_attribute___4;

struct attribute_group___4 {
	const char *name;
	umode_t (*is_visible)(struct kobject___4 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___4 *, struct bin_attribute___4 *, int);
	struct attribute **attrs;
	struct bin_attribute___4 **bin_attrs;
};

struct bin_attribute___4 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___5 *, struct kobject___4 *, struct bin_attribute___4 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___5 *, struct kobject___4 *, struct bin_attribute___4 *, char *, loff_t, size_t);
	int (*mmap)(struct file___5 *, struct kobject___4 *, struct bin_attribute___4 *, struct vm_area_struct___6 *);
};

struct sysfs_ops___4 {
	ssize_t (*show)(struct kobject___4 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___4 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___4;

struct kset___4 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___4 kobj;
	const struct kset_uevent_ops___4 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___4 {
	void (*release)(struct kobject___4 *);
	const struct sysfs_ops___4 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___4 *);
	const void * (*namespace)(struct kobject___4 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___4 {
	int (* const filter)(struct kset___4 *, struct kobject___4 *);
	const char * (* const name)(struct kset___4 *, struct kobject___4 *);
	int (* const uevent)(struct kset___4 *, struct kobject___4 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___4 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___4 *);
	int (*get)(char *, const struct kernel_param___4 *);
	void (*free)(void *);
};

struct kparam_array___4;

struct kernel_param___4 {
	const char *name;
	struct module___7 *mod;
	const struct kernel_param_ops___4 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___4 *arr;
	};
};

struct kparam_array___4 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___4 *ops;
	void *elem;
};

struct module_attribute___4 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___4 *, struct module_kobject___4 *, char *);
	ssize_t (*store)(struct module_attribute___4 *, struct module_kobject___4 *, const char *, size_t);
	void (*setup)(struct module___7 *, const char *);
	int (*test)(struct module___7 *);
	void (*free)(struct module___7 *);
};

struct trace_event_class___4;

struct trace_event_call___4 {
	struct list_head list;
	struct trace_event_class___4 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array *prog_array;
	int (*perf_perm)(struct trace_event_call___4 *, struct perf_event___4 *);
};

struct dev_pm_ops___4 {
	int (*prepare)(struct device___5 *);
	void (*complete)(struct device___5 *);
	int (*suspend)(struct device___5 *);
	int (*resume)(struct device___5 *);
	int (*freeze)(struct device___5 *);
	int (*thaw)(struct device___5 *);
	int (*poweroff)(struct device___5 *);
	int (*restore)(struct device___5 *);
	int (*suspend_late)(struct device___5 *);
	int (*resume_early)(struct device___5 *);
	int (*freeze_late)(struct device___5 *);
	int (*thaw_early)(struct device___5 *);
	int (*poweroff_late)(struct device___5 *);
	int (*restore_early)(struct device___5 *);
	int (*suspend_noirq)(struct device___5 *);
	int (*resume_noirq)(struct device___5 *);
	int (*freeze_noirq)(struct device___5 *);
	int (*thaw_noirq)(struct device___5 *);
	int (*poweroff_noirq)(struct device___5 *);
	int (*restore_noirq)(struct device___5 *);
	int (*runtime_suspend)(struct device___5 *);
	int (*runtime_resume)(struct device___5 *);
	int (*runtime_idle)(struct device___5 *);
};

struct dev_pm_domain___4 {
	struct dev_pm_ops___4 ops;
	void (*detach)(struct device___5 *, bool);
	int (*activate)(struct device___5 *);
	void (*sync)(struct device___5 *);
	void (*dismiss)(struct device___5 *);
};

struct bus_type___4 {
	const char *name;
	const char *dev_name;
	struct device___5 *dev_root;
	const struct attribute_group___4 **bus_groups;
	const struct attribute_group___4 **dev_groups;
	const struct attribute_group___4 **drv_groups;
	int (*match)(struct device___5 *, struct device_driver___4 *);
	int (*uevent)(struct device___5 *, struct kobj_uevent_env *);
	int (*probe)(struct device___5 *);
	int (*remove)(struct device___5 *);
	void (*shutdown)(struct device___5 *);
	int (*online)(struct device___5 *);
	int (*offline)(struct device___5 *);
	int (*suspend)(struct device___5 *, pm_message_t);
	int (*resume)(struct device___5 *);
	int (*num_vf)(struct device___5 *);
	int (*dma_configure)(struct device___5 *);
	const struct dev_pm_ops___4 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___4 {
	const char *name;
	struct bus_type___4 *bus;
	struct module___7 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___5 *);
	int (*remove)(struct device___5 *);
	void (*shutdown)(struct device___5 *);
	int (*suspend)(struct device___5 *, pm_message_t);
	int (*resume)(struct device___5 *);
	const struct attribute_group___4 **groups;
	const struct dev_pm_ops___4 *pm;
	void (*coredump)(struct device___5 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___4 {
	const char *name;
	const struct attribute_group___4 **groups;
	int (*uevent)(struct device___5 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___5 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___5 *);
	const struct dev_pm_ops___4 *pm;
};

struct class___4 {
	const char *name;
	struct module___7 *owner;
	const struct attribute_group___4 **class_groups;
	const struct attribute_group___4 **dev_groups;
	struct kobject___4 *dev_kobj;
	int (*dev_uevent)(struct device___5 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___5 *, umode_t *);
	void (*class_release)(struct class___4 *);
	void (*dev_release)(struct device___5 *);
	int (*shutdown_pre)(struct device___5 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___5 *);
	const struct dev_pm_ops___4 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct fwnode_operations___4;

struct fwnode_handle___4 {
	struct fwnode_handle___4 *secondary;
	const struct fwnode_operations___4 *ops;
};

struct node___4 {
	struct device___5 dev;
};

struct bpf_map___4;

struct bpf_map_ops___4 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___4 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___4 *, struct file___5 *);
	void (*map_free)(struct bpf_map___4 *);
	int (*map_get_next_key)(struct bpf_map___4 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___4 *);
	void * (*map_lookup_elem)(struct bpf_map___4 *, void *);
	int (*map_update_elem)(struct bpf_map___4 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___4 *, void *);
	int (*map_push_elem)(struct bpf_map___4 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___4 *, void *);
	int (*map_peek_elem)(struct bpf_map___4 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___4 *, struct file___5 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___4 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___4 *, void *, struct seq_file___8 *);
	int (*map_check_btf)(const struct bpf_map___4 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___4 {
	const struct bpf_map_ops___4 *ops;
	struct bpf_map___4 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___5 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___4;

typedef void (*kthread_work_func_t___4)(struct kthread_work___4 *);

struct kthread_worker___4;

struct kthread_work___4 {
	struct list_head node;
	kthread_work_func_t___4 func;
	struct kthread_worker___4 *worker;
	int canceling;
};

struct kthread_worker___4 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___6 *task;
	struct kthread_work___4 *current_work;
};

struct kthread_delayed_work___4 {
	struct kthread_work___4 work;
	struct timer_list timer;
};

struct psi_group___4 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___4 *poll_kworker;
	struct kthread_delayed_work___4 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___4 {
	struct kernfs_node___4 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___4;

struct cgroup_subsys_state___4 {
	struct cgroup___4 *cgroup;
	struct cgroup_subsys___4 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___4 *parent;
};

struct cgroup_root___4;

struct cgroup_rstat_cpu___4;

struct cgroup___4 {
	struct cgroup_subsys_state___4 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___4 *kn;
	struct cgroup_file___4 procs_file;
	struct cgroup_file___4 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___4 *subsys[13];
	struct cgroup_root___4 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___4 *dom_cgrp;
	struct cgroup_rstat_cpu___4 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf bpf;
	atomic_t congestion_count;
	struct cgroup___4 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___4 psi;
	int ancestor_ids[0];
};

struct cftype___4;

struct cgroup_subsys___4 {
	struct cgroup_subsys_state___4 * (*css_alloc)(struct cgroup_subsys_state___4 *);
	int (*css_online)(struct cgroup_subsys_state___4 *);
	void (*css_offline)(struct cgroup_subsys_state___4 *);
	void (*css_released)(struct cgroup_subsys_state___4 *);
	void (*css_free)(struct cgroup_subsys_state___4 *);
	void (*css_reset)(struct cgroup_subsys_state___4 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___4 *, int);
	int (*css_extra_stat_show)(struct seq_file___8 *, struct cgroup_subsys_state___4 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___6 *);
	void (*cancel_fork)(struct task_struct___6 *);
	void (*fork)(struct task_struct___6 *);
	void (*exit)(struct task_struct___6 *);
	void (*free)(struct task_struct___6 *);
	void (*bind)(struct cgroup_subsys_state___4 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___4 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___4 *dfl_cftypes;
	struct cftype___4 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___4 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___4 *updated_children;
	struct cgroup___4 *updated_next;
};

struct cgroup_root___4 {
	struct kernfs_root___4 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___4 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___4 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___4 *ss;
	struct list_head node;
	struct kernfs_ops___4 *kf_ops;
	int (*open)(struct kernfs_open_file___4 *);
	void (*release)(struct kernfs_open_file___4 *);
	u64 (*read_u64)(struct cgroup_subsys_state___4 *, struct cftype___4 *);
	s64 (*read_s64)(struct cgroup_subsys_state___4 *, struct cftype___4 *);
	int (*seq_show)(struct seq_file___8 *, void *);
	void * (*seq_start)(struct seq_file___8 *, loff_t *);
	void * (*seq_next)(struct seq_file___8 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___8 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___4 *, struct cftype___4 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___4 *, struct cftype___4 *, s64);
	ssize_t (*write)(struct kernfs_open_file___4 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___4 *, struct poll_table_struct___5 *);
};

struct perf_cpu_context___4;

struct pmu___4 {
	struct list_head entry;
	struct module___7 *module;
	struct device___5 *dev;
	const struct attribute_group___4 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___4 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___4 *);
	void (*pmu_disable)(struct pmu___4 *);
	int (*event_init)(struct perf_event___4 *);
	void (*event_mapped)(struct perf_event___4 *, struct mm_struct___5 *);
	void (*event_unmapped)(struct perf_event___4 *, struct mm_struct___5 *);
	int (*add)(struct perf_event___4 *, int);
	void (*del)(struct perf_event___4 *, int);
	void (*start)(struct perf_event___4 *, int);
	void (*stop)(struct perf_event___4 *, int);
	void (*read)(struct perf_event___4 *);
	void (*start_txn)(struct pmu___4 *, unsigned int);
	int (*commit_txn)(struct pmu___4 *);
	void (*cancel_txn)(struct pmu___4 *);
	int (*event_idx)(struct perf_event___4 *);
	void (*sched_task)(struct perf_event_context___5 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___4 *);
	int (*filter_match)(struct perf_event___4 *);
	int (*check_period)(struct perf_event___4 *, u64);
};

struct perf_cpu_context___4 {
	struct perf_event_context___5 ctx;
	struct perf_event_context___5 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___4 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___4 {
	struct cgroup_subsys_state___4 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___4 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___4 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___4 *);
	struct list_head * (*get_fields)(struct trace_event_call___4 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___4 *);
};

struct hash {
	int ino;
	int minor;
	int major;
	umode_t mode;
	struct hash *next;
	char name[4098];
};

struct dir_entry {
	struct list_head list;
	char *name;
	time64_t mtime;
};

enum state {
	Start = 0,
	Collect = 1,
	GotHeader = 2,
	SkipIt = 3,
	GotName = 4,
	CopyFile = 5,
	GotSymlink = 6,
	Reset = 7,
};

typedef int (*decompress_fn)(unsigned char *, long int, long int (*)(void *, long unsigned int), long int (*)(void *, long unsigned int), unsigned char *, long int *, void (*)(char *));

typedef u32 note_buf_t[106];

struct fwnode_reference_args___4;

struct fwnode_endpoint___4;

struct fwnode_operations___4 {
	struct fwnode_handle___4 * (*get)(struct fwnode_handle___4 *);
	void (*put)(struct fwnode_handle___4 *);
	bool (*device_is_available)(const struct fwnode_handle___4 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___4 *, const struct device___5 *);
	bool (*property_present)(const struct fwnode_handle___4 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___4 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___4 *, const char *, const char **, size_t);
	struct fwnode_handle___4 * (*get_parent)(const struct fwnode_handle___4 *);
	struct fwnode_handle___4 * (*get_next_child_node)(const struct fwnode_handle___4 *, struct fwnode_handle___4 *);
	struct fwnode_handle___4 * (*get_named_child_node)(const struct fwnode_handle___4 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___4 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___4 *);
	struct fwnode_handle___4 * (*graph_get_next_endpoint)(const struct fwnode_handle___4 *, struct fwnode_handle___4 *);
	struct fwnode_handle___4 * (*graph_get_remote_endpoint)(const struct fwnode_handle___4 *);
	struct fwnode_handle___4 * (*graph_get_port_parent)(struct fwnode_handle___4 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___4 *, struct fwnode_endpoint___4 *);
};

struct fwnode_endpoint___4 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___4 *local_fwnode;
};

struct fwnode_reference_args___4 {
	struct fwnode_handle___4 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct kimage_arch {
	void *dtb;
	long unsigned int dtb_mem;
};

typedef int kexec_probe_t(const char *, long unsigned int);

struct kimage;

typedef void *kexec_load_t(struct kimage *, char *, long unsigned int, char *, long unsigned int, char *, long unsigned int);

typedef int kexec_cleanup_t(void *);

struct kexec_file_ops {
	kexec_probe_t *probe;
	kexec_load_t *load;
	kexec_cleanup_t *cleanup;
};

typedef long unsigned int kimage_entry_t;

struct kexec_segment {
	union {
		void *buf;
		void *kbuf;
	};
	size_t bufsz;
	long unsigned int mem;
	size_t memsz;
};

struct purgatory_info {
	const Elf64_Ehdr *ehdr;
	Elf64_Shdr *sechdrs;
	void *purgatory_buf;
};

struct kimage {
	kimage_entry_t head;
	kimage_entry_t *entry;
	kimage_entry_t *last_entry;
	long unsigned int start;
	struct page___6 *control_code_page;
	struct page___6 *swap_page;
	void *vmcoreinfo_data_copy;
	long unsigned int nr_segments;
	struct kexec_segment segment[16];
	struct list_head control_pages;
	struct list_head dest_pages;
	struct list_head unusable_pages;
	long unsigned int control_page;
	unsigned int type: 1;
	unsigned int preserve_context: 1;
	unsigned int file_mode: 1;
	struct kimage_arch arch;
	void *kernel_buf;
	long unsigned int kernel_buf_len;
	void *initrd_buf;
	long unsigned int initrd_buf_len;
	char *cmdline_buf;
	long unsigned int cmdline_buf_len;
	const struct kexec_file_ops *fops;
	void *image_loader_data;
	struct purgatory_info purgatory_info;
};

struct module___8;

struct file___6;

struct kiocb___6;

struct poll_table_struct___6;

struct vm_area_struct___7;

struct inode___8;

struct file_lock___6;

struct page___7;

struct seq_file___9;

struct file_operations___6 {
	struct module___8 *owner;
	loff_t (*llseek)(struct file___6 *, loff_t, int);
	ssize_t (*read)(struct file___6 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___6 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___6 *, struct iov_iter___4 *);
	ssize_t (*write_iter)(struct kiocb___6 *, struct iov_iter___4 *);
	int (*iopoll)(struct kiocb___6 *, bool);
	int (*iterate)(struct file___6 *, struct dir_context *);
	int (*iterate_shared)(struct file___6 *, struct dir_context *);
	__poll_t (*poll)(struct file___6 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___6 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___6 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___6 *, struct vm_area_struct___7 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___8 *, struct file___6 *);
	int (*flush)(struct file___6 *, fl_owner_t);
	int (*release)(struct inode___8 *, struct file___6 *);
	int (*fsync)(struct file___6 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___6 *, int);
	int (*lock)(struct file___6 *, int, struct file_lock___6 *);
	ssize_t (*sendpage)(struct file___6 *, struct page___7 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___6 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___6 *, int, struct file_lock___6 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___6 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___6 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___6 *, long int, struct file_lock___6 **, void **);
	long int (*fallocate)(struct file___6 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___6 *);
	ssize_t (*copy_file_range)(struct file___6 *, loff_t, struct file___6 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___6 *, loff_t, struct file___6 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___6 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___5 {
	u64 seqnum;
	struct vm_area_struct___7 *vmas[4];
};

struct page_frag___5 {
	struct page___7 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___6;

struct pid___5;

struct cred___6;

struct nsproxy___6;

struct signal_struct___6;

struct vm_struct___5;

struct task_struct___7 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___7 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___6 *mm;
	struct mm_struct___6 *active_mm;
	struct vmacache___5 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___7 *real_parent;
	struct task_struct___7 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___7 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___5 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___5 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___5 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___6 *ptracer_cred;
	const struct cred___6 *real_cred;
	const struct cred___6 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___6 *nsproxy;
	struct signal_struct___6 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___7 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___4 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___5 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___7 *oom_reaper_list;
	struct vm_struct___5 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___4 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___5;

struct upid___5 {
	int nr;
	struct pid_namespace___5 *ns;
};

struct dentry___7;

struct user_namespace___6;

struct ucounts___5;

struct pid_namespace___5 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___7 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___5 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___7 *proc_self;
	struct dentry___7 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___6 *user_ns;
	struct ucounts___5 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common ns;
};

struct pid___5 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___5 numbers[1];
};

struct rw_semaphore___6 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___7 *owner;
};

struct key___7;

struct user_namespace___6 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___6 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common ns;
	long unsigned int flags;
	struct key___7 *persistent_keyring_register;
	struct rw_semaphore___6 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___5 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct secondary_data___6 {
	void *stack;
	struct task_struct___7 *task;
	long int status;
};

typedef struct page___7 *pgtable_t___5;

struct address_space___5;

struct dev_pagemap___5;

struct page___7 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___5 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___7 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___5 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___6 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___5 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct user_struct___6 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___7 *uid_keyring;
	struct key___7 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___5;

struct vm_area_struct___7 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___7 *vm_next;
	struct vm_area_struct___7 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___6 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___5 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___6 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___5;

struct mm_struct___6 {
	struct {
		struct vm_area_struct___7 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___6 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___6 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___5 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___7 *owner;
		struct user_namespace___6 *user_ns;
		struct file___6 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___5 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___6 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___7 *session_keyring;
	struct key___7 *process_keyring;
	struct key___7 *thread_keyring;
	struct key___7 *request_key_auth;
	void *security;
	struct user_struct___6 *user;
	struct user_namespace___6 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct nsproxy___6 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___5 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct signal_struct___6 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___7 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___7 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___5 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___5 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___6 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___5 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct fasync_struct___5;

struct pipe_buffer___2;

struct pipe_inode_info {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___7 *tmp_page;
	struct fasync_struct___5 *fasync_readers;
	struct fasync_struct___5 *fasync_writers;
	struct pipe_buffer___2 *bufs;
	struct user_struct___6 *user;
};

struct vm_struct___5 {
	struct vm_struct___5 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___7 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___5 {
	struct task_struct___7 task;
	long unsigned int stack[8192];
};

struct uts_namespace___3 {
	struct kref kref;
	struct new_utsname name;
	struct user_namespace___6 *user_ns;
	struct ucounts___5 *ucounts;
	struct ns_common ns;
};

struct dst_entry___2;

struct neighbour___2;

struct dst_ops___2 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___2 *);
	struct dst_entry___2 * (*check)(struct dst_entry___2 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___2 *);
	unsigned int (*mtu)(const struct dst_entry___2 *);
	u32 * (*cow_metrics)(struct dst_entry___2 *, long unsigned int);
	void (*destroy)(struct dst_entry___2 *);
	void (*ifdown)(struct dst_entry___2 *, struct net_device *, int);
	struct dst_entry___2 * (*negative_advice)(struct dst_entry___2 *);
	void (*link_failure)(struct sk_buff *);
	void (*update_pmtu)(struct dst_entry___2 *, struct sock *, struct sk_buff *, u32);
	void (*redirect)(struct dst_entry___2 *, struct sock *, struct sk_buff *);
	int (*local_out)(struct net *, struct sock *, struct sk_buff *);
	struct neighbour___2 * (*neigh_lookup)(const struct dst_entry___2 *, struct sk_buff *, const void *);
	void (*confirm_neigh)(const struct dst_entry___2 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___2 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___2 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct sock *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops *notifier_ops;
	struct fib_notifier_ops *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_xfrm___2 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___2 xfrm4_dst_ops;
	struct dst_ops___2 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct net {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___6 *user_ns;
	struct ucounts___5 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4 ipv4;
	struct netns_ipv6___2 ipv6;
	struct netns_sctp sctp;
	struct netns_nf nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock *nfnl;
	struct sock *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___2 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ucounts___5 {
	struct hlist_node node;
	struct user_namespace___6 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct pglist_data___5;

struct lruvec___5 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___5 *pgdat;
};

struct zone___5 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___5 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___5 {
	struct zone___5 *zone;
	int zone_idx;
};

struct zonelist___5 {
	struct zoneref___5 _zonerefs[25];
};

struct pglist_data___5 {
	struct zone___5 node_zones[3];
	struct zonelist___5 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___7 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___7 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___5 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___5 {
	struct rw_semaphore___6 rwsem;
	struct notifier_block *head;
};

struct address_space_operations___5;

struct address_space___5 {
	struct inode___8 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___6 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___5 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___5)(struct vm_area_struct___7 *, long unsigned int, const struct page___7 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___5)(struct page___7 *, void *);

struct device___6;

struct dev_pagemap___5 {
	dev_page_fault_t___5 page_fault;
	dev_page_free_t___5 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___6 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___5 {
	struct vfsmount *mnt;
	struct dentry___7 *dentry;
};

struct fown_struct___5 {
	rwlock_t lock;
	struct pid___5 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___6 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___5 f_path;
	struct inode___8 *f_inode;
	const struct file_operations___6 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___5 f_owner;
	const struct cred___6 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___5 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___5;

struct vm_operations_struct___5 {
	void (*open)(struct vm_area_struct___7 *);
	void (*close)(struct vm_area_struct___7 *);
	int (*split)(struct vm_area_struct___7 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___7 *);
	vm_fault_t (*fault)(struct vm_fault___5 *);
	vm_fault_t (*huge_fault)(struct vm_fault___5 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___5 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___7 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___5 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___5 *);
	int (*access)(struct vm_area_struct___7 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___7 *);
	int (*set_policy)(struct vm_area_struct___7 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___7 *, long unsigned int);
	struct page___7 * (*find_special_page)(struct vm_area_struct___7 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___5 {
	struct task_struct___7 *task;
	struct core_thread___5 *next;
};

struct core_state___5 {
	atomic_t nr_threads;
	struct core_thread___5 dumper;
	struct completion startup;
};

struct vm_fault___5 {
	struct vm_area_struct___7 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___7 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___7 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___5 prealloc_pte;
};

struct kset___5;

struct kobj_type___5;

struct kernfs_node___5;

struct kobject___5 {
	const char *name;
	struct list_head entry;
	struct kobject___5 *parent;
	struct kset___5 *kset;
	struct kobj_type___5 *ktype;
	struct kernfs_node___5 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___5 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___6 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___5;

struct bus_type___5;

struct device_driver___5;

struct dev_pm_domain___5;

struct dma_map_ops___3;

struct fwnode_handle___5;

struct class___5;

struct attribute_group___5;

struct device___6 {
	struct device___6 *parent;
	struct device_private *p;
	struct kobject___5 kobj;
	const char *init_name;
	const struct device_type___5 *type;
	struct mutex mutex;
	struct bus_type___5 *bus;
	struct device_driver___5 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___5 power;
	struct dev_pm_domain___5 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___3 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___5 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___5 *class;
	const struct attribute_group___5 **groups;
	void (*release)(struct device___6 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___5;

struct super_block___6;

struct dentry___7 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___7 *d_parent;
	struct qstr d_name;
	struct inode___8 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___5 *d_op;
	struct super_block___6 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___5;

struct block_device___6;

struct inode___8 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___5 *i_op;
	struct super_block___6 *i_sb;
	struct address_space___5 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___6 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___6 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___5 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___6 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___5 {
	int (*d_revalidate)(struct dentry___7 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___7 *, unsigned int);
	int (*d_hash)(const struct dentry___7 *, struct qstr *);
	int (*d_compare)(const struct dentry___7 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___7 *);
	int (*d_init)(struct dentry___7 *);
	void (*d_release)(struct dentry___7 *);
	void (*d_prune)(struct dentry___7 *);
	void (*d_iput)(struct dentry___7 *, struct inode___8 *);
	char * (*d_dname)(struct dentry___7 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___5 *);
	int (*d_manage)(const struct path___5 *, bool);
	struct dentry___7 * (*d_real)(struct dentry___7 *, const struct inode___8 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___5;

struct mem_dqinfo___5 {
	struct quota_format_type___5 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___5;

struct quota_info___5 {
	unsigned int flags;
	struct rw_semaphore___6 dqio_sem;
	struct inode___8 *files[3];
	struct mem_dqinfo___5 info[3];
	const struct quota_format_ops___5 *ops[3];
};

struct rcuwait___5 {
	struct task_struct___7 *task;
};

struct percpu_rw_semaphore___5 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___6 rw_sem;
	struct rcuwait___5 writer;
	int readers_block;
};

struct sb_writers___5 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___5 rw_sem[3];
};

struct file_system_type___5;

struct super_operations___5;

struct dquot_operations___5;

struct quotactl_ops___5;

struct super_block___6 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___5 *s_type;
	const struct super_operations___5 *s_op;
	const struct dquot_operations___5 *dq_op;
	const struct quotactl_ops___5 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___7 *s_root;
	struct rw_semaphore___6 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___6 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___5 s_dquot;
	struct sb_writers___5 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___5 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___6 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___6 {
	struct file___6 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___6 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___6 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___6 *ia_file;
};

struct dquot___5 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___6 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___5 {
	int qf_fmt_id;
	const struct quota_format_ops___5 *qf_ops;
	struct module___8 *qf_owner;
	struct quota_format_type___5 *qf_next;
};

struct quota_format_ops___5 {
	int (*check_quota_file)(struct super_block___6 *, int);
	int (*read_file_info)(struct super_block___6 *, int);
	int (*write_file_info)(struct super_block___6 *, int);
	int (*free_file_info)(struct super_block___6 *, int);
	int (*read_dqblk)(struct dquot___5 *);
	int (*commit_dqblk)(struct dquot___5 *);
	int (*release_dqblk)(struct dquot___5 *);
	int (*get_next_id)(struct super_block___6 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___5 {
	int (*write_dquot)(struct dquot___5 *);
	struct dquot___5 * (*alloc_dquot)(struct super_block___6 *, int);
	void (*destroy_dquot)(struct dquot___5 *);
	int (*acquire_dquot)(struct dquot___5 *);
	int (*release_dquot)(struct dquot___5 *);
	int (*mark_dirty)(struct dquot___5 *);
	int (*write_info)(struct super_block___6 *, int);
	qsize_t * (*get_reserved_space)(struct inode___8 *);
	int (*get_projid)(struct inode___8 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___8 *, qsize_t *);
	int (*get_next_id)(struct super_block___6 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___5 {
	int (*quota_on)(struct super_block___6 *, int, int, const struct path___5 *);
	int (*quota_off)(struct super_block___6 *, int);
	int (*quota_enable)(struct super_block___6 *, unsigned int);
	int (*quota_disable)(struct super_block___6 *, unsigned int);
	int (*quota_sync)(struct super_block___6 *, int);
	int (*set_info)(struct super_block___6 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___6 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___6 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___6 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___6 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___6 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___5 {
	struct kobject___5 kobj;
	struct module___8 *mod;
	struct kobject___5 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___5 {
	struct module___8 *mod;
	struct latch_tree_node node;
};

struct module_layout___5 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___5 mtn;
};

struct module_attribute___5;

struct kernel_param___5;

struct trace_event_call___5;

struct module___8 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___5 mkobj;
	struct module_attribute___5 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___5 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___5 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___5 core_layout;
	struct module_layout___5 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___5 {
	int (*writepage)(struct page___7 *, struct writeback_control___3 *);
	int (*readpage)(struct file___6 *, struct page___7 *);
	int (*writepages)(struct address_space___5 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___7 *);
	int (*readpages)(struct file___6 *, struct address_space___5 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___6 *, struct address_space___5 *, loff_t, unsigned int, unsigned int, struct page___7 **, void **);
	int (*write_end)(struct file___6 *, struct address_space___5 *, loff_t, unsigned int, unsigned int, struct page___7 *, void *);
	sector_t (*bmap)(struct address_space___5 *, sector_t);
	void (*invalidatepage)(struct page___7 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___7 *, gfp_t);
	void (*freepage)(struct page___7 *);
	ssize_t (*direct_IO)(struct kiocb___6 *, struct iov_iter___4 *);
	int (*migratepage)(struct address_space___5 *, struct page___7 *, struct page___7 *, enum migrate_mode);
	bool (*isolate_page)(struct page___7 *, isolate_mode_t);
	void (*putback_page)(struct page___7 *);
	int (*launder_page)(struct page___7 *);
	int (*is_partially_uptodate)(struct page___7 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___7 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___5 *, struct page___7 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___6 *, sector_t *);
	void (*swap_deactivate)(struct file___6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___6 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___8 *bd_inode;
	struct super_block___6 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___6 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___5 {
	struct dentry___7 * (*lookup)(struct inode___8 *, struct dentry___7 *, unsigned int);
	const char * (*get_link)(struct dentry___7 *, struct inode___8 *, struct delayed_call *);
	int (*permission)(struct inode___8 *, int);
	struct posix_acl * (*get_acl)(struct inode___8 *, int);
	int (*readlink)(struct dentry___7 *, char *, int);
	int (*create)(struct inode___8 *, struct dentry___7 *, umode_t, bool);
	int (*link)(struct dentry___7 *, struct inode___8 *, struct dentry___7 *);
	int (*unlink)(struct inode___8 *, struct dentry___7 *);
	int (*symlink)(struct inode___8 *, struct dentry___7 *, const char *);
	int (*mkdir)(struct inode___8 *, struct dentry___7 *, umode_t);
	int (*rmdir)(struct inode___8 *, struct dentry___7 *);
	int (*mknod)(struct inode___8 *, struct dentry___7 *, umode_t, dev_t);
	int (*rename)(struct inode___8 *, struct dentry___7 *, struct inode___8 *, struct dentry___7 *, unsigned int);
	int (*setattr)(struct dentry___7 *, struct iattr___6 *);
	int (*getattr)(const struct path___5 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___7 *, char *, size_t);
	int (*fiemap)(struct inode___8 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___8 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___8 *, struct dentry___7 *, struct file___6 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___8 *, struct dentry___7 *, umode_t);
	int (*set_acl)(struct inode___8 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___5 {
	void (*fl_copy_lock)(struct file_lock___6 *, struct file_lock___6 *);
	void (*fl_release_private)(struct file_lock___6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___5;

struct file_lock___6 {
	struct file_lock___6 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___6 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___5 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___5 *fl_ops;
	const struct lock_manager_operations___5 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___5 {
	int (*lm_compare_owner)(struct file_lock___6 *, struct file_lock___6 *);
	long unsigned int (*lm_owner_key)(struct file_lock___6 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___6 *);
	int (*lm_grant)(struct file_lock___6 *, int);
	bool (*lm_break)(struct file_lock___6 *);
	int (*lm_change)(struct file_lock___6 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___6 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___5 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___5 *fa_next;
	struct file___6 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___5 {
	const char *name;
	int fs_flags;
	struct dentry___7 * (*mount)(struct file_system_type___5 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___6 *);
	struct module___8 *owner;
	struct file_system_type___5 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___5 {
	struct inode___8 * (*alloc_inode)(struct super_block___6 *);
	void (*destroy_inode)(struct inode___8 *);
	void (*dirty_inode)(struct inode___8 *, int);
	int (*write_inode)(struct inode___8 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___8 *);
	void (*evict_inode)(struct inode___8 *);
	void (*put_super)(struct super_block___6 *);
	int (*sync_fs)(struct super_block___6 *, int);
	int (*freeze_super)(struct super_block___6 *);
	int (*freeze_fs)(struct super_block___6 *);
	int (*thaw_super)(struct super_block___6 *);
	int (*unfreeze_fs)(struct super_block___6 *);
	int (*statfs)(struct dentry___7 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___6 *, int *, char *);
	void (*umount_begin)(struct super_block___6 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___7 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___7 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___7 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___7 *);
	ssize_t (*quota_read)(struct super_block___6 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___6 *, int, const char *, size_t, loff_t);
	struct dquot___5 ** (*get_dquots)(struct inode___8 *);
	int (*bdev_try_to_free_page)(struct super_block___6 *, struct page___7 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___6 *, struct shrink_control *);
	long int (*free_cached_objects)(struct super_block___6 *, struct shrink_control *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___6;

struct seq_file___9 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___6 *op;
	int poll_event;
	const struct file___6 *file;
	void *private;
};

struct kobj_attribute___5 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___5 *, struct kobj_attribute___5 *, char *);
	ssize_t (*store)(struct kobject___5 *, struct kobj_attribute___5 *, const char *, size_t);
};

typedef void compound_page_dtor___5(struct page___7 *);

struct kernfs_root___5;

struct kernfs_elem_dir___5 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___5 *root;
};

struct kernfs_syscall_ops___5;

struct kernfs_root___5 {
	struct kernfs_node___5 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___5 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___5 {
	struct kernfs_node___5 *target_kn;
};

struct kernfs_ops___5;

struct kernfs_elem_attr___5 {
	const struct kernfs_ops___5 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___5 *notify_next;
};

struct kernfs_node___5 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___5 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___5 dir;
		struct kernfs_elem_symlink___5 symlink;
		struct kernfs_elem_attr___5 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___5;

struct kernfs_ops___5 {
	int (*open)(struct kernfs_open_file___5 *);
	void (*release)(struct kernfs_open_file___5 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___5 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___5 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___5 *, struct vm_area_struct___7 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___5 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___5 {
	int (*remount_fs)(struct kernfs_root___5 *, int *, char *);
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___5 *);
	int (*mkdir)(struct kernfs_node___5 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___5 *);
	int (*rename)(struct kernfs_node___5 *, struct kernfs_node___5 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___5 *, struct kernfs_root___5 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___5 {
	struct kernfs_node___5 *kn;
	struct file___6 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___5 *vm_ops;
};

struct bin_attribute___5;

struct attribute_group___5 {
	const char *name;
	umode_t (*is_visible)(struct kobject___5 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___5 *, struct bin_attribute___5 *, int);
	struct attribute **attrs;
	struct bin_attribute___5 **bin_attrs;
};

struct bin_attribute___5 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___6 *, struct kobject___5 *, struct bin_attribute___5 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___6 *, struct kobject___5 *, struct bin_attribute___5 *, char *, loff_t, size_t);
	int (*mmap)(struct file___6 *, struct kobject___5 *, struct bin_attribute___5 *, struct vm_area_struct___7 *);
};

struct sysfs_ops___5 {
	ssize_t (*show)(struct kobject___5 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___5 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___5;

struct kset___5 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___5 kobj;
	const struct kset_uevent_ops___5 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___5 {
	void (*release)(struct kobject___5 *);
	const struct sysfs_ops___5 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___5 *);
	const void * (*namespace)(struct kobject___5 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___5 {
	int (* const filter)(struct kset___5 *, struct kobject___5 *);
	const char * (* const name)(struct kset___5 *, struct kobject___5 *);
	int (* const uevent)(struct kset___5 *, struct kobject___5 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___5 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___5 *);
	int (*get)(char *, const struct kernel_param___5 *);
	void (*free)(void *);
};

struct kparam_array___5;

struct kernel_param___5 {
	const char *name;
	struct module___8 *mod;
	const struct kernel_param_ops___5 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___5 *arr;
	};
};

struct kparam_array___5 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___5 *ops;
	void *elem;
};

struct module_attribute___5 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___5 *, struct module_kobject___5 *, char *);
	ssize_t (*store)(struct module_attribute___5 *, struct module_kobject___5 *, const char *, size_t);
	void (*setup)(struct module___8 *, const char *);
	int (*test)(struct module___8 *);
	void (*free)(struct module___8 *);
};

typedef int (*key_restrict_link_func_t___5)(struct key___7 *, const struct key_type *, const union key_payload *, struct key___7 *);

struct key_restriction___6;

struct key___7 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___6 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___6 *restrict_link;
};

struct key_restriction___6 {
	key_restrict_link_func_t___5 check;
	struct key___7 *key;
	struct key_type *keytype;
};

struct seq_operations___6 {
	void * (*start)(struct seq_file___9 *, loff_t *);
	void (*stop)(struct seq_file___9 *, void *);
	void * (*next)(struct seq_file___9 *, void *, loff_t *);
	int (*show)(struct seq_file___9 *, void *);
};

enum flow_dissector_key_id {
	FLOW_DISSECTOR_KEY_CONTROL = 0,
	FLOW_DISSECTOR_KEY_BASIC = 1,
	FLOW_DISSECTOR_KEY_IPV4_ADDRS = 2,
	FLOW_DISSECTOR_KEY_IPV6_ADDRS = 3,
	FLOW_DISSECTOR_KEY_PORTS = 4,
	FLOW_DISSECTOR_KEY_ICMP = 5,
	FLOW_DISSECTOR_KEY_ETH_ADDRS = 6,
	FLOW_DISSECTOR_KEY_TIPC = 7,
	FLOW_DISSECTOR_KEY_ARP = 8,
	FLOW_DISSECTOR_KEY_VLAN = 9,
	FLOW_DISSECTOR_KEY_FLOW_LABEL = 10,
	FLOW_DISSECTOR_KEY_GRE_KEYID = 11,
	FLOW_DISSECTOR_KEY_MPLS_ENTROPY = 12,
	FLOW_DISSECTOR_KEY_ENC_KEYID = 13,
	FLOW_DISSECTOR_KEY_ENC_IPV4_ADDRS = 14,
	FLOW_DISSECTOR_KEY_ENC_IPV6_ADDRS = 15,
	FLOW_DISSECTOR_KEY_ENC_CONTROL = 16,
	FLOW_DISSECTOR_KEY_ENC_PORTS = 17,
	FLOW_DISSECTOR_KEY_MPLS = 18,
	FLOW_DISSECTOR_KEY_TCP = 19,
	FLOW_DISSECTOR_KEY_IP = 20,
	FLOW_DISSECTOR_KEY_CVLAN = 21,
	FLOW_DISSECTOR_KEY_ENC_IP = 22,
	FLOW_DISSECTOR_KEY_ENC_OPTS = 23,
	FLOW_DISSECTOR_KEY_MAX = 24,
};

enum {
	IPSTATS_MIB_NUM = 0,
	IPSTATS_MIB_INPKTS = 1,
	IPSTATS_MIB_INOCTETS = 2,
	IPSTATS_MIB_INDELIVERS = 3,
	IPSTATS_MIB_OUTFORWDATAGRAMS = 4,
	IPSTATS_MIB_OUTPKTS = 5,
	IPSTATS_MIB_OUTOCTETS = 6,
	IPSTATS_MIB_INHDRERRORS = 7,
	IPSTATS_MIB_INTOOBIGERRORS = 8,
	IPSTATS_MIB_INNOROUTES = 9,
	IPSTATS_MIB_INADDRERRORS = 10,
	IPSTATS_MIB_INUNKNOWNPROTOS = 11,
	IPSTATS_MIB_INTRUNCATEDPKTS = 12,
	IPSTATS_MIB_INDISCARDS = 13,
	IPSTATS_MIB_OUTDISCARDS = 14,
	IPSTATS_MIB_OUTNOROUTES = 15,
	IPSTATS_MIB_REASMTIMEOUT = 16,
	IPSTATS_MIB_REASMREQDS = 17,
	IPSTATS_MIB_REASMOKS = 18,
	IPSTATS_MIB_REASMFAILS = 19,
	IPSTATS_MIB_FRAGOKS = 20,
	IPSTATS_MIB_FRAGFAILS = 21,
	IPSTATS_MIB_FRAGCREATES = 22,
	IPSTATS_MIB_INMCASTPKTS = 23,
	IPSTATS_MIB_OUTMCASTPKTS = 24,
	IPSTATS_MIB_INBCASTPKTS = 25,
	IPSTATS_MIB_OUTBCASTPKTS = 26,
	IPSTATS_MIB_INMCASTOCTETS = 27,
	IPSTATS_MIB_OUTMCASTOCTETS = 28,
	IPSTATS_MIB_INBCASTOCTETS = 29,
	IPSTATS_MIB_OUTBCASTOCTETS = 30,
	IPSTATS_MIB_CSUMERRORS = 31,
	IPSTATS_MIB_NOECTPKTS = 32,
	IPSTATS_MIB_ECT1PKTS = 33,
	IPSTATS_MIB_ECT0PKTS = 34,
	IPSTATS_MIB_CEPKTS = 35,
	IPSTATS_MIB_REASM_OVERLAPS = 36,
	__IPSTATS_MIB_MAX = 37,
};

enum {
	ICMP_MIB_NUM = 0,
	ICMP_MIB_INMSGS = 1,
	ICMP_MIB_INERRORS = 2,
	ICMP_MIB_INDESTUNREACHS = 3,
	ICMP_MIB_INTIMEEXCDS = 4,
	ICMP_MIB_INPARMPROBS = 5,
	ICMP_MIB_INSRCQUENCHS = 6,
	ICMP_MIB_INREDIRECTS = 7,
	ICMP_MIB_INECHOS = 8,
	ICMP_MIB_INECHOREPS = 9,
	ICMP_MIB_INTIMESTAMPS = 10,
	ICMP_MIB_INTIMESTAMPREPS = 11,
	ICMP_MIB_INADDRMASKS = 12,
	ICMP_MIB_INADDRMASKREPS = 13,
	ICMP_MIB_OUTMSGS = 14,
	ICMP_MIB_OUTERRORS = 15,
	ICMP_MIB_OUTDESTUNREACHS = 16,
	ICMP_MIB_OUTTIMEEXCDS = 17,
	ICMP_MIB_OUTPARMPROBS = 18,
	ICMP_MIB_OUTSRCQUENCHS = 19,
	ICMP_MIB_OUTREDIRECTS = 20,
	ICMP_MIB_OUTECHOS = 21,
	ICMP_MIB_OUTECHOREPS = 22,
	ICMP_MIB_OUTTIMESTAMPS = 23,
	ICMP_MIB_OUTTIMESTAMPREPS = 24,
	ICMP_MIB_OUTADDRMASKS = 25,
	ICMP_MIB_OUTADDRMASKREPS = 26,
	ICMP_MIB_CSUMERRORS = 27,
	__ICMP_MIB_MAX = 28,
};

enum {
	ICMP6_MIB_NUM = 0,
	ICMP6_MIB_INMSGS = 1,
	ICMP6_MIB_INERRORS = 2,
	ICMP6_MIB_OUTMSGS = 3,
	ICMP6_MIB_OUTERRORS = 4,
	ICMP6_MIB_CSUMERRORS = 5,
	__ICMP6_MIB_MAX = 6,
};

enum {
	TCP_MIB_NUM = 0,
	TCP_MIB_RTOALGORITHM = 1,
	TCP_MIB_RTOMIN = 2,
	TCP_MIB_RTOMAX = 3,
	TCP_MIB_MAXCONN = 4,
	TCP_MIB_ACTIVEOPENS = 5,
	TCP_MIB_PASSIVEOPENS = 6,
	TCP_MIB_ATTEMPTFAILS = 7,
	TCP_MIB_ESTABRESETS = 8,
	TCP_MIB_CURRESTAB = 9,
	TCP_MIB_INSEGS = 10,
	TCP_MIB_OUTSEGS = 11,
	TCP_MIB_RETRANSSEGS = 12,
	TCP_MIB_INERRS = 13,
	TCP_MIB_OUTRSTS = 14,
	TCP_MIB_CSUMERRORS = 15,
	__TCP_MIB_MAX = 16,
};

enum {
	UDP_MIB_NUM = 0,
	UDP_MIB_INDATAGRAMS = 1,
	UDP_MIB_NOPORTS = 2,
	UDP_MIB_INERRORS = 3,
	UDP_MIB_OUTDATAGRAMS = 4,
	UDP_MIB_RCVBUFERRORS = 5,
	UDP_MIB_SNDBUFERRORS = 6,
	UDP_MIB_CSUMERRORS = 7,
	UDP_MIB_IGNOREDMULTI = 8,
	__UDP_MIB_MAX = 9,
};

enum {
	LINUX_MIB_NUM = 0,
	LINUX_MIB_SYNCOOKIESSENT = 1,
	LINUX_MIB_SYNCOOKIESRECV = 2,
	LINUX_MIB_SYNCOOKIESFAILED = 3,
	LINUX_MIB_EMBRYONICRSTS = 4,
	LINUX_MIB_PRUNECALLED = 5,
	LINUX_MIB_RCVPRUNED = 6,
	LINUX_MIB_OFOPRUNED = 7,
	LINUX_MIB_OUTOFWINDOWICMPS = 8,
	LINUX_MIB_LOCKDROPPEDICMPS = 9,
	LINUX_MIB_ARPFILTER = 10,
	LINUX_MIB_TIMEWAITED = 11,
	LINUX_MIB_TIMEWAITRECYCLED = 12,
	LINUX_MIB_TIMEWAITKILLED = 13,
	LINUX_MIB_PAWSACTIVEREJECTED = 14,
	LINUX_MIB_PAWSESTABREJECTED = 15,
	LINUX_MIB_DELAYEDACKS = 16,
	LINUX_MIB_DELAYEDACKLOCKED = 17,
	LINUX_MIB_DELAYEDACKLOST = 18,
	LINUX_MIB_LISTENOVERFLOWS = 19,
	LINUX_MIB_LISTENDROPS = 20,
	LINUX_MIB_TCPHPHITS = 21,
	LINUX_MIB_TCPPUREACKS = 22,
	LINUX_MIB_TCPHPACKS = 23,
	LINUX_MIB_TCPRENORECOVERY = 24,
	LINUX_MIB_TCPSACKRECOVERY = 25,
	LINUX_MIB_TCPSACKRENEGING = 26,
	LINUX_MIB_TCPSACKREORDER = 27,
	LINUX_MIB_TCPRENOREORDER = 28,
	LINUX_MIB_TCPTSREORDER = 29,
	LINUX_MIB_TCPFULLUNDO = 30,
	LINUX_MIB_TCPPARTIALUNDO = 31,
	LINUX_MIB_TCPDSACKUNDO = 32,
	LINUX_MIB_TCPLOSSUNDO = 33,
	LINUX_MIB_TCPLOSTRETRANSMIT = 34,
	LINUX_MIB_TCPRENOFAILURES = 35,
	LINUX_MIB_TCPSACKFAILURES = 36,
	LINUX_MIB_TCPLOSSFAILURES = 37,
	LINUX_MIB_TCPFASTRETRANS = 38,
	LINUX_MIB_TCPSLOWSTARTRETRANS = 39,
	LINUX_MIB_TCPTIMEOUTS = 40,
	LINUX_MIB_TCPLOSSPROBES = 41,
	LINUX_MIB_TCPLOSSPROBERECOVERY = 42,
	LINUX_MIB_TCPRENORECOVERYFAIL = 43,
	LINUX_MIB_TCPSACKRECOVERYFAIL = 44,
	LINUX_MIB_TCPRCVCOLLAPSED = 45,
	LINUX_MIB_TCPDSACKOLDSENT = 46,
	LINUX_MIB_TCPDSACKOFOSENT = 47,
	LINUX_MIB_TCPDSACKRECV = 48,
	LINUX_MIB_TCPDSACKOFORECV = 49,
	LINUX_MIB_TCPABORTONDATA = 50,
	LINUX_MIB_TCPABORTONCLOSE = 51,
	LINUX_MIB_TCPABORTONMEMORY = 52,
	LINUX_MIB_TCPABORTONTIMEOUT = 53,
	LINUX_MIB_TCPABORTONLINGER = 54,
	LINUX_MIB_TCPABORTFAILED = 55,
	LINUX_MIB_TCPMEMORYPRESSURES = 56,
	LINUX_MIB_TCPMEMORYPRESSURESCHRONO = 57,
	LINUX_MIB_TCPSACKDISCARD = 58,
	LINUX_MIB_TCPDSACKIGNOREDOLD = 59,
	LINUX_MIB_TCPDSACKIGNOREDNOUNDO = 60,
	LINUX_MIB_TCPSPURIOUSRTOS = 61,
	LINUX_MIB_TCPMD5NOTFOUND = 62,
	LINUX_MIB_TCPMD5UNEXPECTED = 63,
	LINUX_MIB_TCPMD5FAILURE = 64,
	LINUX_MIB_SACKSHIFTED = 65,
	LINUX_MIB_SACKMERGED = 66,
	LINUX_MIB_SACKSHIFTFALLBACK = 67,
	LINUX_MIB_TCPBACKLOGDROP = 68,
	LINUX_MIB_PFMEMALLOCDROP = 69,
	LINUX_MIB_TCPMINTTLDROP = 70,
	LINUX_MIB_TCPDEFERACCEPTDROP = 71,
	LINUX_MIB_IPRPFILTER = 72,
	LINUX_MIB_TCPTIMEWAITOVERFLOW = 73,
	LINUX_MIB_TCPREQQFULLDOCOOKIES = 74,
	LINUX_MIB_TCPREQQFULLDROP = 75,
	LINUX_MIB_TCPRETRANSFAIL = 76,
	LINUX_MIB_TCPRCVCOALESCE = 77,
	LINUX_MIB_TCPOFOQUEUE = 78,
	LINUX_MIB_TCPOFODROP = 79,
	LINUX_MIB_TCPOFOMERGE = 80,
	LINUX_MIB_TCPCHALLENGEACK = 81,
	LINUX_MIB_TCPSYNCHALLENGE = 82,
	LINUX_MIB_TCPFASTOPENACTIVE = 83,
	LINUX_MIB_TCPFASTOPENACTIVEFAIL = 84,
	LINUX_MIB_TCPFASTOPENPASSIVE = 85,
	LINUX_MIB_TCPFASTOPENPASSIVEFAIL = 86,
	LINUX_MIB_TCPFASTOPENLISTENOVERFLOW = 87,
	LINUX_MIB_TCPFASTOPENCOOKIEREQD = 88,
	LINUX_MIB_TCPFASTOPENBLACKHOLE = 89,
	LINUX_MIB_TCPSPURIOUS_RTX_HOSTQUEUES = 90,
	LINUX_MIB_BUSYPOLLRXPACKETS = 91,
	LINUX_MIB_TCPAUTOCORKING = 92,
	LINUX_MIB_TCPFROMZEROWINDOWADV = 93,
	LINUX_MIB_TCPTOZEROWINDOWADV = 94,
	LINUX_MIB_TCPWANTZEROWINDOWADV = 95,
	LINUX_MIB_TCPSYNRETRANS = 96,
	LINUX_MIB_TCPORIGDATASENT = 97,
	LINUX_MIB_TCPHYSTARTTRAINDETECT = 98,
	LINUX_MIB_TCPHYSTARTTRAINCWND = 99,
	LINUX_MIB_TCPHYSTARTDELAYDETECT = 100,
	LINUX_MIB_TCPHYSTARTDELAYCWND = 101,
	LINUX_MIB_TCPACKSKIPPEDSYNRECV = 102,
	LINUX_MIB_TCPACKSKIPPEDPAWS = 103,
	LINUX_MIB_TCPACKSKIPPEDSEQ = 104,
	LINUX_MIB_TCPACKSKIPPEDFINWAIT2 = 105,
	LINUX_MIB_TCPACKSKIPPEDTIMEWAIT = 106,
	LINUX_MIB_TCPACKSKIPPEDCHALLENGE = 107,
	LINUX_MIB_TCPWINPROBE = 108,
	LINUX_MIB_TCPKEEPALIVE = 109,
	LINUX_MIB_TCPMTUPFAIL = 110,
	LINUX_MIB_TCPMTUPSUCCESS = 111,
	LINUX_MIB_TCPDELIVERED = 112,
	LINUX_MIB_TCPDELIVEREDCE = 113,
	LINUX_MIB_TCPACKCOMPRESSED = 114,
	LINUX_MIB_TCPWQUEUETOOBIG = 115,
	__LINUX_MIB_MAX = 116,
};

enum {
	LINUX_MIB_XFRMNUM = 0,
	LINUX_MIB_XFRMINERROR = 1,
	LINUX_MIB_XFRMINBUFFERERROR = 2,
	LINUX_MIB_XFRMINHDRERROR = 3,
	LINUX_MIB_XFRMINNOSTATES = 4,
	LINUX_MIB_XFRMINSTATEPROTOERROR = 5,
	LINUX_MIB_XFRMINSTATEMODEERROR = 6,
	LINUX_MIB_XFRMINSTATESEQERROR = 7,
	LINUX_MIB_XFRMINSTATEEXPIRED = 8,
	LINUX_MIB_XFRMINSTATEMISMATCH = 9,
	LINUX_MIB_XFRMINSTATEINVALID = 10,
	LINUX_MIB_XFRMINTMPLMISMATCH = 11,
	LINUX_MIB_XFRMINNOPOLS = 12,
	LINUX_MIB_XFRMINPOLBLOCK = 13,
	LINUX_MIB_XFRMINPOLERROR = 14,
	LINUX_MIB_XFRMOUTERROR = 15,
	LINUX_MIB_XFRMOUTBUNDLEGENERROR = 16,
	LINUX_MIB_XFRMOUTBUNDLECHECKERROR = 17,
	LINUX_MIB_XFRMOUTNOSTATES = 18,
	LINUX_MIB_XFRMOUTSTATEPROTOERROR = 19,
	LINUX_MIB_XFRMOUTSTATEMODEERROR = 20,
	LINUX_MIB_XFRMOUTSTATESEQERROR = 21,
	LINUX_MIB_XFRMOUTSTATEEXPIRED = 22,
	LINUX_MIB_XFRMOUTPOLBLOCK = 23,
	LINUX_MIB_XFRMOUTPOLDEAD = 24,
	LINUX_MIB_XFRMOUTPOLERROR = 25,
	LINUX_MIB_XFRMFWDHDRERROR = 26,
	LINUX_MIB_XFRMOUTSTATEINVALID = 27,
	LINUX_MIB_XFRMACQUIREERROR = 28,
	__LINUX_MIB_XFRMMAX = 29,
};

struct net_device___4;

struct dst_ops___3;

struct sk_buff___3;

struct net___4;

struct sock___3;

struct dst_entry___2 {
	struct net_device___4 *dev;
	struct dst_ops___3 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___3 *);
	int (*output)(struct net___4 *, struct sock___3 *, struct sk_buff___3 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

enum nf_inet_hooks {
	NF_INET_PRE_ROUTING = 0,
	NF_INET_LOCAL_IN = 1,
	NF_INET_FORWARD = 2,
	NF_INET_LOCAL_OUT = 3,
	NF_INET_POST_ROUTING = 4,
	NF_INET_NUMHOOKS = 5,
};

enum {
	NFPROTO_UNSPEC = 0,
	NFPROTO_INET = 1,
	NFPROTO_IPV4 = 2,
	NFPROTO_ARP = 3,
	NFPROTO_NETDEV = 5,
	NFPROTO_BRIDGE = 7,
	NFPROTO_IPV6 = 10,
	NFPROTO_DECNET = 12,
	NFPROTO_NUMPROTO = 13,
};

enum tcp_conntrack {
	TCP_CONNTRACK_NONE = 0,
	TCP_CONNTRACK_SYN_SENT = 1,
	TCP_CONNTRACK_SYN_RECV = 2,
	TCP_CONNTRACK_ESTABLISHED = 3,
	TCP_CONNTRACK_FIN_WAIT = 4,
	TCP_CONNTRACK_CLOSE_WAIT = 5,
	TCP_CONNTRACK_LAST_ACK = 6,
	TCP_CONNTRACK_TIME_WAIT = 7,
	TCP_CONNTRACK_CLOSE = 8,
	TCP_CONNTRACK_LISTEN = 9,
	TCP_CONNTRACK_MAX = 10,
	TCP_CONNTRACK_IGNORE = 11,
	TCP_CONNTRACK_RETRANS = 12,
	TCP_CONNTRACK_UNACK = 13,
	TCP_CONNTRACK_TIMEOUT_MAX = 14,
};

enum ct_dccp_states {
	CT_DCCP_NONE = 0,
	CT_DCCP_REQUEST = 1,
	CT_DCCP_RESPOND = 2,
	CT_DCCP_PARTOPEN = 3,
	CT_DCCP_OPEN = 4,
	CT_DCCP_CLOSEREQ = 5,
	CT_DCCP_CLOSING = 6,
	CT_DCCP_TIMEWAIT = 7,
	CT_DCCP_IGNORE = 8,
	CT_DCCP_INVALID = 9,
	__CT_DCCP_MAX = 10,
};

enum ip_conntrack_dir {
	IP_CT_DIR_ORIGINAL = 0,
	IP_CT_DIR_REPLY = 1,
	IP_CT_DIR_MAX = 2,
};

enum sctp_conntrack {
	SCTP_CONNTRACK_NONE = 0,
	SCTP_CONNTRACK_CLOSED = 1,
	SCTP_CONNTRACK_COOKIE_WAIT = 2,
	SCTP_CONNTRACK_COOKIE_ECHOED = 3,
	SCTP_CONNTRACK_ESTABLISHED = 4,
	SCTP_CONNTRACK_SHUTDOWN_SENT = 5,
	SCTP_CONNTRACK_SHUTDOWN_RECD = 6,
	SCTP_CONNTRACK_SHUTDOWN_ACK_SENT = 7,
	SCTP_CONNTRACK_HEARTBEAT_SENT = 8,
	SCTP_CONNTRACK_HEARTBEAT_ACKED = 9,
	SCTP_CONNTRACK_MAX = 10,
};

enum udp_conntrack {
	UDP_CT_UNREPLIED = 0,
	UDP_CT_REPLIED = 1,
	UDP_CT_MAX = 2,
};

enum {
	XFRM_POLICY_IN = 0,
	XFRM_POLICY_OUT = 1,
	XFRM_POLICY_FWD = 2,
	XFRM_POLICY_MASK = 3,
	XFRM_POLICY_MAX = 3,
};

struct dev_pm_ops___5 {
	int (*prepare)(struct device___6 *);
	void (*complete)(struct device___6 *);
	int (*suspend)(struct device___6 *);
	int (*resume)(struct device___6 *);
	int (*freeze)(struct device___6 *);
	int (*thaw)(struct device___6 *);
	int (*poweroff)(struct device___6 *);
	int (*restore)(struct device___6 *);
	int (*suspend_late)(struct device___6 *);
	int (*resume_early)(struct device___6 *);
	int (*freeze_late)(struct device___6 *);
	int (*thaw_early)(struct device___6 *);
	int (*poweroff_late)(struct device___6 *);
	int (*restore_early)(struct device___6 *);
	int (*suspend_noirq)(struct device___6 *);
	int (*resume_noirq)(struct device___6 *);
	int (*freeze_noirq)(struct device___6 *);
	int (*thaw_noirq)(struct device___6 *);
	int (*poweroff_noirq)(struct device___6 *);
	int (*restore_noirq)(struct device___6 *);
	int (*runtime_suspend)(struct device___6 *);
	int (*runtime_resume)(struct device___6 *);
	int (*runtime_idle)(struct device___6 *);
};

struct dev_pm_domain___5 {
	struct dev_pm_ops___5 ops;
	void (*detach)(struct device___6 *, bool);
	int (*activate)(struct device___6 *);
	void (*sync)(struct device___6 *);
	void (*dismiss)(struct device___6 *);
};

struct bus_type___5 {
	const char *name;
	const char *dev_name;
	struct device___6 *dev_root;
	const struct attribute_group___5 **bus_groups;
	const struct attribute_group___5 **dev_groups;
	const struct attribute_group___5 **drv_groups;
	int (*match)(struct device___6 *, struct device_driver___5 *);
	int (*uevent)(struct device___6 *, struct kobj_uevent_env *);
	int (*probe)(struct device___6 *);
	int (*remove)(struct device___6 *);
	void (*shutdown)(struct device___6 *);
	int (*online)(struct device___6 *);
	int (*offline)(struct device___6 *);
	int (*suspend)(struct device___6 *, pm_message_t);
	int (*resume)(struct device___6 *);
	int (*num_vf)(struct device___6 *);
	int (*dma_configure)(struct device___6 *);
	const struct dev_pm_ops___5 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___5 {
	const char *name;
	struct bus_type___5 *bus;
	struct module___8 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___6 *);
	int (*remove)(struct device___6 *);
	void (*shutdown)(struct device___6 *);
	int (*suspend)(struct device___6 *, pm_message_t);
	int (*resume)(struct device___6 *);
	const struct attribute_group___5 **groups;
	const struct dev_pm_ops___5 *pm;
	void (*coredump)(struct device___6 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___5 {
	const char *name;
	const struct attribute_group___5 **groups;
	int (*uevent)(struct device___6 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___6 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___6 *);
	const struct dev_pm_ops___5 *pm;
};

struct class___5 {
	const char *name;
	struct module___8 *owner;
	const struct attribute_group___5 **class_groups;
	const struct attribute_group___5 **dev_groups;
	struct kobject___5 *dev_kobj;
	int (*dev_uevent)(struct device___6 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___6 *, umode_t *);
	void (*class_release)(struct class___5 *);
	void (*dev_release)(struct device___6 *);
	int (*shutdown_pre)(struct device___6 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___6 *);
	const struct dev_pm_ops___5 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___3 {
	void * (*alloc)(struct device___6 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___6 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___6 *, struct vm_area_struct___7 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___6 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___6 *, struct page___7 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___6 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___6 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___6 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___6 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___6 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___6 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___6 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___6 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___6 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___6 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___6 *, u64);
	u64 (*get_required_mask)(struct device___6 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___5;

struct fwnode_handle___5 {
	struct fwnode_handle___5 *secondary;
	const struct fwnode_operations___5 *ops;
};

struct fwnode_reference_args___5;

struct fwnode_endpoint___5;

struct fwnode_operations___5 {
	struct fwnode_handle___5 * (*get)(struct fwnode_handle___5 *);
	void (*put)(struct fwnode_handle___5 *);
	bool (*device_is_available)(const struct fwnode_handle___5 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___5 *, const struct device___6 *);
	bool (*property_present)(const struct fwnode_handle___5 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___5 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___5 *, const char *, const char **, size_t);
	struct fwnode_handle___5 * (*get_parent)(const struct fwnode_handle___5 *);
	struct fwnode_handle___5 * (*get_next_child_node)(const struct fwnode_handle___5 *, struct fwnode_handle___5 *);
	struct fwnode_handle___5 * (*get_named_child_node)(const struct fwnode_handle___5 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___5 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___5 *);
	struct fwnode_handle___5 * (*graph_get_next_endpoint)(const struct fwnode_handle___5 *, struct fwnode_handle___5 *);
	struct fwnode_handle___5 * (*graph_get_remote_endpoint)(const struct fwnode_handle___5 *);
	struct fwnode_handle___5 * (*graph_get_port_parent)(struct fwnode_handle___5 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___5 *, struct fwnode_endpoint___5 *);
};

struct fwnode_endpoint___5 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___5 *local_fwnode;
};

struct fwnode_reference_args___5 {
	struct fwnode_handle___5 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___2;

struct pipe_buffer___2 {
	struct page___7 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___2 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___2 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info *, struct pipe_buffer___2 *);
	void (*release)(struct pipe_inode_info *, struct pipe_buffer___2 *);
	int (*steal)(struct pipe_inode_info *, struct pipe_buffer___2 *);
	union {
		bool (*get)(struct pipe_inode_info *, struct pipe_buffer___2 *);
		struct {
			void (*get)(struct pipe_inode_info *, struct pipe_buffer___2 *);
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
};

enum sched_tunable_scaling {
	SCHED_TUNABLESCALING_NONE = 0,
	SCHED_TUNABLESCALING_LOG = 1,
	SCHED_TUNABLESCALING_LINEAR = 2,
	SCHED_TUNABLESCALING_END = 3,
};

enum audit_ntp_type {
	AUDIT_NTP_OFFSET = 0,
	AUDIT_NTP_FREQ = 1,
	AUDIT_NTP_STATUS = 2,
	AUDIT_NTP_TAI = 3,
	AUDIT_NTP_TICK = 4,
	AUDIT_NTP_ADJUST = 5,
	AUDIT_NTP_NVALS = 6,
};

typedef long int (*syscall_fn_t)(struct pt_regs *);

typedef long unsigned int uintptr_t;

struct module___9;

struct file___7;

struct kiocb___7;

struct vm_area_struct___8;

struct inode___9;

struct file_lock___7;

struct page___8;

struct seq_file___10;

struct file_operations___7 {
	struct module___9 *owner;
	loff_t (*llseek)(struct file___7 *, loff_t, int);
	ssize_t (*read)(struct file___7 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___7 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___7 *, struct iov_iter___4 *);
	ssize_t (*write_iter)(struct kiocb___7 *, struct iov_iter___4 *);
	int (*iopoll)(struct kiocb___7 *, bool);
	int (*iterate)(struct file___7 *, struct dir_context *);
	int (*iterate_shared)(struct file___7 *, struct dir_context *);
	__poll_t (*poll)(struct file___7 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___7 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___7 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___7 *, struct vm_area_struct___8 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___9 *, struct file___7 *);
	int (*flush)(struct file___7 *, fl_owner_t);
	int (*release)(struct inode___9 *, struct file___7 *);
	int (*fsync)(struct file___7 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___7 *, int);
	int (*lock)(struct file___7 *, int, struct file_lock___7 *);
	ssize_t (*sendpage)(struct file___7 *, struct page___8 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___7 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___7 *, int, struct file_lock___7 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___7 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___7 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___7 *, long int, struct file_lock___7 **, void **);
	long int (*fallocate)(struct file___7 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___10 *, struct file___7 *);
	ssize_t (*copy_file_range)(struct file___7 *, loff_t, struct file___7 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___7 *, loff_t, struct file___7 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___7 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___6 {
	u64 seqnum;
	struct vm_area_struct___8 *vmas[4];
};

struct page_frag___6 {
	struct page___8 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___7;

struct pid___6;

struct cred___7;

struct nsproxy___7;

struct signal_struct___7;

struct task_struct___8 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___8 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___7 *mm;
	struct mm_struct___7 *active_mm;
	struct vmacache___6 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___8 *real_parent;
	struct task_struct___8 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___8 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___6 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___6 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___6 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___7 *ptracer_cred;
	const struct cred___7 *real_cred;
	const struct cred___7 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___7 *nsproxy;
	struct signal_struct___7 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___8 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___4 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___6 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___8 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___4 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___8 *pgtable_t___6;

struct address_space___6;

struct dev_pagemap___6;

struct page___8 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___6 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___8 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___6 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___7 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___6 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___6;

struct lruvec___6 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___6 *pgdat;
};

struct zone___6 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___6 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___6 {
	struct zone___6 *zone;
	int zone_idx;
};

struct zonelist___6 {
	struct zoneref___6 _zonerefs[25];
};

struct pglist_data___6 {
	struct zone___6 node_zones[3];
	struct zonelist___6 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___8 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___8 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___6 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___7 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___8 *owner;
};

struct secondary_data___7 {
	void *stack;
	struct task_struct___8 *task;
	long int status;
};

struct blocking_notifier_head___6 {
	struct rw_semaphore___7 rwsem;
	struct notifier_block *head;
};

struct kernfs_root___6;

struct kernfs_elem_dir___6 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___6 *root;
};

struct kernfs_node___6;

struct kernfs_syscall_ops___6;

struct kernfs_root___6 {
	struct kernfs_node___6 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___6 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___6 {
	struct kernfs_node___6 *target_kn;
};

struct kernfs_ops___6;

struct kernfs_elem_attr___6 {
	const struct kernfs_ops___6 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___6 *notify_next;
};

struct kernfs_node___6 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___6 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___6 dir;
		struct kernfs_elem_symlink___6 symlink;
		struct kernfs_elem_attr___6 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___6;

struct kernfs_ops___6 {
	int (*open)(struct kernfs_open_file___6 *);
	void (*release)(struct kernfs_open_file___6 *);
	int (*seq_show)(struct seq_file___10 *, void *);
	void * (*seq_start)(struct seq_file___10 *, loff_t *);
	void * (*seq_next)(struct seq_file___10 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___10 *, void *);
	ssize_t (*read)(struct kernfs_open_file___6 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___6 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___6 *, struct vm_area_struct___8 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___6 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___6 {
	int (*remount_fs)(struct kernfs_root___6 *, int *, char *);
	int (*show_options)(struct seq_file___10 *, struct kernfs_root___6 *);
	int (*mkdir)(struct kernfs_node___6 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___6 *);
	int (*rename)(struct kernfs_node___6 *, struct kernfs_node___6 *, const char *);
	int (*show_path)(struct seq_file___10 *, struct kernfs_node___6 *, struct kernfs_root___6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___7;

struct seq_file___10 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___7 *op;
	int poll_event;
	const struct file___7 *file;
	void *private;
};

struct vm_operations_struct___6;

struct kernfs_open_file___6 {
	struct kernfs_node___6 *kn;
	struct file___7 *file;
	struct seq_file___10 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___6 *vm_ops;
};

struct dentry___8;

struct path___6 {
	struct vfsmount *mnt;
	struct dentry___8 *dentry;
};

struct fown_struct___6 {
	rwlock_t lock;
	struct pid___6 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___7 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___6 f_path;
	struct inode___9 *f_inode;
	const struct file_operations___7 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___6 f_owner;
	const struct cred___7 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___6 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___6;

struct vm_operations_struct___6 {
	void (*open)(struct vm_area_struct___8 *);
	void (*close)(struct vm_area_struct___8 *);
	int (*split)(struct vm_area_struct___8 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___8 *);
	vm_fault_t (*fault)(struct vm_fault___6 *);
	vm_fault_t (*huge_fault)(struct vm_fault___6 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___6 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___8 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___6 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___6 *);
	int (*access)(struct vm_area_struct___8 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___8 *);
	int (*set_policy)(struct vm_area_struct___8 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___8 *, long unsigned int);
	struct page___8 * (*find_special_page)(struct vm_area_struct___8 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_area_struct___8 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___8 *vm_next;
	struct vm_area_struct___8 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___7 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___6 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___7 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___6;

struct bin_attribute___6;

struct attribute_group___6 {
	const char *name;
	umode_t (*is_visible)(struct kobject___6 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___6 *, struct bin_attribute___6 *, int);
	struct attribute **attrs;
	struct bin_attribute___6 **bin_attrs;
};

struct kset___6;

struct kobj_type___6;

struct kobject___6 {
	const char *name;
	struct list_head entry;
	struct kobject___6 *parent;
	struct kset___6 *kset;
	struct kobj_type___6 *ktype;
	struct kernfs_node___6 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___6 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___7 *, struct kobject___6 *, struct bin_attribute___6 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___7 *, struct kobject___6 *, struct bin_attribute___6 *, char *, loff_t, size_t);
	int (*mmap)(struct file___7 *, struct kobject___6 *, struct bin_attribute___6 *, struct vm_area_struct___8 *);
};

struct sysfs_ops___6 {
	ssize_t (*show)(struct kobject___6 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___6 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___6;

struct kset___6 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___6 kobj;
	const struct kset_uevent_ops___6 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___6 {
	void (*release)(struct kobject___6 *);
	const struct sysfs_ops___6 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___6 *);
	const void * (*namespace)(struct kobject___6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___6 {
	int (* const filter)(struct kset___6 *, struct kobject___6 *);
	const char * (* const name)(struct kset___6 *, struct kobject___6 *);
	int (* const uevent)(struct kset___6 *, struct kobject___6 *, struct kobj_uevent_env *);
};

struct kobj_attribute___6 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___6 *, struct kobj_attribute___6 *, char *);
	ssize_t (*store)(struct kobject___6 *, struct kobj_attribute___6 *, const char *, size_t);
};

struct device___7;

struct dev_pm_ops___6 {
	int (*prepare)(struct device___7 *);
	void (*complete)(struct device___7 *);
	int (*suspend)(struct device___7 *);
	int (*resume)(struct device___7 *);
	int (*freeze)(struct device___7 *);
	int (*thaw)(struct device___7 *);
	int (*poweroff)(struct device___7 *);
	int (*restore)(struct device___7 *);
	int (*suspend_late)(struct device___7 *);
	int (*resume_early)(struct device___7 *);
	int (*freeze_late)(struct device___7 *);
	int (*thaw_early)(struct device___7 *);
	int (*poweroff_late)(struct device___7 *);
	int (*restore_early)(struct device___7 *);
	int (*suspend_noirq)(struct device___7 *);
	int (*resume_noirq)(struct device___7 *);
	int (*freeze_noirq)(struct device___7 *);
	int (*thaw_noirq)(struct device___7 *);
	int (*poweroff_noirq)(struct device___7 *);
	int (*restore_noirq)(struct device___7 *);
	int (*runtime_suspend)(struct device___7 *);
	int (*runtime_resume)(struct device___7 *);
	int (*runtime_idle)(struct device___7 *);
};

struct dev_pm_info___6 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___7 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___6;

struct bus_type___6;

struct device_driver___6;

struct dev_pm_domain___6;

struct class___6;

struct device___7 {
	struct device___7 *parent;
	struct device_private *p;
	struct kobject___6 kobj;
	const char *init_name;
	const struct device_type___6 *type;
	struct mutex mutex;
	struct bus_type___6 *bus;
	struct device_driver___6 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___6 power;
	struct dev_pm_domain___6 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___6 *class;
	const struct attribute_group___6 **groups;
	void (*release)(struct device___7 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___6 {
	struct dev_pm_ops___6 ops;
	void (*detach)(struct device___7 *, bool);
	int (*activate)(struct device___7 *);
	void (*sync)(struct device___7 *);
	void (*dismiss)(struct device___7 *);
};

struct pid_namespace___6;

struct upid___6 {
	int nr;
	struct pid_namespace___6 *ns;
};

struct pid_namespace___6 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___8 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___6 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___8 *proc_self;
	struct dentry___8 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___3 *user_ns;
	struct ucounts___2 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common ns;
};

struct pid___6 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___6 numbers[1];
};

struct key___8;

struct user_struct___7 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___8 *uid_keyring;
	struct key___8 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___6;

struct mm_struct___7 {
	struct {
		struct vm_area_struct___8 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___7 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___7 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___6 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___8 *owner;
		struct user_namespace___3 *user_ns;
		struct file___7 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___6 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___7 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___8 *session_keyring;
	struct key___8 *process_keyring;
	struct key___8 *thread_keyring;
	struct key___8 *request_key_auth;
	void *security;
	struct user_struct___7 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct nsproxy___7 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___6 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct signal_struct___7 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___8 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___8 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___6 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___6 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___7 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___6 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

union thread_union___6 {
	struct task_struct___8 task;
	long unsigned int stack[8192];
};

struct bus_type___6 {
	const char *name;
	const char *dev_name;
	struct device___7 *dev_root;
	const struct attribute_group___6 **bus_groups;
	const struct attribute_group___6 **dev_groups;
	const struct attribute_group___6 **drv_groups;
	int (*match)(struct device___7 *, struct device_driver___6 *);
	int (*uevent)(struct device___7 *, struct kobj_uevent_env *);
	int (*probe)(struct device___7 *);
	int (*remove)(struct device___7 *);
	void (*shutdown)(struct device___7 *);
	int (*online)(struct device___7 *);
	int (*offline)(struct device___7 *);
	int (*suspend)(struct device___7 *, pm_message_t);
	int (*resume)(struct device___7 *);
	int (*num_vf)(struct device___7 *);
	int (*dma_configure)(struct device___7 *);
	const struct dev_pm_ops___6 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___6 {
	const char *name;
	struct bus_type___6 *bus;
	struct module___9 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___7 *);
	int (*remove)(struct device___7 *);
	void (*shutdown)(struct device___7 *);
	int (*suspend)(struct device___7 *, pm_message_t);
	int (*resume)(struct device___7 *);
	const struct attribute_group___6 **groups;
	const struct dev_pm_ops___6 *pm;
	void (*coredump)(struct device___7 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___6 {
	const char *name;
	const struct attribute_group___6 **groups;
	int (*uevent)(struct device___7 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___7 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___7 *);
	const struct dev_pm_ops___6 *pm;
};

struct module_kobject___6 {
	struct kobject___6 kobj;
	struct module___9 *mod;
	struct kobject___6 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___6 {
	struct module___9 *mod;
	struct latch_tree_node node;
};

struct module_layout___6 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___6 mtn;
};

struct module_attribute___6;

struct kernel_param___6;

struct module___9 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___6 mkobj;
	struct module_attribute___6 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___6 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___6 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___6 core_layout;
	struct module_layout___6 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct class___6 {
	const char *name;
	struct module___9 *owner;
	const struct attribute_group___6 **class_groups;
	const struct attribute_group___6 **dev_groups;
	struct kobject___6 *dev_kobj;
	int (*dev_uevent)(struct device___7 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___7 *, umode_t *);
	void (*class_release)(struct class___6 *);
	void (*dev_release)(struct device___7 *);
	int (*shutdown_pre)(struct device___7 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___7 *);
	const struct dev_pm_ops___6 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___5 {
	struct device___7 dev;
};

struct dentry_operations___6;

struct super_block___7;

struct dentry___8 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___8 *d_parent;
	struct qstr d_name;
	struct inode___9 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___6 *d_op;
	struct super_block___7 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___6;

struct address_space___6 {
	struct inode___9 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___7 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___6 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___6;

struct block_device___7;

struct inode___9 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___6 *i_op;
	struct super_block___7 *i_sb;
	struct address_space___6 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___7 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___7 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___6 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___7 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___6 {
	int (*d_revalidate)(struct dentry___8 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___8 *, unsigned int);
	int (*d_hash)(const struct dentry___8 *, struct qstr *);
	int (*d_compare)(const struct dentry___8 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___8 *);
	int (*d_init)(struct dentry___8 *);
	void (*d_release)(struct dentry___8 *);
	void (*d_prune)(struct dentry___8 *);
	void (*d_iput)(struct dentry___8 *, struct inode___9 *);
	char * (*d_dname)(struct dentry___8 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___6 *);
	int (*d_manage)(const struct path___6 *, bool);
	struct dentry___8 * (*d_real)(struct dentry___8 *, const struct inode___9 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___6;

struct mem_dqinfo___6 {
	struct quota_format_type___6 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___6;

struct quota_info___6 {
	unsigned int flags;
	struct rw_semaphore___7 dqio_sem;
	struct inode___9 *files[3];
	struct mem_dqinfo___6 info[3];
	const struct quota_format_ops___6 *ops[3];
};

struct rcuwait___6 {
	struct task_struct___8 *task;
};

struct percpu_rw_semaphore___6 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___7 rw_sem;
	struct rcuwait___6 writer;
	int readers_block;
};

struct sb_writers___6 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___6 rw_sem[3];
};

struct file_system_type___6;

struct super_operations___6;

struct dquot_operations___6;

struct quotactl_ops___6;

struct super_block___7 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___6 *s_type;
	const struct super_operations___6 *s_op;
	const struct dquot_operations___6 *dq_op;
	const struct quotactl_ops___6 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___8 *s_root;
	struct rw_semaphore___7 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___7 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___6 s_dquot;
	struct sb_writers___6 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___6 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct step_hook {
	struct list_head node;
	int (*fn)(struct pt_regs *, unsigned int);
};

struct break_hook {
	struct list_head node;
	u32 esr_val;
	u32 esr_mask;
	int (*fn)(struct pt_regs *, unsigned int);
};

enum dbg_active_el {
	DBG_ACTIVE_EL0 = 0,
	DBG_ACTIVE_EL1 = 1,
};

typedef u32 probe_opcode_t;

typedef void probes_handler_t(u32, long int, struct pt_regs *);

struct arch_probe_insn {
	probe_opcode_t *insn;
	pstate_check_t *pstate_cc;
	probes_handler_t *handler;
	long unsigned int restore;
};

typedef u32 kprobe_opcode_t;

struct arch_specific_insn {
	struct arch_probe_insn api;
};

typedef int (*dev_page_fault_t___6)(struct vm_area_struct___8 *, long unsigned int, const struct page___8 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___6)(struct page___8 *, void *);

struct dev_pagemap___6 {
	dev_page_fault_t___6 page_fault;
	dev_page_free_t___6 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___7 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___6 {
	struct task_struct___8 *task;
	struct core_thread___6 *next;
};

struct core_state___6 {
	atomic_t nr_threads;
	struct core_thread___6 dumper;
	struct completion startup;
};

struct vm_fault___6 {
	struct vm_area_struct___8 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___8 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___8 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___6 prealloc_pte;
};

struct kiocb___7 {
	struct file___7 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___7 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___7 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___7 *ia_file;
};

struct dquot___6 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___7 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___6 {
	int qf_fmt_id;
	const struct quota_format_ops___6 *qf_ops;
	struct module___9 *qf_owner;
	struct quota_format_type___6 *qf_next;
};

struct quota_format_ops___6 {
	int (*check_quota_file)(struct super_block___7 *, int);
	int (*read_file_info)(struct super_block___7 *, int);
	int (*write_file_info)(struct super_block___7 *, int);
	int (*free_file_info)(struct super_block___7 *, int);
	int (*read_dqblk)(struct dquot___6 *);
	int (*commit_dqblk)(struct dquot___6 *);
	int (*release_dqblk)(struct dquot___6 *);
	int (*get_next_id)(struct super_block___7 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___6 {
	int (*write_dquot)(struct dquot___6 *);
	struct dquot___6 * (*alloc_dquot)(struct super_block___7 *, int);
	void (*destroy_dquot)(struct dquot___6 *);
	int (*acquire_dquot)(struct dquot___6 *);
	int (*release_dquot)(struct dquot___6 *);
	int (*mark_dirty)(struct dquot___6 *);
	int (*write_info)(struct super_block___7 *, int);
	qsize_t * (*get_reserved_space)(struct inode___9 *);
	int (*get_projid)(struct inode___9 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___9 *, qsize_t *);
	int (*get_next_id)(struct super_block___7 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___6 {
	int (*quota_on)(struct super_block___7 *, int, int, const struct path___6 *);
	int (*quota_off)(struct super_block___7 *, int);
	int (*quota_enable)(struct super_block___7 *, unsigned int);
	int (*quota_disable)(struct super_block___7 *, unsigned int);
	int (*quota_sync)(struct super_block___7 *, int);
	int (*set_info)(struct super_block___7 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___7 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___7 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___7 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___7 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___7 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___6 {
	int (*writepage)(struct page___8 *, struct writeback_control___3 *);
	int (*readpage)(struct file___7 *, struct page___8 *);
	int (*writepages)(struct address_space___6 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___8 *);
	int (*readpages)(struct file___7 *, struct address_space___6 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___7 *, struct address_space___6 *, loff_t, unsigned int, unsigned int, struct page___8 **, void **);
	int (*write_end)(struct file___7 *, struct address_space___6 *, loff_t, unsigned int, unsigned int, struct page___8 *, void *);
	sector_t (*bmap)(struct address_space___6 *, sector_t);
	void (*invalidatepage)(struct page___8 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___8 *, gfp_t);
	void (*freepage)(struct page___8 *);
	ssize_t (*direct_IO)(struct kiocb___7 *, struct iov_iter___4 *);
	int (*migratepage)(struct address_space___6 *, struct page___8 *, struct page___8 *, enum migrate_mode);
	bool (*isolate_page)(struct page___8 *, isolate_mode_t);
	void (*putback_page)(struct page___8 *);
	int (*launder_page)(struct page___8 *);
	int (*is_partially_uptodate)(struct page___8 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___8 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___6 *, struct page___8 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___7 *, sector_t *);
	void (*swap_deactivate)(struct file___7 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___7 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___9 *bd_inode;
	struct super_block___7 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___7 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___6 {
	struct dentry___8 * (*lookup)(struct inode___9 *, struct dentry___8 *, unsigned int);
	const char * (*get_link)(struct dentry___8 *, struct inode___9 *, struct delayed_call *);
	int (*permission)(struct inode___9 *, int);
	struct posix_acl * (*get_acl)(struct inode___9 *, int);
	int (*readlink)(struct dentry___8 *, char *, int);
	int (*create)(struct inode___9 *, struct dentry___8 *, umode_t, bool);
	int (*link)(struct dentry___8 *, struct inode___9 *, struct dentry___8 *);
	int (*unlink)(struct inode___9 *, struct dentry___8 *);
	int (*symlink)(struct inode___9 *, struct dentry___8 *, const char *);
	int (*mkdir)(struct inode___9 *, struct dentry___8 *, umode_t);
	int (*rmdir)(struct inode___9 *, struct dentry___8 *);
	int (*mknod)(struct inode___9 *, struct dentry___8 *, umode_t, dev_t);
	int (*rename)(struct inode___9 *, struct dentry___8 *, struct inode___9 *, struct dentry___8 *, unsigned int);
	int (*setattr)(struct dentry___8 *, struct iattr___7 *);
	int (*getattr)(const struct path___6 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___8 *, char *, size_t);
	int (*fiemap)(struct inode___9 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___9 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___9 *, struct dentry___8 *, struct file___7 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___9 *, struct dentry___8 *, umode_t);
	int (*set_acl)(struct inode___9 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___6 {
	void (*fl_copy_lock)(struct file_lock___7 *, struct file_lock___7 *);
	void (*fl_release_private)(struct file_lock___7 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___6;

struct lock_manager_operations___6;

struct file_lock___7 {
	struct file_lock___7 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___7 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___6 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___6 *fl_ops;
	const struct lock_manager_operations___6 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___6 {
	int (*lm_compare_owner)(struct file_lock___7 *, struct file_lock___7 *);
	long unsigned int (*lm_owner_key)(struct file_lock___7 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___7 *);
	int (*lm_grant)(struct file_lock___7 *, int);
	bool (*lm_break)(struct file_lock___7 *);
	int (*lm_change)(struct file_lock___7 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___7 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___6 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___6 *fa_next;
	struct file___7 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___6 {
	const char *name;
	int fs_flags;
	struct dentry___8 * (*mount)(struct file_system_type___6 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___7 *);
	struct module___9 *owner;
	struct file_system_type___6 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___6 {
	struct inode___9 * (*alloc_inode)(struct super_block___7 *);
	void (*destroy_inode)(struct inode___9 *);
	void (*dirty_inode)(struct inode___9 *, int);
	int (*write_inode)(struct inode___9 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___9 *);
	void (*evict_inode)(struct inode___9 *);
	void (*put_super)(struct super_block___7 *);
	int (*sync_fs)(struct super_block___7 *, int);
	int (*freeze_super)(struct super_block___7 *);
	int (*freeze_fs)(struct super_block___7 *);
	int (*thaw_super)(struct super_block___7 *);
	int (*unfreeze_fs)(struct super_block___7 *);
	int (*statfs)(struct dentry___8 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___7 *, int *, char *);
	void (*umount_begin)(struct super_block___7 *);
	int (*show_options)(struct seq_file___10 *, struct dentry___8 *);
	int (*show_devname)(struct seq_file___10 *, struct dentry___8 *);
	int (*show_path)(struct seq_file___10 *, struct dentry___8 *);
	int (*show_stats)(struct seq_file___10 *, struct dentry___8 *);
	ssize_t (*quota_read)(struct super_block___7 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___7 *, int, const char *, size_t, loff_t);
	struct dquot___6 ** (*get_dquots)(struct inode___9 *);
	int (*bdev_try_to_free_page)(struct super_block___7 *, struct page___8 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___7 *, struct shrink_control *);
	long int (*free_cached_objects)(struct super_block___7 *, struct shrink_control *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*key_restrict_link_func_t___6)(struct key___8 *, const struct key_type *, const union key_payload *, struct key___8 *);

struct key_restriction___7;

struct key___8 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___7 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___7 *restrict_link;
};

struct key_restriction___7 {
	key_restrict_link_func_t___6 check;
	struct key___8 *key;
	struct key_type *keytype;
};

struct seq_operations___7 {
	void * (*start)(struct seq_file___10 *, loff_t *);
	void (*stop)(struct seq_file___10 *, void *);
	void * (*next)(struct seq_file___10 *, void *, loff_t *);
	int (*show)(struct seq_file___10 *, void *);
};

typedef void compound_page_dtor___6(struct page___8 *);

struct kernel_param_ops___6 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___6 *);
	int (*get)(char *, const struct kernel_param___6 *);
	void (*free)(void *);
};

struct kparam_array___6;

struct kernel_param___6 {
	const char *name;
	struct module___9 *mod;
	const struct kernel_param_ops___6 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___6 *arr;
	};
};

struct kparam_array___6 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___6 *ops;
	void *elem;
};

struct module_attribute___6 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___6 *, struct module_kobject___6 *, char *);
	ssize_t (*store)(struct module_attribute___6 *, struct module_kobject___6 *, const char *, size_t);
	void (*setup)(struct module___9 *, const char *);
	int (*test)(struct module___9 *);
	void (*free)(struct module___9 *);
};

struct kprobe;

struct prev_kprobe {
	struct kprobe *kp;
	unsigned int status;
};

typedef int (*kprobe_pre_handler_t)(struct kprobe *, struct pt_regs *);

typedef void (*kprobe_post_handler_t)(struct kprobe *, struct pt_regs *, long unsigned int);

typedef int (*kprobe_fault_handler_t)(struct kprobe *, struct pt_regs *, int);

typedef int (*kprobe_break_handler_t)(struct kprobe *, struct pt_regs *);

struct kprobe {
	struct hlist_node hlist;
	struct list_head list;
	long unsigned int nmissed;
	kprobe_opcode_t *addr;
	const char *symbol_name;
	unsigned int offset;
	kprobe_pre_handler_t pre_handler;
	kprobe_post_handler_t post_handler;
	kprobe_fault_handler_t fault_handler;
	kprobe_break_handler_t break_handler;
	kprobe_opcode_t opcode;
	struct arch_specific_insn ainsn;
	u32 flags;
};

struct kprobe_step_ctx {
	long unsigned int ss_pending;
	long unsigned int match_addr;
};

struct kprobe_ctlblk {
	unsigned int kprobe_status;
	long unsigned int saved_irqflag;
	struct prev_kprobe prev_kprobe;
	struct kprobe_step_ctx ss_ctx;
	struct pt_regs jprobe_saved_regs;
};

struct kretprobe_blackpoint {
	const char *name;
	void *addr;
};

struct kprobe_insn_cache {
	struct mutex mutex;
	void * (*alloc)();
	void (*free)(void *);
	struct list_head pages;
	size_t insn_size;
	int nr_garbage;
};

struct midr_range {
	u32 model;
	u32 rv_min;
	u32 rv_max;
};

struct module___10;

struct file___8;

struct kiocb___8;

struct iov_iter___5;

struct poll_table_struct___7;

struct vm_area_struct___9;

struct inode___10;

struct file_lock___8;

struct page___9;

struct seq_file___11;

struct file_operations___8 {
	struct module___10 *owner;
	loff_t (*llseek)(struct file___8 *, loff_t, int);
	ssize_t (*read)(struct file___8 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___8 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___8 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___8 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___8 *, bool);
	int (*iterate)(struct file___8 *, struct dir_context *);
	int (*iterate_shared)(struct file___8 *, struct dir_context *);
	__poll_t (*poll)(struct file___8 *, struct poll_table_struct___7 *);
	long int (*unlocked_ioctl)(struct file___8 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___8 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___8 *, struct vm_area_struct___9 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___10 *, struct file___8 *);
	int (*flush)(struct file___8 *, fl_owner_t);
	int (*release)(struct inode___10 *, struct file___8 *);
	int (*fsync)(struct file___8 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___8 *, int);
	int (*lock)(struct file___8 *, int, struct file_lock___8 *);
	ssize_t (*sendpage)(struct file___8 *, struct page___9 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___8 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___8 *, int, struct file_lock___8 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___8 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___8 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___8 *, long int, struct file_lock___8 **, void **);
	long int (*fallocate)(struct file___8 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___11 *, struct file___8 *);
	ssize_t (*copy_file_range)(struct file___8 *, loff_t, struct file___8 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___8 *, loff_t, struct file___8 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___8 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___7 {
	u64 seqnum;
	struct vm_area_struct___9 *vmas[4];
};

struct page_frag___7 {
	struct page___9 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___8;

struct cred___8;

struct nsproxy___8;

struct vm_struct___6;

struct task_struct___9 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___9 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___8 *mm;
	struct mm_struct___8 *active_mm;
	struct vmacache___7 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___9 *real_parent;
	struct task_struct___9 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___9 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___6 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___6 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___6 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___8 *ptracer_cred;
	const struct cred___8 *real_cred;
	const struct cred___8 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___9 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___4 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___7 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___9 *oom_reaper_list;
	struct vm_struct___6 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___4 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct secondary_data___8 {
	void *stack;
	struct task_struct___9 *task;
	long int status;
};

enum irqchip_irq_state {
	IRQCHIP_STATE_PENDING = 0,
	IRQCHIP_STATE_ACTIVE = 1,
	IRQCHIP_STATE_MASKED = 2,
	IRQCHIP_STATE_LINE_LEVEL = 3,
};

typedef struct page___9 *pgtable_t___7;

struct address_space___7;

struct dev_pagemap___7;

struct page___9 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___7 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___9 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___7 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___8 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___7 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct key___9;

struct user_struct___8 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___9 *uid_keyring;
	struct key___9 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___7;

struct vm_area_struct___9 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___9 *vm_next;
	struct vm_area_struct___9 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___8 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___7 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___8 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct rw_semaphore___8 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___9 *owner;
};

struct core_state___7;

struct mm_struct___8 {
	struct {
		struct vm_area_struct___9 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___8 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___8 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___7 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___9 *owner;
		struct user_namespace___3 *user_ns;
		struct file___8 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___7 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___8 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___9 *session_keyring;
	struct key___9 *process_keyring;
	struct key___9 *thread_keyring;
	struct key___9 *request_key_auth;
	void *security;
	struct user_struct___8 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct vm_struct___6 {
	struct vm_struct___6 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___9 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct irq_common_data;

struct irq_chip;

struct irq_data {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data *common;
	struct irq_chip *chip;
	struct irq_domain *domain;
	struct irq_data *parent_data;
	void *chip_data;
};

struct pglist_data___7;

struct lruvec___7 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___7 *pgdat;
};

struct zone___7 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___7 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___7 {
	struct zone___7 *zone;
	int zone_idx;
};

struct zonelist___7 {
	struct zoneref___7 _zonerefs[25];
};

struct pglist_data___7 {
	struct zone___7 node_zones[3];
	struct zonelist___7 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___9 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___9 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___7 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___7 {
	struct rw_semaphore___8 rwsem;
	struct notifier_block *head;
};

struct address_space_operations___7;

struct address_space___7 {
	struct inode___10 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___8 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___7 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___7)(struct vm_area_struct___9 *, long unsigned int, const struct page___9 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___7)(struct page___9 *, void *);

struct device___8;

struct dev_pagemap___7 {
	dev_page_fault_t___7 page_fault;
	dev_page_free_t___7 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___8 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct dentry___9;

struct path___7 {
	struct vfsmount *mnt;
	struct dentry___9 *dentry;
};

struct file___8 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___7 f_path;
	struct inode___10 *f_inode;
	const struct file_operations___8 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___6 f_owner;
	const struct cred___8 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___7 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___7;

struct vm_operations_struct___7 {
	void (*open)(struct vm_area_struct___9 *);
	void (*close)(struct vm_area_struct___9 *);
	int (*split)(struct vm_area_struct___9 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___9 *);
	vm_fault_t (*fault)(struct vm_fault___7 *);
	vm_fault_t (*huge_fault)(struct vm_fault___7 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___7 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___9 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___7 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___7 *);
	int (*access)(struct vm_area_struct___9 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___9 *);
	int (*set_policy)(struct vm_area_struct___9 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___9 *, long unsigned int);
	struct page___9 * (*find_special_page)(struct vm_area_struct___9 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___7 {
	struct task_struct___9 *task;
	struct core_thread___7 *next;
};

struct core_state___7 {
	atomic_t nr_threads;
	struct core_thread___7 dumper;
	struct completion startup;
};

struct vm_fault___7 {
	struct vm_area_struct___9 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___9 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___9 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___7 prealloc_pte;
};

struct fwnode_operations___6;

struct fwnode_handle___6 {
	struct fwnode_handle___6 *secondary;
	const struct fwnode_operations___6 *ops;
};

struct fwnode_reference_args___6;

struct fwnode_endpoint___6;

struct fwnode_operations___6 {
	struct fwnode_handle___6 * (*get)(struct fwnode_handle___6 *);
	void (*put)(struct fwnode_handle___6 *);
	bool (*device_is_available)(const struct fwnode_handle___6 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___6 *, const struct device___8 *);
	bool (*property_present)(const struct fwnode_handle___6 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___6 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___6 *, const char *, const char **, size_t);
	struct fwnode_handle___6 * (*get_parent)(const struct fwnode_handle___6 *);
	struct fwnode_handle___6 * (*get_next_child_node)(const struct fwnode_handle___6 *, struct fwnode_handle___6 *);
	struct fwnode_handle___6 * (*get_named_child_node)(const struct fwnode_handle___6 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___6 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___6 *);
	struct fwnode_handle___6 * (*graph_get_next_endpoint)(const struct fwnode_handle___6 *, struct fwnode_handle___6 *);
	struct fwnode_handle___6 * (*graph_get_remote_endpoint)(const struct fwnode_handle___6 *);
	struct fwnode_handle___6 * (*graph_get_port_parent)(struct fwnode_handle___6 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___6 *, struct fwnode_endpoint___6 *);
};

struct fwnode_endpoint___6 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___6 *local_fwnode;
};

struct fwnode_reference_args___6 {
	struct fwnode_handle___6 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct kset___7;

struct kobj_type___7;

struct kernfs_node___7;

struct kobject___7 {
	const char *name;
	struct list_head entry;
	struct kobject___7 *parent;
	struct kset___7 *kset;
	struct kobj_type___7 *ktype;
	struct kernfs_node___7 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___7 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___8 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___7;

struct bus_type___7;

struct device_driver___7;

struct dev_pm_domain___7;

struct device_node___3;

struct class___7;

struct attribute_group___7;

struct device___8 {
	struct device___8 *parent;
	struct device_private *p;
	struct kobject___7 kobj;
	const char *init_name;
	const struct device_type___7 *type;
	struct mutex mutex;
	struct bus_type___7 *bus;
	struct device_driver___7 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___7 power;
	struct dev_pm_domain___7 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___3 *of_node;
	struct fwnode_handle___6 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___7 *class;
	const struct attribute_group___7 **groups;
	void (*release)(struct device___8 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct msi_desc;

struct irq_common_data {
	unsigned int state_use_accessors;
	unsigned int node;
	void *handler_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
	cpumask_var_t effective_affinity;
};

struct msi_msg;

struct irq_chip {
	struct device___8 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data *);
	void (*irq_shutdown)(struct irq_data *);
	void (*irq_enable)(struct irq_data *);
	void (*irq_disable)(struct irq_data *);
	void (*irq_ack)(struct irq_data *);
	void (*irq_mask)(struct irq_data *);
	void (*irq_mask_ack)(struct irq_data *);
	void (*irq_unmask)(struct irq_data *);
	void (*irq_eoi)(struct irq_data *);
	int (*irq_set_affinity)(struct irq_data *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data *);
	int (*irq_set_type)(struct irq_data *, unsigned int);
	int (*irq_set_wake)(struct irq_data *, unsigned int);
	void (*irq_bus_lock)(struct irq_data *);
	void (*irq_bus_sync_unlock)(struct irq_data *);
	void (*irq_cpu_online)(struct irq_data *);
	void (*irq_cpu_offline)(struct irq_data *);
	void (*irq_suspend)(struct irq_data *);
	void (*irq_resume)(struct irq_data *);
	void (*irq_pm_shutdown)(struct irq_data *);
	void (*irq_calc_mask)(struct irq_data *);
	void (*irq_print_chip)(struct irq_data *, struct seq_file___11 *);
	int (*irq_request_resources)(struct irq_data *);
	void (*irq_release_resources)(struct irq_data *);
	void (*irq_compose_msi_msg)(struct irq_data *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data *, void *);
	void (*ipi_send_single)(struct irq_data *, unsigned int);
	void (*ipi_send_mask)(struct irq_data *, const struct cpumask *);
	long unsigned int flags;
};

struct seq_operations___8;

struct seq_file___11 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___8 *op;
	int poll_event;
	const struct file___8 *file;
	void *private;
};

struct kernfs_root___7;

struct kernfs_elem_dir___7 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___7 *root;
};

struct kernfs_syscall_ops___7;

struct kernfs_root___7 {
	struct kernfs_node___7 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___7 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___7 {
	struct kernfs_node___7 *target_kn;
};

struct kernfs_ops___7;

struct kernfs_elem_attr___7 {
	const struct kernfs_ops___7 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___7 *notify_next;
};

struct kernfs_node___7 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___7 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___7 dir;
		struct kernfs_elem_symlink___7 symlink;
		struct kernfs_elem_attr___7 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___7;

struct kernfs_ops___7 {
	int (*open)(struct kernfs_open_file___7 *);
	void (*release)(struct kernfs_open_file___7 *);
	int (*seq_show)(struct seq_file___11 *, void *);
	void * (*seq_start)(struct seq_file___11 *, loff_t *);
	void * (*seq_next)(struct seq_file___11 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___11 *, void *);
	ssize_t (*read)(struct kernfs_open_file___7 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___7 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___7 *, struct vm_area_struct___9 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___7 *, struct poll_table_struct___7 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___7 {
	int (*remount_fs)(struct kernfs_root___7 *, int *, char *);
	int (*show_options)(struct seq_file___11 *, struct kernfs_root___7 *);
	int (*mkdir)(struct kernfs_node___7 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___7 *);
	int (*rename)(struct kernfs_node___7 *, struct kernfs_node___7 *, const char *);
	int (*show_path)(struct seq_file___11 *, struct kernfs_node___7 *, struct kernfs_root___7 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___7 {
	struct kernfs_node___7 *kn;
	struct file___8 *file;
	struct seq_file___11 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___7 *vm_ops;
};

typedef void (*poll_queue_proc___5)(struct file___8 *, wait_queue_head_t *, struct poll_table_struct___7 *);

struct poll_table_struct___7 {
	poll_queue_proc___5 _qproc;
	__poll_t _key;
};

struct bin_attribute___7;

struct attribute_group___7 {
	const char *name;
	umode_t (*is_visible)(struct kobject___7 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___7 *, struct bin_attribute___7 *, int);
	struct attribute **attrs;
	struct bin_attribute___7 **bin_attrs;
};

struct bin_attribute___7 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___8 *, struct kobject___7 *, struct bin_attribute___7 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___8 *, struct kobject___7 *, struct bin_attribute___7 *, char *, loff_t, size_t);
	int (*mmap)(struct file___8 *, struct kobject___7 *, struct bin_attribute___7 *, struct vm_area_struct___9 *);
};

struct sysfs_ops___7 {
	ssize_t (*show)(struct kobject___7 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___7 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___7;

struct kset___7 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___7 kobj;
	const struct kset_uevent_ops___7 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___7 {
	void (*release)(struct kobject___7 *);
	const struct sysfs_ops___7 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___7 *);
	const void * (*namespace)(struct kobject___7 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___7 {
	int (* const filter)(struct kset___7 *, struct kobject___7 *);
	const char * (* const name)(struct kset___7 *, struct kobject___7 *);
	int (* const uevent)(struct kset___7 *, struct kobject___7 *, struct kobj_uevent_env *);
};

struct kobj_attribute___7 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___7 *, struct kobj_attribute___7 *, char *);
	ssize_t (*store)(struct kobject___7 *, struct kobj_attribute___7 *, const char *, size_t);
};

struct module_kobject___7 {
	struct kobject___7 kobj;
	struct module___10 *mod;
	struct kobject___7 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___7 {
	struct module___10 *mod;
	struct latch_tree_node node;
};

struct module_layout___7 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___7 mtn;
};

struct module_attribute___7;

struct kernel_param___7;

struct module___10 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___7 mkobj;
	struct module_attribute___7 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___7 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___7 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___7 core_layout;
	struct module_layout___7 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___7 {
	int (*prepare)(struct device___8 *);
	void (*complete)(struct device___8 *);
	int (*suspend)(struct device___8 *);
	int (*resume)(struct device___8 *);
	int (*freeze)(struct device___8 *);
	int (*thaw)(struct device___8 *);
	int (*poweroff)(struct device___8 *);
	int (*restore)(struct device___8 *);
	int (*suspend_late)(struct device___8 *);
	int (*resume_early)(struct device___8 *);
	int (*freeze_late)(struct device___8 *);
	int (*thaw_early)(struct device___8 *);
	int (*poweroff_late)(struct device___8 *);
	int (*restore_early)(struct device___8 *);
	int (*suspend_noirq)(struct device___8 *);
	int (*resume_noirq)(struct device___8 *);
	int (*freeze_noirq)(struct device___8 *);
	int (*thaw_noirq)(struct device___8 *);
	int (*poweroff_noirq)(struct device___8 *);
	int (*restore_noirq)(struct device___8 *);
	int (*runtime_suspend)(struct device___8 *);
	int (*runtime_resume)(struct device___8 *);
	int (*runtime_idle)(struct device___8 *);
};

struct dev_pm_domain___7 {
	struct dev_pm_ops___7 ops;
	void (*detach)(struct device___8 *, bool);
	int (*activate)(struct device___8 *);
	void (*sync)(struct device___8 *);
	void (*dismiss)(struct device___8 *);
};

struct bus_type___7 {
	const char *name;
	const char *dev_name;
	struct device___8 *dev_root;
	const struct attribute_group___7 **bus_groups;
	const struct attribute_group___7 **dev_groups;
	const struct attribute_group___7 **drv_groups;
	int (*match)(struct device___8 *, struct device_driver___7 *);
	int (*uevent)(struct device___8 *, struct kobj_uevent_env *);
	int (*probe)(struct device___8 *);
	int (*remove)(struct device___8 *);
	void (*shutdown)(struct device___8 *);
	int (*online)(struct device___8 *);
	int (*offline)(struct device___8 *);
	int (*suspend)(struct device___8 *, pm_message_t);
	int (*resume)(struct device___8 *);
	int (*num_vf)(struct device___8 *);
	int (*dma_configure)(struct device___8 *);
	const struct dev_pm_ops___7 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___7 {
	const char *name;
	struct bus_type___7 *bus;
	struct module___10 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___8 *);
	int (*remove)(struct device___8 *);
	void (*shutdown)(struct device___8 *);
	int (*suspend)(struct device___8 *, pm_message_t);
	int (*resume)(struct device___8 *);
	const struct attribute_group___7 **groups;
	const struct dev_pm_ops___7 *pm;
	void (*coredump)(struct device___8 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___7 {
	const char *name;
	const struct attribute_group___7 **groups;
	int (*uevent)(struct device___8 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___8 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___8 *);
	const struct dev_pm_ops___7 *pm;
};

struct class___7 {
	const char *name;
	struct module___10 *owner;
	const struct attribute_group___7 **class_groups;
	const struct attribute_group___7 **dev_groups;
	struct kobject___7 *dev_kobj;
	int (*dev_uevent)(struct device___8 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___8 *, umode_t *);
	void (*class_release)(struct class___7 *);
	void (*dev_release)(struct device___8 *);
	int (*shutdown_pre)(struct device___8 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___8 *);
	const struct dev_pm_ops___7 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct property___2;

struct device_node___3 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___6 fwnode;
	struct property___2 *properties;
	struct property___2 *deadprops;
	struct device_node___3 *parent;
	struct device_node___3 *child;
	struct device_node___3 *sibling;
	struct kobject___7 kobj;
	long unsigned int _flags;
	void *data;
};

struct node___6 {
	struct device___8 dev;
};

struct kernel_param_ops___7 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___7 *);
	int (*get)(char *, const struct kernel_param___7 *);
	void (*free)(void *);
};

struct kparam_array___7;

struct kernel_param___7 {
	const char *name;
	struct module___10 *mod;
	const struct kernel_param_ops___7 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___7 *arr;
	};
};

struct kparam_array___7 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___7 *ops;
	void *elem;
};

struct module_attribute___7 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___7 *, struct module_kobject___7 *, char *);
	ssize_t (*store)(struct module_attribute___7 *, struct module_kobject___7 *, const char *, size_t);
	void (*setup)(struct module___10 *, const char *);
	int (*test)(struct module___10 *);
	void (*free)(struct module___10 *);
};

struct dentry_operations___7;

struct super_block___8;

struct dentry___9 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___9 *d_parent;
	struct qstr d_name;
	struct inode___10 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___7 *d_op;
	struct super_block___8 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___7;

struct block_device___8;

struct cdev___4;

struct inode___10 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___7 *i_op;
	struct super_block___8 *i_sb;
	struct address_space___7 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___8 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___8 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___7 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___8 *i_bdev;
		struct cdev___4 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___7 {
	int (*d_revalidate)(struct dentry___9 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___9 *, unsigned int);
	int (*d_hash)(const struct dentry___9 *, struct qstr *);
	int (*d_compare)(const struct dentry___9 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___9 *);
	int (*d_init)(struct dentry___9 *);
	void (*d_release)(struct dentry___9 *);
	void (*d_prune)(struct dentry___9 *);
	void (*d_iput)(struct dentry___9 *, struct inode___10 *);
	char * (*d_dname)(struct dentry___9 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___7 *);
	int (*d_manage)(const struct path___7 *, bool);
	struct dentry___9 * (*d_real)(struct dentry___9 *, const struct inode___10 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___7;

struct mem_dqinfo___7 {
	struct quota_format_type___7 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___7;

struct quota_info___7 {
	unsigned int flags;
	struct rw_semaphore___8 dqio_sem;
	struct inode___10 *files[3];
	struct mem_dqinfo___7 info[3];
	const struct quota_format_ops___7 *ops[3];
};

struct rcuwait___7 {
	struct task_struct___9 *task;
};

struct percpu_rw_semaphore___7 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___8 rw_sem;
	struct rcuwait___7 writer;
	int readers_block;
};

struct sb_writers___7 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___7 rw_sem[3];
};

struct file_system_type___7;

struct super_operations___7;

struct dquot_operations___7;

struct quotactl_ops___7;

struct super_block___8 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___7 *s_type;
	const struct super_operations___7 *s_op;
	const struct dquot_operations___7 *dq_op;
	const struct quotactl_ops___7 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___9 *s_root;
	struct rw_semaphore___8 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___8 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___7 s_dquot;
	struct sb_writers___7 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___7 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___8 {
	struct file___8 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___8 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___8 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___8 *ia_file;
};

struct dquot___7 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___8 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___7 {
	int qf_fmt_id;
	const struct quota_format_ops___7 *qf_ops;
	struct module___10 *qf_owner;
	struct quota_format_type___7 *qf_next;
};

struct quota_format_ops___7 {
	int (*check_quota_file)(struct super_block___8 *, int);
	int (*read_file_info)(struct super_block___8 *, int);
	int (*write_file_info)(struct super_block___8 *, int);
	int (*free_file_info)(struct super_block___8 *, int);
	int (*read_dqblk)(struct dquot___7 *);
	int (*commit_dqblk)(struct dquot___7 *);
	int (*release_dqblk)(struct dquot___7 *);
	int (*get_next_id)(struct super_block___8 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___7 {
	int (*write_dquot)(struct dquot___7 *);
	struct dquot___7 * (*alloc_dquot)(struct super_block___8 *, int);
	void (*destroy_dquot)(struct dquot___7 *);
	int (*acquire_dquot)(struct dquot___7 *);
	int (*release_dquot)(struct dquot___7 *);
	int (*mark_dirty)(struct dquot___7 *);
	int (*write_info)(struct super_block___8 *, int);
	qsize_t * (*get_reserved_space)(struct inode___10 *);
	int (*get_projid)(struct inode___10 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___10 *, qsize_t *);
	int (*get_next_id)(struct super_block___8 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___7 {
	int (*quota_on)(struct super_block___8 *, int, int, const struct path___7 *);
	int (*quota_off)(struct super_block___8 *, int);
	int (*quota_enable)(struct super_block___8 *, unsigned int);
	int (*quota_disable)(struct super_block___8 *, unsigned int);
	int (*quota_sync)(struct super_block___8 *, int);
	int (*set_info)(struct super_block___8 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___8 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___8 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___8 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___8 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___8 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___7 {
	int (*writepage)(struct page___9 *, struct writeback_control___3 *);
	int (*readpage)(struct file___8 *, struct page___9 *);
	int (*writepages)(struct address_space___7 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___9 *);
	int (*readpages)(struct file___8 *, struct address_space___7 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___8 *, struct address_space___7 *, loff_t, unsigned int, unsigned int, struct page___9 **, void **);
	int (*write_end)(struct file___8 *, struct address_space___7 *, loff_t, unsigned int, unsigned int, struct page___9 *, void *);
	sector_t (*bmap)(struct address_space___7 *, sector_t);
	void (*invalidatepage)(struct page___9 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___9 *, gfp_t);
	void (*freepage)(struct page___9 *);
	ssize_t (*direct_IO)(struct kiocb___8 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___7 *, struct page___9 *, struct page___9 *, enum migrate_mode);
	bool (*isolate_page)(struct page___9 *, isolate_mode_t);
	void (*putback_page)(struct page___9 *);
	int (*launder_page)(struct page___9 *);
	int (*is_partially_uptodate)(struct page___9 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___9 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___7 *, struct page___9 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___8 *, sector_t *);
	void (*swap_deactivate)(struct file___8 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___8 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___10 *bd_inode;
	struct super_block___8 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___8 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___4 {
	struct kobject___7 kobj;
	struct module___10 *owner;
	const struct file_operations___8 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___7 {
	struct dentry___9 * (*lookup)(struct inode___10 *, struct dentry___9 *, unsigned int);
	const char * (*get_link)(struct dentry___9 *, struct inode___10 *, struct delayed_call *);
	int (*permission)(struct inode___10 *, int);
	struct posix_acl * (*get_acl)(struct inode___10 *, int);
	int (*readlink)(struct dentry___9 *, char *, int);
	int (*create)(struct inode___10 *, struct dentry___9 *, umode_t, bool);
	int (*link)(struct dentry___9 *, struct inode___10 *, struct dentry___9 *);
	int (*unlink)(struct inode___10 *, struct dentry___9 *);
	int (*symlink)(struct inode___10 *, struct dentry___9 *, const char *);
	int (*mkdir)(struct inode___10 *, struct dentry___9 *, umode_t);
	int (*rmdir)(struct inode___10 *, struct dentry___9 *);
	int (*mknod)(struct inode___10 *, struct dentry___9 *, umode_t, dev_t);
	int (*rename)(struct inode___10 *, struct dentry___9 *, struct inode___10 *, struct dentry___9 *, unsigned int);
	int (*setattr)(struct dentry___9 *, struct iattr___8 *);
	int (*getattr)(const struct path___7 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___9 *, char *, size_t);
	int (*fiemap)(struct inode___10 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___10 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___10 *, struct dentry___9 *, struct file___8 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___10 *, struct dentry___9 *, umode_t);
	int (*set_acl)(struct inode___10 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___7 {
	void (*fl_copy_lock)(struct file_lock___8 *, struct file_lock___8 *);
	void (*fl_release_private)(struct file_lock___8 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___7;

struct lock_manager_operations___7;

struct file_lock___8 {
	struct file_lock___8 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___8 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___7 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___7 *fl_ops;
	const struct lock_manager_operations___7 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___7 {
	int (*lm_compare_owner)(struct file_lock___8 *, struct file_lock___8 *);
	long unsigned int (*lm_owner_key)(struct file_lock___8 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___8 *);
	int (*lm_grant)(struct file_lock___8 *, int);
	bool (*lm_break)(struct file_lock___8 *);
	int (*lm_change)(struct file_lock___8 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___8 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___7 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___7 *fa_next;
	struct file___8 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___7 {
	const char *name;
	int fs_flags;
	struct dentry___9 * (*mount)(struct file_system_type___7 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___8 *);
	struct module___10 *owner;
	struct file_system_type___7 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___7 {
	struct inode___10 * (*alloc_inode)(struct super_block___8 *);
	void (*destroy_inode)(struct inode___10 *);
	void (*dirty_inode)(struct inode___10 *, int);
	int (*write_inode)(struct inode___10 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___10 *);
	void (*evict_inode)(struct inode___10 *);
	void (*put_super)(struct super_block___8 *);
	int (*sync_fs)(struct super_block___8 *, int);
	int (*freeze_super)(struct super_block___8 *);
	int (*freeze_fs)(struct super_block___8 *);
	int (*thaw_super)(struct super_block___8 *);
	int (*unfreeze_fs)(struct super_block___8 *);
	int (*statfs)(struct dentry___9 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___8 *, int *, char *);
	void (*umount_begin)(struct super_block___8 *);
	int (*show_options)(struct seq_file___11 *, struct dentry___9 *);
	int (*show_devname)(struct seq_file___11 *, struct dentry___9 *);
	int (*show_path)(struct seq_file___11 *, struct dentry___9 *);
	int (*show_stats)(struct seq_file___11 *, struct dentry___9 *);
	ssize_t (*quota_read)(struct super_block___8 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___8 *, int, const char *, size_t, loff_t);
	struct dquot___7 ** (*get_dquots)(struct inode___10 *);
	int (*bdev_try_to_free_page)(struct super_block___8 *, struct page___9 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___8 *, struct shrink_control *);
	long int (*free_cached_objects)(struct super_block___8 *, struct shrink_control *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*key_restrict_link_func_t___7)(struct key___9 *, const struct key_type *, const union key_payload *, struct key___9 *);

struct key_restriction___8;

struct key___9 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___8 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___8 *restrict_link;
};

struct key_restriction___8 {
	key_restrict_link_func_t___7 check;
	struct key___9 *key;
	struct key_type *keytype;
};

struct seq_operations___8 {
	void * (*start)(struct seq_file___11 *, loff_t *);
	void (*stop)(struct seq_file___11 *, void *);
	void * (*next)(struct seq_file___11 *, void *, loff_t *);
	int (*show)(struct seq_file___11 *, void *);
};

typedef void compound_page_dtor___7(struct page___9 *);

struct property___2 {
	char *name;
	int length;
	void *value;
	struct property___2 *next;
	long unsigned int _flags;
	struct bin_attribute___7 attr;
};

struct module___11;

struct file___9;

struct kiocb___9;

struct vm_area_struct___10;

struct inode___11;

struct file_lock___9;

struct page___10;

struct file_operations___9 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___9 *, loff_t, int);
	ssize_t (*read)(struct file___9 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___9 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___9 *, struct iov_iter___4 *);
	ssize_t (*write_iter)(struct kiocb___9 *, struct iov_iter___4 *);
	int (*iopoll)(struct kiocb___9 *, bool);
	int (*iterate)(struct file___9 *, struct dir_context *);
	int (*iterate_shared)(struct file___9 *, struct dir_context *);
	__poll_t (*poll)(struct file___9 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___9 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___9 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___9 *, struct vm_area_struct___10 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___11 *, struct file___9 *);
	int (*flush)(struct file___9 *, fl_owner_t);
	int (*release)(struct inode___11 *, struct file___9 *);
	int (*fsync)(struct file___9 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___9 *, int);
	int (*lock)(struct file___9 *, int, struct file_lock___9 *);
	ssize_t (*sendpage)(struct file___9 *, struct page___10 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___9 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___9 *, int, struct file_lock___9 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___9 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___9 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___9 *, long int, struct file_lock___9 **, void **);
	long int (*fallocate)(struct file___9 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___9 *);
	ssize_t (*copy_file_range)(struct file___9 *, loff_t, struct file___9 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___9 *, loff_t, struct file___9 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___9 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___8 {
	u64 seqnum;
	struct vm_area_struct___10 *vmas[4];
};

struct page_frag___8 {
	struct page___10 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___9;

struct pid___7;

struct cred___9;

struct nsproxy___9;

struct signal_struct___8;

struct task_struct___10 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___10 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___9 *mm;
	struct mm_struct___9 *active_mm;
	struct vmacache___8 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___10 *real_parent;
	struct task_struct___10 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___10 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___7 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___7 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___7 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___9 *ptracer_cred;
	const struct cred___9 *real_cred;
	const struct cred___9 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___9 *nsproxy;
	struct signal_struct___8 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___10 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___4 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___8 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___10 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___4 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct arm64_midr_revidr {
	u32 midr_rv;
	u32 revidr_mask;
};

struct arm64_cpu_capabilities {
	const char *desc;
	u16 capability;
	u16 type;
	bool (*matches)(const struct arm64_cpu_capabilities *, int);
	void (*cpu_enable)(const struct arm64_cpu_capabilities *);
	union {
		struct {
			struct midr_range midr_range;
			const struct arm64_midr_revidr * const fixed_revs;
		};
		const struct midr_range *midr_range_list;
		struct {
			u32 sys_reg;
			u8 field_pos;
			u8 min_field_value;
			u8 hwcap_type;
			bool sign;
			long unsigned int hwcap;
		};
		const struct arm64_cpu_capabilities *match_list;
	};
};

struct secondary_data___9 {
	void *stack;
	struct task_struct___10 *task;
	long int status;
};

typedef struct page___10 *pgtable_t___8;

struct address_space___8;

struct dev_pagemap___8;

struct page___10 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___8 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___10 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___8 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___9 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___8 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___8;

struct lruvec___8 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___8 *pgdat;
};

struct zone___8 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___8 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___8 {
	struct zone___8 *zone;
	int zone_idx;
};

struct zonelist___8 {
	struct zoneref___8 _zonerefs[25];
};

struct pglist_data___8 {
	struct zone___8 node_zones[3];
	struct zonelist___8 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___10 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___10 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___8 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___9 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___10 *owner;
};

struct blocking_notifier_head___8 {
	struct rw_semaphore___9 rwsem;
	struct notifier_block *head;
};

struct pid_namespace___7;

struct upid___7 {
	int nr;
	struct pid_namespace___7 *ns;
};

struct dentry___10;

struct pid_namespace___7 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___10 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___7 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___10 *proc_self;
	struct dentry___10 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___3 *user_ns;
	struct ucounts___2 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common ns;
};

struct pid___7 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___7 numbers[1];
};

struct key___10;

struct user_struct___9 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___10 *uid_keyring;
	struct key___10 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___8;

struct vm_area_struct___10 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___10 *vm_next;
	struct vm_area_struct___10 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___9 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___8 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___9 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___8;

struct mm_struct___9 {
	struct {
		struct vm_area_struct___10 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___9 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___9 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___8 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___10 *owner;
		struct user_namespace___3 *user_ns;
		struct file___9 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___8 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___9 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___10 *session_keyring;
	struct key___10 *process_keyring;
	struct key___10 *thread_keyring;
	struct key___10 *request_key_auth;
	void *security;
	struct user_struct___9 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct nsproxy___9 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___7 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct signal_struct___8 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___10 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___10 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___7 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___7 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___9 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___7 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

union thread_union___7 {
	struct task_struct___10 task;
	long unsigned int stack[8192];
};

struct address_space_operations___8;

struct address_space___8 {
	struct inode___11 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___9 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___8 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___8)(struct vm_area_struct___10 *, long unsigned int, const struct page___10 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___8)(struct page___10 *, void *);

struct device___9;

struct dev_pagemap___8 {
	dev_page_fault_t___8 page_fault;
	dev_page_free_t___8 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___9 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___8 {
	struct vfsmount *mnt;
	struct dentry___10 *dentry;
};

struct fown_struct___7 {
	rwlock_t lock;
	struct pid___7 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___9 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___8 f_path;
	struct inode___11 *f_inode;
	const struct file_operations___9 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___7 f_owner;
	const struct cred___9 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___8 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___8;

struct vm_operations_struct___8 {
	void (*open)(struct vm_area_struct___10 *);
	void (*close)(struct vm_area_struct___10 *);
	int (*split)(struct vm_area_struct___10 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___10 *);
	vm_fault_t (*fault)(struct vm_fault___8 *);
	vm_fault_t (*huge_fault)(struct vm_fault___8 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___8 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___10 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___8 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___8 *);
	int (*access)(struct vm_area_struct___10 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___10 *);
	int (*set_policy)(struct vm_area_struct___10 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___10 *, long unsigned int);
	struct page___10 * (*find_special_page)(struct vm_area_struct___10 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___8 {
	struct task_struct___10 *task;
	struct core_thread___8 *next;
};

struct core_state___8 {
	atomic_t nr_threads;
	struct core_thread___8 dumper;
	struct completion startup;
};

struct vm_fault___8 {
	struct vm_area_struct___10 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___10 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___10 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___8 prealloc_pte;
};

struct kiocb___9 {
	struct file___9 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___9 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dentry_operations___8;

struct super_block___9;

struct dentry___10 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___10 *d_parent;
	struct qstr d_name;
	struct inode___11 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___8 *d_op;
	struct super_block___9 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___8;

struct block_device___9;

struct inode___11 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___8 *i_op;
	struct super_block___9 *i_sb;
	struct address_space___8 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___9 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___9 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___8 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___9 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___8 {
	int (*d_revalidate)(struct dentry___10 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___10 *, unsigned int);
	int (*d_hash)(const struct dentry___10 *, struct qstr *);
	int (*d_compare)(const struct dentry___10 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___10 *);
	int (*d_init)(struct dentry___10 *);
	void (*d_release)(struct dentry___10 *);
	void (*d_prune)(struct dentry___10 *);
	void (*d_iput)(struct dentry___10 *, struct inode___11 *);
	char * (*d_dname)(struct dentry___10 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___8 *);
	int (*d_manage)(const struct path___8 *, bool);
	struct dentry___10 * (*d_real)(struct dentry___10 *, const struct inode___11 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___8;

struct mem_dqinfo___8 {
	struct quota_format_type___8 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___8;

struct quota_info___8 {
	unsigned int flags;
	struct rw_semaphore___9 dqio_sem;
	struct inode___11 *files[3];
	struct mem_dqinfo___8 info[3];
	const struct quota_format_ops___8 *ops[3];
};

struct rcuwait___8 {
	struct task_struct___10 *task;
};

struct percpu_rw_semaphore___8 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___9 rw_sem;
	struct rcuwait___8 writer;
	int readers_block;
};

struct sb_writers___8 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___8 rw_sem[3];
};

struct file_system_type___8;

struct super_operations___8;

struct dquot_operations___8;

struct quotactl_ops___8;

struct super_block___9 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___8 *s_type;
	const struct super_operations___8 *s_op;
	const struct dquot_operations___8 *dq_op;
	const struct quotactl_ops___8 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___10 *s_root;
	struct rw_semaphore___9 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___9 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___8 s_dquot;
	struct sb_writers___8 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___8 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct iattr___9 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___9 *ia_file;
};

struct dquot___8 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___9 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___8 {
	int qf_fmt_id;
	const struct quota_format_ops___8 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___8 *qf_next;
};

struct quota_format_ops___8 {
	int (*check_quota_file)(struct super_block___9 *, int);
	int (*read_file_info)(struct super_block___9 *, int);
	int (*write_file_info)(struct super_block___9 *, int);
	int (*free_file_info)(struct super_block___9 *, int);
	int (*read_dqblk)(struct dquot___8 *);
	int (*commit_dqblk)(struct dquot___8 *);
	int (*release_dqblk)(struct dquot___8 *);
	int (*get_next_id)(struct super_block___9 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___8 {
	int (*write_dquot)(struct dquot___8 *);
	struct dquot___8 * (*alloc_dquot)(struct super_block___9 *, int);
	void (*destroy_dquot)(struct dquot___8 *);
	int (*acquire_dquot)(struct dquot___8 *);
	int (*release_dquot)(struct dquot___8 *);
	int (*mark_dirty)(struct dquot___8 *);
	int (*write_info)(struct super_block___9 *, int);
	qsize_t * (*get_reserved_space)(struct inode___11 *);
	int (*get_projid)(struct inode___11 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___11 *, qsize_t *);
	int (*get_next_id)(struct super_block___9 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___8 {
	int (*quota_on)(struct super_block___9 *, int, int, const struct path___8 *);
	int (*quota_off)(struct super_block___9 *, int);
	int (*quota_enable)(struct super_block___9 *, unsigned int);
	int (*quota_disable)(struct super_block___9 *, unsigned int);
	int (*quota_sync)(struct super_block___9 *, int);
	int (*set_info)(struct super_block___9 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___9 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___9 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___9 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___9 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___9 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___8 {
	int (*writepage)(struct page___10 *, struct writeback_control___3 *);
	int (*readpage)(struct file___9 *, struct page___10 *);
	int (*writepages)(struct address_space___8 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___10 *);
	int (*readpages)(struct file___9 *, struct address_space___8 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___9 *, struct address_space___8 *, loff_t, unsigned int, unsigned int, struct page___10 **, void **);
	int (*write_end)(struct file___9 *, struct address_space___8 *, loff_t, unsigned int, unsigned int, struct page___10 *, void *);
	sector_t (*bmap)(struct address_space___8 *, sector_t);
	void (*invalidatepage)(struct page___10 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___10 *, gfp_t);
	void (*freepage)(struct page___10 *);
	ssize_t (*direct_IO)(struct kiocb___9 *, struct iov_iter___4 *);
	int (*migratepage)(struct address_space___8 *, struct page___10 *, struct page___10 *, enum migrate_mode);
	bool (*isolate_page)(struct page___10 *, isolate_mode_t);
	void (*putback_page)(struct page___10 *);
	int (*launder_page)(struct page___10 *);
	int (*is_partially_uptodate)(struct page___10 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___10 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___8 *, struct page___10 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___9 *, sector_t *);
	void (*swap_deactivate)(struct file___9 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___9 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___11 *bd_inode;
	struct super_block___9 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___9 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___8 {
	struct dentry___10 * (*lookup)(struct inode___11 *, struct dentry___10 *, unsigned int);
	const char * (*get_link)(struct dentry___10 *, struct inode___11 *, struct delayed_call *);
	int (*permission)(struct inode___11 *, int);
	struct posix_acl * (*get_acl)(struct inode___11 *, int);
	int (*readlink)(struct dentry___10 *, char *, int);
	int (*create)(struct inode___11 *, struct dentry___10 *, umode_t, bool);
	int (*link)(struct dentry___10 *, struct inode___11 *, struct dentry___10 *);
	int (*unlink)(struct inode___11 *, struct dentry___10 *);
	int (*symlink)(struct inode___11 *, struct dentry___10 *, const char *);
	int (*mkdir)(struct inode___11 *, struct dentry___10 *, umode_t);
	int (*rmdir)(struct inode___11 *, struct dentry___10 *);
	int (*mknod)(struct inode___11 *, struct dentry___10 *, umode_t, dev_t);
	int (*rename)(struct inode___11 *, struct dentry___10 *, struct inode___11 *, struct dentry___10 *, unsigned int);
	int (*setattr)(struct dentry___10 *, struct iattr___9 *);
	int (*getattr)(const struct path___8 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___10 *, char *, size_t);
	int (*fiemap)(struct inode___11 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___11 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___11 *, struct dentry___10 *, struct file___9 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___11 *, struct dentry___10 *, umode_t);
	int (*set_acl)(struct inode___11 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___8 {
	void (*fl_copy_lock)(struct file_lock___9 *, struct file_lock___9 *);
	void (*fl_release_private)(struct file_lock___9 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___8;

struct lock_manager_operations___8;

struct file_lock___9 {
	struct file_lock___9 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___9 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___8 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___8 *fl_ops;
	const struct lock_manager_operations___8 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___8 {
	int (*lm_compare_owner)(struct file_lock___9 *, struct file_lock___9 *);
	long unsigned int (*lm_owner_key)(struct file_lock___9 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___9 *);
	int (*lm_grant)(struct file_lock___9 *, int);
	bool (*lm_break)(struct file_lock___9 *);
	int (*lm_change)(struct file_lock___9 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___9 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___8 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___8 *fa_next;
	struct file___9 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___8 {
	const char *name;
	int fs_flags;
	struct dentry___10 * (*mount)(struct file_system_type___8 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___9 *);
	struct module___11 *owner;
	struct file_system_type___8 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___8 {
	struct inode___11 * (*alloc_inode)(struct super_block___9 *);
	void (*destroy_inode)(struct inode___11 *);
	void (*dirty_inode)(struct inode___11 *, int);
	int (*write_inode)(struct inode___11 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___11 *);
	void (*evict_inode)(struct inode___11 *);
	void (*put_super)(struct super_block___9 *);
	int (*sync_fs)(struct super_block___9 *, int);
	int (*freeze_super)(struct super_block___9 *);
	int (*freeze_fs)(struct super_block___9 *);
	int (*thaw_super)(struct super_block___9 *);
	int (*unfreeze_fs)(struct super_block___9 *);
	int (*statfs)(struct dentry___10 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___9 *, int *, char *);
	void (*umount_begin)(struct super_block___9 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___10 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___10 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___10 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___10 *);
	ssize_t (*quota_read)(struct super_block___9 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___9 *, int, const char *, size_t, loff_t);
	struct dquot___8 ** (*get_dquots)(struct inode___11 *);
	int (*bdev_try_to_free_page)(struct super_block___9 *, struct page___10 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___9 *, struct shrink_control *);
	long int (*free_cached_objects)(struct super_block___9 *, struct shrink_control *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___8;

struct kobj_type___8;

struct kernfs_node___8;

struct kobject___8 {
	const char *name;
	struct list_head entry;
	struct kobject___8 *parent;
	struct kset___8 *kset;
	struct kobj_type___8 *ktype;
	struct kernfs_node___8 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_root___8;

struct kernfs_elem_dir___8 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___8 *root;
};

struct kernfs_syscall_ops___8;

struct kernfs_root___8 {
	struct kernfs_node___8 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___8 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___8 {
	struct kernfs_node___8 *target_kn;
};

struct kernfs_ops___8;

struct kernfs_elem_attr___8 {
	const struct kernfs_ops___8 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___8 *notify_next;
};

struct kernfs_node___8 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___8 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___8 dir;
		struct kernfs_elem_symlink___8 symlink;
		struct kernfs_elem_attr___8 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___8;

struct kernfs_ops___8 {
	int (*open)(struct kernfs_open_file___8 *);
	void (*release)(struct kernfs_open_file___8 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___8 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___8 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___8 *, struct vm_area_struct___10 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___8 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___8 {
	int (*remount_fs)(struct kernfs_root___8 *, int *, char *);
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___8 *);
	int (*mkdir)(struct kernfs_node___8 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___8 *);
	int (*rename)(struct kernfs_node___8 *, struct kernfs_node___8 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___8 *, struct kernfs_root___8 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___8 {
	struct kernfs_node___8 *kn;
	struct file___9 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___8 *vm_ops;
};

struct bin_attribute___8;

struct attribute_group___8 {
	const char *name;
	umode_t (*is_visible)(struct kobject___8 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___8 *, struct bin_attribute___8 *, int);
	struct attribute **attrs;
	struct bin_attribute___8 **bin_attrs;
};

struct bin_attribute___8 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___9 *, struct kobject___8 *, struct bin_attribute___8 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___9 *, struct kobject___8 *, struct bin_attribute___8 *, char *, loff_t, size_t);
	int (*mmap)(struct file___9 *, struct kobject___8 *, struct bin_attribute___8 *, struct vm_area_struct___10 *);
};

struct sysfs_ops___8 {
	ssize_t (*show)(struct kobject___8 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___8 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___8;

struct kset___8 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___8 kobj;
	const struct kset_uevent_ops___8 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___8 {
	void (*release)(struct kobject___8 *);
	const struct sysfs_ops___8 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___8 *);
	const void * (*namespace)(struct kobject___8 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___8 {
	int (* const filter)(struct kset___8 *, struct kobject___8 *);
	const char * (* const name)(struct kset___8 *, struct kobject___8 *);
	int (* const uevent)(struct kset___8 *, struct kobject___8 *, struct kobj_uevent_env *);
};

struct kobj_attribute___8 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___8 *, struct kobj_attribute___8 *, char *);
	ssize_t (*store)(struct kobject___8 *, struct kobj_attribute___8 *, const char *, size_t);
};

struct dev_pm_ops___8 {
	int (*prepare)(struct device___9 *);
	void (*complete)(struct device___9 *);
	int (*suspend)(struct device___9 *);
	int (*resume)(struct device___9 *);
	int (*freeze)(struct device___9 *);
	int (*thaw)(struct device___9 *);
	int (*poweroff)(struct device___9 *);
	int (*restore)(struct device___9 *);
	int (*suspend_late)(struct device___9 *);
	int (*resume_early)(struct device___9 *);
	int (*freeze_late)(struct device___9 *);
	int (*thaw_early)(struct device___9 *);
	int (*poweroff_late)(struct device___9 *);
	int (*restore_early)(struct device___9 *);
	int (*suspend_noirq)(struct device___9 *);
	int (*resume_noirq)(struct device___9 *);
	int (*freeze_noirq)(struct device___9 *);
	int (*thaw_noirq)(struct device___9 *);
	int (*poweroff_noirq)(struct device___9 *);
	int (*restore_noirq)(struct device___9 *);
	int (*runtime_suspend)(struct device___9 *);
	int (*runtime_resume)(struct device___9 *);
	int (*runtime_idle)(struct device___9 *);
};

struct dev_pm_info___8 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___9 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___8;

struct bus_type___8;

struct device_driver___8;

struct dev_pm_domain___8;

struct class___8;

struct device___9 {
	struct device___9 *parent;
	struct device_private *p;
	struct kobject___8 kobj;
	const char *init_name;
	const struct device_type___8 *type;
	struct mutex mutex;
	struct bus_type___8 *bus;
	struct device_driver___8 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___8 power;
	struct dev_pm_domain___8 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___8 *class;
	const struct attribute_group___8 **groups;
	void (*release)(struct device___9 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___8 {
	struct dev_pm_ops___8 ops;
	void (*detach)(struct device___9 *, bool);
	int (*activate)(struct device___9 *);
	void (*sync)(struct device___9 *);
	void (*dismiss)(struct device___9 *);
};

struct bus_type___8 {
	const char *name;
	const char *dev_name;
	struct device___9 *dev_root;
	const struct attribute_group___8 **bus_groups;
	const struct attribute_group___8 **dev_groups;
	const struct attribute_group___8 **drv_groups;
	int (*match)(struct device___9 *, struct device_driver___8 *);
	int (*uevent)(struct device___9 *, struct kobj_uevent_env *);
	int (*probe)(struct device___9 *);
	int (*remove)(struct device___9 *);
	void (*shutdown)(struct device___9 *);
	int (*online)(struct device___9 *);
	int (*offline)(struct device___9 *);
	int (*suspend)(struct device___9 *, pm_message_t);
	int (*resume)(struct device___9 *);
	int (*num_vf)(struct device___9 *);
	int (*dma_configure)(struct device___9 *);
	const struct dev_pm_ops___8 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___8 {
	const char *name;
	struct bus_type___8 *bus;
	struct module___11 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___9 *);
	int (*remove)(struct device___9 *);
	void (*shutdown)(struct device___9 *);
	int (*suspend)(struct device___9 *, pm_message_t);
	int (*resume)(struct device___9 *);
	const struct attribute_group___8 **groups;
	const struct dev_pm_ops___8 *pm;
	void (*coredump)(struct device___9 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___8 {
	const char *name;
	const struct attribute_group___8 **groups;
	int (*uevent)(struct device___9 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___9 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___9 *);
	const struct dev_pm_ops___8 *pm;
};

struct class___8 {
	const char *name;
	struct module___11 *owner;
	const struct attribute_group___8 **class_groups;
	const struct attribute_group___8 **dev_groups;
	struct kobject___8 *dev_kobj;
	int (*dev_uevent)(struct device___9 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___9 *, umode_t *);
	void (*class_release)(struct class___8 *);
	void (*dev_release)(struct device___9 *);
	int (*shutdown_pre)(struct device___9 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___9 *);
	const struct dev_pm_ops___8 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___7 {
	struct device___9 dev;
};

enum cpu_pm_event {
	CPU_PM_ENTER = 0,
	CPU_PM_ENTER_FAILED = 1,
	CPU_PM_EXIT = 2,
	CPU_CLUSTER_PM_ENTER = 3,
	CPU_CLUSTER_PM_ENTER_FAILED = 4,
	CPU_CLUSTER_PM_EXIT = 5,
};

typedef int (*key_restrict_link_func_t___8)(struct key___10 *, const struct key_type *, const union key_payload *, struct key___10 *);

struct key_restriction___9;

struct key___10 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___9 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___9 *restrict_link;
};

struct key_restriction___9 {
	key_restrict_link_func_t___8 check;
	struct key___10 *key;
	struct key_type *keytype;
};

typedef void compound_page_dtor___8(struct page___10 *);

struct fpsimd_last_state_struct {
	struct user_fpsimd_state *st;
	void *sve_state;
	unsigned int sve_vl;
};

struct module___12;

struct file___10;

struct kiocb___10;

struct poll_table_struct___8;

struct vm_area_struct___11;

struct inode___12;

struct file_lock___10;

struct page___11;

struct seq_file___12;

struct file_operations___10 {
	struct module___12 *owner;
	loff_t (*llseek)(struct file___10 *, loff_t, int);
	ssize_t (*read)(struct file___10 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___10 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___10 *, struct iov_iter___4 *);
	ssize_t (*write_iter)(struct kiocb___10 *, struct iov_iter___4 *);
	int (*iopoll)(struct kiocb___10 *, bool);
	int (*iterate)(struct file___10 *, struct dir_context *);
	int (*iterate_shared)(struct file___10 *, struct dir_context *);
	__poll_t (*poll)(struct file___10 *, struct poll_table_struct___8 *);
	long int (*unlocked_ioctl)(struct file___10 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___10 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___10 *, struct vm_area_struct___11 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___12 *, struct file___10 *);
	int (*flush)(struct file___10 *, fl_owner_t);
	int (*release)(struct inode___12 *, struct file___10 *);
	int (*fsync)(struct file___10 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___10 *, int);
	int (*lock)(struct file___10 *, int, struct file_lock___10 *);
	ssize_t (*sendpage)(struct file___10 *, struct page___11 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___10 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___10 *, int, struct file_lock___10 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___10 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___10 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___10 *, long int, struct file_lock___10 **, void **);
	long int (*fallocate)(struct file___10 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___12 *, struct file___10 *);
	ssize_t (*copy_file_range)(struct file___10 *, loff_t, struct file___10 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___10 *, loff_t, struct file___10 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___10 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___9 {
	u64 seqnum;
	struct vm_area_struct___11 *vmas[4];
};

struct page_frag___9 {
	struct page___11 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___5;

struct debug_info___5 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___5 *hbp_break[16];
	struct perf_event___5 *hbp_watch[16];
};

struct thread_struct___5 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___5 debug;
	long: 64;
};

struct mm_struct___10;

struct pid___8;

struct cred___10;

struct nsproxy___10;

struct signal_struct___9;

struct css_set___6;

struct perf_event_context___6;

struct vm_struct___7;

struct task_struct___11 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___11 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___10 *mm;
	struct mm_struct___10 *active_mm;
	struct vmacache___9 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___11 *real_parent;
	struct task_struct___11 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___11 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___8 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___8 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___8 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___10 *ptracer_cred;
	const struct cred___10 *real_cred;
	const struct cred___10 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___10 *nsproxy;
	struct signal_struct___9 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___11 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___4 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___6 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___6 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___9 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___11 *oom_reaper_list;
	struct vm_struct___7 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___5 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___5 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___11 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___5)(struct perf_event___5 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___5;

struct fasync_struct___9;

struct pid_namespace___8;

struct trace_event_call___6;

struct perf_cgroup___5;

struct perf_event___5 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___5 *group_leader;
	struct pmu___5 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___5 hw;
	struct perf_event_context___6 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___5 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___11 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___9 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___5 *);
	struct callback_head callback_head;
	struct pid_namespace___8 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___5 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___5 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___6 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___5 *cgrp;
	struct list_head sb_list;
};

struct rw_semaphore___10 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___11 *owner;
};

struct key___11;

struct ucounts___6;

struct user_namespace___7 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___7 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common ns;
	long unsigned int flags;
	struct key___11 *persistent_keyring_register;
	struct rw_semaphore___10 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___6 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct secondary_data___10 {
	void *stack;
	struct task_struct___11 *task;
	long int status;
};

struct clock_event_device___2;

struct arch_timer_erratum_workaround___2 {
	enum arch_timer_erratum_match_type match_type;
	const void *id;
	const char *desc;
	u32 (*read_cntp_tval_el0)();
	u32 (*read_cntv_tval_el0)();
	u64 (*read_cntpct_el0)();
	u64 (*read_cntvct_el0)();
	int (*set_next_event_phys)(long unsigned int, struct clock_event_device___2 *);
	int (*set_next_event_virt)(long unsigned int, struct clock_event_device___2 *);
};

struct clock_event_device___2 {
	void (*event_handler)(struct clock_event_device___2 *);
	int (*set_next_event)(long unsigned int, struct clock_event_device___2 *);
	int (*set_next_ktime)(ktime_t, struct clock_event_device___2 *);
	ktime_t next_event;
	u64 max_delta_ns;
	u64 min_delta_ns;
	u32 mult;
	u32 shift;
	enum clock_event_state state_use_accessors;
	unsigned int features;
	long unsigned int retries;
	int (*set_state_periodic)(struct clock_event_device___2 *);
	int (*set_state_oneshot)(struct clock_event_device___2 *);
	int (*set_state_oneshot_stopped)(struct clock_event_device___2 *);
	int (*set_state_shutdown)(struct clock_event_device___2 *);
	int (*tick_resume)(struct clock_event_device___2 *);
	void (*broadcast)(const struct cpumask *);
	void (*suspend)(struct clock_event_device___2 *);
	void (*resume)(struct clock_event_device___2 *);
	long unsigned int min_delta_ticks;
	long unsigned int max_delta_ticks;
	const char *name;
	int rating;
	int irq;
	int bound_on;
	const struct cpumask *cpumask;
	struct list_head list;
	struct module___12 *owner;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___11 *pgtable_t___9;

struct address_space___9;

struct dev_pagemap___9;

struct page___11 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___9 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___11 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___9 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___10 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___9 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___9;

struct lruvec___9 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___9 *pgdat;
};

struct zone___9 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___9 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___9 {
	struct zone___9 *zone;
	int zone_idx;
};

struct zonelist___9 {
	struct zoneref___9 _zonerefs[25];
};

struct pglist_data___9 {
	struct zone___9 node_zones[3];
	struct zonelist___9 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___11 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___11 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___9 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___9 {
	struct rw_semaphore___10 rwsem;
	struct notifier_block *head;
};

struct upid___8 {
	int nr;
	struct pid_namespace___8 *ns;
};

struct dentry___11;

struct pid_namespace___8 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___11 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___8 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___11 *proc_self;
	struct dentry___11 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___7 *user_ns;
	struct ucounts___6 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common ns;
};

struct pid___8 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___8 numbers[1];
};

struct plist_head {
	struct list_head node_list;
};

struct user_struct___10 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___11 *uid_keyring;
	struct key___11 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___9;

struct vm_area_struct___11 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___11 *vm_next;
	struct vm_area_struct___11 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___10 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___9 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___10 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___9;

struct mm_struct___10 {
	struct {
		struct vm_area_struct___11 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___10 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___10 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___9 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___11 *owner;
		struct user_namespace___7 *user_ns;
		struct file___10 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___9 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___10 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___11 *session_keyring;
	struct key___11 *process_keyring;
	struct key___11 *thread_keyring;
	struct key___11 *request_key_auth;
	void *security;
	struct user_struct___10 *user;
	struct user_namespace___7 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct uts_namespace___4;

struct cgroup_namespace___6;

struct nsproxy___10 {
	atomic_t count;
	struct uts_namespace___4 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___8 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___6 *cgroup_ns;
};

struct signal_struct___9 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___11 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___11 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___8 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___8 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___10 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___8 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___5;

struct cgroup___5;

struct css_set___6 {
	struct cgroup_subsys_state___5 *subsys[13];
	refcount_t refcount;
	struct css_set___6 *dom_cset;
	struct cgroup___5 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___5 *mg_src_cgrp;
	struct cgroup___5 *mg_dst_cgrp;
	struct css_set___6 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___6 {
	struct pmu___5 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___11 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___6 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___7 {
	struct vm_struct___7 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___11 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___8 {
	struct task_struct___11 task;
	long unsigned int stack[8192];
};

struct address_space_operations___9;

struct address_space___9 {
	struct inode___12 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___10 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___9 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___9)(struct vm_area_struct___11 *, long unsigned int, const struct page___11 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___9)(struct page___11 *, void *);

struct device___10;

struct dev_pagemap___9 {
	dev_page_fault_t___9 page_fault;
	dev_page_free_t___9 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___10 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___9 {
	struct vfsmount *mnt;
	struct dentry___11 *dentry;
};

struct fown_struct___8 {
	rwlock_t lock;
	struct pid___8 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___10 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___9 f_path;
	struct inode___12 *f_inode;
	const struct file_operations___10 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___8 f_owner;
	const struct cred___10 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___9 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___9;

struct vm_operations_struct___9 {
	void (*open)(struct vm_area_struct___11 *);
	void (*close)(struct vm_area_struct___11 *);
	int (*split)(struct vm_area_struct___11 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___11 *);
	vm_fault_t (*fault)(struct vm_fault___9 *);
	vm_fault_t (*huge_fault)(struct vm_fault___9 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___9 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___11 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___9 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___9 *);
	int (*access)(struct vm_area_struct___11 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___11 *);
	int (*set_policy)(struct vm_area_struct___11 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___11 *, long unsigned int);
	struct page___11 * (*find_special_page)(struct vm_area_struct___11 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___9 {
	struct task_struct___11 *task;
	struct core_thread___9 *next;
};

struct core_state___9 {
	atomic_t nr_threads;
	struct core_thread___9 dumper;
	struct completion startup;
};

struct vm_fault___9 {
	struct vm_area_struct___11 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___11 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___11 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___9 prealloc_pte;
};

struct kset___9;

struct kobj_type___9;

struct kernfs_node___9;

struct kobject___9 {
	const char *name;
	struct list_head entry;
	struct kobject___9 *parent;
	struct kset___9 *kset;
	struct kobj_type___9 *ktype;
	struct kernfs_node___9 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___8 {
	struct kobject___9 kobj;
	struct module___12 *mod;
	struct kobject___9 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___8 {
	struct module___12 *mod;
	struct latch_tree_node node;
};

struct module_layout___8 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___8 mtn;
};

struct module_attribute___8;

struct kernel_param___8;

struct module___12 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___8 mkobj;
	struct module_attribute___8 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___9 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___8 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___8 core_layout;
	struct module_layout___8 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___6 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kiocb___10 {
	struct file___10 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___10 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dentry_operations___9;

struct super_block___10;

struct dentry___11 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___11 *d_parent;
	struct qstr d_name;
	struct inode___12 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___9 *d_op;
	struct super_block___10 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___9;

struct block_device___10;

struct cdev___5;

struct inode___12 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___9 *i_op;
	struct super_block___10 *i_sb;
	struct address_space___9 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___10 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___10 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___9 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___10 *i_bdev;
		struct cdev___5 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___9 {
	int (*d_revalidate)(struct dentry___11 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___11 *, unsigned int);
	int (*d_hash)(const struct dentry___11 *, struct qstr *);
	int (*d_compare)(const struct dentry___11 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___11 *);
	int (*d_init)(struct dentry___11 *);
	void (*d_release)(struct dentry___11 *);
	void (*d_prune)(struct dentry___11 *);
	void (*d_iput)(struct dentry___11 *, struct inode___12 *);
	char * (*d_dname)(struct dentry___11 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___9 *);
	int (*d_manage)(const struct path___9 *, bool);
	struct dentry___11 * (*d_real)(struct dentry___11 *, const struct inode___12 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___9;

struct mem_dqinfo___9 {
	struct quota_format_type___9 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___9;

struct quota_info___9 {
	unsigned int flags;
	struct rw_semaphore___10 dqio_sem;
	struct inode___12 *files[3];
	struct mem_dqinfo___9 info[3];
	const struct quota_format_ops___9 *ops[3];
};

struct rcuwait___9 {
	struct task_struct___11 *task;
};

struct percpu_rw_semaphore___9 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___10 rw_sem;
	struct rcuwait___9 writer;
	int readers_block;
};

struct sb_writers___9 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___9 rw_sem[3];
};

struct file_system_type___9;

struct super_operations___9;

struct dquot_operations___9;

struct quotactl_ops___9;

struct super_block___10 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___9 *s_type;
	const struct super_operations___9 *s_op;
	const struct dquot_operations___9 *dq_op;
	const struct quotactl_ops___9 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___11 *s_root;
	struct rw_semaphore___10 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___10 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___9 s_dquot;
	struct sb_writers___9 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___9 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___7 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct iattr___10 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___10 *ia_file;
};

struct dquot___9 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___10 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___9 {
	int qf_fmt_id;
	const struct quota_format_ops___9 *qf_ops;
	struct module___12 *qf_owner;
	struct quota_format_type___9 *qf_next;
};

struct quota_format_ops___9 {
	int (*check_quota_file)(struct super_block___10 *, int);
	int (*read_file_info)(struct super_block___10 *, int);
	int (*write_file_info)(struct super_block___10 *, int);
	int (*free_file_info)(struct super_block___10 *, int);
	int (*read_dqblk)(struct dquot___9 *);
	int (*commit_dqblk)(struct dquot___9 *);
	int (*release_dqblk)(struct dquot___9 *);
	int (*get_next_id)(struct super_block___10 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___9 {
	int (*write_dquot)(struct dquot___9 *);
	struct dquot___9 * (*alloc_dquot)(struct super_block___10 *, int);
	void (*destroy_dquot)(struct dquot___9 *);
	int (*acquire_dquot)(struct dquot___9 *);
	int (*release_dquot)(struct dquot___9 *);
	int (*mark_dirty)(struct dquot___9 *);
	int (*write_info)(struct super_block___10 *, int);
	qsize_t * (*get_reserved_space)(struct inode___12 *);
	int (*get_projid)(struct inode___12 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___12 *, qsize_t *);
	int (*get_next_id)(struct super_block___10 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___9 {
	int (*quota_on)(struct super_block___10 *, int, int, const struct path___9 *);
	int (*quota_off)(struct super_block___10 *, int);
	int (*quota_enable)(struct super_block___10 *, unsigned int);
	int (*quota_disable)(struct super_block___10 *, unsigned int);
	int (*quota_sync)(struct super_block___10 *, int);
	int (*set_info)(struct super_block___10 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___10 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___10 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___10 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___10 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___10 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___9 {
	int (*writepage)(struct page___11 *, struct writeback_control___3 *);
	int (*readpage)(struct file___10 *, struct page___11 *);
	int (*writepages)(struct address_space___9 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___11 *);
	int (*readpages)(struct file___10 *, struct address_space___9 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___10 *, struct address_space___9 *, loff_t, unsigned int, unsigned int, struct page___11 **, void **);
	int (*write_end)(struct file___10 *, struct address_space___9 *, loff_t, unsigned int, unsigned int, struct page___11 *, void *);
	sector_t (*bmap)(struct address_space___9 *, sector_t);
	void (*invalidatepage)(struct page___11 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___11 *, gfp_t);
	void (*freepage)(struct page___11 *);
	ssize_t (*direct_IO)(struct kiocb___10 *, struct iov_iter___4 *);
	int (*migratepage)(struct address_space___9 *, struct page___11 *, struct page___11 *, enum migrate_mode);
	bool (*isolate_page)(struct page___11 *, isolate_mode_t);
	void (*putback_page)(struct page___11 *);
	int (*launder_page)(struct page___11 *);
	int (*is_partially_uptodate)(struct page___11 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___11 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___9 *, struct page___11 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___10 *, sector_t *);
	void (*swap_deactivate)(struct file___10 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___10 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___12 *bd_inode;
	struct super_block___10 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___10 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___5 {
	struct kobject___9 kobj;
	struct module___12 *owner;
	const struct file_operations___10 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___9 {
	struct dentry___11 * (*lookup)(struct inode___12 *, struct dentry___11 *, unsigned int);
	const char * (*get_link)(struct dentry___11 *, struct inode___12 *, struct delayed_call *);
	int (*permission)(struct inode___12 *, int);
	struct posix_acl * (*get_acl)(struct inode___12 *, int);
	int (*readlink)(struct dentry___11 *, char *, int);
	int (*create)(struct inode___12 *, struct dentry___11 *, umode_t, bool);
	int (*link)(struct dentry___11 *, struct inode___12 *, struct dentry___11 *);
	int (*unlink)(struct inode___12 *, struct dentry___11 *);
	int (*symlink)(struct inode___12 *, struct dentry___11 *, const char *);
	int (*mkdir)(struct inode___12 *, struct dentry___11 *, umode_t);
	int (*rmdir)(struct inode___12 *, struct dentry___11 *);
	int (*mknod)(struct inode___12 *, struct dentry___11 *, umode_t, dev_t);
	int (*rename)(struct inode___12 *, struct dentry___11 *, struct inode___12 *, struct dentry___11 *, unsigned int);
	int (*setattr)(struct dentry___11 *, struct iattr___10 *);
	int (*getattr)(const struct path___9 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___11 *, char *, size_t);
	int (*fiemap)(struct inode___12 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___12 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___12 *, struct dentry___11 *, struct file___10 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___12 *, struct dentry___11 *, umode_t);
	int (*set_acl)(struct inode___12 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___9 {
	void (*fl_copy_lock)(struct file_lock___10 *, struct file_lock___10 *);
	void (*fl_release_private)(struct file_lock___10 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___9;

struct file_lock___10 {
	struct file_lock___10 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___10 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___9 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___9 *fl_ops;
	const struct lock_manager_operations___9 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___9 {
	int (*lm_compare_owner)(struct file_lock___10 *, struct file_lock___10 *);
	long unsigned int (*lm_owner_key)(struct file_lock___10 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___10 *);
	int (*lm_grant)(struct file_lock___10 *, int);
	bool (*lm_break)(struct file_lock___10 *);
	int (*lm_change)(struct file_lock___10 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___10 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___9 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___9 *fa_next;
	struct file___10 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___9 {
	const char *name;
	int fs_flags;
	struct dentry___11 * (*mount)(struct file_system_type___9 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___10 *);
	struct module___12 *owner;
	struct file_system_type___9 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___9 {
	struct inode___12 * (*alloc_inode)(struct super_block___10 *);
	void (*destroy_inode)(struct inode___12 *);
	void (*dirty_inode)(struct inode___12 *, int);
	int (*write_inode)(struct inode___12 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___12 *);
	void (*evict_inode)(struct inode___12 *);
	void (*put_super)(struct super_block___10 *);
	int (*sync_fs)(struct super_block___10 *, int);
	int (*freeze_super)(struct super_block___10 *);
	int (*freeze_fs)(struct super_block___10 *);
	int (*thaw_super)(struct super_block___10 *);
	int (*unfreeze_fs)(struct super_block___10 *);
	int (*statfs)(struct dentry___11 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___10 *, int *, char *);
	void (*umount_begin)(struct super_block___10 *);
	int (*show_options)(struct seq_file___12 *, struct dentry___11 *);
	int (*show_devname)(struct seq_file___12 *, struct dentry___11 *);
	int (*show_path)(struct seq_file___12 *, struct dentry___11 *);
	int (*show_stats)(struct seq_file___12 *, struct dentry___11 *);
	ssize_t (*quota_read)(struct super_block___10 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___10 *, int, const char *, size_t, loff_t);
	struct dquot___9 ** (*get_dquots)(struct inode___12 *);
	int (*bdev_try_to_free_page)(struct super_block___10 *, struct page___11 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___10 *, struct shrink_control *);
	long int (*free_cached_objects)(struct super_block___10 *, struct shrink_control *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___6)(struct file___10 *, wait_queue_head_t *, struct poll_table_struct___8 *);

struct poll_table_struct___8 {
	poll_queue_proc___6 _qproc;
	__poll_t _key;
};

struct seq_operations___9;

struct seq_file___12 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___9 *op;
	int poll_event;
	const struct file___10 *file;
	void *private;
};

struct dev_pm_qos___2;

struct dev_pm_info___9 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___10 *, s32);
	struct dev_pm_qos___2 *qos;
};

struct device_type___9;

struct bus_type___9;

struct device_driver___9;

struct dev_pm_domain___9;

struct device_node___4;

struct fwnode_handle___7;

struct class___9;

struct attribute_group___9;

struct device___10 {
	struct device___10 *parent;
	struct device_private *p;
	struct kobject___9 kobj;
	const char *init_name;
	const struct device_type___9 *type;
	struct mutex mutex;
	struct bus_type___9 *bus;
	struct device_driver___9 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___9 power;
	struct dev_pm_domain___9 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___4 *of_node;
	struct fwnode_handle___7 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___9 *class;
	const struct attribute_group___9 **groups;
	void (*release)(struct device___10 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct kernfs_root___9;

struct kernfs_elem_dir___9 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___9 *root;
};

struct kernfs_syscall_ops___9;

struct kernfs_root___9 {
	struct kernfs_node___9 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___9 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___9 {
	struct kernfs_node___9 *target_kn;
};

struct kernfs_ops___9;

struct kernfs_elem_attr___9 {
	const struct kernfs_ops___9 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___9 *notify_next;
};

struct kernfs_node___9 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___9 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___9 dir;
		struct kernfs_elem_symlink___9 symlink;
		struct kernfs_elem_attr___9 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___9;

struct kernfs_ops___9 {
	int (*open)(struct kernfs_open_file___9 *);
	void (*release)(struct kernfs_open_file___9 *);
	int (*seq_show)(struct seq_file___12 *, void *);
	void * (*seq_start)(struct seq_file___12 *, loff_t *);
	void * (*seq_next)(struct seq_file___12 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___12 *, void *);
	ssize_t (*read)(struct kernfs_open_file___9 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___9 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___9 *, struct vm_area_struct___11 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___9 *, struct poll_table_struct___8 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___9 {
	int (*remount_fs)(struct kernfs_root___9 *, int *, char *);
	int (*show_options)(struct seq_file___12 *, struct kernfs_root___9 *);
	int (*mkdir)(struct kernfs_node___9 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___9 *);
	int (*rename)(struct kernfs_node___9 *, struct kernfs_node___9 *, const char *);
	int (*show_path)(struct seq_file___12 *, struct kernfs_node___9 *, struct kernfs_root___9 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___9 {
	struct kernfs_node___9 *kn;
	struct file___10 *file;
	struct seq_file___12 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___9 *vm_ops;
};

struct bin_attribute___9;

struct attribute_group___9 {
	const char *name;
	umode_t (*is_visible)(struct kobject___9 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___9 *, struct bin_attribute___9 *, int);
	struct attribute **attrs;
	struct bin_attribute___9 **bin_attrs;
};

struct bin_attribute___9 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___10 *, struct kobject___9 *, struct bin_attribute___9 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___10 *, struct kobject___9 *, struct bin_attribute___9 *, char *, loff_t, size_t);
	int (*mmap)(struct file___10 *, struct kobject___9 *, struct bin_attribute___9 *, struct vm_area_struct___11 *);
};

struct sysfs_ops___9 {
	ssize_t (*show)(struct kobject___9 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___9 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___9;

struct kset___9 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___9 kobj;
	const struct kset_uevent_ops___9 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___9 {
	void (*release)(struct kobject___9 *);
	const struct sysfs_ops___9 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___9 *);
	const void * (*namespace)(struct kobject___9 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___9 {
	int (* const filter)(struct kset___9 *, struct kobject___9 *);
	const char * (* const name)(struct kset___9 *, struct kobject___9 *);
	int (* const uevent)(struct kset___9 *, struct kobject___9 *, struct kobj_uevent_env *);
};

struct kobj_attribute___9 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___9 *, struct kobj_attribute___9 *, char *);
	ssize_t (*store)(struct kobject___9 *, struct kobj_attribute___9 *, const char *, size_t);
};

struct dev_pm_ops___9 {
	int (*prepare)(struct device___10 *);
	void (*complete)(struct device___10 *);
	int (*suspend)(struct device___10 *);
	int (*resume)(struct device___10 *);
	int (*freeze)(struct device___10 *);
	int (*thaw)(struct device___10 *);
	int (*poweroff)(struct device___10 *);
	int (*restore)(struct device___10 *);
	int (*suspend_late)(struct device___10 *);
	int (*resume_early)(struct device___10 *);
	int (*freeze_late)(struct device___10 *);
	int (*thaw_early)(struct device___10 *);
	int (*poweroff_late)(struct device___10 *);
	int (*restore_early)(struct device___10 *);
	int (*suspend_noirq)(struct device___10 *);
	int (*resume_noirq)(struct device___10 *);
	int (*freeze_noirq)(struct device___10 *);
	int (*thaw_noirq)(struct device___10 *);
	int (*poweroff_noirq)(struct device___10 *);
	int (*restore_noirq)(struct device___10 *);
	int (*runtime_suspend)(struct device___10 *);
	int (*runtime_resume)(struct device___10 *);
	int (*runtime_idle)(struct device___10 *);
};

enum pm_qos_type {
	PM_QOS_UNITIALIZED = 0,
	PM_QOS_MAX = 1,
	PM_QOS_MIN = 2,
	PM_QOS_SUM = 3,
};

struct pm_qos_constraints {
	struct plist_head list;
	s32 target_value;
	s32 default_value;
	s32 no_constraint_value;
	enum pm_qos_type type;
	struct blocking_notifier_head___9 *notifiers;
};

struct pm_qos_flags {
	struct list_head list;
	s32 effective_flags;
};

struct dev_pm_qos_request;

struct dev_pm_qos___2 {
	struct pm_qos_constraints resume_latency;
	struct pm_qos_constraints latency_tolerance;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request *resume_latency_req;
	struct dev_pm_qos_request *latency_tolerance_req;
	struct dev_pm_qos_request *flags_req;
};

struct dev_pm_domain___9 {
	struct dev_pm_ops___9 ops;
	void (*detach)(struct device___10 *, bool);
	int (*activate)(struct device___10 *);
	void (*sync)(struct device___10 *);
	void (*dismiss)(struct device___10 *);
};

struct bus_type___9 {
	const char *name;
	const char *dev_name;
	struct device___10 *dev_root;
	const struct attribute_group___9 **bus_groups;
	const struct attribute_group___9 **dev_groups;
	const struct attribute_group___9 **drv_groups;
	int (*match)(struct device___10 *, struct device_driver___9 *);
	int (*uevent)(struct device___10 *, struct kobj_uevent_env *);
	int (*probe)(struct device___10 *);
	int (*remove)(struct device___10 *);
	void (*shutdown)(struct device___10 *);
	int (*online)(struct device___10 *);
	int (*offline)(struct device___10 *);
	int (*suspend)(struct device___10 *, pm_message_t);
	int (*resume)(struct device___10 *);
	int (*num_vf)(struct device___10 *);
	int (*dma_configure)(struct device___10 *);
	const struct dev_pm_ops___9 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___9 {
	const char *name;
	struct bus_type___9 *bus;
	struct module___12 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___10 *);
	int (*remove)(struct device___10 *);
	void (*shutdown)(struct device___10 *);
	int (*suspend)(struct device___10 *, pm_message_t);
	int (*resume)(struct device___10 *);
	const struct attribute_group___9 **groups;
	const struct dev_pm_ops___9 *pm;
	void (*coredump)(struct device___10 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___9 {
	const char *name;
	const struct attribute_group___9 **groups;
	int (*uevent)(struct device___10 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___10 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___10 *);
	const struct dev_pm_ops___9 *pm;
};

struct class___9 {
	const char *name;
	struct module___12 *owner;
	const struct attribute_group___9 **class_groups;
	const struct attribute_group___9 **dev_groups;
	struct kobject___9 *dev_kobj;
	int (*dev_uevent)(struct device___10 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___10 *, umode_t *);
	void (*class_release)(struct class___9 *);
	void (*dev_release)(struct device___10 *);
	int (*shutdown_pre)(struct device___10 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___10 *);
	const struct dev_pm_ops___9 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct fwnode_operations___7;

struct fwnode_handle___7 {
	struct fwnode_handle___7 *secondary;
	const struct fwnode_operations___7 *ops;
};

struct property___3;

struct device_node___4 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___7 fwnode;
	struct property___3 *properties;
	struct property___3 *deadprops;
	struct device_node___4 *parent;
	struct device_node___4 *child;
	struct device_node___4 *sibling;
	struct kobject___9 kobj;
	long unsigned int _flags;
	void *data;
};

typedef int (*key_restrict_link_func_t___9)(struct key___11 *, const struct key_type *, const union key_payload *, struct key___11 *);

struct key_restriction___10;

struct key___11 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___10 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___10 *restrict_link;
};

struct key_restriction___10 {
	key_restrict_link_func_t___9 check;
	struct key___11 *key;
	struct key_type *keytype;
};

struct seq_operations___9 {
	void * (*start)(struct seq_file___12 *, loff_t *);
	void (*stop)(struct seq_file___12 *, void *);
	void * (*next)(struct seq_file___12 *, void *, loff_t *);
	int (*show)(struct seq_file___12 *, void *);
};

typedef void compound_page_dtor___9(struct page___11 *);

struct node___8 {
	struct device___10 dev;
};

struct uts_namespace___4 {
	struct kref kref;
	struct new_utsname name;
	struct user_namespace___7 *user_ns;
	struct ucounts___6 *ucounts;
	struct ns_common ns;
};

struct cgroup_namespace___6 {
	refcount_t count;
	struct ns_common ns;
	struct user_namespace___7 *user_ns;
	struct ucounts___6 *ucounts;
	struct css_set___6 *root_cset;
};

struct ucounts___6 {
	struct hlist_node node;
	struct user_namespace___7 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct fwnode_reference_args___7;

struct fwnode_endpoint___7;

struct fwnode_operations___7 {
	struct fwnode_handle___7 * (*get)(struct fwnode_handle___7 *);
	void (*put)(struct fwnode_handle___7 *);
	bool (*device_is_available)(const struct fwnode_handle___7 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___7 *, const struct device___10 *);
	bool (*property_present)(const struct fwnode_handle___7 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___7 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___7 *, const char *, const char **, size_t);
	struct fwnode_handle___7 * (*get_parent)(const struct fwnode_handle___7 *);
	struct fwnode_handle___7 * (*get_next_child_node)(const struct fwnode_handle___7 *, struct fwnode_handle___7 *);
	struct fwnode_handle___7 * (*get_named_child_node)(const struct fwnode_handle___7 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___7 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___7 *);
	struct fwnode_handle___7 * (*graph_get_next_endpoint)(const struct fwnode_handle___7 *, struct fwnode_handle___7 *);
	struct fwnode_handle___7 * (*graph_get_remote_endpoint)(const struct fwnode_handle___7 *);
	struct fwnode_handle___7 * (*graph_get_port_parent)(struct fwnode_handle___7 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___7 *, struct fwnode_endpoint___7 *);
};

struct fwnode_endpoint___7 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___7 *local_fwnode;
};

struct fwnode_reference_args___7 {
	struct fwnode_handle___7 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct property___3 {
	char *name;
	int length;
	void *value;
	struct property___3 *next;
	long unsigned int _flags;
	struct bin_attribute___9 attr;
};

struct kernel_param_ops___8 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___8 *);
	int (*get)(char *, const struct kernel_param___8 *);
	void (*free)(void *);
};

struct kparam_array___8;

struct kernel_param___8 {
	const char *name;
	struct module___12 *mod;
	const struct kernel_param_ops___8 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___8 *arr;
	};
};

struct kparam_array___8 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___8 *ops;
	void *elem;
};

struct module_attribute___8 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___8 *, struct module_kobject___8 *, char *);
	ssize_t (*store)(struct module_attribute___8 *, struct module_kobject___8 *, const char *, size_t);
	void (*setup)(struct module___12 *, const char *);
	int (*test)(struct module___12 *);
	void (*free)(struct module___12 *);
};

struct trace_event_class___5;

struct trace_event_call___6 {
	struct list_head list;
	struct trace_event_class___5 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array *prog_array;
	int (*perf_perm)(struct trace_event_call___6 *, struct perf_event___5 *);
};

struct bpf_map___5;

struct bpf_map_ops___5 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___5 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___5 *, struct file___10 *);
	void (*map_free)(struct bpf_map___5 *);
	int (*map_get_next_key)(struct bpf_map___5 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___5 *);
	void * (*map_lookup_elem)(struct bpf_map___5 *, void *);
	int (*map_update_elem)(struct bpf_map___5 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___5 *, void *);
	int (*map_push_elem)(struct bpf_map___5 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___5 *, void *);
	int (*map_peek_elem)(struct bpf_map___5 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___5 *, struct file___10 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___5 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___5 *, void *, struct seq_file___12 *);
	int (*map_check_btf)(const struct bpf_map___5 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___5 {
	const struct bpf_map_ops___5 *ops;
	struct bpf_map___5 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___10 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___5;

typedef void (*kthread_work_func_t___5)(struct kthread_work___5 *);

struct kthread_worker___5;

struct kthread_work___5 {
	struct list_head node;
	kthread_work_func_t___5 func;
	struct kthread_worker___5 *worker;
	int canceling;
};

struct kthread_worker___5 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___11 *task;
	struct kthread_work___5 *current_work;
};

struct kthread_delayed_work___5 {
	struct kthread_work___5 work;
	struct timer_list timer;
};

struct psi_group___5 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___5 *poll_kworker;
	struct kthread_delayed_work___5 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___5 {
	struct kernfs_node___9 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___5;

struct cgroup_subsys_state___5 {
	struct cgroup___5 *cgroup;
	struct cgroup_subsys___5 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___5 *parent;
};

struct cgroup_root___5;

struct cgroup_rstat_cpu___5;

struct cgroup___5 {
	struct cgroup_subsys_state___5 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___9 *kn;
	struct cgroup_file___5 procs_file;
	struct cgroup_file___5 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___5 *subsys[13];
	struct cgroup_root___5 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___5 *dom_cgrp;
	struct cgroup_rstat_cpu___5 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf bpf;
	atomic_t congestion_count;
	struct cgroup___5 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___5 psi;
	int ancestor_ids[0];
};

struct cftype___5;

struct cgroup_subsys___5 {
	struct cgroup_subsys_state___5 * (*css_alloc)(struct cgroup_subsys_state___5 *);
	int (*css_online)(struct cgroup_subsys_state___5 *);
	void (*css_offline)(struct cgroup_subsys_state___5 *);
	void (*css_released)(struct cgroup_subsys_state___5 *);
	void (*css_free)(struct cgroup_subsys_state___5 *);
	void (*css_reset)(struct cgroup_subsys_state___5 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___5 *, int);
	int (*css_extra_stat_show)(struct seq_file___12 *, struct cgroup_subsys_state___5 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___11 *);
	void (*cancel_fork)(struct task_struct___11 *);
	void (*fork)(struct task_struct___11 *);
	void (*exit)(struct task_struct___11 *);
	void (*free)(struct task_struct___11 *);
	void (*bind)(struct cgroup_subsys_state___5 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___5 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___5 *dfl_cftypes;
	struct cftype___5 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___5 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___5 *updated_children;
	struct cgroup___5 *updated_next;
};

struct cgroup_root___5 {
	struct kernfs_root___9 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___5 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___5 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___5 *ss;
	struct list_head node;
	struct kernfs_ops___9 *kf_ops;
	int (*open)(struct kernfs_open_file___9 *);
	void (*release)(struct kernfs_open_file___9 *);
	u64 (*read_u64)(struct cgroup_subsys_state___5 *, struct cftype___5 *);
	s64 (*read_s64)(struct cgroup_subsys_state___5 *, struct cftype___5 *);
	int (*seq_show)(struct seq_file___12 *, void *);
	void * (*seq_start)(struct seq_file___12 *, loff_t *);
	void * (*seq_next)(struct seq_file___12 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___12 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___5 *, struct cftype___5 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___5 *, struct cftype___5 *, s64);
	ssize_t (*write)(struct kernfs_open_file___9 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___9 *, struct poll_table_struct___8 *);
};

struct perf_cpu_context___5;

struct pmu___5 {
	struct list_head entry;
	struct module___12 *module;
	struct device___10 *dev;
	const struct attribute_group___9 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___5 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___5 *);
	void (*pmu_disable)(struct pmu___5 *);
	int (*event_init)(struct perf_event___5 *);
	void (*event_mapped)(struct perf_event___5 *, struct mm_struct___10 *);
	void (*event_unmapped)(struct perf_event___5 *, struct mm_struct___10 *);
	int (*add)(struct perf_event___5 *, int);
	void (*del)(struct perf_event___5 *, int);
	void (*start)(struct perf_event___5 *, int);
	void (*stop)(struct perf_event___5 *, int);
	void (*read)(struct perf_event___5 *);
	void (*start_txn)(struct pmu___5 *, unsigned int);
	int (*commit_txn)(struct pmu___5 *);
	void (*cancel_txn)(struct pmu___5 *);
	int (*event_idx)(struct perf_event___5 *);
	void (*sched_task)(struct perf_event_context___6 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___5 *);
	int (*filter_match)(struct perf_event___5 *);
	int (*check_period)(struct perf_event___5 *, u64);
};

struct perf_cpu_context___5 {
	struct perf_event_context___6 ctx;
	struct perf_event_context___6 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___5 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___5 {
	struct cgroup_subsys_state___5 css;
	struct perf_cgroup_info *info;
};

struct pm_qos_flags_request {
	struct list_head node;
	s32 flags;
};

enum dev_pm_qos_req_type {
	DEV_PM_QOS_RESUME_LATENCY = 1,
	DEV_PM_QOS_LATENCY_TOLERANCE = 2,
	DEV_PM_QOS_FLAGS = 3,
};

struct dev_pm_qos_request {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___10 *dev;
};

struct trace_event_class___5 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___6 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___6 *);
	struct list_head * (*get_fields)(struct trace_event_call___6 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___6 *);
};

struct stackframe {
	long unsigned int fp;
	long unsigned int pc;
	int graph;
};

struct module___13;

struct file___11;

struct kiocb___11;

struct poll_table_struct___9;

struct vm_area_struct___12;

struct inode___13;

struct file_lock___11;

struct page___12;

struct seq_file___13;

struct file_operations___11 {
	struct module___13 *owner;
	loff_t (*llseek)(struct file___11 *, loff_t, int);
	ssize_t (*read)(struct file___11 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___11 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___11 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___11 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___11 *, bool);
	int (*iterate)(struct file___11 *, struct dir_context *);
	int (*iterate_shared)(struct file___11 *, struct dir_context *);
	__poll_t (*poll)(struct file___11 *, struct poll_table_struct___9 *);
	long int (*unlocked_ioctl)(struct file___11 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___11 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___11 *, struct vm_area_struct___12 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___13 *, struct file___11 *);
	int (*flush)(struct file___11 *, fl_owner_t);
	int (*release)(struct inode___13 *, struct file___11 *);
	int (*fsync)(struct file___11 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___11 *, int);
	int (*lock)(struct file___11 *, int, struct file_lock___11 *);
	ssize_t (*sendpage)(struct file___11 *, struct page___12 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___11 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___11 *, int, struct file_lock___11 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___11 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___11 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___11 *, long int, struct file_lock___11 **, void **);
	long int (*fallocate)(struct file___11 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___13 *, struct file___11 *);
	ssize_t (*copy_file_range)(struct file___11 *, loff_t, struct file___11 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___11 *, loff_t, struct file___11 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___11 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct user_sve_header {
	__u32 size;
	__u32 max_size;
	__u16 vl;
	__u16 max_vl;
	__u16 flags;
	__u16 __reserved;
};

struct vmacache___10 {
	u64 seqnum;
	struct vm_area_struct___12 *vmas[4];
};

struct page_frag___10 {
	struct page___12 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___6;

struct debug_info___6 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___6 *hbp_break[16];
	struct perf_event___6 *hbp_watch[16];
};

struct thread_struct___6 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___6 debug;
	long: 64;
};

struct mm_struct___11;

struct mem_cgroup___3;

struct pid___9;

struct cred___11;

struct nsproxy___11;

struct signal_struct___10;

struct io_context___5;

struct css_set___7;

struct perf_event_context___7;

struct request_queue___5;

struct vm_struct___8;

struct task_struct___12 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___12 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___11 *mm;
	struct mm_struct___11 *active_mm;
	struct vmacache___10 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___12 *real_parent;
	struct task_struct___12 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___12 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___3 *active_memcg;
	long int rh_reserved2;
	struct pid___9 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___9 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___9 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___11 *ptracer_cred;
	const struct cred___11 *real_cred;
	const struct cred___11 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___11 *nsproxy;
	struct signal_struct___10 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___12 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___5 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___7 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___7 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___10 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___3 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___5 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___12 *oom_reaper_list;
	struct vm_struct___8 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___6 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___6 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___12 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___6)(struct perf_event___6 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___6;

struct fasync_struct___10;

struct pid_namespace___9;

struct trace_event_call___7;

struct perf_cgroup___6;

struct perf_event___6 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___6 *group_leader;
	struct pmu___6 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___6 hw;
	struct perf_event_context___7 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___6 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___12 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___10 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___6 *);
	struct callback_head callback_head;
	struct pid_namespace___9 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___6 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___6 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___7 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___6 *cgrp;
	struct list_head sb_list;
};

struct upid___9 {
	int nr;
	struct pid_namespace___9 *ns;
};

struct dentry___12;

struct user_namespace___8;

struct ucounts___7;

struct pid_namespace___9 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___12 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___9 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___12 *proc_self;
	struct dentry___12 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___8 *user_ns;
	struct ucounts___7 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common ns;
};

struct pid___9 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___9 numbers[1];
};

struct rw_semaphore___11 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___12 *owner;
};

struct key___12;

struct user_namespace___8 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___8 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common ns;
	long unsigned int flags;
	struct key___12 *persistent_keyring_register;
	struct rw_semaphore___11 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___7 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct secondary_data___11 {
	void *stack;
	struct task_struct___12 *task;
	long int status;
};

typedef struct page___12 *pgtable_t___10;

struct address_space___10;

struct dev_pagemap___10;

struct page___12 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___10 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___12 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___10 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___11 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___10 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___3 *mem_cgroup;
};

struct seccomp_data {
	int nr;
	__u32 arch;
	__u64 instruction_pointer;
	__u64 args[6];
};

struct user_struct___11 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___12 *uid_keyring;
	struct key___12 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___10;

struct vm_area_struct___12 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___12 *vm_next;
	struct vm_area_struct___12 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___11 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___10 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___11 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___10;

struct mm_struct___11 {
	struct {
		struct vm_area_struct___12 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___11 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___11 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___10 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___12 *owner;
		struct user_namespace___8 *user_ns;
		struct file___11 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___10 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup___6;

struct cgroup_subsys___6;

struct cgroup_subsys_state___6 {
	struct cgroup___6 *cgroup;
	struct cgroup_subsys___6 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___6 *parent;
};

struct mem_cgroup_id___3 {
	int id;
	union {
		refcount_t ref;
		struct {
			atomic_t ref;
		} __UNIQUE_ID_rh_kabi_hide41;
		union {		};
	};
};

struct kernfs_node___10;

struct cgroup_file___6 {
	struct kernfs_node___10 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___3;

struct mem_cgroup___3 {
	struct cgroup_subsys_state___6 css;
	struct mem_cgroup_id___3 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___6 events_file;
	struct cgroup_file___6 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___12 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___3 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cred___11 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___12 *session_keyring;
	struct key___12 *process_keyring;
	struct key___12 *thread_keyring;
	struct key___12 *request_key_auth;
	void *security;
	struct user_struct___11 *user;
	struct user_namespace___8 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___7;

struct nsproxy___11 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___9 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___7 *cgroup_ns;
};

struct signal_struct___10 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___12 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___12 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___9 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___9 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___11 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___9 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___4;

struct bio_list___2 {
	struct bio___4 *head;
	struct bio___4 *tail;
};

struct bdi_writeback_congested___4;

struct bdi_writeback___4 {
	struct backing_dev_info___2 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___4 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___6 *memcg_css;
	struct cgroup_subsys_state___6 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___11;

struct backing_dev_info___2 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___4 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___11 *dev;
	struct device___11 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___12 *debug_dir;
	struct dentry___12 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___4;

struct io_context___5 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___4 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___7 {
	struct cgroup_subsys_state___6 *subsys[13];
	refcount_t refcount;
	struct css_set___7 *dom_cset;
	struct cgroup___6 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___6 *mg_src_cgrp;
	struct cgroup___6 *mg_dst_cgrp;
	struct css_set___7 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___7 {
	struct pmu___6 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___12 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___7 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

typedef blk_qc_t make_request_fn___4(struct request_queue___5 *, struct bio___4 *);

struct request___5;

typedef int dma_drain_needed_fn___4(struct request___5 *);

struct kset___10;

struct kobj_type___10;

struct kobject___10 {
	const char *name;
	struct list_head entry;
	struct kobject___10 *parent;
	struct kset___10 *kset;
	struct kobj_type___10 *ktype;
	struct kernfs_node___10 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___4;

struct bsg_class_device___4 {
	struct device___11 *class_dev;
	int minor;
	struct request_queue___5 *queue;
	const struct bsg_ops___4 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___4 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___2 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___4;

struct blkcg_gq___2;

struct request_queue___5 {
	struct list_head queue_head;
	struct request___5 *last_merge;
	struct elevator_queue___4 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___4 *make_request_fn;
	dma_drain_needed_fn___4 *dma_drain_needed;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___2 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___10 kobj;
	struct kobject___10 *mq_kobj;
	struct blk_integrity integrity;
	struct device___11 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___2 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide43;
		union {		};
	};
	struct bsg_class_device___4 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___4 bio_split;
	struct dentry___12 *debugfs_dir;
	struct dentry___12 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___8 {
	struct vm_struct___8 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___12 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___9 {
	struct task_struct___12 task;
	long unsigned int stack[8192];
};

typedef int (*key_restrict_link_func_t___10)(struct key___12 *, const struct key_type *, const union key_payload *, struct key___12 *);

struct key_restriction___11;

struct key___12 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___11 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___11 *restrict_link;
};

struct key_restriction___11 {
	key_restrict_link_func_t___10 check;
	struct key___12 *key;
	struct key_type *keytype;
};

struct pglist_data___10;

struct lruvec___10 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___10 *pgdat;
};

struct zone___10 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___10 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___10 {
	struct zone___10 *zone;
	int zone_idx;
};

struct zonelist___10 {
	struct zoneref___10 _zonerefs[25];
};

struct pglist_data___10 {
	struct zone___10 node_zones[3];
	struct zonelist___10 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___12 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___12 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___10 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___10 {
	struct rw_semaphore___11 rwsem;
	struct notifier_block *head;
};

struct address_space_operations___10;

struct address_space___10 {
	struct inode___13 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___11 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___10 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___10)(struct vm_area_struct___12 *, long unsigned int, const struct page___12 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___10)(struct page___12 *, void *);

struct dev_pagemap___10 {
	dev_page_fault_t___10 page_fault;
	dev_page_free_t___10 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___11 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___10 {
	struct vfsmount *mnt;
	struct dentry___12 *dentry;
};

struct fown_struct___9 {
	rwlock_t lock;
	struct pid___9 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___11 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___10 f_path;
	struct inode___13 *f_inode;
	const struct file_operations___11 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___9 f_owner;
	const struct cred___11 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___10 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___10;

struct vm_operations_struct___10 {
	void (*open)(struct vm_area_struct___12 *);
	void (*close)(struct vm_area_struct___12 *);
	int (*split)(struct vm_area_struct___12 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___12 *);
	vm_fault_t (*fault)(struct vm_fault___10 *);
	vm_fault_t (*huge_fault)(struct vm_fault___10 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___10 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___12 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___10 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___10 *);
	int (*access)(struct vm_area_struct___12 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___12 *);
	int (*set_policy)(struct vm_area_struct___12 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___12 *, long unsigned int);
	struct page___12 * (*find_special_page)(struct vm_area_struct___12 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___10 {
	struct task_struct___12 *task;
	struct core_thread___10 *next;
};

struct core_state___10 {
	atomic_t nr_threads;
	struct core_thread___10 dumper;
	struct completion startup;
};

struct vm_fault___10 {
	struct vm_area_struct___12 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___12 *cow_page;
	struct mem_cgroup___3 *memcg;
	struct page___12 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___10 prealloc_pte;
};

struct shrink_control___3 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___3 *memcg;
};

struct shrinker___3 {
	long unsigned int (*count_objects)(struct shrinker___3 *, struct shrink_control___3 *);
	long unsigned int (*scan_objects)(struct shrinker___3 *, struct shrink_control___3 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct dev_pm_info___10 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___11 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___10;

struct bus_type___10;

struct device_driver___10;

struct dev_pm_domain___10;

struct fwnode_handle___8;

struct class___10;

struct attribute_group___10;

struct device___11 {
	struct device___11 *parent;
	struct device_private *p;
	struct kobject___10 kobj;
	const char *init_name;
	const struct device_type___10 *type;
	struct mutex mutex;
	struct bus_type___10 *bus;
	struct device_driver___10 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___10 power;
	struct dev_pm_domain___10 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___8 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___10 *class;
	const struct attribute_group___10 **groups;
	void (*release)(struct device___11 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___10;

struct super_block___11;

struct dentry___12 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___12 *d_parent;
	struct qstr d_name;
	struct inode___13 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___10 *d_op;
	struct super_block___11 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___10;

struct block_device___11;

struct inode___13 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___10 *i_op;
	struct super_block___11 *i_sb;
	struct address_space___10 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___11 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___11 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___10 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___11 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___10 {
	int (*d_revalidate)(struct dentry___12 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___12 *, unsigned int);
	int (*d_hash)(const struct dentry___12 *, struct qstr *);
	int (*d_compare)(const struct dentry___12 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___12 *);
	int (*d_init)(struct dentry___12 *);
	void (*d_release)(struct dentry___12 *);
	void (*d_prune)(struct dentry___12 *);
	void (*d_iput)(struct dentry___12 *, struct inode___13 *);
	char * (*d_dname)(struct dentry___12 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___10 *);
	int (*d_manage)(const struct path___10 *, bool);
	struct dentry___12 * (*d_real)(struct dentry___12 *, const struct inode___13 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___10;

struct mem_dqinfo___10 {
	struct quota_format_type___10 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___10;

struct quota_info___10 {
	unsigned int flags;
	struct rw_semaphore___11 dqio_sem;
	struct inode___13 *files[3];
	struct mem_dqinfo___10 info[3];
	const struct quota_format_ops___10 *ops[3];
};

struct rcuwait___10 {
	struct task_struct___12 *task;
};

struct percpu_rw_semaphore___10 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___11 rw_sem;
	struct rcuwait___10 writer;
	int readers_block;
};

struct sb_writers___10 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___10 rw_sem[3];
};

struct file_system_type___10;

struct super_operations___10;

struct dquot_operations___10;

struct quotactl_ops___10;

struct super_block___11 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___10 *s_type;
	const struct super_operations___10 *s_op;
	const struct dquot_operations___10 *dq_op;
	const struct quotactl_ops___10 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___12 *s_root;
	struct rw_semaphore___11 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___11 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___10 s_dquot;
	struct sb_writers___10 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___10 *s_d_op;
	int cleancache_poolid;
	struct shrinker___3 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___8 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct io_cq___4 {
	struct request_queue___5 *q;
	struct io_context___5 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___11 {
	struct file___11 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___11 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___11 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___11 *ia_file;
};

struct dquot___10 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___11 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___10 {
	int qf_fmt_id;
	const struct quota_format_ops___10 *qf_ops;
	struct module___13 *qf_owner;
	struct quota_format_type___10 *qf_next;
};

struct quota_format_ops___10 {
	int (*check_quota_file)(struct super_block___11 *, int);
	int (*read_file_info)(struct super_block___11 *, int);
	int (*write_file_info)(struct super_block___11 *, int);
	int (*free_file_info)(struct super_block___11 *, int);
	int (*read_dqblk)(struct dquot___10 *);
	int (*commit_dqblk)(struct dquot___10 *);
	int (*release_dqblk)(struct dquot___10 *);
	int (*get_next_id)(struct super_block___11 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___10 {
	int (*write_dquot)(struct dquot___10 *);
	struct dquot___10 * (*alloc_dquot)(struct super_block___11 *, int);
	void (*destroy_dquot)(struct dquot___10 *);
	int (*acquire_dquot)(struct dquot___10 *);
	int (*release_dquot)(struct dquot___10 *);
	int (*mark_dirty)(struct dquot___10 *);
	int (*write_info)(struct super_block___11 *, int);
	qsize_t * (*get_reserved_space)(struct inode___13 *);
	int (*get_projid)(struct inode___13 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___13 *, qsize_t *);
	int (*get_next_id)(struct super_block___11 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___10 {
	int (*quota_on)(struct super_block___11 *, int, int, const struct path___10 *);
	int (*quota_off)(struct super_block___11 *, int);
	int (*quota_enable)(struct super_block___11 *, unsigned int);
	int (*quota_disable)(struct super_block___11 *, unsigned int);
	int (*quota_sync)(struct super_block___11 *, int);
	int (*set_info)(struct super_block___11 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___11 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___11 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___11 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___11 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___11 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___9 {
	struct kobject___10 kobj;
	struct module___13 *mod;
	struct kobject___10 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___9 {
	struct module___13 *mod;
	struct latch_tree_node node;
};

struct module_layout___9 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___9 mtn;
};

struct module_attribute___9;

struct kernel_param___9;

struct module___13 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___9 mkobj;
	struct module_attribute___9 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___10 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___9 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___9 core_layout;
	struct module_layout___9 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___7 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___10 {
	int (*writepage)(struct page___12 *, struct writeback_control___3 *);
	int (*readpage)(struct file___11 *, struct page___12 *);
	int (*writepages)(struct address_space___10 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___12 *);
	int (*readpages)(struct file___11 *, struct address_space___10 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___11 *, struct address_space___10 *, loff_t, unsigned int, unsigned int, struct page___12 **, void **);
	int (*write_end)(struct file___11 *, struct address_space___10 *, loff_t, unsigned int, unsigned int, struct page___12 *, void *);
	sector_t (*bmap)(struct address_space___10 *, sector_t);
	void (*invalidatepage)(struct page___12 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___12 *, gfp_t);
	void (*freepage)(struct page___12 *);
	ssize_t (*direct_IO)(struct kiocb___11 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___10 *, struct page___12 *, struct page___12 *, enum migrate_mode);
	bool (*isolate_page)(struct page___12 *, isolate_mode_t);
	void (*putback_page)(struct page___12 *);
	int (*launder_page)(struct page___12 *);
	int (*is_partially_uptodate)(struct page___12 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___12 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___10 *, struct page___12 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___11 *, sector_t *);
	void (*swap_deactivate)(struct file___11 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___3 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___4 *wb;
	struct inode___13 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___4;

struct iov_iter___5 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___4 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___11 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___13 *bd_inode;
	struct super_block___11 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___11 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___5 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct hd_struct___4 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___11 __dev;
	struct kobject___10 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___4;

struct block_device_operations___4;

struct gendisk___4 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___4 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___4 *part_tbl;
	struct hd_struct___4 part0;
	const struct block_device_operations___4 *fops;
	struct request_queue___5 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___11 lookup_sem;
	struct kobject___10 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___10 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___10 {
	struct dentry___12 * (*lookup)(struct inode___13 *, struct dentry___12 *, unsigned int);
	const char * (*get_link)(struct dentry___12 *, struct inode___13 *, struct delayed_call *);
	int (*permission)(struct inode___13 *, int);
	struct posix_acl * (*get_acl)(struct inode___13 *, int);
	int (*readlink)(struct dentry___12 *, char *, int);
	int (*create)(struct inode___13 *, struct dentry___12 *, umode_t, bool);
	int (*link)(struct dentry___12 *, struct inode___13 *, struct dentry___12 *);
	int (*unlink)(struct inode___13 *, struct dentry___12 *);
	int (*symlink)(struct inode___13 *, struct dentry___12 *, const char *);
	int (*mkdir)(struct inode___13 *, struct dentry___12 *, umode_t);
	int (*rmdir)(struct inode___13 *, struct dentry___12 *);
	int (*mknod)(struct inode___13 *, struct dentry___12 *, umode_t, dev_t);
	int (*rename)(struct inode___13 *, struct dentry___12 *, struct inode___13 *, struct dentry___12 *, unsigned int);
	int (*setattr)(struct dentry___12 *, struct iattr___11 *);
	int (*getattr)(const struct path___10 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___12 *, char *, size_t);
	int (*fiemap)(struct inode___13 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___13 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___13 *, struct dentry___12 *, struct file___11 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___13 *, struct dentry___12 *, umode_t);
	int (*set_acl)(struct inode___13 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___10 {
	void (*fl_copy_lock)(struct file_lock___11 *, struct file_lock___11 *);
	void (*fl_release_private)(struct file_lock___11 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___10;

struct file_lock___11 {
	struct file_lock___11 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___11 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___10 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___10 *fl_ops;
	const struct lock_manager_operations___10 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___10 {
	int (*lm_compare_owner)(struct file_lock___11 *, struct file_lock___11 *);
	long unsigned int (*lm_owner_key)(struct file_lock___11 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___11 *);
	int (*lm_grant)(struct file_lock___11 *, int);
	bool (*lm_break)(struct file_lock___11 *);
	int (*lm_change)(struct file_lock___11 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___11 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___10 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___10 *fa_next;
	struct file___11 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___10 {
	const char *name;
	int fs_flags;
	struct dentry___12 * (*mount)(struct file_system_type___10 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___11 *);
	struct module___13 *owner;
	struct file_system_type___10 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___10 {
	struct inode___13 * (*alloc_inode)(struct super_block___11 *);
	void (*destroy_inode)(struct inode___13 *);
	void (*dirty_inode)(struct inode___13 *, int);
	int (*write_inode)(struct inode___13 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___13 *);
	void (*evict_inode)(struct inode___13 *);
	void (*put_super)(struct super_block___11 *);
	int (*sync_fs)(struct super_block___11 *, int);
	int (*freeze_super)(struct super_block___11 *);
	int (*freeze_fs)(struct super_block___11 *);
	int (*thaw_super)(struct super_block___11 *);
	int (*unfreeze_fs)(struct super_block___11 *);
	int (*statfs)(struct dentry___12 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___11 *, int *, char *);
	void (*umount_begin)(struct super_block___11 *);
	int (*show_options)(struct seq_file___13 *, struct dentry___12 *);
	int (*show_devname)(struct seq_file___13 *, struct dentry___12 *);
	int (*show_path)(struct seq_file___13 *, struct dentry___12 *);
	int (*show_stats)(struct seq_file___13 *, struct dentry___12 *);
	ssize_t (*quota_read)(struct super_block___11 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___11 *, int, const char *, size_t, loff_t);
	struct dquot___10 ** (*get_dquots)(struct inode___13 *);
	int (*bdev_try_to_free_page)(struct super_block___11 *, struct page___12 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___11 *, struct shrink_control___3 *);
	long int (*free_cached_objects)(struct super_block___11 *, struct shrink_control___3 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___7)(struct file___11 *, wait_queue_head_t *, struct poll_table_struct___9 *);

struct poll_table_struct___9 {
	poll_queue_proc___7 _qproc;
	__poll_t _key;
};

struct seq_operations___10;

struct seq_file___13 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___10 *op;
	int poll_event;
	const struct file___11 *file;
	void *private;
};

typedef void bio_end_io_t___4(struct bio___4 *);

struct bio_vec___4 {
	struct page___12 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___4;

struct bio___4 {
	struct bio___4 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___4 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___2 *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___4 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___4 *bi_io_vec;
	struct bio_set___4 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___4 bi_inline_vecs[0];
};

struct kobj_attribute___10 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___10 *, struct kobj_attribute___10 *, char *);
	ssize_t (*store)(struct kobject___10 *, struct kobj_attribute___10 *, const char *, size_t);
};

typedef void compound_page_dtor___10(struct page___12 *);

struct cgroup_namespace___7 {
	refcount_t count;
	struct ns_common ns;
	struct user_namespace___8 *user_ns;
	struct ucounts___7 *ucounts;
	struct css_set___7 *root_cset;
};

struct ucounts___7 {
	struct hlist_node node;
	struct user_namespace___8 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

enum perf_type_id {
	PERF_TYPE_HARDWARE = 0,
	PERF_TYPE_SOFTWARE = 1,
	PERF_TYPE_TRACEPOINT = 2,
	PERF_TYPE_HW_CACHE = 3,
	PERF_TYPE_RAW = 4,
	PERF_TYPE_BREAKPOINT = 5,
	PERF_TYPE_MAX = 6,
};

struct kernfs_root___10;

struct kernfs_elem_dir___10 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___10 *root;
};

struct kernfs_syscall_ops___10;

struct kernfs_root___10 {
	struct kernfs_node___10 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___10 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___10 {
	struct kernfs_node___10 *target_kn;
};

struct kernfs_ops___10;

struct kernfs_elem_attr___10 {
	const struct kernfs_ops___10 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___10 *notify_next;
};

struct kernfs_node___10 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___10 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___10 dir;
		struct kernfs_elem_symlink___10 symlink;
		struct kernfs_elem_attr___10 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___10;

struct kernfs_ops___10 {
	int (*open)(struct kernfs_open_file___10 *);
	void (*release)(struct kernfs_open_file___10 *);
	int (*seq_show)(struct seq_file___13 *, void *);
	void * (*seq_start)(struct seq_file___13 *, loff_t *);
	void * (*seq_next)(struct seq_file___13 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___13 *, void *);
	ssize_t (*read)(struct kernfs_open_file___10 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___10 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___10 *, struct vm_area_struct___12 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___10 *, struct poll_table_struct___9 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___10 {
	int (*remount_fs)(struct kernfs_root___10 *, int *, char *);
	int (*show_options)(struct seq_file___13 *, struct kernfs_root___10 *);
	int (*mkdir)(struct kernfs_node___10 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___10 *);
	int (*rename)(struct kernfs_node___10 *, struct kernfs_node___10 *, const char *);
	int (*show_path)(struct seq_file___13 *, struct kernfs_node___10 *, struct kernfs_root___10 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___10 {
	struct kernfs_node___10 *kn;
	struct file___11 *file;
	struct seq_file___13 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___10 *vm_ops;
};

struct bin_attribute___10;

struct attribute_group___10 {
	const char *name;
	umode_t (*is_visible)(struct kobject___10 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___10 *, struct bin_attribute___10 *, int);
	struct attribute **attrs;
	struct bin_attribute___10 **bin_attrs;
};

struct bin_attribute___10 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___11 *, struct kobject___10 *, struct bin_attribute___10 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___11 *, struct kobject___10 *, struct bin_attribute___10 *, char *, loff_t, size_t);
	int (*mmap)(struct file___11 *, struct kobject___10 *, struct bin_attribute___10 *, struct vm_area_struct___12 *);
};

struct sysfs_ops___10 {
	ssize_t (*show)(struct kobject___10 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___10 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___10;

struct kset___10 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___10 kobj;
	const struct kset_uevent_ops___10 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___10 {
	void (*release)(struct kobject___10 *);
	const struct sysfs_ops___10 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___10 *);
	const void * (*namespace)(struct kobject___10 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___10 {
	int (* const filter)(struct kset___10 *, struct kobject___10 *);
	const char * (* const name)(struct kset___10 *, struct kobject___10 *);
	int (* const uevent)(struct kset___10 *, struct kobject___10 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___9 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___9 *);
	int (*get)(char *, const struct kernel_param___9 *);
	void (*free)(void *);
};

struct kparam_array___9;

struct kernel_param___9 {
	const char *name;
	struct module___13 *mod;
	const struct kernel_param_ops___9 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___9 *arr;
	};
};

struct kparam_array___9 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___9 *ops;
	void *elem;
};

struct module_attribute___9 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___9 *, struct module_kobject___9 *, char *);
	ssize_t (*store)(struct module_attribute___9 *, struct module_kobject___9 *, const char *, size_t);
	void (*setup)(struct module___13 *, const char *);
	int (*test)(struct module___13 *);
	void (*free)(struct module___13 *);
};

struct trace_event_class___6;

struct trace_event_call___7 {
	struct list_head list;
	struct trace_event_class___6 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array *prog_array;
	int (*perf_perm)(struct trace_event_call___7 *, struct perf_event___6 *);
};

struct dev_pm_ops___10 {
	int (*prepare)(struct device___11 *);
	void (*complete)(struct device___11 *);
	int (*suspend)(struct device___11 *);
	int (*resume)(struct device___11 *);
	int (*freeze)(struct device___11 *);
	int (*thaw)(struct device___11 *);
	int (*poweroff)(struct device___11 *);
	int (*restore)(struct device___11 *);
	int (*suspend_late)(struct device___11 *);
	int (*resume_early)(struct device___11 *);
	int (*freeze_late)(struct device___11 *);
	int (*thaw_early)(struct device___11 *);
	int (*poweroff_late)(struct device___11 *);
	int (*restore_early)(struct device___11 *);
	int (*suspend_noirq)(struct device___11 *);
	int (*resume_noirq)(struct device___11 *);
	int (*freeze_noirq)(struct device___11 *);
	int (*thaw_noirq)(struct device___11 *);
	int (*poweroff_noirq)(struct device___11 *);
	int (*restore_noirq)(struct device___11 *);
	int (*runtime_suspend)(struct device___11 *);
	int (*runtime_resume)(struct device___11 *);
	int (*runtime_idle)(struct device___11 *);
};

struct dev_pm_domain___10 {
	struct dev_pm_ops___10 ops;
	void (*detach)(struct device___11 *, bool);
	int (*activate)(struct device___11 *);
	void (*sync)(struct device___11 *);
	void (*dismiss)(struct device___11 *);
};

struct bus_type___10 {
	const char *name;
	const char *dev_name;
	struct device___11 *dev_root;
	const struct attribute_group___10 **bus_groups;
	const struct attribute_group___10 **dev_groups;
	const struct attribute_group___10 **drv_groups;
	int (*match)(struct device___11 *, struct device_driver___10 *);
	int (*uevent)(struct device___11 *, struct kobj_uevent_env *);
	int (*probe)(struct device___11 *);
	int (*remove)(struct device___11 *);
	void (*shutdown)(struct device___11 *);
	int (*online)(struct device___11 *);
	int (*offline)(struct device___11 *);
	int (*suspend)(struct device___11 *, pm_message_t);
	int (*resume)(struct device___11 *);
	int (*num_vf)(struct device___11 *);
	int (*dma_configure)(struct device___11 *);
	const struct dev_pm_ops___10 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___10 {
	const char *name;
	struct bus_type___10 *bus;
	struct module___13 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___11 *);
	int (*remove)(struct device___11 *);
	void (*shutdown)(struct device___11 *);
	int (*suspend)(struct device___11 *, pm_message_t);
	int (*resume)(struct device___11 *);
	const struct attribute_group___10 **groups;
	const struct dev_pm_ops___10 *pm;
	void (*coredump)(struct device___11 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___10 {
	const char *name;
	const struct attribute_group___10 **groups;
	int (*uevent)(struct device___11 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___11 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___11 *);
	const struct dev_pm_ops___10 *pm;
};

struct class___10 {
	const char *name;
	struct module___13 *owner;
	const struct attribute_group___10 **class_groups;
	const struct attribute_group___10 **dev_groups;
	struct kobject___10 *dev_kobj;
	int (*dev_uevent)(struct device___11 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___11 *, umode_t *);
	void (*class_release)(struct class___10 *);
	void (*dev_release)(struct device___11 *);
	int (*shutdown_pre)(struct device___11 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___11 *);
	const struct dev_pm_ops___10 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct fwnode_operations___8;

struct fwnode_handle___8 {
	struct fwnode_handle___8 *secondary;
	const struct fwnode_operations___8 *ops;
};

struct node___9 {
	struct device___11 dev;
};

struct seq_operations___10 {
	void * (*start)(struct seq_file___13 *, loff_t *);
	void (*stop)(struct seq_file___13 *, void *);
	void * (*next)(struct seq_file___13 *, void *, loff_t *);
	int (*show)(struct seq_file___13 *, void *);
};

struct bpf_map___6;

struct bpf_map_ops___6 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___6 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___6 *, struct file___11 *);
	void (*map_free)(struct bpf_map___6 *);
	int (*map_get_next_key)(struct bpf_map___6 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___6 *);
	void * (*map_lookup_elem)(struct bpf_map___6 *, void *);
	int (*map_update_elem)(struct bpf_map___6 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___6 *, void *);
	int (*map_push_elem)(struct bpf_map___6 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___6 *, void *);
	int (*map_peek_elem)(struct bpf_map___6 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___6 *, struct file___11 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___6 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___6 *, void *, struct seq_file___13 *);
	int (*map_check_btf)(const struct bpf_map___6 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___6 {
	const struct bpf_map_ops___6 *ops;
	struct bpf_map___6 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___11 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___6;

typedef void (*kthread_work_func_t___6)(struct kthread_work___6 *);

struct kthread_worker___6;

struct kthread_work___6 {
	struct list_head node;
	kthread_work_func_t___6 func;
	struct kthread_worker___6 *worker;
	int canceling;
};

struct kthread_worker___6 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___12 *task;
	struct kthread_work___6 *current_work;
};

struct kthread_delayed_work___6 {
	struct kthread_work___6 work;
	struct timer_list timer;
};

struct psi_group___6 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___6 *poll_kworker;
	struct kthread_delayed_work___6 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___6;

struct cgroup_rstat_cpu___6;

struct cgroup___6 {
	struct cgroup_subsys_state___6 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___10 *kn;
	struct cgroup_file___6 procs_file;
	struct cgroup_file___6 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___6 *subsys[13];
	struct cgroup_root___6 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___6 *dom_cgrp;
	struct cgroup_rstat_cpu___6 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf bpf;
	atomic_t congestion_count;
	struct cgroup___6 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___6 psi;
	int ancestor_ids[0];
};

struct cftype___6;

struct cgroup_subsys___6 {
	struct cgroup_subsys_state___6 * (*css_alloc)(struct cgroup_subsys_state___6 *);
	int (*css_online)(struct cgroup_subsys_state___6 *);
	void (*css_offline)(struct cgroup_subsys_state___6 *);
	void (*css_released)(struct cgroup_subsys_state___6 *);
	void (*css_free)(struct cgroup_subsys_state___6 *);
	void (*css_reset)(struct cgroup_subsys_state___6 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___6 *, int);
	int (*css_extra_stat_show)(struct seq_file___13 *, struct cgroup_subsys_state___6 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___12 *);
	void (*cancel_fork)(struct task_struct___12 *);
	void (*fork)(struct task_struct___12 *);
	void (*exit)(struct task_struct___12 *);
	void (*free)(struct task_struct___12 *);
	void (*bind)(struct cgroup_subsys_state___6 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___6 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___6 *dfl_cftypes;
	struct cftype___6 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___6 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___6 *updated_children;
	struct cgroup___6 *updated_next;
};

struct cgroup_root___6 {
	struct kernfs_root___10 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___6 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___6 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___6 *ss;
	struct list_head node;
	struct kernfs_ops___10 *kf_ops;
	int (*open)(struct kernfs_open_file___10 *);
	void (*release)(struct kernfs_open_file___10 *);
	u64 (*read_u64)(struct cgroup_subsys_state___6 *, struct cftype___6 *);
	s64 (*read_s64)(struct cgroup_subsys_state___6 *, struct cftype___6 *);
	int (*seq_show)(struct seq_file___13 *, void *);
	void * (*seq_start)(struct seq_file___13 *, loff_t *);
	void * (*seq_next)(struct seq_file___13 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___13 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___6 *, struct cftype___6 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___6 *, struct cftype___6 *, s64);
	ssize_t (*write)(struct kernfs_open_file___10 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___10 *, struct poll_table_struct___9 *);
};

struct perf_cpu_context___6;

struct pmu___6 {
	struct list_head entry;
	struct module___13 *module;
	struct device___11 *dev;
	const struct attribute_group___10 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___6 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___6 *);
	void (*pmu_disable)(struct pmu___6 *);
	int (*event_init)(struct perf_event___6 *);
	void (*event_mapped)(struct perf_event___6 *, struct mm_struct___11 *);
	void (*event_unmapped)(struct perf_event___6 *, struct mm_struct___11 *);
	int (*add)(struct perf_event___6 *, int);
	void (*del)(struct perf_event___6 *, int);
	void (*start)(struct perf_event___6 *, int);
	void (*stop)(struct perf_event___6 *, int);
	void (*read)(struct perf_event___6 *);
	void (*start_txn)(struct pmu___6 *, unsigned int);
	int (*commit_txn)(struct pmu___6 *);
	void (*cancel_txn)(struct pmu___6 *);
	int (*event_idx)(struct perf_event___6 *);
	void (*sched_task)(struct perf_event_context___7 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___6 *);
	int (*filter_match)(struct perf_event___6 *);
	int (*check_period)(struct perf_event___6 *, u64);
};

struct perf_cpu_context___6 {
	struct perf_event_context___7 ctx;
	struct perf_event_context___7 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___6 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___6 {
	struct cgroup_subsys_state___6 css;
	struct perf_cgroup_info *info;
};

enum {
	HW_BREAKPOINT_LEN_1 = 1,
	HW_BREAKPOINT_LEN_2 = 2,
	HW_BREAKPOINT_LEN_3 = 3,
	HW_BREAKPOINT_LEN_4 = 4,
	HW_BREAKPOINT_LEN_5 = 5,
	HW_BREAKPOINT_LEN_6 = 6,
	HW_BREAKPOINT_LEN_7 = 7,
	HW_BREAKPOINT_LEN_8 = 8,
};

enum {
	HW_BREAKPOINT_EMPTY = 0,
	HW_BREAKPOINT_R = 1,
	HW_BREAKPOINT_W = 2,
	HW_BREAKPOINT_RW = 3,
	HW_BREAKPOINT_X = 4,
	HW_BREAKPOINT_INVALID = 7,
};

enum bp_type_idx {
	TYPE_INST = 0,
	TYPE_DATA = 1,
	TYPE_MAX = 2,
};

struct user_regset;

typedef int user_regset_active_fn(struct task_struct___12 *, const struct user_regset *);

typedef int user_regset_get_fn(struct task_struct___12 *, const struct user_regset *, unsigned int, unsigned int, void *, void *);

typedef int user_regset_set_fn(struct task_struct___12 *, const struct user_regset *, unsigned int, unsigned int, const void *, const void *);

typedef int user_regset_writeback_fn(struct task_struct___12 *, const struct user_regset *, int);

typedef unsigned int user_regset_get_size_fn(struct task_struct___12 *, const struct user_regset *);

struct user_regset {
	user_regset_get_fn *get;
	user_regset_set_fn *set;
	user_regset_active_fn *active;
	user_regset_writeback_fn *writeback;
	user_regset_get_size_fn *get_size;
	unsigned int n;
	unsigned int size;
	unsigned int align;
	unsigned int bias;
	unsigned int core_note_type;
};

struct user_regset_view {
	const char *name;
	const struct user_regset *regsets;
	unsigned int n;
	u32 e_flags;
	u16 e_machine;
	u8 ei_osabi;
};

struct bdi_writeback_congested___4 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___2 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___4 {
	struct bio___4 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___4 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___4 bip_inline_vecs[0];
};

struct blkcg___2;

struct blkg_policy_data___2;

struct blkcg_gq___2 {
	struct request_queue___5 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___2 *blkcg;
	struct bdi_writeback_congested___4 *wb_congested;
	struct blkcg_gq___2 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_rwstat stat_bytes;
	struct blkg_rwstat stat_ios;
	struct blkg_policy_data___2 *pd[5];
	struct callback_head callback_head;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
};

struct mem_cgroup_reclaim_iter___3 {
	struct mem_cgroup___3 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___3 {
	struct lruvec___10 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___3 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___3 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct disk_part_tbl___4 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___4 *last_lookup;
	struct hd_struct___4 *part[0];
};

struct block_device_operations___4 {
	int (*open)(struct block_device___11 *, fmode_t);
	void (*release)(struct gendisk___4 *, fmode_t);
	int (*rw_page)(struct block_device___11 *, sector_t, struct page___12 *, unsigned int);
	int (*ioctl)(struct block_device___11 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___11 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___4 *, unsigned int);
	int (*media_changed)(struct gendisk___4 *);
	void (*unlock_native_capacity)(struct gendisk___4 *);
	int (*revalidate_disk)(struct gendisk___4 *);
	int (*getgeo)(struct block_device___11 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___11 *, long unsigned int);
	int (*report_zones)(struct gendisk___4 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___13 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___4 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___5 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___5 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___5 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___4(struct request___5 *, blk_status_t);

struct request___5 {
	struct request_queue___5 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___4 *bio;
	struct bio___4 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___4 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___4 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___4 *saved_end_io;
		} flush;
	};
	struct gendisk___4 *rq_disk;
	struct hd_struct___4 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___4 *end_io;
	void *end_io_data;
	struct request___5 *next_rq;
};

struct fwnode_reference_args___8;

struct fwnode_endpoint___8;

struct fwnode_operations___8 {
	struct fwnode_handle___8 * (*get)(struct fwnode_handle___8 *);
	void (*put)(struct fwnode_handle___8 *);
	bool (*device_is_available)(const struct fwnode_handle___8 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___8 *, const struct device___11 *);
	bool (*property_present)(const struct fwnode_handle___8 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___8 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___8 *, const char *, const char **, size_t);
	struct fwnode_handle___8 * (*get_parent)(const struct fwnode_handle___8 *);
	struct fwnode_handle___8 * (*get_next_child_node)(const struct fwnode_handle___8 *, struct fwnode_handle___8 *);
	struct fwnode_handle___8 * (*get_named_child_node)(const struct fwnode_handle___8 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___8 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___8 *);
	struct fwnode_handle___8 * (*graph_get_next_endpoint)(const struct fwnode_handle___8 *, struct fwnode_handle___8 *);
	struct fwnode_handle___8 * (*graph_get_remote_endpoint)(const struct fwnode_handle___8 *);
	struct fwnode_handle___8 * (*graph_get_port_parent)(struct fwnode_handle___8 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___8 *, struct fwnode_endpoint___8 *);
};

struct fwnode_endpoint___8 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___8 *local_fwnode;
};

struct fwnode_reference_args___8 {
	struct fwnode_handle___8 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct elevator_type___4;

struct elevator_mq_ops___4 {
	int (*init_sched)(struct request_queue___5 *, struct elevator_type___4 *);
	void (*exit_sched)(struct elevator_queue___4 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	bool (*allow_merge)(struct request_queue___5 *, struct request___5 *, struct bio___4 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx *, struct bio___4 *);
	int (*request_merge)(struct request_queue___5 *, struct request___5 **, struct bio___4 *);
	void (*request_merged)(struct request_queue___5 *, struct request___5 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___5 *, struct request___5 *, struct request___5 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___5 *, struct bio___4 *);
	void (*finish_request)(struct request___5 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___5 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___5 *, u64);
	void (*started_request)(struct request___5 *);
	void (*requeue_request)(struct request___5 *);
	struct request___5 * (*former_request)(struct request_queue___5 *, struct request___5 *);
	struct request___5 * (*next_request)(struct request_queue___5 *, struct request___5 *);
	void (*init_icq)(struct io_cq___4 *);
	void (*exit_icq)(struct io_cq___4 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide42;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___4;

struct elevator_type___4 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___4 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___4 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___13 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___4 {
	struct elevator_type___4 *type;
	void *elevator_data;
	struct kobject___10 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___4 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___4 *, char *);
	ssize_t (*store)(struct elevator_queue___4 *, const char *, size_t);
};

struct blkcg_policy_data___2;

struct blkcg___2 {
	struct cgroup_subsys_state___6 css;
	spinlock_t lock;
	struct xarray blkg_tree;
	struct blkcg_gq___2 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___2 *cpd[5];
	struct list_head all_blkcgs_node;
	struct list_head cgwb_list;
	refcount_t cgwb_refcnt;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct blkcg_policy_data___2 {
	struct blkcg___2 *blkcg;
	int plid;
};

struct blkg_policy_data___2 {
	struct blkcg_gq___2 *blkg;
	int plid;
};

struct trace_event_class___6 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___7 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___7 *);
	struct list_head * (*get_fields)(struct trace_event_call___7 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___7 *);
};

struct trace_event_file___2;

struct trace_event_buffer___2 {
	struct ring_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___2 *trace_file;
	void *entry;
	long unsigned int flags;
	int pc;
};

struct trace_event_file___2 {
	struct list_head list;
	struct trace_event_call___7 *event_call;
	struct event_filter *filter;
	struct dentry___12 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_sys_enter {
	struct trace_entry ent;
	long int id;
	long unsigned int args[6];
	char __data[0];
};

struct trace_event_raw_sys_exit {
	struct trace_entry ent;
	long int id;
	long int ret;
	char __data[0];
};

struct trace_event_data_offsets_sys_enter {};

struct trace_event_data_offsets_sys_exit {};

struct pt_regs_offset {
	const char *name;
	int offset;
};

enum aarch64_regset {
	REGSET_GPR = 0,
	REGSET_FPR = 1,
	REGSET_TLS = 2,
	REGSET_HW_BREAK = 3,
	REGSET_HW_WATCH = 4,
	REGSET_SYSTEM_CALL = 5,
	REGSET_SVE = 6,
};

enum ptrace_syscall_dir {
	PTRACE_SYSCALL_ENTER = 0,
	PTRACE_SYSCALL_EXIT = 1,
};

struct file___12;

struct kiocb___12;

struct vm_area_struct___13;

struct inode___14;

struct file_lock___12;

struct page___13;

struct seq_file___14;

struct file_operations___12 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___12 *, loff_t, int);
	ssize_t (*read)(struct file___12 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___12 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___12 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___12 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___12 *, bool);
	int (*iterate)(struct file___12 *, struct dir_context *);
	int (*iterate_shared)(struct file___12 *, struct dir_context *);
	__poll_t (*poll)(struct file___12 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___12 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___12 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___12 *, struct vm_area_struct___13 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___14 *, struct file___12 *);
	int (*flush)(struct file___12 *, fl_owner_t);
	int (*release)(struct inode___14 *, struct file___12 *);
	int (*fsync)(struct file___12 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___12 *, int);
	int (*lock)(struct file___12 *, int, struct file_lock___12 *);
	ssize_t (*sendpage)(struct file___12 *, struct page___13 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___12 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___12 *, int, struct file_lock___12 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___12 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___12 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___12 *, long int, struct file_lock___12 **, void **);
	long int (*fallocate)(struct file___12 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___14 *, struct file___12 *);
	ssize_t (*copy_file_range)(struct file___12 *, loff_t, struct file___12 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___12 *, loff_t, struct file___12 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___12 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___11 {
	u64 seqnum;
	struct vm_area_struct___13 *vmas[4];
};

struct page_frag___11 {
	struct page___13 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___12;

struct pid___10;

struct cred___12;

struct vm_struct___9;

struct task_struct___13 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___13 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___12 *mm;
	struct mm_struct___12 *active_mm;
	struct vmacache___11 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___13 *real_parent;
	struct task_struct___13 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___13 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___10 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___10 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___10 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___12 *ptracer_cred;
	const struct cred___12 *real_cred;
	const struct cred___12 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___13 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___5 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___11 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___13 *oom_reaper_list;
	struct vm_struct___9 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___6 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___13 *pgtable_t___11;

struct address_space___11;

struct dev_pagemap___11;

struct page___13 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___11 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___13 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___11 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___12 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___11 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___11;

struct lruvec___11 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___11 *pgdat;
};

struct zone___11 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___11 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___11 {
	struct zone___11 *zone;
	int zone_idx;
};

struct zonelist___11 {
	struct zoneref___11 _zonerefs[25];
};

struct pglist_data___11 {
	struct zone___11 node_zones[3];
	struct zonelist___11 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___13 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___13 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___11 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___12 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___13 *owner;
};

struct secondary_data___12 {
	void *stack;
	struct task_struct___13 *task;
	long int status;
};

struct blocking_notifier_head___11 {
	struct rw_semaphore___12 rwsem;
	struct notifier_block *head;
};

struct kernfs_root___11;

struct kernfs_elem_dir___11 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___11 *root;
};

struct kernfs_node___11;

struct kernfs_syscall_ops___11;

struct kernfs_root___11 {
	struct kernfs_node___11 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___11 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___11 {
	struct kernfs_node___11 *target_kn;
};

struct kernfs_ops___11;

struct kernfs_elem_attr___11 {
	const struct kernfs_ops___11 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___11 *notify_next;
};

struct kernfs_node___11 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___11 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___11 dir;
		struct kernfs_elem_symlink___11 symlink;
		struct kernfs_elem_attr___11 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___11;

struct kernfs_ops___11 {
	int (*open)(struct kernfs_open_file___11 *);
	void (*release)(struct kernfs_open_file___11 *);
	int (*seq_show)(struct seq_file___14 *, void *);
	void * (*seq_start)(struct seq_file___14 *, loff_t *);
	void * (*seq_next)(struct seq_file___14 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___14 *, void *);
	ssize_t (*read)(struct kernfs_open_file___11 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___11 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___11 *, struct vm_area_struct___13 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___11 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___11 {
	int (*remount_fs)(struct kernfs_root___11 *, int *, char *);
	int (*show_options)(struct seq_file___14 *, struct kernfs_root___11 *);
	int (*mkdir)(struct kernfs_node___11 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___11 *);
	int (*rename)(struct kernfs_node___11 *, struct kernfs_node___11 *, const char *);
	int (*show_path)(struct seq_file___14 *, struct kernfs_node___11 *, struct kernfs_root___11 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___11;

struct seq_file___14 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___11 *op;
	int poll_event;
	const struct file___12 *file;
	void *private;
};

struct vm_operations_struct___11;

struct kernfs_open_file___11 {
	struct kernfs_node___11 *kn;
	struct file___12 *file;
	struct seq_file___14 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___11 *vm_ops;
};

struct dentry___13;

struct path___11 {
	struct vfsmount *mnt;
	struct dentry___13 *dentry;
};

struct fown_struct___10 {
	rwlock_t lock;
	struct pid___10 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___12 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___11 f_path;
	struct inode___14 *f_inode;
	const struct file_operations___12 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___10 f_owner;
	const struct cred___12 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___11 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___11;

struct vm_operations_struct___11 {
	void (*open)(struct vm_area_struct___13 *);
	void (*close)(struct vm_area_struct___13 *);
	int (*split)(struct vm_area_struct___13 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___13 *);
	vm_fault_t (*fault)(struct vm_fault___11 *);
	vm_fault_t (*huge_fault)(struct vm_fault___11 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___11 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___13 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___11 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___11 *);
	int (*access)(struct vm_area_struct___13 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___13 *);
	int (*set_policy)(struct vm_area_struct___13 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___13 *, long unsigned int);
	struct page___13 * (*find_special_page)(struct vm_area_struct___13 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___8)(struct file___12 *, wait_queue_head_t *, struct poll_table_struct___6 *);

struct poll_table_struct___6 {
	poll_queue_proc___8 _qproc;
	__poll_t _key;
};

struct vm_area_struct___13 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___13 *vm_next;
	struct vm_area_struct___13 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___12 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___11 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___12 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___11;

struct bin_attribute___11;

struct attribute_group___11 {
	const char *name;
	umode_t (*is_visible)(struct kobject___11 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___11 *, struct bin_attribute___11 *, int);
	struct attribute **attrs;
	struct bin_attribute___11 **bin_attrs;
};

struct kset___11;

struct kobj_type___11;

struct kobject___11 {
	const char *name;
	struct list_head entry;
	struct kobject___11 *parent;
	struct kset___11 *kset;
	struct kobj_type___11 *ktype;
	struct kernfs_node___11 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___11 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___12 *, struct kobject___11 *, struct bin_attribute___11 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___12 *, struct kobject___11 *, struct bin_attribute___11 *, char *, loff_t, size_t);
	int (*mmap)(struct file___12 *, struct kobject___11 *, struct bin_attribute___11 *, struct vm_area_struct___13 *);
};

struct sysfs_ops___11 {
	ssize_t (*show)(struct kobject___11 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___11 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___11;

struct kset___11 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___11 kobj;
	const struct kset_uevent_ops___11 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___11 {
	void (*release)(struct kobject___11 *);
	const struct sysfs_ops___11 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___11 *);
	const void * (*namespace)(struct kobject___11 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___11 {
	int (* const filter)(struct kset___11 *, struct kobject___11 *);
	const char * (* const name)(struct kset___11 *, struct kobject___11 *);
	int (* const uevent)(struct kset___11 *, struct kobject___11 *, struct kobj_uevent_env *);
};

struct kobj_attribute___11 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___11 *, struct kobj_attribute___11 *, char *);
	ssize_t (*store)(struct kobject___11 *, struct kobj_attribute___11 *, const char *, size_t);
};

struct device___12;

struct dev_pm_ops___11 {
	int (*prepare)(struct device___12 *);
	void (*complete)(struct device___12 *);
	int (*suspend)(struct device___12 *);
	int (*resume)(struct device___12 *);
	int (*freeze)(struct device___12 *);
	int (*thaw)(struct device___12 *);
	int (*poweroff)(struct device___12 *);
	int (*restore)(struct device___12 *);
	int (*suspend_late)(struct device___12 *);
	int (*resume_early)(struct device___12 *);
	int (*freeze_late)(struct device___12 *);
	int (*thaw_early)(struct device___12 *);
	int (*poweroff_late)(struct device___12 *);
	int (*restore_early)(struct device___12 *);
	int (*suspend_noirq)(struct device___12 *);
	int (*resume_noirq)(struct device___12 *);
	int (*freeze_noirq)(struct device___12 *);
	int (*thaw_noirq)(struct device___12 *);
	int (*poweroff_noirq)(struct device___12 *);
	int (*restore_noirq)(struct device___12 *);
	int (*runtime_suspend)(struct device___12 *);
	int (*runtime_resume)(struct device___12 *);
	int (*runtime_idle)(struct device___12 *);
};

struct dev_pm_info___11 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___12 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___11;

struct bus_type___11;

struct device_driver___11;

struct dev_pm_domain___11;

struct fwnode_handle___9;

struct class___11;

struct device___12 {
	struct device___12 *parent;
	struct device_private *p;
	struct kobject___11 kobj;
	const char *init_name;
	const struct device_type___11 *type;
	struct mutex mutex;
	struct bus_type___11 *bus;
	struct device_driver___11 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___11 power;
	struct dev_pm_domain___11 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___9 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___11 *class;
	const struct attribute_group___11 **groups;
	void (*release)(struct device___12 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___11 {
	struct dev_pm_ops___11 ops;
	void (*detach)(struct device___12 *, bool);
	int (*activate)(struct device___12 *);
	void (*sync)(struct device___12 *);
	void (*dismiss)(struct device___12 *);
};

struct pid_namespace___10;

struct upid___10 {
	int nr;
	struct pid_namespace___10 *ns;
};

struct pid_namespace___10 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___13 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___10 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___13 *proc_self;
	struct dentry___13 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___3 *user_ns;
	struct ucounts___2 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common ns;
};

struct pid___10 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___10 numbers[1];
};

struct key___13;

struct user_struct___12 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___13 *uid_keyring;
	struct key___13 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___11;

struct mm_struct___12 {
	struct {
		struct vm_area_struct___13 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___12 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___12 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___11 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___13 *owner;
		struct user_namespace___3 *user_ns;
		struct file___12 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___11 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___12 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___13 *session_keyring;
	struct key___13 *process_keyring;
	struct key___13 *thread_keyring;
	struct key___13 *request_key_auth;
	void *security;
	struct user_struct___12 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct nsproxy___8 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___10 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct signal_struct___2 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___13 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___13 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___10 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___10 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___12 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___10 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_struct___9 {
	struct vm_struct___9 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___13 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___10 {
	struct task_struct___13 task;
	long unsigned int stack[8192];
};

struct bus_type___11 {
	const char *name;
	const char *dev_name;
	struct device___12 *dev_root;
	const struct attribute_group___11 **bus_groups;
	const struct attribute_group___11 **dev_groups;
	const struct attribute_group___11 **drv_groups;
	int (*match)(struct device___12 *, struct device_driver___11 *);
	int (*uevent)(struct device___12 *, struct kobj_uevent_env *);
	int (*probe)(struct device___12 *);
	int (*remove)(struct device___12 *);
	void (*shutdown)(struct device___12 *);
	int (*online)(struct device___12 *);
	int (*offline)(struct device___12 *);
	int (*suspend)(struct device___12 *, pm_message_t);
	int (*resume)(struct device___12 *);
	int (*num_vf)(struct device___12 *);
	int (*dma_configure)(struct device___12 *);
	const struct dev_pm_ops___11 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___11 {
	const char *name;
	struct bus_type___11 *bus;
	struct module___11 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___12 *);
	int (*remove)(struct device___12 *);
	void (*shutdown)(struct device___12 *);
	int (*suspend)(struct device___12 *, pm_message_t);
	int (*resume)(struct device___12 *);
	const struct attribute_group___11 **groups;
	const struct dev_pm_ops___11 *pm;
	void (*coredump)(struct device___12 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___11 {
	const char *name;
	const struct attribute_group___11 **groups;
	int (*uevent)(struct device___12 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___12 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___12 *);
	const struct dev_pm_ops___11 *pm;
};

struct module_kobject___10 {
	struct kobject___11 kobj;
	struct module___11 *mod;
	struct kobject___11 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___10 {
	struct module___11 *mod;
	struct latch_tree_node node;
};

struct module_layout___10 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___10 mtn;
};

struct module_attribute___10;

struct kernel_param___10;

struct module___11 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___10 mkobj;
	struct module_attribute___10 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___11 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___10 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___10 core_layout;
	struct module_layout___10 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct class___11 {
	const char *name;
	struct module___11 *owner;
	const struct attribute_group___11 **class_groups;
	const struct attribute_group___11 **dev_groups;
	struct kobject___11 *dev_kobj;
	int (*dev_uevent)(struct device___12 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___12 *, umode_t *);
	void (*class_release)(struct class___11 *);
	void (*dev_release)(struct device___12 *);
	int (*shutdown_pre)(struct device___12 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___12 *);
	const struct dev_pm_ops___11 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct fwnode_operations___9;

struct fwnode_handle___9 {
	struct fwnode_handle___9 *secondary;
	const struct fwnode_operations___9 *ops;
};

struct fwnode_reference_args___9;

struct fwnode_endpoint___9;

struct fwnode_operations___9 {
	struct fwnode_handle___9 * (*get)(struct fwnode_handle___9 *);
	void (*put)(struct fwnode_handle___9 *);
	bool (*device_is_available)(const struct fwnode_handle___9 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___9 *, const struct device___12 *);
	bool (*property_present)(const struct fwnode_handle___9 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___9 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___9 *, const char *, const char **, size_t);
	struct fwnode_handle___9 * (*get_parent)(const struct fwnode_handle___9 *);
	struct fwnode_handle___9 * (*get_next_child_node)(const struct fwnode_handle___9 *, struct fwnode_handle___9 *);
	struct fwnode_handle___9 * (*get_named_child_node)(const struct fwnode_handle___9 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___9 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___9 *);
	struct fwnode_handle___9 * (*graph_get_next_endpoint)(const struct fwnode_handle___9 *, struct fwnode_handle___9 *);
	struct fwnode_handle___9 * (*graph_get_remote_endpoint)(const struct fwnode_handle___9 *);
	struct fwnode_handle___9 * (*graph_get_port_parent)(struct fwnode_handle___9 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___9 *, struct fwnode_endpoint___9 *);
};

struct fwnode_endpoint___9 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___9 *local_fwnode;
};

struct fwnode_reference_args___9 {
	struct fwnode_handle___9 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct kernel_param_ops___10 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___10 *);
	int (*get)(char *, const struct kernel_param___10 *);
	void (*free)(void *);
};

struct kparam_array___10;

struct kernel_param___10 {
	const char *name;
	struct module___11 *mod;
	const struct kernel_param_ops___10 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___10 *arr;
	};
};

struct kparam_array___10 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___10 *ops;
	void *elem;
};

struct module_attribute___10 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___10 *, struct module_kobject___10 *, char *);
	ssize_t (*store)(struct module_attribute___10 *, struct module_kobject___10 *, const char *, size_t);
	void (*setup)(struct module___11 *, const char *);
	int (*test)(struct module___11 *);
	void (*free)(struct module___11 *);
};

struct dentry_operations___11;

struct super_block___12;

struct dentry___13 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___13 *d_parent;
	struct qstr d_name;
	struct inode___14 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___11 *d_op;
	struct super_block___12 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___11;

struct address_space___11 {
	struct inode___14 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___12 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___11 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___11;

struct block_device___12;

struct inode___14 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___11 *i_op;
	struct super_block___12 *i_sb;
	struct address_space___11 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___12 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___12 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___11 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___12 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___11 {
	int (*d_revalidate)(struct dentry___13 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___13 *, unsigned int);
	int (*d_hash)(const struct dentry___13 *, struct qstr *);
	int (*d_compare)(const struct dentry___13 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___13 *);
	int (*d_init)(struct dentry___13 *);
	void (*d_release)(struct dentry___13 *);
	void (*d_prune)(struct dentry___13 *);
	void (*d_iput)(struct dentry___13 *, struct inode___14 *);
	char * (*d_dname)(struct dentry___13 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___11 *);
	int (*d_manage)(const struct path___11 *, bool);
	struct dentry___13 * (*d_real)(struct dentry___13 *, const struct inode___14 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___11;

struct mem_dqinfo___11 {
	struct quota_format_type___11 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___11;

struct quota_info___11 {
	unsigned int flags;
	struct rw_semaphore___12 dqio_sem;
	struct inode___14 *files[3];
	struct mem_dqinfo___11 info[3];
	const struct quota_format_ops___11 *ops[3];
};

struct rcuwait___11 {
	struct task_struct___13 *task;
};

struct percpu_rw_semaphore___11 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___12 rw_sem;
	struct rcuwait___11 writer;
	int readers_block;
};

struct sb_writers___11 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___11 rw_sem[3];
};

struct file_system_type___11;

struct super_operations___11;

struct dquot_operations___11;

struct quotactl_ops___11;

struct super_block___12 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___11 *s_type;
	const struct super_operations___11 *s_op;
	const struct dquot_operations___11 *dq_op;
	const struct quotactl_ops___11 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___13 *s_root;
	struct rw_semaphore___12 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___12 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___11 s_dquot;
	struct sb_writers___11 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___11 *s_d_op;
	int cleancache_poolid;
	struct shrinker___3 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

typedef int (*dev_page_fault_t___11)(struct vm_area_struct___13 *, long unsigned int, const struct page___13 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___11)(struct page___13 *, void *);

struct dev_pagemap___11 {
	dev_page_fault_t___11 page_fault;
	dev_page_free_t___11 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___12 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___11 {
	struct task_struct___13 *task;
	struct core_thread___11 *next;
};

struct core_state___11 {
	atomic_t nr_threads;
	struct core_thread___11 dumper;
	struct completion startup;
};

struct vm_fault___11 {
	struct vm_area_struct___13 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___13 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___13 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___11 prealloc_pte;
};

struct kiocb___12 {
	struct file___12 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___12 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___12 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___12 *ia_file;
};

struct dquot___11 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___12 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___11 {
	int qf_fmt_id;
	const struct quota_format_ops___11 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___11 *qf_next;
};

struct quota_format_ops___11 {
	int (*check_quota_file)(struct super_block___12 *, int);
	int (*read_file_info)(struct super_block___12 *, int);
	int (*write_file_info)(struct super_block___12 *, int);
	int (*free_file_info)(struct super_block___12 *, int);
	int (*read_dqblk)(struct dquot___11 *);
	int (*commit_dqblk)(struct dquot___11 *);
	int (*release_dqblk)(struct dquot___11 *);
	int (*get_next_id)(struct super_block___12 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___11 {
	int (*write_dquot)(struct dquot___11 *);
	struct dquot___11 * (*alloc_dquot)(struct super_block___12 *, int);
	void (*destroy_dquot)(struct dquot___11 *);
	int (*acquire_dquot)(struct dquot___11 *);
	int (*release_dquot)(struct dquot___11 *);
	int (*mark_dirty)(struct dquot___11 *);
	int (*write_info)(struct super_block___12 *, int);
	qsize_t * (*get_reserved_space)(struct inode___14 *);
	int (*get_projid)(struct inode___14 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___14 *, qsize_t *);
	int (*get_next_id)(struct super_block___12 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___11 {
	int (*quota_on)(struct super_block___12 *, int, int, const struct path___11 *);
	int (*quota_off)(struct super_block___12 *, int);
	int (*quota_enable)(struct super_block___12 *, unsigned int);
	int (*quota_disable)(struct super_block___12 *, unsigned int);
	int (*quota_sync)(struct super_block___12 *, int);
	int (*set_info)(struct super_block___12 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___12 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___12 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___12 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___12 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___12 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___11 {
	int (*writepage)(struct page___13 *, struct writeback_control___3 *);
	int (*readpage)(struct file___12 *, struct page___13 *);
	int (*writepages)(struct address_space___11 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___13 *);
	int (*readpages)(struct file___12 *, struct address_space___11 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___12 *, struct address_space___11 *, loff_t, unsigned int, unsigned int, struct page___13 **, void **);
	int (*write_end)(struct file___12 *, struct address_space___11 *, loff_t, unsigned int, unsigned int, struct page___13 *, void *);
	sector_t (*bmap)(struct address_space___11 *, sector_t);
	void (*invalidatepage)(struct page___13 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___13 *, gfp_t);
	void (*freepage)(struct page___13 *);
	ssize_t (*direct_IO)(struct kiocb___12 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___11 *, struct page___13 *, struct page___13 *, enum migrate_mode);
	bool (*isolate_page)(struct page___13 *, isolate_mode_t);
	void (*putback_page)(struct page___13 *);
	int (*launder_page)(struct page___13 *);
	int (*is_partially_uptodate)(struct page___13 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___13 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___11 *, struct page___13 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___12 *, sector_t *);
	void (*swap_deactivate)(struct file___12 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___12 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___14 *bd_inode;
	struct super_block___12 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___12 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___3 {
	struct kobject___11 kobj;
	struct module___11 *owner;
	const struct file_operations___12 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___11 {
	struct dentry___13 * (*lookup)(struct inode___14 *, struct dentry___13 *, unsigned int);
	const char * (*get_link)(struct dentry___13 *, struct inode___14 *, struct delayed_call *);
	int (*permission)(struct inode___14 *, int);
	struct posix_acl * (*get_acl)(struct inode___14 *, int);
	int (*readlink)(struct dentry___13 *, char *, int);
	int (*create)(struct inode___14 *, struct dentry___13 *, umode_t, bool);
	int (*link)(struct dentry___13 *, struct inode___14 *, struct dentry___13 *);
	int (*unlink)(struct inode___14 *, struct dentry___13 *);
	int (*symlink)(struct inode___14 *, struct dentry___13 *, const char *);
	int (*mkdir)(struct inode___14 *, struct dentry___13 *, umode_t);
	int (*rmdir)(struct inode___14 *, struct dentry___13 *);
	int (*mknod)(struct inode___14 *, struct dentry___13 *, umode_t, dev_t);
	int (*rename)(struct inode___14 *, struct dentry___13 *, struct inode___14 *, struct dentry___13 *, unsigned int);
	int (*setattr)(struct dentry___13 *, struct iattr___12 *);
	int (*getattr)(const struct path___11 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___13 *, char *, size_t);
	int (*fiemap)(struct inode___14 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___14 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___14 *, struct dentry___13 *, struct file___12 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___14 *, struct dentry___13 *, umode_t);
	int (*set_acl)(struct inode___14 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___11 {
	void (*fl_copy_lock)(struct file_lock___12 *, struct file_lock___12 *);
	void (*fl_release_private)(struct file_lock___12 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___11;

struct lock_manager_operations___11;

struct file_lock___12 {
	struct file_lock___12 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___12 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___11 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___11 *fl_ops;
	const struct lock_manager_operations___11 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___11 {
	int (*lm_compare_owner)(struct file_lock___12 *, struct file_lock___12 *);
	long unsigned int (*lm_owner_key)(struct file_lock___12 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___12 *);
	int (*lm_grant)(struct file_lock___12 *, int);
	bool (*lm_break)(struct file_lock___12 *);
	int (*lm_change)(struct file_lock___12 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___12 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___11 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___11 *fa_next;
	struct file___12 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___11 {
	const char *name;
	int fs_flags;
	struct dentry___13 * (*mount)(struct file_system_type___11 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___12 *);
	struct module___11 *owner;
	struct file_system_type___11 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___11 {
	struct inode___14 * (*alloc_inode)(struct super_block___12 *);
	void (*destroy_inode)(struct inode___14 *);
	void (*dirty_inode)(struct inode___14 *, int);
	int (*write_inode)(struct inode___14 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___14 *);
	void (*evict_inode)(struct inode___14 *);
	void (*put_super)(struct super_block___12 *);
	int (*sync_fs)(struct super_block___12 *, int);
	int (*freeze_super)(struct super_block___12 *);
	int (*freeze_fs)(struct super_block___12 *);
	int (*thaw_super)(struct super_block___12 *);
	int (*unfreeze_fs)(struct super_block___12 *);
	int (*statfs)(struct dentry___13 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___12 *, int *, char *);
	void (*umount_begin)(struct super_block___12 *);
	int (*show_options)(struct seq_file___14 *, struct dentry___13 *);
	int (*show_devname)(struct seq_file___14 *, struct dentry___13 *);
	int (*show_path)(struct seq_file___14 *, struct dentry___13 *);
	int (*show_stats)(struct seq_file___14 *, struct dentry___13 *);
	ssize_t (*quota_read)(struct super_block___12 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___12 *, int, const char *, size_t, loff_t);
	struct dquot___11 ** (*get_dquots)(struct inode___14 *);
	int (*bdev_try_to_free_page)(struct super_block___12 *, struct page___13 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___12 *, struct shrink_control___3 *);
	long int (*free_cached_objects)(struct super_block___12 *, struct shrink_control___3 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*key_restrict_link_func_t___11)(struct key___13 *, const struct key_type *, const union key_payload *, struct key___13 *);

struct key_restriction___12;

struct key___13 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___12 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___12 *restrict_link;
};

struct key_restriction___12 {
	key_restrict_link_func_t___11 check;
	struct key___13 *key;
	struct key_type *keytype;
};

struct seq_operations___11 {
	void * (*start)(struct seq_file___14 *, loff_t *);
	void (*stop)(struct seq_file___14 *, void *);
	void * (*next)(struct seq_file___14 *, void *, loff_t *);
	int (*show)(struct seq_file___14 *, void *);
};

typedef void compound_page_dtor___11(struct page___13 *);

struct consw___2 {
	struct module___11 *owner;
	const char * (*con_startup)();
	void (*con_init)(struct vc_data *, int);
	void (*con_deinit)(struct vc_data *);
	void (*con_clear)(struct vc_data *, int, int, int, int);
	void (*con_putc)(struct vc_data *, int, int, int);
	void (*con_putcs)(struct vc_data *, const short unsigned int *, int, int, int);
	void (*con_cursor)(struct vc_data *, int);
	bool (*con_scroll)(struct vc_data *, unsigned int, unsigned int, enum con_scroll, unsigned int);
	int (*con_switch)(struct vc_data *);
	int (*con_blank)(struct vc_data *, int, int);
	int (*con_font_set)(struct vc_data *, struct console_font *, unsigned int);
	int (*con_font_get)(struct vc_data *, struct console_font *);
	int (*con_font_default)(struct vc_data *, struct console_font *, char *);
	int (*con_font_copy)(struct vc_data *, int);
	int (*con_resize)(struct vc_data *, unsigned int, unsigned int, unsigned int);
	void (*con_set_palette)(struct vc_data *, const unsigned char *);
	void (*con_scrolldelta)(struct vc_data *, int);
	int (*con_set_origin)(struct vc_data *);
	void (*con_save_screen)(struct vc_data *);
	u8 (*con_build_attr)(struct vc_data *, u8, u8, u8, u8, u8, u8);
	void (*con_invert_region)(struct vc_data *, u16 *, int);
	u16 * (*con_screen_pos)(struct vc_data *, int);
	long unsigned int (*con_getxy)(struct vc_data *, long unsigned int, int *, int *);
	void (*con_flush_scrollback)(struct vc_data *);
	int (*con_debug_enter)(struct vc_data *);
	int (*con_debug_leave)(struct vc_data *);
};

struct kimage___2;

typedef void *kexec_load_t___2(struct kimage___2 *, char *, long unsigned int, char *, long unsigned int, char *, long unsigned int);

struct kexec_file_ops___2 {
	kexec_probe_t *probe;
	kexec_load_t___2 *load;
	kexec_cleanup_t *cleanup;
};

struct kimage___2 {
	kimage_entry_t head;
	kimage_entry_t *entry;
	kimage_entry_t *last_entry;
	long unsigned int start;
	struct page___13 *control_code_page;
	struct page___13 *swap_page;
	void *vmcoreinfo_data_copy;
	long unsigned int nr_segments;
	struct kexec_segment segment[16];
	struct list_head control_pages;
	struct list_head dest_pages;
	struct list_head unusable_pages;
	long unsigned int control_page;
	unsigned int type: 1;
	unsigned int preserve_context: 1;
	unsigned int file_mode: 1;
	struct kimage_arch arch;
	void *kernel_buf;
	long unsigned int kernel_buf_len;
	void *initrd_buf;
	long unsigned int initrd_buf_len;
	char *cmdline_buf;
	long unsigned int cmdline_buf_len;
	const struct kexec_file_ops___2 *fops;
	void *image_loader_data;
	struct purgatory_info purgatory_info;
};

struct node___10 {
	struct device___12 dev;
};

struct cpu {
	int node_id;
	int hotpluggable;
	struct device___12 dev;
};

struct cpuinfo_arm64 {
	struct cpu cpu;
	struct kobject___11 kobj;
	u32 reg_ctr;
	u32 reg_cntfrq;
	u32 reg_dczid;
	u32 reg_midr;
	u32 reg_revidr;
	u64 reg_id_aa64dfr0;
	u64 reg_id_aa64dfr1;
	u64 reg_id_aa64isar0;
	u64 reg_id_aa64isar1;
	u64 reg_id_aa64mmfr0;
	u64 reg_id_aa64mmfr1;
	u64 reg_id_aa64mmfr2;
	u64 reg_id_aa64pfr0;
	u64 reg_id_aa64pfr1;
	u64 reg_id_aa64zfr0;
	u32 reg_id_dfr0;
	u32 reg_id_isar0;
	u32 reg_id_isar1;
	u32 reg_id_isar2;
	u32 reg_id_isar3;
	u32 reg_id_isar4;
	u32 reg_id_isar5;
	u32 reg_id_mmfr0;
	u32 reg_id_mmfr1;
	u32 reg_id_mmfr2;
	u32 reg_id_mmfr3;
	u32 reg_id_pfr0;
	u32 reg_id_pfr1;
	u32 reg_mvfr0;
	u32 reg_mvfr1;
	u32 reg_mvfr2;
	u64 reg_zcr;
};

struct cpu_operations {
	const char *name;
	int (*cpu_init)(unsigned int);
	int (*cpu_prepare)(unsigned int);
	int (*cpu_boot)(unsigned int);
	void (*cpu_postboot)();
	int (*cpu_disable)(unsigned int);
	void (*cpu_die)(unsigned int);
	int (*cpu_kill)(unsigned int);
	int (*cpu_init_idle)(unsigned int);
	int (*cpu_suspend)(long unsigned int);
};

struct module___14;

struct file___13;

struct kiocb___13;

struct iov_iter___6;

struct poll_table_struct___10;

struct vm_area_struct___14;

struct inode___15;

struct file_lock___13;

struct page___14;

struct seq_file___15;

struct file_operations___13 {
	struct module___14 *owner;
	loff_t (*llseek)(struct file___13 *, loff_t, int);
	ssize_t (*read)(struct file___13 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___13 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___13 *, struct iov_iter___6 *);
	ssize_t (*write_iter)(struct kiocb___13 *, struct iov_iter___6 *);
	int (*iopoll)(struct kiocb___13 *, bool);
	int (*iterate)(struct file___13 *, struct dir_context *);
	int (*iterate_shared)(struct file___13 *, struct dir_context *);
	__poll_t (*poll)(struct file___13 *, struct poll_table_struct___10 *);
	long int (*unlocked_ioctl)(struct file___13 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___13 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___13 *, struct vm_area_struct___14 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___15 *, struct file___13 *);
	int (*flush)(struct file___13 *, fl_owner_t);
	int (*release)(struct inode___15 *, struct file___13 *);
	int (*fsync)(struct file___13 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___13 *, int);
	int (*lock)(struct file___13 *, int, struct file_lock___13 *);
	ssize_t (*sendpage)(struct file___13 *, struct page___14 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___13 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___13 *, int, struct file_lock___13 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___13 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___13 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___13 *, long int, struct file_lock___13 **, void **);
	long int (*fallocate)(struct file___13 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___15 *, struct file___13 *);
	ssize_t (*copy_file_range)(struct file___13 *, loff_t, struct file___13 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___13 *, loff_t, struct file___13 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___13 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___12 {
	u64 seqnum;
	struct vm_area_struct___14 *vmas[4];
};

struct page_frag___12 {
	struct page___14 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___7;

struct debug_info___7 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___7 *hbp_break[16];
	struct perf_event___7 *hbp_watch[16];
};

struct thread_struct___7 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___7 debug;
	long: 64;
};

struct mm_struct___13;

struct mem_cgroup___4;

struct pid___11;

struct cred___13;

struct nsproxy___12;

struct signal_struct___11;

struct bio_list___5;

struct backing_dev_info___5;

struct css_set___8;

struct perf_event_context___8;

struct request_queue___6;

struct vm_struct___10;

struct task_struct___14 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___14 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___13 *mm;
	struct mm_struct___13 *active_mm;
	struct vmacache___12 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___14 *real_parent;
	struct task_struct___14 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___14 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___4 *active_memcg;
	long int rh_reserved2;
	struct pid___11 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___11 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___11 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___13 *ptracer_cred;
	const struct cred___13 *real_cred;
	const struct cred___13 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___12 *nsproxy;
	struct signal_struct___11 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___14 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___5 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___5 *backing_dev_info;
	struct io_context___2 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___8 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___8 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___12 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___4 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___6 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___14 *oom_reaper_list;
	struct vm_struct___10 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___7 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___7 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___14 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___7)(struct perf_event___7 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___7;

struct fasync_struct___12;

struct pid_namespace___11;

struct trace_event_call___8;

struct perf_cgroup___7;

struct perf_event___7 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___7 *group_leader;
	struct pmu___7 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___7 hw;
	struct perf_event_context___8 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___7 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___14 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___12 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___7 *);
	struct callback_head callback_head;
	struct pid_namespace___11 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___7 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___7 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___8 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___7 *cgrp;
	struct list_head sb_list;
};

struct sigcontext {
	__u64 fault_address;
	__u64 regs[31];
	__u64 sp;
	__u64 pc;
	__u64 pstate;
	long: 64;
	__u8 __reserved[4096];
};

struct _aarch64_ctx {
	__u32 magic;
	__u32 size;
};

struct fpsimd_context {
	struct _aarch64_ctx head;
	__u32 fpsr;
	__u32 fpcr;
	__int128 unsigned vregs[32];
};

struct esr_context {
	struct _aarch64_ctx head;
	__u64 esr;
};

struct extra_context {
	struct _aarch64_ctx head;
	__u64 datap;
	__u32 size;
	__u32 __reserved[3];
};

struct sve_context {
	struct _aarch64_ctx head;
	__u16 vl;
	__u16 __reserved[3];
};

struct rw_semaphore___13 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___14 *owner;
};

struct key___14;

struct ucounts___8;

struct user_namespace___9 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___9 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common ns;
	long unsigned int flags;
	struct key___14 *persistent_keyring_register;
	struct rw_semaphore___13 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___8 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct secondary_data___13 {
	void *stack;
	struct task_struct___14 *task;
	long int status;
};

typedef struct page___14 *pgtable_t___12;

struct address_space___12;

struct dev_pagemap___12;

struct page___14 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___12 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___14 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___12 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___13 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___12 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___4 *mem_cgroup;
};

struct pglist_data___12;

struct lruvec___12 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___12 *pgdat;
};

struct zone___12 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___12 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___12 {
	struct zone___12 *zone;
	int zone_idx;
};

struct zonelist___12 {
	struct zoneref___12 _zonerefs[25];
};

struct pglist_data___12 {
	struct zone___12 node_zones[3];
	struct zonelist___12 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___14 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___14 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___12 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___12 {
	struct rw_semaphore___13 rwsem;
	struct notifier_block *head;
};

struct cgroup___7;

struct cgroup_subsys___7;

struct cgroup_subsys_state___7 {
	struct cgroup___7 *cgroup;
	struct cgroup_subsys___7 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___7 *parent;
};

struct mem_cgroup_id___4 {
	int id;
	union {
		refcount_t ref;
		struct {
			atomic_t ref;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
};

struct kernfs_node___12;

struct cgroup_file___7 {
	struct kernfs_node___12 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___4;

struct mem_cgroup___4 {
	struct cgroup_subsys_state___7 css;
	struct mem_cgroup_id___4 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___7 events_file;
	struct cgroup_file___7 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___14 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___4 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct upid___11 {
	int nr;
	struct pid_namespace___11 *ns;
};

struct dentry___14;

struct pid_namespace___11 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___14 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___11 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___14 *proc_self;
	struct dentry___14 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___9 *user_ns;
	struct ucounts___8 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common ns;
};

struct pid___11 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___11 numbers[1];
};

struct sigaltstack {
	void *ss_sp;
	int ss_flags;
	size_t ss_size;
};

typedef struct sigaltstack stack_t;

struct user_struct___13 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___14 *uid_keyring;
	struct key___14 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct ksignal {
	struct k_sigaction ka;
	kernel_siginfo_t info;
	int sig;
};

struct vm_operations_struct___12;

struct vm_area_struct___14 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___14 *vm_next;
	struct vm_area_struct___14 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___13 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___12 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___13 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___12;

struct mm_struct___13 {
	struct {
		struct vm_area_struct___14 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___13 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___13 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___12 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___14 *owner;
		struct user_namespace___9 *user_ns;
		struct file___13 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___12 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___13 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___14 *session_keyring;
	struct key___14 *process_keyring;
	struct key___14 *thread_keyring;
	struct key___14 *request_key_auth;
	void *security;
	struct user_struct___13 *user;
	struct user_namespace___9 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___8;

struct nsproxy___12 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___11 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___8 *cgroup_ns;
};

struct signal_struct___11 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___14 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___14 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___11 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___11 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___13 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___11 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___5;

struct bio_list___5 {
	struct bio___5 *head;
	struct bio___5 *tail;
};

struct bdi_writeback_congested___5;

struct bdi_writeback___5 {
	struct backing_dev_info___5 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___5 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___7 *memcg_css;
	struct cgroup_subsys_state___7 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___13;

struct backing_dev_info___5 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___5 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___13 *dev;
	struct device___13 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___14 *debug_dir;
	struct dentry___14 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___5;

struct io_context___2 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___5 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___8 {
	struct cgroup_subsys_state___7 *subsys[13];
	refcount_t refcount;
	struct css_set___8 *dom_cset;
	struct cgroup___7 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___7 *mg_src_cgrp;
	struct cgroup___7 *mg_dst_cgrp;
	struct css_set___8 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___8 {
	struct pmu___7 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___14 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___8 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

typedef blk_qc_t make_request_fn___5(struct request_queue___6 *, struct bio___5 *);

struct request___6;

typedef int dma_drain_needed_fn___5(struct request___6 *);

struct kset___12;

struct kobj_type___12;

struct kobject___12 {
	const char *name;
	struct list_head entry;
	struct kobject___12 *parent;
	struct kset___12 *kset;
	struct kobj_type___12 *ktype;
	struct kernfs_node___12 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___5;

struct bsg_class_device___5 {
	struct device___13 *class_dev;
	int minor;
	struct request_queue___6 *queue;
	const struct bsg_ops___5 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___5 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___5 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___5;

struct blkcg_gq___3;

struct request_queue___6 {
	struct list_head queue_head;
	struct request___6 *last_merge;
	struct elevator_queue___5 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___5 *make_request_fn;
	dma_drain_needed_fn___5 *dma_drain_needed;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___5 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___12 kobj;
	struct kobject___12 *mq_kobj;
	struct blk_integrity integrity;
	struct device___13 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___3 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	struct bsg_class_device___5 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___5 bio_split;
	struct dentry___14 *debugfs_dir;
	struct dentry___14 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___10 {
	struct vm_struct___10 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___14 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___11 {
	struct task_struct___14 task;
	long unsigned int stack[8192];
};

struct address_space_operations___12;

struct address_space___12 {
	struct inode___15 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___13 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___12 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___12)(struct vm_area_struct___14 *, long unsigned int, const struct page___14 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___12)(struct page___14 *, void *);

struct dev_pagemap___12 {
	dev_page_fault_t___12 page_fault;
	dev_page_free_t___12 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___13 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___12 {
	struct vfsmount *mnt;
	struct dentry___14 *dentry;
};

struct fown_struct___11 {
	rwlock_t lock;
	struct pid___11 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___13 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___12 f_path;
	struct inode___15 *f_inode;
	const struct file_operations___13 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___11 f_owner;
	const struct cred___13 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___12 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___12;

struct vm_operations_struct___12 {
	void (*open)(struct vm_area_struct___14 *);
	void (*close)(struct vm_area_struct___14 *);
	int (*split)(struct vm_area_struct___14 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___14 *);
	vm_fault_t (*fault)(struct vm_fault___12 *);
	vm_fault_t (*huge_fault)(struct vm_fault___12 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___12 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___14 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___12 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___12 *);
	int (*access)(struct vm_area_struct___14 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___14 *);
	int (*set_policy)(struct vm_area_struct___14 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___14 *, long unsigned int);
	struct page___14 * (*find_special_page)(struct vm_area_struct___14 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___12 {
	struct task_struct___14 *task;
	struct core_thread___12 *next;
};

struct core_state___12 {
	atomic_t nr_threads;
	struct core_thread___12 dumper;
	struct completion startup;
};

struct vm_fault___12 {
	struct vm_area_struct___14 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___14 *cow_page;
	struct mem_cgroup___4 *memcg;
	struct page___14 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___12 prealloc_pte;
};

struct module_kobject___11 {
	struct kobject___12 kobj;
	struct module___14 *mod;
	struct kobject___12 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___11 {
	struct module___14 *mod;
	struct latch_tree_node node;
};

struct module_layout___11 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___11 mtn;
};

struct module_attribute___11;

struct kernel_param___11;

struct module___14 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___11 mkobj;
	struct module_attribute___11 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___12 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___11 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___11 core_layout;
	struct module_layout___11 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___8 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide46;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide47;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bio_vec___5 {
	struct page___14 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___6 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___5 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct kiocb___13 {
	struct file___13 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___13 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dentry_operations___12;

struct super_block___13;

struct dentry___14 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___14 *d_parent;
	struct qstr d_name;
	struct inode___15 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___12 *d_op;
	struct super_block___13 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___12;

struct block_device___13;

struct inode___15 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___12 *i_op;
	struct super_block___13 *i_sb;
	struct address_space___12 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___13 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___5 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___13 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___12 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___13 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___12 {
	int (*d_revalidate)(struct dentry___14 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___14 *, unsigned int);
	int (*d_hash)(const struct dentry___14 *, struct qstr *);
	int (*d_compare)(const struct dentry___14 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___14 *);
	int (*d_init)(struct dentry___14 *);
	void (*d_release)(struct dentry___14 *);
	void (*d_prune)(struct dentry___14 *);
	void (*d_iput)(struct dentry___14 *, struct inode___15 *);
	char * (*d_dname)(struct dentry___14 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___12 *);
	int (*d_manage)(const struct path___12 *, bool);
	struct dentry___14 * (*d_real)(struct dentry___14 *, const struct inode___15 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___12;

struct mem_dqinfo___12 {
	struct quota_format_type___12 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___12;

struct quota_info___12 {
	unsigned int flags;
	struct rw_semaphore___13 dqio_sem;
	struct inode___15 *files[3];
	struct mem_dqinfo___12 info[3];
	const struct quota_format_ops___12 *ops[3];
};

struct rcuwait___12 {
	struct task_struct___14 *task;
};

struct percpu_rw_semaphore___12 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___13 rw_sem;
	struct rcuwait___12 writer;
	int readers_block;
};

struct sb_writers___12 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___12 rw_sem[3];
};

struct shrink_control___4;

struct shrinker___4 {
	long unsigned int (*count_objects)(struct shrinker___4 *, struct shrink_control___4 *);
	long unsigned int (*scan_objects)(struct shrinker___4 *, struct shrink_control___4 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___12;

struct super_operations___12;

struct dquot_operations___12;

struct quotactl_ops___12;

struct super_block___13 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___12 *s_type;
	const struct super_operations___12 *s_op;
	const struct dquot_operations___12 *dq_op;
	const struct quotactl_ops___12 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___14 *s_root;
	struct rw_semaphore___13 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___13 *s_bdev;
	struct backing_dev_info___5 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___12 s_dquot;
	struct sb_writers___12 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___12 *s_d_op;
	int cleancache_poolid;
	struct shrinker___4 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___9 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___4 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___4 *memcg;
};

struct io_cq___5 {
	struct request_queue___6 *q;
	struct io_context___2 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct iattr___13 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___13 *ia_file;
};

struct dquot___12 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___13 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___12 {
	int qf_fmt_id;
	const struct quota_format_ops___12 *qf_ops;
	struct module___14 *qf_owner;
	struct quota_format_type___12 *qf_next;
};

struct quota_format_ops___12 {
	int (*check_quota_file)(struct super_block___13 *, int);
	int (*read_file_info)(struct super_block___13 *, int);
	int (*write_file_info)(struct super_block___13 *, int);
	int (*free_file_info)(struct super_block___13 *, int);
	int (*read_dqblk)(struct dquot___12 *);
	int (*commit_dqblk)(struct dquot___12 *);
	int (*release_dqblk)(struct dquot___12 *);
	int (*get_next_id)(struct super_block___13 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___12 {
	int (*write_dquot)(struct dquot___12 *);
	struct dquot___12 * (*alloc_dquot)(struct super_block___13 *, int);
	void (*destroy_dquot)(struct dquot___12 *);
	int (*acquire_dquot)(struct dquot___12 *);
	int (*release_dquot)(struct dquot___12 *);
	int (*mark_dirty)(struct dquot___12 *);
	int (*write_info)(struct super_block___13 *, int);
	qsize_t * (*get_reserved_space)(struct inode___15 *);
	int (*get_projid)(struct inode___15 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___15 *, qsize_t *);
	int (*get_next_id)(struct super_block___13 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___12 {
	int (*quota_on)(struct super_block___13 *, int, int, const struct path___12 *);
	int (*quota_off)(struct super_block___13 *, int);
	int (*quota_enable)(struct super_block___13 *, unsigned int);
	int (*quota_disable)(struct super_block___13 *, unsigned int);
	int (*quota_sync)(struct super_block___13 *, int);
	int (*set_info)(struct super_block___13 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___13 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___13 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___13 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___13 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___13 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___4;

struct address_space_operations___12 {
	int (*writepage)(struct page___14 *, struct writeback_control___4 *);
	int (*readpage)(struct file___13 *, struct page___14 *);
	int (*writepages)(struct address_space___12 *, struct writeback_control___4 *);
	int (*set_page_dirty)(struct page___14 *);
	int (*readpages)(struct file___13 *, struct address_space___12 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___13 *, struct address_space___12 *, loff_t, unsigned int, unsigned int, struct page___14 **, void **);
	int (*write_end)(struct file___13 *, struct address_space___12 *, loff_t, unsigned int, unsigned int, struct page___14 *, void *);
	sector_t (*bmap)(struct address_space___12 *, sector_t);
	void (*invalidatepage)(struct page___14 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___14 *, gfp_t);
	void (*freepage)(struct page___14 *);
	ssize_t (*direct_IO)(struct kiocb___13 *, struct iov_iter___6 *);
	int (*migratepage)(struct address_space___12 *, struct page___14 *, struct page___14 *, enum migrate_mode);
	bool (*isolate_page)(struct page___14 *, isolate_mode_t);
	void (*putback_page)(struct page___14 *);
	int (*launder_page)(struct page___14 *);
	int (*is_partially_uptodate)(struct page___14 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___14 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___12 *, struct page___14 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___13 *, sector_t *);
	void (*swap_deactivate)(struct file___13 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___4 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___5 *wb;
	struct inode___15 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct hd_struct___5;

struct gendisk___5;

struct block_device___13 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___15 *bd_inode;
	struct super_block___13 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___13 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___5 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___5 *bd_disk;
	struct request_queue___6 *bd_queue;
	struct backing_dev_info___5 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___12 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___13 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___12;

struct bus_type___12;

struct device_driver___12;

struct dev_pm_domain___12;

struct fwnode_handle___10;

struct class___12;

struct attribute_group___12;

struct device___13 {
	struct device___13 *parent;
	struct device_private *p;
	struct kobject___12 kobj;
	const char *init_name;
	const struct device_type___12 *type;
	struct mutex mutex;
	struct bus_type___12 *bus;
	struct device_driver___12 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___12 power;
	struct dev_pm_domain___12 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___10 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___12 *class;
	const struct attribute_group___12 **groups;
	void (*release)(struct device___13 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___5 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___13 __dev;
	struct kobject___12 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___5;

struct block_device_operations___5;

struct gendisk___5 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___5 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___5 *part_tbl;
	struct hd_struct___5 part0;
	const struct block_device_operations___5 *fops;
	struct request_queue___6 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___13 lookup_sem;
	struct kobject___12 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___12 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___12 {
	struct dentry___14 * (*lookup)(struct inode___15 *, struct dentry___14 *, unsigned int);
	const char * (*get_link)(struct dentry___14 *, struct inode___15 *, struct delayed_call *);
	int (*permission)(struct inode___15 *, int);
	struct posix_acl * (*get_acl)(struct inode___15 *, int);
	int (*readlink)(struct dentry___14 *, char *, int);
	int (*create)(struct inode___15 *, struct dentry___14 *, umode_t, bool);
	int (*link)(struct dentry___14 *, struct inode___15 *, struct dentry___14 *);
	int (*unlink)(struct inode___15 *, struct dentry___14 *);
	int (*symlink)(struct inode___15 *, struct dentry___14 *, const char *);
	int (*mkdir)(struct inode___15 *, struct dentry___14 *, umode_t);
	int (*rmdir)(struct inode___15 *, struct dentry___14 *);
	int (*mknod)(struct inode___15 *, struct dentry___14 *, umode_t, dev_t);
	int (*rename)(struct inode___15 *, struct dentry___14 *, struct inode___15 *, struct dentry___14 *, unsigned int);
	int (*setattr)(struct dentry___14 *, struct iattr___13 *);
	int (*getattr)(const struct path___12 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___14 *, char *, size_t);
	int (*fiemap)(struct inode___15 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___15 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___15 *, struct dentry___14 *, struct file___13 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___15 *, struct dentry___14 *, umode_t);
	int (*set_acl)(struct inode___15 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___12 {
	void (*fl_copy_lock)(struct file_lock___13 *, struct file_lock___13 *);
	void (*fl_release_private)(struct file_lock___13 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___12;

struct file_lock___13 {
	struct file_lock___13 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___13 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___12 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___12 *fl_ops;
	const struct lock_manager_operations___12 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___12 {
	int (*lm_compare_owner)(struct file_lock___13 *, struct file_lock___13 *);
	long unsigned int (*lm_owner_key)(struct file_lock___13 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___13 *);
	int (*lm_grant)(struct file_lock___13 *, int);
	bool (*lm_break)(struct file_lock___13 *);
	int (*lm_change)(struct file_lock___13 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___13 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___12 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___12 *fa_next;
	struct file___13 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___12 {
	const char *name;
	int fs_flags;
	struct dentry___14 * (*mount)(struct file_system_type___12 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___13 *);
	struct module___14 *owner;
	struct file_system_type___12 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___12 {
	struct inode___15 * (*alloc_inode)(struct super_block___13 *);
	void (*destroy_inode)(struct inode___15 *);
	void (*dirty_inode)(struct inode___15 *, int);
	int (*write_inode)(struct inode___15 *, struct writeback_control___4 *);
	int (*drop_inode)(struct inode___15 *);
	void (*evict_inode)(struct inode___15 *);
	void (*put_super)(struct super_block___13 *);
	int (*sync_fs)(struct super_block___13 *, int);
	int (*freeze_super)(struct super_block___13 *);
	int (*freeze_fs)(struct super_block___13 *);
	int (*thaw_super)(struct super_block___13 *);
	int (*unfreeze_fs)(struct super_block___13 *);
	int (*statfs)(struct dentry___14 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___13 *, int *, char *);
	void (*umount_begin)(struct super_block___13 *);
	int (*show_options)(struct seq_file___15 *, struct dentry___14 *);
	int (*show_devname)(struct seq_file___15 *, struct dentry___14 *);
	int (*show_path)(struct seq_file___15 *, struct dentry___14 *);
	int (*show_stats)(struct seq_file___15 *, struct dentry___14 *);
	ssize_t (*quota_read)(struct super_block___13 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___13 *, int, const char *, size_t, loff_t);
	struct dquot___12 ** (*get_dquots)(struct inode___15 *);
	int (*bdev_try_to_free_page)(struct super_block___13 *, struct page___14 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___13 *, struct shrink_control___4 *);
	long int (*free_cached_objects)(struct super_block___13 *, struct shrink_control___4 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___9)(struct file___13 *, wait_queue_head_t *, struct poll_table_struct___10 *);

struct poll_table_struct___10 {
	poll_queue_proc___9 _qproc;
	__poll_t _key;
};

struct seq_operations___12;

struct seq_file___15 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___12 *op;
	int poll_event;
	const struct file___13 *file;
	void *private;
};

typedef void bio_end_io_t___5(struct bio___5 *);

struct bio_integrity_payload___5;

struct bio___5 {
	struct bio___5 *bi_next;
	struct gendisk___5 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___5 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___3 *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___5 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___5 *bi_io_vec;
	struct bio_set___5 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___5 bi_inline_vecs[0];
};

typedef int (*key_restrict_link_func_t___12)(struct key___14 *, const struct key_type *, const union key_payload *, struct key___14 *);

struct key_restriction___13;

struct key___14 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___13 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___13 *restrict_link;
};

struct key_restriction___13 {
	key_restrict_link_func_t___12 check;
	struct key___14 *key;
	struct key_type *keytype;
};

struct kobj_attribute___12 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___12 *, struct kobj_attribute___12 *, char *);
	ssize_t (*store)(struct kobject___12 *, struct kobj_attribute___12 *, const char *, size_t);
};

typedef void compound_page_dtor___12(struct page___14 *);

struct cgroup_namespace___8 {
	refcount_t count;
	struct ns_common ns;
	struct user_namespace___9 *user_ns;
	struct ucounts___8 *ucounts;
	struct css_set___8 *root_cset;
};

struct ucounts___8 {
	struct hlist_node node;
	struct user_namespace___9 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct seq_operations___12 {
	void * (*start)(struct seq_file___15 *, loff_t *);
	void (*stop)(struct seq_file___15 *, void *);
	void * (*next)(struct seq_file___15 *, void *, loff_t *);
	int (*show)(struct seq_file___15 *, void *);
};

struct kernfs_root___12;

struct kernfs_elem_dir___12 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___12 *root;
};

struct kernfs_syscall_ops___12;

struct kernfs_root___12 {
	struct kernfs_node___12 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___12 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___12 {
	struct kernfs_node___12 *target_kn;
};

struct kernfs_ops___12;

struct kernfs_elem_attr___12 {
	const struct kernfs_ops___12 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___12 *notify_next;
};

struct kernfs_node___12 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___12 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___12 dir;
		struct kernfs_elem_symlink___12 symlink;
		struct kernfs_elem_attr___12 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___12;

struct kernfs_ops___12 {
	int (*open)(struct kernfs_open_file___12 *);
	void (*release)(struct kernfs_open_file___12 *);
	int (*seq_show)(struct seq_file___15 *, void *);
	void * (*seq_start)(struct seq_file___15 *, loff_t *);
	void * (*seq_next)(struct seq_file___15 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___15 *, void *);
	ssize_t (*read)(struct kernfs_open_file___12 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___12 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___12 *, struct vm_area_struct___14 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___12 *, struct poll_table_struct___10 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___12 {
	int (*remount_fs)(struct kernfs_root___12 *, int *, char *);
	int (*show_options)(struct seq_file___15 *, struct kernfs_root___12 *);
	int (*mkdir)(struct kernfs_node___12 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___12 *);
	int (*rename)(struct kernfs_node___12 *, struct kernfs_node___12 *, const char *);
	int (*show_path)(struct seq_file___15 *, struct kernfs_node___12 *, struct kernfs_root___12 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___12 {
	struct kernfs_node___12 *kn;
	struct file___13 *file;
	struct seq_file___15 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___12 *vm_ops;
};

struct bpf_map___7;

struct bpf_map_ops___7 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___7 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___7 *, struct file___13 *);
	void (*map_free)(struct bpf_map___7 *);
	int (*map_get_next_key)(struct bpf_map___7 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___7 *);
	void * (*map_lookup_elem)(struct bpf_map___7 *, void *);
	int (*map_update_elem)(struct bpf_map___7 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___7 *, void *);
	int (*map_push_elem)(struct bpf_map___7 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___7 *, void *);
	int (*map_peek_elem)(struct bpf_map___7 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___7 *, struct file___13 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___7 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___7 *, void *, struct seq_file___15 *);
	int (*map_check_btf)(const struct bpf_map___7 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___7 {
	const struct bpf_map_ops___7 *ops;
	struct bpf_map___7 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___13 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___7;

typedef void (*kthread_work_func_t___7)(struct kthread_work___7 *);

struct kthread_worker___7;

struct kthread_work___7 {
	struct list_head node;
	kthread_work_func_t___7 func;
	struct kthread_worker___7 *worker;
	int canceling;
};

struct kthread_worker___7 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___14 *task;
	struct kthread_work___7 *current_work;
};

struct kthread_delayed_work___7 {
	struct kthread_work___7 work;
	struct timer_list timer;
};

struct psi_group___7 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___7 *poll_kworker;
	struct kthread_delayed_work___7 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___7;

struct cgroup_rstat_cpu___7;

struct cgroup___7 {
	struct cgroup_subsys_state___7 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___12 *kn;
	struct cgroup_file___7 procs_file;
	struct cgroup_file___7 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___7 *subsys[13];
	struct cgroup_root___7 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___7 *dom_cgrp;
	struct cgroup_rstat_cpu___7 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf bpf;
	atomic_t congestion_count;
	struct cgroup___7 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___7 psi;
	int ancestor_ids[0];
};

struct cftype___7;

struct cgroup_subsys___7 {
	struct cgroup_subsys_state___7 * (*css_alloc)(struct cgroup_subsys_state___7 *);
	int (*css_online)(struct cgroup_subsys_state___7 *);
	void (*css_offline)(struct cgroup_subsys_state___7 *);
	void (*css_released)(struct cgroup_subsys_state___7 *);
	void (*css_free)(struct cgroup_subsys_state___7 *);
	void (*css_reset)(struct cgroup_subsys_state___7 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___7 *, int);
	int (*css_extra_stat_show)(struct seq_file___15 *, struct cgroup_subsys_state___7 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___14 *);
	void (*cancel_fork)(struct task_struct___14 *);
	void (*fork)(struct task_struct___14 *);
	void (*exit)(struct task_struct___14 *);
	void (*free)(struct task_struct___14 *);
	void (*bind)(struct cgroup_subsys_state___7 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___7 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___7 *dfl_cftypes;
	struct cftype___7 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___7 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___7 *updated_children;
	struct cgroup___7 *updated_next;
};

struct cgroup_root___7 {
	struct kernfs_root___12 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___7 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___7 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___7 *ss;
	struct list_head node;
	struct kernfs_ops___12 *kf_ops;
	int (*open)(struct kernfs_open_file___12 *);
	void (*release)(struct kernfs_open_file___12 *);
	u64 (*read_u64)(struct cgroup_subsys_state___7 *, struct cftype___7 *);
	s64 (*read_s64)(struct cgroup_subsys_state___7 *, struct cftype___7 *);
	int (*seq_show)(struct seq_file___15 *, void *);
	void * (*seq_start)(struct seq_file___15 *, loff_t *);
	void * (*seq_next)(struct seq_file___15 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___15 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___7 *, struct cftype___7 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___7 *, struct cftype___7 *, s64);
	ssize_t (*write)(struct kernfs_open_file___12 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___12 *, struct poll_table_struct___10 *);
};

struct bdi_writeback_congested___5 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___5 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___5 {
	struct bio___5 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___5 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___5 bip_inline_vecs[0];
};

struct blkcg___3;

struct blkg_policy_data___3;

struct blkcg_gq___3 {
	struct request_queue___6 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___3 *blkcg;
	struct bdi_writeback_congested___5 *wb_congested;
	struct blkcg_gq___3 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_rwstat stat_bytes;
	struct blkg_rwstat stat_ios;
	struct blkg_policy_data___3 *pd[5];
	struct callback_head callback_head;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
};

struct mem_cgroup_reclaim_iter___4 {
	struct mem_cgroup___4 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___4 {
	struct lruvec___12 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___4 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___4 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct dev_pm_ops___12;

struct device_type___12 {
	const char *name;
	const struct attribute_group___12 **groups;
	int (*uevent)(struct device___13 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___13 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___13 *);
	const struct dev_pm_ops___12 *pm;
};

struct class___12 {
	const char *name;
	struct module___14 *owner;
	const struct attribute_group___12 **class_groups;
	const struct attribute_group___12 **dev_groups;
	struct kobject___12 *dev_kobj;
	int (*dev_uevent)(struct device___13 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___13 *, umode_t *);
	void (*class_release)(struct class___12 *);
	void (*dev_release)(struct device___13 *);
	int (*shutdown_pre)(struct device___13 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___13 *);
	const struct dev_pm_ops___12 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct bin_attribute___12;

struct attribute_group___12 {
	const char *name;
	umode_t (*is_visible)(struct kobject___12 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___12 *, struct bin_attribute___12 *, int);
	struct attribute **attrs;
	struct bin_attribute___12 **bin_attrs;
};

struct bin_attribute___12 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___13 *, struct kobject___12 *, struct bin_attribute___12 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___13 *, struct kobject___12 *, struct bin_attribute___12 *, char *, loff_t, size_t);
	int (*mmap)(struct file___13 *, struct kobject___12 *, struct bin_attribute___12 *, struct vm_area_struct___14 *);
};

struct sysfs_ops___12 {
	ssize_t (*show)(struct kobject___12 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___12 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___12;

struct kset___12 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___12 kobj;
	const struct kset_uevent_ops___12 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___12 {
	void (*release)(struct kobject___12 *);
	const struct sysfs_ops___12 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___12 *);
	const void * (*namespace)(struct kobject___12 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___12 {
	int (* const filter)(struct kset___12 *, struct kobject___12 *);
	const char * (* const name)(struct kset___12 *, struct kobject___12 *);
	int (* const uevent)(struct kset___12 *, struct kobject___12 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___12 {
	int (*prepare)(struct device___13 *);
	void (*complete)(struct device___13 *);
	int (*suspend)(struct device___13 *);
	int (*resume)(struct device___13 *);
	int (*freeze)(struct device___13 *);
	int (*thaw)(struct device___13 *);
	int (*poweroff)(struct device___13 *);
	int (*restore)(struct device___13 *);
	int (*suspend_late)(struct device___13 *);
	int (*resume_early)(struct device___13 *);
	int (*freeze_late)(struct device___13 *);
	int (*thaw_early)(struct device___13 *);
	int (*poweroff_late)(struct device___13 *);
	int (*restore_early)(struct device___13 *);
	int (*suspend_noirq)(struct device___13 *);
	int (*resume_noirq)(struct device___13 *);
	int (*freeze_noirq)(struct device___13 *);
	int (*thaw_noirq)(struct device___13 *);
	int (*poweroff_noirq)(struct device___13 *);
	int (*restore_noirq)(struct device___13 *);
	int (*runtime_suspend)(struct device___13 *);
	int (*runtime_resume)(struct device___13 *);
	int (*runtime_idle)(struct device___13 *);
};

struct dev_pm_domain___12 {
	struct dev_pm_ops___12 ops;
	void (*detach)(struct device___13 *, bool);
	int (*activate)(struct device___13 *);
	void (*sync)(struct device___13 *);
	void (*dismiss)(struct device___13 *);
};

struct bus_type___12 {
	const char *name;
	const char *dev_name;
	struct device___13 *dev_root;
	const struct attribute_group___12 **bus_groups;
	const struct attribute_group___12 **dev_groups;
	const struct attribute_group___12 **drv_groups;
	int (*match)(struct device___13 *, struct device_driver___12 *);
	int (*uevent)(struct device___13 *, struct kobj_uevent_env *);
	int (*probe)(struct device___13 *);
	int (*remove)(struct device___13 *);
	void (*shutdown)(struct device___13 *);
	int (*online)(struct device___13 *);
	int (*offline)(struct device___13 *);
	int (*suspend)(struct device___13 *, pm_message_t);
	int (*resume)(struct device___13 *);
	int (*num_vf)(struct device___13 *);
	int (*dma_configure)(struct device___13 *);
	const struct dev_pm_ops___12 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___12 {
	const char *name;
	struct bus_type___12 *bus;
	struct module___14 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___13 *);
	int (*remove)(struct device___13 *);
	void (*shutdown)(struct device___13 *);
	int (*suspend)(struct device___13 *, pm_message_t);
	int (*resume)(struct device___13 *);
	const struct attribute_group___12 **groups;
	const struct dev_pm_ops___12 *pm;
	void (*coredump)(struct device___13 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct fwnode_operations___10;

struct fwnode_handle___10 {
	struct fwnode_handle___10 *secondary;
	const struct fwnode_operations___10 *ops;
};

struct disk_part_tbl___5 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___5 *last_lookup;
	struct hd_struct___5 *part[0];
};

struct block_device_operations___5 {
	int (*open)(struct block_device___13 *, fmode_t);
	void (*release)(struct gendisk___5 *, fmode_t);
	int (*rw_page)(struct block_device___13 *, sector_t, struct page___14 *, unsigned int);
	int (*ioctl)(struct block_device___13 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___13 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___5 *, unsigned int);
	int (*media_changed)(struct gendisk___5 *);
	void (*unlock_native_capacity)(struct gendisk___5 *);
	int (*revalidate_disk)(struct gendisk___5 *);
	int (*getgeo)(struct block_device___13 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___13 *, long unsigned int);
	int (*report_zones)(struct gendisk___5 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___14 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___5 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___6 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___6 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___5(struct request___6 *, blk_status_t);

struct request___6 {
	struct request_queue___6 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___5 *bio;
	struct bio___5 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___5 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___5 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___5 *saved_end_io;
		} flush;
	};
	struct gendisk___5 *rq_disk;
	struct hd_struct___5 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___5 *end_io;
	void *end_io_data;
	struct request___6 *next_rq;
};

struct fwnode_reference_args___10;

struct fwnode_endpoint___10;

struct fwnode_operations___10 {
	struct fwnode_handle___10 * (*get)(struct fwnode_handle___10 *);
	void (*put)(struct fwnode_handle___10 *);
	bool (*device_is_available)(const struct fwnode_handle___10 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___10 *, const struct device___13 *);
	bool (*property_present)(const struct fwnode_handle___10 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___10 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___10 *, const char *, const char **, size_t);
	struct fwnode_handle___10 * (*get_parent)(const struct fwnode_handle___10 *);
	struct fwnode_handle___10 * (*get_next_child_node)(const struct fwnode_handle___10 *, struct fwnode_handle___10 *);
	struct fwnode_handle___10 * (*get_named_child_node)(const struct fwnode_handle___10 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___10 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___10 *);
	struct fwnode_handle___10 * (*graph_get_next_endpoint)(const struct fwnode_handle___10 *, struct fwnode_handle___10 *);
	struct fwnode_handle___10 * (*graph_get_remote_endpoint)(const struct fwnode_handle___10 *);
	struct fwnode_handle___10 * (*graph_get_port_parent)(struct fwnode_handle___10 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___10 *, struct fwnode_endpoint___10 *);
};

struct fwnode_endpoint___10 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___10 *local_fwnode;
};

struct fwnode_reference_args___10 {
	struct fwnode_handle___10 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct elevator_type___5;

struct elevator_mq_ops___5 {
	int (*init_sched)(struct request_queue___6 *, struct elevator_type___5 *);
	void (*exit_sched)(struct elevator_queue___5 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	bool (*allow_merge)(struct request_queue___6 *, struct request___6 *, struct bio___5 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx *, struct bio___5 *);
	int (*request_merge)(struct request_queue___6 *, struct request___6 **, struct bio___5 *);
	void (*request_merged)(struct request_queue___6 *, struct request___6 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___6 *, struct request___6 *, struct request___6 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___6 *, struct bio___5 *);
	void (*finish_request)(struct request___6 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___6 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___6 *, u64);
	void (*started_request)(struct request___6 *);
	void (*requeue_request)(struct request___6 *);
	struct request___6 * (*former_request)(struct request_queue___6 *, struct request___6 *);
	struct request___6 * (*next_request)(struct request_queue___6 *, struct request___6 *);
	void (*init_icq)(struct io_cq___5 *);
	void (*exit_icq)(struct io_cq___5 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___5;

struct elevator_type___5 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___5 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___5 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___14 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___5 {
	struct elevator_type___5 *type;
	void *elevator_data;
	struct kobject___12 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___5 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___5 *, char *);
	ssize_t (*store)(struct elevator_queue___5 *, const char *, size_t);
};

struct blkcg_policy_data___3;

struct blkcg___3 {
	struct cgroup_subsys_state___7 css;
	spinlock_t lock;
	struct xarray blkg_tree;
	struct blkcg_gq___3 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___3 *cpd[5];
	struct list_head all_blkcgs_node;
	struct list_head cgwb_list;
	refcount_t cgwb_refcnt;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct blkcg_policy_data___3 {
	struct blkcg___3 *blkcg;
	int plid;
};

struct blkg_policy_data___3 {
	struct blkcg_gq___3 *blkg;
	int plid;
};

struct kernel_param_ops___11 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___11 *);
	int (*get)(char *, const struct kernel_param___11 *);
	void (*free)(void *);
};

struct kparam_array___11;

struct kernel_param___11 {
	const char *name;
	struct module___14 *mod;
	const struct kernel_param_ops___11 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___11 *arr;
	};
};

struct kparam_array___11 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___11 *ops;
	void *elem;
};

struct module_attribute___11 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___11 *, struct module_kobject___11 *, char *);
	ssize_t (*store)(struct module_attribute___11 *, struct module_kobject___11 *, const char *, size_t);
	void (*setup)(struct module___14 *, const char *);
	int (*test)(struct module___14 *);
	void (*free)(struct module___14 *);
};

struct trace_event_class___7;

struct trace_event_call___8 {
	struct list_head list;
	struct trace_event_class___7 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array *prog_array;
	int (*perf_perm)(struct trace_event_call___8 *, struct perf_event___7 *);
};

struct node___11 {
	struct device___13 dev;
};

struct perf_cpu_context___7;

struct pmu___7 {
	struct list_head entry;
	struct module___14 *module;
	struct device___13 *dev;
	const struct attribute_group___12 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___7 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___7 *);
	void (*pmu_disable)(struct pmu___7 *);
	int (*event_init)(struct perf_event___7 *);
	void (*event_mapped)(struct perf_event___7 *, struct mm_struct___13 *);
	void (*event_unmapped)(struct perf_event___7 *, struct mm_struct___13 *);
	int (*add)(struct perf_event___7 *, int);
	void (*del)(struct perf_event___7 *, int);
	void (*start)(struct perf_event___7 *, int);
	void (*stop)(struct perf_event___7 *, int);
	void (*read)(struct perf_event___7 *);
	void (*start_txn)(struct pmu___7 *, unsigned int);
	int (*commit_txn)(struct pmu___7 *);
	void (*cancel_txn)(struct pmu___7 *);
	int (*event_idx)(struct perf_event___7 *);
	void (*sched_task)(struct perf_event_context___8 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___7 *);
	int (*filter_match)(struct perf_event___7 *);
	int (*check_period)(struct perf_event___7 *, u64);
};

struct perf_cpu_context___7 {
	struct perf_event_context___8 ctx;
	struct perf_event_context___8 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___7 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___7 {
	struct cgroup_subsys_state___7 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___7 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___8 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___8 *);
	struct list_head * (*get_fields)(struct trace_event_call___8 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___8 *);
};

struct syscall_metadata {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___8 *enter_event;
	struct trace_event_call___8 *exit_event;
};

struct ucontext {
	long unsigned int uc_flags;
	struct ucontext *uc_link;
	stack_t uc_stack;
	sigset_t uc_sigmask;
	__u8 __unused[120];
	long: 64;
	struct sigcontext uc_mcontext;
};

struct rt_sigframe {
	struct siginfo info;
	struct ucontext uc;
};

struct frame_record {
	u64 fp;
	u64 lr;
};

struct rt_sigframe_user_layout {
	struct rt_sigframe *sigframe;
	struct frame_record *next_frame;
	long unsigned int size;
	long unsigned int limit;
	long unsigned int fpsimd_offset;
	long unsigned int esr_offset;
	long unsigned int sve_offset;
	long unsigned int extra_offset;
	long unsigned int end_offset;
};

struct user_ctxs {
	struct fpsimd_context *fpsimd;
	struct sve_context *sve;
};

typedef __kernel_long_t __kernel_off_t;

typedef __kernel_off_t off_t;

enum {
	PER_LINUX = 0,
	PER_LINUX_32BIT = 8388608,
	PER_LINUX_FDPIC = 524288,
	PER_SVR4 = 68157441,
	PER_SVR3 = 83886082,
	PER_SCOSVR3 = 117440515,
	PER_OSR5 = 100663299,
	PER_WYSEV386 = 83886084,
	PER_ISCR4 = 67108869,
	PER_BSD = 6,
	PER_SUNOS = 67108870,
	PER_XENIX = 83886087,
	PER_LINUX32 = 8,
	PER_LINUX32_3GB = 134217736,
	PER_IRIX32 = 67108873,
	PER_IRIXN32 = 67108874,
	PER_IRIX64 = 67108875,
	PER_RISCOS = 12,
	PER_SOLARIS = 67108877,
	PER_UW7 = 68157454,
	PER_OSF4 = 15,
	PER_HPUX = 16,
	PER_MASK = 255,
};

struct syscall_metadata___2 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___4 *enter_event;
	struct trace_event_call___4 *exit_event;
};

struct stack_trace_data {
	struct stack_trace *trace;
	unsigned int no_sched_functions;
	unsigned int skip;
};

struct clock_event_device___3;

struct arch_timer_erratum_workaround___3 {
	enum arch_timer_erratum_match_type match_type;
	const void *id;
	const char *desc;
	u32 (*read_cntp_tval_el0)();
	u32 (*read_cntv_tval_el0)();
	u64 (*read_cntpct_el0)();
	u64 (*read_cntvct_el0)();
	int (*set_next_event_phys)(long unsigned int, struct clock_event_device___3 *);
	int (*set_next_event_virt)(long unsigned int, struct clock_event_device___3 *);
};

struct clock_event_device___3 {
	void (*event_handler)(struct clock_event_device___3 *);
	int (*set_next_event)(long unsigned int, struct clock_event_device___3 *);
	int (*set_next_ktime)(ktime_t, struct clock_event_device___3 *);
	ktime_t next_event;
	u64 max_delta_ns;
	u64 min_delta_ns;
	u32 mult;
	u32 shift;
	enum clock_event_state state_use_accessors;
	unsigned int features;
	long unsigned int retries;
	int (*set_state_periodic)(struct clock_event_device___3 *);
	int (*set_state_oneshot)(struct clock_event_device___3 *);
	int (*set_state_oneshot_stopped)(struct clock_event_device___3 *);
	int (*set_state_shutdown)(struct clock_event_device___3 *);
	int (*tick_resume)(struct clock_event_device___3 *);
	void (*broadcast)(const struct cpumask *);
	void (*suspend)(struct clock_event_device___3 *);
	void (*resume)(struct clock_event_device___3 *);
	long unsigned int min_delta_ticks;
	long unsigned int max_delta_ticks;
	const char *name;
	int rating;
	int irq;
	int bound_on;
	const struct cpumask *cpumask;
	struct list_head list;
	struct module___11 *owner;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct property___4 {
	char *name;
	int length;
	void *value;
	struct property___4 *next;
	long unsigned int _flags;
	struct bin_attribute___11 attr;
};

struct device_node___2 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___9 fwnode;
	struct property___4 *properties;
	struct property___4 *deadprops;
	struct device_node___2 *parent;
	struct device_node___2 *child;
	struct device_node___2 *sibling;
	struct kobject___11 kobj;
	long unsigned int _flags;
	void *data;
};

struct irq_chip___2;

struct irq_data___2 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data *common;
	struct irq_chip___2 *chip;
	struct irq_domain *domain;
	struct irq_data___2 *parent_data;
	void *chip_data;
};

struct irq_chip___2 {
	struct device___12 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___2 *);
	void (*irq_shutdown)(struct irq_data___2 *);
	void (*irq_enable)(struct irq_data___2 *);
	void (*irq_disable)(struct irq_data___2 *);
	void (*irq_ack)(struct irq_data___2 *);
	void (*irq_mask)(struct irq_data___2 *);
	void (*irq_mask_ack)(struct irq_data___2 *);
	void (*irq_unmask)(struct irq_data___2 *);
	void (*irq_eoi)(struct irq_data___2 *);
	int (*irq_set_affinity)(struct irq_data___2 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___2 *);
	int (*irq_set_type)(struct irq_data___2 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___2 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___2 *);
	void (*irq_bus_sync_unlock)(struct irq_data___2 *);
	void (*irq_cpu_online)(struct irq_data___2 *);
	void (*irq_cpu_offline)(struct irq_data___2 *);
	void (*irq_suspend)(struct irq_data___2 *);
	void (*irq_resume)(struct irq_data___2 *);
	void (*irq_pm_shutdown)(struct irq_data___2 *);
	void (*irq_calc_mask)(struct irq_data___2 *);
	void (*irq_print_chip)(struct irq_data___2 *, struct seq_file___14 *);
	int (*irq_request_resources)(struct irq_data___2 *);
	void (*irq_release_resources)(struct irq_data___2 *);
	void (*irq_compose_msi_msg)(struct irq_data___2 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___2 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___2 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___2 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___2 *, void *);
	void (*ipi_send_single)(struct irq_data___2 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___2 *, const struct cpumask *);
	long unsigned int flags;
};

struct clk_hw;

struct clk_rate_request {
	long unsigned int rate;
	long unsigned int min_rate;
	long unsigned int max_rate;
	long unsigned int best_parent_rate;
	struct clk_hw *best_parent_hw;
};

struct clk_core;

struct clk;

struct clk_init_data;

struct clk_hw {
	struct clk_core *core;
	struct clk *clk;
	const struct clk_init_data *init;
};

struct clk_ops {
	int (*prepare)(struct clk_hw *);
	void (*unprepare)(struct clk_hw *);
	int (*is_prepared)(struct clk_hw *);
	void (*unprepare_unused)(struct clk_hw *);
	int (*enable)(struct clk_hw *);
	void (*disable)(struct clk_hw *);
	int (*is_enabled)(struct clk_hw *);
	void (*disable_unused)(struct clk_hw *);
	long unsigned int (*recalc_rate)(struct clk_hw *, long unsigned int);
	long int (*round_rate)(struct clk_hw *, long unsigned int, long unsigned int *);
	int (*determine_rate)(struct clk_hw *, struct clk_rate_request *);
	int (*set_parent)(struct clk_hw *, u8);
	u8 (*get_parent)(struct clk_hw *);
	int (*set_rate)(struct clk_hw *, long unsigned int, long unsigned int);
	int (*set_rate_and_parent)(struct clk_hw *, long unsigned int, long unsigned int, u8);
	long unsigned int (*recalc_accuracy)(struct clk_hw *, long unsigned int);
	int (*get_phase)(struct clk_hw *);
	int (*set_phase)(struct clk_hw *, int);
	void (*init)(struct clk_hw *);
	void (*debug_init)(struct clk_hw *, struct dentry___13 *);
};

struct clk_init_data {
	const char *name;
	const struct clk_ops *ops;
	const char * const *parent_names;
	u8 num_parents;
	long unsigned int flags;
};

struct module___15;

struct file___14;

struct kiocb___14;

struct poll_table_struct___11;

struct vm_area_struct___15;

struct inode___16;

struct file_lock___14;

struct page___15;

struct seq_file___16;

struct file_operations___14 {
	struct module___15 *owner;
	loff_t (*llseek)(struct file___14 *, loff_t, int);
	ssize_t (*read)(struct file___14 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___14 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___14 *, struct iov_iter___6 *);
	ssize_t (*write_iter)(struct kiocb___14 *, struct iov_iter___6 *);
	int (*iopoll)(struct kiocb___14 *, bool);
	int (*iterate)(struct file___14 *, struct dir_context *);
	int (*iterate_shared)(struct file___14 *, struct dir_context *);
	__poll_t (*poll)(struct file___14 *, struct poll_table_struct___11 *);
	long int (*unlocked_ioctl)(struct file___14 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___14 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___14 *, struct vm_area_struct___15 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___16 *, struct file___14 *);
	int (*flush)(struct file___14 *, fl_owner_t);
	int (*release)(struct inode___16 *, struct file___14 *);
	int (*fsync)(struct file___14 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___14 *, int);
	int (*lock)(struct file___14 *, int, struct file_lock___14 *);
	ssize_t (*sendpage)(struct file___14 *, struct page___15 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___14 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___14 *, int, struct file_lock___14 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___14 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___14 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___14 *, long int, struct file_lock___14 **, void **);
	long int (*fallocate)(struct file___14 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___16 *, struct file___14 *);
	ssize_t (*copy_file_range)(struct file___14 *, loff_t, struct file___14 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___14 *, loff_t, struct file___14 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___14 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

enum lockdep_ok {
	LOCKDEP_STILL_OK = 0,
	LOCKDEP_NOW_UNRELIABLE = 1,
};

enum bug_trap_type {
	BUG_TRAP_TYPE_NONE = 0,
	BUG_TRAP_TYPE_WARN = 1,
	BUG_TRAP_TYPE_BUG = 2,
};

struct user_struct___2 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___3 *uid_keyring;
	struct key___3 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

enum siginfo_layout {
	SIL_KILL = 0,
	SIL_TIMER = 1,
	SIL_POLL = 2,
	SIL_FAULT = 3,
	SIL_FAULT_MCEERR = 4,
	SIL_FAULT_BNDERR = 5,
	SIL_FAULT_PKUERR = 6,
	SIL_CHLD = 7,
	SIL_RT = 8,
	SIL_SYS = 9,
};

struct vmacache___13 {
	u64 seqnum;
	struct vm_area_struct___15 *vmas[4];
};

struct page_frag___13 {
	struct page___15 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___8;

struct debug_info___8 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___8 *hbp_break[16];
	struct perf_event___8 *hbp_watch[16];
};

struct thread_struct___8 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___8 debug;
	long: 64;
};

struct mm_struct___14;

struct pid___12;

struct nsproxy___13;

struct signal_struct___12;

struct vm_struct___11;

struct task_struct___15 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___15 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___14 *mm;
	struct mm_struct___14 *active_mm;
	struct vmacache___13 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___15 *real_parent;
	struct task_struct___15 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___15 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___12 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___12 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___12 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___2 *ptracer_cred;
	const struct cred___2 *real_cred;
	const struct cred___2 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___13 *nsproxy;
	struct signal_struct___12 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___15 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___2 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___13 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___15 *oom_reaper_list;
	struct vm_struct___11 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___8 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___8 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___15 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___8)(struct perf_event___8 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___8;

struct fasync_struct___13;

struct pid_namespace___12;

struct perf_cgroup___8;

struct perf_event___8 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___8 *group_leader;
	struct pmu___8 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___8 hw;
	struct perf_event_context___2 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___8 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___15 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___13 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___8 *);
	struct callback_head callback_head;
	struct pid_namespace___12 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___8 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___8 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___5 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___8 *cgrp;
	struct list_head sb_list;
};

typedef struct page___15 *pgtable_t___13;

struct address_space___13;

struct dev_pagemap___13;

struct page___15 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___13 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___15 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___13 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___14 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___13 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___13;

struct lruvec___13 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___13 *pgdat;
};

struct zone___13 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___13 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___13 {
	struct zone___13 *zone;
	int zone_idx;
};

struct zonelist___13 {
	struct zoneref___13 _zonerefs[25];
};

struct pglist_data___13 {
	struct zone___13 node_zones[3];
	struct zonelist___13 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___15 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___15 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___13 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___14 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___15 *owner;
};

struct secondary_data___14 {
	void *stack;
	struct task_struct___15 *task;
	long int status;
};

struct blocking_notifier_head___13 {
	struct rw_semaphore___14 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___13;

struct vm_area_struct___15 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___15 *vm_next;
	struct vm_area_struct___15 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___14 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___13 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___14 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___13;

struct mm_struct___14 {
	struct {
		struct vm_area_struct___15 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___14 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___14 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___13 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___15 *owner;
		struct user_namespace___2 *user_ns;
		struct file___14 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___13 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___13;

struct address_space___13 {
	struct inode___16 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___14 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___13 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___13)(struct vm_area_struct___15 *, long unsigned int, const struct page___15 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___13)(struct page___15 *, void *);

struct device___14;

struct dev_pagemap___13 {
	dev_page_fault_t___13 page_fault;
	dev_page_free_t___13 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___14 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct dentry___15;

struct path___13 {
	struct vfsmount *mnt;
	struct dentry___15 *dentry;
};

struct fown_struct___12 {
	rwlock_t lock;
	struct pid___12 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___14 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___13 f_path;
	struct inode___16 *f_inode;
	const struct file_operations___14 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___12 f_owner;
	const struct cred___2 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___13 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___13;

struct vm_operations_struct___13 {
	void (*open)(struct vm_area_struct___15 *);
	void (*close)(struct vm_area_struct___15 *);
	int (*split)(struct vm_area_struct___15 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___15 *);
	vm_fault_t (*fault)(struct vm_fault___13 *);
	vm_fault_t (*huge_fault)(struct vm_fault___13 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___13 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___15 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___13 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___13 *);
	int (*access)(struct vm_area_struct___15 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___15 *);
	int (*set_policy)(struct vm_area_struct___15 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___15 *, long unsigned int);
	struct page___15 * (*find_special_page)(struct vm_area_struct___15 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___13 {
	struct task_struct___15 *task;
	struct core_thread___13 *next;
};

struct core_state___13 {
	atomic_t nr_threads;
	struct core_thread___13 dumper;
	struct completion startup;
};

struct ucounts___9;

struct user_namespace___2 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___2 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common ns;
	long unsigned int flags;
	struct key___3 *persistent_keyring_register;
	struct rw_semaphore___14 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___9 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___13 {
	struct vm_area_struct___15 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___15 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___15 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___13 prealloc_pte;
};

struct upid___12 {
	int nr;
	struct pid_namespace___12 *ns;
};

struct pid_namespace___12 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___15 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___12 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___15 *proc_self;
	struct dentry___15 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___2 *user_ns;
	struct ucounts___9 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common ns;
};

struct pid___12 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___12 numbers[1];
};

struct nsproxy___13 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___12 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct signal_struct___12 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___15 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___15 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___12 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___12 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___14 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___12 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___8;

struct cgroup___8;

struct css_set___2 {
	struct cgroup_subsys_state___8 *subsys[13];
	refcount_t refcount;
	struct css_set___2 *dom_cset;
	struct cgroup___8 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___8 *mg_src_cgrp;
	struct cgroup___8 *mg_dst_cgrp;
	struct css_set___2 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___2 {
	struct pmu___8 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___15 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___2 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___11 {
	struct vm_struct___11 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___15 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___12 {
	struct task_struct___15 task;
	long unsigned int stack[8192];
};

struct kset___13;

struct kobj_type___13;

struct kernfs_node___13;

struct kobject___13 {
	const char *name;
	struct list_head entry;
	struct kobject___13 *parent;
	struct kset___13 *kset;
	struct kobj_type___13 *ktype;
	struct kernfs_node___13 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___13 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___14 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___13;

struct bus_type___13;

struct device_driver___13;

struct dev_pm_domain___13;

struct fwnode_handle___11;

struct class___13;

struct attribute_group___13;

struct device___14 {
	struct device___14 *parent;
	struct device_private *p;
	struct kobject___13 kobj;
	const char *init_name;
	const struct device_type___13 *type;
	struct mutex mutex;
	struct bus_type___13 *bus;
	struct device_driver___13 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___13 power;
	struct dev_pm_domain___13 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___11 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___13 *class;
	const struct attribute_group___13 **groups;
	void (*release)(struct device___14 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___13;

struct super_block___14;

struct dentry___15 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___15 *d_parent;
	struct qstr d_name;
	struct inode___16 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___13 *d_op;
	struct super_block___14 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___13;

struct block_device___14;

struct inode___16 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___13 *i_op;
	struct super_block___14 *i_sb;
	struct address_space___13 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___14 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___14 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___13 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___14 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___13 {
	int (*d_revalidate)(struct dentry___15 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___15 *, unsigned int);
	int (*d_hash)(const struct dentry___15 *, struct qstr *);
	int (*d_compare)(const struct dentry___15 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___15 *);
	int (*d_init)(struct dentry___15 *);
	void (*d_release)(struct dentry___15 *);
	void (*d_prune)(struct dentry___15 *);
	void (*d_iput)(struct dentry___15 *, struct inode___16 *);
	char * (*d_dname)(struct dentry___15 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___13 *);
	int (*d_manage)(const struct path___13 *, bool);
	struct dentry___15 * (*d_real)(struct dentry___15 *, const struct inode___16 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___13;

struct mem_dqinfo___13 {
	struct quota_format_type___13 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___13;

struct quota_info___13 {
	unsigned int flags;
	struct rw_semaphore___14 dqio_sem;
	struct inode___16 *files[3];
	struct mem_dqinfo___13 info[3];
	const struct quota_format_ops___13 *ops[3];
};

struct rcuwait___13 {
	struct task_struct___15 *task;
};

struct percpu_rw_semaphore___13 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___14 rw_sem;
	struct rcuwait___13 writer;
	int readers_block;
};

struct sb_writers___13 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___13 rw_sem[3];
};

struct file_system_type___13;

struct super_operations___13;

struct dquot_operations___13;

struct quotactl_ops___13;

struct super_block___14 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___13 *s_type;
	const struct super_operations___13 *s_op;
	const struct dquot_operations___13 *dq_op;
	const struct quotactl_ops___13 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___15 *s_root;
	struct rw_semaphore___14 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___14 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___13 s_dquot;
	struct sb_writers___13 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___13 *s_d_op;
	int cleancache_poolid;
	struct shrinker___4 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___2 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___14 {
	struct file___14 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___14 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___14 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___14 *ia_file;
};

struct dquot___13 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___14 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___13 {
	int qf_fmt_id;
	const struct quota_format_ops___13 *qf_ops;
	struct module___15 *qf_owner;
	struct quota_format_type___13 *qf_next;
};

struct quota_format_ops___13 {
	int (*check_quota_file)(struct super_block___14 *, int);
	int (*read_file_info)(struct super_block___14 *, int);
	int (*write_file_info)(struct super_block___14 *, int);
	int (*free_file_info)(struct super_block___14 *, int);
	int (*read_dqblk)(struct dquot___13 *);
	int (*commit_dqblk)(struct dquot___13 *);
	int (*release_dqblk)(struct dquot___13 *);
	int (*get_next_id)(struct super_block___14 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___13 {
	int (*write_dquot)(struct dquot___13 *);
	struct dquot___13 * (*alloc_dquot)(struct super_block___14 *, int);
	void (*destroy_dquot)(struct dquot___13 *);
	int (*acquire_dquot)(struct dquot___13 *);
	int (*release_dquot)(struct dquot___13 *);
	int (*mark_dirty)(struct dquot___13 *);
	int (*write_info)(struct super_block___14 *, int);
	qsize_t * (*get_reserved_space)(struct inode___16 *);
	int (*get_projid)(struct inode___16 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___16 *, qsize_t *);
	int (*get_next_id)(struct super_block___14 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___13 {
	int (*quota_on)(struct super_block___14 *, int, int, const struct path___13 *);
	int (*quota_off)(struct super_block___14 *, int);
	int (*quota_enable)(struct super_block___14 *, unsigned int);
	int (*quota_disable)(struct super_block___14 *, unsigned int);
	int (*quota_sync)(struct super_block___14 *, int);
	int (*set_info)(struct super_block___14 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___14 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___14 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___14 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___14 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___14 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___12 {
	struct kobject___13 kobj;
	struct module___15 *mod;
	struct kobject___13 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___12 {
	struct module___15 *mod;
	struct latch_tree_node node;
};

struct module_layout___12 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___12 mtn;
};

struct module_attribute___12;

struct kernel_param___12;

struct module___15 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___12 mkobj;
	struct module_attribute___12 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___13 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___12 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___12 core_layout;
	struct module_layout___12 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___13 {
	int (*writepage)(struct page___15 *, struct writeback_control___3 *);
	int (*readpage)(struct file___14 *, struct page___15 *);
	int (*writepages)(struct address_space___13 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___15 *);
	int (*readpages)(struct file___14 *, struct address_space___13 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___14 *, struct address_space___13 *, loff_t, unsigned int, unsigned int, struct page___15 **, void **);
	int (*write_end)(struct file___14 *, struct address_space___13 *, loff_t, unsigned int, unsigned int, struct page___15 *, void *);
	sector_t (*bmap)(struct address_space___13 *, sector_t);
	void (*invalidatepage)(struct page___15 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___15 *, gfp_t);
	void (*freepage)(struct page___15 *);
	ssize_t (*direct_IO)(struct kiocb___14 *, struct iov_iter___6 *);
	int (*migratepage)(struct address_space___13 *, struct page___15 *, struct page___15 *, enum migrate_mode);
	bool (*isolate_page)(struct page___15 *, isolate_mode_t);
	void (*putback_page)(struct page___15 *);
	int (*launder_page)(struct page___15 *);
	int (*is_partially_uptodate)(struct page___15 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___15 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___13 *, struct page___15 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___14 *, sector_t *);
	void (*swap_deactivate)(struct file___14 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___14 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___16 *bd_inode;
	struct super_block___14 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___14 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___13 {
	struct dentry___15 * (*lookup)(struct inode___16 *, struct dentry___15 *, unsigned int);
	const char * (*get_link)(struct dentry___15 *, struct inode___16 *, struct delayed_call *);
	int (*permission)(struct inode___16 *, int);
	struct posix_acl * (*get_acl)(struct inode___16 *, int);
	int (*readlink)(struct dentry___15 *, char *, int);
	int (*create)(struct inode___16 *, struct dentry___15 *, umode_t, bool);
	int (*link)(struct dentry___15 *, struct inode___16 *, struct dentry___15 *);
	int (*unlink)(struct inode___16 *, struct dentry___15 *);
	int (*symlink)(struct inode___16 *, struct dentry___15 *, const char *);
	int (*mkdir)(struct inode___16 *, struct dentry___15 *, umode_t);
	int (*rmdir)(struct inode___16 *, struct dentry___15 *);
	int (*mknod)(struct inode___16 *, struct dentry___15 *, umode_t, dev_t);
	int (*rename)(struct inode___16 *, struct dentry___15 *, struct inode___16 *, struct dentry___15 *, unsigned int);
	int (*setattr)(struct dentry___15 *, struct iattr___14 *);
	int (*getattr)(const struct path___13 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___15 *, char *, size_t);
	int (*fiemap)(struct inode___16 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___16 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___16 *, struct dentry___15 *, struct file___14 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___16 *, struct dentry___15 *, umode_t);
	int (*set_acl)(struct inode___16 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___13 {
	void (*fl_copy_lock)(struct file_lock___14 *, struct file_lock___14 *);
	void (*fl_release_private)(struct file_lock___14 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___13;

struct file_lock___14 {
	struct file_lock___14 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___14 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___13 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___13 *fl_ops;
	const struct lock_manager_operations___13 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___13 {
	int (*lm_compare_owner)(struct file_lock___14 *, struct file_lock___14 *);
	long unsigned int (*lm_owner_key)(struct file_lock___14 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___14 *);
	int (*lm_grant)(struct file_lock___14 *, int);
	bool (*lm_break)(struct file_lock___14 *);
	int (*lm_change)(struct file_lock___14 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___14 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___13 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___13 *fa_next;
	struct file___14 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___13 {
	const char *name;
	int fs_flags;
	struct dentry___15 * (*mount)(struct file_system_type___13 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___14 *);
	struct module___15 *owner;
	struct file_system_type___13 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___13 {
	struct inode___16 * (*alloc_inode)(struct super_block___14 *);
	void (*destroy_inode)(struct inode___16 *);
	void (*dirty_inode)(struct inode___16 *, int);
	int (*write_inode)(struct inode___16 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___16 *);
	void (*evict_inode)(struct inode___16 *);
	void (*put_super)(struct super_block___14 *);
	int (*sync_fs)(struct super_block___14 *, int);
	int (*freeze_super)(struct super_block___14 *);
	int (*freeze_fs)(struct super_block___14 *);
	int (*thaw_super)(struct super_block___14 *);
	int (*unfreeze_fs)(struct super_block___14 *);
	int (*statfs)(struct dentry___15 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___14 *, int *, char *);
	void (*umount_begin)(struct super_block___14 *);
	int (*show_options)(struct seq_file___16 *, struct dentry___15 *);
	int (*show_devname)(struct seq_file___16 *, struct dentry___15 *);
	int (*show_path)(struct seq_file___16 *, struct dentry___15 *);
	int (*show_stats)(struct seq_file___16 *, struct dentry___15 *);
	ssize_t (*quota_read)(struct super_block___14 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___14 *, int, const char *, size_t, loff_t);
	struct dquot___13 ** (*get_dquots)(struct inode___16 *);
	int (*bdev_try_to_free_page)(struct super_block___14 *, struct page___15 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___14 *, struct shrink_control___4 *);
	long int (*free_cached_objects)(struct super_block___14 *, struct shrink_control___4 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___10)(struct file___14 *, wait_queue_head_t *, struct poll_table_struct___11 *);

struct poll_table_struct___11 {
	poll_queue_proc___10 _qproc;
	__poll_t _key;
};

struct seq_operations___13;

struct seq_file___16 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___13 *op;
	int poll_event;
	const struct file___14 *file;
	void *private;
};

struct kobj_attribute___13 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___13 *, struct kobj_attribute___13 *, char *);
	ssize_t (*store)(struct kobject___13 *, struct kobj_attribute___13 *, const char *, size_t);
};

typedef void compound_page_dtor___13(struct page___15 *);

struct kernfs_root___13;

struct kernfs_elem_dir___13 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___13 *root;
};

struct kernfs_syscall_ops___13;

struct kernfs_root___13 {
	struct kernfs_node___13 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___13 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___13 {
	struct kernfs_node___13 *target_kn;
};

struct kernfs_ops___13;

struct kernfs_elem_attr___13 {
	const struct kernfs_ops___13 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___13 *notify_next;
};

struct kernfs_node___13 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___13 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___13 dir;
		struct kernfs_elem_symlink___13 symlink;
		struct kernfs_elem_attr___13 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___13;

struct kernfs_ops___13 {
	int (*open)(struct kernfs_open_file___13 *);
	void (*release)(struct kernfs_open_file___13 *);
	int (*seq_show)(struct seq_file___16 *, void *);
	void * (*seq_start)(struct seq_file___16 *, loff_t *);
	void * (*seq_next)(struct seq_file___16 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___16 *, void *);
	ssize_t (*read)(struct kernfs_open_file___13 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___13 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___13 *, struct vm_area_struct___15 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___13 *, struct poll_table_struct___11 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___13 {
	int (*remount_fs)(struct kernfs_root___13 *, int *, char *);
	int (*show_options)(struct seq_file___16 *, struct kernfs_root___13 *);
	int (*mkdir)(struct kernfs_node___13 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___13 *);
	int (*rename)(struct kernfs_node___13 *, struct kernfs_node___13 *, const char *);
	int (*show_path)(struct seq_file___16 *, struct kernfs_node___13 *, struct kernfs_root___13 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___13 {
	struct kernfs_node___13 *kn;
	struct file___14 *file;
	struct seq_file___16 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___13 *vm_ops;
};

struct bin_attribute___13;

struct attribute_group___13 {
	const char *name;
	umode_t (*is_visible)(struct kobject___13 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___13 *, struct bin_attribute___13 *, int);
	struct attribute **attrs;
	struct bin_attribute___13 **bin_attrs;
};

struct bin_attribute___13 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___14 *, struct kobject___13 *, struct bin_attribute___13 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___14 *, struct kobject___13 *, struct bin_attribute___13 *, char *, loff_t, size_t);
	int (*mmap)(struct file___14 *, struct kobject___13 *, struct bin_attribute___13 *, struct vm_area_struct___15 *);
};

struct sysfs_ops___13 {
	ssize_t (*show)(struct kobject___13 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___13 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___13;

struct kset___13 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___13 kobj;
	const struct kset_uevent_ops___13 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___13 {
	void (*release)(struct kobject___13 *);
	const struct sysfs_ops___13 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___13 *);
	const void * (*namespace)(struct kobject___13 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___13 {
	int (* const filter)(struct kset___13 *, struct kobject___13 *);
	const char * (* const name)(struct kset___13 *, struct kobject___13 *);
	int (* const uevent)(struct kset___13 *, struct kobject___13 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___12 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___12 *);
	int (*get)(char *, const struct kernel_param___12 *);
	void (*free)(void *);
};

struct kparam_array___12;

struct kernel_param___12 {
	const char *name;
	struct module___15 *mod;
	const struct kernel_param_ops___12 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___12 *arr;
	};
};

struct kparam_array___12 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___12 *ops;
	void *elem;
};

struct module_attribute___12 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___12 *, struct module_kobject___12 *, char *);
	ssize_t (*store)(struct module_attribute___12 *, struct module_kobject___12 *, const char *, size_t);
	void (*setup)(struct module___15 *, const char *);
	int (*test)(struct module___15 *);
	void (*free)(struct module___15 *);
};

struct trace_event_class___8;

struct trace_event_call___5 {
	struct list_head list;
	struct trace_event_class___8 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array *prog_array;
	int (*perf_perm)(struct trace_event_call___5 *, struct perf_event___8 *);
};

enum die_val {
	DIE_UNUSED = 0,
	DIE_OOPS = 1,
};

typedef int (*key_restrict_link_func_t___13)(struct key___3 *, const struct key_type *, const union key_payload *, struct key___3 *);

struct key_restriction___14;

struct key___3 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___14 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___14 *restrict_link;
};

struct key_restriction___14 {
	key_restrict_link_func_t___13 check;
	struct key___3 *key;
	struct key_type *keytype;
};

struct cgroup_namespace___2 {
	refcount_t count;
	struct ns_common ns;
	struct user_namespace___2 *user_ns;
	struct ucounts___9 *ucounts;
	struct css_set___2 *root_cset;
};

struct ucounts___9 {
	struct hlist_node node;
	struct user_namespace___2 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct fwnode_operations___11;

struct fwnode_handle___11 {
	struct fwnode_handle___11 *secondary;
	const struct fwnode_operations___11 *ops;
};

struct fwnode_reference_args___11;

struct fwnode_endpoint___11;

struct fwnode_operations___11 {
	struct fwnode_handle___11 * (*get)(struct fwnode_handle___11 *);
	void (*put)(struct fwnode_handle___11 *);
	bool (*device_is_available)(const struct fwnode_handle___11 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___11 *, const struct device___14 *);
	bool (*property_present)(const struct fwnode_handle___11 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___11 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___11 *, const char *, const char **, size_t);
	struct fwnode_handle___11 * (*get_parent)(const struct fwnode_handle___11 *);
	struct fwnode_handle___11 * (*get_next_child_node)(const struct fwnode_handle___11 *, struct fwnode_handle___11 *);
	struct fwnode_handle___11 * (*get_named_child_node)(const struct fwnode_handle___11 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___11 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___11 *);
	struct fwnode_handle___11 * (*graph_get_next_endpoint)(const struct fwnode_handle___11 *, struct fwnode_handle___11 *);
	struct fwnode_handle___11 * (*graph_get_remote_endpoint)(const struct fwnode_handle___11 *);
	struct fwnode_handle___11 * (*graph_get_port_parent)(struct fwnode_handle___11 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___11 *, struct fwnode_endpoint___11 *);
};

struct fwnode_endpoint___11 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___11 *local_fwnode;
};

struct fwnode_reference_args___11 {
	struct fwnode_handle___11 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct kimage___3;

typedef void *kexec_load_t___3(struct kimage___3 *, char *, long unsigned int, char *, long unsigned int, char *, long unsigned int);

struct kexec_file_ops___3 {
	kexec_probe_t *probe;
	kexec_load_t___3 *load;
	kexec_cleanup_t *cleanup;
};

struct kimage___3 {
	kimage_entry_t head;
	kimage_entry_t *entry;
	kimage_entry_t *last_entry;
	long unsigned int start;
	struct page___15 *control_code_page;
	struct page___15 *swap_page;
	void *vmcoreinfo_data_copy;
	long unsigned int nr_segments;
	struct kexec_segment segment[16];
	struct list_head control_pages;
	struct list_head dest_pages;
	struct list_head unusable_pages;
	long unsigned int control_page;
	unsigned int type: 1;
	unsigned int preserve_context: 1;
	unsigned int file_mode: 1;
	struct kimage_arch arch;
	void *kernel_buf;
	long unsigned int kernel_buf_len;
	void *initrd_buf;
	long unsigned int initrd_buf_len;
	char *cmdline_buf;
	long unsigned int cmdline_buf_len;
	const struct kexec_file_ops___3 *fops;
	void *image_loader_data;
	struct purgatory_info purgatory_info;
};

struct seq_operations___13 {
	void * (*start)(struct seq_file___16 *, loff_t *);
	void (*stop)(struct seq_file___16 *, void *);
	void * (*next)(struct seq_file___16 *, void *, loff_t *);
	int (*show)(struct seq_file___16 *, void *);
};

struct dev_pm_ops___13 {
	int (*prepare)(struct device___14 *);
	void (*complete)(struct device___14 *);
	int (*suspend)(struct device___14 *);
	int (*resume)(struct device___14 *);
	int (*freeze)(struct device___14 *);
	int (*thaw)(struct device___14 *);
	int (*poweroff)(struct device___14 *);
	int (*restore)(struct device___14 *);
	int (*suspend_late)(struct device___14 *);
	int (*resume_early)(struct device___14 *);
	int (*freeze_late)(struct device___14 *);
	int (*thaw_early)(struct device___14 *);
	int (*poweroff_late)(struct device___14 *);
	int (*restore_early)(struct device___14 *);
	int (*suspend_noirq)(struct device___14 *);
	int (*resume_noirq)(struct device___14 *);
	int (*freeze_noirq)(struct device___14 *);
	int (*thaw_noirq)(struct device___14 *);
	int (*poweroff_noirq)(struct device___14 *);
	int (*restore_noirq)(struct device___14 *);
	int (*runtime_suspend)(struct device___14 *);
	int (*runtime_resume)(struct device___14 *);
	int (*runtime_idle)(struct device___14 *);
};

struct dev_pm_domain___13 {
	struct dev_pm_ops___13 ops;
	void (*detach)(struct device___14 *, bool);
	int (*activate)(struct device___14 *);
	void (*sync)(struct device___14 *);
	void (*dismiss)(struct device___14 *);
};

struct bus_type___13 {
	const char *name;
	const char *dev_name;
	struct device___14 *dev_root;
	const struct attribute_group___13 **bus_groups;
	const struct attribute_group___13 **dev_groups;
	const struct attribute_group___13 **drv_groups;
	int (*match)(struct device___14 *, struct device_driver___13 *);
	int (*uevent)(struct device___14 *, struct kobj_uevent_env *);
	int (*probe)(struct device___14 *);
	int (*remove)(struct device___14 *);
	void (*shutdown)(struct device___14 *);
	int (*online)(struct device___14 *);
	int (*offline)(struct device___14 *);
	int (*suspend)(struct device___14 *, pm_message_t);
	int (*resume)(struct device___14 *);
	int (*num_vf)(struct device___14 *);
	int (*dma_configure)(struct device___14 *);
	const struct dev_pm_ops___13 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___13 {
	const char *name;
	struct bus_type___13 *bus;
	struct module___15 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___14 *);
	int (*remove)(struct device___14 *);
	void (*shutdown)(struct device___14 *);
	int (*suspend)(struct device___14 *, pm_message_t);
	int (*resume)(struct device___14 *);
	const struct attribute_group___13 **groups;
	const struct dev_pm_ops___13 *pm;
	void (*coredump)(struct device___14 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___13 {
	const char *name;
	const struct attribute_group___13 **groups;
	int (*uevent)(struct device___14 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___14 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___14 *);
	const struct dev_pm_ops___13 *pm;
};

struct class___13 {
	const char *name;
	struct module___15 *owner;
	const struct attribute_group___13 **class_groups;
	const struct attribute_group___13 **dev_groups;
	struct kobject___13 *dev_kobj;
	int (*dev_uevent)(struct device___14 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___14 *, umode_t *);
	void (*class_release)(struct class___13 *);
	void (*dev_release)(struct device___14 *);
	int (*shutdown_pre)(struct device___14 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___14 *);
	const struct dev_pm_ops___13 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___12 {
	struct device___14 dev;
};

struct bpf_map___8;

struct bpf_map_ops___8 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___8 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___8 *, struct file___14 *);
	void (*map_free)(struct bpf_map___8 *);
	int (*map_get_next_key)(struct bpf_map___8 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___8 *);
	void * (*map_lookup_elem)(struct bpf_map___8 *, void *);
	int (*map_update_elem)(struct bpf_map___8 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___8 *, void *);
	int (*map_push_elem)(struct bpf_map___8 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___8 *, void *);
	int (*map_peek_elem)(struct bpf_map___8 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___8 *, struct file___14 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___8 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___8 *, void *, struct seq_file___16 *);
	int (*map_check_btf)(const struct bpf_map___8 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___8 {
	const struct bpf_map_ops___8 *ops;
	struct bpf_map___8 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___2 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___8;

typedef void (*kthread_work_func_t___8)(struct kthread_work___8 *);

struct kthread_worker___8;

struct kthread_work___8 {
	struct list_head node;
	kthread_work_func_t___8 func;
	struct kthread_worker___8 *worker;
	int canceling;
};

struct kthread_worker___8 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___15 *task;
	struct kthread_work___8 *current_work;
};

struct kthread_delayed_work___8 {
	struct kthread_work___8 work;
	struct timer_list timer;
};

struct psi_group___8 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___8 *poll_kworker;
	struct kthread_delayed_work___8 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___8 {
	struct kernfs_node___13 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___8;

struct cgroup_subsys_state___8 {
	struct cgroup___8 *cgroup;
	struct cgroup_subsys___8 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___8 *parent;
};

struct cgroup_root___8;

struct cgroup_rstat_cpu___8;

struct cgroup___8 {
	struct cgroup_subsys_state___8 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___13 *kn;
	struct cgroup_file___8 procs_file;
	struct cgroup_file___8 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___8 *subsys[13];
	struct cgroup_root___8 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___8 *dom_cgrp;
	struct cgroup_rstat_cpu___8 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf bpf;
	atomic_t congestion_count;
	struct cgroup___8 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___8 psi;
	int ancestor_ids[0];
};

struct cftype___8;

struct cgroup_subsys___8 {
	struct cgroup_subsys_state___8 * (*css_alloc)(struct cgroup_subsys_state___8 *);
	int (*css_online)(struct cgroup_subsys_state___8 *);
	void (*css_offline)(struct cgroup_subsys_state___8 *);
	void (*css_released)(struct cgroup_subsys_state___8 *);
	void (*css_free)(struct cgroup_subsys_state___8 *);
	void (*css_reset)(struct cgroup_subsys_state___8 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___8 *, int);
	int (*css_extra_stat_show)(struct seq_file___16 *, struct cgroup_subsys_state___8 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___15 *);
	void (*cancel_fork)(struct task_struct___15 *);
	void (*fork)(struct task_struct___15 *);
	void (*exit)(struct task_struct___15 *);
	void (*free)(struct task_struct___15 *);
	void (*bind)(struct cgroup_subsys_state___8 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___8 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___8 *dfl_cftypes;
	struct cftype___8 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___8 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___8 *updated_children;
	struct cgroup___8 *updated_next;
};

struct cgroup_root___8 {
	struct kernfs_root___13 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___8 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___8 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___8 *ss;
	struct list_head node;
	struct kernfs_ops___13 *kf_ops;
	int (*open)(struct kernfs_open_file___13 *);
	void (*release)(struct kernfs_open_file___13 *);
	u64 (*read_u64)(struct cgroup_subsys_state___8 *, struct cftype___8 *);
	s64 (*read_s64)(struct cgroup_subsys_state___8 *, struct cftype___8 *);
	int (*seq_show)(struct seq_file___16 *, void *);
	void * (*seq_start)(struct seq_file___16 *, loff_t *);
	void * (*seq_next)(struct seq_file___16 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___16 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___8 *, struct cftype___8 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___8 *, struct cftype___8 *, s64);
	ssize_t (*write)(struct kernfs_open_file___13 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___13 *, struct poll_table_struct___11 *);
};

struct perf_cpu_context___8;

struct pmu___8 {
	struct list_head entry;
	struct module___15 *module;
	struct device___14 *dev;
	const struct attribute_group___13 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___8 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___8 *);
	void (*pmu_disable)(struct pmu___8 *);
	int (*event_init)(struct perf_event___8 *);
	void (*event_mapped)(struct perf_event___8 *, struct mm_struct___14 *);
	void (*event_unmapped)(struct perf_event___8 *, struct mm_struct___14 *);
	int (*add)(struct perf_event___8 *, int);
	void (*del)(struct perf_event___8 *, int);
	void (*start)(struct perf_event___8 *, int);
	void (*stop)(struct perf_event___8 *, int);
	void (*read)(struct perf_event___8 *);
	void (*start_txn)(struct pmu___8 *, unsigned int);
	int (*commit_txn)(struct pmu___8 *);
	void (*cancel_txn)(struct pmu___8 *);
	int (*event_idx)(struct perf_event___8 *);
	void (*sched_task)(struct perf_event_context___2 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___8 *);
	int (*filter_match)(struct perf_event___8 *);
	int (*check_period)(struct perf_event___8 *, u64);
};

struct perf_cpu_context___8 {
	struct perf_event_context___2 ctx;
	struct perf_event_context___2 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___8 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___8 {
	struct cgroup_subsys_state___8 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___8 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___5 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___5 *);
	struct list_head * (*get_fields)(struct trace_event_call___5 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___5 *);
};

struct undef_hook {
	struct list_head node;
	u32 instr_mask;
	u32 instr_val;
	u64 pstate_mask;
	u64 pstate_val;
	int (*fn)(struct pt_regs *, u32);
};

struct sys64_hook {
	unsigned int esr_mask;
	unsigned int esr_val;
	void (*handler)(unsigned int, struct pt_regs *);
};

struct arch_clocksource_data {
	bool vdso_direct;
};

struct clocksource {
	u64 (*read)(struct clocksource *);
	u64 mask;
	u32 mult;
	u32 shift;
	u64 max_idle_ns;
	u32 maxadj;
	struct arch_clocksource_data archdata;
	u64 max_cycles;
	const char *name;
	struct list_head list;
	int rating;
	int (*enable)(struct clocksource *);
	void (*disable)(struct clocksource *);
	long unsigned int flags;
	void (*suspend)(struct clocksource *);
	void (*resume)(struct clocksource *);
	void (*mark_unstable)(struct clocksource *);
	void (*tick_stable)(struct clocksource *);
	struct module___11 *owner;
};

struct vm_special_mapping {
	const char *name;
	struct page___13 **pages;
	vm_fault_t (*fault)(const struct vm_special_mapping *, struct vm_area_struct___13 *, struct vm_fault___11 *);
	int (*mremap)(const struct vm_special_mapping *, struct vm_area_struct___13 *);
};

struct tk_read_base {
	struct clocksource *clock;
	u64 mask;
	u64 cycle_last;
	u32 mult;
	u32 shift;
	u64 xtime_nsec;
	ktime_t base;
	u64 base_real;
};

struct timekeeper {
	struct tk_read_base tkr_mono;
	struct tk_read_base tkr_raw;
	u64 xtime_sec;
	long unsigned int ktime_sec;
	struct timespec64 wall_to_monotonic;
	ktime_t offs_real;
	ktime_t offs_boot;
	ktime_t offs_tai;
	s32 tai_offset;
	unsigned int clock_was_set_seq;
	u8 cs_was_changed_seq;
	ktime_t next_leap_ktime;
	u64 raw_sec;
	u64 cycle_interval;
	u64 xtime_interval;
	s64 xtime_remainder;
	u64 raw_interval;
	u64 ntp_tick;
	s64 ntp_error;
	u32 ntp_error_shift;
	u32 ntp_err_mult;
	u32 skip_second_overflow;
};

struct vdso_data {
	__u64 cs_cycle_last;
	__u64 raw_time_sec;
	__u64 raw_time_nsec;
	__u64 xtime_clock_sec;
	__u64 xtime_clock_nsec;
	__u64 xtime_coarse_sec;
	__u64 xtime_coarse_nsec;
	__u64 wtm_clock_sec;
	__u64 wtm_clock_nsec;
	__u32 tb_seq_count;
	__u32 cs_mono_mult;
	__u32 cs_shift;
	__u32 cs_raw_mult;
	__u32 tz_minuteswest;
	__u32 tz_dsttime;
	__u32 use_syscall;
};

struct linux_binprm___2;

enum aarch64_insn_encoding_class {
	AARCH64_INSN_CLS_UNKNOWN = 0,
	AARCH64_INSN_CLS_DP_IMM = 1,
	AARCH64_INSN_CLS_DP_REG = 2,
	AARCH64_INSN_CLS_DP_FPSIMD = 3,
	AARCH64_INSN_CLS_LDST = 4,
	AARCH64_INSN_CLS_BR_SYS = 5,
};

enum aarch64_insn_hint_op {
	AARCH64_INSN_HINT_NOP = 0,
	AARCH64_INSN_HINT_YIELD = 32,
	AARCH64_INSN_HINT_WFE = 64,
	AARCH64_INSN_HINT_WFI = 96,
	AARCH64_INSN_HINT_SEV = 128,
	AARCH64_INSN_HINT_SEVL = 160,
};

enum aarch64_insn_imm_type {
	AARCH64_INSN_IMM_ADR = 0,
	AARCH64_INSN_IMM_26 = 1,
	AARCH64_INSN_IMM_19 = 2,
	AARCH64_INSN_IMM_16 = 3,
	AARCH64_INSN_IMM_14 = 4,
	AARCH64_INSN_IMM_12 = 5,
	AARCH64_INSN_IMM_9 = 6,
	AARCH64_INSN_IMM_7 = 7,
	AARCH64_INSN_IMM_6 = 8,
	AARCH64_INSN_IMM_S = 9,
	AARCH64_INSN_IMM_R = 10,
	AARCH64_INSN_IMM_N = 11,
	AARCH64_INSN_IMM_MAX = 12,
};

enum aarch64_insn_register_type {
	AARCH64_INSN_REGTYPE_RT = 0,
	AARCH64_INSN_REGTYPE_RN = 1,
	AARCH64_INSN_REGTYPE_RT2 = 2,
	AARCH64_INSN_REGTYPE_RM = 3,
	AARCH64_INSN_REGTYPE_RD = 4,
	AARCH64_INSN_REGTYPE_RA = 5,
	AARCH64_INSN_REGTYPE_RS = 6,
};

enum aarch64_insn_register {
	AARCH64_INSN_REG_0 = 0,
	AARCH64_INSN_REG_1 = 1,
	AARCH64_INSN_REG_2 = 2,
	AARCH64_INSN_REG_3 = 3,
	AARCH64_INSN_REG_4 = 4,
	AARCH64_INSN_REG_5 = 5,
	AARCH64_INSN_REG_6 = 6,
	AARCH64_INSN_REG_7 = 7,
	AARCH64_INSN_REG_8 = 8,
	AARCH64_INSN_REG_9 = 9,
	AARCH64_INSN_REG_10 = 10,
	AARCH64_INSN_REG_11 = 11,
	AARCH64_INSN_REG_12 = 12,
	AARCH64_INSN_REG_13 = 13,
	AARCH64_INSN_REG_14 = 14,
	AARCH64_INSN_REG_15 = 15,
	AARCH64_INSN_REG_16 = 16,
	AARCH64_INSN_REG_17 = 17,
	AARCH64_INSN_REG_18 = 18,
	AARCH64_INSN_REG_19 = 19,
	AARCH64_INSN_REG_20 = 20,
	AARCH64_INSN_REG_21 = 21,
	AARCH64_INSN_REG_22 = 22,
	AARCH64_INSN_REG_23 = 23,
	AARCH64_INSN_REG_24 = 24,
	AARCH64_INSN_REG_25 = 25,
	AARCH64_INSN_REG_26 = 26,
	AARCH64_INSN_REG_27 = 27,
	AARCH64_INSN_REG_28 = 28,
	AARCH64_INSN_REG_29 = 29,
	AARCH64_INSN_REG_FP = 29,
	AARCH64_INSN_REG_30 = 30,
	AARCH64_INSN_REG_LR = 30,
	AARCH64_INSN_REG_ZR = 31,
	AARCH64_INSN_REG_SP = 31,
};

enum aarch64_insn_variant {
	AARCH64_INSN_VARIANT_32BIT = 0,
	AARCH64_INSN_VARIANT_64BIT = 1,
};

enum aarch64_insn_condition {
	AARCH64_INSN_COND_EQ = 0,
	AARCH64_INSN_COND_NE = 1,
	AARCH64_INSN_COND_CS = 2,
	AARCH64_INSN_COND_CC = 3,
	AARCH64_INSN_COND_MI = 4,
	AARCH64_INSN_COND_PL = 5,
	AARCH64_INSN_COND_VS = 6,
	AARCH64_INSN_COND_VC = 7,
	AARCH64_INSN_COND_HI = 8,
	AARCH64_INSN_COND_LS = 9,
	AARCH64_INSN_COND_GE = 10,
	AARCH64_INSN_COND_LT = 11,
	AARCH64_INSN_COND_GT = 12,
	AARCH64_INSN_COND_LE = 13,
	AARCH64_INSN_COND_AL = 14,
};

enum aarch64_insn_branch_type {
	AARCH64_INSN_BRANCH_NOLINK = 0,
	AARCH64_INSN_BRANCH_LINK = 1,
	AARCH64_INSN_BRANCH_RETURN = 2,
	AARCH64_INSN_BRANCH_COMP_ZERO = 3,
	AARCH64_INSN_BRANCH_COMP_NONZERO = 4,
};

enum aarch64_insn_size_type {
	AARCH64_INSN_SIZE_8 = 0,
	AARCH64_INSN_SIZE_16 = 1,
	AARCH64_INSN_SIZE_32 = 2,
	AARCH64_INSN_SIZE_64 = 3,
};

enum aarch64_insn_ldst_type {
	AARCH64_INSN_LDST_LOAD_REG_OFFSET = 0,
	AARCH64_INSN_LDST_STORE_REG_OFFSET = 1,
	AARCH64_INSN_LDST_LOAD_PAIR_PRE_INDEX = 2,
	AARCH64_INSN_LDST_STORE_PAIR_PRE_INDEX = 3,
	AARCH64_INSN_LDST_LOAD_PAIR_POST_INDEX = 4,
	AARCH64_INSN_LDST_STORE_PAIR_POST_INDEX = 5,
	AARCH64_INSN_LDST_LOAD_EX = 6,
	AARCH64_INSN_LDST_STORE_EX = 7,
};

enum aarch64_insn_adsb_type {
	AARCH64_INSN_ADSB_ADD = 0,
	AARCH64_INSN_ADSB_SUB = 1,
	AARCH64_INSN_ADSB_ADD_SETFLAGS = 2,
	AARCH64_INSN_ADSB_SUB_SETFLAGS = 3,
};

enum aarch64_insn_movewide_type {
	AARCH64_INSN_MOVEWIDE_ZERO = 0,
	AARCH64_INSN_MOVEWIDE_KEEP = 1,
	AARCH64_INSN_MOVEWIDE_INVERSE = 2,
};

enum aarch64_insn_bitfield_type {
	AARCH64_INSN_BITFIELD_MOVE = 0,
	AARCH64_INSN_BITFIELD_MOVE_UNSIGNED = 1,
	AARCH64_INSN_BITFIELD_MOVE_SIGNED = 2,
};

enum aarch64_insn_data1_type {
	AARCH64_INSN_DATA1_REVERSE_16 = 0,
	AARCH64_INSN_DATA1_REVERSE_32 = 1,
	AARCH64_INSN_DATA1_REVERSE_64 = 2,
};

enum aarch64_insn_data2_type {
	AARCH64_INSN_DATA2_UDIV = 0,
	AARCH64_INSN_DATA2_SDIV = 1,
	AARCH64_INSN_DATA2_LSLV = 2,
	AARCH64_INSN_DATA2_LSRV = 3,
	AARCH64_INSN_DATA2_ASRV = 4,
	AARCH64_INSN_DATA2_RORV = 5,
};

enum aarch64_insn_data3_type {
	AARCH64_INSN_DATA3_MADD = 0,
	AARCH64_INSN_DATA3_MSUB = 1,
};

enum aarch64_insn_logic_type {
	AARCH64_INSN_LOGIC_AND = 0,
	AARCH64_INSN_LOGIC_BIC = 1,
	AARCH64_INSN_LOGIC_ORR = 2,
	AARCH64_INSN_LOGIC_ORN = 3,
	AARCH64_INSN_LOGIC_EOR = 4,
	AARCH64_INSN_LOGIC_EON = 5,
	AARCH64_INSN_LOGIC_AND_SETFLAGS = 6,
	AARCH64_INSN_LOGIC_BIC_SETFLAGS = 7,
};

enum aarch64_insn_prfm_type {
	AARCH64_INSN_PRFM_TYPE_PLD = 0,
	AARCH64_INSN_PRFM_TYPE_PLI = 1,
	AARCH64_INSN_PRFM_TYPE_PST = 2,
};

enum aarch64_insn_prfm_target {
	AARCH64_INSN_PRFM_TARGET_L1 = 0,
	AARCH64_INSN_PRFM_TARGET_L2 = 1,
	AARCH64_INSN_PRFM_TARGET_L3 = 2,
};

enum aarch64_insn_prfm_policy {
	AARCH64_INSN_PRFM_POLICY_KEEP = 0,
	AARCH64_INSN_PRFM_POLICY_STRM = 1,
};

struct file___15;

struct kiocb___15;

struct vm_area_struct___16;

struct inode___17;

struct file_lock___15;

struct page___16;

struct file_operations___15 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___15 *, loff_t, int);
	ssize_t (*read)(struct file___15 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___15 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___15 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___15 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___15 *, bool);
	int (*iterate)(struct file___15 *, struct dir_context *);
	int (*iterate_shared)(struct file___15 *, struct dir_context *);
	__poll_t (*poll)(struct file___15 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___15 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___15 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___15 *, struct vm_area_struct___16 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___17 *, struct file___15 *);
	int (*flush)(struct file___15 *, fl_owner_t);
	int (*release)(struct inode___17 *, struct file___15 *);
	int (*fsync)(struct file___15 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___15 *, int);
	int (*lock)(struct file___15 *, int, struct file_lock___15 *);
	ssize_t (*sendpage)(struct file___15 *, struct page___16 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___15 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___15 *, int, struct file_lock___15 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___15 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___15 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___15 *, long int, struct file_lock___15 **, void **);
	long int (*fallocate)(struct file___15 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___15 *);
	ssize_t (*copy_file_range)(struct file___15 *, loff_t, struct file___15 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___15 *, loff_t, struct file___15 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___15 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___14 {
	u64 seqnum;
	struct vm_area_struct___16 *vmas[4];
};

struct page_frag___14 {
	struct page___16 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___15;

struct pid___13;

struct cred___14;

struct nsproxy___14;

struct signal_struct___13;

struct task_struct___16 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___16 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___15 *mm;
	struct mm_struct___15 *active_mm;
	struct vmacache___14 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___16 *real_parent;
	struct task_struct___16 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___16 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___13 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___13 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___13 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___14 *ptracer_cred;
	const struct cred___14 *real_cred;
	const struct cred___14 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___14 *nsproxy;
	struct signal_struct___13 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___16 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___2 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___14 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___16 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___8 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___16 *pgtable_t___14;

struct address_space___14;

struct dev_pagemap___14;

struct page___16 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___14 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___16 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___14 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___15 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___14 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___14;

struct lruvec___14 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___14 *pgdat;
};

struct zone___14 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___14 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___14 {
	struct zone___14 *zone;
	int zone_idx;
};

struct zonelist___14 {
	struct zoneref___14 _zonerefs[25];
};

struct pglist_data___14 {
	struct zone___14 node_zones[3];
	struct zonelist___14 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___16 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___16 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___14 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___15 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___16 *owner;
};

struct secondary_data___15 {
	void *stack;
	struct task_struct___16 *task;
	long int status;
};

struct blocking_notifier_head___14 {
	struct rw_semaphore___15 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___14;

struct vm_area_struct___16 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___16 *vm_next;
	struct vm_area_struct___16 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___15 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___14 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___15 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___14;

struct mm_struct___15 {
	struct {
		struct vm_area_struct___16 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___15 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___15 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___14 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___16 *owner;
		struct user_namespace___3 *user_ns;
		struct file___15 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___14 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___14;

struct address_space___14 {
	struct inode___17 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___15 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___14 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___14)(struct vm_area_struct___16 *, long unsigned int, const struct page___16 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___14)(struct page___16 *, void *);

struct device___15;

struct dev_pagemap___14 {
	dev_page_fault_t___14 page_fault;
	dev_page_free_t___14 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___15 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct dentry___16;

struct path___14 {
	struct vfsmount *mnt;
	struct dentry___16 *dentry;
};

struct fown_struct___13 {
	rwlock_t lock;
	struct pid___13 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___15 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___14 f_path;
	struct inode___17 *f_inode;
	const struct file_operations___15 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___13 f_owner;
	const struct cred___14 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___14 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___14;

struct vm_operations_struct___14 {
	void (*open)(struct vm_area_struct___16 *);
	void (*close)(struct vm_area_struct___16 *);
	int (*split)(struct vm_area_struct___16 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___16 *);
	vm_fault_t (*fault)(struct vm_fault___14 *);
	vm_fault_t (*huge_fault)(struct vm_fault___14 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___14 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___16 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___14 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___14 *);
	int (*access)(struct vm_area_struct___16 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___16 *);
	int (*set_policy)(struct vm_area_struct___16 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___16 *, long unsigned int);
	struct page___16 * (*find_special_page)(struct vm_area_struct___16 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___14 {
	struct task_struct___16 *task;
	struct core_thread___14 *next;
};

struct core_state___14 {
	atomic_t nr_threads;
	struct core_thread___14 dumper;
	struct completion startup;
};

struct vm_fault___14 {
	struct vm_area_struct___16 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___16 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___16 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___14 prealloc_pte;
};

struct pid_namespace___13;

struct upid___13 {
	int nr;
	struct pid_namespace___13 *ns;
};

struct pid_namespace___13 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___16 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___13 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___16 *proc_self;
	struct dentry___16 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___3 *user_ns;
	struct ucounts___2 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common ns;
};

struct pid___13 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___13 numbers[1];
};

struct key___15;

struct user_struct___14 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___15 *uid_keyring;
	struct key___15 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___14 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___15 *session_keyring;
	struct key___15 *process_keyring;
	struct key___15 *thread_keyring;
	struct key___15 *request_key_auth;
	void *security;
	struct user_struct___14 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct nsproxy___14 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___13 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct signal_struct___13 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___16 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___16 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___13 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___13 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___15 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___13 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

union thread_union___13 {
	struct task_struct___16 task;
	long unsigned int stack[8192];
};

enum fixed_addresses {
	FIX_HOLE = 0,
	FIX_FDT_END = 1,
	FIX_FDT = 64,
	FIX_EARLYCON_MEM_BASE = 65,
	FIX_TEXT_POKE0 = 66,
	FIX_APEI_GHES_IRQ = 67,
	FIX_APEI_GHES_NMI = 68,
	FIX_ENTRY_TRAMP_DATA = 69,
	FIX_ENTRY_TRAMP_TEXT = 70,
	__end_of_permanent_fixed_addresses = 71,
	FIX_BTMAP_END = 71,
	FIX_BTMAP_BEGIN = 98,
	FIX_PTE = 99,
	FIX_PMD = 100,
	FIX_PUD = 101,
	FIX_PGD = 102,
	__end_of_fixed_addresses = 103,
};

struct kset___14;

struct kobj_type___14;

struct kernfs_node___14;

struct kobject___14 {
	const char *name;
	struct list_head entry;
	struct kobject___14 *parent;
	struct kset___14 *kset;
	struct kobj_type___14 *ktype;
	struct kernfs_node___14 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___14 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___15 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___14;

struct bus_type___14;

struct device_driver___14;

struct dev_pm_domain___14;

struct class___14;

struct attribute_group___14;

struct device___15 {
	struct device___15 *parent;
	struct device_private *p;
	struct kobject___14 kobj;
	const char *init_name;
	const struct device_type___14 *type;
	struct mutex mutex;
	struct bus_type___14 *bus;
	struct device_driver___14 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___14 power;
	struct dev_pm_domain___14 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___14 *class;
	const struct attribute_group___14 **groups;
	void (*release)(struct device___15 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___14;

struct super_block___15;

struct dentry___16 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___16 *d_parent;
	struct qstr d_name;
	struct inode___17 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___14 *d_op;
	struct super_block___15 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___14;

struct block_device___15;

struct inode___17 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___14 *i_op;
	struct super_block___15 *i_sb;
	struct address_space___14 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___15 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___15 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___14 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___15 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___14 {
	int (*d_revalidate)(struct dentry___16 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___16 *, unsigned int);
	int (*d_hash)(const struct dentry___16 *, struct qstr *);
	int (*d_compare)(const struct dentry___16 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___16 *);
	int (*d_init)(struct dentry___16 *);
	void (*d_release)(struct dentry___16 *);
	void (*d_prune)(struct dentry___16 *);
	void (*d_iput)(struct dentry___16 *, struct inode___17 *);
	char * (*d_dname)(struct dentry___16 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___14 *);
	int (*d_manage)(const struct path___14 *, bool);
	struct dentry___16 * (*d_real)(struct dentry___16 *, const struct inode___17 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___14;

struct mem_dqinfo___14 {
	struct quota_format_type___14 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___14;

struct quota_info___14 {
	unsigned int flags;
	struct rw_semaphore___15 dqio_sem;
	struct inode___17 *files[3];
	struct mem_dqinfo___14 info[3];
	const struct quota_format_ops___14 *ops[3];
};

struct rcuwait___14 {
	struct task_struct___16 *task;
};

struct percpu_rw_semaphore___14 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___15 rw_sem;
	struct rcuwait___14 writer;
	int readers_block;
};

struct sb_writers___14 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___14 rw_sem[3];
};

struct file_system_type___14;

struct super_operations___14;

struct dquot_operations___14;

struct quotactl_ops___14;

struct super_block___15 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___14 *s_type;
	const struct super_operations___14 *s_op;
	const struct dquot_operations___14 *dq_op;
	const struct quotactl_ops___14 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___16 *s_root;
	struct rw_semaphore___15 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___15 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___14 s_dquot;
	struct sb_writers___14 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___14 *s_d_op;
	int cleancache_poolid;
	struct shrinker___4 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___15 {
	struct file___15 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___15 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___15 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___15 *ia_file;
};

struct dquot___14 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___15 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___14 {
	int qf_fmt_id;
	const struct quota_format_ops___14 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___14 *qf_next;
};

struct quota_format_ops___14 {
	int (*check_quota_file)(struct super_block___15 *, int);
	int (*read_file_info)(struct super_block___15 *, int);
	int (*write_file_info)(struct super_block___15 *, int);
	int (*free_file_info)(struct super_block___15 *, int);
	int (*read_dqblk)(struct dquot___14 *);
	int (*commit_dqblk)(struct dquot___14 *);
	int (*release_dqblk)(struct dquot___14 *);
	int (*get_next_id)(struct super_block___15 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___14 {
	int (*write_dquot)(struct dquot___14 *);
	struct dquot___14 * (*alloc_dquot)(struct super_block___15 *, int);
	void (*destroy_dquot)(struct dquot___14 *);
	int (*acquire_dquot)(struct dquot___14 *);
	int (*release_dquot)(struct dquot___14 *);
	int (*mark_dirty)(struct dquot___14 *);
	int (*write_info)(struct super_block___15 *, int);
	qsize_t * (*get_reserved_space)(struct inode___17 *);
	int (*get_projid)(struct inode___17 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___17 *, qsize_t *);
	int (*get_next_id)(struct super_block___15 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___14 {
	int (*quota_on)(struct super_block___15 *, int, int, const struct path___14 *);
	int (*quota_off)(struct super_block___15 *, int);
	int (*quota_enable)(struct super_block___15 *, unsigned int);
	int (*quota_disable)(struct super_block___15 *, unsigned int);
	int (*quota_sync)(struct super_block___15 *, int);
	int (*set_info)(struct super_block___15 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___15 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___15 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___15 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___15 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___15 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___14 {
	int (*writepage)(struct page___16 *, struct writeback_control___3 *);
	int (*readpage)(struct file___15 *, struct page___16 *);
	int (*writepages)(struct address_space___14 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___16 *);
	int (*readpages)(struct file___15 *, struct address_space___14 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___15 *, struct address_space___14 *, loff_t, unsigned int, unsigned int, struct page___16 **, void **);
	int (*write_end)(struct file___15 *, struct address_space___14 *, loff_t, unsigned int, unsigned int, struct page___16 *, void *);
	sector_t (*bmap)(struct address_space___14 *, sector_t);
	void (*invalidatepage)(struct page___16 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___16 *, gfp_t);
	void (*freepage)(struct page___16 *);
	ssize_t (*direct_IO)(struct kiocb___15 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___14 *, struct page___16 *, struct page___16 *, enum migrate_mode);
	bool (*isolate_page)(struct page___16 *, isolate_mode_t);
	void (*putback_page)(struct page___16 *);
	int (*launder_page)(struct page___16 *);
	int (*is_partially_uptodate)(struct page___16 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___16 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___14 *, struct page___16 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___15 *, sector_t *);
	void (*swap_deactivate)(struct file___15 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___15 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___17 *bd_inode;
	struct super_block___15 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___15 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___14 {
	struct dentry___16 * (*lookup)(struct inode___17 *, struct dentry___16 *, unsigned int);
	const char * (*get_link)(struct dentry___16 *, struct inode___17 *, struct delayed_call *);
	int (*permission)(struct inode___17 *, int);
	struct posix_acl * (*get_acl)(struct inode___17 *, int);
	int (*readlink)(struct dentry___16 *, char *, int);
	int (*create)(struct inode___17 *, struct dentry___16 *, umode_t, bool);
	int (*link)(struct dentry___16 *, struct inode___17 *, struct dentry___16 *);
	int (*unlink)(struct inode___17 *, struct dentry___16 *);
	int (*symlink)(struct inode___17 *, struct dentry___16 *, const char *);
	int (*mkdir)(struct inode___17 *, struct dentry___16 *, umode_t);
	int (*rmdir)(struct inode___17 *, struct dentry___16 *);
	int (*mknod)(struct inode___17 *, struct dentry___16 *, umode_t, dev_t);
	int (*rename)(struct inode___17 *, struct dentry___16 *, struct inode___17 *, struct dentry___16 *, unsigned int);
	int (*setattr)(struct dentry___16 *, struct iattr___15 *);
	int (*getattr)(const struct path___14 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___16 *, char *, size_t);
	int (*fiemap)(struct inode___17 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___17 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___17 *, struct dentry___16 *, struct file___15 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___17 *, struct dentry___16 *, umode_t);
	int (*set_acl)(struct inode___17 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___14 {
	void (*fl_copy_lock)(struct file_lock___15 *, struct file_lock___15 *);
	void (*fl_release_private)(struct file_lock___15 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___14;

struct lock_manager_operations___14;

struct file_lock___15 {
	struct file_lock___15 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___15 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___14 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___14 *fl_ops;
	const struct lock_manager_operations___14 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___14 {
	int (*lm_compare_owner)(struct file_lock___15 *, struct file_lock___15 *);
	long unsigned int (*lm_owner_key)(struct file_lock___15 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___15 *);
	int (*lm_grant)(struct file_lock___15 *, int);
	bool (*lm_break)(struct file_lock___15 *);
	int (*lm_change)(struct file_lock___15 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___15 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___14 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___14 *fa_next;
	struct file___15 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___14 {
	const char *name;
	int fs_flags;
	struct dentry___16 * (*mount)(struct file_system_type___14 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___15 *);
	struct module___11 *owner;
	struct file_system_type___14 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___14 {
	struct inode___17 * (*alloc_inode)(struct super_block___15 *);
	void (*destroy_inode)(struct inode___17 *);
	void (*dirty_inode)(struct inode___17 *, int);
	int (*write_inode)(struct inode___17 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___17 *);
	void (*evict_inode)(struct inode___17 *);
	void (*put_super)(struct super_block___15 *);
	int (*sync_fs)(struct super_block___15 *, int);
	int (*freeze_super)(struct super_block___15 *);
	int (*freeze_fs)(struct super_block___15 *);
	int (*thaw_super)(struct super_block___15 *);
	int (*unfreeze_fs)(struct super_block___15 *);
	int (*statfs)(struct dentry___16 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___15 *, int *, char *);
	void (*umount_begin)(struct super_block___15 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___16 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___16 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___16 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___16 *);
	ssize_t (*quota_read)(struct super_block___15 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___15 *, int, const char *, size_t, loff_t);
	struct dquot___14 ** (*get_dquots)(struct inode___17 *);
	int (*bdev_try_to_free_page)(struct super_block___15 *, struct page___16 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___15 *, struct shrink_control___4 *);
	long int (*free_cached_objects)(struct super_block___15 *, struct shrink_control___4 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_attribute___14 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___14 *, struct kobj_attribute___14 *, char *);
	ssize_t (*store)(struct kobject___14 *, struct kobj_attribute___14 *, const char *, size_t);
};

typedef void compound_page_dtor___14(struct page___16 *);

struct kernfs_root___14;

struct kernfs_elem_dir___14 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___14 *root;
};

struct kernfs_syscall_ops___14;

struct kernfs_root___14 {
	struct kernfs_node___14 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___14 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___14 {
	struct kernfs_node___14 *target_kn;
};

struct kernfs_ops___14;

struct kernfs_elem_attr___14 {
	const struct kernfs_ops___14 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___14 *notify_next;
};

struct kernfs_node___14 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___14 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___14 dir;
		struct kernfs_elem_symlink___14 symlink;
		struct kernfs_elem_attr___14 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___14;

struct kernfs_ops___14 {
	int (*open)(struct kernfs_open_file___14 *);
	void (*release)(struct kernfs_open_file___14 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___14 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___14 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___14 *, struct vm_area_struct___16 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___14 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___14 {
	int (*remount_fs)(struct kernfs_root___14 *, int *, char *);
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___14 *);
	int (*mkdir)(struct kernfs_node___14 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___14 *);
	int (*rename)(struct kernfs_node___14 *, struct kernfs_node___14 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___14 *, struct kernfs_root___14 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___14 {
	struct kernfs_node___14 *kn;
	struct file___15 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___14 *vm_ops;
};

struct bin_attribute___14;

struct attribute_group___14 {
	const char *name;
	umode_t (*is_visible)(struct kobject___14 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___14 *, struct bin_attribute___14 *, int);
	struct attribute **attrs;
	struct bin_attribute___14 **bin_attrs;
};

struct bin_attribute___14 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___15 *, struct kobject___14 *, struct bin_attribute___14 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___15 *, struct kobject___14 *, struct bin_attribute___14 *, char *, loff_t, size_t);
	int (*mmap)(struct file___15 *, struct kobject___14 *, struct bin_attribute___14 *, struct vm_area_struct___16 *);
};

struct sysfs_ops___14 {
	ssize_t (*show)(struct kobject___14 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___14 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___14;

struct kset___14 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___14 kobj;
	const struct kset_uevent_ops___14 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___14 {
	void (*release)(struct kobject___14 *);
	const struct sysfs_ops___14 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___14 *);
	const void * (*namespace)(struct kobject___14 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___14 {
	int (* const filter)(struct kset___14 *, struct kobject___14 *);
	const char * (* const name)(struct kset___14 *, struct kobject___14 *);
	int (* const uevent)(struct kset___14 *, struct kobject___14 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___14 {
	int (*prepare)(struct device___15 *);
	void (*complete)(struct device___15 *);
	int (*suspend)(struct device___15 *);
	int (*resume)(struct device___15 *);
	int (*freeze)(struct device___15 *);
	int (*thaw)(struct device___15 *);
	int (*poweroff)(struct device___15 *);
	int (*restore)(struct device___15 *);
	int (*suspend_late)(struct device___15 *);
	int (*resume_early)(struct device___15 *);
	int (*freeze_late)(struct device___15 *);
	int (*thaw_early)(struct device___15 *);
	int (*poweroff_late)(struct device___15 *);
	int (*restore_early)(struct device___15 *);
	int (*suspend_noirq)(struct device___15 *);
	int (*resume_noirq)(struct device___15 *);
	int (*freeze_noirq)(struct device___15 *);
	int (*thaw_noirq)(struct device___15 *);
	int (*poweroff_noirq)(struct device___15 *);
	int (*restore_noirq)(struct device___15 *);
	int (*runtime_suspend)(struct device___15 *);
	int (*runtime_resume)(struct device___15 *);
	int (*runtime_idle)(struct device___15 *);
};

struct dev_pm_domain___14 {
	struct dev_pm_ops___14 ops;
	void (*detach)(struct device___15 *, bool);
	int (*activate)(struct device___15 *);
	void (*sync)(struct device___15 *);
	void (*dismiss)(struct device___15 *);
};

struct bus_type___14 {
	const char *name;
	const char *dev_name;
	struct device___15 *dev_root;
	const struct attribute_group___14 **bus_groups;
	const struct attribute_group___14 **dev_groups;
	const struct attribute_group___14 **drv_groups;
	int (*match)(struct device___15 *, struct device_driver___14 *);
	int (*uevent)(struct device___15 *, struct kobj_uevent_env *);
	int (*probe)(struct device___15 *);
	int (*remove)(struct device___15 *);
	void (*shutdown)(struct device___15 *);
	int (*online)(struct device___15 *);
	int (*offline)(struct device___15 *);
	int (*suspend)(struct device___15 *, pm_message_t);
	int (*resume)(struct device___15 *);
	int (*num_vf)(struct device___15 *);
	int (*dma_configure)(struct device___15 *);
	const struct dev_pm_ops___14 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___14 {
	const char *name;
	struct bus_type___14 *bus;
	struct module___11 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___15 *);
	int (*remove)(struct device___15 *);
	void (*shutdown)(struct device___15 *);
	int (*suspend)(struct device___15 *, pm_message_t);
	int (*resume)(struct device___15 *);
	const struct attribute_group___14 **groups;
	const struct dev_pm_ops___14 *pm;
	void (*coredump)(struct device___15 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___14 {
	const char *name;
	const struct attribute_group___14 **groups;
	int (*uevent)(struct device___15 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___15 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___15 *);
	const struct dev_pm_ops___14 *pm;
};

struct class___14 {
	const char *name;
	struct module___11 *owner;
	const struct attribute_group___14 **class_groups;
	const struct attribute_group___14 **dev_groups;
	struct kobject___14 *dev_kobj;
	int (*dev_uevent)(struct device___15 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___15 *, umode_t *);
	void (*class_release)(struct class___14 *);
	void (*dev_release)(struct device___15 *);
	int (*shutdown_pre)(struct device___15 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___15 *);
	const struct dev_pm_ops___14 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___13 {
	struct device___15 dev;
};

typedef int (*key_restrict_link_func_t___14)(struct key___15 *, const struct key_type *, const union key_payload *, struct key___15 *);

struct key_restriction___15;

struct key___15 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___15 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___15 *restrict_link;
};

struct key_restriction___15 {
	key_restrict_link_func_t___14 check;
	struct key___15 *key;
	struct key_type *keytype;
};

struct aarch64_insn_patch {
	void **text_addrs;
	u32 *new_insns;
	int insn_cnt;
	atomic_t cpu_count;
};

struct return_address_data {
	unsigned int level;
	void *addr;
};

struct arm_smccc_res {
	long unsigned int a0;
	long unsigned int a1;
	long unsigned int a2;
	long unsigned int a3;
};

struct alt_instr {
	s32 orig_offset;
	s32 alt_offset;
	u16 cpufeature;
	u8 orig_len;
	u8 alt_len;
};

enum migratetype {
	MIGRATE_UNMOVABLE = 0,
	MIGRATE_MOVABLE = 1,
	MIGRATE_RECLAIMABLE = 2,
	MIGRATE_PCPTYPES = 3,
	MIGRATE_HIGHATOMIC = 3,
	MIGRATE_ISOLATE = 4,
	MIGRATE_TYPES = 5,
};

enum zone_watermarks {
	WMARK_MIN = 0,
	WMARK_LOW = 1,
	WMARK_HIGH = 2,
	NR_WMARK = 3,
};

enum {
	ZONELIST_FALLBACK = 0,
	ZONELIST_NOFALLBACK = 1,
	MAX_ZONELISTS = 2,
};

struct device_attribute {
	struct attribute attr;
	ssize_t (*show)(struct device___12 *, struct device_attribute *, char *);
	ssize_t (*store)(struct device___12 *, struct device_attribute *, const char *, size_t);
};

struct ssbd_options {
	const char *str;
	int state;
};

enum {
	CAP_HWCAP = 1,
};

struct kimage___4;

typedef void *kexec_load_t___4(struct kimage___4 *, char *, long unsigned int, char *, long unsigned int, char *, long unsigned int);

struct kexec_file_ops___4 {
	kexec_probe_t *probe;
	kexec_load_t___4 *load;
	kexec_cleanup_t *cleanup;
};

struct kimage___4 {
	kimage_entry_t head;
	kimage_entry_t *entry;
	kimage_entry_t *last_entry;
	long unsigned int start;
	struct page___12 *control_code_page;
	struct page___12 *swap_page;
	void *vmcoreinfo_data_copy;
	long unsigned int nr_segments;
	struct kexec_segment segment[16];
	struct list_head control_pages;
	struct list_head dest_pages;
	struct list_head unusable_pages;
	long unsigned int control_page;
	unsigned int type: 1;
	unsigned int preserve_context: 1;
	unsigned int file_mode: 1;
	struct kimage_arch arch;
	void *kernel_buf;
	long unsigned int kernel_buf_len;
	void *initrd_buf;
	long unsigned int initrd_buf_len;
	char *cmdline_buf;
	long unsigned int cmdline_buf_len;
	const struct kexec_file_ops___4 *fops;
	void *image_loader_data;
	struct purgatory_info purgatory_info;
};

struct device_attribute___2 {
	struct attribute attr;
	ssize_t (*show)(struct device___11 *, struct device_attribute___2 *, char *);
	ssize_t (*store)(struct device___11 *, struct device_attribute___2 *, const char *, size_t);
};

struct cpu___2 {
	int node_id;
	int hotpluggable;
	struct device___11 dev;
};

struct cpuinfo_arm64___2 {
	struct cpu___2 cpu;
	struct kobject___10 kobj;
	u32 reg_ctr;
	u32 reg_cntfrq;
	u32 reg_dczid;
	u32 reg_midr;
	u32 reg_revidr;
	u64 reg_id_aa64dfr0;
	u64 reg_id_aa64dfr1;
	u64 reg_id_aa64isar0;
	u64 reg_id_aa64isar1;
	u64 reg_id_aa64mmfr0;
	u64 reg_id_aa64mmfr1;
	u64 reg_id_aa64mmfr2;
	u64 reg_id_aa64pfr0;
	u64 reg_id_aa64pfr1;
	u64 reg_id_aa64zfr0;
	u32 reg_id_dfr0;
	u32 reg_id_isar0;
	u32 reg_id_isar1;
	u32 reg_id_isar2;
	u32 reg_id_isar3;
	u32 reg_id_isar4;
	u32 reg_id_isar5;
	u32 reg_id_mmfr0;
	u32 reg_id_mmfr1;
	u32 reg_id_mmfr2;
	u32 reg_id_mmfr3;
	u32 reg_id_pfr0;
	u32 reg_id_pfr1;
	u32 reg_mvfr0;
	u32 reg_mvfr1;
	u32 reg_mvfr2;
	u64 reg_zcr;
};

struct __ftr_reg_entry {
	u32 sys_id;
	struct arm64_ftr_reg *reg;
};

typedef void kpti_remap_fn(int, int, phys_addr_t);

typedef void ttbr_replace_func(phys_addr_t);

typedef void (*alternative_cb_t)(struct alt_instr *, __le32 *, __le32 *, int);

struct alt_region {
	struct alt_instr *begin;
	struct alt_instr *end;
};

enum cache_type {
	CACHE_TYPE_NOCACHE = 0,
	CACHE_TYPE_INST = 1,
	CACHE_TYPE_DATA = 2,
	CACHE_TYPE_SEPARATE = 3,
	CACHE_TYPE_UNIFIED = 4,
};

struct cacheinfo {
	unsigned int id;
	enum cache_type type;
	unsigned int level;
	unsigned int coherency_line_size;
	unsigned int number_of_sets;
	unsigned int ways_of_associativity;
	unsigned int physical_line_partition;
	unsigned int size;
	cpumask_t shared_cpu_map;
	unsigned int attributes;
	void *fw_token;
	bool disable_sysfs;
	void *priv;
};

struct cpu_cacheinfo {
	struct cacheinfo *info_list;
	unsigned int num_levels;
	unsigned int num_leaves;
	bool cpu_map_populated;
};

struct module___16;

struct file___16;

struct kiocb___16;

struct poll_table_struct___12;

struct inode___18;

struct file_lock___16;

struct seq_file___17;

struct file_operations___16 {
	struct module___16 *owner;
	loff_t (*llseek)(struct file___16 *, loff_t, int);
	ssize_t (*read)(struct file___16 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___16 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___16 *, struct iov_iter___6 *);
	ssize_t (*write_iter)(struct kiocb___16 *, struct iov_iter___6 *);
	int (*iopoll)(struct kiocb___16 *, bool);
	int (*iterate)(struct file___16 *, struct dir_context *);
	int (*iterate_shared)(struct file___16 *, struct dir_context *);
	__poll_t (*poll)(struct file___16 *, struct poll_table_struct___12 *);
	long int (*unlocked_ioctl)(struct file___16 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___16 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___16 *, struct vm_area_struct___2 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___18 *, struct file___16 *);
	int (*flush)(struct file___16 *, fl_owner_t);
	int (*release)(struct inode___18 *, struct file___16 *);
	int (*fsync)(struct file___16 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___16 *, int);
	int (*lock)(struct file___16 *, int, struct file_lock___16 *);
	ssize_t (*sendpage)(struct file___16 *, struct page___2 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___16 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___16 *, int, struct file_lock___16 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___16 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___16 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___16 *, long int, struct file_lock___16 **, void **);
	long int (*fallocate)(struct file___16 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___17 *, struct file___16 *);
	ssize_t (*copy_file_range)(struct file___16 *, loff_t, struct file___16 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___16 *, loff_t, struct file___16 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___16 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___15 {
	u64 seqnum;
	struct vm_area_struct___2 *vmas[4];
};

struct page_frag___15 {
	struct page___2 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___9;

struct debug_info___9 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___9 *hbp_break[16];
	struct perf_event___9 *hbp_watch[16];
};

struct thread_struct___9 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___9 debug;
	long: 64;
};

struct mm_struct___16;

struct pid___14;

struct cred___15;

struct nsproxy___15;

struct signal_struct___14;

struct css_set___9;

struct perf_event_context___9;

struct vm_struct___12;

struct task_struct___17 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___17 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___16 *mm;
	struct mm_struct___16 *active_mm;
	struct vmacache___15 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___17 *real_parent;
	struct task_struct___17 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___17 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___14 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___14 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___14 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___15 *ptracer_cred;
	const struct cred___15 *real_cred;
	const struct cred___15 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___15 *nsproxy;
	struct signal_struct___14 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___17 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___2 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___9 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___9 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___15 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___17 *oom_reaper_list;
	struct vm_struct___12 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___9 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___9 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___17 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___9)(struct perf_event___9 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___9;

struct fasync_struct___15;

struct pid_namespace___14;

struct trace_event_call___9;

struct perf_cgroup___9;

struct perf_event___9 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___9 *group_leader;
	struct pmu___9 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___9 hw;
	struct perf_event_context___9 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___9 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___17 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___15 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___9 *);
	struct callback_head callback_head;
	struct pid_namespace___14 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___9 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___9 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___9 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___9 *cgrp;
	struct list_head sb_list;
};

typedef struct page___2 *pgtable_t___15;

struct address_space___15;

struct dev_pagemap___15;

struct page___2 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___15 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___2 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___15 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___16 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___15 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___15;

struct lruvec___15 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___15 *pgdat;
};

struct zone___15 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___15 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___15 {
	struct zone___15 *zone;
	int zone_idx;
};

struct zonelist___15 {
	struct zoneref___15 _zonerefs[25];
};

struct pglist_data___15 {
	struct zone___15 node_zones[3];
	struct zonelist___15 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___17 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___17 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___15 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___16 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___17 *owner;
};

struct secondary_data___16 {
	void *stack;
	struct task_struct___17 *task;
	long int status;
};

struct clock_event_device___4;

struct arch_timer_erratum_workaround___4 {
	enum arch_timer_erratum_match_type match_type;
	const void *id;
	const char *desc;
	u32 (*read_cntp_tval_el0)();
	u32 (*read_cntv_tval_el0)();
	u64 (*read_cntpct_el0)();
	u64 (*read_cntvct_el0)();
	int (*set_next_event_phys)(long unsigned int, struct clock_event_device___4 *);
	int (*set_next_event_virt)(long unsigned int, struct clock_event_device___4 *);
};

struct clock_event_device___4 {
	void (*event_handler)(struct clock_event_device___4 *);
	int (*set_next_event)(long unsigned int, struct clock_event_device___4 *);
	int (*set_next_ktime)(ktime_t, struct clock_event_device___4 *);
	ktime_t next_event;
	u64 max_delta_ns;
	u64 min_delta_ns;
	u32 mult;
	u32 shift;
	enum clock_event_state state_use_accessors;
	unsigned int features;
	long unsigned int retries;
	int (*set_state_periodic)(struct clock_event_device___4 *);
	int (*set_state_oneshot)(struct clock_event_device___4 *);
	int (*set_state_oneshot_stopped)(struct clock_event_device___4 *);
	int (*set_state_shutdown)(struct clock_event_device___4 *);
	int (*tick_resume)(struct clock_event_device___4 *);
	void (*broadcast)(const struct cpumask *);
	void (*suspend)(struct clock_event_device___4 *);
	void (*resume)(struct clock_event_device___4 *);
	long unsigned int min_delta_ticks;
	long unsigned int max_delta_ticks;
	const char *name;
	int rating;
	int irq;
	int bound_on;
	const struct cpumask *cpumask;
	struct list_head list;
	struct module___16 *owner;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct blocking_notifier_head___15 {
	struct rw_semaphore___16 rwsem;
	struct notifier_block *head;
};

struct key___16;

struct ucounts___10;

struct user_namespace___10 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___10 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common ns;
	long unsigned int flags;
	struct key___16 *persistent_keyring_register;
	struct rw_semaphore___16 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___10 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_root___15;

struct kernfs_elem_dir___15 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___15 *root;
};

struct kernfs_node___15;

struct kernfs_syscall_ops___15;

struct kernfs_root___15 {
	struct kernfs_node___15 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___15 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___15 {
	struct kernfs_node___15 *target_kn;
};

struct kernfs_ops___15;

struct kernfs_elem_attr___15 {
	const struct kernfs_ops___15 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___15 *notify_next;
};

struct kernfs_node___15 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___15 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___15 dir;
		struct kernfs_elem_symlink___15 symlink;
		struct kernfs_elem_attr___15 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___15;

struct kernfs_ops___15 {
	int (*open)(struct kernfs_open_file___15 *);
	void (*release)(struct kernfs_open_file___15 *);
	int (*seq_show)(struct seq_file___17 *, void *);
	void * (*seq_start)(struct seq_file___17 *, loff_t *);
	void * (*seq_next)(struct seq_file___17 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___17 *, void *);
	ssize_t (*read)(struct kernfs_open_file___15 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___15 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___15 *, struct vm_area_struct___2 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___15 *, struct poll_table_struct___12 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___15 {
	int (*remount_fs)(struct kernfs_root___15 *, int *, char *);
	int (*show_options)(struct seq_file___17 *, struct kernfs_root___15 *);
	int (*mkdir)(struct kernfs_node___15 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___15 *);
	int (*rename)(struct kernfs_node___15 *, struct kernfs_node___15 *, const char *);
	int (*show_path)(struct seq_file___17 *, struct kernfs_node___15 *, struct kernfs_root___15 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___14;

struct seq_file___17 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___14 *op;
	int poll_event;
	const struct file___16 *file;
	void *private;
};

struct vm_operations_struct___15;

struct kernfs_open_file___15 {
	struct kernfs_node___15 *kn;
	struct file___16 *file;
	struct seq_file___17 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___15 *vm_ops;
};

struct dentry___17;

struct path___15 {
	struct vfsmount *mnt;
	struct dentry___17 *dentry;
};

struct fown_struct___14 {
	rwlock_t lock;
	struct pid___14 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___16 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___15 f_path;
	struct inode___18 *f_inode;
	const struct file_operations___16 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___14 f_owner;
	const struct cred___15 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___15 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___15;

struct vm_operations_struct___15 {
	void (*open)(struct vm_area_struct___2 *);
	void (*close)(struct vm_area_struct___2 *);
	int (*split)(struct vm_area_struct___2 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___2 *);
	vm_fault_t (*fault)(struct vm_fault___15 *);
	vm_fault_t (*huge_fault)(struct vm_fault___15 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___15 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___2 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___15 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___15 *);
	int (*access)(struct vm_area_struct___2 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___2 *);
	int (*set_policy)(struct vm_area_struct___2 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___2 *, long unsigned int);
	struct page___2 * (*find_special_page)(struct vm_area_struct___2 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___11)(struct file___16 *, wait_queue_head_t *, struct poll_table_struct___12 *);

struct poll_table_struct___12 {
	poll_queue_proc___11 _qproc;
	__poll_t _key;
};

struct vm_area_struct___2 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___2 *vm_next;
	struct vm_area_struct___2 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___16 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___15 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___16 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___15;

struct bin_attribute___15;

struct attribute_group___15 {
	const char *name;
	umode_t (*is_visible)(struct kobject___15 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___15 *, struct bin_attribute___15 *, int);
	struct attribute **attrs;
	struct bin_attribute___15 **bin_attrs;
};

struct kset___15;

struct kobj_type___15;

struct kobject___15 {
	const char *name;
	struct list_head entry;
	struct kobject___15 *parent;
	struct kset___15 *kset;
	struct kobj_type___15 *ktype;
	struct kernfs_node___15 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___15 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___16 *, struct kobject___15 *, struct bin_attribute___15 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___16 *, struct kobject___15 *, struct bin_attribute___15 *, char *, loff_t, size_t);
	int (*mmap)(struct file___16 *, struct kobject___15 *, struct bin_attribute___15 *, struct vm_area_struct___2 *);
};

struct sysfs_ops___15 {
	ssize_t (*show)(struct kobject___15 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___15 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___15;

struct kset___15 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___15 kobj;
	const struct kset_uevent_ops___15 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___15 {
	void (*release)(struct kobject___15 *);
	const struct sysfs_ops___15 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___15 *);
	const void * (*namespace)(struct kobject___15 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___15 {
	int (* const filter)(struct kset___15 *, struct kobject___15 *);
	const char * (* const name)(struct kset___15 *, struct kobject___15 *);
	int (* const uevent)(struct kset___15 *, struct kobject___15 *, struct kobj_uevent_env *);
};

struct kobj_attribute___15 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___15 *, struct kobj_attribute___15 *, char *);
	ssize_t (*store)(struct kobject___15 *, struct kobj_attribute___15 *, const char *, size_t);
};

struct dev_pm_ops___15 {
	int (*prepare)(struct device___2 *);
	void (*complete)(struct device___2 *);
	int (*suspend)(struct device___2 *);
	int (*resume)(struct device___2 *);
	int (*freeze)(struct device___2 *);
	int (*thaw)(struct device___2 *);
	int (*poweroff)(struct device___2 *);
	int (*restore)(struct device___2 *);
	int (*suspend_late)(struct device___2 *);
	int (*resume_early)(struct device___2 *);
	int (*freeze_late)(struct device___2 *);
	int (*thaw_early)(struct device___2 *);
	int (*poweroff_late)(struct device___2 *);
	int (*restore_early)(struct device___2 *);
	int (*suspend_noirq)(struct device___2 *);
	int (*resume_noirq)(struct device___2 *);
	int (*freeze_noirq)(struct device___2 *);
	int (*thaw_noirq)(struct device___2 *);
	int (*poweroff_noirq)(struct device___2 *);
	int (*restore_noirq)(struct device___2 *);
	int (*runtime_suspend)(struct device___2 *);
	int (*runtime_resume)(struct device___2 *);
	int (*runtime_idle)(struct device___2 *);
};

struct dev_pm_info___15 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___2 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___15;

struct bus_type___15;

struct device_driver___15;

struct dev_pm_domain___15;

struct device_node___5;

struct fwnode_handle___12;

struct class___15;

struct device___2 {
	struct device___2 *parent;
	struct device_private *p;
	struct kobject___15 kobj;
	const char *init_name;
	const struct device_type___15 *type;
	struct mutex mutex;
	struct bus_type___15 *bus;
	struct device_driver___15 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___15 power;
	struct dev_pm_domain___15 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___5 *of_node;
	struct fwnode_handle___12 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___15 *class;
	const struct attribute_group___15 **groups;
	void (*release)(struct device___2 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___15 {
	struct dev_pm_ops___15 ops;
	void (*detach)(struct device___2 *, bool);
	int (*activate)(struct device___2 *);
	void (*sync)(struct device___2 *);
	void (*dismiss)(struct device___2 *);
};

struct upid___14 {
	int nr;
	struct pid_namespace___14 *ns;
};

struct pid_namespace___14 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___17 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___14 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___17 *proc_self;
	struct dentry___17 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___10 *user_ns;
	struct ucounts___10 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common ns;
};

struct pid___14 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___14 numbers[1];
};

struct user_struct___15 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___16 *uid_keyring;
	struct key___16 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___15;

struct mm_struct___16 {
	struct {
		struct vm_area_struct___2 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___16 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___16 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___15 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___17 *owner;
		struct user_namespace___10 *user_ns;
		struct file___16 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___15 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___15 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___16 *session_keyring;
	struct key___16 *process_keyring;
	struct key___16 *thread_keyring;
	struct key___16 *request_key_auth;
	void *security;
	struct user_struct___15 *user;
	struct user_namespace___10 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___9;

struct nsproxy___15 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___14 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___9 *cgroup_ns;
};

struct signal_struct___14 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___17 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___17 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___14 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___14 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___16 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___14 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___9;

struct cgroup___9;

struct css_set___9 {
	struct cgroup_subsys_state___9 *subsys[13];
	refcount_t refcount;
	struct css_set___9 *dom_cset;
	struct cgroup___9 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___9 *mg_src_cgrp;
	struct cgroup___9 *mg_dst_cgrp;
	struct css_set___9 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___9 {
	struct pmu___9 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___17 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___9 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___12 {
	struct vm_struct___12 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___2 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___14 {
	struct task_struct___17 task;
	long unsigned int stack[8192];
};

struct bus_type___15 {
	const char *name;
	const char *dev_name;
	struct device___2 *dev_root;
	const struct attribute_group___15 **bus_groups;
	const struct attribute_group___15 **dev_groups;
	const struct attribute_group___15 **drv_groups;
	int (*match)(struct device___2 *, struct device_driver___15 *);
	int (*uevent)(struct device___2 *, struct kobj_uevent_env *);
	int (*probe)(struct device___2 *);
	int (*remove)(struct device___2 *);
	void (*shutdown)(struct device___2 *);
	int (*online)(struct device___2 *);
	int (*offline)(struct device___2 *);
	int (*suspend)(struct device___2 *, pm_message_t);
	int (*resume)(struct device___2 *);
	int (*num_vf)(struct device___2 *);
	int (*dma_configure)(struct device___2 *);
	const struct dev_pm_ops___15 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___15 {
	const char *name;
	struct bus_type___15 *bus;
	struct module___16 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___2 *);
	int (*remove)(struct device___2 *);
	void (*shutdown)(struct device___2 *);
	int (*suspend)(struct device___2 *, pm_message_t);
	int (*resume)(struct device___2 *);
	const struct attribute_group___15 **groups;
	const struct dev_pm_ops___15 *pm;
	void (*coredump)(struct device___2 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___15 {
	const char *name;
	const struct attribute_group___15 **groups;
	int (*uevent)(struct device___2 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___2 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___2 *);
	const struct dev_pm_ops___15 *pm;
};

struct module_kobject___13 {
	struct kobject___15 kobj;
	struct module___16 *mod;
	struct kobject___15 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___13 {
	struct module___16 *mod;
	struct latch_tree_node node;
};

struct module_layout___13 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___13 mtn;
};

struct module_attribute___13;

struct kernel_param___13;

struct module___16 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___13 mkobj;
	struct module_attribute___13 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___15 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___13 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___13 core_layout;
	struct module_layout___13 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___9 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct class___15 {
	const char *name;
	struct module___16 *owner;
	const struct attribute_group___15 **class_groups;
	const struct attribute_group___15 **dev_groups;
	struct kobject___15 *dev_kobj;
	int (*dev_uevent)(struct device___2 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___2 *, umode_t *);
	void (*class_release)(struct class___15 *);
	void (*dev_release)(struct device___2 *);
	int (*shutdown_pre)(struct device___2 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___2 *);
	const struct dev_pm_ops___15 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct fwnode_operations___12;

struct fwnode_handle___12 {
	struct fwnode_handle___12 *secondary;
	const struct fwnode_operations___12 *ops;
};

struct property___5;

struct device_node___5 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___12 fwnode;
	struct property___5 *properties;
	struct property___5 *deadprops;
	struct device_node___5 *parent;
	struct device_node___5 *child;
	struct device_node___5 *sibling;
	struct kobject___15 kobj;
	long unsigned int _flags;
	void *data;
};

struct fwnode_reference_args___12;

struct fwnode_endpoint___12;

struct fwnode_operations___12 {
	struct fwnode_handle___12 * (*get)(struct fwnode_handle___12 *);
	void (*put)(struct fwnode_handle___12 *);
	bool (*device_is_available)(const struct fwnode_handle___12 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___12 *, const struct device___2 *);
	bool (*property_present)(const struct fwnode_handle___12 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___12 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___12 *, const char *, const char **, size_t);
	struct fwnode_handle___12 * (*get_parent)(const struct fwnode_handle___12 *);
	struct fwnode_handle___12 * (*get_next_child_node)(const struct fwnode_handle___12 *, struct fwnode_handle___12 *);
	struct fwnode_handle___12 * (*get_named_child_node)(const struct fwnode_handle___12 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___12 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___12 *);
	struct fwnode_handle___12 * (*graph_get_next_endpoint)(const struct fwnode_handle___12 *, struct fwnode_handle___12 *);
	struct fwnode_handle___12 * (*graph_get_remote_endpoint)(const struct fwnode_handle___12 *);
	struct fwnode_handle___12 * (*graph_get_port_parent)(struct fwnode_handle___12 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___12 *, struct fwnode_endpoint___12 *);
};

struct fwnode_endpoint___12 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___12 *local_fwnode;
};

struct fwnode_reference_args___12 {
	struct fwnode_handle___12 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct acpi_subtable_header {
	u8 type;
	u8 length;
};

enum acpi_madt_type {
	ACPI_MADT_TYPE_LOCAL_APIC = 0,
	ACPI_MADT_TYPE_IO_APIC = 1,
	ACPI_MADT_TYPE_INTERRUPT_OVERRIDE = 2,
	ACPI_MADT_TYPE_NMI_SOURCE = 3,
	ACPI_MADT_TYPE_LOCAL_APIC_NMI = 4,
	ACPI_MADT_TYPE_LOCAL_APIC_OVERRIDE = 5,
	ACPI_MADT_TYPE_IO_SAPIC = 6,
	ACPI_MADT_TYPE_LOCAL_SAPIC = 7,
	ACPI_MADT_TYPE_INTERRUPT_SOURCE = 8,
	ACPI_MADT_TYPE_LOCAL_X2APIC = 9,
	ACPI_MADT_TYPE_LOCAL_X2APIC_NMI = 10,
	ACPI_MADT_TYPE_GENERIC_INTERRUPT = 11,
	ACPI_MADT_TYPE_GENERIC_DISTRIBUTOR = 12,
	ACPI_MADT_TYPE_GENERIC_MSI_FRAME = 13,
	ACPI_MADT_TYPE_GENERIC_REDISTRIBUTOR = 14,
	ACPI_MADT_TYPE_GENERIC_TRANSLATOR = 15,
	ACPI_MADT_TYPE_RESERVED = 16,
};

struct acpi_madt_generic_interrupt {
	struct acpi_subtable_header header;
	u16 reserved;
	u32 cpu_interface_number;
	u32 uid;
	u32 flags;
	u32 parking_version;
	u32 performance_interrupt;
	u64 parked_address;
	u64 base_address;
	u64 gicv_base_address;
	u64 gich_base_address;
	u32 vgic_interrupt;
	u64 gicr_base_address;
	u64 arm_mpidr;
	u8 efficiency_class;
	u8 reserved2[3];
} __attribute__((packed));

struct kernel_param_ops___13 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___13 *);
	int (*get)(char *, const struct kernel_param___13 *);
	void (*free)(void *);
};

struct kparam_array___13;

struct kernel_param___13 {
	const char *name;
	struct module___16 *mod;
	const struct kernel_param_ops___13 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___13 *arr;
	};
};

struct kparam_array___13 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___13 *ops;
	void *elem;
};

struct module_attribute___13 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___13 *, struct module_kobject___13 *, char *);
	ssize_t (*store)(struct module_attribute___13 *, struct module_kobject___13 *, const char *, size_t);
	void (*setup)(struct module___16 *, const char *);
	int (*test)(struct module___16 *);
	void (*free)(struct module___16 *);
};

struct trace_event_class___9;

struct trace_event_call___9 {
	struct list_head list;
	struct trace_event_class___9 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array *prog_array;
	int (*perf_perm)(struct trace_event_call___9 *, struct perf_event___9 *);
};

struct dentry_operations___15;

struct super_block___16;

struct dentry___17 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___17 *d_parent;
	struct qstr d_name;
	struct inode___18 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___15 *d_op;
	struct super_block___16 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___15;

struct address_space___15 {
	struct inode___18 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___16 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___15 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___15;

struct block_device___16;

struct cdev___6;

struct inode___18 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___15 *i_op;
	struct super_block___16 *i_sb;
	struct address_space___15 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___16 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___16 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___15 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___16 *i_bdev;
		struct cdev___6 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___15 {
	int (*d_revalidate)(struct dentry___17 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___17 *, unsigned int);
	int (*d_hash)(const struct dentry___17 *, struct qstr *);
	int (*d_compare)(const struct dentry___17 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___17 *);
	int (*d_init)(struct dentry___17 *);
	void (*d_release)(struct dentry___17 *);
	void (*d_prune)(struct dentry___17 *);
	void (*d_iput)(struct dentry___17 *, struct inode___18 *);
	char * (*d_dname)(struct dentry___17 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___15 *);
	int (*d_manage)(const struct path___15 *, bool);
	struct dentry___17 * (*d_real)(struct dentry___17 *, const struct inode___18 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___15;

struct mem_dqinfo___15 {
	struct quota_format_type___15 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___15;

struct quota_info___15 {
	unsigned int flags;
	struct rw_semaphore___16 dqio_sem;
	struct inode___18 *files[3];
	struct mem_dqinfo___15 info[3];
	const struct quota_format_ops___15 *ops[3];
};

struct rcuwait___15 {
	struct task_struct___17 *task;
};

struct percpu_rw_semaphore___15 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___16 rw_sem;
	struct rcuwait___15 writer;
	int readers_block;
};

struct sb_writers___15 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___15 rw_sem[3];
};

struct file_system_type___15;

struct super_operations___15;

struct dquot_operations___15;

struct quotactl_ops___15;

struct super_block___16 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___15 *s_type;
	const struct super_operations___15 *s_op;
	const struct dquot_operations___15 *dq_op;
	const struct quotactl_ops___15 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___17 *s_root;
	struct rw_semaphore___16 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___16 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___15 s_dquot;
	struct sb_writers___15 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___15 *s_d_op;
	int cleancache_poolid;
	struct shrinker___4 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___10 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

typedef int (*dev_page_fault_t___15)(struct vm_area_struct___2 *, long unsigned int, const struct page___2 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___15)(struct page___2 *, void *);

struct dev_pagemap___15 {
	dev_page_fault_t___15 page_fault;
	dev_page_free_t___15 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___2 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___15 {
	struct task_struct___17 *task;
	struct core_thread___15 *next;
};

struct core_state___15 {
	atomic_t nr_threads;
	struct core_thread___15 dumper;
	struct completion startup;
};

struct vm_fault___15 {
	struct vm_area_struct___2 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___2 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___2 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___15 prealloc_pte;
};

struct kiocb___16 {
	struct file___16 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___16 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___16 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___16 *ia_file;
};

struct dquot___15 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___16 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___15 {
	int qf_fmt_id;
	const struct quota_format_ops___15 *qf_ops;
	struct module___16 *qf_owner;
	struct quota_format_type___15 *qf_next;
};

struct quota_format_ops___15 {
	int (*check_quota_file)(struct super_block___16 *, int);
	int (*read_file_info)(struct super_block___16 *, int);
	int (*write_file_info)(struct super_block___16 *, int);
	int (*free_file_info)(struct super_block___16 *, int);
	int (*read_dqblk)(struct dquot___15 *);
	int (*commit_dqblk)(struct dquot___15 *);
	int (*release_dqblk)(struct dquot___15 *);
	int (*get_next_id)(struct super_block___16 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___15 {
	int (*write_dquot)(struct dquot___15 *);
	struct dquot___15 * (*alloc_dquot)(struct super_block___16 *, int);
	void (*destroy_dquot)(struct dquot___15 *);
	int (*acquire_dquot)(struct dquot___15 *);
	int (*release_dquot)(struct dquot___15 *);
	int (*mark_dirty)(struct dquot___15 *);
	int (*write_info)(struct super_block___16 *, int);
	qsize_t * (*get_reserved_space)(struct inode___18 *);
	int (*get_projid)(struct inode___18 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___18 *, qsize_t *);
	int (*get_next_id)(struct super_block___16 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___15 {
	int (*quota_on)(struct super_block___16 *, int, int, const struct path___15 *);
	int (*quota_off)(struct super_block___16 *, int);
	int (*quota_enable)(struct super_block___16 *, unsigned int);
	int (*quota_disable)(struct super_block___16 *, unsigned int);
	int (*quota_sync)(struct super_block___16 *, int);
	int (*set_info)(struct super_block___16 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___16 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___16 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___16 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___16 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___16 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___15 {
	int (*writepage)(struct page___2 *, struct writeback_control___3 *);
	int (*readpage)(struct file___16 *, struct page___2 *);
	int (*writepages)(struct address_space___15 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___2 *);
	int (*readpages)(struct file___16 *, struct address_space___15 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___16 *, struct address_space___15 *, loff_t, unsigned int, unsigned int, struct page___2 **, void **);
	int (*write_end)(struct file___16 *, struct address_space___15 *, loff_t, unsigned int, unsigned int, struct page___2 *, void *);
	sector_t (*bmap)(struct address_space___15 *, sector_t);
	void (*invalidatepage)(struct page___2 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___2 *, gfp_t);
	void (*freepage)(struct page___2 *);
	ssize_t (*direct_IO)(struct kiocb___16 *, struct iov_iter___6 *);
	int (*migratepage)(struct address_space___15 *, struct page___2 *, struct page___2 *, enum migrate_mode);
	bool (*isolate_page)(struct page___2 *, isolate_mode_t);
	void (*putback_page)(struct page___2 *);
	int (*launder_page)(struct page___2 *);
	int (*is_partially_uptodate)(struct page___2 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___2 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___15 *, struct page___2 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___16 *, sector_t *);
	void (*swap_deactivate)(struct file___16 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___16 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___18 *bd_inode;
	struct super_block___16 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___16 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___6 {
	struct kobject___15 kobj;
	struct module___16 *owner;
	const struct file_operations___16 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___15 {
	struct dentry___17 * (*lookup)(struct inode___18 *, struct dentry___17 *, unsigned int);
	const char * (*get_link)(struct dentry___17 *, struct inode___18 *, struct delayed_call *);
	int (*permission)(struct inode___18 *, int);
	struct posix_acl * (*get_acl)(struct inode___18 *, int);
	int (*readlink)(struct dentry___17 *, char *, int);
	int (*create)(struct inode___18 *, struct dentry___17 *, umode_t, bool);
	int (*link)(struct dentry___17 *, struct inode___18 *, struct dentry___17 *);
	int (*unlink)(struct inode___18 *, struct dentry___17 *);
	int (*symlink)(struct inode___18 *, struct dentry___17 *, const char *);
	int (*mkdir)(struct inode___18 *, struct dentry___17 *, umode_t);
	int (*rmdir)(struct inode___18 *, struct dentry___17 *);
	int (*mknod)(struct inode___18 *, struct dentry___17 *, umode_t, dev_t);
	int (*rename)(struct inode___18 *, struct dentry___17 *, struct inode___18 *, struct dentry___17 *, unsigned int);
	int (*setattr)(struct dentry___17 *, struct iattr___16 *);
	int (*getattr)(const struct path___15 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___17 *, char *, size_t);
	int (*fiemap)(struct inode___18 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___18 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___18 *, struct dentry___17 *, struct file___16 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___18 *, struct dentry___17 *, umode_t);
	int (*set_acl)(struct inode___18 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___15 {
	void (*fl_copy_lock)(struct file_lock___16 *, struct file_lock___16 *);
	void (*fl_release_private)(struct file_lock___16 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___15;

struct file_lock___16 {
	struct file_lock___16 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___16 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___15 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___15 *fl_ops;
	const struct lock_manager_operations___15 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___15 {
	int (*lm_compare_owner)(struct file_lock___16 *, struct file_lock___16 *);
	long unsigned int (*lm_owner_key)(struct file_lock___16 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___16 *);
	int (*lm_grant)(struct file_lock___16 *, int);
	bool (*lm_break)(struct file_lock___16 *);
	int (*lm_change)(struct file_lock___16 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___16 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___15 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___15 *fa_next;
	struct file___16 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___15 {
	const char *name;
	int fs_flags;
	struct dentry___17 * (*mount)(struct file_system_type___15 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___16 *);
	struct module___16 *owner;
	struct file_system_type___15 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___15 {
	struct inode___18 * (*alloc_inode)(struct super_block___16 *);
	void (*destroy_inode)(struct inode___18 *);
	void (*dirty_inode)(struct inode___18 *, int);
	int (*write_inode)(struct inode___18 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___18 *);
	void (*evict_inode)(struct inode___18 *);
	void (*put_super)(struct super_block___16 *);
	int (*sync_fs)(struct super_block___16 *, int);
	int (*freeze_super)(struct super_block___16 *);
	int (*freeze_fs)(struct super_block___16 *);
	int (*thaw_super)(struct super_block___16 *);
	int (*unfreeze_fs)(struct super_block___16 *);
	int (*statfs)(struct dentry___17 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___16 *, int *, char *);
	void (*umount_begin)(struct super_block___16 *);
	int (*show_options)(struct seq_file___17 *, struct dentry___17 *);
	int (*show_devname)(struct seq_file___17 *, struct dentry___17 *);
	int (*show_path)(struct seq_file___17 *, struct dentry___17 *);
	int (*show_stats)(struct seq_file___17 *, struct dentry___17 *);
	ssize_t (*quota_read)(struct super_block___16 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___16 *, int, const char *, size_t, loff_t);
	struct dquot___15 ** (*get_dquots)(struct inode___18 *);
	int (*bdev_try_to_free_page)(struct super_block___16 *, struct page___2 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___16 *, struct shrink_control___4 *);
	long int (*free_cached_objects)(struct super_block___16 *, struct shrink_control___4 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*key_restrict_link_func_t___15)(struct key___16 *, const struct key_type *, const union key_payload *, struct key___16 *);

struct key_restriction___16;

struct key___16 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___16 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___16 *restrict_link;
};

struct key_restriction___16 {
	key_restrict_link_func_t___15 check;
	struct key___16 *key;
	struct key_type *keytype;
};

struct seq_operations___14 {
	void * (*start)(struct seq_file___17 *, loff_t *);
	void (*stop)(struct seq_file___17 *, void *);
	void * (*next)(struct seq_file___17 *, void *, loff_t *);
	int (*show)(struct seq_file___17 *, void *);
};

typedef void compound_page_dtor___15(struct page___2 *);

struct node___14 {
	struct device___2 dev;
};

struct cpu___3 {
	int node_id;
	int hotpluggable;
	struct device___2 dev;
};

struct irq_chip___3;

struct irq_data___3 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data *common;
	struct irq_chip___3 *chip;
	struct irq_domain *domain;
	struct irq_data___3 *parent_data;
	void *chip_data;
};

struct irq_chip___3 {
	struct device___2 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___3 *);
	void (*irq_shutdown)(struct irq_data___3 *);
	void (*irq_enable)(struct irq_data___3 *);
	void (*irq_disable)(struct irq_data___3 *);
	void (*irq_ack)(struct irq_data___3 *);
	void (*irq_mask)(struct irq_data___3 *);
	void (*irq_mask_ack)(struct irq_data___3 *);
	void (*irq_unmask)(struct irq_data___3 *);
	void (*irq_eoi)(struct irq_data___3 *);
	int (*irq_set_affinity)(struct irq_data___3 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___3 *);
	int (*irq_set_type)(struct irq_data___3 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___3 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___3 *);
	void (*irq_bus_sync_unlock)(struct irq_data___3 *);
	void (*irq_cpu_online)(struct irq_data___3 *);
	void (*irq_cpu_offline)(struct irq_data___3 *);
	void (*irq_suspend)(struct irq_data___3 *);
	void (*irq_resume)(struct irq_data___3 *);
	void (*irq_pm_shutdown)(struct irq_data___3 *);
	void (*irq_calc_mask)(struct irq_data___3 *);
	void (*irq_print_chip)(struct irq_data___3 *, struct seq_file___17 *);
	int (*irq_request_resources)(struct irq_data___3 *);
	void (*irq_release_resources)(struct irq_data___3 *);
	void (*irq_compose_msi_msg)(struct irq_data___3 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___3 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___3 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___3 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___3 *, void *);
	void (*ipi_send_single)(struct irq_data___3 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___3 *, const struct cpumask *);
	long unsigned int flags;
};

struct property___5 {
	char *name;
	int length;
	void *value;
	struct property___5 *next;
	long unsigned int _flags;
	struct bin_attribute___15 attr;
};

struct cgroup_namespace___9 {
	refcount_t count;
	struct ns_common ns;
	struct user_namespace___10 *user_ns;
	struct ucounts___10 *ucounts;
	struct css_set___9 *root_cset;
};

struct ucounts___10 {
	struct hlist_node node;
	struct user_namespace___10 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct kimage___5;

typedef void *kexec_load_t___5(struct kimage___5 *, char *, long unsigned int, char *, long unsigned int, char *, long unsigned int);

struct kexec_file_ops___5 {
	kexec_probe_t *probe;
	kexec_load_t___5 *load;
	kexec_cleanup_t *cleanup;
};

struct kimage___5 {
	kimage_entry_t head;
	kimage_entry_t *entry;
	kimage_entry_t *last_entry;
	long unsigned int start;
	struct page___2 *control_code_page;
	struct page___2 *swap_page;
	void *vmcoreinfo_data_copy;
	long unsigned int nr_segments;
	struct kexec_segment segment[16];
	struct list_head control_pages;
	struct list_head dest_pages;
	struct list_head unusable_pages;
	long unsigned int control_page;
	unsigned int type: 1;
	unsigned int preserve_context: 1;
	unsigned int file_mode: 1;
	struct kimage_arch arch;
	void *kernel_buf;
	long unsigned int kernel_buf_len;
	void *initrd_buf;
	long unsigned int initrd_buf_len;
	char *cmdline_buf;
	long unsigned int cmdline_buf_len;
	const struct kexec_file_ops___5 *fops;
	void *image_loader_data;
	struct purgatory_info purgatory_info;
};

struct cpuinfo_arm64___3 {
	struct cpu___3 cpu;
	struct kobject___15 kobj;
	u32 reg_ctr;
	u32 reg_cntfrq;
	u32 reg_dczid;
	u32 reg_midr;
	u32 reg_revidr;
	u64 reg_id_aa64dfr0;
	u64 reg_id_aa64dfr1;
	u64 reg_id_aa64isar0;
	u64 reg_id_aa64isar1;
	u64 reg_id_aa64mmfr0;
	u64 reg_id_aa64mmfr1;
	u64 reg_id_aa64mmfr2;
	u64 reg_id_aa64pfr0;
	u64 reg_id_aa64pfr1;
	u64 reg_id_aa64zfr0;
	u32 reg_id_dfr0;
	u32 reg_id_isar0;
	u32 reg_id_isar1;
	u32 reg_id_isar2;
	u32 reg_id_isar3;
	u32 reg_id_isar4;
	u32 reg_id_isar5;
	u32 reg_id_mmfr0;
	u32 reg_id_mmfr1;
	u32 reg_id_mmfr2;
	u32 reg_id_mmfr3;
	u32 reg_id_pfr0;
	u32 reg_id_pfr1;
	u32 reg_mvfr0;
	u32 reg_mvfr1;
	u32 reg_mvfr2;
	u64 reg_zcr;
};

struct bpf_map___9;

struct bpf_map_ops___9 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___9 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___9 *, struct file___16 *);
	void (*map_free)(struct bpf_map___9 *);
	int (*map_get_next_key)(struct bpf_map___9 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___9 *);
	void * (*map_lookup_elem)(struct bpf_map___9 *, void *);
	int (*map_update_elem)(struct bpf_map___9 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___9 *, void *);
	int (*map_push_elem)(struct bpf_map___9 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___9 *, void *);
	int (*map_peek_elem)(struct bpf_map___9 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___9 *, struct file___16 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___9 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___9 *, void *, struct seq_file___17 *);
	int (*map_check_btf)(const struct bpf_map___9 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___9 {
	const struct bpf_map_ops___9 *ops;
	struct bpf_map___9 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___15 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___9;

typedef void (*kthread_work_func_t___9)(struct kthread_work___9 *);

struct kthread_worker___9;

struct kthread_work___9 {
	struct list_head node;
	kthread_work_func_t___9 func;
	struct kthread_worker___9 *worker;
	int canceling;
};

struct kthread_worker___9 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___17 *task;
	struct kthread_work___9 *current_work;
};

struct kthread_delayed_work___9 {
	struct kthread_work___9 work;
	struct timer_list timer;
};

struct psi_group___9 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___9 *poll_kworker;
	struct kthread_delayed_work___9 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___9 {
	struct kernfs_node___15 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___9;

struct cgroup_subsys_state___9 {
	struct cgroup___9 *cgroup;
	struct cgroup_subsys___9 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___9 *parent;
};

struct cgroup_root___9;

struct cgroup_rstat_cpu___9;

struct cgroup___9 {
	struct cgroup_subsys_state___9 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___15 *kn;
	struct cgroup_file___9 procs_file;
	struct cgroup_file___9 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___9 *subsys[13];
	struct cgroup_root___9 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___9 *dom_cgrp;
	struct cgroup_rstat_cpu___9 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf bpf;
	atomic_t congestion_count;
	struct cgroup___9 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___9 psi;
	int ancestor_ids[0];
};

struct cftype___9;

struct cgroup_subsys___9 {
	struct cgroup_subsys_state___9 * (*css_alloc)(struct cgroup_subsys_state___9 *);
	int (*css_online)(struct cgroup_subsys_state___9 *);
	void (*css_offline)(struct cgroup_subsys_state___9 *);
	void (*css_released)(struct cgroup_subsys_state___9 *);
	void (*css_free)(struct cgroup_subsys_state___9 *);
	void (*css_reset)(struct cgroup_subsys_state___9 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___9 *, int);
	int (*css_extra_stat_show)(struct seq_file___17 *, struct cgroup_subsys_state___9 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___17 *);
	void (*cancel_fork)(struct task_struct___17 *);
	void (*fork)(struct task_struct___17 *);
	void (*exit)(struct task_struct___17 *);
	void (*free)(struct task_struct___17 *);
	void (*bind)(struct cgroup_subsys_state___9 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___9 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___9 *dfl_cftypes;
	struct cftype___9 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___9 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___9 *updated_children;
	struct cgroup___9 *updated_next;
};

struct cgroup_root___9 {
	struct kernfs_root___15 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___9 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___9 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___9 *ss;
	struct list_head node;
	struct kernfs_ops___15 *kf_ops;
	int (*open)(struct kernfs_open_file___15 *);
	void (*release)(struct kernfs_open_file___15 *);
	u64 (*read_u64)(struct cgroup_subsys_state___9 *, struct cftype___9 *);
	s64 (*read_s64)(struct cgroup_subsys_state___9 *, struct cftype___9 *);
	int (*seq_show)(struct seq_file___17 *, void *);
	void * (*seq_start)(struct seq_file___17 *, loff_t *);
	void * (*seq_next)(struct seq_file___17 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___17 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___9 *, struct cftype___9 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___9 *, struct cftype___9 *, s64);
	ssize_t (*write)(struct kernfs_open_file___15 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___15 *, struct poll_table_struct___12 *);
};

struct perf_cpu_context___9;

struct pmu___9 {
	struct list_head entry;
	struct module___16 *module;
	struct device___2 *dev;
	const struct attribute_group___15 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___9 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___9 *);
	void (*pmu_disable)(struct pmu___9 *);
	int (*event_init)(struct perf_event___9 *);
	void (*event_mapped)(struct perf_event___9 *, struct mm_struct___16 *);
	void (*event_unmapped)(struct perf_event___9 *, struct mm_struct___16 *);
	int (*add)(struct perf_event___9 *, int);
	void (*del)(struct perf_event___9 *, int);
	void (*start)(struct perf_event___9 *, int);
	void (*stop)(struct perf_event___9 *, int);
	void (*read)(struct perf_event___9 *);
	void (*start_txn)(struct pmu___9 *, unsigned int);
	int (*commit_txn)(struct pmu___9 *);
	void (*cancel_txn)(struct pmu___9 *);
	int (*event_idx)(struct perf_event___9 *);
	void (*sched_task)(struct perf_event_context___9 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___9 *);
	int (*filter_match)(struct perf_event___9 *);
	int (*check_period)(struct perf_event___9 *, u64);
};

struct perf_cpu_context___9 {
	struct perf_event_context___9 ctx;
	struct perf_event_context___9 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___9 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___9 {
	struct cgroup_subsys_state___9 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___9 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___9 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___9 *);
	struct list_head * (*get_fields)(struct trace_event_call___9 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___9 *);
};

struct trace_event_file___3;

struct trace_event_buffer___3 {
	struct ring_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___3 *trace_file;
	void *entry;
	long unsigned int flags;
	int pc;
};

struct trace_event_file___3 {
	struct list_head list;
	struct trace_event_call___9 *event_call;
	struct event_filter *filter;
	struct dentry___17 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_ipi_raise {
	struct trace_entry ent;
	u32 __data_loc_target_cpus;
	const char *reason;
	char __data[0];
};

struct trace_event_raw_ipi_handler {
	struct trace_entry ent;
	const char *reason;
	char __data[0];
};

struct trace_event_data_offsets_ipi_raise {
	u32 target_cpus;
};

struct trace_event_data_offsets_ipi_handler {};

enum ipi_msg_type {
	IPI_RESCHEDULE = 0,
	IPI_CALL_FUNC = 1,
	IPI_CPU_STOP = 2,
	IPI_CPU_CRASH_STOP = 3,
	IPI_TIMER = 4,
	IPI_IRQ_WORK = 5,
	IPI_WAKEUP = 6,
};

typedef __u64 __le64;

struct dyn_arch_ftrace {};

struct dyn_ftrace {
	long unsigned int ip;
	long unsigned int flags;
	struct dyn_arch_ftrace arch;
};

struct elf64_rela {
	Elf64_Addr r_offset;
	Elf64_Xword r_info;
	Elf64_Sxword r_addend;
};

typedef struct elf64_rela Elf64_Rela;

enum aarch64_reloc_op {
	RELOC_OP_NONE = 0,
	RELOC_OP_ABS = 1,
	RELOC_OP_PREL = 2,
	RELOC_OP_PAGE = 3,
};

enum aarch64_insn_movw_imm_type {
	AARCH64_INSN_IMM_MOVNZ = 0,
	AARCH64_INSN_IMM_MOVKZ = 1,
};

enum perf_sample_regs_abi {
	PERF_SAMPLE_REGS_ABI_NONE = 0,
	PERF_SAMPLE_REGS_ABI_32 = 1,
	PERF_SAMPLE_REGS_ABI_64 = 2,
};

enum perf_event_arm_regs {
	PERF_REG_ARM64_X0 = 0,
	PERF_REG_ARM64_X1 = 1,
	PERF_REG_ARM64_X2 = 2,
	PERF_REG_ARM64_X3 = 3,
	PERF_REG_ARM64_X4 = 4,
	PERF_REG_ARM64_X5 = 5,
	PERF_REG_ARM64_X6 = 6,
	PERF_REG_ARM64_X7 = 7,
	PERF_REG_ARM64_X8 = 8,
	PERF_REG_ARM64_X9 = 9,
	PERF_REG_ARM64_X10 = 10,
	PERF_REG_ARM64_X11 = 11,
	PERF_REG_ARM64_X12 = 12,
	PERF_REG_ARM64_X13 = 13,
	PERF_REG_ARM64_X14 = 14,
	PERF_REG_ARM64_X15 = 15,
	PERF_REG_ARM64_X16 = 16,
	PERF_REG_ARM64_X17 = 17,
	PERF_REG_ARM64_X18 = 18,
	PERF_REG_ARM64_X19 = 19,
	PERF_REG_ARM64_X20 = 20,
	PERF_REG_ARM64_X21 = 21,
	PERF_REG_ARM64_X22 = 22,
	PERF_REG_ARM64_X23 = 23,
	PERF_REG_ARM64_X24 = 24,
	PERF_REG_ARM64_X25 = 25,
	PERF_REG_ARM64_X26 = 26,
	PERF_REG_ARM64_X27 = 27,
	PERF_REG_ARM64_X28 = 28,
	PERF_REG_ARM64_X29 = 29,
	PERF_REG_ARM64_LR = 30,
	PERF_REG_ARM64_SP = 31,
	PERF_REG_ARM64_PC = 32,
	PERF_REG_ARM64_MAX = 33,
};

struct perf_callchain_entry_ctx {
	struct perf_callchain_entry *entry;
	u32 max_stack;
	u32 nr;
	short int contexts;
	bool contexts_maxed;
};

struct frame_tail {
	struct frame_tail *fp;
	long unsigned int lr;
};

struct pdev_archdata {};

struct device_attribute___3 {
	struct attribute attr;
	ssize_t (*show)(struct device___2 *, struct device_attribute___3 *, char *);
	ssize_t (*store)(struct device___2 *, struct device_attribute___3 *, const char *, size_t);
};

struct platform_device_id {
	char name[20];
	kernel_ulong_t driver_data;
};

enum irqreturn {
	IRQ_NONE = 0,
	IRQ_HANDLED = 1,
	IRQ_WAKE_THREAD = 2,
};

typedef enum irqreturn irqreturn_t;

enum perf_hw_id {
	PERF_COUNT_HW_CPU_CYCLES = 0,
	PERF_COUNT_HW_INSTRUCTIONS = 1,
	PERF_COUNT_HW_CACHE_REFERENCES = 2,
	PERF_COUNT_HW_CACHE_MISSES = 3,
	PERF_COUNT_HW_BRANCH_INSTRUCTIONS = 4,
	PERF_COUNT_HW_BRANCH_MISSES = 5,
	PERF_COUNT_HW_BUS_CYCLES = 6,
	PERF_COUNT_HW_STALLED_CYCLES_FRONTEND = 7,
	PERF_COUNT_HW_STALLED_CYCLES_BACKEND = 8,
	PERF_COUNT_HW_REF_CPU_CYCLES = 9,
	PERF_COUNT_HW_MAX = 10,
};

enum perf_hw_cache_id {
	PERF_COUNT_HW_CACHE_L1D = 0,
	PERF_COUNT_HW_CACHE_L1I = 1,
	PERF_COUNT_HW_CACHE_LL = 2,
	PERF_COUNT_HW_CACHE_DTLB = 3,
	PERF_COUNT_HW_CACHE_ITLB = 4,
	PERF_COUNT_HW_CACHE_BPU = 5,
	PERF_COUNT_HW_CACHE_NODE = 6,
	PERF_COUNT_HW_CACHE_MAX = 7,
};

enum perf_hw_cache_op_id {
	PERF_COUNT_HW_CACHE_OP_READ = 0,
	PERF_COUNT_HW_CACHE_OP_WRITE = 1,
	PERF_COUNT_HW_CACHE_OP_PREFETCH = 2,
	PERF_COUNT_HW_CACHE_OP_MAX = 3,
};

enum perf_hw_cache_op_result_id {
	PERF_COUNT_HW_CACHE_RESULT_ACCESS = 0,
	PERF_COUNT_HW_CACHE_RESULT_MISS = 1,
	PERF_COUNT_HW_CACHE_RESULT_MAX = 2,
};

struct perf_event_mmap_page {
	__u32 version;
	__u32 compat_version;
	__u32 lock;
	__u32 index;
	__s64 offset;
	__u64 time_enabled;
	__u64 time_running;
	union {
		__u64 capabilities;
		struct {
			__u64 cap_bit0: 1;
			__u64 cap_bit0_is_deprecated: 1;
			__u64 cap_user_rdpmc: 1;
			__u64 cap_user_time: 1;
			__u64 cap_user_time_zero: 1;
			__u64 cap_____res: 59;
		};
	};
	__u16 pmc_width;
	__u16 time_shift;
	__u32 time_mult;
	__u64 time_offset;
	__u64 time_zero;
	__u32 size;
	__u8 __reserved[948];
	__u64 data_head;
	__u64 data_tail;
	__u64 data_offset;
	__u64 data_size;
	__u64 aux_head;
	__u64 aux_tail;
	__u64 aux_offset;
	__u64 aux_size;
};

struct perf_pmu_events_attr {
	struct device_attribute___3 attr;
	u64 id;
	const char *event_str;
};

struct mfd_cell;

struct platform_device {
	const char *name;
	int id;
	bool id_auto;
	struct device___2 dev;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct platform_driver {
	int (*probe)(struct platform_device *);
	int (*remove)(struct platform_device *);
	void (*shutdown)(struct platform_device *);
	int (*suspend)(struct platform_device *, pm_message_t);
	int (*resume)(struct platform_device *);
	struct device_driver___15 driver;
	const struct platform_device_id *id_table;
	bool prevent_deferred_probe;
};

struct arm_pmu;

struct pmu_hw_events {
	struct perf_event___9 *events[32];
	long unsigned int used_mask[1];
	raw_spinlock_t pmu_lock;
	struct arm_pmu *percpu_pmu;
	int irq;
};

struct arm_pmu {
	struct pmu___9 pmu;
	cpumask_t supported_cpus;
	char *name;
	irqreturn_t (*handle_irq)(struct arm_pmu *);
	void (*enable)(struct perf_event___9 *);
	void (*disable)(struct perf_event___9 *);
	int (*get_event_idx)(struct pmu_hw_events *, struct perf_event___9 *);
	void (*clear_event_idx)(struct pmu_hw_events *, struct perf_event___9 *);
	int (*set_event_filter)(struct hw_perf_event___9 *, struct perf_event_attr *);
	u64 (*read_counter)(struct perf_event___9 *);
	void (*write_counter)(struct perf_event___9 *, u64);
	void (*start)(struct arm_pmu *);
	void (*stop)(struct arm_pmu *);
	void (*reset)(void *);
	int (*map_event)(struct perf_event___9 *);
	int (*filter_match)(struct perf_event___9 *);
	int num_events;
	bool secure_access;
	long unsigned int pmceid_bitmap[1];
	long unsigned int pmceid_ext_bitmap[1];
	struct platform_device *plat_device;
	struct pmu_hw_events *hw_events;
	struct hlist_node node;
	struct notifier_block cpu_pm_nb;
	const struct attribute_group___15 *attr_groups[4];
	long unsigned int acpi_cpuid;
};

enum armpmu_attr_groups {
	ARMPMU_ATTR_GROUP_COMMON = 0,
	ARMPMU_ATTR_GROUP_EVENTS = 1,
	ARMPMU_ATTR_GROUP_FORMATS = 2,
	ARMPMU_NR_ATTR_GROUPS = 3,
};

struct armv8pmu_probe_info {
	struct arm_pmu *pmu;
	bool present;
};

enum hw_breakpoint_ops {
	HW_BREAKPOINT_INSTALL = 0,
	HW_BREAKPOINT_UNINSTALL = 1,
	HW_BREAKPOINT_RESTORE = 2,
};

struct cpu_suspend_ctx {
	u64 ctx_regs[12];
	u64 sp;
	long: 64;
};

struct sleep_stack_data {
	struct cpu_suspend_ctx system_regs;
	long unsigned int callee_saved_regs[12];
};

typedef void *acpi_handle;

typedef u64 phys_cpuid_t;

struct cpuidle_state_usage {
	long long unsigned int disable;
	long long unsigned int usage;
	long long unsigned int time;
	long long unsigned int s2idle_usage;
	long long unsigned int s2idle_time;
};

struct cpuidle_device;

struct cpuidle_driver;

struct cpuidle_state {
	char name[16];
	char desc[32];
	unsigned int flags;
	unsigned int exit_latency;
	int power_usage;
	unsigned int target_residency;
	bool disabled;
	int (*enter)(struct cpuidle_device *, struct cpuidle_driver *, int);
	int (*enter_dead)(struct cpuidle_device *, int);
	void (*enter_s2idle)(struct cpuidle_device *, struct cpuidle_driver *, int);
};

struct cpuidle_state_kobj;

struct cpuidle_driver_kobj;

struct cpuidle_device_kobj;

struct cpuidle_device {
	unsigned int registered: 1;
	unsigned int enabled: 1;
	unsigned int use_deepest_state: 1;
	unsigned int poll_time_limit: 1;
	unsigned int cpu;
	int last_residency;
	int last_state_idx;
	struct cpuidle_state_usage states_usage[10];
	struct cpuidle_state_kobj *kobjs[10];
	struct cpuidle_driver_kobj *kobj_driver;
	struct cpuidle_device_kobj *kobj_dev;
	struct list_head device_list;
	u64 poll_limit_ns;
};

struct cpuidle_driver {
	const char *name;
	struct module___16 *owner;
	int refcnt;
	unsigned int bctimer: 1;
	struct cpuidle_state states[10];
	int state_count;
	int safe_state_index;
	struct cpumask *cpumask;
};

enum thermal_device_mode {
	THERMAL_DEVICE_DISABLED = 0,
	THERMAL_DEVICE_ENABLED = 1,
};

enum thermal_trip_type {
	THERMAL_TRIP_ACTIVE = 0,
	THERMAL_TRIP_PASSIVE = 1,
	THERMAL_TRIP_HOT = 2,
	THERMAL_TRIP_CRITICAL = 3,
};

enum thermal_trend {
	THERMAL_TREND_STABLE = 0,
	THERMAL_TREND_RAISING = 1,
	THERMAL_TREND_DROPPING = 2,
	THERMAL_TREND_RAISE_FULL = 3,
	THERMAL_TREND_DROP_FULL = 4,
};

enum thermal_notify_event {
	THERMAL_EVENT_UNSPECIFIED = 0,
	THERMAL_EVENT_TEMP_SAMPLE = 1,
	THERMAL_TRIP_VIOLATED = 2,
	THERMAL_TRIP_CHANGED = 3,
	THERMAL_DEVICE_DOWN = 4,
	THERMAL_DEVICE_UP = 5,
	THERMAL_DEVICE_POWER_CAPABILITY_CHANGED = 6,
	THERMAL_TABLE_CHANGED = 7,
};

struct thermal_zone_device;

struct thermal_cooling_device;

struct thermal_zone_device_ops {
	int (*bind)(struct thermal_zone_device *, struct thermal_cooling_device *);
	int (*unbind)(struct thermal_zone_device *, struct thermal_cooling_device *);
	int (*get_temp)(struct thermal_zone_device *, int *);
	int (*set_trips)(struct thermal_zone_device *, int, int);
	int (*get_mode)(struct thermal_zone_device *, enum thermal_device_mode *);
	int (*set_mode)(struct thermal_zone_device *, enum thermal_device_mode);
	int (*get_trip_type)(struct thermal_zone_device *, int, enum thermal_trip_type *);
	int (*get_trip_temp)(struct thermal_zone_device *, int, int *);
	int (*set_trip_temp)(struct thermal_zone_device *, int, int);
	int (*get_trip_hyst)(struct thermal_zone_device *, int, int *);
	int (*set_trip_hyst)(struct thermal_zone_device *, int, int);
	int (*get_crit_temp)(struct thermal_zone_device *, int *);
	int (*set_emul_temp)(struct thermal_zone_device *, int);
	int (*get_trend)(struct thermal_zone_device *, int, enum thermal_trend *);
	int (*notify)(struct thermal_zone_device *, int, enum thermal_trip_type);
};

struct thermal_attr;

struct thermal_zone_params;

struct thermal_governor;

struct thermal_zone_device {
	int id;
	char type[20];
	struct device___2 device;
	struct attribute_group___15 trips_attribute_group;
	struct thermal_attr *trip_temp_attrs;
	struct thermal_attr *trip_type_attrs;
	struct thermal_attr *trip_hyst_attrs;
	void *devdata;
	int trips;
	long unsigned int trips_disabled;
	int passive_delay;
	int polling_delay;
	int temperature;
	int last_temperature;
	int emul_temperature;
	int passive;
	int prev_low_trip;
	int prev_high_trip;
	unsigned int forced_passive;
	atomic_t need_update;
	struct thermal_zone_device_ops *ops;
	struct thermal_zone_params *tzp;
	struct thermal_governor *governor;
	void *governor_data;
	struct list_head thermal_instances;
	struct ida ida;
	struct mutex lock;
	struct list_head node;
	struct delayed_work poll_queue;
	enum thermal_notify_event notify_event;
};

struct thermal_cooling_device_ops;

struct thermal_cooling_device {
	int id;
	char type[20];
	struct device___2 device;
	struct device_node___5 *np;
	void *devdata;
	void *stats;
	const struct thermal_cooling_device_ops *ops;
	bool updated;
	struct mutex lock;
	struct list_head thermal_instances;
	struct list_head node;
};

struct thermal_cooling_device_ops {
	int (*get_max_state)(struct thermal_cooling_device *, long unsigned int *);
	int (*get_cur_state)(struct thermal_cooling_device *, long unsigned int *);
	int (*set_cur_state)(struct thermal_cooling_device *, long unsigned int);
	int (*get_requested_power)(struct thermal_cooling_device *, struct thermal_zone_device *, u32 *);
	int (*state2power)(struct thermal_cooling_device *, struct thermal_zone_device *, long unsigned int, u32 *);
	int (*power2state)(struct thermal_cooling_device *, struct thermal_zone_device *, u32, long unsigned int *);
};

struct thermal_attr {
	struct device_attribute___3 attr;
	char name[20];
};

struct thermal_bind_params;

struct thermal_zone_params {
	char governor_name[20];
	bool no_hwmon;
	int num_tbps;
	struct thermal_bind_params *tbp;
	u32 sustainable_power;
	s32 k_po;
	s32 k_pu;
	s32 k_i;
	s32 k_d;
	s32 integral_cutoff;
	int slope;
	int offset;
};

struct thermal_governor {
	char name[20];
	int (*bind_to_tz)(struct thermal_zone_device *);
	void (*unbind_from_tz)(struct thermal_zone_device *);
	int (*throttle)(struct thermal_zone_device *, int);
	struct list_head governor_list;
};

struct thermal_bind_params {
	struct thermal_cooling_device *cdev;
	int weight;
	int trip_mask;
	long unsigned int *binding_limits;
	int (*match)(struct thermal_zone_device *, struct thermal_cooling_device *);
};

struct acpi_processor_cx {
	u8 valid;
	u8 type;
	u32 address;
	u8 entry_method;
	u8 index;
	u32 latency;
	u8 bm_sts_skip;
	char desc[32];
};

struct acpi_lpi_state {
	u32 min_residency;
	u32 wake_latency;
	u32 flags;
	u32 arch_flags;
	u32 res_cnt_freq;
	u32 enable_parent_state;
	u64 address;
	u8 index;
	u8 entry_method;
	char desc[32];
};

struct acpi_processor_power {
	int count;
	union {
		struct acpi_processor_cx states[8];
		struct acpi_lpi_state lpi_states[8];
	};
	int timer_broadcast_on_state;
};

struct acpi_psd_package {
	u64 num_entries;
	u64 revision;
	u64 domain;
	u64 coord_type;
	u64 num_processors;
};

struct acpi_pct_register {
	u8 descriptor;
	u16 length;
	u8 space_id;
	u8 bit_width;
	u8 bit_offset;
	u8 reserved;
	u64 address;
} __attribute__((packed));

struct acpi_processor_px {
	u64 core_frequency;
	u64 power;
	u64 transition_latency;
	u64 bus_master_latency;
	u64 control;
	u64 status;
};

struct acpi_processor_performance {
	unsigned int state;
	unsigned int platform_limit;
	struct acpi_pct_register control_register;
	struct acpi_pct_register status_register;
	short: 16;
	unsigned int state_count;
	int: 32;
	struct acpi_processor_px *states;
	struct acpi_psd_package domain_info;
	cpumask_var_t shared_cpu_map;
	unsigned int shared_type;
	int: 32;
} __attribute__((packed));

struct acpi_tsd_package {
	u64 num_entries;
	u64 revision;
	u64 domain;
	u64 coord_type;
	u64 num_processors;
};

struct acpi_processor_tx_tss {
	u64 freqpercentage;
	u64 power;
	u64 transition_latency;
	u64 control;
	u64 status;
};

struct acpi_processor_tx {
	u16 power;
	u16 performance;
};

struct acpi_processor;

struct acpi_processor_throttling {
	unsigned int state;
	unsigned int platform_limit;
	struct acpi_pct_register control_register;
	struct acpi_pct_register status_register;
	short: 16;
	unsigned int state_count;
	int: 32;
	struct acpi_processor_tx_tss *states_tss;
	struct acpi_tsd_package domain_info;
	cpumask_var_t shared_cpu_map;
	int (*acpi_processor_get_throttling)(struct acpi_processor *);
	int (*acpi_processor_set_throttling)(struct acpi_processor *, int, bool);
	u32 address;
	u8 duty_offset;
	u8 duty_width;
	u8 tsd_valid_flag;
	char: 8;
	unsigned int shared_type;
	struct acpi_processor_tx states[16];
	int: 32;
} __attribute__((packed));

struct acpi_processor_flags {
	u8 power: 1;
	u8 performance: 1;
	u8 throttling: 1;
	u8 limit: 1;
	u8 bm_control: 1;
	u8 bm_check: 1;
	u8 has_cst: 1;
	u8 has_lpi: 1;
	u8 power_setup_done: 1;
	u8 bm_rld_set: 1;
	u8 need_hotplug_init: 1;
};

struct acpi_processor_lx {
	int px;
	int tx;
};

struct acpi_processor_limit {
	struct acpi_processor_lx state;
	struct acpi_processor_lx thermal;
	struct acpi_processor_lx user;
};

struct acpi_processor {
	acpi_handle handle;
	u32 acpi_id;
	phys_cpuid_t phys_id;
	u32 id;
	u32 pblk;
	int performance_platform_limit;
	int throttling_platform_limit;
	struct acpi_processor_flags flags;
	struct acpi_processor_power power;
	struct acpi_processor_performance *performance;
	struct acpi_processor_throttling throttling;
	struct acpi_processor_limit limit;
	struct thermal_cooling_device *cdev;
	struct device___2 *dev;
};

struct acpi_processor_errata {
	u8 smp;
	struct {
		u8 throttle: 1;
		u8 fdma: 1;
		u8 reserved: 6;
		u32 bmisx;
	} piix4;
};

enum jump_label_type {
	JUMP_LABEL_NOP = 0,
	JUMP_LABEL_JMP = 1,
};

struct module___17;

struct file___17;

struct kiocb___17;

struct vm_area_struct___17;

struct inode___19;

struct file_lock___17;

struct page___17;

struct file_operations___17 {
	struct module___17 *owner;
	loff_t (*llseek)(struct file___17 *, loff_t, int);
	ssize_t (*read)(struct file___17 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___17 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___17 *, struct iov_iter___6 *);
	ssize_t (*write_iter)(struct kiocb___17 *, struct iov_iter___6 *);
	int (*iopoll)(struct kiocb___17 *, bool);
	int (*iterate)(struct file___17 *, struct dir_context *);
	int (*iterate_shared)(struct file___17 *, struct dir_context *);
	__poll_t (*poll)(struct file___17 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___17 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___17 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___17 *, struct vm_area_struct___17 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___19 *, struct file___17 *);
	int (*flush)(struct file___17 *, fl_owner_t);
	int (*release)(struct inode___19 *, struct file___17 *);
	int (*fsync)(struct file___17 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___17 *, int);
	int (*lock)(struct file___17 *, int, struct file_lock___17 *);
	ssize_t (*sendpage)(struct file___17 *, struct page___17 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___17 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___17 *, int, struct file_lock___17 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___17 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___17 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___17 *, long int, struct file_lock___17 **, void **);
	long int (*fallocate)(struct file___17 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___17 *);
	ssize_t (*copy_file_range)(struct file___17 *, loff_t, struct file___17 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___17 *, loff_t, struct file___17 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___17 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___16 {
	u64 seqnum;
	struct vm_area_struct___17 *vmas[4];
};

struct page_frag___16 {
	struct page___17 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___17;

struct pid___15;

struct cred___16;

struct nsproxy___16;

struct signal_struct___15;

struct vm_struct___13;

struct task_struct___18 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___18 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___17 *mm;
	struct mm_struct___17 *active_mm;
	struct vmacache___16 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___18 *real_parent;
	struct task_struct___18 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___18 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___15 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___15 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___15 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___16 *ptracer_cred;
	const struct cred___16 *real_cred;
	const struct cred___16 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___16 *nsproxy;
	struct signal_struct___15 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___18 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___2 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___16 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___18 *oom_reaper_list;
	struct vm_struct___13 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___9 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___17 *pgtable_t___16;

struct address_space___16;

struct dev_pagemap___16;

struct page___17 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___16 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___17 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___16 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___17 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___16 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___16;

struct lruvec___16 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___16 *pgdat;
};

struct zone___16 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___16 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___16 {
	struct zone___16 *zone;
	int zone_idx;
};

struct zonelist___16 {
	struct zoneref___16 _zonerefs[25];
};

struct pglist_data___16 {
	struct zone___16 node_zones[3];
	struct zonelist___16 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___18 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___18 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___16 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___17 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___18 *owner;
};

struct secondary_data___17 {
	void *stack;
	struct task_struct___18 *task;
	long int status;
};

struct blocking_notifier_head___16 {
	struct rw_semaphore___17 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___16;

struct vm_area_struct___17 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___17 *vm_next;
	struct vm_area_struct___17 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___17 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___16 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___17 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___16;

struct mm_struct___17 {
	struct {
		struct vm_area_struct___17 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___17 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___17 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___16 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___18 *owner;
		struct user_namespace___3 *user_ns;
		struct file___17 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___16 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___16;

struct address_space___16 {
	struct inode___19 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___17 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___16 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___16)(struct vm_area_struct___17 *, long unsigned int, const struct page___17 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___16)(struct page___17 *, void *);

struct dev_pagemap___16 {
	dev_page_fault_t___16 page_fault;
	dev_page_free_t___16 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___6 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct dentry___18;

struct path___16 {
	struct vfsmount *mnt;
	struct dentry___18 *dentry;
};

struct fown_struct___15 {
	rwlock_t lock;
	struct pid___15 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___17 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___16 f_path;
	struct inode___19 *f_inode;
	const struct file_operations___17 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___15 f_owner;
	const struct cred___16 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___16 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___16;

struct vm_operations_struct___16 {
	void (*open)(struct vm_area_struct___17 *);
	void (*close)(struct vm_area_struct___17 *);
	int (*split)(struct vm_area_struct___17 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___17 *);
	vm_fault_t (*fault)(struct vm_fault___16 *);
	vm_fault_t (*huge_fault)(struct vm_fault___16 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___16 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___17 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___16 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___16 *);
	int (*access)(struct vm_area_struct___17 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___17 *);
	int (*set_policy)(struct vm_area_struct___17 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___17 *, long unsigned int);
	struct page___17 * (*find_special_page)(struct vm_area_struct___17 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___16 {
	struct task_struct___18 *task;
	struct core_thread___16 *next;
};

struct core_state___16 {
	atomic_t nr_threads;
	struct core_thread___16 dumper;
	struct completion startup;
};

struct vm_fault___16 {
	struct vm_area_struct___17 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___17 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___17 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___16 prealloc_pte;
};

struct pid_namespace___15;

struct upid___15 {
	int nr;
	struct pid_namespace___15 *ns;
};

struct pid_namespace___15 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___18 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___15 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___18 *proc_self;
	struct dentry___18 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___3 *user_ns;
	struct ucounts___2 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common ns;
};

struct pid___15 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___15 numbers[1];
};

struct key___17;

struct user_struct___16 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___17 *uid_keyring;
	struct key___17 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___16 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___17 *session_keyring;
	struct key___17 *process_keyring;
	struct key___17 *thread_keyring;
	struct key___17 *request_key_auth;
	void *security;
	struct user_struct___16 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct nsproxy___16 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___15 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct signal_struct___15 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___18 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___18 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___15 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___15 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___17 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___15 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_struct___13 {
	struct vm_struct___13 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___17 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___15 {
	struct task_struct___18 task;
	long unsigned int stack[8192];
};

struct kernfs_root___16;

struct kernfs_elem_dir___16 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___16 *root;
};

struct kernfs_node___16;

struct kernfs_syscall_ops___16;

struct kernfs_root___16 {
	struct kernfs_node___16 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___16 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___16 {
	struct kernfs_node___16 *target_kn;
};

struct kernfs_ops___16;

struct kernfs_elem_attr___16 {
	const struct kernfs_ops___16 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___16 *notify_next;
};

struct kernfs_node___16 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___16 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___16 dir;
		struct kernfs_elem_symlink___16 symlink;
		struct kernfs_elem_attr___16 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___16;

struct kernfs_ops___16 {
	int (*open)(struct kernfs_open_file___16 *);
	void (*release)(struct kernfs_open_file___16 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___16 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___16 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___16 *, struct vm_area_struct___17 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___16 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___16 {
	int (*remount_fs)(struct kernfs_root___16 *, int *, char *);
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___16 *);
	int (*mkdir)(struct kernfs_node___16 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___16 *);
	int (*rename)(struct kernfs_node___16 *, struct kernfs_node___16 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___16 *, struct kernfs_root___16 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___16 {
	struct kernfs_node___16 *kn;
	struct file___17 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___16 *vm_ops;
};

struct kset___16;

struct kobj_type___16;

struct kobject___16 {
	const char *name;
	struct list_head entry;
	struct kobject___16 *parent;
	struct kset___16 *kset;
	struct kobj_type___16 *ktype;
	struct kernfs_node___16 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sysfs_ops___16 {
	ssize_t (*show)(struct kobject___16 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___16 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___16;

struct kset___16 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___16 kobj;
	const struct kset_uevent_ops___16 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___16 {
	void (*release)(struct kobject___16 *);
	const struct sysfs_ops___16 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___16 *);
	const void * (*namespace)(struct kobject___16 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___16 {
	int (* const filter)(struct kset___16 *, struct kobject___16 *);
	const char * (* const name)(struct kset___16 *, struct kobject___16 *);
	int (* const uevent)(struct kset___16 *, struct kobject___16 *, struct kobj_uevent_env *);
};

struct kobj_attribute___16 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___16 *, struct kobj_attribute___16 *, char *);
	ssize_t (*store)(struct kobject___16 *, struct kobj_attribute___16 *, const char *, size_t);
};

struct module_kobject___14 {
	struct kobject___16 kobj;
	struct module___17 *mod;
	struct kobject___16 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___14 {
	struct module___17 *mod;
	struct latch_tree_node node;
};

struct module_layout___14 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___14 mtn;
};

struct module_attribute___14;

struct kernel_param___14;

struct module___17 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___14 mkobj;
	struct module_attribute___14 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___16 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___14 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___14 core_layout;
	struct module_layout___14 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct die_args {
	struct pt_regs *regs;
	const char *str;
	long int err;
	int trapnr;
	int signr;
};

typedef int (*key_restrict_link_func_t___16)(struct key___17 *, const struct key_type *, const union key_payload *, struct key___17 *);

struct key_restriction___17;

struct key___17 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___17 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___17 *restrict_link;
};

struct key_restriction___17 {
	key_restrict_link_func_t___16 check;
	struct key___17 *key;
	struct key_type *keytype;
};

struct dentry_operations___16;

struct super_block___17;

struct dentry___18 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___18 *d_parent;
	struct qstr d_name;
	struct inode___19 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___16 *d_op;
	struct super_block___17 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___16;

struct block_device___17;

struct inode___19 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___16 *i_op;
	struct super_block___17 *i_sb;
	struct address_space___16 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___17 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___17 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___16 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___17 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___16 {
	int (*d_revalidate)(struct dentry___18 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___18 *, unsigned int);
	int (*d_hash)(const struct dentry___18 *, struct qstr *);
	int (*d_compare)(const struct dentry___18 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___18 *);
	int (*d_init)(struct dentry___18 *);
	void (*d_release)(struct dentry___18 *);
	void (*d_prune)(struct dentry___18 *);
	void (*d_iput)(struct dentry___18 *, struct inode___19 *);
	char * (*d_dname)(struct dentry___18 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___16 *);
	int (*d_manage)(const struct path___16 *, bool);
	struct dentry___18 * (*d_real)(struct dentry___18 *, const struct inode___19 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___16;

struct mem_dqinfo___16 {
	struct quota_format_type___16 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___16;

struct quota_info___16 {
	unsigned int flags;
	struct rw_semaphore___17 dqio_sem;
	struct inode___19 *files[3];
	struct mem_dqinfo___16 info[3];
	const struct quota_format_ops___16 *ops[3];
};

struct rcuwait___16 {
	struct task_struct___18 *task;
};

struct percpu_rw_semaphore___16 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___17 rw_sem;
	struct rcuwait___16 writer;
	int readers_block;
};

struct sb_writers___16 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___16 rw_sem[3];
};

struct file_system_type___16;

struct super_operations___16;

struct dquot_operations___16;

struct quotactl_ops___16;

struct super_block___17 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___16 *s_type;
	const struct super_operations___16 *s_op;
	const struct dquot_operations___16 *dq_op;
	const struct quotactl_ops___16 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___18 *s_root;
	struct rw_semaphore___17 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___17 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___16 s_dquot;
	struct sb_writers___16 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___16 *s_d_op;
	int cleancache_poolid;
	struct shrinker___4 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___17 {
	struct file___17 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___17 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___17 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___17 *ia_file;
};

struct dquot___16 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___17 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___16 {
	int qf_fmt_id;
	const struct quota_format_ops___16 *qf_ops;
	struct module___17 *qf_owner;
	struct quota_format_type___16 *qf_next;
};

struct quota_format_ops___16 {
	int (*check_quota_file)(struct super_block___17 *, int);
	int (*read_file_info)(struct super_block___17 *, int);
	int (*write_file_info)(struct super_block___17 *, int);
	int (*free_file_info)(struct super_block___17 *, int);
	int (*read_dqblk)(struct dquot___16 *);
	int (*commit_dqblk)(struct dquot___16 *);
	int (*release_dqblk)(struct dquot___16 *);
	int (*get_next_id)(struct super_block___17 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___16 {
	int (*write_dquot)(struct dquot___16 *);
	struct dquot___16 * (*alloc_dquot)(struct super_block___17 *, int);
	void (*destroy_dquot)(struct dquot___16 *);
	int (*acquire_dquot)(struct dquot___16 *);
	int (*release_dquot)(struct dquot___16 *);
	int (*mark_dirty)(struct dquot___16 *);
	int (*write_info)(struct super_block___17 *, int);
	qsize_t * (*get_reserved_space)(struct inode___19 *);
	int (*get_projid)(struct inode___19 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___19 *, qsize_t *);
	int (*get_next_id)(struct super_block___17 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___16 {
	int (*quota_on)(struct super_block___17 *, int, int, const struct path___16 *);
	int (*quota_off)(struct super_block___17 *, int);
	int (*quota_enable)(struct super_block___17 *, unsigned int);
	int (*quota_disable)(struct super_block___17 *, unsigned int);
	int (*quota_sync)(struct super_block___17 *, int);
	int (*set_info)(struct super_block___17 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___17 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___17 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___17 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___17 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___17 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___16 {
	int (*writepage)(struct page___17 *, struct writeback_control___3 *);
	int (*readpage)(struct file___17 *, struct page___17 *);
	int (*writepages)(struct address_space___16 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___17 *);
	int (*readpages)(struct file___17 *, struct address_space___16 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___17 *, struct address_space___16 *, loff_t, unsigned int, unsigned int, struct page___17 **, void **);
	int (*write_end)(struct file___17 *, struct address_space___16 *, loff_t, unsigned int, unsigned int, struct page___17 *, void *);
	sector_t (*bmap)(struct address_space___16 *, sector_t);
	void (*invalidatepage)(struct page___17 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___17 *, gfp_t);
	void (*freepage)(struct page___17 *);
	ssize_t (*direct_IO)(struct kiocb___17 *, struct iov_iter___6 *);
	int (*migratepage)(struct address_space___16 *, struct page___17 *, struct page___17 *, enum migrate_mode);
	bool (*isolate_page)(struct page___17 *, isolate_mode_t);
	void (*putback_page)(struct page___17 *);
	int (*launder_page)(struct page___17 *);
	int (*is_partially_uptodate)(struct page___17 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___17 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___16 *, struct page___17 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___17 *, sector_t *);
	void (*swap_deactivate)(struct file___17 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___17 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___19 *bd_inode;
	struct super_block___17 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___17 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___16 {
	struct dentry___18 * (*lookup)(struct inode___19 *, struct dentry___18 *, unsigned int);
	const char * (*get_link)(struct dentry___18 *, struct inode___19 *, struct delayed_call *);
	int (*permission)(struct inode___19 *, int);
	struct posix_acl * (*get_acl)(struct inode___19 *, int);
	int (*readlink)(struct dentry___18 *, char *, int);
	int (*create)(struct inode___19 *, struct dentry___18 *, umode_t, bool);
	int (*link)(struct dentry___18 *, struct inode___19 *, struct dentry___18 *);
	int (*unlink)(struct inode___19 *, struct dentry___18 *);
	int (*symlink)(struct inode___19 *, struct dentry___18 *, const char *);
	int (*mkdir)(struct inode___19 *, struct dentry___18 *, umode_t);
	int (*rmdir)(struct inode___19 *, struct dentry___18 *);
	int (*mknod)(struct inode___19 *, struct dentry___18 *, umode_t, dev_t);
	int (*rename)(struct inode___19 *, struct dentry___18 *, struct inode___19 *, struct dentry___18 *, unsigned int);
	int (*setattr)(struct dentry___18 *, struct iattr___17 *);
	int (*getattr)(const struct path___16 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___18 *, char *, size_t);
	int (*fiemap)(struct inode___19 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___19 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___19 *, struct dentry___18 *, struct file___17 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___19 *, struct dentry___18 *, umode_t);
	int (*set_acl)(struct inode___19 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___16 {
	void (*fl_copy_lock)(struct file_lock___17 *, struct file_lock___17 *);
	void (*fl_release_private)(struct file_lock___17 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___16;

struct lock_manager_operations___16;

struct file_lock___17 {
	struct file_lock___17 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___17 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___16 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___16 *fl_ops;
	const struct lock_manager_operations___16 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___16 {
	int (*lm_compare_owner)(struct file_lock___17 *, struct file_lock___17 *);
	long unsigned int (*lm_owner_key)(struct file_lock___17 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___17 *);
	int (*lm_grant)(struct file_lock___17 *, int);
	bool (*lm_break)(struct file_lock___17 *);
	int (*lm_change)(struct file_lock___17 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___17 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___16 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___16 *fa_next;
	struct file___17 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___16 {
	const char *name;
	int fs_flags;
	struct dentry___18 * (*mount)(struct file_system_type___16 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___17 *);
	struct module___17 *owner;
	struct file_system_type___16 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___16 {
	struct inode___19 * (*alloc_inode)(struct super_block___17 *);
	void (*destroy_inode)(struct inode___19 *);
	void (*dirty_inode)(struct inode___19 *, int);
	int (*write_inode)(struct inode___19 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___19 *);
	void (*evict_inode)(struct inode___19 *);
	void (*put_super)(struct super_block___17 *);
	int (*sync_fs)(struct super_block___17 *, int);
	int (*freeze_super)(struct super_block___17 *);
	int (*freeze_fs)(struct super_block___17 *);
	int (*thaw_super)(struct super_block___17 *);
	int (*unfreeze_fs)(struct super_block___17 *);
	int (*statfs)(struct dentry___18 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___17 *, int *, char *);
	void (*umount_begin)(struct super_block___17 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___18 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___18 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___18 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___18 *);
	ssize_t (*quota_read)(struct super_block___17 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___17 *, int, const char *, size_t, loff_t);
	struct dquot___16 ** (*get_dquots)(struct inode___19 *);
	int (*bdev_try_to_free_page)(struct super_block___17 *, struct page___17 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___17 *, struct shrink_control___4 *);
	long int (*free_cached_objects)(struct super_block___17 *, struct shrink_control___4 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___16(struct page___17 *);

enum kgdb_bpstate {
	BP_UNDEFINED = 0,
	BP_REMOVED = 1,
	BP_SET = 2,
	BP_ACTIVE = 3,
};

struct kgdb_bkpt {
	long unsigned int bpt_addr;
	unsigned char saved_instr[4];
	enum kgdb_bptype type;
	enum kgdb_bpstate state;
};

struct kernel_param_ops___14 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___14 *);
	int (*get)(char *, const struct kernel_param___14 *);
	void (*free)(void *);
};

struct kparam_array___14;

struct kernel_param___14 {
	const char *name;
	struct module___17 *mod;
	const struct kernel_param_ops___14 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___14 *arr;
	};
};

struct kparam_array___14 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___14 *ops;
	void *elem;
};

struct module_attribute___14 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___14 *, struct module_kobject___14 *, char *);
	ssize_t (*store)(struct module_attribute___14 *, struct module_kobject___14 *, const char *, size_t);
	void (*setup)(struct module___17 *, const char *);
	int (*test)(struct module___17 *);
	void (*free)(struct module___17 *);
};

struct resource_entry {
	struct list_head node;
	struct resource *res;
	resource_size_t offset;
	struct resource __res;
};

typedef u64 acpi_io_address;

typedef u32 acpi_object_type;

union acpi_object {
	acpi_object_type type;
	struct {
		acpi_object_type type;
		u64 value;
	} integer;
	struct {
		acpi_object_type type;
		u32 length;
		char *pointer;
	} string;
	struct {
		acpi_object_type type;
		u32 length;
		u8 *pointer;
	} buffer;
	struct {
		acpi_object_type type;
		u32 count;
		union acpi_object *elements;
	} package;
	struct {
		acpi_object_type type;
		acpi_object_type actual_type;
		acpi_handle handle;
	} reference;
	struct {
		acpi_object_type type;
		u32 proc_id;
		acpi_io_address pblk_address;
		u32 pblk_length;
	} processor;
	struct {
		acpi_object_type type;
		u32 system_level;
		u32 resource_order;
	} power_resource;
};

struct pci_device_id {
	__u32 vendor;
	__u32 device;
	__u32 subvendor;
	__u32 subdevice;
	__u32 class;
	__u32 class_mask;
	kernel_ulong_t driver_data;
};

struct acpi_device;

struct acpi_hotplug_profile {
	struct kobject___15 kobj;
	int (*scan_dependent)(struct acpi_device *);
	void (*notify_online)(struct acpi_device *);
	bool enabled: 1;
	bool demand_offline: 1;
};

struct acpi_device_status {
	u32 present: 1;
	u32 enabled: 1;
	u32 show_in_ui: 1;
	u32 functional: 1;
	u32 battery_present: 1;
	u32 reserved: 27;
};

struct acpi_device_flags {
	u32 dynamic_status: 1;
	u32 removable: 1;
	u32 ejectable: 1;
	u32 power_manageable: 1;
	u32 match_driver: 1;
	u32 initialized: 1;
	u32 visited: 1;
	u32 hotplug_notify: 1;
	u32 is_dock_station: 1;
	u32 of_compatible_ok: 1;
	u32 coherent_dma: 1;
	u32 cca_seen: 1;
	u32 enumeration_by_parent: 1;
	u32 reserved: 19;
};

typedef char acpi_bus_id[8];

struct acpi_pnp_type {
	u32 hardware_id: 1;
	u32 bus_address: 1;
	u32 platform_id: 1;
	u32 reserved: 29;
};

typedef long unsigned int acpi_bus_address;

typedef char acpi_device_name[40];

typedef char acpi_device_class[20];

struct acpi_device_pnp {
	acpi_bus_id bus_id;
	struct acpi_pnp_type type;
	acpi_bus_address bus_address;
	char *unique_id;
	struct list_head ids;
	acpi_device_name device_name;
	acpi_device_class device_class;
	union acpi_object *str_obj;
};

struct acpi_device_power_flags {
	u32 explicit_get: 1;
	u32 power_resources: 1;
	u32 inrush_current: 1;
	u32 power_removed: 1;
	u32 ignore_parent: 1;
	u32 dsw_present: 1;
	u32 reserved: 26;
};

struct acpi_device_power_state {
	struct {
		u8 valid: 1;
		u8 explicit_set: 1;
		u8 reserved: 6;
	} flags;
	int power;
	int latency;
	struct list_head resources;
};

struct acpi_device_power {
	int state;
	struct acpi_device_power_flags flags;
	struct acpi_device_power_state states[5];
};

struct acpi_device_wakeup_flags {
	u8 valid: 1;
	u8 notifier_present: 1;
};

struct acpi_device_wakeup_context {
	void (*func)(struct acpi_device_wakeup_context *);
	struct device___2 *dev;
};

struct acpi_device_wakeup {
	acpi_handle gpe_device;
	u64 gpe_number;
	u64 sleep_state;
	struct list_head resources;
	struct acpi_device_wakeup_flags flags;
	struct acpi_device_wakeup_context context;
	struct wakeup_source *ws;
	int prepare_count;
	int enable_count;
};

struct acpi_device_perf_flags {
	u8 reserved: 8;
};

struct acpi_device_perf_state;

struct acpi_device_perf {
	int state;
	struct acpi_device_perf_flags flags;
	int state_count;
	struct acpi_device_perf_state *states;
};

struct acpi_device_dir {
	struct proc_dir_entry *entry;
};

struct acpi_device_data {
	const union acpi_object *pointer;
	struct list_head properties;
	const union acpi_object *of_compatible;
	struct list_head subnodes;
};

struct acpi_scan_handler;

struct acpi_hotplug_context;

struct acpi_driver;

struct acpi_gpio_mapping;

struct acpi_device {
	int device_type;
	acpi_handle handle;
	struct fwnode_handle___12 fwnode;
	struct acpi_device *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_device_data data;
	struct acpi_scan_handler *handler;
	struct acpi_hotplug_context *hp;
	struct acpi_driver *driver;
	const struct acpi_gpio_mapping *driver_gpios;
	void *driver_data;
	struct device___2 dev;
	unsigned int physical_node_count;
	unsigned int dep_unmet;
	struct list_head physical_node_list;
	struct mutex physical_node_lock;
	void (*remove)(struct acpi_device *);
};

struct acpi_scan_handler {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	bool (*match)(const char *, const struct acpi_device_id **);
	int (*attach)(struct acpi_device *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device *);
	void (*bind)(struct device___2 *);
	void (*unbind)(struct device___2 *);
	struct acpi_hotplug_profile hotplug;
};

struct acpi_hotplug_context {
	struct acpi_device *self;
	int (*notify)(struct acpi_device *, u32);
	void (*uevent)(struct acpi_device *, u32);
	void (*fixup)(struct acpi_device *);
};

typedef int (*acpi_op_add)(struct acpi_device *);

typedef int (*acpi_op_remove)(struct acpi_device *);

typedef void (*acpi_op_notify)(struct acpi_device *, u32);

struct acpi_device_ops {
	acpi_op_add add;
	acpi_op_remove remove;
	acpi_op_notify notify;
};

struct acpi_driver {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops ops;
	struct device_driver___15 drv;
	struct module___16 *owner;
};

struct acpi_device_perf_state {
	struct {
		u8 valid: 1;
		u8 reserved: 7;
	} flags;
	u8 power;
	u8 performance;
	int latency;
};

struct acpi_gpio_params;

struct acpi_gpio_mapping {
	const char *name;
	const struct acpi_gpio_params *data;
	unsigned int size;
	unsigned int quirks;
};

struct pci_bus;

struct acpi_pci_root {
	struct acpi_device *device;
	struct pci_bus *bus;
	u16 segment;
	struct resource secondary;
	u32 osc_support_set;
	u32 osc_control_set;
	phys_addr_t mcfg_addr;
};

typedef short unsigned int pci_bus_flags_t;

struct pci_dev;

struct pci_ops;

struct msi_controller;

struct pci_bus {
	struct list_head node;
	struct pci_bus *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops *ops;
	struct msi_controller *msi;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	int domain_nr;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___2 *bridge;
	struct device___2 dev;
	struct bin_attribute___15 *legacy_io;
	struct bin_attribute___15 *legacy_mem;
	unsigned int is_added: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
};

struct irq_affinity_desc {
	struct cpumask mask;
	unsigned int is_managed: 1;
};

struct acpi_gpio_params {
	unsigned int crs_entry_index;
	unsigned int line_index;
	bool active_low;
};

struct hotplug_slot;

struct pci_slot {
	struct pci_bus *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject___15 kobj;
};

enum {
	PCI_STD_RESOURCES = 0,
	PCI_STD_RESOURCE_END = 5,
	PCI_ROM_RESOURCE = 6,
	PCI_IOV_RESOURCES = 7,
	PCI_IOV_RESOURCE_END = 12,
	PCI_BRIDGE_RESOURCES = 13,
	PCI_BRIDGE_RESOURCE_END = 16,
	PCI_NUM_RESOURCES = 17,
	DEVICE_COUNT_RESOURCE = 17,
};

typedef int pci_power_t;

typedef unsigned int pci_channel_state_t;

enum pci_channel_state {
	pci_channel_io_normal = 1,
	pci_channel_io_frozen = 2,
	pci_channel_io_perm_failure = 3,
};

typedef unsigned int pcie_reset_state_t;

typedef short unsigned int pci_dev_flags_t;

struct pci_dev_extended_rh {};

struct aer_stats;

struct pci_p2pdma;

struct pci_driver;

struct pcie_link_state;

struct pci_vpd;

struct pci_sriov;

struct pci_dev {
	struct list_head bus_list;
	struct pci_bus *bus;
	struct pci_bus *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u16 aer_cap;
	struct aer_stats *aer_stats;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	long unsigned int *dma_alias_mask;
	struct pci_driver *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	unsigned int imm_ready: 1;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int bridge_d3: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int hotplug_user_indicators: 1;
	unsigned int clear_retrain_link: 1;
	unsigned int d3_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	unsigned int ltr_path: 1;
	unsigned int eetlp_prefix_path: 1;
	pci_channel_state_t error_state;
	struct device___2 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int multifunction: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int ats_enabled: 1;
	unsigned int pasid_enabled: 1;
	unsigned int pri_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int reset_fn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int shpc_managed: 1;
	unsigned int is_thunderbolt: 1;
	unsigned int __aer_firmware_first_valid: 1;
	unsigned int __aer_firmware_first: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int irq_managed: 1;
	unsigned int has_secondary_link: 1;
	unsigned int non_compliant_bars: 1;
	unsigned int is_probed: 1;
	unsigned int link_active_reporting: 1;
	unsigned int untrusted: 1;
	unsigned int no_vf_scan: 1;
	unsigned int io_window: 1;
	unsigned int pref_window: 1;
	unsigned int pref_64_window: 1;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	struct bin_attribute___15 *rom_attr;
	int rom_attr_enabled;
	struct bin_attribute___15 *res_attr[17];
	struct bin_attribute___15 *res_attr_wc[17];
	unsigned int broken_cmd_compl: 1;
	const struct attribute_group___15 **msi_irq_groups;
	struct pci_vpd *vpd;
	union {
		struct pci_sriov *sriov;
		struct pci_dev *physfn;
	};
	u16 ats_cap;
	u8 ats_stu;
	atomic_t ats_ref_cnt;
	u32 pri_reqs_alloc;
	u16 pasid_features;
	struct pci_p2pdma *p2pdma;
	phys_addr_t rom;
	size_t romlen;
	char *driver_override;
	long unsigned int priv_flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t pci_dev_extended_size_rh;
	struct pci_dev_extended_rh pci_dev_extended_rh;
};

struct pci_dynids {
	spinlock_t lock;
	struct list_head list;
};

struct pci_error_handlers;

struct pci_driver {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev *, const struct pci_device_id *);
	void (*remove)(struct pci_dev *);
	int (*suspend)(struct pci_dev *, pm_message_t);
	int (*suspend_late)(struct pci_dev *, pm_message_t);
	int (*resume_early)(struct pci_dev *);
	int (*resume)(struct pci_dev *);
	void (*shutdown)(struct pci_dev *);
	int (*sriov_configure)(struct pci_dev *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	const struct pci_error_handlers *err_handler;
	const struct attribute_group___15 **groups;
	struct device_driver___15 driver;
	struct pci_dynids dynids;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct pci_host_bridge {
	struct device___2 dev;
	struct pci_bus *bus;
	struct pci_ops *ops;
	void *sysdata;
	int busnr;
	struct list_head windows;
	u8 (*swizzle_irq)(struct pci_dev *, u8 *);
	int (*map_irq)(const struct pci_dev *, u8, u8);
	void (*release_fn)(struct pci_host_bridge *);
	void *release_data;
	struct msi_controller *msi;
	unsigned int ignore_reset_delay: 1;
	unsigned int no_ext_tags: 1;
	unsigned int native_aer: 1;
	unsigned int native_pcie_hotplug: 1;
	unsigned int native_shpc_hotplug: 1;
	unsigned int native_pme: 1;
	unsigned int native_ltr: 1;
	resource_size_t (*align_resource)(struct pci_dev *, const struct resource *, resource_size_t, resource_size_t, resource_size_t);
	long: 64;
	long unsigned int private[0];
};

struct pci_ops {
	int (*add_bus)(struct pci_bus *);
	void (*remove_bus)(struct pci_bus *);
	void * (*map_bus)(struct pci_bus *, unsigned int, int);
	int (*read)(struct pci_bus *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus *, unsigned int, int, int, u32);
};

struct msi_desc___2;

struct msi_controller {
	struct module___16 *owner;
	struct device___2 *dev;
	struct device_node___5 *of_node;
	struct list_head list;
	int (*setup_irq)(struct msi_controller *, struct pci_dev *, struct msi_desc___2 *);
	int (*setup_irqs)(struct msi_controller *, struct pci_dev *, int, int);
	void (*teardown_irq)(struct msi_controller *, unsigned int);
};

typedef unsigned int pci_ers_result_t;

struct pci_error_handlers {
	pci_ers_result_t (*error_detected)(struct pci_dev *, enum pci_channel_state);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev *);
	pci_ers_result_t (*slot_reset)(struct pci_dev *);
	void (*reset_prepare)(struct pci_dev *);
	void (*reset_done)(struct pci_dev *);
	void (*resume)(struct pci_dev *);
};

enum pcie_bus_config_types {
	PCIE_BUS_TUNE_OFF = 0,
	PCIE_BUS_DEFAULT = 1,
	PCIE_BUS_SAFE = 2,
	PCIE_BUS_PERFORMANCE = 3,
	PCIE_BUS_PEER2PEER = 4,
};

struct msi_msg {
	u32 address_lo;
	u32 address_hi;
	u32 data;
};

struct platform_msi_priv_data;

struct platform_msi_desc {
	struct platform_msi_priv_data *msi_priv_data;
	u16 msi_index;
};

struct fsl_mc_msi_desc {
	u16 msi_index;
};

struct msi_desc___2 {
	struct list_head list;
	unsigned int irq;
	unsigned int nvec_used;
	struct device___2 *dev;
	struct msi_msg msg;
	struct irq_affinity_desc *affinity;
	const void *iommu_cookie;
	union {
		struct {
			u32 masked;
			struct {
				u8 is_msix: 1;
				u8 multiple: 3;
				u8 multi_cap: 3;
				u8 maskbit: 1;
				u8 is_64: 1;
				u16 entry_nr;
				unsigned int default_irq;
			} msi_attrib;
			union {
				u8 mask_pos;
				void *mask_base;
			};
		};
		struct platform_msi_desc platform;
		struct fsl_mc_msi_desc fsl_mc;
	};
};

struct acpi_pci_root_ops;

struct acpi_pci_root_info {
	struct acpi_pci_root *root;
	struct acpi_device *bridge;
	struct acpi_pci_root_ops *ops;
	struct list_head resources;
	char name[16];
};

struct acpi_pci_root_ops {
	struct pci_ops *pci_ops;
	int (*init_info)(struct acpi_pci_root_info *);
	void (*release_info)(struct acpi_pci_root_info *);
	int (*prepare_resources)(struct acpi_pci_root_info *);
};

struct pci_config_window;

struct pci_ecam_ops {
	unsigned int bus_shift;
	struct pci_ops pci_ops;
	int (*init)(struct pci_config_window *);
};

struct pci_config_window {
	struct resource res;
	struct resource busr;
	void *priv;
	struct pci_ecam_ops *ops;
	union {
		void *win;
		void **winp;
	};
	struct device___2 *parent;
};

struct acpi_pci_generic_root_info {
	struct acpi_pci_root_info common;
	struct pci_config_window *cfg;
};

typedef long unsigned int irq_hw_number_t;

enum irq_domain_bus_token {
	DOMAIN_BUS_ANY = 0,
	DOMAIN_BUS_WIRED = 1,
	DOMAIN_BUS_PCI_MSI = 2,
	DOMAIN_BUS_PLATFORM_MSI = 3,
	DOMAIN_BUS_NEXUS = 4,
	DOMAIN_BUS_IPI = 5,
	DOMAIN_BUS_FSL_MC_MSI = 6,
};

struct irq_domain_ops;

struct irq_domain_chip_generic;

struct irq_domain {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___12 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic *gc;
	struct irq_domain *parent;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_direct_max_irq;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_tree_mutex;
	unsigned int linear_revmap[0];
};

typedef u32 acpi_status;

typedef irqreturn_t (*irq_handler_t)(int, void *);

struct irqaction {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction *next;
	irq_handler_t thread_fn;
	struct task_struct___17 *thread;
	struct irqaction *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_affinity_notify {
	unsigned int irq;
	struct kref kref;
	struct work_struct work;
	void (*notify)(struct irq_affinity_notify *, const cpumask_t *);
	void (*release)(struct kref *);
};

struct irq_desc;

typedef void (*irq_flow_handler_t)(struct irq_desc *);

struct irq_desc {
	struct irq_common_data irq_common_data;
	struct irq_data___3 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t handle_irq;
	struct irqaction *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int irq_count;
	unsigned int tot_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___15 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___16 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip_regs {
	long unsigned int enable;
	long unsigned int disable;
	long unsigned int mask;
	long unsigned int ack;
	long unsigned int eoi;
	long unsigned int type;
	long unsigned int polarity;
};

struct irq_chip_type {
	struct irq_chip___3 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic *);
	void (*resume)(struct irq_chip_generic *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain *domain;
	struct list_head list;
	struct irq_chip_type chip_types[0];
};

enum irq_gc_flags {
	IRQ_GC_INIT_MASK_CACHE = 1,
	IRQ_GC_INIT_NESTED_LOCK = 2,
	IRQ_GC_MASK_CACHE_PER_TYPE = 4,
	IRQ_GC_NO_MASK = 8,
	IRQ_GC_BE_IO = 16,
};

struct irq_domain_chip_generic {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic *gc[0];
};

struct irq_fwspec {
	struct fwnode_handle___12 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops {
	int (*match)(struct irq_domain *, struct device_node___5 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain *, struct irq_fwspec *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain *, unsigned int);
	int (*xlate)(struct irq_domain *, struct device_node___5 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain *, struct irq_data___3 *, bool);
	void (*deactivate)(struct irq_domain *, struct irq_data___3 *);
	int (*translate)(struct irq_domain *, struct irq_fwspec *, long unsigned int *, unsigned int *);
};

struct circ_buf {
	char *buf;
	int head;
	int tail;
};

struct tty_struct___2;

struct tty_driver___3;

struct tty_operations___2 {
	struct tty_struct___2 * (*lookup)(struct tty_driver___3 *, struct file___16 *, int);
	int (*install)(struct tty_driver___3 *, struct tty_struct___2 *);
	void (*remove)(struct tty_driver___3 *, struct tty_struct___2 *);
	int (*open)(struct tty_struct___2 *, struct file___16 *);
	void (*close)(struct tty_struct___2 *, struct file___16 *);
	void (*shutdown)(struct tty_struct___2 *);
	void (*cleanup)(struct tty_struct___2 *);
	int (*write)(struct tty_struct___2 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___2 *, unsigned char);
	void (*flush_chars)(struct tty_struct___2 *);
	int (*write_room)(struct tty_struct___2 *);
	int (*chars_in_buffer)(struct tty_struct___2 *);
	int (*ioctl)(struct tty_struct___2 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___2 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___2 *, struct ktermios *);
	void (*throttle)(struct tty_struct___2 *);
	void (*unthrottle)(struct tty_struct___2 *);
	void (*stop)(struct tty_struct___2 *);
	void (*start)(struct tty_struct___2 *);
	void (*hangup)(struct tty_struct___2 *);
	int (*break_ctl)(struct tty_struct___2 *, int);
	void (*flush_buffer)(struct tty_struct___2 *);
	void (*set_ldisc)(struct tty_struct___2 *);
	void (*wait_until_sent)(struct tty_struct___2 *, int);
	void (*send_xchar)(struct tty_struct___2 *, char);
	int (*tiocmget)(struct tty_struct___2 *);
	int (*tiocmset)(struct tty_struct___2 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___2 *, struct winsize *);
	int (*set_termiox)(struct tty_struct___2 *, struct termiox *);
	int (*get_icount)(struct tty_struct___2 *, struct serial_icounter_struct *);
	void (*show_fdinfo)(struct tty_struct___2 *, struct seq_file___17 *);
	int (*poll_init)(struct tty_driver___3 *, int, char *);
	int (*poll_get_char)(struct tty_driver___3 *, int);
	void (*poll_put_char)(struct tty_driver___3 *, int, char);
	int (*proc_show)(struct seq_file___17 *, void *);
};

struct tty_ldisc___2;

struct tty_port___2;

struct tty_struct___2 {
	int magic;
	struct kref kref;
	struct device___2 *dev;
	struct tty_driver___3 *driver;
	const struct tty_operations___2 *ops;
	int index;
	struct ld_semaphore ldisc_sem;
	struct tty_ldisc___2 *ldisc;
	struct mutex atomic_write_lock;
	struct mutex legacy_mutex;
	struct mutex throttle_mutex;
	struct rw_semaphore___16 termios_rwsem;
	struct mutex winsize_mutex;
	spinlock_t ctrl_lock;
	spinlock_t flow_lock;
	struct ktermios termios;
	struct ktermios termios_locked;
	struct termiox *termiox;
	char name[64];
	struct pid___14 *pgrp;
	struct pid___14 *session;
	long unsigned int flags;
	int count;
	struct winsize winsize;
	long unsigned int stopped: 1;
	long unsigned int flow_stopped: 1;
	int: 30;
	long unsigned int unused: 62;
	int hw_stopped;
	long unsigned int ctrl_status: 8;
	long unsigned int packet: 1;
	int: 23;
	long unsigned int unused_ctrl: 55;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___2 *link;
	struct fasync_struct___15 *fasync;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	spinlock_t files_lock;
	struct list_head tty_files;
	int closing;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___2 *port;
};

struct tty_driver___3 {
	int magic;
	struct kref kref;
	struct cdev___6 **cdevs;
	struct module___16 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___3 *other;
	struct tty_struct___2 **ttys;
	struct tty_port___2 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___2 *ops;
	struct list_head tty_drivers;
};

struct serial_icounter_struct {
	int cts;
	int dsr;
	int rng;
	int dcd;
	int rx;
	int tx;
	int frame;
	int overrun;
	int parity;
	int brk;
	int buf_overrun;
	int reserved[9];
};

struct tty_port_operations___2;

struct tty_port_client_operations___2;

struct tty_port___2 {
	struct tty_bufhead buf;
	struct tty_struct___2 *tty;
	struct tty_struct___2 *itty;
	const struct tty_port_operations___2 *ops;
	const struct tty_port_client_operations___2 *client_ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	unsigned char low_latency: 1;
	struct mutex mutex;
	struct mutex buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
	void *client_data;
};

struct tty_ldisc_ops___2 {
	int magic;
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___2 *);
	void (*close)(struct tty_struct___2 *);
	void (*flush_buffer)(struct tty_struct___2 *);
	ssize_t (*read)(struct tty_struct___2 *, struct file___16 *, unsigned char *, size_t);
	ssize_t (*write)(struct tty_struct___2 *, struct file___16 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___2 *, struct file___16 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___2 *, struct file___16 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___2 *, struct ktermios *);
	__poll_t (*poll)(struct tty_struct___2 *, struct file___16 *, struct poll_table_struct___12 *);
	int (*hangup)(struct tty_struct___2 *);
	void (*receive_buf)(struct tty_struct___2 *, const unsigned char *, char *, int);
	void (*write_wakeup)(struct tty_struct___2 *);
	void (*dcd_change)(struct tty_struct___2 *, unsigned int);
	int (*receive_buf2)(struct tty_struct___2 *, const unsigned char *, char *, int);
	struct module___16 *owner;
	int refcount;
};

struct tty_ldisc___2 {
	struct tty_ldisc_ops___2 *ops;
	struct tty_struct___2 *tty;
};

struct tty_port_operations___2 {
	int (*carrier_raised)(struct tty_port___2 *);
	void (*dtr_rts)(struct tty_port___2 *, int);
	void (*shutdown)(struct tty_port___2 *);
	int (*activate)(struct tty_port___2 *, struct tty_struct___2 *);
	void (*destruct)(struct tty_port___2 *);
};

struct tty_port_client_operations___2 {
	int (*receive_buf)(struct tty_port___2 *, const unsigned char *, const unsigned char *, size_t);
	void (*write_wakeup)(struct tty_port___2 *);
};

struct serial_struct {
	int type;
	int line;
	unsigned int port;
	int irq;
	int flags;
	int xmit_fifo_size;
	int custom_divisor;
	int baud_base;
	short unsigned int close_delay;
	char io_type;
	char reserved_char[1];
	int hub6;
	short unsigned int closing_wait;
	short unsigned int closing_wait2;
	unsigned char *iomem_base;
	short unsigned int iomem_reg_shift;
	unsigned int port_high;
	long unsigned int iomap_base;
};

struct serial_rs485 {
	__u32 flags;
	__u32 delay_rts_before_send;
	__u32 delay_rts_after_send;
	__u32 padding[5];
};

struct uart_port;

struct uart_ops {
	unsigned int (*tx_empty)(struct uart_port *);
	void (*set_mctrl)(struct uart_port *, unsigned int);
	unsigned int (*get_mctrl)(struct uart_port *);
	void (*stop_tx)(struct uart_port *);
	void (*start_tx)(struct uart_port *);
	void (*throttle)(struct uart_port *);
	void (*unthrottle)(struct uart_port *);
	void (*send_xchar)(struct uart_port *, char);
	void (*stop_rx)(struct uart_port *);
	void (*enable_ms)(struct uart_port *);
	void (*break_ctl)(struct uart_port *, int);
	int (*startup)(struct uart_port *);
	void (*shutdown)(struct uart_port *);
	void (*flush_buffer)(struct uart_port *);
	void (*set_termios)(struct uart_port *, struct ktermios *, struct ktermios *);
	void (*set_ldisc)(struct uart_port *, struct ktermios *);
	void (*pm)(struct uart_port *, unsigned int, unsigned int);
	const char * (*type)(struct uart_port *);
	void (*release_port)(struct uart_port *);
	int (*request_port)(struct uart_port *);
	void (*config_port)(struct uart_port *, int);
	int (*verify_port)(struct uart_port *, struct serial_struct *);
	int (*ioctl)(struct uart_port *, unsigned int, long unsigned int);
	int (*poll_init)(struct uart_port *);
	void (*poll_put_char)(struct uart_port *, unsigned char);
	int (*poll_get_char)(struct uart_port *);
};

struct uart_icount {
	__u32 cts;
	__u32 dsr;
	__u32 rng;
	__u32 dcd;
	__u32 rx;
	__u32 tx;
	__u32 frame;
	__u32 overrun;
	__u32 parity;
	__u32 brk;
	__u32 buf_overrun;
};

typedef unsigned int upf_t;

typedef unsigned int upstat_t;

struct uart_state;

struct console___2;

struct uart_port {
	spinlock_t lock;
	long unsigned int iobase;
	unsigned char *membase;
	unsigned int (*serial_in)(struct uart_port *, int);
	void (*serial_out)(struct uart_port *, int, int);
	void (*set_termios)(struct uart_port *, struct ktermios *, struct ktermios *);
	void (*set_ldisc)(struct uart_port *, struct ktermios *);
	unsigned int (*get_mctrl)(struct uart_port *);
	void (*set_mctrl)(struct uart_port *, unsigned int);
	int (*startup)(struct uart_port *);
	void (*shutdown)(struct uart_port *);
	void (*throttle)(struct uart_port *);
	void (*unthrottle)(struct uart_port *);
	int (*handle_irq)(struct uart_port *);
	void (*pm)(struct uart_port *, unsigned int, unsigned int);
	void (*handle_break)(struct uart_port *);
	int (*rs485_config)(struct uart_port *, struct serial_rs485 *);
	unsigned int irq;
	long unsigned int irqflags;
	unsigned int uartclk;
	unsigned int fifosize;
	unsigned char x_char;
	unsigned char regshift;
	unsigned char iotype;
	unsigned char quirks;
	unsigned int read_status_mask;
	unsigned int ignore_status_mask;
	struct uart_state *state;
	struct uart_icount icount;
	struct console___2 *cons;
	long unsigned int sysrq;
	upf_t flags;
	upstat_t status;
	int hw_stopped;
	unsigned int mctrl;
	unsigned int timeout;
	unsigned int type;
	const struct uart_ops *ops;
	unsigned int custom_divisor;
	unsigned int line;
	unsigned int minor;
	resource_size_t mapbase;
	resource_size_t mapsize;
	struct device___2 *dev;
	unsigned char hub6;
	unsigned char suspended;
	unsigned char unused[2];
	const char *name;
	struct attribute_group___15 *attr_group;
	const struct attribute_group___15 **tty_groups;
	struct serial_rs485 rs485;
	void *private_data;
};

enum uart_pm_state {
	UART_PM_STATE_ON = 0,
	UART_PM_STATE_OFF = 3,
	UART_PM_STATE_UNDEFINED = 4,
};

struct uart_state {
	struct tty_port___2 port;
	enum uart_pm_state pm_state;
	struct circ_buf xmit;
	atomic_t refcount;
	wait_queue_head_t remove_wait;
	struct uart_port *uart_port;
};

struct earlycon_device {
	struct console___2 *con;
	struct uart_port port;
	char options[16];
	unsigned int baud;
};

struct earlycon_id {
	char name[15];
	char name_term;
	char compatible[128];
	int (*setup)(struct earlycon_device *, const char *);
};

struct acpi_srat_gicc_affinity {
	struct acpi_subtable_header header;
	u32 proximity_domain;
	u32 acpi_processor_uid;
	u32 flags;
	u32 clock_domain;
} __attribute__((packed));

struct cpuidle_driver___2;

struct __node_cpu_hwid {
	u32 node_id;
	u64 cpu_hwid;
};

struct parking_protocol_mailbox {
	__le32 cpu_id;
	__le32 reserved;
	__le64 entry_point;
};

struct cpu_mailbox_entry {
	struct parking_protocol_mailbox *mailbox;
	phys_addr_t mailbox_addr;
	u8 version;
	u8 gic_cpu_id;
};

struct pv_time_ops {
	long long unsigned int (*steal_clock)(int);
};

typedef __be64 fdt64_t;

struct kobject___17;

struct kobj_attribute___17;

typedef long unsigned int ulong;

struct module___18;

struct file___18;

struct kiocb___18;

struct iov_iter___7;

struct vm_area_struct___18;

struct inode___20;

struct file_lock___18;

struct page___18;

struct seq_file___18;

struct file_operations___18 {
	struct module___18 *owner;
	loff_t (*llseek)(struct file___18 *, loff_t, int);
	ssize_t (*read)(struct file___18 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___18 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___18 *, struct iov_iter___7 *);
	ssize_t (*write_iter)(struct kiocb___18 *, struct iov_iter___7 *);
	int (*iopoll)(struct kiocb___18 *, bool);
	int (*iterate)(struct file___18 *, struct dir_context *);
	int (*iterate_shared)(struct file___18 *, struct dir_context *);
	__poll_t (*poll)(struct file___18 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___18 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___18 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___18 *, struct vm_area_struct___18 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___20 *, struct file___18 *);
	int (*flush)(struct file___18 *, fl_owner_t);
	int (*release)(struct inode___20 *, struct file___18 *);
	int (*fsync)(struct file___18 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___18 *, int);
	int (*lock)(struct file___18 *, int, struct file_lock___18 *);
	ssize_t (*sendpage)(struct file___18 *, struct page___18 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___18 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___18 *, int, struct file_lock___18 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___18 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___18 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___18 *, long int, struct file_lock___18 **, void **);
	long int (*fallocate)(struct file___18 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___18 *, struct file___18 *);
	ssize_t (*copy_file_range)(struct file___18 *, loff_t, struct file___18 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___18 *, loff_t, struct file___18 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___18 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct perf_event___10;

struct debug_info___10 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___10 *hbp_break[16];
	struct perf_event___10 *hbp_watch[16];
};

struct task_struct___19;

struct hw_perf_event___10 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___19 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___10)(struct perf_event___10 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___10;

struct perf_event_context___10;

struct fasync_struct___17;

struct pid_namespace___16;

struct perf_cgroup___10;

struct perf_event___10 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___10 *group_leader;
	struct pmu___10 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___10 hw;
	struct perf_event_context___10 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___10 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___19 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___17 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___10 *);
	struct callback_head callback_head;
	struct pid_namespace___16 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___10 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___10 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___5 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___10 *cgrp;
	struct list_head sb_list;
};

struct thread_struct___10 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___10 debug;
	long: 64;
};

struct vmacache___17 {
	u64 seqnum;
	struct vm_area_struct___18 *vmas[4];
};

struct page_frag___17 {
	struct page___18 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___18;

struct mem_cgroup___5;

struct pid___16;

struct cred___17;

struct nsproxy___17;

struct signal_struct___16;

struct bio_list___6;

struct backing_dev_info___6;

struct css_set___10;

struct vm_struct___14;

struct task_struct___19 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___19 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___18 *mm;
	struct mm_struct___18 *active_mm;
	struct vmacache___17 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___19 *real_parent;
	struct task_struct___19 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___19 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___5 *active_memcg;
	long int rh_reserved2;
	struct pid___16 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___16 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___16 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___17 *ptracer_cred;
	const struct cred___17 *real_cred;
	const struct cred___17 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___17 *nsproxy;
	struct signal_struct___16 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___19 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___6 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___6 *backing_dev_info;
	struct io_context___2 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___10 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___10 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___17 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___5 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___19 *oom_reaper_list;
	struct vm_struct___14 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___10 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct preempt_notifier;

struct preempt_ops {
	void (*sched_in)(struct preempt_notifier *, int);
	void (*sched_out)(struct preempt_notifier *, struct task_struct___19 *);
};

struct preempt_notifier {
	struct hlist_node link;
	struct preempt_ops *ops;
};

typedef u64 pudval_t;

typedef struct page___18 *pgtable_t___17;

struct address_space___17;

struct dev_pagemap___17;

struct page___18 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___17 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___18 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___17 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___18 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___17 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___5 *mem_cgroup;
};

struct pglist_data___17;

struct lruvec___17 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___17 *pgdat;
};

struct zone___17 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___17 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___17 {
	struct zone___17 *zone;
	int zone_idx;
};

struct zonelist___17 {
	struct zoneref___17 _zonerefs[25];
};

struct pglist_data___17 {
	struct zone___17 node_zones[3];
	struct zonelist___17 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___19 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___19 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___17 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___18 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___19 *owner;
};

struct secondary_data___18 {
	void *stack;
	struct task_struct___19 *task;
	long int status;
};

struct rcu_segcblist {
	struct callback_head *head;
	struct callback_head **tails[4];
	long unsigned int gp_seq[4];
	long int len;
	long int len_lazy;
};

struct srcu_node;

struct srcu_struct;

struct srcu_data {
	long unsigned int srcu_lock_count[2];
	long unsigned int srcu_unlock_count[2];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t lock;
	struct rcu_segcblist srcu_cblist;
	long unsigned int srcu_gp_seq_needed;
	long unsigned int srcu_gp_seq_needed_exp;
	bool srcu_cblist_invoking;
	struct delayed_work work;
	struct callback_head srcu_barrier_head;
	struct srcu_node *mynode;
	long unsigned int grpmask;
	int cpu;
	struct srcu_struct *sp;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct srcu_node {
	spinlock_t lock;
	long unsigned int srcu_have_cbs[4];
	long unsigned int srcu_data_have_cbs[4];
	long unsigned int srcu_gp_seq_needed_exp;
	struct srcu_node *srcu_parent;
	int grplo;
	int grphi;
};

struct srcu_struct {
	struct srcu_node node[261];
	struct srcu_node *level[4];
	struct mutex srcu_cb_mutex;
	spinlock_t lock;
	struct mutex srcu_gp_mutex;
	unsigned int srcu_idx;
	long unsigned int srcu_gp_seq;
	long unsigned int srcu_gp_seq_needed;
	long unsigned int srcu_gp_seq_needed_exp;
	long unsigned int srcu_last_gp_end;
	struct srcu_data *sda;
	long unsigned int srcu_barrier_seq;
	struct mutex srcu_barrier_mutex;
	struct completion srcu_barrier_completion;
	atomic_t srcu_barrier_cpu_cnt;
	struct delayed_work work;
};

struct blocking_notifier_head___17 {
	struct rw_semaphore___18 rwsem;
	struct notifier_block *head;
};

struct key___18;

struct ucounts___11;

struct user_namespace___11 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___11 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common ns;
	long unsigned int flags;
	struct key___18 *persistent_keyring_register;
	struct rw_semaphore___18 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___11 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_root___17;

struct kernfs_elem_dir___17 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___17 *root;
};

struct kernfs_node___17;

struct kernfs_syscall_ops___17;

struct kernfs_root___17 {
	struct kernfs_node___17 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___17 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___17 {
	struct kernfs_node___17 *target_kn;
};

struct kernfs_ops___17;

struct kernfs_elem_attr___17 {
	const struct kernfs_ops___17 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___17 *notify_next;
};

struct kernfs_node___17 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___17 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___17 dir;
		struct kernfs_elem_symlink___17 symlink;
		struct kernfs_elem_attr___17 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___17;

struct kernfs_ops___17 {
	int (*open)(struct kernfs_open_file___17 *);
	void (*release)(struct kernfs_open_file___17 *);
	int (*seq_show)(struct seq_file___18 *, void *);
	void * (*seq_start)(struct seq_file___18 *, loff_t *);
	void * (*seq_next)(struct seq_file___18 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___18 *, void *);
	ssize_t (*read)(struct kernfs_open_file___17 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___17 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___17 *, struct vm_area_struct___18 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___17 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___17 {
	int (*remount_fs)(struct kernfs_root___17 *, int *, char *);
	int (*show_options)(struct seq_file___18 *, struct kernfs_root___17 *);
	int (*mkdir)(struct kernfs_node___17 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___17 *);
	int (*rename)(struct kernfs_node___17 *, struct kernfs_node___17 *, const char *);
	int (*show_path)(struct seq_file___18 *, struct kernfs_node___17 *, struct kernfs_root___17 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___15;

struct seq_file___18 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___15 *op;
	int poll_event;
	const struct file___18 *file;
	void *private;
};

struct vm_operations_struct___17;

struct kernfs_open_file___17 {
	struct kernfs_node___17 *kn;
	struct file___18 *file;
	struct seq_file___18 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___17 *vm_ops;
};

struct dentry___19;

struct path___17 {
	struct vfsmount *mnt;
	struct dentry___19 *dentry;
};

struct fown_struct___16 {
	rwlock_t lock;
	struct pid___16 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___18 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___17 f_path;
	struct inode___20 *f_inode;
	const struct file_operations___18 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___16 f_owner;
	const struct cred___17 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___17 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___17;

struct vm_operations_struct___17 {
	void (*open)(struct vm_area_struct___18 *);
	void (*close)(struct vm_area_struct___18 *);
	int (*split)(struct vm_area_struct___18 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___18 *);
	vm_fault_t (*fault)(struct vm_fault___17 *);
	vm_fault_t (*huge_fault)(struct vm_fault___17 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___17 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___18 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___17 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___17 *);
	int (*access)(struct vm_area_struct___18 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___18 *);
	int (*set_policy)(struct vm_area_struct___18 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___18 *, long unsigned int);
	struct page___18 * (*find_special_page)(struct vm_area_struct___18 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_area_struct___18 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___18 *vm_next;
	struct vm_area_struct___18 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___18 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___17 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___18 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___18;

struct bin_attribute___16;

struct attribute_group___16 {
	const char *name;
	umode_t (*is_visible)(struct kobject___18 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___18 *, struct bin_attribute___16 *, int);
	struct attribute **attrs;
	struct bin_attribute___16 **bin_attrs;
};

struct kset___17;

struct kobj_type___17;

struct kobject___18 {
	const char *name;
	struct list_head entry;
	struct kobject___18 *parent;
	struct kset___17 *kset;
	struct kobj_type___17 *ktype;
	struct kernfs_node___17 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___16 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___18 *, struct kobject___18 *, struct bin_attribute___16 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___18 *, struct kobject___18 *, struct bin_attribute___16 *, char *, loff_t, size_t);
	int (*mmap)(struct file___18 *, struct kobject___18 *, struct bin_attribute___16 *, struct vm_area_struct___18 *);
};

struct sysfs_ops___17 {
	ssize_t (*show)(struct kobject___18 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___18 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___17;

struct kset___17 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___18 kobj;
	const struct kset_uevent_ops___17 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___17 {
	void (*release)(struct kobject___18 *);
	const struct sysfs_ops___17 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___18 *);
	const void * (*namespace)(struct kobject___18 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___17 {
	int (* const filter)(struct kset___17 *, struct kobject___18 *);
	const char * (* const name)(struct kset___17 *, struct kobject___18 *);
	int (* const uevent)(struct kset___17 *, struct kobject___18 *, struct kobj_uevent_env *);
};

struct kobj_attribute___18 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___18 *, struct kobj_attribute___18 *, char *);
	ssize_t (*store)(struct kobject___18 *, struct kobj_attribute___18 *, const char *, size_t);
};

struct device___16;

struct dev_pm_ops___16 {
	int (*prepare)(struct device___16 *);
	void (*complete)(struct device___16 *);
	int (*suspend)(struct device___16 *);
	int (*resume)(struct device___16 *);
	int (*freeze)(struct device___16 *);
	int (*thaw)(struct device___16 *);
	int (*poweroff)(struct device___16 *);
	int (*restore)(struct device___16 *);
	int (*suspend_late)(struct device___16 *);
	int (*resume_early)(struct device___16 *);
	int (*freeze_late)(struct device___16 *);
	int (*thaw_early)(struct device___16 *);
	int (*poweroff_late)(struct device___16 *);
	int (*restore_early)(struct device___16 *);
	int (*suspend_noirq)(struct device___16 *);
	int (*resume_noirq)(struct device___16 *);
	int (*freeze_noirq)(struct device___16 *);
	int (*thaw_noirq)(struct device___16 *);
	int (*poweroff_noirq)(struct device___16 *);
	int (*restore_noirq)(struct device___16 *);
	int (*runtime_suspend)(struct device___16 *);
	int (*runtime_resume)(struct device___16 *);
	int (*runtime_idle)(struct device___16 *);
};

struct dev_pm_info___16 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___16 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___16;

struct bus_type___16;

struct device_driver___16;

struct dev_pm_domain___16;

struct device_node___6;

struct fwnode_handle___13;

struct class___16;

struct device___16 {
	struct device___16 *parent;
	struct device_private *p;
	struct kobject___18 kobj;
	const char *init_name;
	const struct device_type___16 *type;
	struct mutex mutex;
	struct bus_type___16 *bus;
	struct device_driver___16 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___16 power;
	struct dev_pm_domain___16 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___6 *of_node;
	struct fwnode_handle___13 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___16 *class;
	const struct attribute_group___16 **groups;
	void (*release)(struct device___16 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___16 {
	struct dev_pm_ops___16 ops;
	void (*detach)(struct device___16 *, bool);
	int (*activate)(struct device___16 *);
	void (*sync)(struct device___16 *);
	void (*dismiss)(struct device___16 *);
};

struct upid___16 {
	int nr;
	struct pid_namespace___16 *ns;
};

struct pid_namespace___16 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___19 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___16 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___19 *proc_self;
	struct dentry___19 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___11 *user_ns;
	struct ucounts___11 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common ns;
};

struct pid___16 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___16 numbers[1];
};

struct user_struct___17 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___18 *uid_keyring;
	struct key___18 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___17;

struct mm_struct___18 {
	struct {
		struct vm_area_struct___18 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___18 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___18 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___17 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___19 *owner;
		struct user_namespace___11 *user_ns;
		struct file___18 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___17 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup___10;

struct cgroup_subsys___10;

struct cgroup_subsys_state___10 {
	struct cgroup___10 *cgroup;
	struct cgroup_subsys___10 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___10 *parent;
};

struct mem_cgroup_id___5 {
	int id;
	union {
		refcount_t ref;
		struct {
			atomic_t ref;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
};

struct cgroup_file___10 {
	struct kernfs_node___17 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___5;

struct mem_cgroup___5 {
	struct cgroup_subsys_state___10 css;
	struct mem_cgroup_id___5 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___10 events_file;
	struct cgroup_file___10 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___19 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___5 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cred___17 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___18 *session_keyring;
	struct key___18 *process_keyring;
	struct key___18 *thread_keyring;
	struct key___18 *request_key_auth;
	void *security;
	struct user_struct___17 *user;
	struct user_namespace___11 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct uts_namespace___5;

struct cgroup_namespace___10;

struct nsproxy___17 {
	atomic_t count;
	struct uts_namespace___5 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___16 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___10 *cgroup_ns;
};

struct signal_struct___16 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___19 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___19 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___16 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___16 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___18 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___16 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___6;

struct bio_list___6 {
	struct bio___6 *head;
	struct bio___6 *tail;
};

struct bdi_writeback_congested___6;

struct bdi_writeback___6 {
	struct backing_dev_info___6 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___6 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___10 *memcg_css;
	struct cgroup_subsys_state___10 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___6 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___6 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___16 *dev;
	struct device___16 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___19 *debug_dir;
	struct dentry___19 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___10 {
	struct cgroup_subsys_state___10 *subsys[13];
	refcount_t refcount;
	struct css_set___10 *dom_cset;
	struct cgroup___10 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___10 *mg_src_cgrp;
	struct cgroup___10 *mg_dst_cgrp;
	struct css_set___10 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___10 {
	struct pmu___10 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___19 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___10 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___14 {
	struct vm_struct___14 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___18 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___16 {
	struct task_struct___19 task;
	long unsigned int stack[8192];
};

struct bus_type___16 {
	const char *name;
	const char *dev_name;
	struct device___16 *dev_root;
	const struct attribute_group___16 **bus_groups;
	const struct attribute_group___16 **dev_groups;
	const struct attribute_group___16 **drv_groups;
	int (*match)(struct device___16 *, struct device_driver___16 *);
	int (*uevent)(struct device___16 *, struct kobj_uevent_env *);
	int (*probe)(struct device___16 *);
	int (*remove)(struct device___16 *);
	void (*shutdown)(struct device___16 *);
	int (*online)(struct device___16 *);
	int (*offline)(struct device___16 *);
	int (*suspend)(struct device___16 *, pm_message_t);
	int (*resume)(struct device___16 *);
	int (*num_vf)(struct device___16 *);
	int (*dma_configure)(struct device___16 *);
	const struct dev_pm_ops___16 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___16 {
	const char *name;
	struct bus_type___16 *bus;
	struct module___18 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___16 *);
	int (*remove)(struct device___16 *);
	void (*shutdown)(struct device___16 *);
	int (*suspend)(struct device___16 *, pm_message_t);
	int (*resume)(struct device___16 *);
	const struct attribute_group___16 **groups;
	const struct dev_pm_ops___16 *pm;
	void (*coredump)(struct device___16 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___16 {
	const char *name;
	const struct attribute_group___16 **groups;
	int (*uevent)(struct device___16 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___16 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___16 *);
	const struct dev_pm_ops___16 *pm;
};

struct module_kobject___15 {
	struct kobject___18 kobj;
	struct module___18 *mod;
	struct kobject___18 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___15 {
	struct module___18 *mod;
	struct latch_tree_node node;
};

struct module_layout___15 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___15 mtn;
};

struct module_attribute___15;

struct kernel_param___15;

struct module___18 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___15 mkobj;
	struct module_attribute___15 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___18 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___15 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___15 core_layout;
	struct module_layout___15 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct class___16 {
	const char *name;
	struct module___18 *owner;
	const struct attribute_group___16 **class_groups;
	const struct attribute_group___16 **dev_groups;
	struct kobject___18 *dev_kobj;
	int (*dev_uevent)(struct device___16 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___16 *, umode_t *);
	void (*class_release)(struct class___16 *);
	void (*dev_release)(struct device___16 *);
	int (*shutdown_pre)(struct device___16 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___16 *);
	const struct dev_pm_ops___16 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct fwnode_operations___13;

struct fwnode_handle___13 {
	struct fwnode_handle___13 *secondary;
	const struct fwnode_operations___13 *ops;
};

struct property___6;

struct device_node___6 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___13 fwnode;
	struct property___6 *properties;
	struct property___6 *deadprops;
	struct device_node___6 *parent;
	struct device_node___6 *child;
	struct device_node___6 *sibling;
	struct kobject___18 kobj;
	long unsigned int _flags;
	void *data;
};

struct node___15 {
	struct device___16 dev;
};

struct address_space_operations___17;

struct address_space___17 {
	struct inode___20 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___18 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___17 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___17)(struct vm_area_struct___18 *, long unsigned int, const struct page___18 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___17)(struct page___18 *, void *);

struct dev_pagemap___17 {
	dev_page_fault_t___17 page_fault;
	dev_page_free_t___17 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___16 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___17 {
	struct task_struct___19 *task;
	struct core_thread___17 *next;
};

struct core_state___17 {
	atomic_t nr_threads;
	struct core_thread___17 dumper;
	struct completion startup;
};

struct mmu_notifier_mm {
	struct hlist_head list;
	spinlock_t lock;
};

struct vm_fault___17 {
	struct vm_area_struct___18 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___18 *cow_page;
	struct mem_cgroup___5 *memcg;
	struct page___18 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___17 prealloc_pte;
};

struct shrink_control___5 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___5 *memcg;
};

struct shrinker___5 {
	long unsigned int (*count_objects)(struct shrinker___5 *, struct shrink_control___5 *);
	long unsigned int (*scan_objects)(struct shrinker___5 *, struct shrink_control___5 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct dentry_operations___17;

struct super_block___18;

struct dentry___19 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___19 *d_parent;
	struct qstr d_name;
	struct inode___20 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___17 *d_op;
	struct super_block___18 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___17;

struct block_device___18;

struct inode___20 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___17 *i_op;
	struct super_block___18 *i_sb;
	struct address_space___17 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___18 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___6 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___18 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___17 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___18 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___17 {
	int (*d_revalidate)(struct dentry___19 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___19 *, unsigned int);
	int (*d_hash)(const struct dentry___19 *, struct qstr *);
	int (*d_compare)(const struct dentry___19 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___19 *);
	int (*d_init)(struct dentry___19 *);
	void (*d_release)(struct dentry___19 *);
	void (*d_prune)(struct dentry___19 *);
	void (*d_iput)(struct dentry___19 *, struct inode___20 *);
	char * (*d_dname)(struct dentry___19 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___17 *);
	int (*d_manage)(const struct path___17 *, bool);
	struct dentry___19 * (*d_real)(struct dentry___19 *, const struct inode___20 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___17;

struct mem_dqinfo___17 {
	struct quota_format_type___17 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___17;

struct quota_info___17 {
	unsigned int flags;
	struct rw_semaphore___18 dqio_sem;
	struct inode___20 *files[3];
	struct mem_dqinfo___17 info[3];
	const struct quota_format_ops___17 *ops[3];
};

struct rcuwait___17 {
	struct task_struct___19 *task;
};

struct percpu_rw_semaphore___17 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___18 rw_sem;
	struct rcuwait___17 writer;
	int readers_block;
};

struct sb_writers___17 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___17 rw_sem[3];
};

struct file_system_type___17;

struct super_operations___17;

struct dquot_operations___17;

struct quotactl_ops___17;

struct super_block___18 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___17 *s_type;
	const struct super_operations___17 *s_op;
	const struct dquot_operations___17 *dq_op;
	const struct quotactl_ops___17 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___19 *s_root;
	struct rw_semaphore___18 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___18 *s_bdev;
	struct backing_dev_info___6 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___17 s_dquot;
	struct sb_writers___17 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___17 *s_d_op;
	int cleancache_poolid;
	struct shrinker___5 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___11 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___18 {
	struct file___18 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___18 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___18 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___18 *ia_file;
};

struct dquot___17 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___18 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___17 {
	int qf_fmt_id;
	const struct quota_format_ops___17 *qf_ops;
	struct module___18 *qf_owner;
	struct quota_format_type___17 *qf_next;
};

struct quota_format_ops___17 {
	int (*check_quota_file)(struct super_block___18 *, int);
	int (*read_file_info)(struct super_block___18 *, int);
	int (*write_file_info)(struct super_block___18 *, int);
	int (*free_file_info)(struct super_block___18 *, int);
	int (*read_dqblk)(struct dquot___17 *);
	int (*commit_dqblk)(struct dquot___17 *);
	int (*release_dqblk)(struct dquot___17 *);
	int (*get_next_id)(struct super_block___18 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___17 {
	int (*write_dquot)(struct dquot___17 *);
	struct dquot___17 * (*alloc_dquot)(struct super_block___18 *, int);
	void (*destroy_dquot)(struct dquot___17 *);
	int (*acquire_dquot)(struct dquot___17 *);
	int (*release_dquot)(struct dquot___17 *);
	int (*mark_dirty)(struct dquot___17 *);
	int (*write_info)(struct super_block___18 *, int);
	qsize_t * (*get_reserved_space)(struct inode___20 *);
	int (*get_projid)(struct inode___20 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___20 *, qsize_t *);
	int (*get_next_id)(struct super_block___18 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___17 {
	int (*quota_on)(struct super_block___18 *, int, int, const struct path___17 *);
	int (*quota_off)(struct super_block___18 *, int);
	int (*quota_enable)(struct super_block___18 *, unsigned int);
	int (*quota_disable)(struct super_block___18 *, unsigned int);
	int (*quota_sync)(struct super_block___18 *, int);
	int (*set_info)(struct super_block___18 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___18 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___18 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___18 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___18 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___18 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___5;

struct swap_info_struct___4;

struct address_space_operations___17 {
	int (*writepage)(struct page___18 *, struct writeback_control___5 *);
	int (*readpage)(struct file___18 *, struct page___18 *);
	int (*writepages)(struct address_space___17 *, struct writeback_control___5 *);
	int (*set_page_dirty)(struct page___18 *);
	int (*readpages)(struct file___18 *, struct address_space___17 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___18 *, struct address_space___17 *, loff_t, unsigned int, unsigned int, struct page___18 **, void **);
	int (*write_end)(struct file___18 *, struct address_space___17 *, loff_t, unsigned int, unsigned int, struct page___18 *, void *);
	sector_t (*bmap)(struct address_space___17 *, sector_t);
	void (*invalidatepage)(struct page___18 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___18 *, gfp_t);
	void (*freepage)(struct page___18 *);
	ssize_t (*direct_IO)(struct kiocb___18 *, struct iov_iter___7 *);
	int (*migratepage)(struct address_space___17 *, struct page___18 *, struct page___18 *, enum migrate_mode);
	bool (*isolate_page)(struct page___18 *, isolate_mode_t);
	void (*putback_page)(struct page___18 *);
	int (*launder_page)(struct page___18 *);
	int (*is_partially_uptodate)(struct page___18 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___18 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___17 *, struct page___18 *);
	int (*swap_activate)(struct swap_info_struct___4 *, struct file___18 *, sector_t *);
	void (*swap_deactivate)(struct file___18 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___5 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___6 *wb;
	struct inode___20 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___6;

struct iov_iter___7 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___6 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct swap_info_struct___4 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___18 *bdev;
	struct file___18 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___18 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___20 *bd_inode;
	struct super_block___18 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___18 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___6 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___17 {
	struct dentry___19 * (*lookup)(struct inode___20 *, struct dentry___19 *, unsigned int);
	const char * (*get_link)(struct dentry___19 *, struct inode___20 *, struct delayed_call *);
	int (*permission)(struct inode___20 *, int);
	struct posix_acl * (*get_acl)(struct inode___20 *, int);
	int (*readlink)(struct dentry___19 *, char *, int);
	int (*create)(struct inode___20 *, struct dentry___19 *, umode_t, bool);
	int (*link)(struct dentry___19 *, struct inode___20 *, struct dentry___19 *);
	int (*unlink)(struct inode___20 *, struct dentry___19 *);
	int (*symlink)(struct inode___20 *, struct dentry___19 *, const char *);
	int (*mkdir)(struct inode___20 *, struct dentry___19 *, umode_t);
	int (*rmdir)(struct inode___20 *, struct dentry___19 *);
	int (*mknod)(struct inode___20 *, struct dentry___19 *, umode_t, dev_t);
	int (*rename)(struct inode___20 *, struct dentry___19 *, struct inode___20 *, struct dentry___19 *, unsigned int);
	int (*setattr)(struct dentry___19 *, struct iattr___18 *);
	int (*getattr)(const struct path___17 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___19 *, char *, size_t);
	int (*fiemap)(struct inode___20 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___20 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___20 *, struct dentry___19 *, struct file___18 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___20 *, struct dentry___19 *, umode_t);
	int (*set_acl)(struct inode___20 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___17 {
	void (*fl_copy_lock)(struct file_lock___18 *, struct file_lock___18 *);
	void (*fl_release_private)(struct file_lock___18 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___17;

struct file_lock___18 {
	struct file_lock___18 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___18 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___17 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___17 *fl_ops;
	const struct lock_manager_operations___17 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___17 {
	int (*lm_compare_owner)(struct file_lock___18 *, struct file_lock___18 *);
	long unsigned int (*lm_owner_key)(struct file_lock___18 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___18 *);
	int (*lm_grant)(struct file_lock___18 *, int);
	bool (*lm_break)(struct file_lock___18 *);
	int (*lm_change)(struct file_lock___18 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___18 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___17 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___17 *fa_next;
	struct file___18 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___17 {
	const char *name;
	int fs_flags;
	struct dentry___19 * (*mount)(struct file_system_type___17 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___18 *);
	struct module___18 *owner;
	struct file_system_type___17 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___17 {
	struct inode___20 * (*alloc_inode)(struct super_block___18 *);
	void (*destroy_inode)(struct inode___20 *);
	void (*dirty_inode)(struct inode___20 *, int);
	int (*write_inode)(struct inode___20 *, struct writeback_control___5 *);
	int (*drop_inode)(struct inode___20 *);
	void (*evict_inode)(struct inode___20 *);
	void (*put_super)(struct super_block___18 *);
	int (*sync_fs)(struct super_block___18 *, int);
	int (*freeze_super)(struct super_block___18 *);
	int (*freeze_fs)(struct super_block___18 *);
	int (*thaw_super)(struct super_block___18 *);
	int (*unfreeze_fs)(struct super_block___18 *);
	int (*statfs)(struct dentry___19 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___18 *, int *, char *);
	void (*umount_begin)(struct super_block___18 *);
	int (*show_options)(struct seq_file___18 *, struct dentry___19 *);
	int (*show_devname)(struct seq_file___18 *, struct dentry___19 *);
	int (*show_path)(struct seq_file___18 *, struct dentry___19 *);
	int (*show_stats)(struct seq_file___18 *, struct dentry___19 *);
	ssize_t (*quota_read)(struct super_block___18 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___18 *, int, const char *, size_t, loff_t);
	struct dquot___17 ** (*get_dquots)(struct inode___20 *);
	int (*bdev_try_to_free_page)(struct super_block___18 *, struct page___18 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___18 *, struct shrink_control___5 *);
	long int (*free_cached_objects)(struct super_block___18 *, struct shrink_control___5 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___6(struct bio___6 *);

struct bio_vec___6 {
	struct page___18 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___6;

struct bio_set___6;

struct bio___6 {
	struct bio___6 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___6 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___6 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___6 *bi_io_vec;
	struct bio_set___6 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___6 bi_inline_vecs[0];
};

typedef void compound_page_dtor___17(struct page___18 *);

struct mmu_notifier;

struct mmu_notifier_ops {
	int flags;
	void (*release)(struct mmu_notifier *, struct mm_struct___18 *);
	int (*clear_flush_young)(struct mmu_notifier *, struct mm_struct___18 *, long unsigned int, long unsigned int);
	int (*clear_young)(struct mmu_notifier *, struct mm_struct___18 *, long unsigned int, long unsigned int);
	int (*test_young)(struct mmu_notifier *, struct mm_struct___18 *, long unsigned int);
	void (*change_pte)(struct mmu_notifier *, struct mm_struct___18 *, long unsigned int, pte_t);
	void (*invalidate_range_start)(struct mmu_notifier *, struct mm_struct___18 *, long unsigned int, long unsigned int);
	void (*invalidate_range_end)(struct mmu_notifier *, struct mm_struct___18 *, long unsigned int, long unsigned int);
	void (*invalidate_range)(struct mmu_notifier *, struct mm_struct___18 *, long unsigned int, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mmu_notifier {
	struct hlist_node hlist;
	const struct mmu_notifier_ops *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct swait_queue_head {
	raw_spinlock_t lock;
	struct list_head task_list;
};

struct kvm_regs {
	struct user_pt_regs regs;
	__u64 sp_el1;
	__u64 elr_el1;
	__u64 spsr[5];
	long: 64;
	struct user_fpsimd_state fp_regs;
};

struct kvm_guest_debug_arch {
	__u64 dbg_bcr[16];
	__u64 dbg_bvr[16];
	__u64 dbg_wcr[16];
	__u64 dbg_wvr[16];
};

struct kvm_debug_exit_arch {
	__u32 hsr;
	__u64 far;
};

struct kvm_sync_regs {
	__u64 device_irq_level;
};

struct kvm_arch_memory_slot {};

struct kvm_irq_level {
	union {
		__u32 irq;
		__s32 status;
	};
	__u32 level;
};

struct kvm_hyperv_exit {
	__u32 type;
	union {
		struct {
			__u32 msr;
			__u64 control;
			__u64 evt_page;
			__u64 msg_page;
		} synic;
		struct {
			__u64 input;
			__u64 result;
			__u64 params[2];
		} hcall;
	} u;
};

struct kvm_run {
	__u8 request_interrupt_window;
	__u8 immediate_exit;
	__u8 padding1[6];
	__u32 exit_reason;
	__u8 ready_for_interrupt_injection;
	__u8 if_flag;
	__u16 flags;
	__u64 cr8;
	__u64 apic_base;
	union {
		struct {
			__u64 hardware_exit_reason;
		} hw;
		struct {
			__u64 hardware_entry_failure_reason;
		} fail_entry;
		struct {
			__u32 exception;
			__u32 error_code;
		} ex;
		struct {
			__u8 direction;
			__u8 size;
			__u16 port;
			__u32 count;
			__u64 data_offset;
		} io;
		struct {
			struct kvm_debug_exit_arch arch;
		} debug;
		struct {
			__u64 phys_addr;
			__u8 data[8];
			__u32 len;
			__u8 is_write;
		} mmio;
		struct {
			__u64 nr;
			__u64 args[6];
			__u64 ret;
			__u32 longmode;
			__u32 pad;
		} hypercall;
		struct {
			__u64 rip;
			__u32 is_write;
			__u32 pad;
		} tpr_access;
		struct {
			__u8 icptcode;
			__u16 ipa;
			__u32 ipb;
		} s390_sieic;
		__u64 s390_reset_flags;
		struct {
			__u64 trans_exc_code;
			__u32 pgm_code;
		} s390_ucontrol;
		struct {
			__u32 dcrn;
			__u32 data;
			__u8 is_write;
		} dcr;
		struct {
			__u32 suberror;
			__u32 ndata;
			__u64 data[16];
		} internal;
		struct {
			__u64 gprs[32];
		} osi;
		struct {
			__u64 nr;
			__u64 ret;
			__u64 args[9];
		} papr_hcall;
		struct {
			__u16 subchannel_id;
			__u16 subchannel_nr;
			__u32 io_int_parm;
			__u32 io_int_word;
			__u32 ipb;
			__u8 dequeued;
		} s390_tsch;
		struct {
			__u32 epr;
		} epr;
		struct {
			__u32 type;
			__u64 flags;
		} system_event;
		struct {
			__u64 addr;
			__u8 ar;
			__u8 reserved;
			__u8 fc;
			__u8 sel1;
			__u16 sel2;
		} s390_stsi;
		struct {
			__u8 vector;
		} eoi;
		struct kvm_hyperv_exit hyperv;
		char padding[256];
	};
	__u64 kvm_valid_regs;
	__u64 kvm_dirty_regs;
	union {
		struct kvm_sync_regs regs;
		char padding[2048];
	} s;
};

struct kvm_coalesced_mmio {
	__u64 phys_addr;
	__u32 len;
	union {
		__u32 pad;
		__u32 pio;
	};
	__u8 data[8];
};

struct kvm_coalesced_mmio_ring {
	__u32 first;
	__u32 last;
	struct kvm_coalesced_mmio coalesced_mmio[0];
};

struct kvm_device_attr {
	__u32 flags;
	__u32 group;
	__u64 attr;
	__u64 addr;
};

typedef u64 gpa_t;

typedef u64 gfn_t;

struct kvm_memory_slot {
	gfn_t base_gfn;
	long unsigned int npages;
	long unsigned int *dirty_bitmap;
	struct kvm_arch_memory_slot arch;
	long unsigned int userspace_addr;
	u32 flags;
	short int id;
};

struct kvm_decode {
	long unsigned int rt;
	bool sign_extend;
};

struct kvm_vcpu;

struct kvm_io_device;

struct kvm_io_device_ops {
	int (*read)(struct kvm_vcpu *, struct kvm_io_device *, gpa_t, int, void *);
	int (*write)(struct kvm_vcpu *, struct kvm_io_device *, gpa_t, int, const void *);
	void (*destructor)(struct kvm_io_device *);
};

struct kvm_vcpu_stat {
	u64 halt_successful_poll;
	u64 halt_attempted_poll;
	u64 halt_poll_invalid;
	u64 halt_wakeup;
	u64 hvc_exit_stat;
	u64 wfe_exit_stat;
	u64 wfi_exit_stat;
	u64 mmio_exit_user;
	u64 mmio_exit_kernel;
	u64 exits;
};

struct kvm_mmio_fragment {
	gpa_t gpa;
	void *data;
	unsigned int len;
};

struct kvm_cpu_context {
	struct kvm_regs gp_regs;
	union {
		u64 sys_regs[101];
		u32 copro[202];
	};
	struct kvm_vcpu *__hyp_running_vcpu;
};

struct kvm_vcpu_fault_info {
	u32 esr_el2;
	u64 far_el2;
	u64 hpfar_el2;
	u64 disr_el1;
};

typedef struct kvm_cpu_context kvm_cpu_context_t;

struct vgic_v2_cpu_if {
	u32 vgic_hcr;
	u32 vgic_vmcr;
	u32 vgic_apr;
	u32 vgic_lr[64];
};

struct its_vm;

struct its_vpe {
	struct page___18 *vpt_page;
	struct its_vm *its_vm;
	int irq;
	irq_hw_number_t vpe_db_lpi;
	int vpe_proxy_event;
	u16 col_idx;
	u16 vpe_id;
	bool idai;
	bool pending_last;
};

struct vgic_v3_cpu_if {
	u32 vgic_hcr;
	u32 vgic_vmcr;
	u32 vgic_sre;
	u32 vgic_ap0r[4];
	u32 vgic_ap1r[4];
	u64 vgic_lr[16];
	struct its_vpe its_vpe;
};

enum vgic_irq_config {
	VGIC_CONFIG_EDGE = 0,
	VGIC_CONFIG_LEVEL = 1,
};

struct vgic_irq {
	raw_spinlock_t irq_lock;
	struct list_head lpi_list;
	struct list_head ap_list;
	struct kvm_vcpu *vcpu;
	struct kvm_vcpu *target_vcpu;
	u32 intid;
	bool line_level;
	bool pending_latch;
	bool active;
	bool enabled;
	bool hw;
	struct kref refcount;
	u32 hwintid;
	unsigned int host_irq;
	union {
		u8 targets;
		u32 mpidr;
	};
	u8 source;
	u8 active_source;
	u8 priority;
	u8 group;
	enum vgic_irq_config config;
	bool (*get_input_level)(int);
	void *owner;
};

enum iodev_type {
	IODEV_CPUIF = 0,
	IODEV_DIST = 1,
	IODEV_REDIST = 2,
	IODEV_ITS = 3,
};

struct kvm_io_device {
	const struct kvm_io_device_ops *ops;
};

struct vgic_its;

struct vgic_register_region;

struct vgic_io_device {
	gpa_t base_addr;
	union {
		struct kvm_vcpu *redist_vcpu;
		struct vgic_its *its;
	};
	const struct vgic_register_region *regions;
	enum iodev_type iodev_type;
	int nr_regions;
	struct kvm_io_device dev;
};

struct vgic_redist_region;

struct vgic_cpu {
	union {
		struct vgic_v2_cpu_if vgic_v2;
		struct vgic_v3_cpu_if vgic_v3;
	};
	unsigned int used_lrs;
	struct vgic_irq private_irqs[32];
	raw_spinlock_t ap_list_lock;
	struct list_head ap_list_head;
	struct vgic_io_device rd_iodev;
	struct vgic_io_device sgi_iodev;
	struct vgic_redist_region *rdreg;
	u64 pendbaser;
	bool lpis_enabled;
	u32 num_pri_bits;
	u32 num_id_bits;
};

struct arch_timer_context {
	struct kvm_vcpu *vcpu;
	u32 cnt_ctl;
	u64 cnt_cval;
	struct kvm_irq_level irq;
	u64 cntvoff;
	struct hrtimer hrtimer;
	bool loaded;
	u32 host_timer_irq;
	u32 host_timer_irq_flags;
};

struct arch_timer_cpu {
	struct arch_timer_context timers[2];
	struct hrtimer bg_timer;
	bool enabled;
};

struct kvm_pmc {
	u8 idx;
	struct perf_event___10 *perf_event;
	u64 bitmask;
};

struct kvm_pmu {
	int irq_num;
	struct kvm_pmc pmc[32];
	bool ready;
	bool created;
	bool irq_level;
};

struct kvm_mmu_memory_cache {
	int nobjs;
	void *objects[40];
};

struct vcpu_reset_state {
	long unsigned int pc;
	long unsigned int r0;
	bool be;
	bool reset;
};

struct kvm_vcpu_arch {
	struct kvm_cpu_context ctxt;
	void *sve_state;
	unsigned int sve_max_vl;
	u64 hcr_el2;
	u32 mdcr_el2;
	struct kvm_vcpu_fault_info fault;
	u64 workaround_flags;
	u64 flags;
	struct kvm_guest_debug_arch *debug_ptr;
	struct kvm_guest_debug_arch vcpu_debug_state;
	struct kvm_guest_debug_arch external_debug_state;
	kvm_cpu_context_t *host_cpu_context;
	struct thread_info *host_thread_info;
	struct user_fpsimd_state *host_fpsimd_state;
	struct {
		struct kvm_guest_debug_arch regs;
		u64 pmscr_el1;
	} host_debug_state;
	struct vgic_cpu vgic_cpu;
	struct arch_timer_cpu timer_cpu;
	struct kvm_pmu pmu;
	struct {
		u32 mdscr_el1;
	} guest_debug_preserved;
	bool power_off;
	bool pause;
	struct kvm_decode mmio_decode;
	struct kvm_mmu_memory_cache mmu_page_cache;
	int target;
	long unsigned int features[1];
	bool has_run_once;
	u64 vsesr_el2;
	struct vcpu_reset_state reset_state;
	bool sysregs_loaded_on_cpu;
};

struct kvm;

struct kvm_vcpu {
	struct kvm *kvm;
	struct preempt_notifier preempt_notifier;
	int cpu;
	int vcpu_id;
	int srcu_idx;
	int mode;
	u64 requests;
	long unsigned int guest_debug;
	int pre_pcpu;
	struct list_head blocked_vcpu_list;
	struct mutex mutex;
	struct kvm_run *run;
	int guest_xcr0_loaded;
	struct swait_queue_head wq;
	struct pid___16 *pid;
	int sigset_active;
	sigset_t sigset;
	struct kvm_vcpu_stat stat;
	unsigned int halt_poll_ns;
	bool valid_wakeup;
	int mmio_needed;
	int mmio_read_completed;
	int mmio_is_write;
	int mmio_cur_fragment;
	int mmio_nr_fragments;
	struct kvm_mmio_fragment mmio_fragments[2];
	struct {
		bool in_spin_loop;
		bool dy_eligible;
	} spin_loop;
	bool preempted;
	struct kvm_vcpu_arch arch;
	struct dentry___19 *debugfs_dentry;
	long: 64;
};

struct its_vm {
	struct fwnode_handle___13 *fwnode;
	struct irq_domain *domain;
	struct page___18 *vprop_page;
	struct its_vpe **vpes;
	int nr_vpes;
	irq_hw_number_t db_lpi_base;
	long unsigned int *db_bitmap;
	int nr_db_lpis;
	u32 vlpi_count[16];
};

enum vgic_type {
	VGIC_V2 = 0,
	VGIC_V3 = 1,
};

struct vgic_global {
	enum vgic_type type;
	phys_addr_t vcpu_base;
	void *vcpu_base_va;
	void *vcpu_hyp_va;
	void *vctrl_base;
	void *vctrl_hyp;
	int nr_lr;
	unsigned int maint_irq;
	int max_gic_vcpus;
	bool can_emulate_gicv2;
	bool has_gicv4;
	struct static_key_false gicv3_cpuif;
	u32 ich_vtr_el2;
};

struct kvm_device;

struct vgic_its {
	gpa_t vgic_its_base;
	bool enabled;
	struct vgic_io_device iodev;
	struct kvm_device *dev;
	u64 baser_device_table;
	u64 baser_coll_table;
	struct mutex cmd_lock;
	u64 cbaser;
	u32 creadr;
	u32 cwriter;
	u32 abi_rev;
	struct mutex its_lock;
	struct list_head device_list;
	struct list_head collection_list;
};

struct kvm_vcpu___2;

struct kvm___2;

struct vgic_its___2;

struct vgic_register_region {
	unsigned int reg_offset;
	unsigned int len;
	unsigned int bits_per_irq;
	unsigned int access_flags;
	union {
		long unsigned int (*read)(struct kvm_vcpu___2 *, gpa_t, unsigned int);
		long unsigned int (*its_read)(struct kvm___2 *, struct vgic_its___2 *, gpa_t, unsigned int);
	};
	union {
		void (*write)(struct kvm_vcpu___2 *, gpa_t, unsigned int, long unsigned int);
		void (*its_write)(struct kvm___2 *, struct vgic_its___2 *, gpa_t, unsigned int, long unsigned int);
	};
	long unsigned int (*uaccess_read)(struct kvm_vcpu___2 *, gpa_t, unsigned int);
	union {
		int (*uaccess_write)(struct kvm_vcpu___2 *, gpa_t, unsigned int, long unsigned int);
		int (*uaccess_its_write)(struct kvm___2 *, struct vgic_its___2 *, gpa_t, unsigned int, long unsigned int);
	};
};

struct kvm_device_ops;

struct kvm_device {
	struct kvm_device_ops *ops;
	struct kvm *kvm;
	void *private;
	struct list_head vm_node;
};

struct vgic_redist_region {
	u32 index;
	gpa_t base;
	u32 count;
	u32 free_index;
	struct list_head list;
};

struct vgic_state_iter;

struct vgic_dist {
	bool in_kernel;
	bool ready;
	bool initialized;
	u32 vgic_model;
	u32 implementation_rev;
	bool v2_groups_user_writable;
	bool msis_require_devid;
	int nr_spis;
	gpa_t vgic_dist_base;
	union {
		gpa_t vgic_cpu_base;
		struct list_head rd_regions;
	};
	bool enabled;
	struct vgic_irq *spis;
	struct vgic_io_device dist_iodev;
	bool has_its;
	u64 propbaser;
	raw_spinlock_t lpi_list_lock;
	struct list_head lpi_list_head;
	int lpi_list_count;
	struct vgic_state_iter *iter;
	struct its_vm its_vm;
};

struct fwnode_reference_args___13;

struct fwnode_endpoint___13;

struct fwnode_operations___13 {
	struct fwnode_handle___13 * (*get)(struct fwnode_handle___13 *);
	void (*put)(struct fwnode_handle___13 *);
	bool (*device_is_available)(const struct fwnode_handle___13 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___13 *, const struct device___16 *);
	bool (*property_present)(const struct fwnode_handle___13 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___13 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___13 *, const char *, const char **, size_t);
	struct fwnode_handle___13 * (*get_parent)(const struct fwnode_handle___13 *);
	struct fwnode_handle___13 * (*get_next_child_node)(const struct fwnode_handle___13 *, struct fwnode_handle___13 *);
	struct fwnode_handle___13 * (*get_named_child_node)(const struct fwnode_handle___13 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___13 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___13 *);
	struct fwnode_handle___13 * (*graph_get_next_endpoint)(const struct fwnode_handle___13 *, struct fwnode_handle___13 *);
	struct fwnode_handle___13 * (*graph_get_remote_endpoint)(const struct fwnode_handle___13 *);
	struct fwnode_handle___13 * (*graph_get_port_parent)(struct fwnode_handle___13 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___13 *, struct fwnode_endpoint___13 *);
};

struct fwnode_endpoint___13 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___13 *local_fwnode;
};

struct fwnode_reference_args___13 {
	struct fwnode_handle___13 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct property___6 {
	char *name;
	int length;
	void *value;
	struct property___6 *next;
	long unsigned int _flags;
	struct bin_attribute___16 attr;
};

enum kvm_arch_timers {
	TIMER_PTIMER = 0,
	TIMER_VTIMER = 1,
	NR_KVM_TIMERS = 2,
};

struct uts_namespace___5 {
	struct kref kref;
	struct new_utsname name;
	struct user_namespace___11 *user_ns;
	struct ucounts___11 *ucounts;
	struct ns_common ns;
};

struct cgroup_namespace___10 {
	refcount_t count;
	struct ns_common ns;
	struct user_namespace___11 *user_ns;
	struct ucounts___11 *ucounts;
	struct css_set___10 *root_cset;
};

struct ucounts___11 {
	struct hlist_node node;
	struct user_namespace___11 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct kernel_param_ops___15 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___15 *);
	int (*get)(char *, const struct kernel_param___15 *);
	void (*free)(void *);
};

struct kparam_array___15;

struct kernel_param___15 {
	const char *name;
	struct module___18 *mod;
	const struct kernel_param_ops___15 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___15 *arr;
	};
};

struct kparam_array___15 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___15 *ops;
	void *elem;
};

struct module_attribute___15 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___15 *, struct module_kobject___15 *, char *);
	ssize_t (*store)(struct module_attribute___15 *, struct module_kobject___15 *, const char *, size_t);
	void (*setup)(struct module___18 *, const char *);
	int (*test)(struct module___18 *);
	void (*free)(struct module___18 *);
};

typedef int (*key_restrict_link_func_t___17)(struct key___18 *, const struct key_type *, const union key_payload *, struct key___18 *);

struct key_restriction___18;

struct key___18 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___18 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___18 *restrict_link;
};

struct key_restriction___18 {
	key_restrict_link_func_t___17 check;
	struct key___18 *key;
	struct key_type *keytype;
};

struct seq_operations___15 {
	void * (*start)(struct seq_file___18 *, loff_t *);
	void (*stop)(struct seq_file___18 *, void *);
	void * (*next)(struct seq_file___18 *, void *, loff_t *);
	int (*show)(struct seq_file___18 *, void *);
};

struct bpf_map___10;

struct bpf_map_ops___10 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___10 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___10 *, struct file___18 *);
	void (*map_free)(struct bpf_map___10 *);
	int (*map_get_next_key)(struct bpf_map___10 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___10 *);
	void * (*map_lookup_elem)(struct bpf_map___10 *, void *);
	int (*map_update_elem)(struct bpf_map___10 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___10 *, void *);
	int (*map_push_elem)(struct bpf_map___10 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___10 *, void *);
	int (*map_peek_elem)(struct bpf_map___10 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___10 *, struct file___18 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___10 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___10 *, void *, struct seq_file___18 *);
	int (*map_check_btf)(const struct bpf_map___10 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___10 {
	const struct bpf_map_ops___10 *ops;
	struct bpf_map___10 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___17 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___10;

typedef void (*kthread_work_func_t___10)(struct kthread_work___10 *);

struct kthread_worker___10;

struct kthread_work___10 {
	struct list_head node;
	kthread_work_func_t___10 func;
	struct kthread_worker___10 *worker;
	int canceling;
};

struct kthread_worker___10 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___19 *task;
	struct kthread_work___10 *current_work;
};

struct kthread_delayed_work___10 {
	struct kthread_work___10 work;
	struct timer_list timer;
};

struct psi_group___10 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___10 *poll_kworker;
	struct kthread_delayed_work___10 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___10;

struct cgroup_rstat_cpu___10;

struct cgroup___10 {
	struct cgroup_subsys_state___10 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___17 *kn;
	struct cgroup_file___10 procs_file;
	struct cgroup_file___10 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___10 *subsys[13];
	struct cgroup_root___10 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___10 *dom_cgrp;
	struct cgroup_rstat_cpu___10 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf bpf;
	atomic_t congestion_count;
	struct cgroup___10 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___10 psi;
	int ancestor_ids[0];
};

struct cftype___10;

struct cgroup_subsys___10 {
	struct cgroup_subsys_state___10 * (*css_alloc)(struct cgroup_subsys_state___10 *);
	int (*css_online)(struct cgroup_subsys_state___10 *);
	void (*css_offline)(struct cgroup_subsys_state___10 *);
	void (*css_released)(struct cgroup_subsys_state___10 *);
	void (*css_free)(struct cgroup_subsys_state___10 *);
	void (*css_reset)(struct cgroup_subsys_state___10 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___10 *, int);
	int (*css_extra_stat_show)(struct seq_file___18 *, struct cgroup_subsys_state___10 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___19 *);
	void (*cancel_fork)(struct task_struct___19 *);
	void (*fork)(struct task_struct___19 *);
	void (*exit)(struct task_struct___19 *);
	void (*free)(struct task_struct___19 *);
	void (*bind)(struct cgroup_subsys_state___10 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___10 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___10 *dfl_cftypes;
	struct cftype___10 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___10 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___10 *updated_children;
	struct cgroup___10 *updated_next;
};

struct cgroup_root___10 {
	struct kernfs_root___17 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___10 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___10 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___10 *ss;
	struct list_head node;
	struct kernfs_ops___17 *kf_ops;
	int (*open)(struct kernfs_open_file___17 *);
	void (*release)(struct kernfs_open_file___17 *);
	u64 (*read_u64)(struct cgroup_subsys_state___10 *, struct cftype___10 *);
	s64 (*read_s64)(struct cgroup_subsys_state___10 *, struct cftype___10 *);
	int (*seq_show)(struct seq_file___18 *, void *);
	void * (*seq_start)(struct seq_file___18 *, loff_t *);
	void * (*seq_next)(struct seq_file___18 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___18 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___10 *, struct cftype___10 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___10 *, struct cftype___10 *, s64);
	ssize_t (*write)(struct kernfs_open_file___17 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___17 *, struct poll_table_struct___6 *);
};

struct perf_cpu_context___10;

struct pmu___10 {
	struct list_head entry;
	struct module___18 *module;
	struct device___16 *dev;
	const struct attribute_group___16 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___10 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___10 *);
	void (*pmu_disable)(struct pmu___10 *);
	int (*event_init)(struct perf_event___10 *);
	void (*event_mapped)(struct perf_event___10 *, struct mm_struct___18 *);
	void (*event_unmapped)(struct perf_event___10 *, struct mm_struct___18 *);
	int (*add)(struct perf_event___10 *, int);
	void (*del)(struct perf_event___10 *, int);
	void (*start)(struct perf_event___10 *, int);
	void (*stop)(struct perf_event___10 *, int);
	void (*read)(struct perf_event___10 *);
	void (*start_txn)(struct pmu___10 *, unsigned int);
	int (*commit_txn)(struct pmu___10 *);
	void (*cancel_txn)(struct pmu___10 *);
	int (*event_idx)(struct perf_event___10 *);
	void (*sched_task)(struct perf_event_context___10 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___10 *);
	int (*filter_match)(struct perf_event___10 *);
	int (*check_period)(struct perf_event___10 *, u64);
};

struct perf_cpu_context___10 {
	struct perf_event_context___10 ctx;
	struct perf_event_context___10 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___10 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___10 {
	struct cgroup_subsys_state___10 css;
	struct perf_cgroup_info *info;
};

struct kvm_vmid {
	u64 vmid_gen;
	u32 vmid;
};

struct kvm_arch {
	struct kvm_vmid vmid;
	pgd_t *pgd;
	phys_addr_t pgd_phys;
	u64 vtcr;
	int *last_vcpu_ran;
	int max_vcpus;
	struct vgic_dist vgic;
	u32 psci_version;
};

enum vcpu_sysreg {
	__INVALID_SYSREG__ = 0,
	MPIDR_EL1 = 1,
	CSSELR_EL1 = 2,
	SCTLR_EL1 = 3,
	ACTLR_EL1 = 4,
	CPACR_EL1 = 5,
	ZCR_EL1 = 6,
	TTBR0_EL1 = 7,
	TTBR1_EL1 = 8,
	TCR_EL1 = 9,
	ESR_EL1 = 10,
	AFSR0_EL1 = 11,
	AFSR1_EL1 = 12,
	FAR_EL1 = 13,
	MAIR_EL1 = 14,
	VBAR_EL1 = 15,
	CONTEXTIDR_EL1 = 16,
	TPIDR_EL0 = 17,
	TPIDRRO_EL0 = 18,
	TPIDR_EL1 = 19,
	AMAIR_EL1 = 20,
	CNTKCTL_EL1 = 21,
	PAR_EL1 = 22,
	MDSCR_EL1 = 23,
	MDCCINT_EL1 = 24,
	DISR_EL1 = 25,
	PMCR_EL0 = 26,
	PMSELR_EL0 = 27,
	PMEVCNTR0_EL0 = 28,
	PMEVCNTR30_EL0 = 58,
	PMCCNTR_EL0 = 59,
	PMEVTYPER0_EL0 = 60,
	PMEVTYPER30_EL0 = 90,
	PMCCFILTR_EL0 = 91,
	PMCNTENSET_EL0 = 92,
	PMINTENSET_EL1 = 93,
	PMOVSSET_EL0 = 94,
	PMSWINC_EL0 = 95,
	PMUSERENR_EL0 = 96,
	DACR32_EL2 = 97,
	IFSR32_EL2 = 98,
	FPEXC32_EL2 = 99,
	DBGVCR32_EL2 = 100,
	NR_SYS_REGS = 101,
};

struct kvm_vm_stat {
	ulong remote_tlb_flush;
};

struct kvm_io_range {
	gpa_t addr;
	int len;
	struct kvm_io_device *dev;
};

struct kvm_io_bus {
	int dev_count;
	int ioeventfd_count;
	struct kvm_io_range range[0];
};

enum kvm_bus {
	KVM_MMIO_BUS = 0,
	KVM_PIO_BUS = 1,
	KVM_VIRTIO_CCW_NOTIFY_BUS = 2,
	KVM_FAST_MMIO_BUS = 3,
	KVM_NR_BUSES = 4,
};

struct kvm_memslots;

struct kvm_irq_routing_table;

struct kvm_stat_data;

struct kvm {
	spinlock_t mmu_lock;
	struct mutex slots_lock;
	struct mm_struct___18 *mm;
	struct kvm_memslots *memslots[1];
	struct kvm_vcpu *vcpus[512];
	atomic_t online_vcpus;
	int created_vcpus;
	int last_boosted_vcpu;
	struct list_head vm_list;
	struct mutex lock;
	struct kvm_io_bus *buses[4];
	struct {
		spinlock_t lock;
		struct list_head items;
		struct list_head resampler_list;
		struct mutex resampler_lock;
	} irqfds;
	struct list_head ioeventfds;
	struct kvm_vm_stat stat;
	struct kvm_arch arch;
	refcount_t users_count;
	struct kvm_coalesced_mmio_ring *coalesced_mmio_ring;
	spinlock_t ring_lock;
	struct list_head coalesced_zones;
	struct mutex irq_lock;
	struct kvm_irq_routing_table *irq_routing;
	struct hlist_head irq_ack_notifier_list;
	struct mmu_notifier mmu_notifier;
	long unsigned int mmu_notifier_seq;
	long int mmu_notifier_count;
	long int tlbs_dirty;
	struct list_head devices;
	bool manual_dirty_log_protect;
	struct dentry___19 *debugfs_dentry;
	struct kvm_stat_data **debugfs_stat_data;
	struct srcu_struct srcu;
	struct srcu_struct irq_srcu;
	pid_t userspace_pid;
};

struct kvm_irq_routing_table {
	int chip[988];
	u32 nr_rt_entries;
	struct hlist_head map[0];
};

struct kvm_memslots {
	u64 generation;
	struct kvm_memory_slot memslots[512];
	short int id_to_index[512];
	atomic_t lru_slot;
	int used_slots;
};

struct kvm_stat_data {
	int offset;
	int mode;
	struct kvm *kvm;
};

enum kvm_stat_kind {
	KVM_STAT_VM = 0,
	KVM_STAT_VCPU = 1,
};

struct kvm_stats_debugfs_item {
	const char *name;
	int offset;
	enum kvm_stat_kind kind;
	int mode;
};

struct kvm_device_ops {
	const char *name;
	int (*create)(struct kvm_device *, u32);
	void (*init)(struct kvm_device *);
	void (*destroy)(struct kvm_device *);
	void (*release)(struct kvm_device *);
	int (*set_attr)(struct kvm_device *, struct kvm_device_attr *);
	int (*get_attr)(struct kvm_device *, struct kvm_device_attr *);
	int (*has_attr)(struct kvm_device *, struct kvm_device_attr *);
	long int (*ioctl)(struct kvm_device *, unsigned int, long unsigned int);
	int (*mmap)(struct kvm_device *, struct vm_area_struct___18 *);
};

struct bdi_writeback_congested___6 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___6 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___6 {
	struct bio___6 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___6 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___6 bip_inline_vecs[0];
};

struct bio_set___6 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___6 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___5 {
	struct mem_cgroup___5 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___5 {
	struct lruvec___17 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___5 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___5 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct kexec_file_ops___6;

struct arch_hibernate_hdr_invariants {
	char uts_version[65];
};

struct arch_hibernate_hdr {
	struct arch_hibernate_hdr_invariants invariants;
	phys_addr_t ttbr1_el1;
	void (*reenter_kernel)();
	phys_addr_t __hyp_stub_vectors;
	u64 sleep_cpu_mpidr;
};

struct module___19;

struct file___19;

struct kiocb___19;

struct vm_area_struct___19;

struct inode___21;

struct file_lock___19;

struct page___19;

struct file_operations___19 {
	struct module___19 *owner;
	loff_t (*llseek)(struct file___19 *, loff_t, int);
	ssize_t (*read)(struct file___19 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___19 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___19 *, struct iov_iter___7 *);
	ssize_t (*write_iter)(struct kiocb___19 *, struct iov_iter___7 *);
	int (*iopoll)(struct kiocb___19 *, bool);
	int (*iterate)(struct file___19 *, struct dir_context *);
	int (*iterate_shared)(struct file___19 *, struct dir_context *);
	__poll_t (*poll)(struct file___19 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___19 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___19 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___19 *, struct vm_area_struct___19 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___21 *, struct file___19 *);
	int (*flush)(struct file___19 *, fl_owner_t);
	int (*release)(struct inode___21 *, struct file___19 *);
	int (*fsync)(struct file___19 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___19 *, int);
	int (*lock)(struct file___19 *, int, struct file_lock___19 *);
	ssize_t (*sendpage)(struct file___19 *, struct page___19 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___19 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___19 *, int, struct file_lock___19 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___19 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___19 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___19 *, long int, struct file_lock___19 **, void **);
	long int (*fallocate)(struct file___19 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___19 *);
	ssize_t (*copy_file_range)(struct file___19 *, loff_t, struct file___19 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___19 *, loff_t, struct file___19 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___19 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___18 {
	u64 seqnum;
	struct vm_area_struct___19 *vmas[4];
};

struct page_frag___18 {
	struct page___19 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___19;

struct pid___17;

struct cred___18;

struct nsproxy___18;

struct signal_struct___17;

struct vm_struct___15;

struct task_struct___20 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___20 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___19 *mm;
	struct mm_struct___19 *active_mm;
	struct vmacache___18 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___20 *real_parent;
	struct task_struct___20 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___20 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___17 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___17 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___17 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___18 *ptracer_cred;
	const struct cred___18 *real_cred;
	const struct cred___18 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___18 *nsproxy;
	struct signal_struct___17 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___20 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___2 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___18 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___20 *oom_reaper_list;
	struct vm_struct___15 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___10 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct secondary_data___19 {
	void *stack;
	struct task_struct___20 *task;
	long int status;
};

struct irqaction___2 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___2 *next;
	irq_handler_t thread_fn;
	struct task_struct___20 *thread;
	struct irqaction___2 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_desc___2;

typedef void (*irq_flow_handler_t___2)(struct irq_desc___2 *);

struct kset___18;

struct kobj_type___18;

struct kernfs_node___18;

struct kobject___19 {
	const char *name;
	struct list_head entry;
	struct kobject___19 *parent;
	struct kset___18 *kset;
	struct kobj_type___18 *ktype;
	struct kernfs_node___18 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct irq_desc___2 {
	struct irq_common_data irq_common_data;
	struct irq_data___3 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___2 handle_irq;
	struct irqaction___2 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int irq_count;
	unsigned int tot_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___19 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___19 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___19 *pgtable_t___18;

struct address_space___18;

struct dev_pagemap___18;

struct page___19 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___18 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___19 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___18 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___19 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___18 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___18;

struct lruvec___18 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___18 *pgdat;
};

struct zone___18 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___18 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___18 {
	struct zone___18 *zone;
	int zone_idx;
};

struct zonelist___18 {
	struct zoneref___18 _zonerefs[25];
};

struct pglist_data___18 {
	struct zone___18 node_zones[3];
	struct zonelist___18 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___20 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___20 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___18 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___19 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___20 *owner;
};

struct blocking_notifier_head___18 {
	struct rw_semaphore___19 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___18;

struct vm_area_struct___19 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___19 *vm_next;
	struct vm_area_struct___19 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___19 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___18 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___19 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___18;

struct mm_struct___19 {
	struct {
		struct vm_area_struct___19 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___19 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___19 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___18 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___20 *owner;
		struct user_namespace___3 *user_ns;
		struct file___19 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___18 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___18;

struct address_space___18 {
	struct inode___21 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___19 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___18 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___18)(struct vm_area_struct___19 *, long unsigned int, const struct page___19 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___18)(struct page___19 *, void *);

struct dev_pagemap___18 {
	dev_page_fault_t___18 page_fault;
	dev_page_free_t___18 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___6 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct dentry___20;

struct path___18 {
	struct vfsmount *mnt;
	struct dentry___20 *dentry;
};

struct fown_struct___17 {
	rwlock_t lock;
	struct pid___17 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___19 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___18 f_path;
	struct inode___21 *f_inode;
	const struct file_operations___19 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___17 f_owner;
	const struct cred___18 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___18 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___18;

struct vm_operations_struct___18 {
	void (*open)(struct vm_area_struct___19 *);
	void (*close)(struct vm_area_struct___19 *);
	int (*split)(struct vm_area_struct___19 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___19 *);
	vm_fault_t (*fault)(struct vm_fault___18 *);
	vm_fault_t (*huge_fault)(struct vm_fault___18 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___18 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___19 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___18 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___18 *);
	int (*access)(struct vm_area_struct___19 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___19 *);
	int (*set_policy)(struct vm_area_struct___19 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___19 *, long unsigned int);
	struct page___19 * (*find_special_page)(struct vm_area_struct___19 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___18 {
	struct task_struct___20 *task;
	struct core_thread___18 *next;
};

struct core_state___18 {
	atomic_t nr_threads;
	struct core_thread___18 dumper;
	struct completion startup;
};

struct vm_fault___18 {
	struct vm_area_struct___19 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___19 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___19 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___18 prealloc_pte;
};

struct pid_namespace___17;

struct upid___17 {
	int nr;
	struct pid_namespace___17 *ns;
};

struct pid_namespace___17 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___20 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___17 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___20 *proc_self;
	struct dentry___20 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___3 *user_ns;
	struct ucounts___2 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common ns;
};

struct pid___17 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___17 numbers[1];
};

struct key___19;

struct user_struct___18 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___19 *uid_keyring;
	struct key___19 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___18 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___19 *session_keyring;
	struct key___19 *process_keyring;
	struct key___19 *thread_keyring;
	struct key___19 *request_key_auth;
	void *security;
	struct user_struct___18 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct nsproxy___18 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___17 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct signal_struct___17 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___20 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___20 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___17 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___17 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___19 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___17 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_struct___15 {
	struct vm_struct___15 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___19 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___17 {
	struct task_struct___20 task;
	long unsigned int stack[8192];
};

enum {
	IRQD_TRIGGER_MASK = 15,
	IRQD_SETAFFINITY_PENDING = 256,
	IRQD_ACTIVATED = 512,
	IRQD_NO_BALANCING = 1024,
	IRQD_PER_CPU = 2048,
	IRQD_AFFINITY_SET = 4096,
	IRQD_LEVEL = 8192,
	IRQD_WAKEUP_STATE = 16384,
	IRQD_MOVE_PCNTXT = 32768,
	IRQD_IRQ_DISABLED = 65536,
	IRQD_IRQ_MASKED = 131072,
	IRQD_IRQ_INPROGRESS = 262144,
	IRQD_WAKEUP_ARMED = 524288,
	IRQD_FORWARDED_TO_VCPU = 1048576,
	IRQD_AFFINITY_MANAGED = 2097152,
	IRQD_IRQ_STARTED = 4194304,
	IRQD_MANAGED_SHUTDOWN = 8388608,
	IRQD_SINGLE_TARGET = 16777216,
	IRQD_DEFAULT_TRIGGER_SET = 33554432,
	IRQD_CAN_RESERVE = 67108864,
};

struct kernfs_root___18;

struct kernfs_elem_dir___18 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___18 *root;
};

struct kernfs_syscall_ops___18;

struct kernfs_root___18 {
	struct kernfs_node___18 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___18 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___18 {
	struct kernfs_node___18 *target_kn;
};

struct kernfs_ops___18;

struct kernfs_elem_attr___18 {
	const struct kernfs_ops___18 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___18 *notify_next;
};

struct kernfs_node___18 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___18 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___18 dir;
		struct kernfs_elem_symlink___18 symlink;
		struct kernfs_elem_attr___18 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___18;

struct kernfs_ops___18 {
	int (*open)(struct kernfs_open_file___18 *);
	void (*release)(struct kernfs_open_file___18 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___18 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___18 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___18 *, struct vm_area_struct___19 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___18 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___18 {
	int (*remount_fs)(struct kernfs_root___18 *, int *, char *);
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___18 *);
	int (*mkdir)(struct kernfs_node___18 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___18 *);
	int (*rename)(struct kernfs_node___18 *, struct kernfs_node___18 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___18 *, struct kernfs_root___18 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___18 {
	struct kernfs_node___18 *kn;
	struct file___19 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___18 *vm_ops;
};

struct sysfs_ops___18 {
	ssize_t (*show)(struct kobject___19 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___19 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___18;

struct kset___18 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___19 kobj;
	const struct kset_uevent_ops___18 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___18 {
	void (*release)(struct kobject___19 *);
	const struct sysfs_ops___18 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___19 *);
	const void * (*namespace)(struct kobject___19 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___18 {
	int (* const filter)(struct kset___18 *, struct kobject___19 *);
	const char * (* const name)(struct kset___18 *, struct kobject___19 *);
	int (* const uevent)(struct kset___18 *, struct kobject___19 *, struct kobj_uevent_env *);
};

struct kobj_attribute___19 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___19 *, struct kobj_attribute___19 *, char *);
	ssize_t (*store)(struct kobject___19 *, struct kobj_attribute___19 *, const char *, size_t);
};

struct module_kobject___16 {
	struct kobject___19 kobj;
	struct module___19 *mod;
	struct kobject___19 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___16 {
	struct module___19 *mod;
	struct latch_tree_node node;
};

struct module_layout___16 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___16 mtn;
};

struct module_attribute___16;

struct kernel_param___16;

struct module___19 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___16 mkobj;
	struct module_attribute___16 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___19 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___16 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___16 core_layout;
	struct module_layout___16 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef int (*key_restrict_link_func_t___18)(struct key___19 *, const struct key_type *, const union key_payload *, struct key___19 *);

struct key_restriction___19;

struct key___19 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___19 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___19 *restrict_link;
};

struct key_restriction___19 {
	key_restrict_link_func_t___18 check;
	struct key___19 *key;
	struct key_type *keytype;
};

enum pageflags {
	PG_locked = 0,
	PG_error = 1,
	PG_referenced = 2,
	PG_uptodate = 3,
	PG_dirty = 4,
	PG_lru = 5,
	PG_active = 6,
	PG_waiters = 7,
	PG_slab = 8,
	PG_owner_priv_1 = 9,
	PG_arch_1 = 10,
	PG_reserved = 11,
	PG_private = 12,
	PG_private_2 = 13,
	PG_writeback = 14,
	PG_head = 15,
	PG_mappedtodisk = 16,
	PG_reclaim = 17,
	PG_swapbacked = 18,
	PG_unevictable = 19,
	PG_mlocked = 20,
	PG_hwpoison = 21,
	PG_young = 22,
	PG_idle = 23,
	PG_workingset = 24,
	__NR_PAGEFLAGS = 25,
	PG_checked = 9,
	PG_swapcache = 9,
	PG_fscache = 13,
	PG_pinned = 9,
	PG_savepinned = 4,
	PG_foreign = 9,
	PG_slob_free = 12,
	PG_double_map = 13,
	PG_isolated = 17,
};

struct dentry_operations___18;

struct super_block___19;

struct dentry___20 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___20 *d_parent;
	struct qstr d_name;
	struct inode___21 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___18 *d_op;
	struct super_block___19 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___18;

struct block_device___19;

struct inode___21 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___18 *i_op;
	struct super_block___19 *i_sb;
	struct address_space___18 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___19 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___19 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___18 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___19 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___18 {
	int (*d_revalidate)(struct dentry___20 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___20 *, unsigned int);
	int (*d_hash)(const struct dentry___20 *, struct qstr *);
	int (*d_compare)(const struct dentry___20 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___20 *);
	int (*d_init)(struct dentry___20 *);
	void (*d_release)(struct dentry___20 *);
	void (*d_prune)(struct dentry___20 *);
	void (*d_iput)(struct dentry___20 *, struct inode___21 *);
	char * (*d_dname)(struct dentry___20 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___18 *);
	int (*d_manage)(const struct path___18 *, bool);
	struct dentry___20 * (*d_real)(struct dentry___20 *, const struct inode___21 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___18;

struct mem_dqinfo___18 {
	struct quota_format_type___18 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___18;

struct quota_info___18 {
	unsigned int flags;
	struct rw_semaphore___19 dqio_sem;
	struct inode___21 *files[3];
	struct mem_dqinfo___18 info[3];
	const struct quota_format_ops___18 *ops[3];
};

struct rcuwait___18 {
	struct task_struct___20 *task;
};

struct percpu_rw_semaphore___18 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___19 rw_sem;
	struct rcuwait___18 writer;
	int readers_block;
};

struct sb_writers___18 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___18 rw_sem[3];
};

struct file_system_type___18;

struct super_operations___18;

struct dquot_operations___18;

struct quotactl_ops___18;

struct super_block___19 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___18 *s_type;
	const struct super_operations___18 *s_op;
	const struct dquot_operations___18 *dq_op;
	const struct quotactl_ops___18 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___20 *s_root;
	struct rw_semaphore___19 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___19 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___18 s_dquot;
	struct sb_writers___18 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___18 *s_d_op;
	int cleancache_poolid;
	struct shrinker___5 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___19 {
	struct file___19 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___19 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___19 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___19 *ia_file;
};

struct dquot___18 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___19 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___18 {
	int qf_fmt_id;
	const struct quota_format_ops___18 *qf_ops;
	struct module___19 *qf_owner;
	struct quota_format_type___18 *qf_next;
};

struct quota_format_ops___18 {
	int (*check_quota_file)(struct super_block___19 *, int);
	int (*read_file_info)(struct super_block___19 *, int);
	int (*write_file_info)(struct super_block___19 *, int);
	int (*free_file_info)(struct super_block___19 *, int);
	int (*read_dqblk)(struct dquot___18 *);
	int (*commit_dqblk)(struct dquot___18 *);
	int (*release_dqblk)(struct dquot___18 *);
	int (*get_next_id)(struct super_block___19 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___18 {
	int (*write_dquot)(struct dquot___18 *);
	struct dquot___18 * (*alloc_dquot)(struct super_block___19 *, int);
	void (*destroy_dquot)(struct dquot___18 *);
	int (*acquire_dquot)(struct dquot___18 *);
	int (*release_dquot)(struct dquot___18 *);
	int (*mark_dirty)(struct dquot___18 *);
	int (*write_info)(struct super_block___19 *, int);
	qsize_t * (*get_reserved_space)(struct inode___21 *);
	int (*get_projid)(struct inode___21 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___21 *, qsize_t *);
	int (*get_next_id)(struct super_block___19 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___18 {
	int (*quota_on)(struct super_block___19 *, int, int, const struct path___18 *);
	int (*quota_off)(struct super_block___19 *, int);
	int (*quota_enable)(struct super_block___19 *, unsigned int);
	int (*quota_disable)(struct super_block___19 *, unsigned int);
	int (*quota_sync)(struct super_block___19 *, int);
	int (*set_info)(struct super_block___19 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___19 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___19 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___19 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___19 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___19 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___18 {
	int (*writepage)(struct page___19 *, struct writeback_control___3 *);
	int (*readpage)(struct file___19 *, struct page___19 *);
	int (*writepages)(struct address_space___18 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___19 *);
	int (*readpages)(struct file___19 *, struct address_space___18 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___19 *, struct address_space___18 *, loff_t, unsigned int, unsigned int, struct page___19 **, void **);
	int (*write_end)(struct file___19 *, struct address_space___18 *, loff_t, unsigned int, unsigned int, struct page___19 *, void *);
	sector_t (*bmap)(struct address_space___18 *, sector_t);
	void (*invalidatepage)(struct page___19 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___19 *, gfp_t);
	void (*freepage)(struct page___19 *);
	ssize_t (*direct_IO)(struct kiocb___19 *, struct iov_iter___7 *);
	int (*migratepage)(struct address_space___18 *, struct page___19 *, struct page___19 *, enum migrate_mode);
	bool (*isolate_page)(struct page___19 *, isolate_mode_t);
	void (*putback_page)(struct page___19 *);
	int (*launder_page)(struct page___19 *);
	int (*is_partially_uptodate)(struct page___19 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___19 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___18 *, struct page___19 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___19 *, sector_t *);
	void (*swap_deactivate)(struct file___19 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___19 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___21 *bd_inode;
	struct super_block___19 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___19 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___18 {
	struct dentry___20 * (*lookup)(struct inode___21 *, struct dentry___20 *, unsigned int);
	const char * (*get_link)(struct dentry___20 *, struct inode___21 *, struct delayed_call *);
	int (*permission)(struct inode___21 *, int);
	struct posix_acl * (*get_acl)(struct inode___21 *, int);
	int (*readlink)(struct dentry___20 *, char *, int);
	int (*create)(struct inode___21 *, struct dentry___20 *, umode_t, bool);
	int (*link)(struct dentry___20 *, struct inode___21 *, struct dentry___20 *);
	int (*unlink)(struct inode___21 *, struct dentry___20 *);
	int (*symlink)(struct inode___21 *, struct dentry___20 *, const char *);
	int (*mkdir)(struct inode___21 *, struct dentry___20 *, umode_t);
	int (*rmdir)(struct inode___21 *, struct dentry___20 *);
	int (*mknod)(struct inode___21 *, struct dentry___20 *, umode_t, dev_t);
	int (*rename)(struct inode___21 *, struct dentry___20 *, struct inode___21 *, struct dentry___20 *, unsigned int);
	int (*setattr)(struct dentry___20 *, struct iattr___19 *);
	int (*getattr)(const struct path___18 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___20 *, char *, size_t);
	int (*fiemap)(struct inode___21 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___21 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___21 *, struct dentry___20 *, struct file___19 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___21 *, struct dentry___20 *, umode_t);
	int (*set_acl)(struct inode___21 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___18 {
	void (*fl_copy_lock)(struct file_lock___19 *, struct file_lock___19 *);
	void (*fl_release_private)(struct file_lock___19 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___18;

struct lock_manager_operations___18;

struct file_lock___19 {
	struct file_lock___19 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___19 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___18 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___18 *fl_ops;
	const struct lock_manager_operations___18 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___18 {
	int (*lm_compare_owner)(struct file_lock___19 *, struct file_lock___19 *);
	long unsigned int (*lm_owner_key)(struct file_lock___19 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___19 *);
	int (*lm_grant)(struct file_lock___19 *, int);
	bool (*lm_break)(struct file_lock___19 *);
	int (*lm_change)(struct file_lock___19 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___19 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___18 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___18 *fa_next;
	struct file___19 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___18 {
	const char *name;
	int fs_flags;
	struct dentry___20 * (*mount)(struct file_system_type___18 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___19 *);
	struct module___19 *owner;
	struct file_system_type___18 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___18 {
	struct inode___21 * (*alloc_inode)(struct super_block___19 *);
	void (*destroy_inode)(struct inode___21 *);
	void (*dirty_inode)(struct inode___21 *, int);
	int (*write_inode)(struct inode___21 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___21 *);
	void (*evict_inode)(struct inode___21 *);
	void (*put_super)(struct super_block___19 *);
	int (*sync_fs)(struct super_block___19 *, int);
	int (*freeze_super)(struct super_block___19 *);
	int (*freeze_fs)(struct super_block___19 *);
	int (*thaw_super)(struct super_block___19 *);
	int (*unfreeze_fs)(struct super_block___19 *);
	int (*statfs)(struct dentry___20 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___19 *, int *, char *);
	void (*umount_begin)(struct super_block___19 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___20 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___20 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___20 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___20 *);
	ssize_t (*quota_read)(struct super_block___19 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___19 *, int, const char *, size_t, loff_t);
	struct dquot___18 ** (*get_dquots)(struct inode___21 *);
	int (*bdev_try_to_free_page)(struct super_block___19 *, struct page___19 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___19 *, struct shrink_control___5 *);
	long int (*free_cached_objects)(struct super_block___19 *, struct shrink_control___5 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___18(struct page___19 *);

struct kernel_param_ops___16 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___16 *);
	int (*get)(char *, const struct kernel_param___16 *);
	void (*free)(void *);
};

struct kparam_array___16;

struct kernel_param___16 {
	const char *name;
	struct module___19 *mod;
	const struct kernel_param_ops___16 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___16 *arr;
	};
};

struct kparam_array___16 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___16 *ops;
	void *elem;
};

struct module_attribute___16 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___16 *, struct module_kobject___16 *, char *);
	ssize_t (*store)(struct module_attribute___16 *, struct module_kobject___16 *, const char *, size_t);
	void (*setup)(struct module___19 *, const char *);
	int (*test)(struct module___19 *);
	void (*free)(struct module___19 *);
};

struct kimage___6;

typedef void *kexec_load_t___6(struct kimage___6 *, char *, long unsigned int, char *, long unsigned int, char *, long unsigned int);

struct kexec_file_ops___7 {
	kexec_probe_t *probe;
	kexec_load_t___6 *load;
	kexec_cleanup_t *cleanup;
};

struct kimage___6 {
	kimage_entry_t head;
	kimage_entry_t *entry;
	kimage_entry_t *last_entry;
	long unsigned int start;
	struct page___19 *control_code_page;
	struct page___19 *swap_page;
	void *vmcoreinfo_data_copy;
	long unsigned int nr_segments;
	struct kexec_segment segment[16];
	struct list_head control_pages;
	struct list_head dest_pages;
	struct list_head unusable_pages;
	long unsigned int control_page;
	unsigned int type: 1;
	unsigned int preserve_context: 1;
	unsigned int file_mode: 1;
	struct kimage_arch arch;
	void *kernel_buf;
	long unsigned int kernel_buf_len;
	void *initrd_buf;
	long unsigned int initrd_buf_len;
	char *cmdline_buf;
	long unsigned int cmdline_buf_len;
	const struct kexec_file_ops___7 *fops;
	void *image_loader_data;
	struct purgatory_info purgatory_info;
};

struct kexec_buf {
	struct kimage___4 *image;
	void *buffer;
	long unsigned int bufsz;
	long unsigned int mem;
	long unsigned int memsz;
	long unsigned int buf_align;
	long unsigned int buf_min;
	long unsigned int buf_max;
	bool top_down;
};

typedef __be32 fdt32_t;

struct fdt_header {
	fdt32_t magic;
	fdt32_t totalsize;
	fdt32_t off_dt_struct;
	fdt32_t off_dt_strings;
	fdt32_t off_mem_rsvmap;
	fdt32_t version;
	fdt32_t last_comp_version;
	fdt32_t boot_cpuid_phys;
	fdt32_t size_dt_strings;
	fdt32_t size_dt_struct;
};

struct arm64_image_header {
	__le32 code0;
	__le32 code1;
	__le64 text_offset;
	__le64 image_size;
	__le64 flags;
	__le64 res2;
	__le64 res3;
	__le64 res4;
	__le32 magic;
	__le32 res5;
};

enum {
	MEMREMAP_WB = 1,
	MEMREMAP_WT = 2,
	MEMREMAP_WC = 4,
	MEMREMAP_ENC = 8,
	MEMREMAP_DEC = 16,
};

enum sdei_conduit_types {
	CONDUIT_INVALID = 0,
	CONDUIT_SMC = 1,
	CONDUIT_HVC = 2,
};

typedef int sdei_event_callback(u32, struct pt_regs *, void *);

struct sdei_registered_event {
	struct pt_regs interrupted_regs;
	sdei_event_callback *callback;
	void *callback_arg;
	u32 event_num;
	u8 priority;
};

struct kretprobe_instance;

typedef int (*kretprobe_handler_t)(struct kretprobe_instance *, struct pt_regs *);

struct kretprobe;

struct kretprobe_instance {
	struct hlist_node hlist;
	struct kretprobe *rp;
	kprobe_opcode_t *ret_addr;
	struct task_struct___15 *task;
	char data[0];
};

struct jprobe {
	struct kprobe kp;
	void *entry;
};

struct kretprobe {
	struct kprobe kp;
	kretprobe_handler_t handler;
	kretprobe_handler_t entry_handler;
	int maxactive;
	int nmissed;
	size_t data_size;
	struct hlist_head free_instances;
	raw_spinlock_t lock;
};

enum probe_insn {
	INSN_REJECTED = 0,
	INSN_GOOD_NO_SLOT = 1,
	INSN_GOOD = 2,
};

enum aarch64_insn_special_register {
	AARCH64_INSN_SPCLREG_SPSR_EL1 = 49664,
	AARCH64_INSN_SPCLREG_ELR_EL1 = 49665,
	AARCH64_INSN_SPCLREG_SP_EL0 = 49672,
	AARCH64_INSN_SPCLREG_SPSEL = 49680,
	AARCH64_INSN_SPCLREG_CURRENTEL = 49682,
	AARCH64_INSN_SPCLREG_DAIF = 55825,
	AARCH64_INSN_SPCLREG_NZCV = 55824,
	AARCH64_INSN_SPCLREG_FPCR = 55840,
	AARCH64_INSN_SPCLREG_DSPSR_EL0 = 55848,
	AARCH64_INSN_SPCLREG_DLR_EL0 = 55849,
	AARCH64_INSN_SPCLREG_SPSR_EL2 = 57856,
	AARCH64_INSN_SPCLREG_ELR_EL2 = 57857,
	AARCH64_INSN_SPCLREG_SP_EL1 = 57864,
	AARCH64_INSN_SPCLREG_SPSR_INQ = 57880,
	AARCH64_INSN_SPCLREG_SPSR_ABT = 57881,
	AARCH64_INSN_SPCLREG_SPSR_UND = 57882,
	AARCH64_INSN_SPCLREG_SPSR_FIQ = 57883,
	AARCH64_INSN_SPCLREG_SPSR_EL3 = 61952,
	AARCH64_INSN_SPCLREG_ELR_EL3 = 61953,
	AARCH64_INSN_SPCLREG_SP_EL2 = 61968,
};

struct file___20;

struct kiocb___20;

struct vm_area_struct___20;

struct inode___22;

struct file_lock___20;

struct page___20;

struct file_operations___20 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___20 *, loff_t, int);
	ssize_t (*read)(struct file___20 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___20 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___20 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___20 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___20 *, bool);
	int (*iterate)(struct file___20 *, struct dir_context *);
	int (*iterate_shared)(struct file___20 *, struct dir_context *);
	__poll_t (*poll)(struct file___20 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___20 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___20 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___20 *, struct vm_area_struct___20 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___22 *, struct file___20 *);
	int (*flush)(struct file___20 *, fl_owner_t);
	int (*release)(struct inode___22 *, struct file___20 *);
	int (*fsync)(struct file___20 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___20 *, int);
	int (*lock)(struct file___20 *, int, struct file_lock___20 *);
	ssize_t (*sendpage)(struct file___20 *, struct page___20 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___20 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___20 *, int, struct file_lock___20 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___20 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___20 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___20 *, long int, struct file_lock___20 **, void **);
	long int (*fallocate)(struct file___20 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___20 *);
	ssize_t (*copy_file_range)(struct file___20 *, loff_t, struct file___20 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___20 *, loff_t, struct file___20 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___20 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___19 {
	u64 seqnum;
	struct vm_area_struct___20 *vmas[4];
};

struct page_frag___19 {
	struct page___20 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___20;

struct pid___18;

struct cred___19;

struct nsproxy___19;

struct signal_struct___18;

struct task_struct___21 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___21 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___20 *mm;
	struct mm_struct___20 *active_mm;
	struct vmacache___19 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___21 *real_parent;
	struct task_struct___21 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___21 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___18 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___18 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___18 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___19 *ptracer_cred;
	const struct cred___19 *real_cred;
	const struct cred___19 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___19 *nsproxy;
	struct signal_struct___18 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___21 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___2 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___19 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___21 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___10 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___19;

struct super_block___20;

struct dentry___21 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___21 *d_parent;
	struct qstr d_name;
	struct inode___22 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___19 *d_op;
	struct super_block___20 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct rw_semaphore___20 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___21 *owner;
};

struct address_space_operations___19;

struct address_space___19 {
	struct inode___22 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___20 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___19 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___19;

struct block_device___20;

struct inode___22 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___19 *i_op;
	struct super_block___20 *i_sb;
	struct address_space___19 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___20 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___20 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___19 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___20 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___19;

struct dentry_operations___19 {
	int (*d_revalidate)(struct dentry___21 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___21 *, unsigned int);
	int (*d_hash)(const struct dentry___21 *, struct qstr *);
	int (*d_compare)(const struct dentry___21 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___21 *);
	int (*d_init)(struct dentry___21 *);
	void (*d_release)(struct dentry___21 *);
	void (*d_prune)(struct dentry___21 *);
	void (*d_iput)(struct dentry___21 *, struct inode___22 *);
	char * (*d_dname)(struct dentry___21 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___19 *);
	int (*d_manage)(const struct path___19 *, bool);
	struct dentry___21 * (*d_real)(struct dentry___21 *, const struct inode___22 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___19;

struct mem_dqinfo___19 {
	struct quota_format_type___19 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___19;

struct quota_info___19 {
	unsigned int flags;
	struct rw_semaphore___20 dqio_sem;
	struct inode___22 *files[3];
	struct mem_dqinfo___19 info[3];
	const struct quota_format_ops___19 *ops[3];
};

struct rcuwait___19 {
	struct task_struct___21 *task;
};

struct percpu_rw_semaphore___19 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___20 rw_sem;
	struct rcuwait___19 writer;
	int readers_block;
};

struct sb_writers___19 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___19 rw_sem[3];
};

struct file_system_type___19;

struct super_operations___19;

struct dquot_operations___19;

struct quotactl_ops___19;

struct super_block___20 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___19 *s_type;
	const struct super_operations___19 *s_op;
	const struct dquot_operations___19 *dq_op;
	const struct quotactl_ops___19 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___21 *s_root;
	struct rw_semaphore___20 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___20 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___19 s_dquot;
	struct sb_writers___19 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___19 *s_d_op;
	int cleancache_poolid;
	struct shrinker___5 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct path___19 {
	struct vfsmount *mnt;
	struct dentry___21 *dentry;
};

typedef struct page___20 *pgtable_t___19;

struct dev_pagemap___19;

struct page___20 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___19 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___20 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___19 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___20 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___19 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___19;

struct lruvec___19 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___19 *pgdat;
};

struct zone___19 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___19 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___19 {
	struct zone___19 *zone;
	int zone_idx;
};

struct zonelist___19 {
	struct zoneref___19 _zonerefs[25];
};

struct pglist_data___19 {
	struct zone___19 node_zones[3];
	struct zonelist___19 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___21 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___21 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___19 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___20 {
	void *stack;
	struct task_struct___21 *task;
	long int status;
};

struct blocking_notifier_head___19 {
	struct rw_semaphore___20 rwsem;
	struct notifier_block *head;
};

struct pid_namespace___18;

struct upid___18 {
	int nr;
	struct pid_namespace___18 *ns;
};

struct pid_namespace___18 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___21 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___18 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___21 *proc_self;
	struct dentry___21 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___3 *user_ns;
	struct ucounts___2 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common ns;
};

struct pid___18 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___18 numbers[1];
};

struct vm_operations_struct___19;

struct vm_area_struct___20 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___20 *vm_next;
	struct vm_area_struct___20 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___20 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___19 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___20 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___19;

struct mm_struct___20 {
	struct {
		struct vm_area_struct___20 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___20 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___20 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___19 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___21 *owner;
		struct user_namespace___3 *user_ns;
		struct file___20 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___19 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct arch_uprobe {
	union {
		u8 insn[4];
		u8 ixol[4];
	};
	struct arch_probe_insn api;
	bool simulate;
};

enum rp_check {
	RP_CHECK_CALL = 0,
	RP_CHECK_CHAIN_CALL = 1,
	RP_CHECK_RET = 2,
};

typedef int (*dev_page_fault_t___19)(struct vm_area_struct___20 *, long unsigned int, const struct page___20 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___19)(struct page___20 *, void *);

struct dev_pagemap___19 {
	dev_page_fault_t___19 page_fault;
	dev_page_free_t___19 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___6 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct fown_struct___18 {
	rwlock_t lock;
	struct pid___18 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___20 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___19 f_path;
	struct inode___22 *f_inode;
	const struct file_operations___20 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___18 f_owner;
	const struct cred___19 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___19 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___19;

struct vm_operations_struct___19 {
	void (*open)(struct vm_area_struct___20 *);
	void (*close)(struct vm_area_struct___20 *);
	int (*split)(struct vm_area_struct___20 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___20 *);
	vm_fault_t (*fault)(struct vm_fault___19 *);
	vm_fault_t (*huge_fault)(struct vm_fault___19 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___19 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___20 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___19 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___19 *);
	int (*access)(struct vm_area_struct___20 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___20 *);
	int (*set_policy)(struct vm_area_struct___20 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___20 *, long unsigned int);
	struct page___20 * (*find_special_page)(struct vm_area_struct___20 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___19 {
	struct task_struct___21 *task;
	struct core_thread___19 *next;
};

struct core_state___19 {
	atomic_t nr_threads;
	struct core_thread___19 dumper;
	struct completion startup;
};

struct vm_fault___19 {
	struct vm_area_struct___20 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___20 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___20 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___19 prealloc_pte;
};

struct key___20;

struct user_struct___19 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___20 *uid_keyring;
	struct key___20 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___19 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___20 *session_keyring;
	struct key___20 *process_keyring;
	struct key___20 *thread_keyring;
	struct key___20 *request_key_auth;
	void *security;
	struct user_struct___19 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct nsproxy___19 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___18 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct signal_struct___18 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___21 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___21 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___18 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___18 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___20 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___18 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

union thread_union___18 {
	struct task_struct___21 task;
	long unsigned int stack[8192];
};

struct kiocb___20 {
	struct file___20 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___20 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___20 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___20 *ia_file;
};

struct dquot___19 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___20 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___19 {
	int qf_fmt_id;
	const struct quota_format_ops___19 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___19 *qf_next;
};

struct quota_format_ops___19 {
	int (*check_quota_file)(struct super_block___20 *, int);
	int (*read_file_info)(struct super_block___20 *, int);
	int (*write_file_info)(struct super_block___20 *, int);
	int (*free_file_info)(struct super_block___20 *, int);
	int (*read_dqblk)(struct dquot___19 *);
	int (*commit_dqblk)(struct dquot___19 *);
	int (*release_dqblk)(struct dquot___19 *);
	int (*get_next_id)(struct super_block___20 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___19 {
	int (*write_dquot)(struct dquot___19 *);
	struct dquot___19 * (*alloc_dquot)(struct super_block___20 *, int);
	void (*destroy_dquot)(struct dquot___19 *);
	int (*acquire_dquot)(struct dquot___19 *);
	int (*release_dquot)(struct dquot___19 *);
	int (*mark_dirty)(struct dquot___19 *);
	int (*write_info)(struct super_block___20 *, int);
	qsize_t * (*get_reserved_space)(struct inode___22 *);
	int (*get_projid)(struct inode___22 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___22 *, qsize_t *);
	int (*get_next_id)(struct super_block___20 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___19 {
	int (*quota_on)(struct super_block___20 *, int, int, const struct path___19 *);
	int (*quota_off)(struct super_block___20 *, int);
	int (*quota_enable)(struct super_block___20 *, unsigned int);
	int (*quota_disable)(struct super_block___20 *, unsigned int);
	int (*quota_sync)(struct super_block___20 *, int);
	int (*set_info)(struct super_block___20 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___20 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___20 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___20 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___20 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___20 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___19 {
	int (*writepage)(struct page___20 *, struct writeback_control___3 *);
	int (*readpage)(struct file___20 *, struct page___20 *);
	int (*writepages)(struct address_space___19 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___20 *);
	int (*readpages)(struct file___20 *, struct address_space___19 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___20 *, struct address_space___19 *, loff_t, unsigned int, unsigned int, struct page___20 **, void **);
	int (*write_end)(struct file___20 *, struct address_space___19 *, loff_t, unsigned int, unsigned int, struct page___20 *, void *);
	sector_t (*bmap)(struct address_space___19 *, sector_t);
	void (*invalidatepage)(struct page___20 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___20 *, gfp_t);
	void (*freepage)(struct page___20 *);
	ssize_t (*direct_IO)(struct kiocb___20 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___19 *, struct page___20 *, struct page___20 *, enum migrate_mode);
	bool (*isolate_page)(struct page___20 *, isolate_mode_t);
	void (*putback_page)(struct page___20 *);
	int (*launder_page)(struct page___20 *);
	int (*is_partially_uptodate)(struct page___20 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___20 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___19 *, struct page___20 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___20 *, sector_t *);
	void (*swap_deactivate)(struct file___20 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___20 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___22 *bd_inode;
	struct super_block___20 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___20 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___19 {
	struct dentry___21 * (*lookup)(struct inode___22 *, struct dentry___21 *, unsigned int);
	const char * (*get_link)(struct dentry___21 *, struct inode___22 *, struct delayed_call *);
	int (*permission)(struct inode___22 *, int);
	struct posix_acl * (*get_acl)(struct inode___22 *, int);
	int (*readlink)(struct dentry___21 *, char *, int);
	int (*create)(struct inode___22 *, struct dentry___21 *, umode_t, bool);
	int (*link)(struct dentry___21 *, struct inode___22 *, struct dentry___21 *);
	int (*unlink)(struct inode___22 *, struct dentry___21 *);
	int (*symlink)(struct inode___22 *, struct dentry___21 *, const char *);
	int (*mkdir)(struct inode___22 *, struct dentry___21 *, umode_t);
	int (*rmdir)(struct inode___22 *, struct dentry___21 *);
	int (*mknod)(struct inode___22 *, struct dentry___21 *, umode_t, dev_t);
	int (*rename)(struct inode___22 *, struct dentry___21 *, struct inode___22 *, struct dentry___21 *, unsigned int);
	int (*setattr)(struct dentry___21 *, struct iattr___20 *);
	int (*getattr)(const struct path___19 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___21 *, char *, size_t);
	int (*fiemap)(struct inode___22 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___22 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___22 *, struct dentry___21 *, struct file___20 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___22 *, struct dentry___21 *, umode_t);
	int (*set_acl)(struct inode___22 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___19 {
	void (*fl_copy_lock)(struct file_lock___20 *, struct file_lock___20 *);
	void (*fl_release_private)(struct file_lock___20 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___19;

struct lock_manager_operations___19;

struct file_lock___20 {
	struct file_lock___20 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___20 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___19 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___19 *fl_ops;
	const struct lock_manager_operations___19 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___19 {
	int (*lm_compare_owner)(struct file_lock___20 *, struct file_lock___20 *);
	long unsigned int (*lm_owner_key)(struct file_lock___20 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___20 *);
	int (*lm_grant)(struct file_lock___20 *, int);
	bool (*lm_break)(struct file_lock___20 *);
	int (*lm_change)(struct file_lock___20 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___20 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___19 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___19 *fa_next;
	struct file___20 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___19 {
	const char *name;
	int fs_flags;
	struct dentry___21 * (*mount)(struct file_system_type___19 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___20 *);
	struct module___11 *owner;
	struct file_system_type___19 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___19 {
	struct inode___22 * (*alloc_inode)(struct super_block___20 *);
	void (*destroy_inode)(struct inode___22 *);
	void (*dirty_inode)(struct inode___22 *, int);
	int (*write_inode)(struct inode___22 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___22 *);
	void (*evict_inode)(struct inode___22 *);
	void (*put_super)(struct super_block___20 *);
	int (*sync_fs)(struct super_block___20 *, int);
	int (*freeze_super)(struct super_block___20 *);
	int (*freeze_fs)(struct super_block___20 *);
	int (*thaw_super)(struct super_block___20 *);
	int (*unfreeze_fs)(struct super_block___20 *);
	int (*statfs)(struct dentry___21 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___20 *, int *, char *);
	void (*umount_begin)(struct super_block___20 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___21 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___21 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___21 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___21 *);
	ssize_t (*quota_read)(struct super_block___20 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___20 *, int, const char *, size_t, loff_t);
	struct dquot___19 ** (*get_dquots)(struct inode___22 *);
	int (*bdev_try_to_free_page)(struct super_block___20 *, struct page___20 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___20 *, struct shrink_control___5 *);
	long int (*free_cached_objects)(struct super_block___20 *, struct shrink_control___5 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___19(struct page___20 *);

typedef int (*key_restrict_link_func_t___19)(struct key___20 *, const struct key_type *, const union key_payload *, struct key___20 *);

struct key_restriction___20;

struct key___20 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___20 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___20 *restrict_link;
};

struct key_restriction___20 {
	key_restrict_link_func_t___19 check;
	struct key___20 *key;
	struct key_type *keytype;
};

struct iommu_fwspec {
	const struct iommu_ops *ops;
	struct fwnode_handle___12 *iommu_fwnode;
	void *iommu_priv;
	unsigned int num_ids;
	u32 ids[1];
};

struct of_phandle_args {
	struct device_node___5 *np;
	int args_count;
	uint32_t args[16];
};

typedef int (*iommu_fault_handler_t)(struct iommu_domain *, struct device___2 *, long unsigned int, int, void *);

struct iommu_domain_geometry {
	dma_addr_t aperture_start;
	dma_addr_t aperture_end;
	bool force_aperture;
};

struct iommu_domain {
	unsigned int type;
	const struct iommu_ops *ops;
	long unsigned int pgsize_bitmap;
	iommu_fault_handler_t handler;
	void *handler_token;
	struct iommu_domain_geometry geometry;
	void *iova_cookie;
};

enum iommu_resv_type {
	IOMMU_RESV_DIRECT = 0,
	IOMMU_RESV_RESERVED = 1,
	IOMMU_RESV_MSI = 2,
	IOMMU_RESV_SW_MSI = 3,
};

struct iommu_resv_region {
	struct list_head list;
	phys_addr_t start;
	size_t length;
	int prot;
	enum iommu_resv_type type;
};

enum swiotlb_force {
	SWIOTLB_NORMAL = 0,
	SWIOTLB_FORCE = 1,
	SWIOTLB_NO_FORCE = 2,
};

struct module___20;

struct file___21;

struct kiocb___21;

struct poll_table_struct___13;

struct vm_area_struct___21;

struct inode___23;

struct file_lock___21;

struct page___21;

struct seq_file___19;

struct file_operations___21 {
	struct module___20 *owner;
	loff_t (*llseek)(struct file___21 *, loff_t, int);
	ssize_t (*read)(struct file___21 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___21 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___21 *, struct iov_iter___7 *);
	ssize_t (*write_iter)(struct kiocb___21 *, struct iov_iter___7 *);
	int (*iopoll)(struct kiocb___21 *, bool);
	int (*iterate)(struct file___21 *, struct dir_context *);
	int (*iterate_shared)(struct file___21 *, struct dir_context *);
	__poll_t (*poll)(struct file___21 *, struct poll_table_struct___13 *);
	long int (*unlocked_ioctl)(struct file___21 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___21 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___21 *, struct vm_area_struct___21 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___23 *, struct file___21 *);
	int (*flush)(struct file___21 *, fl_owner_t);
	int (*release)(struct inode___23 *, struct file___21 *);
	int (*fsync)(struct file___21 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___21 *, int);
	int (*lock)(struct file___21 *, int, struct file_lock___21 *);
	ssize_t (*sendpage)(struct file___21 *, struct page___21 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___21 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___21 *, int, struct file_lock___21 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___21 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___21 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___21 *, long int, struct file_lock___21 **, void **);
	long int (*fallocate)(struct file___21 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___19 *, struct file___21 *);
	ssize_t (*copy_file_range)(struct file___21 *, loff_t, struct file___21 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___21 *, loff_t, struct file___21 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___21 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct key___21;

struct user_struct___20 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___21 *uid_keyring;
	struct key___21 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vmacache___20 {
	u64 seqnum;
	struct vm_area_struct___21 *vmas[4];
};

struct page_frag___20 {
	struct page___21 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___11;

struct debug_info___11 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___11 *hbp_break[16];
	struct perf_event___11 *hbp_watch[16];
};

struct thread_struct___11 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___11 debug;
	long: 64;
};

struct mm_struct___21;

struct pid___19;

struct cred___20;

struct nsproxy___20;

struct signal_struct___19;

struct css_set___11;

struct perf_event_context___11;

struct vm_struct___16;

struct task_struct___22 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___22 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___21 *mm;
	struct mm_struct___21 *active_mm;
	struct vmacache___20 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___22 *real_parent;
	struct task_struct___22 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___22 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___19 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___19 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___19 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___20 *ptracer_cred;
	const struct cred___20 *real_cred;
	const struct cred___20 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___20 *nsproxy;
	struct signal_struct___19 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___22 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___2 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___11 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___11 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___20 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___22 *oom_reaper_list;
	struct vm_struct___16 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___11 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___11 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___22 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___11)(struct perf_event___11 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___11;

struct fasync_struct___20;

struct pid_namespace___19;

struct perf_cgroup___11;

struct perf_event___11 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___11 *group_leader;
	struct pmu___11 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___11 hw;
	struct perf_event_context___11 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___11 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___22 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___20 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___11 *);
	struct callback_head callback_head;
	struct pid_namespace___19 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___11 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___11 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___5 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___11 *cgrp;
	struct list_head sb_list;
};

typedef struct page___21 *pgtable_t___20;

struct address_space___20;

struct dev_pagemap___20;

struct page___21 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___20 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___21 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___20 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___21 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___20 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___20;

struct lruvec___20 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___20 *pgdat;
};

struct zone___20 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___20 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___20 {
	struct zone___20 *zone;
	int zone_idx;
};

struct zonelist___20 {
	struct zoneref___20 _zonerefs[25];
};

struct pglist_data___20 {
	struct zone___20 node_zones[3];
	struct zonelist___20 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___22 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___22 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___20 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___21 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___22 *owner;
};

struct secondary_data___21 {
	void *stack;
	struct task_struct___22 *task;
	long int status;
};

struct blocking_notifier_head___20 {
	struct rw_semaphore___21 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___20;

struct vm_area_struct___21 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___21 *vm_next;
	struct vm_area_struct___21 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___21 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___20 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___21 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___20;

struct user_namespace___12;

struct mm_struct___21 {
	struct {
		struct vm_area_struct___21 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___21 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___21 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___20 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___22 *owner;
		struct user_namespace___12 *user_ns;
		struct file___21 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___20 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___20;

struct address_space___20 {
	struct inode___23 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___21 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___20 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___20)(struct vm_area_struct___21 *, long unsigned int, const struct page___21 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___20)(struct page___21 *, void *);

struct device___17;

struct dev_pagemap___20 {
	dev_page_fault_t___20 page_fault;
	dev_page_free_t___20 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___17 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct dentry___22;

struct path___20 {
	struct vfsmount *mnt;
	struct dentry___22 *dentry;
};

struct fown_struct___19 {
	rwlock_t lock;
	struct pid___19 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___21 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___20 f_path;
	struct inode___23 *f_inode;
	const struct file_operations___21 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___19 f_owner;
	const struct cred___20 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___20 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___20;

struct vm_operations_struct___20 {
	void (*open)(struct vm_area_struct___21 *);
	void (*close)(struct vm_area_struct___21 *);
	int (*split)(struct vm_area_struct___21 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___21 *);
	vm_fault_t (*fault)(struct vm_fault___20 *);
	vm_fault_t (*huge_fault)(struct vm_fault___20 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___20 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___21 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___20 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___20 *);
	int (*access)(struct vm_area_struct___21 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___21 *);
	int (*set_policy)(struct vm_area_struct___21 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___21 *, long unsigned int);
	struct page___21 * (*find_special_page)(struct vm_area_struct___21 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___20 {
	struct task_struct___22 *task;
	struct core_thread___20 *next;
};

struct core_state___20 {
	atomic_t nr_threads;
	struct core_thread___20 dumper;
	struct completion startup;
};

struct ucounts___12;

struct user_namespace___12 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___12 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common ns;
	long unsigned int flags;
	struct key___21 *persistent_keyring_register;
	struct rw_semaphore___21 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___12 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___20 {
	struct vm_area_struct___21 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___21 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___21 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___20 prealloc_pte;
};

struct upid___19 {
	int nr;
	struct pid_namespace___19 *ns;
};

struct pid_namespace___19 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___22 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___19 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___22 *proc_self;
	struct dentry___22 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___12 *user_ns;
	struct ucounts___12 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common ns;
};

struct pid___19 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___19 numbers[1];
};

struct cred___20 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___21 *session_keyring;
	struct key___21 *process_keyring;
	struct key___21 *thread_keyring;
	struct key___21 *request_key_auth;
	void *security;
	struct user_struct___20 *user;
	struct user_namespace___12 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___11;

struct nsproxy___20 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___19 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___11 *cgroup_ns;
};

struct signal_struct___19 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___22 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___22 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___19 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___19 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___21 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___19 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___11;

struct cgroup___11;

struct css_set___11 {
	struct cgroup_subsys_state___11 *subsys[13];
	refcount_t refcount;
	struct css_set___11 *dom_cset;
	struct cgroup___11 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___11 *mg_src_cgrp;
	struct cgroup___11 *mg_dst_cgrp;
	struct css_set___11 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___11 {
	struct pmu___11 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___22 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___11 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___16 {
	struct vm_struct___16 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___21 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___19 {
	struct task_struct___22 task;
	long unsigned int stack[8192];
};

struct kset___19;

struct kobj_type___19;

struct kernfs_node___19;

struct kobject___20 {
	const char *name;
	struct list_head entry;
	struct kobject___20 *parent;
	struct kset___19 *kset;
	struct kobj_type___19 *ktype;
	struct kernfs_node___19 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___17 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___17 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___17;

struct bus_type___17;

struct device_driver___17;

struct dev_pm_domain___17;

struct fwnode_handle___14;

struct class___17;

struct attribute_group___17;

struct device___17 {
	struct device___17 *parent;
	struct device_private *p;
	struct kobject___20 kobj;
	const char *init_name;
	const struct device_type___17 *type;
	struct mutex mutex;
	struct bus_type___17 *bus;
	struct device_driver___17 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___17 power;
	struct dev_pm_domain___17 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___14 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___17 *class;
	const struct attribute_group___17 **groups;
	void (*release)(struct device___17 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___20;

struct super_block___21;

struct dentry___22 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___22 *d_parent;
	struct qstr d_name;
	struct inode___23 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___20 *d_op;
	struct super_block___21 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___20;

struct block_device___21;

struct cdev___7;

struct inode___23 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___20 *i_op;
	struct super_block___21 *i_sb;
	struct address_space___20 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___21 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___21 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___20 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___21 *i_bdev;
		struct cdev___7 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___20 {
	int (*d_revalidate)(struct dentry___22 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___22 *, unsigned int);
	int (*d_hash)(const struct dentry___22 *, struct qstr *);
	int (*d_compare)(const struct dentry___22 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___22 *);
	int (*d_init)(struct dentry___22 *);
	void (*d_release)(struct dentry___22 *);
	void (*d_prune)(struct dentry___22 *);
	void (*d_iput)(struct dentry___22 *, struct inode___23 *);
	char * (*d_dname)(struct dentry___22 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___20 *);
	int (*d_manage)(const struct path___20 *, bool);
	struct dentry___22 * (*d_real)(struct dentry___22 *, const struct inode___23 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___20;

struct mem_dqinfo___20 {
	struct quota_format_type___20 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___20;

struct quota_info___20 {
	unsigned int flags;
	struct rw_semaphore___21 dqio_sem;
	struct inode___23 *files[3];
	struct mem_dqinfo___20 info[3];
	const struct quota_format_ops___20 *ops[3];
};

struct rcuwait___20 {
	struct task_struct___22 *task;
};

struct percpu_rw_semaphore___20 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___21 rw_sem;
	struct rcuwait___20 writer;
	int readers_block;
};

struct sb_writers___20 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___20 rw_sem[3];
};

struct file_system_type___20;

struct super_operations___20;

struct dquot_operations___20;

struct quotactl_ops___20;

struct super_block___21 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___20 *s_type;
	const struct super_operations___20 *s_op;
	const struct dquot_operations___20 *dq_op;
	const struct quotactl_ops___20 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___22 *s_root;
	struct rw_semaphore___21 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___21 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___20 s_dquot;
	struct sb_writers___20 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___20 *s_d_op;
	int cleancache_poolid;
	struct shrinker___5 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___12 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___21 {
	struct file___21 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___21 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___21 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___21 *ia_file;
};

struct dquot___20 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___21 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___20 {
	int qf_fmt_id;
	const struct quota_format_ops___20 *qf_ops;
	struct module___20 *qf_owner;
	struct quota_format_type___20 *qf_next;
};

struct quota_format_ops___20 {
	int (*check_quota_file)(struct super_block___21 *, int);
	int (*read_file_info)(struct super_block___21 *, int);
	int (*write_file_info)(struct super_block___21 *, int);
	int (*free_file_info)(struct super_block___21 *, int);
	int (*read_dqblk)(struct dquot___20 *);
	int (*commit_dqblk)(struct dquot___20 *);
	int (*release_dqblk)(struct dquot___20 *);
	int (*get_next_id)(struct super_block___21 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___20 {
	int (*write_dquot)(struct dquot___20 *);
	struct dquot___20 * (*alloc_dquot)(struct super_block___21 *, int);
	void (*destroy_dquot)(struct dquot___20 *);
	int (*acquire_dquot)(struct dquot___20 *);
	int (*release_dquot)(struct dquot___20 *);
	int (*mark_dirty)(struct dquot___20 *);
	int (*write_info)(struct super_block___21 *, int);
	qsize_t * (*get_reserved_space)(struct inode___23 *);
	int (*get_projid)(struct inode___23 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___23 *, qsize_t *);
	int (*get_next_id)(struct super_block___21 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___20 {
	int (*quota_on)(struct super_block___21 *, int, int, const struct path___20 *);
	int (*quota_off)(struct super_block___21 *, int);
	int (*quota_enable)(struct super_block___21 *, unsigned int);
	int (*quota_disable)(struct super_block___21 *, unsigned int);
	int (*quota_sync)(struct super_block___21 *, int);
	int (*set_info)(struct super_block___21 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___21 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___21 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___21 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___21 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___21 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___17 {
	struct kobject___20 kobj;
	struct module___20 *mod;
	struct kobject___20 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___17 {
	struct module___20 *mod;
	struct latch_tree_node node;
};

struct module_layout___17 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___17 mtn;
};

struct module_attribute___17;

struct kernel_param___17;

struct module___20 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___17 mkobj;
	struct module_attribute___17 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___20 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___17 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___17 core_layout;
	struct module_layout___17 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___20 {
	int (*writepage)(struct page___21 *, struct writeback_control___3 *);
	int (*readpage)(struct file___21 *, struct page___21 *);
	int (*writepages)(struct address_space___20 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___21 *);
	int (*readpages)(struct file___21 *, struct address_space___20 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___21 *, struct address_space___20 *, loff_t, unsigned int, unsigned int, struct page___21 **, void **);
	int (*write_end)(struct file___21 *, struct address_space___20 *, loff_t, unsigned int, unsigned int, struct page___21 *, void *);
	sector_t (*bmap)(struct address_space___20 *, sector_t);
	void (*invalidatepage)(struct page___21 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___21 *, gfp_t);
	void (*freepage)(struct page___21 *);
	ssize_t (*direct_IO)(struct kiocb___21 *, struct iov_iter___7 *);
	int (*migratepage)(struct address_space___20 *, struct page___21 *, struct page___21 *, enum migrate_mode);
	bool (*isolate_page)(struct page___21 *, isolate_mode_t);
	void (*putback_page)(struct page___21 *);
	int (*launder_page)(struct page___21 *);
	int (*is_partially_uptodate)(struct page___21 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___21 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___20 *, struct page___21 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___21 *, sector_t *);
	void (*swap_deactivate)(struct file___21 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___21 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___23 *bd_inode;
	struct super_block___21 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___21 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___7 {
	struct kobject___20 kobj;
	struct module___20 *owner;
	const struct file_operations___21 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___20 {
	struct dentry___22 * (*lookup)(struct inode___23 *, struct dentry___22 *, unsigned int);
	const char * (*get_link)(struct dentry___22 *, struct inode___23 *, struct delayed_call *);
	int (*permission)(struct inode___23 *, int);
	struct posix_acl * (*get_acl)(struct inode___23 *, int);
	int (*readlink)(struct dentry___22 *, char *, int);
	int (*create)(struct inode___23 *, struct dentry___22 *, umode_t, bool);
	int (*link)(struct dentry___22 *, struct inode___23 *, struct dentry___22 *);
	int (*unlink)(struct inode___23 *, struct dentry___22 *);
	int (*symlink)(struct inode___23 *, struct dentry___22 *, const char *);
	int (*mkdir)(struct inode___23 *, struct dentry___22 *, umode_t);
	int (*rmdir)(struct inode___23 *, struct dentry___22 *);
	int (*mknod)(struct inode___23 *, struct dentry___22 *, umode_t, dev_t);
	int (*rename)(struct inode___23 *, struct dentry___22 *, struct inode___23 *, struct dentry___22 *, unsigned int);
	int (*setattr)(struct dentry___22 *, struct iattr___21 *);
	int (*getattr)(const struct path___20 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___22 *, char *, size_t);
	int (*fiemap)(struct inode___23 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___23 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___23 *, struct dentry___22 *, struct file___21 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___23 *, struct dentry___22 *, umode_t);
	int (*set_acl)(struct inode___23 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___20 {
	void (*fl_copy_lock)(struct file_lock___21 *, struct file_lock___21 *);
	void (*fl_release_private)(struct file_lock___21 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___20;

struct file_lock___21 {
	struct file_lock___21 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___21 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___20 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___20 *fl_ops;
	const struct lock_manager_operations___20 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___20 {
	int (*lm_compare_owner)(struct file_lock___21 *, struct file_lock___21 *);
	long unsigned int (*lm_owner_key)(struct file_lock___21 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___21 *);
	int (*lm_grant)(struct file_lock___21 *, int);
	bool (*lm_break)(struct file_lock___21 *);
	int (*lm_change)(struct file_lock___21 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___21 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___20 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___20 *fa_next;
	struct file___21 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___20 {
	const char *name;
	int fs_flags;
	struct dentry___22 * (*mount)(struct file_system_type___20 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___21 *);
	struct module___20 *owner;
	struct file_system_type___20 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___20 {
	struct inode___23 * (*alloc_inode)(struct super_block___21 *);
	void (*destroy_inode)(struct inode___23 *);
	void (*dirty_inode)(struct inode___23 *, int);
	int (*write_inode)(struct inode___23 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___23 *);
	void (*evict_inode)(struct inode___23 *);
	void (*put_super)(struct super_block___21 *);
	int (*sync_fs)(struct super_block___21 *, int);
	int (*freeze_super)(struct super_block___21 *);
	int (*freeze_fs)(struct super_block___21 *);
	int (*thaw_super)(struct super_block___21 *);
	int (*unfreeze_fs)(struct super_block___21 *);
	int (*statfs)(struct dentry___22 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___21 *, int *, char *);
	void (*umount_begin)(struct super_block___21 *);
	int (*show_options)(struct seq_file___19 *, struct dentry___22 *);
	int (*show_devname)(struct seq_file___19 *, struct dentry___22 *);
	int (*show_path)(struct seq_file___19 *, struct dentry___22 *);
	int (*show_stats)(struct seq_file___19 *, struct dentry___22 *);
	ssize_t (*quota_read)(struct super_block___21 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___21 *, int, const char *, size_t, loff_t);
	struct dquot___20 ** (*get_dquots)(struct inode___23 *);
	int (*bdev_try_to_free_page)(struct super_block___21 *, struct page___21 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___21 *, struct shrink_control___5 *);
	long int (*free_cached_objects)(struct super_block___21 *, struct shrink_control___5 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___12)(struct file___21 *, wait_queue_head_t *, struct poll_table_struct___13 *);

struct poll_table_struct___13 {
	poll_queue_proc___12 _qproc;
	__poll_t _key;
};

struct seq_operations___16;

struct seq_file___19 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___16 *op;
	int poll_event;
	const struct file___21 *file;
	void *private;
};

struct kobj_attribute___20 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___20 *, struct kobj_attribute___20 *, char *);
	ssize_t (*store)(struct kobject___20 *, struct kobj_attribute___20 *, const char *, size_t);
};

typedef void compound_page_dtor___20(struct page___21 *);

struct kernfs_root___19;

struct kernfs_elem_dir___19 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___19 *root;
};

struct kernfs_syscall_ops___19;

struct kernfs_root___19 {
	struct kernfs_node___19 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___19 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___19 {
	struct kernfs_node___19 *target_kn;
};

struct kernfs_ops___19;

struct kernfs_elem_attr___19 {
	const struct kernfs_ops___19 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___19 *notify_next;
};

struct kernfs_node___19 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___19 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___19 dir;
		struct kernfs_elem_symlink___19 symlink;
		struct kernfs_elem_attr___19 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___19;

struct kernfs_ops___19 {
	int (*open)(struct kernfs_open_file___19 *);
	void (*release)(struct kernfs_open_file___19 *);
	int (*seq_show)(struct seq_file___19 *, void *);
	void * (*seq_start)(struct seq_file___19 *, loff_t *);
	void * (*seq_next)(struct seq_file___19 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___19 *, void *);
	ssize_t (*read)(struct kernfs_open_file___19 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___19 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___19 *, struct vm_area_struct___21 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___19 *, struct poll_table_struct___13 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___19 {
	int (*remount_fs)(struct kernfs_root___19 *, int *, char *);
	int (*show_options)(struct seq_file___19 *, struct kernfs_root___19 *);
	int (*mkdir)(struct kernfs_node___19 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___19 *);
	int (*rename)(struct kernfs_node___19 *, struct kernfs_node___19 *, const char *);
	int (*show_path)(struct seq_file___19 *, struct kernfs_node___19 *, struct kernfs_root___19 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___19 {
	struct kernfs_node___19 *kn;
	struct file___21 *file;
	struct seq_file___19 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___20 *vm_ops;
};

struct bin_attribute___17;

struct attribute_group___17 {
	const char *name;
	umode_t (*is_visible)(struct kobject___20 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___20 *, struct bin_attribute___17 *, int);
	struct attribute **attrs;
	struct bin_attribute___17 **bin_attrs;
};

struct bin_attribute___17 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___21 *, struct kobject___20 *, struct bin_attribute___17 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___21 *, struct kobject___20 *, struct bin_attribute___17 *, char *, loff_t, size_t);
	int (*mmap)(struct file___21 *, struct kobject___20 *, struct bin_attribute___17 *, struct vm_area_struct___21 *);
};

struct sysfs_ops___19 {
	ssize_t (*show)(struct kobject___20 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___20 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___19;

struct kset___19 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___20 kobj;
	const struct kset_uevent_ops___19 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___19 {
	void (*release)(struct kobject___20 *);
	const struct sysfs_ops___19 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___20 *);
	const void * (*namespace)(struct kobject___20 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___19 {
	int (* const filter)(struct kset___19 *, struct kobject___20 *);
	const char * (* const name)(struct kset___19 *, struct kobject___20 *);
	int (* const uevent)(struct kset___19 *, struct kobject___20 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___17 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___17 *);
	int (*get)(char *, const struct kernel_param___17 *);
	void (*free)(void *);
};

struct kparam_array___17;

struct kernel_param___17 {
	const char *name;
	struct module___20 *mod;
	const struct kernel_param_ops___17 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___17 *arr;
	};
};

struct kparam_array___17 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___17 *ops;
	void *elem;
};

struct module_attribute___17 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___17 *, struct module_kobject___17 *, char *);
	ssize_t (*store)(struct module_attribute___17 *, struct module_kobject___17 *, const char *, size_t);
	void (*setup)(struct module___20 *, const char *);
	int (*test)(struct module___20 *);
	void (*free)(struct module___20 *);
};

typedef int (*key_restrict_link_func_t___20)(struct key___21 *, const struct key_type *, const union key_payload *, struct key___21 *);

struct key_restriction___21;

struct key___21 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___21 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___21 *restrict_link;
};

struct key_restriction___21 {
	key_restrict_link_func_t___20 check;
	struct key___21 *key;
	struct key_type *keytype;
};

struct cgroup_namespace___11 {
	refcount_t count;
	struct ns_common ns;
	struct user_namespace___12 *user_ns;
	struct ucounts___12 *ucounts;
	struct css_set___11 *root_cset;
};

struct ucounts___12 {
	struct hlist_node node;
	struct user_namespace___12 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct dev_pm_ops___17 {
	int (*prepare)(struct device___17 *);
	void (*complete)(struct device___17 *);
	int (*suspend)(struct device___17 *);
	int (*resume)(struct device___17 *);
	int (*freeze)(struct device___17 *);
	int (*thaw)(struct device___17 *);
	int (*poweroff)(struct device___17 *);
	int (*restore)(struct device___17 *);
	int (*suspend_late)(struct device___17 *);
	int (*resume_early)(struct device___17 *);
	int (*freeze_late)(struct device___17 *);
	int (*thaw_early)(struct device___17 *);
	int (*poweroff_late)(struct device___17 *);
	int (*restore_early)(struct device___17 *);
	int (*suspend_noirq)(struct device___17 *);
	int (*resume_noirq)(struct device___17 *);
	int (*freeze_noirq)(struct device___17 *);
	int (*thaw_noirq)(struct device___17 *);
	int (*poweroff_noirq)(struct device___17 *);
	int (*restore_noirq)(struct device___17 *);
	int (*runtime_suspend)(struct device___17 *);
	int (*runtime_resume)(struct device___17 *);
	int (*runtime_idle)(struct device___17 *);
};

struct dev_pm_domain___17 {
	struct dev_pm_ops___17 ops;
	void (*detach)(struct device___17 *, bool);
	int (*activate)(struct device___17 *);
	void (*sync)(struct device___17 *);
	void (*dismiss)(struct device___17 *);
};

struct bus_type___17 {
	const char *name;
	const char *dev_name;
	struct device___17 *dev_root;
	const struct attribute_group___17 **bus_groups;
	const struct attribute_group___17 **dev_groups;
	const struct attribute_group___17 **drv_groups;
	int (*match)(struct device___17 *, struct device_driver___17 *);
	int (*uevent)(struct device___17 *, struct kobj_uevent_env *);
	int (*probe)(struct device___17 *);
	int (*remove)(struct device___17 *);
	void (*shutdown)(struct device___17 *);
	int (*online)(struct device___17 *);
	int (*offline)(struct device___17 *);
	int (*suspend)(struct device___17 *, pm_message_t);
	int (*resume)(struct device___17 *);
	int (*num_vf)(struct device___17 *);
	int (*dma_configure)(struct device___17 *);
	const struct dev_pm_ops___17 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___17 {
	const char *name;
	struct bus_type___17 *bus;
	struct module___20 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___17 *);
	int (*remove)(struct device___17 *);
	void (*shutdown)(struct device___17 *);
	int (*suspend)(struct device___17 *, pm_message_t);
	int (*resume)(struct device___17 *);
	const struct attribute_group___17 **groups;
	const struct dev_pm_ops___17 *pm;
	void (*coredump)(struct device___17 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___17 {
	const char *name;
	const struct attribute_group___17 **groups;
	int (*uevent)(struct device___17 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___17 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___17 *);
	const struct dev_pm_ops___17 *pm;
};

struct class___17 {
	const char *name;
	struct module___20 *owner;
	const struct attribute_group___17 **class_groups;
	const struct attribute_group___17 **dev_groups;
	struct kobject___20 *dev_kobj;
	int (*dev_uevent)(struct device___17 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___17 *, umode_t *);
	void (*class_release)(struct class___17 *);
	void (*dev_release)(struct device___17 *);
	int (*shutdown_pre)(struct device___17 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___17 *);
	const struct dev_pm_ops___17 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct fwnode_operations___14;

struct fwnode_handle___14 {
	struct fwnode_handle___14 *secondary;
	const struct fwnode_operations___14 *ops;
};

struct node___16 {
	struct device___17 dev;
};

struct seq_operations___16 {
	void * (*start)(struct seq_file___19 *, loff_t *);
	void (*stop)(struct seq_file___19 *, void *);
	void * (*next)(struct seq_file___19 *, void *, loff_t *);
	int (*show)(struct seq_file___19 *, void *);
};

struct bpf_map___11;

struct bpf_map_ops___11 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___11 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___11 *, struct file___21 *);
	void (*map_free)(struct bpf_map___11 *);
	int (*map_get_next_key)(struct bpf_map___11 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___11 *);
	void * (*map_lookup_elem)(struct bpf_map___11 *, void *);
	int (*map_update_elem)(struct bpf_map___11 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___11 *, void *);
	int (*map_push_elem)(struct bpf_map___11 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___11 *, void *);
	int (*map_peek_elem)(struct bpf_map___11 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___11 *, struct file___21 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___11 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___11 *, void *, struct seq_file___19 *);
	int (*map_check_btf)(const struct bpf_map___11 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___11 {
	const struct bpf_map_ops___11 *ops;
	struct bpf_map___11 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___20 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___11;

typedef void (*kthread_work_func_t___11)(struct kthread_work___11 *);

struct kthread_worker___11;

struct kthread_work___11 {
	struct list_head node;
	kthread_work_func_t___11 func;
	struct kthread_worker___11 *worker;
	int canceling;
};

struct kthread_worker___11 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___22 *task;
	struct kthread_work___11 *current_work;
};

struct kthread_delayed_work___11 {
	struct kthread_work___11 work;
	struct timer_list timer;
};

struct psi_group___11 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___11 *poll_kworker;
	struct kthread_delayed_work___11 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___11 {
	struct kernfs_node___19 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___11;

struct cgroup_subsys_state___11 {
	struct cgroup___11 *cgroup;
	struct cgroup_subsys___11 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___11 *parent;
};

struct cgroup_root___11;

struct cgroup_rstat_cpu___11;

struct cgroup___11 {
	struct cgroup_subsys_state___11 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___19 *kn;
	struct cgroup_file___11 procs_file;
	struct cgroup_file___11 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___11 *subsys[13];
	struct cgroup_root___11 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___11 *dom_cgrp;
	struct cgroup_rstat_cpu___11 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf bpf;
	atomic_t congestion_count;
	struct cgroup___11 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___11 psi;
	int ancestor_ids[0];
};

struct cftype___11;

struct cgroup_subsys___11 {
	struct cgroup_subsys_state___11 * (*css_alloc)(struct cgroup_subsys_state___11 *);
	int (*css_online)(struct cgroup_subsys_state___11 *);
	void (*css_offline)(struct cgroup_subsys_state___11 *);
	void (*css_released)(struct cgroup_subsys_state___11 *);
	void (*css_free)(struct cgroup_subsys_state___11 *);
	void (*css_reset)(struct cgroup_subsys_state___11 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___11 *, int);
	int (*css_extra_stat_show)(struct seq_file___19 *, struct cgroup_subsys_state___11 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___22 *);
	void (*cancel_fork)(struct task_struct___22 *);
	void (*fork)(struct task_struct___22 *);
	void (*exit)(struct task_struct___22 *);
	void (*free)(struct task_struct___22 *);
	void (*bind)(struct cgroup_subsys_state___11 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___11 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___11 *dfl_cftypes;
	struct cftype___11 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___11 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___11 *updated_children;
	struct cgroup___11 *updated_next;
};

struct cgroup_root___11 {
	struct kernfs_root___19 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___11 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___11 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___11 *ss;
	struct list_head node;
	struct kernfs_ops___19 *kf_ops;
	int (*open)(struct kernfs_open_file___19 *);
	void (*release)(struct kernfs_open_file___19 *);
	u64 (*read_u64)(struct cgroup_subsys_state___11 *, struct cftype___11 *);
	s64 (*read_s64)(struct cgroup_subsys_state___11 *, struct cftype___11 *);
	int (*seq_show)(struct seq_file___19 *, void *);
	void * (*seq_start)(struct seq_file___19 *, loff_t *);
	void * (*seq_next)(struct seq_file___19 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___19 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___11 *, struct cftype___11 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___11 *, struct cftype___11 *, s64);
	ssize_t (*write)(struct kernfs_open_file___19 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___19 *, struct poll_table_struct___13 *);
};

struct perf_cpu_context___11;

struct pmu___11 {
	struct list_head entry;
	struct module___20 *module;
	struct device___17 *dev;
	const struct attribute_group___17 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___11 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___11 *);
	void (*pmu_disable)(struct pmu___11 *);
	int (*event_init)(struct perf_event___11 *);
	void (*event_mapped)(struct perf_event___11 *, struct mm_struct___21 *);
	void (*event_unmapped)(struct perf_event___11 *, struct mm_struct___21 *);
	int (*add)(struct perf_event___11 *, int);
	void (*del)(struct perf_event___11 *, int);
	void (*start)(struct perf_event___11 *, int);
	void (*stop)(struct perf_event___11 *, int);
	void (*read)(struct perf_event___11 *);
	void (*start_txn)(struct pmu___11 *, unsigned int);
	int (*commit_txn)(struct pmu___11 *);
	void (*cancel_txn)(struct pmu___11 *);
	int (*event_idx)(struct perf_event___11 *);
	void (*sched_task)(struct perf_event_context___11 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___11 *);
	int (*filter_match)(struct perf_event___11 *);
	int (*check_period)(struct perf_event___11 *, u64);
};

struct perf_cpu_context___11 {
	struct perf_event_context___11 ctx;
	struct perf_event_context___11 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___11 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___11 {
	struct cgroup_subsys_state___11 css;
	struct perf_cgroup_info *info;
};

struct hstate {
	int next_nid_to_alloc;
	int next_nid_to_free;
	unsigned int order;
	long unsigned int mask;
	long unsigned int max_huge_pages;
	long unsigned int nr_huge_pages;
	long unsigned int free_huge_pages;
	long unsigned int resv_huge_pages;
	long unsigned int surplus_huge_pages;
	long unsigned int nr_overcommit_huge_pages;
	struct list_head hugepage_activelist;
	struct list_head hugepage_freelists[8];
	unsigned int nr_huge_pages_node[8];
	unsigned int free_huge_pages_node[8];
	unsigned int surplus_huge_pages_node[8];
	struct cftype___11 cgroup_files[5];
	char name[32];
};

struct fwnode_reference_args___14;

struct fwnode_endpoint___14;

struct fwnode_operations___14 {
	struct fwnode_handle___14 * (*get)(struct fwnode_handle___14 *);
	void (*put)(struct fwnode_handle___14 *);
	bool (*device_is_available)(const struct fwnode_handle___14 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___14 *, const struct device___17 *);
	bool (*property_present)(const struct fwnode_handle___14 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___14 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___14 *, const char *, const char **, size_t);
	struct fwnode_handle___14 * (*get_parent)(const struct fwnode_handle___14 *);
	struct fwnode_handle___14 * (*get_next_child_node)(const struct fwnode_handle___14 *, struct fwnode_handle___14 *);
	struct fwnode_handle___14 * (*get_named_child_node)(const struct fwnode_handle___14 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___14 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___14 *);
	struct fwnode_handle___14 * (*graph_get_next_endpoint)(const struct fwnode_handle___14 *, struct fwnode_handle___14 *);
	struct fwnode_handle___14 * (*graph_get_remote_endpoint)(const struct fwnode_handle___14 *);
	struct fwnode_handle___14 * (*graph_get_port_parent)(struct fwnode_handle___14 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___14 *, struct fwnode_endpoint___14 *);
};

struct fwnode_endpoint___14 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___14 *local_fwnode;
};

struct fwnode_reference_args___14 {
	struct fwnode_handle___14 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct fault_info {
	int (*fn)(long unsigned int, unsigned int, struct pt_regs *);
	int sig;
	int code;
	const char *name;
};

struct module___21;

struct file___22;

struct kiocb___22;

struct iov_iter___8;

struct poll_table_struct___14;

struct vm_area_struct___22;

struct inode___24;

struct file_lock___22;

struct page___22;

struct seq_file___20;

struct file_operations___22 {
	struct module___21 *owner;
	loff_t (*llseek)(struct file___22 *, loff_t, int);
	ssize_t (*read)(struct file___22 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___22 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___22 *, struct iov_iter___8 *);
	ssize_t (*write_iter)(struct kiocb___22 *, struct iov_iter___8 *);
	int (*iopoll)(struct kiocb___22 *, bool);
	int (*iterate)(struct file___22 *, struct dir_context *);
	int (*iterate_shared)(struct file___22 *, struct dir_context *);
	__poll_t (*poll)(struct file___22 *, struct poll_table_struct___14 *);
	long int (*unlocked_ioctl)(struct file___22 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___22 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___22 *, struct vm_area_struct___22 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___24 *, struct file___22 *);
	int (*flush)(struct file___22 *, fl_owner_t);
	int (*release)(struct inode___24 *, struct file___22 *);
	int (*fsync)(struct file___22 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___22 *, int);
	int (*lock)(struct file___22 *, int, struct file_lock___22 *);
	ssize_t (*sendpage)(struct file___22 *, struct page___22 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___22 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___22 *, int, struct file_lock___22 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___22 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___22 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___22 *, long int, struct file_lock___22 **, void **);
	long int (*fallocate)(struct file___22 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___20 *, struct file___22 *);
	ssize_t (*copy_file_range)(struct file___22 *, loff_t, struct file___22 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___22 *, loff_t, struct file___22 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___22 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___21 {
	u64 seqnum;
	struct vm_area_struct___22 *vmas[4];
};

struct page_frag___21 {
	struct page___22 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___22;

struct mem_cgroup___6;

struct pid___20;

struct cred___21;

struct nsproxy___21;

struct signal_struct___20;

struct bio_list___7;

struct backing_dev_info___7;

struct css_set___12;

struct vm_struct___17;

struct task_struct___23 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___23 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___22 *mm;
	struct mm_struct___22 *active_mm;
	struct vmacache___21 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___23 *real_parent;
	struct task_struct___23 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___23 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___6 *active_memcg;
	long int rh_reserved2;
	struct pid___20 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___20 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___20 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___21 *ptracer_cred;
	const struct cred___21 *real_cred;
	const struct cred___21 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___21 *nsproxy;
	struct signal_struct___20 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___23 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___7 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___7 *backing_dev_info;
	struct io_context___2 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___12 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___21 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___6 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___23 *oom_reaper_list;
	struct vm_struct___17 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___11 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___22 *pgtable_t___21;

struct address_space___21;

struct dev_pagemap___21;

struct page___22 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___21 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___22 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___21 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___22 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___21 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___6 *mem_cgroup;
};

struct pglist_data___21;

struct lruvec___21 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___21 *pgdat;
};

struct zone___21 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___21 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___21 {
	struct zone___21 *zone;
	int zone_idx;
};

struct zonelist___21 {
	struct zoneref___21 _zonerefs[25];
};

struct pglist_data___21 {
	struct zone___21 node_zones[3];
	struct zonelist___21 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___23 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___23 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___21 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___22 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___23 *owner;
};

struct secondary_data___22 {
	void *stack;
	struct task_struct___23 *task;
	long int status;
};

struct blocking_notifier_head___21 {
	struct rw_semaphore___22 rwsem;
	struct notifier_block *head;
};

struct pid_namespace___20;

struct upid___20 {
	int nr;
	struct pid_namespace___20 *ns;
};

struct dentry___23;

struct user_namespace___13;

struct ucounts___13;

struct pid_namespace___20 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___23 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___20 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___23 *proc_self;
	struct dentry___23 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___13 *user_ns;
	struct ucounts___13 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common ns;
};

struct pid___20 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___20 numbers[1];
};

struct key___22;

struct user_namespace___13 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___13 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common ns;
	long unsigned int flags;
	struct key___22 *persistent_keyring_register;
	struct rw_semaphore___22 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___13 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct user_struct___21 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___22 *uid_keyring;
	struct key___22 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___21;

struct vm_area_struct___22 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___22 *vm_next;
	struct vm_area_struct___22 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___22 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___21 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___22 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___21;

struct mm_struct___22 {
	struct {
		struct vm_area_struct___22 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___22 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___22 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___21 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___23 *owner;
		struct user_namespace___13 *user_ns;
		struct file___22 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___21 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup___12;

struct cgroup_subsys___12;

struct cgroup_subsys_state___12 {
	struct cgroup___12 *cgroup;
	struct cgroup_subsys___12 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___12 *parent;
};

struct mem_cgroup_id___6 {
	int id;
	union {
		refcount_t ref;
		struct {
			atomic_t ref;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
};

struct kernfs_node___20;

struct cgroup_file___12 {
	struct kernfs_node___20 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___6;

struct mem_cgroup___6 {
	struct cgroup_subsys_state___12 css;
	struct mem_cgroup_id___6 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___12 events_file;
	struct cgroup_file___12 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___23 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___6 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cred___21 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___22 *session_keyring;
	struct key___22 *process_keyring;
	struct key___22 *thread_keyring;
	struct key___22 *request_key_auth;
	void *security;
	struct user_struct___21 *user;
	struct user_namespace___13 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___12;

struct nsproxy___21 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___20 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___12 *cgroup_ns;
};

struct signal_struct___20 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___23 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___23 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___20 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___20 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___22 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___20 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___7;

struct bio_list___7 {
	struct bio___7 *head;
	struct bio___7 *tail;
};

struct bdi_writeback_congested___7;

struct bdi_writeback___7 {
	struct backing_dev_info___7 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___7 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___12 *memcg_css;
	struct cgroup_subsys_state___12 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___18;

struct backing_dev_info___7 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___7 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___18 *dev;
	struct device___18 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___23 *debug_dir;
	struct dentry___23 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___12 {
	struct cgroup_subsys_state___12 *subsys[13];
	refcount_t refcount;
	struct css_set___12 *dom_cset;
	struct cgroup___12 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___12 *mg_src_cgrp;
	struct cgroup___12 *mg_dst_cgrp;
	struct css_set___12 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct vm_struct___17 {
	struct vm_struct___17 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___22 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___20 {
	struct task_struct___23 task;
	long unsigned int stack[8192];
};

struct dentry_operations___21;

struct super_block___22;

struct dentry___23 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___23 *d_parent;
	struct qstr d_name;
	struct inode___24 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___21 *d_op;
	struct super_block___22 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___21;

struct address_space___21 {
	struct inode___24 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___22 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___21 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___21;

struct block_device___22;

struct cdev___8;

struct inode___24 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___21 *i_op;
	struct super_block___22 *i_sb;
	struct address_space___21 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___22 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___7 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___22 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___21 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___22 *i_bdev;
		struct cdev___8 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___21;

struct dentry_operations___21 {
	int (*d_revalidate)(struct dentry___23 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___23 *, unsigned int);
	int (*d_hash)(const struct dentry___23 *, struct qstr *);
	int (*d_compare)(const struct dentry___23 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___23 *);
	int (*d_init)(struct dentry___23 *);
	void (*d_release)(struct dentry___23 *);
	void (*d_prune)(struct dentry___23 *);
	void (*d_iput)(struct dentry___23 *, struct inode___24 *);
	char * (*d_dname)(struct dentry___23 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___21 *);
	int (*d_manage)(const struct path___21 *, bool);
	struct dentry___23 * (*d_real)(struct dentry___23 *, const struct inode___24 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___21;

struct mem_dqinfo___21 {
	struct quota_format_type___21 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___21;

struct quota_info___21 {
	unsigned int flags;
	struct rw_semaphore___22 dqio_sem;
	struct inode___24 *files[3];
	struct mem_dqinfo___21 info[3];
	const struct quota_format_ops___21 *ops[3];
};

struct rcuwait___21 {
	struct task_struct___23 *task;
};

struct percpu_rw_semaphore___21 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___22 rw_sem;
	struct rcuwait___21 writer;
	int readers_block;
};

struct sb_writers___21 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___21 rw_sem[3];
};

struct shrink_control___6;

struct shrinker___6 {
	long unsigned int (*count_objects)(struct shrinker___6 *, struct shrink_control___6 *);
	long unsigned int (*scan_objects)(struct shrinker___6 *, struct shrink_control___6 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___21;

struct super_operations___21;

struct dquot_operations___21;

struct quotactl_ops___21;

struct super_block___22 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___21 *s_type;
	const struct super_operations___21 *s_op;
	const struct dquot_operations___21 *dq_op;
	const struct quotactl_ops___21 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___23 *s_root;
	struct rw_semaphore___22 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___22 *s_bdev;
	struct backing_dev_info___7 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___21 s_dquot;
	struct sb_writers___21 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___21 *s_d_op;
	int cleancache_poolid;
	struct shrinker___6 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___13 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct path___21 {
	struct vfsmount *mnt;
	struct dentry___23 *dentry;
};

struct shrink_control___6 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___6 *memcg;
};

typedef int (*dev_page_fault_t___21)(struct vm_area_struct___22 *, long unsigned int, const struct page___22 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___21)(struct page___22 *, void *);

struct dev_pagemap___21 {
	dev_page_fault_t___21 page_fault;
	dev_page_free_t___21 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___18 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct fown_struct___20 {
	rwlock_t lock;
	struct pid___20 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___22 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___21 f_path;
	struct inode___24 *f_inode;
	const struct file_operations___22 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___20 f_owner;
	const struct cred___21 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___21 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___21;

struct vm_operations_struct___21 {
	void (*open)(struct vm_area_struct___22 *);
	void (*close)(struct vm_area_struct___22 *);
	int (*split)(struct vm_area_struct___22 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___22 *);
	vm_fault_t (*fault)(struct vm_fault___21 *);
	vm_fault_t (*huge_fault)(struct vm_fault___21 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___21 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___22 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___21 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___21 *);
	int (*access)(struct vm_area_struct___22 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___22 *);
	int (*set_policy)(struct vm_area_struct___22 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___22 *, long unsigned int);
	struct page___22 * (*find_special_page)(struct vm_area_struct___22 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___21 {
	struct task_struct___23 *task;
	struct core_thread___21 *next;
};

struct core_state___21 {
	atomic_t nr_threads;
	struct core_thread___21 dumper;
	struct completion startup;
};

struct vm_fault___21 {
	struct vm_area_struct___22 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___22 *cow_page;
	struct mem_cgroup___6 *memcg;
	struct page___22 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___21 prealloc_pte;
};

struct kiocb___22 {
	struct file___22 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___22 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___22 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___22 *ia_file;
};

struct dquot___21 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___22 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___21 {
	int qf_fmt_id;
	const struct quota_format_ops___21 *qf_ops;
	struct module___21 *qf_owner;
	struct quota_format_type___21 *qf_next;
};

struct quota_format_ops___21 {
	int (*check_quota_file)(struct super_block___22 *, int);
	int (*read_file_info)(struct super_block___22 *, int);
	int (*write_file_info)(struct super_block___22 *, int);
	int (*free_file_info)(struct super_block___22 *, int);
	int (*read_dqblk)(struct dquot___21 *);
	int (*commit_dqblk)(struct dquot___21 *);
	int (*release_dqblk)(struct dquot___21 *);
	int (*get_next_id)(struct super_block___22 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___21 {
	int (*write_dquot)(struct dquot___21 *);
	struct dquot___21 * (*alloc_dquot)(struct super_block___22 *, int);
	void (*destroy_dquot)(struct dquot___21 *);
	int (*acquire_dquot)(struct dquot___21 *);
	int (*release_dquot)(struct dquot___21 *);
	int (*mark_dirty)(struct dquot___21 *);
	int (*write_info)(struct super_block___22 *, int);
	qsize_t * (*get_reserved_space)(struct inode___24 *);
	int (*get_projid)(struct inode___24 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___24 *, qsize_t *);
	int (*get_next_id)(struct super_block___22 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___21 {
	int (*quota_on)(struct super_block___22 *, int, int, const struct path___21 *);
	int (*quota_off)(struct super_block___22 *, int);
	int (*quota_enable)(struct super_block___22 *, unsigned int);
	int (*quota_disable)(struct super_block___22 *, unsigned int);
	int (*quota_sync)(struct super_block___22 *, int);
	int (*set_info)(struct super_block___22 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___22 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___22 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___22 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___22 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___22 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___20;

struct kobj_type___20;

struct kobject___21 {
	const char *name;
	struct list_head entry;
	struct kobject___21 *parent;
	struct kset___20 *kset;
	struct kobj_type___20 *ktype;
	struct kernfs_node___20 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___18 {
	struct kobject___21 kobj;
	struct module___21 *mod;
	struct kobject___21 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___18 {
	struct module___21 *mod;
	struct latch_tree_node node;
};

struct module_layout___18 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___18 mtn;
};

struct module_attribute___18;

struct kernel_param___18;

struct module___21 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___18 mkobj;
	struct module_attribute___18 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___21 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___18 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___18 core_layout;
	struct module_layout___18 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide35;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide36;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___6;

struct address_space_operations___21 {
	int (*writepage)(struct page___22 *, struct writeback_control___6 *);
	int (*readpage)(struct file___22 *, struct page___22 *);
	int (*writepages)(struct address_space___21 *, struct writeback_control___6 *);
	int (*set_page_dirty)(struct page___22 *);
	int (*readpages)(struct file___22 *, struct address_space___21 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___22 *, struct address_space___21 *, loff_t, unsigned int, unsigned int, struct page___22 **, void **);
	int (*write_end)(struct file___22 *, struct address_space___21 *, loff_t, unsigned int, unsigned int, struct page___22 *, void *);
	sector_t (*bmap)(struct address_space___21 *, sector_t);
	void (*invalidatepage)(struct page___22 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___22 *, gfp_t);
	void (*freepage)(struct page___22 *);
	ssize_t (*direct_IO)(struct kiocb___22 *, struct iov_iter___8 *);
	int (*migratepage)(struct address_space___21 *, struct page___22 *, struct page___22 *, enum migrate_mode);
	bool (*isolate_page)(struct page___22 *, isolate_mode_t);
	void (*putback_page)(struct page___22 *);
	int (*launder_page)(struct page___22 *);
	int (*is_partially_uptodate)(struct page___22 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___22 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___21 *, struct page___22 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___22 *, sector_t *);
	void (*swap_deactivate)(struct file___22 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___6 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___7 *wb;
	struct inode___24 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___7;

struct iov_iter___8 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___7 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct swap_info_struct___3 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___22 *bdev;
	struct file___22 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___22 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___24 *bd_inode;
	struct super_block___22 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___22 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___7 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___8 {
	struct kobject___21 kobj;
	struct module___21 *owner;
	const struct file_operations___22 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___21 {
	struct dentry___23 * (*lookup)(struct inode___24 *, struct dentry___23 *, unsigned int);
	const char * (*get_link)(struct dentry___23 *, struct inode___24 *, struct delayed_call *);
	int (*permission)(struct inode___24 *, int);
	struct posix_acl * (*get_acl)(struct inode___24 *, int);
	int (*readlink)(struct dentry___23 *, char *, int);
	int (*create)(struct inode___24 *, struct dentry___23 *, umode_t, bool);
	int (*link)(struct dentry___23 *, struct inode___24 *, struct dentry___23 *);
	int (*unlink)(struct inode___24 *, struct dentry___23 *);
	int (*symlink)(struct inode___24 *, struct dentry___23 *, const char *);
	int (*mkdir)(struct inode___24 *, struct dentry___23 *, umode_t);
	int (*rmdir)(struct inode___24 *, struct dentry___23 *);
	int (*mknod)(struct inode___24 *, struct dentry___23 *, umode_t, dev_t);
	int (*rename)(struct inode___24 *, struct dentry___23 *, struct inode___24 *, struct dentry___23 *, unsigned int);
	int (*setattr)(struct dentry___23 *, struct iattr___22 *);
	int (*getattr)(const struct path___21 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___23 *, char *, size_t);
	int (*fiemap)(struct inode___24 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___24 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___24 *, struct dentry___23 *, struct file___22 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___24 *, struct dentry___23 *, umode_t);
	int (*set_acl)(struct inode___24 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___21 {
	void (*fl_copy_lock)(struct file_lock___22 *, struct file_lock___22 *);
	void (*fl_release_private)(struct file_lock___22 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___21;

struct lock_manager_operations___21;

struct file_lock___22 {
	struct file_lock___22 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___22 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___21 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___21 *fl_ops;
	const struct lock_manager_operations___21 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___21 {
	int (*lm_compare_owner)(struct file_lock___22 *, struct file_lock___22 *);
	long unsigned int (*lm_owner_key)(struct file_lock___22 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___22 *);
	int (*lm_grant)(struct file_lock___22 *, int);
	bool (*lm_break)(struct file_lock___22 *);
	int (*lm_change)(struct file_lock___22 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___22 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___21 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___21 *fa_next;
	struct file___22 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___21 {
	const char *name;
	int fs_flags;
	struct dentry___23 * (*mount)(struct file_system_type___21 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___22 *);
	struct module___21 *owner;
	struct file_system_type___21 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___21 {
	struct inode___24 * (*alloc_inode)(struct super_block___22 *);
	void (*destroy_inode)(struct inode___24 *);
	void (*dirty_inode)(struct inode___24 *, int);
	int (*write_inode)(struct inode___24 *, struct writeback_control___6 *);
	int (*drop_inode)(struct inode___24 *);
	void (*evict_inode)(struct inode___24 *);
	void (*put_super)(struct super_block___22 *);
	int (*sync_fs)(struct super_block___22 *, int);
	int (*freeze_super)(struct super_block___22 *);
	int (*freeze_fs)(struct super_block___22 *);
	int (*thaw_super)(struct super_block___22 *);
	int (*unfreeze_fs)(struct super_block___22 *);
	int (*statfs)(struct dentry___23 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___22 *, int *, char *);
	void (*umount_begin)(struct super_block___22 *);
	int (*show_options)(struct seq_file___20 *, struct dentry___23 *);
	int (*show_devname)(struct seq_file___20 *, struct dentry___23 *);
	int (*show_path)(struct seq_file___20 *, struct dentry___23 *);
	int (*show_stats)(struct seq_file___20 *, struct dentry___23 *);
	ssize_t (*quota_read)(struct super_block___22 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___22 *, int, const char *, size_t, loff_t);
	struct dquot___21 ** (*get_dquots)(struct inode___24 *);
	int (*bdev_try_to_free_page)(struct super_block___22 *, struct page___22 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___22 *, struct shrink_control___6 *);
	long int (*free_cached_objects)(struct super_block___22 *, struct shrink_control___6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___13)(struct file___22 *, wait_queue_head_t *, struct poll_table_struct___14 *);

struct poll_table_struct___14 {
	poll_queue_proc___13 _qproc;
	__poll_t _key;
};

struct seq_operations___17;

struct seq_file___20 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___17 *op;
	int poll_event;
	const struct file___22 *file;
	void *private;
};

typedef void bio_end_io_t___7(struct bio___7 *);

struct bio_vec___7 {
	struct page___22 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___7;

struct bio_set___7;

struct bio___7 {
	struct bio___7 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___7 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___7 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___7 *bi_io_vec;
	struct bio_set___7 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___7 bi_inline_vecs[0];
};

typedef int (*key_restrict_link_func_t___21)(struct key___22 *, const struct key_type *, const union key_payload *, struct key___22 *);

struct key_restriction___22;

struct key___22 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___22 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___22 *restrict_link;
};

struct key_restriction___22 {
	key_restrict_link_func_t___21 check;
	struct key___22 *key;
	struct key_type *keytype;
};

struct seq_operations___17 {
	void * (*start)(struct seq_file___20 *, loff_t *);
	void (*stop)(struct seq_file___20 *, void *);
	void * (*next)(struct seq_file___20 *, void *, loff_t *);
	int (*show)(struct seq_file___20 *, void *);
};

struct kernfs_root___20;

struct kernfs_elem_dir___20 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___20 *root;
};

struct kernfs_syscall_ops___20;

struct kernfs_root___20 {
	struct kernfs_node___20 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___20 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___20 {
	struct kernfs_node___20 *target_kn;
};

struct kernfs_ops___20;

struct kernfs_elem_attr___20 {
	const struct kernfs_ops___20 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___20 *notify_next;
};

struct kernfs_node___20 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___20 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___20 dir;
		struct kernfs_elem_symlink___20 symlink;
		struct kernfs_elem_attr___20 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___20;

struct kernfs_ops___20 {
	int (*open)(struct kernfs_open_file___20 *);
	void (*release)(struct kernfs_open_file___20 *);
	int (*seq_show)(struct seq_file___20 *, void *);
	void * (*seq_start)(struct seq_file___20 *, loff_t *);
	void * (*seq_next)(struct seq_file___20 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___20 *, void *);
	ssize_t (*read)(struct kernfs_open_file___20 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___20 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___20 *, struct vm_area_struct___22 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___20 *, struct poll_table_struct___14 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___20 {
	int (*remount_fs)(struct kernfs_root___20 *, int *, char *);
	int (*show_options)(struct seq_file___20 *, struct kernfs_root___20 *);
	int (*mkdir)(struct kernfs_node___20 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___20 *);
	int (*rename)(struct kernfs_node___20 *, struct kernfs_node___20 *, const char *);
	int (*show_path)(struct seq_file___20 *, struct kernfs_node___20 *, struct kernfs_root___20 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___20 {
	struct kernfs_node___20 *kn;
	struct file___22 *file;
	struct seq_file___20 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___21 *vm_ops;
};

struct cgroup_namespace___12 {
	refcount_t count;
	struct ns_common ns;
	struct user_namespace___13 *user_ns;
	struct ucounts___13 *ucounts;
	struct css_set___12 *root_cset;
};

struct ucounts___13 {
	struct hlist_node node;
	struct user_namespace___13 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___12;

struct bpf_map_ops___12 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___12 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___12 *, struct file___22 *);
	void (*map_free)(struct bpf_map___12 *);
	int (*map_get_next_key)(struct bpf_map___12 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___12 *);
	void * (*map_lookup_elem)(struct bpf_map___12 *, void *);
	int (*map_update_elem)(struct bpf_map___12 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___12 *, void *);
	int (*map_push_elem)(struct bpf_map___12 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___12 *, void *);
	int (*map_peek_elem)(struct bpf_map___12 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___12 *, struct file___22 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___12 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___12 *, void *, struct seq_file___20 *);
	int (*map_check_btf)(const struct bpf_map___12 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___12 {
	const struct bpf_map_ops___12 *ops;
	struct bpf_map___12 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___21 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___12;

typedef void (*kthread_work_func_t___12)(struct kthread_work___12 *);

struct kthread_worker___12;

struct kthread_work___12 {
	struct list_head node;
	kthread_work_func_t___12 func;
	struct kthread_worker___12 *worker;
	int canceling;
};

struct kthread_worker___12 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___23 *task;
	struct kthread_work___12 *current_work;
};

struct kthread_delayed_work___12 {
	struct kthread_work___12 work;
	struct timer_list timer;
};

struct psi_group___12 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___12 *poll_kworker;
	struct kthread_delayed_work___12 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___12;

struct cgroup_rstat_cpu___12;

struct cgroup___12 {
	struct cgroup_subsys_state___12 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___20 *kn;
	struct cgroup_file___12 procs_file;
	struct cgroup_file___12 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___12 *subsys[13];
	struct cgroup_root___12 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___12 *dom_cgrp;
	struct cgroup_rstat_cpu___12 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf bpf;
	atomic_t congestion_count;
	struct cgroup___12 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___12 psi;
	int ancestor_ids[0];
};

struct cftype___12;

struct cgroup_subsys___12 {
	struct cgroup_subsys_state___12 * (*css_alloc)(struct cgroup_subsys_state___12 *);
	int (*css_online)(struct cgroup_subsys_state___12 *);
	void (*css_offline)(struct cgroup_subsys_state___12 *);
	void (*css_released)(struct cgroup_subsys_state___12 *);
	void (*css_free)(struct cgroup_subsys_state___12 *);
	void (*css_reset)(struct cgroup_subsys_state___12 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___12 *, int);
	int (*css_extra_stat_show)(struct seq_file___20 *, struct cgroup_subsys_state___12 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___23 *);
	void (*cancel_fork)(struct task_struct___23 *);
	void (*fork)(struct task_struct___23 *);
	void (*exit)(struct task_struct___23 *);
	void (*free)(struct task_struct___23 *);
	void (*bind)(struct cgroup_subsys_state___12 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___12 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___12 *dfl_cftypes;
	struct cftype___12 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___12 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___12 *updated_children;
	struct cgroup___12 *updated_next;
};

struct cgroup_root___12 {
	struct kernfs_root___20 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___12 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___12 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___12 *ss;
	struct list_head node;
	struct kernfs_ops___20 *kf_ops;
	int (*open)(struct kernfs_open_file___20 *);
	void (*release)(struct kernfs_open_file___20 *);
	u64 (*read_u64)(struct cgroup_subsys_state___12 *, struct cftype___12 *);
	s64 (*read_s64)(struct cgroup_subsys_state___12 *, struct cftype___12 *);
	int (*seq_show)(struct seq_file___20 *, void *);
	void * (*seq_start)(struct seq_file___20 *, loff_t *);
	void * (*seq_next)(struct seq_file___20 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___20 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___12 *, struct cftype___12 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___12 *, struct cftype___12 *, s64);
	ssize_t (*write)(struct kernfs_open_file___20 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___20 *, struct poll_table_struct___14 *);
};

struct dev_pm_info___18 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___18 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___18;

struct bus_type___18;

struct device_driver___18;

struct dev_pm_domain___18;

struct dma_map_ops___4;

struct device_node___7;

struct fwnode_handle___15;

struct class___18;

struct attribute_group___18;

struct device___18 {
	struct device___18 *parent;
	struct device_private *p;
	struct kobject___21 kobj;
	const char *init_name;
	const struct device_type___18 *type;
	struct mutex mutex;
	struct bus_type___18 *bus;
	struct device_driver___18 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___18 power;
	struct dev_pm_domain___18 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___4 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___7 *of_node;
	struct fwnode_handle___15 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___18 *class;
	const struct attribute_group___18 **groups;
	void (*release)(struct device___18 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct kobj_attribute___21 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___21 *, struct kobj_attribute___21 *, char *);
	ssize_t (*store)(struct kobject___21 *, struct kobj_attribute___21 *, const char *, size_t);
};

typedef void compound_page_dtor___21(struct page___22 *);

struct bdi_writeback_congested___7 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___7 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___7 {
	struct bio___7 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___7 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___7 bip_inline_vecs[0];
};

struct bio_set___7 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___7 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___6 {
	struct mem_cgroup___6 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___6 {
	struct lruvec___21 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___6 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___6 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct bin_attribute___18;

struct attribute_group___18 {
	const char *name;
	umode_t (*is_visible)(struct kobject___21 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___21 *, struct bin_attribute___18 *, int);
	struct attribute **attrs;
	struct bin_attribute___18 **bin_attrs;
};

struct bin_attribute___18 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___22 *, struct kobject___21 *, struct bin_attribute___18 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___22 *, struct kobject___21 *, struct bin_attribute___18 *, char *, loff_t, size_t);
	int (*mmap)(struct file___22 *, struct kobject___21 *, struct bin_attribute___18 *, struct vm_area_struct___22 *);
};

struct sysfs_ops___20 {
	ssize_t (*show)(struct kobject___21 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___21 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___20;

struct kset___20 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___21 kobj;
	const struct kset_uevent_ops___20 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___20 {
	void (*release)(struct kobject___21 *);
	const struct sysfs_ops___20 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___21 *);
	const void * (*namespace)(struct kobject___21 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___20 {
	int (* const filter)(struct kset___20 *, struct kobject___21 *);
	const char * (* const name)(struct kset___20 *, struct kobject___21 *);
	int (* const uevent)(struct kset___20 *, struct kobject___21 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___18 {
	int (*prepare)(struct device___18 *);
	void (*complete)(struct device___18 *);
	int (*suspend)(struct device___18 *);
	int (*resume)(struct device___18 *);
	int (*freeze)(struct device___18 *);
	int (*thaw)(struct device___18 *);
	int (*poweroff)(struct device___18 *);
	int (*restore)(struct device___18 *);
	int (*suspend_late)(struct device___18 *);
	int (*resume_early)(struct device___18 *);
	int (*freeze_late)(struct device___18 *);
	int (*thaw_early)(struct device___18 *);
	int (*poweroff_late)(struct device___18 *);
	int (*restore_early)(struct device___18 *);
	int (*suspend_noirq)(struct device___18 *);
	int (*resume_noirq)(struct device___18 *);
	int (*freeze_noirq)(struct device___18 *);
	int (*thaw_noirq)(struct device___18 *);
	int (*poweroff_noirq)(struct device___18 *);
	int (*restore_noirq)(struct device___18 *);
	int (*runtime_suspend)(struct device___18 *);
	int (*runtime_resume)(struct device___18 *);
	int (*runtime_idle)(struct device___18 *);
};

struct dev_pm_domain___18 {
	struct dev_pm_ops___18 ops;
	void (*detach)(struct device___18 *, bool);
	int (*activate)(struct device___18 *);
	void (*sync)(struct device___18 *);
	void (*dismiss)(struct device___18 *);
};

struct bus_type___18 {
	const char *name;
	const char *dev_name;
	struct device___18 *dev_root;
	const struct attribute_group___18 **bus_groups;
	const struct attribute_group___18 **dev_groups;
	const struct attribute_group___18 **drv_groups;
	int (*match)(struct device___18 *, struct device_driver___18 *);
	int (*uevent)(struct device___18 *, struct kobj_uevent_env *);
	int (*probe)(struct device___18 *);
	int (*remove)(struct device___18 *);
	void (*shutdown)(struct device___18 *);
	int (*online)(struct device___18 *);
	int (*offline)(struct device___18 *);
	int (*suspend)(struct device___18 *, pm_message_t);
	int (*resume)(struct device___18 *);
	int (*num_vf)(struct device___18 *);
	int (*dma_configure)(struct device___18 *);
	const struct dev_pm_ops___18 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___18 {
	const char *name;
	struct bus_type___18 *bus;
	struct module___21 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___18 *);
	int (*remove)(struct device___18 *);
	void (*shutdown)(struct device___18 *);
	int (*suspend)(struct device___18 *, pm_message_t);
	int (*resume)(struct device___18 *);
	const struct attribute_group___18 **groups;
	const struct dev_pm_ops___18 *pm;
	void (*coredump)(struct device___18 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___18 {
	const char *name;
	const struct attribute_group___18 **groups;
	int (*uevent)(struct device___18 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___18 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___18 *);
	const struct dev_pm_ops___18 *pm;
};

struct class___18 {
	const char *name;
	struct module___21 *owner;
	const struct attribute_group___18 **class_groups;
	const struct attribute_group___18 **dev_groups;
	struct kobject___21 *dev_kobj;
	int (*dev_uevent)(struct device___18 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___18 *, umode_t *);
	void (*class_release)(struct class___18 *);
	void (*dev_release)(struct device___18 *);
	int (*shutdown_pre)(struct device___18 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___18 *);
	const struct dev_pm_ops___18 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___4 {
	void * (*alloc)(struct device___18 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___18 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___18 *, struct vm_area_struct___22 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___18 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___18 *, struct page___22 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___18 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___18 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___18 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___18 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___18 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___18 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___18 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___18 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___18 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___18 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___18 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___18 *, u64);
	u64 (*get_required_mask)(struct device___18 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___15;

struct fwnode_handle___15 {
	struct fwnode_handle___15 *secondary;
	const struct fwnode_operations___15 *ops;
};

struct property___7;

struct device_node___7 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___15 fwnode;
	struct property___7 *properties;
	struct property___7 *deadprops;
	struct device_node___7 *parent;
	struct device_node___7 *child;
	struct device_node___7 *sibling;
	struct kobject___21 kobj;
	long unsigned int _flags;
	void *data;
};

struct node___17 {
	struct device___18 dev;
};

struct fwnode_reference_args___15;

struct fwnode_endpoint___15;

struct fwnode_operations___15 {
	struct fwnode_handle___15 * (*get)(struct fwnode_handle___15 *);
	void (*put)(struct fwnode_handle___15 *);
	bool (*device_is_available)(const struct fwnode_handle___15 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___15 *, const struct device___18 *);
	bool (*property_present)(const struct fwnode_handle___15 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___15 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___15 *, const char *, const char **, size_t);
	struct fwnode_handle___15 * (*get_parent)(const struct fwnode_handle___15 *);
	struct fwnode_handle___15 * (*get_next_child_node)(const struct fwnode_handle___15 *, struct fwnode_handle___15 *);
	struct fwnode_handle___15 * (*get_named_child_node)(const struct fwnode_handle___15 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___15 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___15 *);
	struct fwnode_handle___15 * (*graph_get_next_endpoint)(const struct fwnode_handle___15 *, struct fwnode_handle___15 *);
	struct fwnode_handle___15 * (*graph_get_remote_endpoint)(const struct fwnode_handle___15 *);
	struct fwnode_handle___15 * (*graph_get_port_parent)(struct fwnode_handle___15 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___15 *, struct fwnode_endpoint___15 *);
};

struct fwnode_endpoint___15 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___15 *local_fwnode;
};

struct fwnode_reference_args___15 {
	struct fwnode_handle___15 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct property___7 {
	char *name;
	int length;
	void *value;
	struct property___7 *next;
	long unsigned int _flags;
	struct bin_attribute___18 attr;
};

struct kernel_param_ops___18 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___18 *);
	int (*get)(char *, const struct kernel_param___18 *);
	void (*free)(void *);
};

struct kparam_array___18;

struct kernel_param___18 {
	const char *name;
	struct module___21 *mod;
	const struct kernel_param_ops___18 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___18 *arr;
	};
};

struct kparam_array___18 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___18 *ops;
	void *elem;
};

struct module_attribute___18 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___18 *, struct module_kobject___18 *, char *);
	ssize_t (*store)(struct module_attribute___18 *, struct module_kobject___18 *, const char *, size_t);
	void (*setup)(struct module___21 *, const char *);
	int (*test)(struct module___21 *);
	void (*free)(struct module___21 *);
};

struct kimage___7;

typedef void *kexec_load_t___7(struct kimage___7 *, char *, long unsigned int, char *, long unsigned int, char *, long unsigned int);

struct kexec_file_ops___8 {
	kexec_probe_t *probe;
	kexec_load_t___7 *load;
	kexec_cleanup_t *cleanup;
};

struct kimage___7 {
	kimage_entry_t head;
	kimage_entry_t *entry;
	kimage_entry_t *last_entry;
	long unsigned int start;
	struct page___22 *control_code_page;
	struct page___22 *swap_page;
	void *vmcoreinfo_data_copy;
	long unsigned int nr_segments;
	struct kexec_segment segment[16];
	struct list_head control_pages;
	struct list_head dest_pages;
	struct list_head unusable_pages;
	long unsigned int control_page;
	unsigned int type: 1;
	unsigned int preserve_context: 1;
	unsigned int file_mode: 1;
	struct kimage_arch arch;
	void *kernel_buf;
	long unsigned int kernel_buf_len;
	void *initrd_buf;
	long unsigned int initrd_buf_len;
	char *cmdline_buf;
	long unsigned int cmdline_buf_len;
	const struct kexec_file_ops___8 *fops;
	void *image_loader_data;
	struct purgatory_info purgatory_info;
};

struct file___23;

struct kiocb___23;

struct vm_area_struct___23;

struct inode___25;

struct file_lock___23;

struct page___23;

struct file_operations___23 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___23 *, loff_t, int);
	ssize_t (*read)(struct file___23 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___23 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___23 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___23 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___23 *, bool);
	int (*iterate)(struct file___23 *, struct dir_context *);
	int (*iterate_shared)(struct file___23 *, struct dir_context *);
	__poll_t (*poll)(struct file___23 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___23 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___23 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___23 *, struct vm_area_struct___23 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___25 *, struct file___23 *);
	int (*flush)(struct file___23 *, fl_owner_t);
	int (*release)(struct inode___25 *, struct file___23 *);
	int (*fsync)(struct file___23 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___23 *, int);
	int (*lock)(struct file___23 *, int, struct file_lock___23 *);
	ssize_t (*sendpage)(struct file___23 *, struct page___23 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___23 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___23 *, int, struct file_lock___23 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___23 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___23 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___23 *, long int, struct file_lock___23 **, void **);
	long int (*fallocate)(struct file___23 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___23 *);
	ssize_t (*copy_file_range)(struct file___23 *, loff_t, struct file___23 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___23 *, loff_t, struct file___23 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___23 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___22 {
	u64 seqnum;
	struct vm_area_struct___23 *vmas[4];
};

struct page_frag___22 {
	struct page___23 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___23;

struct cred___22;

struct signal_struct___21;

struct vm_struct___18;

struct task_struct___24 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___24 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___23 *mm;
	struct mm_struct___23 *active_mm;
	struct vmacache___22 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___24 *real_parent;
	struct task_struct___24 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___24 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___20 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___20 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___20 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___22 *ptracer_cred;
	const struct cred___22 *real_cred;
	const struct cred___22 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___21 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___24 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___2 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___22 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___24 *oom_reaper_list;
	struct vm_struct___18 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___11 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___22;

struct super_block___23;

struct dentry___24 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___24 *d_parent;
	struct qstr d_name;
	struct inode___25 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___22 *d_op;
	struct super_block___23 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct rw_semaphore___23 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___24 *owner;
};

struct address_space_operations___22;

struct address_space___22 {
	struct inode___25 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___23 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___22 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___22;

struct block_device___23;

struct inode___25 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___22 *i_op;
	struct super_block___23 *i_sb;
	struct address_space___22 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___23 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___23 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___22 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___23 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___22;

struct dentry_operations___22 {
	int (*d_revalidate)(struct dentry___24 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___24 *, unsigned int);
	int (*d_hash)(const struct dentry___24 *, struct qstr *);
	int (*d_compare)(const struct dentry___24 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___24 *);
	int (*d_init)(struct dentry___24 *);
	void (*d_release)(struct dentry___24 *);
	void (*d_prune)(struct dentry___24 *);
	void (*d_iput)(struct dentry___24 *, struct inode___25 *);
	char * (*d_dname)(struct dentry___24 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___22 *);
	int (*d_manage)(const struct path___22 *, bool);
	struct dentry___24 * (*d_real)(struct dentry___24 *, const struct inode___25 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___22;

struct mem_dqinfo___22 {
	struct quota_format_type___22 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___22;

struct quota_info___22 {
	unsigned int flags;
	struct rw_semaphore___23 dqio_sem;
	struct inode___25 *files[3];
	struct mem_dqinfo___22 info[3];
	const struct quota_format_ops___22 *ops[3];
};

struct rcuwait___22 {
	struct task_struct___24 *task;
};

struct percpu_rw_semaphore___22 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___23 rw_sem;
	struct rcuwait___22 writer;
	int readers_block;
};

struct sb_writers___22 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___22 rw_sem[3];
};

struct file_system_type___22;

struct super_operations___22;

struct dquot_operations___22;

struct quotactl_ops___22;

struct super_block___23 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___22 *s_type;
	const struct super_operations___22 *s_op;
	const struct dquot_operations___22 *dq_op;
	const struct quotactl_ops___22 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___24 *s_root;
	struct rw_semaphore___23 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___23 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___22 s_dquot;
	struct sb_writers___22 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___22 *s_d_op;
	int cleancache_poolid;
	struct shrinker___6 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct path___22 {
	struct vfsmount *mnt;
	struct dentry___24 *dentry;
};

typedef struct page___23 *pgtable_t___22;

struct dev_pagemap___22;

struct page___23 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___22 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___23 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___22 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___23 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___22 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___22;

struct lruvec___22 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___22 *pgdat;
};

struct zone___22 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___22 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___22 {
	struct zone___22 *zone;
	int zone_idx;
};

struct zonelist___22 {
	struct zoneref___22 _zonerefs[25];
};

struct pglist_data___22 {
	struct zone___22 node_zones[3];
	struct zonelist___22 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___24 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___24 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___22 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___23 {
	void *stack;
	struct task_struct___24 *task;
	long int status;
};

struct blocking_notifier_head___22 {
	struct rw_semaphore___23 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___22;

struct vm_area_struct___23 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___23 *vm_next;
	struct vm_area_struct___23 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___23 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___22 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___23 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___22;

struct mm_struct___23 {
	struct {
		struct vm_area_struct___23 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___23 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___23 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___22 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___24 *owner;
		struct user_namespace___3 *user_ns;
		struct file___23 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___22 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___22)(struct vm_area_struct___23 *, long unsigned int, const struct page___23 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___22)(struct page___23 *, void *);

struct dev_pagemap___22 {
	dev_page_fault_t___22 page_fault;
	dev_page_free_t___22 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___6 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct file___23 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___22 f_path;
	struct inode___25 *f_inode;
	const struct file_operations___23 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___20 f_owner;
	const struct cred___22 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___22 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___22;

struct vm_operations_struct___22 {
	void (*open)(struct vm_area_struct___23 *);
	void (*close)(struct vm_area_struct___23 *);
	int (*split)(struct vm_area_struct___23 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___23 *);
	vm_fault_t (*fault)(struct vm_fault___22 *);
	vm_fault_t (*huge_fault)(struct vm_fault___22 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___22 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___23 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___22 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___22 *);
	int (*access)(struct vm_area_struct___23 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___23 *);
	int (*set_policy)(struct vm_area_struct___23 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___23 *, long unsigned int);
	struct page___23 * (*find_special_page)(struct vm_area_struct___23 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___22 {
	struct task_struct___24 *task;
	struct core_thread___22 *next;
};

struct core_state___22 {
	atomic_t nr_threads;
	struct core_thread___22 dumper;
	struct completion startup;
};

struct vm_fault___22 {
	struct vm_area_struct___23 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___23 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___23 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___22 prealloc_pte;
};

struct key___23;

struct user_struct___22 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___23 *uid_keyring;
	struct key___23 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___22 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___23 *session_keyring;
	struct key___23 *process_keyring;
	struct key___23 *thread_keyring;
	struct key___23 *request_key_auth;
	void *security;
	struct user_struct___22 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct signal_struct___21 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___24 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___24 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___20 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___20 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___23 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___20 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_struct___18 {
	struct vm_struct___18 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___23 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___21 {
	struct task_struct___24 task;
	long unsigned int stack[8192];
};

struct kiocb___23 {
	struct file___23 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___23 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___23 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___23 *ia_file;
};

struct dquot___22 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___23 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___22 {
	int qf_fmt_id;
	const struct quota_format_ops___22 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___22 *qf_next;
};

struct quota_format_ops___22 {
	int (*check_quota_file)(struct super_block___23 *, int);
	int (*read_file_info)(struct super_block___23 *, int);
	int (*write_file_info)(struct super_block___23 *, int);
	int (*free_file_info)(struct super_block___23 *, int);
	int (*read_dqblk)(struct dquot___22 *);
	int (*commit_dqblk)(struct dquot___22 *);
	int (*release_dqblk)(struct dquot___22 *);
	int (*get_next_id)(struct super_block___23 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___22 {
	int (*write_dquot)(struct dquot___22 *);
	struct dquot___22 * (*alloc_dquot)(struct super_block___23 *, int);
	void (*destroy_dquot)(struct dquot___22 *);
	int (*acquire_dquot)(struct dquot___22 *);
	int (*release_dquot)(struct dquot___22 *);
	int (*mark_dirty)(struct dquot___22 *);
	int (*write_info)(struct super_block___23 *, int);
	qsize_t * (*get_reserved_space)(struct inode___25 *);
	int (*get_projid)(struct inode___25 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___25 *, qsize_t *);
	int (*get_next_id)(struct super_block___23 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___22 {
	int (*quota_on)(struct super_block___23 *, int, int, const struct path___22 *);
	int (*quota_off)(struct super_block___23 *, int);
	int (*quota_enable)(struct super_block___23 *, unsigned int);
	int (*quota_disable)(struct super_block___23 *, unsigned int);
	int (*quota_sync)(struct super_block___23 *, int);
	int (*set_info)(struct super_block___23 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___23 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___23 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___23 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___23 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___23 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___22 {
	int (*writepage)(struct page___23 *, struct writeback_control___3 *);
	int (*readpage)(struct file___23 *, struct page___23 *);
	int (*writepages)(struct address_space___22 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___23 *);
	int (*readpages)(struct file___23 *, struct address_space___22 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___23 *, struct address_space___22 *, loff_t, unsigned int, unsigned int, struct page___23 **, void **);
	int (*write_end)(struct file___23 *, struct address_space___22 *, loff_t, unsigned int, unsigned int, struct page___23 *, void *);
	sector_t (*bmap)(struct address_space___22 *, sector_t);
	void (*invalidatepage)(struct page___23 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___23 *, gfp_t);
	void (*freepage)(struct page___23 *);
	ssize_t (*direct_IO)(struct kiocb___23 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___22 *, struct page___23 *, struct page___23 *, enum migrate_mode);
	bool (*isolate_page)(struct page___23 *, isolate_mode_t);
	void (*putback_page)(struct page___23 *);
	int (*launder_page)(struct page___23 *);
	int (*is_partially_uptodate)(struct page___23 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___23 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___22 *, struct page___23 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___23 *, sector_t *);
	void (*swap_deactivate)(struct file___23 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___23 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___25 *bd_inode;
	struct super_block___23 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___23 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___22 {
	struct dentry___24 * (*lookup)(struct inode___25 *, struct dentry___24 *, unsigned int);
	const char * (*get_link)(struct dentry___24 *, struct inode___25 *, struct delayed_call *);
	int (*permission)(struct inode___25 *, int);
	struct posix_acl * (*get_acl)(struct inode___25 *, int);
	int (*readlink)(struct dentry___24 *, char *, int);
	int (*create)(struct inode___25 *, struct dentry___24 *, umode_t, bool);
	int (*link)(struct dentry___24 *, struct inode___25 *, struct dentry___24 *);
	int (*unlink)(struct inode___25 *, struct dentry___24 *);
	int (*symlink)(struct inode___25 *, struct dentry___24 *, const char *);
	int (*mkdir)(struct inode___25 *, struct dentry___24 *, umode_t);
	int (*rmdir)(struct inode___25 *, struct dentry___24 *);
	int (*mknod)(struct inode___25 *, struct dentry___24 *, umode_t, dev_t);
	int (*rename)(struct inode___25 *, struct dentry___24 *, struct inode___25 *, struct dentry___24 *, unsigned int);
	int (*setattr)(struct dentry___24 *, struct iattr___23 *);
	int (*getattr)(const struct path___22 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___24 *, char *, size_t);
	int (*fiemap)(struct inode___25 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___25 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___25 *, struct dentry___24 *, struct file___23 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___25 *, struct dentry___24 *, umode_t);
	int (*set_acl)(struct inode___25 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___22 {
	void (*fl_copy_lock)(struct file_lock___23 *, struct file_lock___23 *);
	void (*fl_release_private)(struct file_lock___23 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___22;

struct lock_manager_operations___22;

struct file_lock___23 {
	struct file_lock___23 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___23 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___22 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___22 *fl_ops;
	const struct lock_manager_operations___22 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___22 {
	int (*lm_compare_owner)(struct file_lock___23 *, struct file_lock___23 *);
	long unsigned int (*lm_owner_key)(struct file_lock___23 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___23 *);
	int (*lm_grant)(struct file_lock___23 *, int);
	bool (*lm_break)(struct file_lock___23 *);
	int (*lm_change)(struct file_lock___23 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___23 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___22 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___22 *fa_next;
	struct file___23 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___22 {
	const char *name;
	int fs_flags;
	struct dentry___24 * (*mount)(struct file_system_type___22 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___23 *);
	struct module___11 *owner;
	struct file_system_type___22 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___22 {
	struct inode___25 * (*alloc_inode)(struct super_block___23 *);
	void (*destroy_inode)(struct inode___25 *);
	void (*dirty_inode)(struct inode___25 *, int);
	int (*write_inode)(struct inode___25 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___25 *);
	void (*evict_inode)(struct inode___25 *);
	void (*put_super)(struct super_block___23 *);
	int (*sync_fs)(struct super_block___23 *, int);
	int (*freeze_super)(struct super_block___23 *);
	int (*freeze_fs)(struct super_block___23 *);
	int (*thaw_super)(struct super_block___23 *);
	int (*unfreeze_fs)(struct super_block___23 *);
	int (*statfs)(struct dentry___24 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___23 *, int *, char *);
	void (*umount_begin)(struct super_block___23 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___24 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___24 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___24 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___24 *);
	ssize_t (*quota_read)(struct super_block___23 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___23 *, int, const char *, size_t, loff_t);
	struct dquot___22 ** (*get_dquots)(struct inode___25 *);
	int (*bdev_try_to_free_page)(struct super_block___23 *, struct page___23 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___23 *, struct shrink_control___6 *);
	long int (*free_cached_objects)(struct super_block___23 *, struct shrink_control___6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___22(struct page___23 *);

typedef int (*key_restrict_link_func_t___22)(struct key___23 *, const struct key_type *, const union key_payload *, struct key___23 *);

struct key_restriction___23;

struct key___23 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___23 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___23 *restrict_link;
};

struct key_restriction___23 {
	key_restrict_link_func_t___22 check;
	struct key___23 *key;
	struct key_type *keytype;
};

struct module___22;

struct file___24;

struct kiocb___24;

struct iov_iter___9;

struct vm_area_struct___24;

struct inode___26;

struct file_lock___24;

struct page___24;

struct seq_file___21;

struct file_operations___24 {
	struct module___22 *owner;
	loff_t (*llseek)(struct file___24 *, loff_t, int);
	ssize_t (*read)(struct file___24 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___24 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___24 *, struct iov_iter___9 *);
	ssize_t (*write_iter)(struct kiocb___24 *, struct iov_iter___9 *);
	int (*iopoll)(struct kiocb___24 *, bool);
	int (*iterate)(struct file___24 *, struct dir_context *);
	int (*iterate_shared)(struct file___24 *, struct dir_context *);
	__poll_t (*poll)(struct file___24 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___24 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___24 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___24 *, struct vm_area_struct___24 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___26 *, struct file___24 *);
	int (*flush)(struct file___24 *, fl_owner_t);
	int (*release)(struct inode___26 *, struct file___24 *);
	int (*fsync)(struct file___24 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___24 *, int);
	int (*lock)(struct file___24 *, int, struct file_lock___24 *);
	ssize_t (*sendpage)(struct file___24 *, struct page___24 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___24 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___24 *, int, struct file_lock___24 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___24 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___24 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___24 *, long int, struct file_lock___24 **, void **);
	long int (*fallocate)(struct file___24 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___21 *, struct file___24 *);
	ssize_t (*copy_file_range)(struct file___24 *, loff_t, struct file___24 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___24 *, loff_t, struct file___24 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___24 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___23 {
	u64 seqnum;
	struct vm_area_struct___24 *vmas[4];
};

struct page_frag___23 {
	struct page___24 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___24;

struct mem_cgroup___7;

struct pid___21;

struct cred___23;

struct nsproxy___22;

struct signal_struct___22;

struct bio_list___8;

struct backing_dev_info___8;

struct css_set___13;

struct vm_struct___19;

struct task_struct___25 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___25 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___24 *mm;
	struct mm_struct___24 *active_mm;
	struct vmacache___23 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___25 *real_parent;
	struct task_struct___25 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___25 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___7 *active_memcg;
	long int rh_reserved2;
	struct pid___21 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___21 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___21 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___23 *ptracer_cred;
	const struct cred___23 *real_cred;
	const struct cred___23 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___22 *nsproxy;
	struct signal_struct___22 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___25 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___8 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___8 *backing_dev_info;
	struct io_context___2 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___13 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___23 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___7 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___25 *oom_reaper_list;
	struct vm_struct___19 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___11 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___21;

struct upid___21 {
	int nr;
	struct pid_namespace___21 *ns;
};

struct dentry___25;

struct user_namespace___14;

struct ucounts___14;

struct pid_namespace___21 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___25 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___21 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___25 *proc_self;
	struct dentry___25 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common ns;
};

struct pid___21 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___21 numbers[1];
};

struct rw_semaphore___24 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___25 *owner;
};

struct key___24;

struct user_namespace___14 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___14 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common ns;
	long unsigned int flags;
	struct key___24 *persistent_keyring_register;
	struct rw_semaphore___24 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___14 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct secondary_data___24 {
	void *stack;
	struct task_struct___25 *task;
	long int status;
};

typedef struct page___24 *pgtable_t___23;

struct address_space___23;

struct dev_pagemap___23;

struct page___24 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___23 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___24 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___23 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___24 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___23 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___7 *mem_cgroup;
};

struct user_struct___23 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___24 *uid_keyring;
	struct key___24 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___23;

struct vm_area_struct___24 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___24 *vm_next;
	struct vm_area_struct___24 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___24 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___23 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___24 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___23;

struct mm_struct___24 {
	struct {
		struct vm_area_struct___24 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___24 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___24 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___23 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___25 *owner;
		struct user_namespace___14 *user_ns;
		struct file___24 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___23 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup___13;

struct cgroup_subsys___13;

struct cgroup_subsys_state___13 {
	struct cgroup___13 *cgroup;
	struct cgroup_subsys___13 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___13 *parent;
};

struct kernfs_node___21;

struct cgroup_file___13 {
	struct kernfs_node___21 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___7;

struct mem_cgroup___7 {
	struct cgroup_subsys_state___13 css;
	struct mem_cgroup_id___5 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___13 events_file;
	struct cgroup_file___13 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___25 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___7 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cred___23 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___24 *session_keyring;
	struct key___24 *process_keyring;
	struct key___24 *thread_keyring;
	struct key___24 *request_key_auth;
	void *security;
	struct user_struct___23 *user;
	struct user_namespace___14 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___13;

struct nsproxy___22 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___21 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___13 *cgroup_ns;
};

struct signal_struct___22 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___25 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___25 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___21 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___21 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___24 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___21 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___8;

struct bio_list___8 {
	struct bio___8 *head;
	struct bio___8 *tail;
};

struct bdi_writeback_congested___8;

struct bdi_writeback___8 {
	struct backing_dev_info___8 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___8 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___13 *memcg_css;
	struct cgroup_subsys_state___13 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___19;

struct backing_dev_info___8 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___8 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___19 *dev;
	struct device___19 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___25 *debug_dir;
	struct dentry___25 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___13 {
	struct cgroup_subsys_state___13 *subsys[13];
	refcount_t refcount;
	struct css_set___13 *dom_cset;
	struct cgroup___13 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___13 *mg_src_cgrp;
	struct cgroup___13 *mg_dst_cgrp;
	struct css_set___13 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct vm_struct___19 {
	struct vm_struct___19 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___24 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___22 {
	struct task_struct___25 task;
	long unsigned int stack[8192];
};

typedef int (*key_restrict_link_func_t___23)(struct key___24 *, const struct key_type *, const union key_payload *, struct key___24 *);

struct key_restriction___24;

struct key___24 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___24 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___24 *restrict_link;
};

struct key_restriction___24 {
	key_restrict_link_func_t___23 check;
	struct key___24 *key;
	struct key_type *keytype;
};

struct pglist_data___23;

struct lruvec___23 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___23 *pgdat;
};

struct zone___23 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___23 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___23 {
	struct zone___23 *zone;
	int zone_idx;
};

struct zonelist___23 {
	struct zoneref___23 _zonerefs[25];
};

struct pglist_data___23 {
	struct zone___23 node_zones[3];
	struct zonelist___23 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___25 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___25 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___23 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___23 {
	struct rw_semaphore___24 rwsem;
	struct notifier_block *head;
};

struct address_space_operations___23;

struct address_space___23 {
	struct inode___26 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___24 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___23 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___23)(struct vm_area_struct___24 *, long unsigned int, const struct page___24 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___23)(struct page___24 *, void *);

struct dev_pagemap___23 {
	dev_page_fault_t___23 page_fault;
	dev_page_free_t___23 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___19 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___23 {
	struct vfsmount *mnt;
	struct dentry___25 *dentry;
};

struct fown_struct___21 {
	rwlock_t lock;
	struct pid___21 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___24 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___23 f_path;
	struct inode___26 *f_inode;
	const struct file_operations___24 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___21 f_owner;
	const struct cred___23 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___23 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___23;

struct vm_operations_struct___23 {
	void (*open)(struct vm_area_struct___24 *);
	void (*close)(struct vm_area_struct___24 *);
	int (*split)(struct vm_area_struct___24 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___24 *);
	vm_fault_t (*fault)(struct vm_fault___23 *);
	vm_fault_t (*huge_fault)(struct vm_fault___23 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___23 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___24 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___23 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___23 *);
	int (*access)(struct vm_area_struct___24 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___24 *);
	int (*set_policy)(struct vm_area_struct___24 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___24 *, long unsigned int);
	struct page___24 * (*find_special_page)(struct vm_area_struct___24 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___23 {
	struct task_struct___25 *task;
	struct core_thread___23 *next;
};

struct core_state___23 {
	atomic_t nr_threads;
	struct core_thread___23 dumper;
	struct completion startup;
};

struct vm_fault___23 {
	struct vm_area_struct___24 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___24 *cow_page;
	struct mem_cgroup___7 *memcg;
	struct page___24 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___23 prealloc_pte;
};

struct shrink_control___7 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___7 *memcg;
};

struct shrinker___7 {
	long unsigned int (*count_objects)(struct shrinker___7 *, struct shrink_control___7 *);
	long unsigned int (*scan_objects)(struct shrinker___7 *, struct shrink_control___7 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct kset___21;

struct kobj_type___21;

struct kobject___22 {
	const char *name;
	struct list_head entry;
	struct kobject___22 *parent;
	struct kset___21 *kset;
	struct kobj_type___21 *ktype;
	struct kernfs_node___21 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___19 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___19 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___19;

struct bus_type___19;

struct device_driver___19;

struct dev_pm_domain___19;

struct fwnode_handle___16;

struct class___19;

struct attribute_group___19;

struct device___19 {
	struct device___19 *parent;
	struct device_private *p;
	struct kobject___22 kobj;
	const char *init_name;
	const struct device_type___19 *type;
	struct mutex mutex;
	struct bus_type___19 *bus;
	struct device_driver___19 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___19 power;
	struct dev_pm_domain___19 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___16 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___19 *class;
	const struct attribute_group___19 **groups;
	void (*release)(struct device___19 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___23;

struct super_block___24;

struct dentry___25 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___25 *d_parent;
	struct qstr d_name;
	struct inode___26 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___23 *d_op;
	struct super_block___24 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___23;

struct block_device___24;

struct inode___26 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___23 *i_op;
	struct super_block___24 *i_sb;
	struct address_space___23 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___24 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___8 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___24 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___23 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___24 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___23 {
	int (*d_revalidate)(struct dentry___25 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___25 *, unsigned int);
	int (*d_hash)(const struct dentry___25 *, struct qstr *);
	int (*d_compare)(const struct dentry___25 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___25 *);
	int (*d_init)(struct dentry___25 *);
	void (*d_release)(struct dentry___25 *);
	void (*d_prune)(struct dentry___25 *);
	void (*d_iput)(struct dentry___25 *, struct inode___26 *);
	char * (*d_dname)(struct dentry___25 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___23 *);
	int (*d_manage)(const struct path___23 *, bool);
	struct dentry___25 * (*d_real)(struct dentry___25 *, const struct inode___26 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___23;

struct mem_dqinfo___23 {
	struct quota_format_type___23 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___23;

struct quota_info___23 {
	unsigned int flags;
	struct rw_semaphore___24 dqio_sem;
	struct inode___26 *files[3];
	struct mem_dqinfo___23 info[3];
	const struct quota_format_ops___23 *ops[3];
};

struct rcuwait___23 {
	struct task_struct___25 *task;
};

struct percpu_rw_semaphore___23 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___24 rw_sem;
	struct rcuwait___23 writer;
	int readers_block;
};

struct sb_writers___23 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___23 rw_sem[3];
};

struct file_system_type___23;

struct super_operations___23;

struct dquot_operations___23;

struct quotactl_ops___23;

struct super_block___24 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___23 *s_type;
	const struct super_operations___23 *s_op;
	const struct dquot_operations___23 *dq_op;
	const struct quotactl_ops___23 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___25 *s_root;
	struct rw_semaphore___24 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___24 *s_bdev;
	struct backing_dev_info___8 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___23 s_dquot;
	struct sb_writers___23 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___23 *s_d_op;
	int cleancache_poolid;
	struct shrinker___7 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___14 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___24 {
	struct file___24 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___24 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___24 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___24 *ia_file;
};

struct dquot___23 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___24 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___23 {
	int qf_fmt_id;
	const struct quota_format_ops___23 *qf_ops;
	struct module___22 *qf_owner;
	struct quota_format_type___23 *qf_next;
};

struct quota_format_ops___23 {
	int (*check_quota_file)(struct super_block___24 *, int);
	int (*read_file_info)(struct super_block___24 *, int);
	int (*write_file_info)(struct super_block___24 *, int);
	int (*free_file_info)(struct super_block___24 *, int);
	int (*read_dqblk)(struct dquot___23 *);
	int (*commit_dqblk)(struct dquot___23 *);
	int (*release_dqblk)(struct dquot___23 *);
	int (*get_next_id)(struct super_block___24 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___23 {
	int (*write_dquot)(struct dquot___23 *);
	struct dquot___23 * (*alloc_dquot)(struct super_block___24 *, int);
	void (*destroy_dquot)(struct dquot___23 *);
	int (*acquire_dquot)(struct dquot___23 *);
	int (*release_dquot)(struct dquot___23 *);
	int (*mark_dirty)(struct dquot___23 *);
	int (*write_info)(struct super_block___24 *, int);
	qsize_t * (*get_reserved_space)(struct inode___26 *);
	int (*get_projid)(struct inode___26 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___26 *, qsize_t *);
	int (*get_next_id)(struct super_block___24 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___23 {
	int (*quota_on)(struct super_block___24 *, int, int, const struct path___23 *);
	int (*quota_off)(struct super_block___24 *, int);
	int (*quota_enable)(struct super_block___24 *, unsigned int);
	int (*quota_disable)(struct super_block___24 *, unsigned int);
	int (*quota_sync)(struct super_block___24 *, int);
	int (*set_info)(struct super_block___24 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___24 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___24 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___24 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___24 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___24 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___19 {
	struct kobject___22 kobj;
	struct module___22 *mod;
	struct kobject___22 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___19 {
	struct module___22 *mod;
	struct latch_tree_node node;
};

struct module_layout___19 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___19 mtn;
};

struct module_attribute___19;

struct kernel_param___19;

struct module___22 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___19 mkobj;
	struct module_attribute___19 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___22 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___19 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___19 core_layout;
	struct module_layout___19 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___7;

struct swap_info_struct___5;

struct address_space_operations___23 {
	int (*writepage)(struct page___24 *, struct writeback_control___7 *);
	int (*readpage)(struct file___24 *, struct page___24 *);
	int (*writepages)(struct address_space___23 *, struct writeback_control___7 *);
	int (*set_page_dirty)(struct page___24 *);
	int (*readpages)(struct file___24 *, struct address_space___23 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___24 *, struct address_space___23 *, loff_t, unsigned int, unsigned int, struct page___24 **, void **);
	int (*write_end)(struct file___24 *, struct address_space___23 *, loff_t, unsigned int, unsigned int, struct page___24 *, void *);
	sector_t (*bmap)(struct address_space___23 *, sector_t);
	void (*invalidatepage)(struct page___24 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___24 *, gfp_t);
	void (*freepage)(struct page___24 *);
	ssize_t (*direct_IO)(struct kiocb___24 *, struct iov_iter___9 *);
	int (*migratepage)(struct address_space___23 *, struct page___24 *, struct page___24 *, enum migrate_mode);
	bool (*isolate_page)(struct page___24 *, isolate_mode_t);
	void (*putback_page)(struct page___24 *);
	int (*launder_page)(struct page___24 *);
	int (*is_partially_uptodate)(struct page___24 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___24 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___23 *, struct page___24 *);
	int (*swap_activate)(struct swap_info_struct___5 *, struct file___24 *, sector_t *);
	void (*swap_deactivate)(struct file___24 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___7 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___8 *wb;
	struct inode___26 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___8;

struct iov_iter___9 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___8 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct swap_info_struct___5 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___24 *bdev;
	struct file___24 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___24 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___26 *bd_inode;
	struct super_block___24 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___24 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___8 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___23 {
	struct dentry___25 * (*lookup)(struct inode___26 *, struct dentry___25 *, unsigned int);
	const char * (*get_link)(struct dentry___25 *, struct inode___26 *, struct delayed_call *);
	int (*permission)(struct inode___26 *, int);
	struct posix_acl * (*get_acl)(struct inode___26 *, int);
	int (*readlink)(struct dentry___25 *, char *, int);
	int (*create)(struct inode___26 *, struct dentry___25 *, umode_t, bool);
	int (*link)(struct dentry___25 *, struct inode___26 *, struct dentry___25 *);
	int (*unlink)(struct inode___26 *, struct dentry___25 *);
	int (*symlink)(struct inode___26 *, struct dentry___25 *, const char *);
	int (*mkdir)(struct inode___26 *, struct dentry___25 *, umode_t);
	int (*rmdir)(struct inode___26 *, struct dentry___25 *);
	int (*mknod)(struct inode___26 *, struct dentry___25 *, umode_t, dev_t);
	int (*rename)(struct inode___26 *, struct dentry___25 *, struct inode___26 *, struct dentry___25 *, unsigned int);
	int (*setattr)(struct dentry___25 *, struct iattr___24 *);
	int (*getattr)(const struct path___23 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___25 *, char *, size_t);
	int (*fiemap)(struct inode___26 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___26 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___26 *, struct dentry___25 *, struct file___24 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___26 *, struct dentry___25 *, umode_t);
	int (*set_acl)(struct inode___26 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___23 {
	void (*fl_copy_lock)(struct file_lock___24 *, struct file_lock___24 *);
	void (*fl_release_private)(struct file_lock___24 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___23;

struct lock_manager_operations___23;

struct file_lock___24 {
	struct file_lock___24 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___24 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___23 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___23 *fl_ops;
	const struct lock_manager_operations___23 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___23 {
	int (*lm_compare_owner)(struct file_lock___24 *, struct file_lock___24 *);
	long unsigned int (*lm_owner_key)(struct file_lock___24 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___24 *);
	int (*lm_grant)(struct file_lock___24 *, int);
	bool (*lm_break)(struct file_lock___24 *);
	int (*lm_change)(struct file_lock___24 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___24 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___23 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___23 *fa_next;
	struct file___24 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___23 {
	const char *name;
	int fs_flags;
	struct dentry___25 * (*mount)(struct file_system_type___23 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___24 *);
	struct module___22 *owner;
	struct file_system_type___23 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___23 {
	struct inode___26 * (*alloc_inode)(struct super_block___24 *);
	void (*destroy_inode)(struct inode___26 *);
	void (*dirty_inode)(struct inode___26 *, int);
	int (*write_inode)(struct inode___26 *, struct writeback_control___7 *);
	int (*drop_inode)(struct inode___26 *);
	void (*evict_inode)(struct inode___26 *);
	void (*put_super)(struct super_block___24 *);
	int (*sync_fs)(struct super_block___24 *, int);
	int (*freeze_super)(struct super_block___24 *);
	int (*freeze_fs)(struct super_block___24 *);
	int (*thaw_super)(struct super_block___24 *);
	int (*unfreeze_fs)(struct super_block___24 *);
	int (*statfs)(struct dentry___25 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___24 *, int *, char *);
	void (*umount_begin)(struct super_block___24 *);
	int (*show_options)(struct seq_file___21 *, struct dentry___25 *);
	int (*show_devname)(struct seq_file___21 *, struct dentry___25 *);
	int (*show_path)(struct seq_file___21 *, struct dentry___25 *);
	int (*show_stats)(struct seq_file___21 *, struct dentry___25 *);
	ssize_t (*quota_read)(struct super_block___24 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___24 *, int, const char *, size_t, loff_t);
	struct dquot___23 ** (*get_dquots)(struct inode___26 *);
	int (*bdev_try_to_free_page)(struct super_block___24 *, struct page___24 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___24 *, struct shrink_control___7 *);
	long int (*free_cached_objects)(struct super_block___24 *, struct shrink_control___7 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___18;

struct seq_file___21 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___18 *op;
	int poll_event;
	const struct file___24 *file;
	void *private;
};

typedef void bio_end_io_t___8(struct bio___8 *);

struct bio_vec___8 {
	struct page___24 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___8;

struct bio_set___8;

struct bio___8 {
	struct bio___8 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___8 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___8 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___8 *bi_io_vec;
	struct bio_set___8 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___8 bi_inline_vecs[0];
};

struct kobj_attribute___22 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___22 *, struct kobj_attribute___22 *, char *);
	ssize_t (*store)(struct kobject___22 *, struct kobj_attribute___22 *, const char *, size_t);
};

typedef void compound_page_dtor___23(struct page___24 *);

struct cgroup_namespace___13 {
	refcount_t count;
	struct ns_common ns;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	struct css_set___13 *root_cset;
};

struct ucounts___14 {
	struct hlist_node node;
	struct user_namespace___14 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct fwnode_operations___16;

struct fwnode_handle___16 {
	struct fwnode_handle___16 *secondary;
	const struct fwnode_operations___16 *ops;
};

struct fwnode_reference_args___16;

struct fwnode_endpoint___16;

struct fwnode_operations___16 {
	struct fwnode_handle___16 * (*get)(struct fwnode_handle___16 *);
	void (*put)(struct fwnode_handle___16 *);
	bool (*device_is_available)(const struct fwnode_handle___16 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___16 *, const struct device___19 *);
	bool (*property_present)(const struct fwnode_handle___16 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___16 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___16 *, const char *, const char **, size_t);
	struct fwnode_handle___16 * (*get_parent)(const struct fwnode_handle___16 *);
	struct fwnode_handle___16 * (*get_next_child_node)(const struct fwnode_handle___16 *, struct fwnode_handle___16 *);
	struct fwnode_handle___16 * (*get_named_child_node)(const struct fwnode_handle___16 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___16 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___16 *);
	struct fwnode_handle___16 * (*graph_get_next_endpoint)(const struct fwnode_handle___16 *, struct fwnode_handle___16 *);
	struct fwnode_handle___16 * (*graph_get_remote_endpoint)(const struct fwnode_handle___16 *);
	struct fwnode_handle___16 * (*graph_get_port_parent)(struct fwnode_handle___16 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___16 *, struct fwnode_endpoint___16 *);
};

struct fwnode_endpoint___16 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___16 *local_fwnode;
};

struct fwnode_reference_args___16 {
	struct fwnode_handle___16 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct kernfs_root___21;

struct kernfs_elem_dir___21 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___21 *root;
};

struct kernfs_syscall_ops___21;

struct kernfs_root___21 {
	struct kernfs_node___21 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___21 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___21 {
	struct kernfs_node___21 *target_kn;
};

struct kernfs_ops___21;

struct kernfs_elem_attr___21 {
	const struct kernfs_ops___21 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___21 *notify_next;
};

struct kernfs_node___21 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___21 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___21 dir;
		struct kernfs_elem_symlink___21 symlink;
		struct kernfs_elem_attr___21 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___21;

struct kernfs_ops___21 {
	int (*open)(struct kernfs_open_file___21 *);
	void (*release)(struct kernfs_open_file___21 *);
	int (*seq_show)(struct seq_file___21 *, void *);
	void * (*seq_start)(struct seq_file___21 *, loff_t *);
	void * (*seq_next)(struct seq_file___21 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___21 *, void *);
	ssize_t (*read)(struct kernfs_open_file___21 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___21 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___21 *, struct vm_area_struct___24 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___21 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___21 {
	int (*remount_fs)(struct kernfs_root___21 *, int *, char *);
	int (*show_options)(struct seq_file___21 *, struct kernfs_root___21 *);
	int (*mkdir)(struct kernfs_node___21 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___21 *);
	int (*rename)(struct kernfs_node___21 *, struct kernfs_node___21 *, const char *);
	int (*show_path)(struct seq_file___21 *, struct kernfs_node___21 *, struct kernfs_root___21 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___21 {
	struct kernfs_node___21 *kn;
	struct file___24 *file;
	struct seq_file___21 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___23 *vm_ops;
};

struct bin_attribute___19;

struct attribute_group___19 {
	const char *name;
	umode_t (*is_visible)(struct kobject___22 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___22 *, struct bin_attribute___19 *, int);
	struct attribute **attrs;
	struct bin_attribute___19 **bin_attrs;
};

struct bin_attribute___19 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___24 *, struct kobject___22 *, struct bin_attribute___19 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___24 *, struct kobject___22 *, struct bin_attribute___19 *, char *, loff_t, size_t);
	int (*mmap)(struct file___24 *, struct kobject___22 *, struct bin_attribute___19 *, struct vm_area_struct___24 *);
};

struct sysfs_ops___21 {
	ssize_t (*show)(struct kobject___22 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___22 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___21;

struct kset___21 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___22 kobj;
	const struct kset_uevent_ops___21 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___21 {
	void (*release)(struct kobject___22 *);
	const struct sysfs_ops___21 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___22 *);
	const void * (*namespace)(struct kobject___22 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___21 {
	int (* const filter)(struct kset___21 *, struct kobject___22 *);
	const char * (* const name)(struct kset___21 *, struct kobject___22 *);
	int (* const uevent)(struct kset___21 *, struct kobject___22 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___19 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___19 *);
	int (*get)(char *, const struct kernel_param___19 *);
	void (*free)(void *);
};

struct kparam_array___19;

struct kernel_param___19 {
	const char *name;
	struct module___22 *mod;
	const struct kernel_param_ops___19 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___19 *arr;
	};
};

struct kparam_array___19 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___19 *ops;
	void *elem;
};

struct module_attribute___19 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___19 *, struct module_kobject___19 *, char *);
	ssize_t (*store)(struct module_attribute___19 *, struct module_kobject___19 *, const char *, size_t);
	void (*setup)(struct module___22 *, const char *);
	int (*test)(struct module___22 *);
	void (*free)(struct module___22 *);
};

struct kimage___8;

typedef void *kexec_load_t___8(struct kimage___8 *, char *, long unsigned int, char *, long unsigned int, char *, long unsigned int);

struct kexec_file_ops___9 {
	kexec_probe_t *probe;
	kexec_load_t___8 *load;
	kexec_cleanup_t *cleanup;
};

struct kimage___8 {
	kimage_entry_t head;
	kimage_entry_t *entry;
	kimage_entry_t *last_entry;
	long unsigned int start;
	struct page___24 *control_code_page;
	struct page___24 *swap_page;
	void *vmcoreinfo_data_copy;
	long unsigned int nr_segments;
	struct kexec_segment segment[16];
	struct list_head control_pages;
	struct list_head dest_pages;
	struct list_head unusable_pages;
	long unsigned int control_page;
	unsigned int type: 1;
	unsigned int preserve_context: 1;
	unsigned int file_mode: 1;
	struct kimage_arch arch;
	void *kernel_buf;
	long unsigned int kernel_buf_len;
	void *initrd_buf;
	long unsigned int initrd_buf_len;
	char *cmdline_buf;
	long unsigned int cmdline_buf_len;
	const struct kexec_file_ops___9 *fops;
	void *image_loader_data;
	struct purgatory_info purgatory_info;
};

struct seq_operations___18 {
	void * (*start)(struct seq_file___21 *, loff_t *);
	void (*stop)(struct seq_file___21 *, void *);
	void * (*next)(struct seq_file___21 *, void *, loff_t *);
	int (*show)(struct seq_file___21 *, void *);
};

struct bpf_map___13;

struct bpf_map_ops___13 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___13 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___13 *, struct file___24 *);
	void (*map_free)(struct bpf_map___13 *);
	int (*map_get_next_key)(struct bpf_map___13 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___13 *);
	void * (*map_lookup_elem)(struct bpf_map___13 *, void *);
	int (*map_update_elem)(struct bpf_map___13 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___13 *, void *);
	int (*map_push_elem)(struct bpf_map___13 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___13 *, void *);
	int (*map_peek_elem)(struct bpf_map___13 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___13 *, struct file___24 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___13 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___13 *, void *, struct seq_file___21 *);
	int (*map_check_btf)(const struct bpf_map___13 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___13 {
	const struct bpf_map_ops___13 *ops;
	struct bpf_map___13 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___23 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___13;

typedef void (*kthread_work_func_t___13)(struct kthread_work___13 *);

struct kthread_worker___13;

struct kthread_work___13 {
	struct list_head node;
	kthread_work_func_t___13 func;
	struct kthread_worker___13 *worker;
	int canceling;
};

struct kthread_worker___13 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___25 *task;
	struct kthread_work___13 *current_work;
};

struct kthread_delayed_work___13 {
	struct kthread_work___13 work;
	struct timer_list timer;
};

struct psi_group___13 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___13 *poll_kworker;
	struct kthread_delayed_work___13 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___13;

struct cgroup_rstat_cpu___13;

struct cgroup___13 {
	struct cgroup_subsys_state___13 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___21 *kn;
	struct cgroup_file___13 procs_file;
	struct cgroup_file___13 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___13 *subsys[13];
	struct cgroup_root___13 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___13 *dom_cgrp;
	struct cgroup_rstat_cpu___13 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf bpf;
	atomic_t congestion_count;
	struct cgroup___13 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___13 psi;
	int ancestor_ids[0];
};

struct cftype___13;

struct cgroup_subsys___13 {
	struct cgroup_subsys_state___13 * (*css_alloc)(struct cgroup_subsys_state___13 *);
	int (*css_online)(struct cgroup_subsys_state___13 *);
	void (*css_offline)(struct cgroup_subsys_state___13 *);
	void (*css_released)(struct cgroup_subsys_state___13 *);
	void (*css_free)(struct cgroup_subsys_state___13 *);
	void (*css_reset)(struct cgroup_subsys_state___13 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___13 *, int);
	int (*css_extra_stat_show)(struct seq_file___21 *, struct cgroup_subsys_state___13 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___25 *);
	void (*cancel_fork)(struct task_struct___25 *);
	void (*fork)(struct task_struct___25 *);
	void (*exit)(struct task_struct___25 *);
	void (*free)(struct task_struct___25 *);
	void (*bind)(struct cgroup_subsys_state___13 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___13 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___13 *dfl_cftypes;
	struct cftype___13 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___13 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___13 *updated_children;
	struct cgroup___13 *updated_next;
};

struct cgroup_root___13 {
	struct kernfs_root___21 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___13 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___13 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___13 *ss;
	struct list_head node;
	struct kernfs_ops___21 *kf_ops;
	int (*open)(struct kernfs_open_file___21 *);
	void (*release)(struct kernfs_open_file___21 *);
	u64 (*read_u64)(struct cgroup_subsys_state___13 *, struct cftype___13 *);
	s64 (*read_s64)(struct cgroup_subsys_state___13 *, struct cftype___13 *);
	int (*seq_show)(struct seq_file___21 *, void *);
	void * (*seq_start)(struct seq_file___21 *, loff_t *);
	void * (*seq_next)(struct seq_file___21 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___21 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___13 *, struct cftype___13 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___13 *, struct cftype___13 *, s64);
	ssize_t (*write)(struct kernfs_open_file___21 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___21 *, struct poll_table_struct___6 *);
};

struct bdi_writeback_congested___8 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___8 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___8 {
	struct bio___8 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___8 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___8 bip_inline_vecs[0];
};

struct bio_set___8 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___8 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___7 {
	struct mem_cgroup___7 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___7 {
	struct lruvec___23 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___7 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___7 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct dev_pm_ops___19 {
	int (*prepare)(struct device___19 *);
	void (*complete)(struct device___19 *);
	int (*suspend)(struct device___19 *);
	int (*resume)(struct device___19 *);
	int (*freeze)(struct device___19 *);
	int (*thaw)(struct device___19 *);
	int (*poweroff)(struct device___19 *);
	int (*restore)(struct device___19 *);
	int (*suspend_late)(struct device___19 *);
	int (*resume_early)(struct device___19 *);
	int (*freeze_late)(struct device___19 *);
	int (*thaw_early)(struct device___19 *);
	int (*poweroff_late)(struct device___19 *);
	int (*restore_early)(struct device___19 *);
	int (*suspend_noirq)(struct device___19 *);
	int (*resume_noirq)(struct device___19 *);
	int (*freeze_noirq)(struct device___19 *);
	int (*thaw_noirq)(struct device___19 *);
	int (*poweroff_noirq)(struct device___19 *);
	int (*restore_noirq)(struct device___19 *);
	int (*runtime_suspend)(struct device___19 *);
	int (*runtime_resume)(struct device___19 *);
	int (*runtime_idle)(struct device___19 *);
};

struct dev_pm_domain___19 {
	struct dev_pm_ops___19 ops;
	void (*detach)(struct device___19 *, bool);
	int (*activate)(struct device___19 *);
	void (*sync)(struct device___19 *);
	void (*dismiss)(struct device___19 *);
};

struct bus_type___19 {
	const char *name;
	const char *dev_name;
	struct device___19 *dev_root;
	const struct attribute_group___19 **bus_groups;
	const struct attribute_group___19 **dev_groups;
	const struct attribute_group___19 **drv_groups;
	int (*match)(struct device___19 *, struct device_driver___19 *);
	int (*uevent)(struct device___19 *, struct kobj_uevent_env *);
	int (*probe)(struct device___19 *);
	int (*remove)(struct device___19 *);
	void (*shutdown)(struct device___19 *);
	int (*online)(struct device___19 *);
	int (*offline)(struct device___19 *);
	int (*suspend)(struct device___19 *, pm_message_t);
	int (*resume)(struct device___19 *);
	int (*num_vf)(struct device___19 *);
	int (*dma_configure)(struct device___19 *);
	const struct dev_pm_ops___19 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___19 {
	const char *name;
	struct bus_type___19 *bus;
	struct module___22 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___19 *);
	int (*remove)(struct device___19 *);
	void (*shutdown)(struct device___19 *);
	int (*suspend)(struct device___19 *, pm_message_t);
	int (*resume)(struct device___19 *);
	const struct attribute_group___19 **groups;
	const struct dev_pm_ops___19 *pm;
	void (*coredump)(struct device___19 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___19 {
	const char *name;
	const struct attribute_group___19 **groups;
	int (*uevent)(struct device___19 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___19 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___19 *);
	const struct dev_pm_ops___19 *pm;
};

struct class___19 {
	const char *name;
	struct module___22 *owner;
	const struct attribute_group___19 **class_groups;
	const struct attribute_group___19 **dev_groups;
	struct kobject___22 *dev_kobj;
	int (*dev_uevent)(struct device___19 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___19 *, umode_t *);
	void (*class_release)(struct class___19 *);
	void (*dev_release)(struct device___19 *);
	int (*shutdown_pre)(struct device___19 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___19 *);
	const struct dev_pm_ops___19 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___18 {
	struct device___19 dev;
};

struct page_change_data {
	pgprot_t set_mask;
	pgprot_t clear_mask;
};

struct file___25;

struct kiocb___25;

struct vm_area_struct___25;

struct inode___27;

struct file_lock___25;

struct page___25;

struct seq_file___22;

struct file_operations___25 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___25 *, loff_t, int);
	ssize_t (*read)(struct file___25 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___25 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___25 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___25 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___25 *, bool);
	int (*iterate)(struct file___25 *, struct dir_context *);
	int (*iterate_shared)(struct file___25 *, struct dir_context *);
	__poll_t (*poll)(struct file___25 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___25 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___25 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___25 *, struct vm_area_struct___25 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___27 *, struct file___25 *);
	int (*flush)(struct file___25 *, fl_owner_t);
	int (*release)(struct inode___27 *, struct file___25 *);
	int (*fsync)(struct file___25 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___25 *, int);
	int (*lock)(struct file___25 *, int, struct file_lock___25 *);
	ssize_t (*sendpage)(struct file___25 *, struct page___25 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___25 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___25 *, int, struct file_lock___25 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___25 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___25 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___25 *, long int, struct file_lock___25 **, void **);
	long int (*fallocate)(struct file___25 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___22 *, struct file___25 *);
	ssize_t (*copy_file_range)(struct file___25 *, loff_t, struct file___25 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___25 *, loff_t, struct file___25 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___25 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___24 {
	u64 seqnum;
	struct vm_area_struct___25 *vmas[4];
};

struct page_frag___24 {
	struct page___25 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___25;

struct mem_cgroup___8;

struct cred___24;

struct nsproxy___23;

struct bio_list___9;

struct backing_dev_info___9;

struct css_set___14;

struct task_struct___26 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___26 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___25 *mm;
	struct mm_struct___25 *active_mm;
	struct vmacache___24 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___26 *real_parent;
	struct task_struct___26 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___26 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___8 *active_memcg;
	long int rh_reserved2;
	struct pid___21 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___21 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___21 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___24 *ptracer_cred;
	const struct cred___24 *real_cred;
	const struct cred___24 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___23 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___26 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___9 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___9 *backing_dev_info;
	struct io_context___3 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___14 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___24 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___8 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___26 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___11 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___24;

struct super_block___25;

struct dentry___26 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___26 *d_parent;
	struct qstr d_name;
	struct inode___27 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___24 *d_op;
	struct super_block___25 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct rw_semaphore___25 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___26 *owner;
};

struct address_space_operations___24;

struct address_space___24 {
	struct inode___27 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___25 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___24 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___24;

struct bdi_writeback___9;

struct block_device___25;

struct inode___27 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___24 *i_op;
	struct super_block___25 *i_sb;
	struct address_space___24 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___25 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___9 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___25 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___24 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___25 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___24;

struct dentry_operations___24 {
	int (*d_revalidate)(struct dentry___26 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___26 *, unsigned int);
	int (*d_hash)(const struct dentry___26 *, struct qstr *);
	int (*d_compare)(const struct dentry___26 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___26 *);
	int (*d_init)(struct dentry___26 *);
	void (*d_release)(struct dentry___26 *);
	void (*d_prune)(struct dentry___26 *);
	void (*d_iput)(struct dentry___26 *, struct inode___27 *);
	char * (*d_dname)(struct dentry___26 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___24 *);
	int (*d_manage)(const struct path___24 *, bool);
	struct dentry___26 * (*d_real)(struct dentry___26 *, const struct inode___27 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___24;

struct mem_dqinfo___24 {
	struct quota_format_type___24 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___24;

struct quota_info___24 {
	unsigned int flags;
	struct rw_semaphore___25 dqio_sem;
	struct inode___27 *files[3];
	struct mem_dqinfo___24 info[3];
	const struct quota_format_ops___24 *ops[3];
};

struct rcuwait___24 {
	struct task_struct___26 *task;
};

struct percpu_rw_semaphore___24 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___25 rw_sem;
	struct rcuwait___24 writer;
	int readers_block;
};

struct sb_writers___24 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___24 rw_sem[3];
};

struct shrink_control___8;

struct shrinker___8 {
	long unsigned int (*count_objects)(struct shrinker___8 *, struct shrink_control___8 *);
	long unsigned int (*scan_objects)(struct shrinker___8 *, struct shrink_control___8 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___24;

struct super_operations___24;

struct dquot_operations___24;

struct quotactl_ops___24;

struct user_namespace___15;

struct super_block___25 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___24 *s_type;
	const struct super_operations___24 *s_op;
	const struct dquot_operations___24 *dq_op;
	const struct quotactl_ops___24 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___26 *s_root;
	struct rw_semaphore___25 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___25 *s_bdev;
	struct backing_dev_info___9 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___24 s_dquot;
	struct sb_writers___24 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___24 *s_d_op;
	int cleancache_poolid;
	struct shrinker___8 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___15 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct path___24 {
	struct vfsmount *mnt;
	struct dentry___26 *dentry;
};

struct key___25;

struct ucounts___15;

struct user_namespace___15 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___15 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___2 ns;
	long unsigned int flags;
	struct key___25 *persistent_keyring_register;
	struct rw_semaphore___25 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___15 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct shrink_control___8 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___8 *memcg;
};

struct cgroup___14;

struct cgroup_subsys___14;

struct cgroup_subsys_state___14 {
	struct cgroup___14 *cgroup;
	struct cgroup_subsys___14 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___14 *parent;
};

struct kernfs_node___22;

struct cgroup_file___14 {
	struct kernfs_node___22 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___8;

struct mem_cgroup___8 {
	struct cgroup_subsys_state___14 css;
	struct mem_cgroup_id___6 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___14 events_file;
	struct cgroup_file___14 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___26 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___8 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___25 *pgtable_t___24;

struct dev_pagemap___24;

struct page___25 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___24 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___25 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___24 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___25 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___24 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___8 *mem_cgroup;
};

struct pglist_data___24;

struct lruvec___24 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___24 *pgdat;
};

struct zone___24 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___24 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___24 {
	struct zone___24 *zone;
	int zone_idx;
};

struct zonelist___24 {
	struct zoneref___24 _zonerefs[25];
};

struct pglist_data___24 {
	struct zone___24 node_zones[3];
	struct zonelist___24 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___26 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___26 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___24 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___25 {
	void *stack;
	struct task_struct___26 *task;
	long int status;
};

struct blocking_notifier_head___24 {
	struct rw_semaphore___25 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___24;

struct vm_area_struct___25 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___25 *vm_next;
	struct vm_area_struct___25 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___25 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___24 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___25 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___24;

struct mm_struct___25 {
	struct {
		struct vm_area_struct___25 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___25 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___25 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___24 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___26 *owner;
		struct user_namespace___15 *user_ns;
		struct file___25 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___24 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___24)(struct vm_area_struct___25 *, long unsigned int, const struct page___25 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___24)(struct page___25 *, void *);

struct device___20;

struct dev_pagemap___24 {
	dev_page_fault_t___24 page_fault;
	dev_page_free_t___24 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___20 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct file___25 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___24 f_path;
	struct inode___27 *f_inode;
	const struct file_operations___25 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___2 f_owner;
	const struct cred___24 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___24 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___24;

struct vm_operations_struct___24 {
	void (*open)(struct vm_area_struct___25 *);
	void (*close)(struct vm_area_struct___25 *);
	int (*split)(struct vm_area_struct___25 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___25 *);
	vm_fault_t (*fault)(struct vm_fault___24 *);
	vm_fault_t (*huge_fault)(struct vm_fault___24 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___24 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___25 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___24 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___24 *);
	int (*access)(struct vm_area_struct___25 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___25 *);
	int (*set_policy)(struct vm_area_struct___25 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___25 *, long unsigned int);
	struct page___25 * (*find_special_page)(struct vm_area_struct___25 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___24 {
	struct task_struct___26 *task;
	struct core_thread___24 *next;
};

struct core_state___24 {
	atomic_t nr_threads;
	struct core_thread___24 dumper;
	struct completion startup;
};

struct vm_fault___24 {
	struct vm_area_struct___25 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___25 *cow_page;
	struct mem_cgroup___8 *memcg;
	struct page___25 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___24 prealloc_pte;
};

struct user_struct___24 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___25 *uid_keyring;
	struct key___25 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___24 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___25 *session_keyring;
	struct key___25 *process_keyring;
	struct key___25 *thread_keyring;
	struct key___25 *request_key_auth;
	void *security;
	struct user_struct___24 *user;
	struct user_namespace___15 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___14;

struct nsproxy___23 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___14 *cgroup_ns;
};

struct bio___9;

struct bio_list___9 {
	struct bio___9 *head;
	struct bio___9 *tail;
};

struct bdi_writeback_congested___9;

struct bdi_writeback___9 {
	struct backing_dev_info___9 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___9 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___14 *memcg_css;
	struct cgroup_subsys_state___14 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___9 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___9 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___20 *dev;
	struct device___20 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___26 *debug_dir;
	struct dentry___26 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___14 {
	struct cgroup_subsys_state___14 *subsys[13];
	refcount_t refcount;
	struct css_set___14 *dom_cset;
	struct cgroup___14 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___14 *mg_src_cgrp;
	struct cgroup___14 *mg_dst_cgrp;
	struct css_set___14 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct kiocb___25 {
	struct file___25 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___25 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___25 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___25 *ia_file;
};

struct dquot___24 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___25 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___24 {
	int qf_fmt_id;
	const struct quota_format_ops___24 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___24 *qf_next;
};

struct quota_format_ops___24 {
	int (*check_quota_file)(struct super_block___25 *, int);
	int (*read_file_info)(struct super_block___25 *, int);
	int (*write_file_info)(struct super_block___25 *, int);
	int (*free_file_info)(struct super_block___25 *, int);
	int (*read_dqblk)(struct dquot___24 *);
	int (*commit_dqblk)(struct dquot___24 *);
	int (*release_dqblk)(struct dquot___24 *);
	int (*get_next_id)(struct super_block___25 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___24 {
	int (*write_dquot)(struct dquot___24 *);
	struct dquot___24 * (*alloc_dquot)(struct super_block___25 *, int);
	void (*destroy_dquot)(struct dquot___24 *);
	int (*acquire_dquot)(struct dquot___24 *);
	int (*release_dquot)(struct dquot___24 *);
	int (*mark_dirty)(struct dquot___24 *);
	int (*write_info)(struct super_block___25 *, int);
	qsize_t * (*get_reserved_space)(struct inode___27 *);
	int (*get_projid)(struct inode___27 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___27 *, qsize_t *);
	int (*get_next_id)(struct super_block___25 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___24 {
	int (*quota_on)(struct super_block___25 *, int, int, const struct path___24 *);
	int (*quota_off)(struct super_block___25 *, int);
	int (*quota_enable)(struct super_block___25 *, unsigned int);
	int (*quota_disable)(struct super_block___25 *, unsigned int);
	int (*quota_sync)(struct super_block___25 *, int);
	int (*set_info)(struct super_block___25 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___25 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___25 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___25 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___25 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___25 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___8;

struct swap_info_struct___6;

struct address_space_operations___24 {
	int (*writepage)(struct page___25 *, struct writeback_control___8 *);
	int (*readpage)(struct file___25 *, struct page___25 *);
	int (*writepages)(struct address_space___24 *, struct writeback_control___8 *);
	int (*set_page_dirty)(struct page___25 *);
	int (*readpages)(struct file___25 *, struct address_space___24 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___25 *, struct address_space___24 *, loff_t, unsigned int, unsigned int, struct page___25 **, void **);
	int (*write_end)(struct file___25 *, struct address_space___24 *, loff_t, unsigned int, unsigned int, struct page___25 *, void *);
	sector_t (*bmap)(struct address_space___24 *, sector_t);
	void (*invalidatepage)(struct page___25 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___25 *, gfp_t);
	void (*freepage)(struct page___25 *);
	ssize_t (*direct_IO)(struct kiocb___25 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___24 *, struct page___25 *, struct page___25 *, enum migrate_mode);
	bool (*isolate_page)(struct page___25 *, isolate_mode_t);
	void (*putback_page)(struct page___25 *);
	int (*launder_page)(struct page___25 *);
	int (*is_partially_uptodate)(struct page___25 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___25 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___24 *, struct page___25 *);
	int (*swap_activate)(struct swap_info_struct___6 *, struct file___25 *, sector_t *);
	void (*swap_deactivate)(struct file___25 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___8 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___9 *wb;
	struct inode___27 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct swap_info_struct___6 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___25 *bdev;
	struct file___25 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___25 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___27 *bd_inode;
	struct super_block___25 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___25 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___9 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___24 {
	struct dentry___26 * (*lookup)(struct inode___27 *, struct dentry___26 *, unsigned int);
	const char * (*get_link)(struct dentry___26 *, struct inode___27 *, struct delayed_call *);
	int (*permission)(struct inode___27 *, int);
	struct posix_acl * (*get_acl)(struct inode___27 *, int);
	int (*readlink)(struct dentry___26 *, char *, int);
	int (*create)(struct inode___27 *, struct dentry___26 *, umode_t, bool);
	int (*link)(struct dentry___26 *, struct inode___27 *, struct dentry___26 *);
	int (*unlink)(struct inode___27 *, struct dentry___26 *);
	int (*symlink)(struct inode___27 *, struct dentry___26 *, const char *);
	int (*mkdir)(struct inode___27 *, struct dentry___26 *, umode_t);
	int (*rmdir)(struct inode___27 *, struct dentry___26 *);
	int (*mknod)(struct inode___27 *, struct dentry___26 *, umode_t, dev_t);
	int (*rename)(struct inode___27 *, struct dentry___26 *, struct inode___27 *, struct dentry___26 *, unsigned int);
	int (*setattr)(struct dentry___26 *, struct iattr___25 *);
	int (*getattr)(const struct path___24 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___26 *, char *, size_t);
	int (*fiemap)(struct inode___27 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___27 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___27 *, struct dentry___26 *, struct file___25 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___27 *, struct dentry___26 *, umode_t);
	int (*set_acl)(struct inode___27 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___24 {
	void (*fl_copy_lock)(struct file_lock___25 *, struct file_lock___25 *);
	void (*fl_release_private)(struct file_lock___25 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___24;

struct lock_manager_operations___24;

struct file_lock___25 {
	struct file_lock___25 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___25 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___24 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___24 *fl_ops;
	const struct lock_manager_operations___24 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___24 {
	int (*lm_compare_owner)(struct file_lock___25 *, struct file_lock___25 *);
	long unsigned int (*lm_owner_key)(struct file_lock___25 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___25 *);
	int (*lm_grant)(struct file_lock___25 *, int);
	bool (*lm_break)(struct file_lock___25 *);
	int (*lm_change)(struct file_lock___25 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___25 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___24 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___24 *fa_next;
	struct file___25 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___24 {
	const char *name;
	int fs_flags;
	struct dentry___26 * (*mount)(struct file_system_type___24 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___25 *);
	struct module___11 *owner;
	struct file_system_type___24 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___24 {
	struct inode___27 * (*alloc_inode)(struct super_block___25 *);
	void (*destroy_inode)(struct inode___27 *);
	void (*dirty_inode)(struct inode___27 *, int);
	int (*write_inode)(struct inode___27 *, struct writeback_control___8 *);
	int (*drop_inode)(struct inode___27 *);
	void (*evict_inode)(struct inode___27 *);
	void (*put_super)(struct super_block___25 *);
	int (*sync_fs)(struct super_block___25 *, int);
	int (*freeze_super)(struct super_block___25 *);
	int (*freeze_fs)(struct super_block___25 *);
	int (*thaw_super)(struct super_block___25 *);
	int (*unfreeze_fs)(struct super_block___25 *);
	int (*statfs)(struct dentry___26 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___25 *, int *, char *);
	void (*umount_begin)(struct super_block___25 *);
	int (*show_options)(struct seq_file___22 *, struct dentry___26 *);
	int (*show_devname)(struct seq_file___22 *, struct dentry___26 *);
	int (*show_path)(struct seq_file___22 *, struct dentry___26 *);
	int (*show_stats)(struct seq_file___22 *, struct dentry___26 *);
	ssize_t (*quota_read)(struct super_block___25 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___25 *, int, const char *, size_t, loff_t);
	struct dquot___24 ** (*get_dquots)(struct inode___27 *);
	int (*bdev_try_to_free_page)(struct super_block___25 *, struct page___25 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___25 *, struct shrink_control___8 *);
	long int (*free_cached_objects)(struct super_block___25 *, struct shrink_control___8 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___19;

struct seq_file___22 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___19 *op;
	int poll_event;
	const struct file___25 *file;
	void *private;
};

struct kset___22;

struct kobj_type___22;

struct kobject___23 {
	const char *name;
	struct list_head entry;
	struct kobject___23 *parent;
	struct kset___22 *kset;
	struct kobj_type___22 *ktype;
	struct kernfs_node___22 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___9(struct bio___9 *);

struct bio_vec___9 {
	struct page___25 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___9;

struct bio_set___9;

struct bio___9 {
	struct bio___9 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___9 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___9 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___9 *bi_io_vec;
	struct bio_set___9 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___9 bi_inline_vecs[0];
};

struct dev_pm_info___20 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___20 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___20;

struct bus_type___20;

struct device_driver___20;

struct dev_pm_domain___20;

struct class___20;

struct attribute_group___20;

struct device___20 {
	struct device___20 *parent;
	struct device_private *p;
	struct kobject___23 kobj;
	const char *init_name;
	const struct device_type___20 *type;
	struct mutex mutex;
	struct bus_type___20 *bus;
	struct device_driver___20 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___20 power;
	struct dev_pm_domain___20 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___20 *class;
	const struct attribute_group___20 **groups;
	void (*release)(struct device___20 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct kobj_attribute___23 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___23 *, struct kobj_attribute___23 *, char *);
	ssize_t (*store)(struct kobject___23 *, struct kobj_attribute___23 *, const char *, size_t);
};

typedef void compound_page_dtor___24(struct page___25 *);

typedef int (*key_restrict_link_func_t___24)(struct key___25 *, const struct key_type *, const union key_payload *, struct key___25 *);

struct key_restriction___25;

struct key___25 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___25 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___25 *restrict_link;
};

struct key_restriction___25 {
	key_restrict_link_func_t___24 check;
	struct key___25 *key;
	struct key_type *keytype;
};

struct seq_operations___19 {
	void * (*start)(struct seq_file___22 *, loff_t *);
	void (*stop)(struct seq_file___22 *, void *);
	void * (*next)(struct seq_file___22 *, void *, loff_t *);
	int (*show)(struct seq_file___22 *, void *);
};

struct kernfs_root___22;

struct kernfs_elem_dir___22 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___22 *root;
};

struct kernfs_syscall_ops___22;

struct kernfs_root___22 {
	struct kernfs_node___22 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___22 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___22 {
	struct kernfs_node___22 *target_kn;
};

struct kernfs_ops___22;

struct kernfs_elem_attr___22 {
	const struct kernfs_ops___22 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___22 *notify_next;
};

struct kernfs_node___22 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___22 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___22 dir;
		struct kernfs_elem_symlink___22 symlink;
		struct kernfs_elem_attr___22 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___22;

struct kernfs_ops___22 {
	int (*open)(struct kernfs_open_file___22 *);
	void (*release)(struct kernfs_open_file___22 *);
	int (*seq_show)(struct seq_file___22 *, void *);
	void * (*seq_start)(struct seq_file___22 *, loff_t *);
	void * (*seq_next)(struct seq_file___22 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___22 *, void *);
	ssize_t (*read)(struct kernfs_open_file___22 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___22 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___22 *, struct vm_area_struct___25 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___22 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___22 {
	int (*remount_fs)(struct kernfs_root___22 *, int *, char *);
	int (*show_options)(struct seq_file___22 *, struct kernfs_root___22 *);
	int (*mkdir)(struct kernfs_node___22 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___22 *);
	int (*rename)(struct kernfs_node___22 *, struct kernfs_node___22 *, const char *);
	int (*show_path)(struct seq_file___22 *, struct kernfs_node___22 *, struct kernfs_root___22 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___22 {
	struct kernfs_node___22 *kn;
	struct file___25 *file;
	struct seq_file___22 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___24 *vm_ops;
};

struct cgroup_namespace___14 {
	refcount_t count;
	struct ns_common___2 ns;
	struct user_namespace___15 *user_ns;
	struct ucounts___15 *ucounts;
	struct css_set___14 *root_cset;
};

struct ucounts___15 {
	struct hlist_node node;
	struct user_namespace___15 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___14;

struct bpf_map_ops___14 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___14 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___14 *, struct file___25 *);
	void (*map_free)(struct bpf_map___14 *);
	int (*map_get_next_key)(struct bpf_map___14 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___14 *);
	void * (*map_lookup_elem)(struct bpf_map___14 *, void *);
	int (*map_update_elem)(struct bpf_map___14 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___14 *, void *);
	int (*map_push_elem)(struct bpf_map___14 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___14 *, void *);
	int (*map_peek_elem)(struct bpf_map___14 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___14 *, struct file___25 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___14 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___14 *, void *, struct seq_file___22 *);
	int (*map_check_btf)(const struct bpf_map___14 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___14 {
	const struct bpf_map_ops___14 *ops;
	struct bpf_map___14 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___24 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___14;

typedef void (*kthread_work_func_t___14)(struct kthread_work___14 *);

struct kthread_worker___14;

struct kthread_work___14 {
	struct list_head node;
	kthread_work_func_t___14 func;
	struct kthread_worker___14 *worker;
	int canceling;
};

struct kthread_worker___14 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___26 *task;
	struct kthread_work___14 *current_work;
};

struct kthread_delayed_work___14 {
	struct kthread_work___14 work;
	struct timer_list timer;
};

struct psi_group___14 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___14 *poll_kworker;
	struct kthread_delayed_work___14 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___14;

struct cgroup_rstat_cpu___14;

struct cgroup___14 {
	struct cgroup_subsys_state___14 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___22 *kn;
	struct cgroup_file___14 procs_file;
	struct cgroup_file___14 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___14 *subsys[13];
	struct cgroup_root___14 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___14 *dom_cgrp;
	struct cgroup_rstat_cpu___14 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf bpf;
	atomic_t congestion_count;
	struct cgroup___14 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___14 psi;
	int ancestor_ids[0];
};

struct cftype___14;

struct cgroup_subsys___14 {
	struct cgroup_subsys_state___14 * (*css_alloc)(struct cgroup_subsys_state___14 *);
	int (*css_online)(struct cgroup_subsys_state___14 *);
	void (*css_offline)(struct cgroup_subsys_state___14 *);
	void (*css_released)(struct cgroup_subsys_state___14 *);
	void (*css_free)(struct cgroup_subsys_state___14 *);
	void (*css_reset)(struct cgroup_subsys_state___14 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___14 *, int);
	int (*css_extra_stat_show)(struct seq_file___22 *, struct cgroup_subsys_state___14 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___26 *);
	void (*cancel_fork)(struct task_struct___26 *);
	void (*fork)(struct task_struct___26 *);
	void (*exit)(struct task_struct___26 *);
	void (*free)(struct task_struct___26 *);
	void (*bind)(struct cgroup_subsys_state___14 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___14 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___14 *dfl_cftypes;
	struct cftype___14 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___14 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___14 *updated_children;
	struct cgroup___14 *updated_next;
};

struct cgroup_root___14 {
	struct kernfs_root___22 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___14 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___14 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___14 *ss;
	struct list_head node;
	struct kernfs_ops___22 *kf_ops;
	int (*open)(struct kernfs_open_file___22 *);
	void (*release)(struct kernfs_open_file___22 *);
	u64 (*read_u64)(struct cgroup_subsys_state___14 *, struct cftype___14 *);
	s64 (*read_s64)(struct cgroup_subsys_state___14 *, struct cftype___14 *);
	int (*seq_show)(struct seq_file___22 *, void *);
	void * (*seq_start)(struct seq_file___22 *, loff_t *);
	void * (*seq_next)(struct seq_file___22 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___22 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___14 *, struct cftype___14 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___14 *, struct cftype___14 *, s64);
	ssize_t (*write)(struct kernfs_open_file___22 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___22 *, struct poll_table_struct___6 *);
};

struct bin_attribute___20;

struct attribute_group___20 {
	const char *name;
	umode_t (*is_visible)(struct kobject___23 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___23 *, struct bin_attribute___20 *, int);
	struct attribute **attrs;
	struct bin_attribute___20 **bin_attrs;
};

struct hstate___2;

struct hugepage_subpool {
	spinlock_t lock;
	long int count;
	long int max_hpages;
	long int used_hpages;
	struct hstate___2 *hstate;
	long int min_hpages;
	long int rsv_hpages;
};

struct hstate___2 {
	int next_nid_to_alloc;
	int next_nid_to_free;
	unsigned int order;
	long unsigned int mask;
	long unsigned int max_huge_pages;
	long unsigned int nr_huge_pages;
	long unsigned int free_huge_pages;
	long unsigned int resv_huge_pages;
	long unsigned int surplus_huge_pages;
	long unsigned int nr_overcommit_huge_pages;
	struct list_head hugepage_activelist;
	struct list_head hugepage_freelists[8];
	unsigned int nr_huge_pages_node[8];
	unsigned int free_huge_pages_node[8];
	unsigned int surplus_huge_pages_node[8];
	struct cftype___14 cgroup_files[5];
	char name[32];
};

struct hugetlbfs_sb_info {
	long int max_inodes;
	long int free_inodes;
	spinlock_t stat_lock;
	struct hstate___2 *hstate;
	struct hugepage_subpool *spool;
	kuid_t uid;
	kgid_t gid;
	umode_t mode;
};

struct bdi_writeback_congested___9 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___9 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___9 {
	struct bio___9 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___9 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___9 bip_inline_vecs[0];
};

struct bio_set___9 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___9 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___8 {
	struct mem_cgroup___8 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___8 {
	struct lruvec___24 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___8 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___8 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct bin_attribute___20 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___25 *, struct kobject___23 *, struct bin_attribute___20 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___25 *, struct kobject___23 *, struct bin_attribute___20 *, char *, loff_t, size_t);
	int (*mmap)(struct file___25 *, struct kobject___23 *, struct bin_attribute___20 *, struct vm_area_struct___25 *);
};

struct sysfs_ops___22 {
	ssize_t (*show)(struct kobject___23 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___23 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___22;

struct kset___22 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___23 kobj;
	const struct kset_uevent_ops___22 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___22 {
	void (*release)(struct kobject___23 *);
	const struct sysfs_ops___22 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___23 *);
	const void * (*namespace)(struct kobject___23 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___22 {
	int (* const filter)(struct kset___22 *, struct kobject___23 *);
	const char * (* const name)(struct kset___22 *, struct kobject___23 *);
	int (* const uevent)(struct kset___22 *, struct kobject___23 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___20 {
	int (*prepare)(struct device___20 *);
	void (*complete)(struct device___20 *);
	int (*suspend)(struct device___20 *);
	int (*resume)(struct device___20 *);
	int (*freeze)(struct device___20 *);
	int (*thaw)(struct device___20 *);
	int (*poweroff)(struct device___20 *);
	int (*restore)(struct device___20 *);
	int (*suspend_late)(struct device___20 *);
	int (*resume_early)(struct device___20 *);
	int (*freeze_late)(struct device___20 *);
	int (*thaw_early)(struct device___20 *);
	int (*poweroff_late)(struct device___20 *);
	int (*restore_early)(struct device___20 *);
	int (*suspend_noirq)(struct device___20 *);
	int (*resume_noirq)(struct device___20 *);
	int (*freeze_noirq)(struct device___20 *);
	int (*thaw_noirq)(struct device___20 *);
	int (*poweroff_noirq)(struct device___20 *);
	int (*restore_noirq)(struct device___20 *);
	int (*runtime_suspend)(struct device___20 *);
	int (*runtime_resume)(struct device___20 *);
	int (*runtime_idle)(struct device___20 *);
};

struct dev_pm_domain___20 {
	struct dev_pm_ops___20 ops;
	void (*detach)(struct device___20 *, bool);
	int (*activate)(struct device___20 *);
	void (*sync)(struct device___20 *);
	void (*dismiss)(struct device___20 *);
};

struct bus_type___20 {
	const char *name;
	const char *dev_name;
	struct device___20 *dev_root;
	const struct attribute_group___20 **bus_groups;
	const struct attribute_group___20 **dev_groups;
	const struct attribute_group___20 **drv_groups;
	int (*match)(struct device___20 *, struct device_driver___20 *);
	int (*uevent)(struct device___20 *, struct kobj_uevent_env *);
	int (*probe)(struct device___20 *);
	int (*remove)(struct device___20 *);
	void (*shutdown)(struct device___20 *);
	int (*online)(struct device___20 *);
	int (*offline)(struct device___20 *);
	int (*suspend)(struct device___20 *, pm_message_t);
	int (*resume)(struct device___20 *);
	int (*num_vf)(struct device___20 *);
	int (*dma_configure)(struct device___20 *);
	const struct dev_pm_ops___20 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___20 {
	const char *name;
	struct bus_type___20 *bus;
	struct module___11 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___20 *);
	int (*remove)(struct device___20 *);
	void (*shutdown)(struct device___20 *);
	int (*suspend)(struct device___20 *, pm_message_t);
	int (*resume)(struct device___20 *);
	const struct attribute_group___20 **groups;
	const struct dev_pm_ops___20 *pm;
	void (*coredump)(struct device___20 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___20 {
	const char *name;
	const struct attribute_group___20 **groups;
	int (*uevent)(struct device___20 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___20 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___20 *);
	const struct dev_pm_ops___20 *pm;
};

struct class___20 {
	const char *name;
	struct module___11 *owner;
	const struct attribute_group___20 **class_groups;
	const struct attribute_group___20 **dev_groups;
	struct kobject___23 *dev_kobj;
	int (*dev_uevent)(struct device___20 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___20 *, umode_t *);
	void (*class_release)(struct class___20 *);
	void (*dev_release)(struct device___20 *);
	int (*shutdown_pre)(struct device___20 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___20 *);
	const struct dev_pm_ops___20 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___19 {
	struct device___20 dev;
};

enum {
	BPF_REG_0 = 0,
	BPF_REG_1 = 1,
	BPF_REG_2 = 2,
	BPF_REG_3 = 3,
	BPF_REG_4 = 4,
	BPF_REG_5 = 5,
	BPF_REG_6 = 6,
	BPF_REG_7 = 7,
	BPF_REG_8 = 8,
	BPF_REG_9 = 9,
	BPF_REG_10 = 10,
	__MAX_BPF_REG = 11,
};

struct module___23;

struct file___26;

struct kiocb___26;

struct iov_iter___10;

struct vm_area_struct___26;

struct inode___28;

struct file_lock___26;

struct page___26;

struct pipe_inode_info___3;

struct seq_file___23;

struct file_operations___26 {
	struct module___23 *owner;
	loff_t (*llseek)(struct file___26 *, loff_t, int);
	ssize_t (*read)(struct file___26 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___26 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___26 *, struct iov_iter___10 *);
	ssize_t (*write_iter)(struct kiocb___26 *, struct iov_iter___10 *);
	int (*iopoll)(struct kiocb___26 *, bool);
	int (*iterate)(struct file___26 *, struct dir_context *);
	int (*iterate_shared)(struct file___26 *, struct dir_context *);
	__poll_t (*poll)(struct file___26 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___26 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___26 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___26 *, struct vm_area_struct___26 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___28 *, struct file___26 *);
	int (*flush)(struct file___26 *, fl_owner_t);
	int (*release)(struct inode___28 *, struct file___26 *);
	int (*fsync)(struct file___26 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___26 *, int);
	int (*lock)(struct file___26 *, int, struct file_lock___26 *);
	ssize_t (*sendpage)(struct file___26 *, struct page___26 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___26 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___26 *, int, struct file_lock___26 *);
	ssize_t (*splice_write)(struct pipe_inode_info___3 *, struct file___26 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___26 *, loff_t *, struct pipe_inode_info___3 *, size_t, unsigned int);
	int (*setlease)(struct file___26 *, long int, struct file_lock___26 **, void **);
	long int (*fallocate)(struct file___26 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___23 *, struct file___26 *);
	ssize_t (*copy_file_range)(struct file___26 *, loff_t, struct file___26 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___26 *, loff_t, struct file___26 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___26 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

enum {
	DUMP_PREFIX_NONE = 0,
	DUMP_PREFIX_ADDRESS = 1,
	DUMP_PREFIX_OFFSET = 2,
};

struct vmacache___25 {
	u64 seqnum;
	struct vm_area_struct___26 *vmas[4];
};

struct page_frag___25 {
	struct page___26 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___26;

struct cred___25;

struct nsproxy___24;

struct signal_struct___23;

struct css_set___15;

struct vm_struct___20;

struct task_struct___27 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___27 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___26 *mm;
	struct mm_struct___26 *active_mm;
	struct vmacache___25 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___27 *real_parent;
	struct task_struct___27 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___27 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___3 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___3 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___3 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___25 *ptracer_cred;
	const struct cred___25 *real_cred;
	const struct cred___25 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___24 *nsproxy;
	struct signal_struct___23 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___27 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___3 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___15 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___3 *splice_pipe;
	struct page_frag___25 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___27 *oom_reaper_list;
	struct vm_struct___20 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___3 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct secondary_data___26 {
	void *stack;
	struct task_struct___27 *task;
	long int status;
};

struct dentry___27;

struct path___25 {
	struct vfsmount *mnt;
	struct dentry___27 *dentry;
};

struct address_space___25;

struct file___26 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___25 f_path;
	struct inode___28 *f_inode;
	const struct file_operations___26 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___2 f_owner;
	const struct cred___25 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___25 *f_mapping;
	errseq_t f_wb_err;
};

struct bpf_map___15;

struct bpf_map_ops___15 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___15 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___15 *, struct file___26 *);
	void (*map_free)(struct bpf_map___15 *);
	int (*map_get_next_key)(struct bpf_map___15 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___15 *);
	void * (*map_lookup_elem)(struct bpf_map___15 *, void *);
	int (*map_update_elem)(struct bpf_map___15 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___15 *, void *);
	int (*map_push_elem)(struct bpf_map___15 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___15 *, void *);
	int (*map_peek_elem)(struct bpf_map___15 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___15 *, struct file___26 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___15 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___15 *, void *, struct seq_file___23 *);
	int (*map_check_btf)(const struct bpf_map___15 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct user_struct___25;

struct bpf_map___15 {
	const struct bpf_map_ops___15 *ops;
	struct bpf_map___15 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___25 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct seq_operations___20;

struct seq_file___23 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___20 *op;
	int poll_event;
	const struct file___26 *file;
	void *private;
};

struct key___26;

struct user_struct___25 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___26 *uid_keyring;
	struct key___26 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bpf_offloaded_map___2;

struct bpf_map_dev_ops___2 {
	int (*map_get_next_key)(struct bpf_offloaded_map___2 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___2 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___2 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___2 *, void *);
};

struct net_device___5;

struct bpf_offloaded_map___2 {
	struct bpf_map___15 map;
	struct net_device___5 *netdev;
	const struct bpf_map_dev_ops___2 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___4;

typedef rx_handler_result_t rx_handler_func_t___2(struct sk_buff___4 **);

struct net___5;

typedef struct {
	struct net___5 *net;
} possible_net_t___2;

struct kset___23;

struct kobj_type___23;

struct kernfs_node___23;

struct kobject___24 {
	const char *name;
	struct list_head entry;
	struct kobject___24 *parent;
	struct kset___23 *kset;
	struct kobj_type___23 *ktype;
	struct kernfs_node___23 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___21;

struct dev_pm_info___21 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___21 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___21;

struct bus_type___21;

struct device_driver___21;

struct dev_pm_domain___21;

struct dma_map_ops___5;

struct fwnode_handle___17;

struct class___21;

struct attribute_group___21;

struct device___21 {
	struct device___21 *parent;
	struct device_private *p;
	struct kobject___24 kobj;
	const char *init_name;
	const struct device_type___21 *type;
	struct mutex mutex;
	struct bus_type___21 *bus;
	struct device_driver___21 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___21 power;
	struct dev_pm_domain___21 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___5 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___17 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___21 *class;
	const struct attribute_group___21 **groups;
	void (*release)(struct device___21 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct net_device_ops___2;

struct ethtool_ops___2;

struct l3mdev_ops___2;

struct ndisc_ops___2;

struct xfrmdev_ops___2;

struct tlsdev_ops___2;

struct header_ops___2;

struct inet6_dev___2;

struct netdev_rx_queue___2;

struct bpf_prog___2;

struct mini_Qdisc___2;

struct netdev_queue___2;

struct Qdisc___2;

struct rtnl_link_ops___2;

struct dcbnl_rtnl_ops___2;

struct net_device___5 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___2 *netdev_ops;
	const struct ethtool_ops___2 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___2 *l3mdev_ops;
	const struct ndisc_ops___2 *ndisc_ops;
	const struct xfrmdev_ops___2 *xfrmdev_ops;
	const struct tlsdev_ops___2 *tlsdev_ops;
	const struct header_ops___2 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___23 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___2 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___2 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___2 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___2 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___2 *miniq_ingress;
	struct netdev_queue___2 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___2 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___2 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___2 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___2 = 0,
		NETREG_REGISTERED___2 = 1,
		NETREG_UNREGISTERING___2 = 2,
		NETREG_UNREGISTERED___2 = 3,
		NETREG_RELEASED___2 = 4,
		NETREG_DUMMY___2 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___2 = 0,
		RTNL_LINK_INITIALIZING___2 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___5 *);
	struct netpoll_info *npinfo;
	possible_net_t___2 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___21 dev;
	const struct attribute_group___21 *sysfs_groups[4];
	const struct attribute_group___21 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___2 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___2 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide35;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct bpf_prog_ops___2 {
	int (*test_run)(struct bpf_prog___2 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_aux___2;

struct bpf_prog___2 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___2 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

struct bpf_verifier_ops___2 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___2 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___2 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___2 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___2 *, u32 *);
};

struct bpf_prog_offload_ops___2 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___2 *);
	int (*translate)(struct bpf_prog___2 *);
	void (*destroy)(struct bpf_prog___2 *);
};

struct bpf_prog_offload___2 {
	struct bpf_prog___2 *prog;
	struct net_device___5 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___2 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___2 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___2 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___2 *ops;
	struct bpf_map___15 **used_maps;
	struct bpf_prog___2 *prog;
	struct user_struct___25 *user;
	u64 load_time;
	struct bpf_map___15 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___2 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___2 {
	struct bpf_prog___2 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___2 {
	struct callback_head rcu;
	struct bpf_prog_array_item___2 items[0];
};

struct rw_semaphore___26 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___27 *owner;
};

struct ucounts___16;

struct user_namespace___16 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___16 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___2 ns;
	long unsigned int flags;
	struct key___26 *persistent_keyring_register;
	struct rw_semaphore___26 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___16 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___26 *pgtable_t___25;

struct dev_pagemap___25;

struct page___26 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___25 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___26 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___25 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___26 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___25 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___25;

struct lruvec___25 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___25 *pgdat;
};

struct zone___25 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___25 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___25 {
	struct zone___25 *zone;
	int zone_idx;
};

struct zonelist___25 {
	struct zoneref___25 _zonerefs[25];
};

struct pglist_data___25 {
	struct zone___25 node_zones[3];
	struct zonelist___25 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___27 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___27 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___25 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___25 {
	struct rw_semaphore___26 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___25;

struct vm_area_struct___26 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___26 *vm_next;
	struct vm_area_struct___26 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___26 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___25 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___26 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___25;

struct mm_struct___26 {
	struct {
		struct vm_area_struct___26 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___26 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___26 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___25 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___27 *owner;
		struct user_namespace___16 *user_ns;
		struct file___26 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___25 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___25 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___26 *session_keyring;
	struct key___26 *process_keyring;
	struct key___26 *thread_keyring;
	struct key___26 *request_key_auth;
	void *security;
	struct user_struct___25 *user;
	struct user_namespace___16 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___15;

struct nsproxy___24 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net___5 *net_ns;
	struct cgroup_namespace___15 *cgroup_ns;
};

struct signal_struct___23 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___27 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___27 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___3 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___3 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___26 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___3 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___15;

struct cgroup___15;

struct css_set___15 {
	struct cgroup_subsys_state___15 *subsys[13];
	refcount_t refcount;
	struct css_set___15 *dom_cset;
	struct cgroup___15 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___15 *mg_src_cgrp;
	struct cgroup___15 *mg_dst_cgrp;
	struct css_set___15 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___25;

struct pipe_buffer___3;

struct pipe_inode_info___3 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___26 *tmp_page;
	struct fasync_struct___25 *fasync_readers;
	struct fasync_struct___25 *fasync_writers;
	struct pipe_buffer___3 *bufs;
	struct user_struct___25 *user;
};

struct vm_struct___20 {
	struct vm_struct___20 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___26 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___23 {
	struct task_struct___27 task;
	long unsigned int stack[8192];
};

struct address_space_operations___25;

struct address_space___25 {
	struct inode___28 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___26 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___25 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___25)(struct vm_area_struct___26 *, long unsigned int, const struct page___26 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___25)(struct page___26 *, void *);

struct dev_pagemap___25 {
	dev_page_fault_t___25 page_fault;
	dev_page_free_t___25 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___21 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct vm_fault___25;

struct vm_operations_struct___25 {
	void (*open)(struct vm_area_struct___26 *);
	void (*close)(struct vm_area_struct___26 *);
	int (*split)(struct vm_area_struct___26 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___26 *);
	vm_fault_t (*fault)(struct vm_fault___25 *);
	vm_fault_t (*huge_fault)(struct vm_fault___25 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___25 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___26 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___25 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___25 *);
	int (*access)(struct vm_area_struct___26 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___26 *);
	int (*set_policy)(struct vm_area_struct___26 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___26 *, long unsigned int);
	struct page___26 * (*find_special_page)(struct vm_area_struct___26 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___25 {
	struct task_struct___27 *task;
	struct core_thread___25 *next;
};

struct core_state___25 {
	atomic_t nr_threads;
	struct core_thread___25 dumper;
	struct completion startup;
};

struct vm_fault___25 {
	struct vm_area_struct___26 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___26 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___26 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___25 prealloc_pte;
};

struct module_kobject___20 {
	struct kobject___24 kobj;
	struct module___23 *mod;
	struct kobject___24 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___20 {
	struct module___23 *mod;
	struct latch_tree_node node;
};

struct module_layout___20 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___20 mtn;
};

struct module_attribute___20;

struct kernel_param___20;

struct module___23 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___20 mkobj;
	struct module_attribute___20 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___24 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___20 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___20 core_layout;
	struct module_layout___20 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct iov_iter___10 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___3 *bvec;
		struct pipe_inode_info___3 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct kiocb___26 {
	struct file___26 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___26 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dentry_operations___25;

struct super_block___26;

struct dentry___27 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___27 *d_parent;
	struct qstr d_name;
	struct inode___28 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___25 *d_op;
	struct super_block___26 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___25;

struct block_device___26;

struct inode___28 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___25 *i_op;
	struct super_block___26 *i_sb;
	struct address_space___25 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___26 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___26 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___25 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___3 *i_pipe;
		struct block_device___26 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___25 {
	int (*d_revalidate)(struct dentry___27 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___27 *, unsigned int);
	int (*d_hash)(const struct dentry___27 *, struct qstr *);
	int (*d_compare)(const struct dentry___27 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___27 *);
	int (*d_init)(struct dentry___27 *);
	void (*d_release)(struct dentry___27 *);
	void (*d_prune)(struct dentry___27 *);
	void (*d_iput)(struct dentry___27 *, struct inode___28 *);
	char * (*d_dname)(struct dentry___27 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___25 *);
	int (*d_manage)(const struct path___25 *, bool);
	struct dentry___27 * (*d_real)(struct dentry___27 *, const struct inode___28 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___25;

struct mem_dqinfo___25 {
	struct quota_format_type___25 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___25;

struct quota_info___25 {
	unsigned int flags;
	struct rw_semaphore___26 dqio_sem;
	struct inode___28 *files[3];
	struct mem_dqinfo___25 info[3];
	const struct quota_format_ops___25 *ops[3];
};

struct rcuwait___25 {
	struct task_struct___27 *task;
};

struct percpu_rw_semaphore___25 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___26 rw_sem;
	struct rcuwait___25 writer;
	int readers_block;
};

struct sb_writers___25 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___25 rw_sem[3];
};

struct file_system_type___25;

struct super_operations___25;

struct dquot_operations___25;

struct quotactl_ops___25;

struct super_block___26 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___25 *s_type;
	const struct super_operations___25 *s_op;
	const struct dquot_operations___25 *dq_op;
	const struct quotactl_ops___25 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___27 *s_root;
	struct rw_semaphore___26 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___26 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___25 s_dquot;
	struct sb_writers___25 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___25 *s_d_op;
	int cleancache_poolid;
	struct shrinker___2 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___16 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct iattr___26 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___26 *ia_file;
};

struct dquot___25 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___26 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___25 {
	int qf_fmt_id;
	const struct quota_format_ops___25 *qf_ops;
	struct module___23 *qf_owner;
	struct quota_format_type___25 *qf_next;
};

struct quota_format_ops___25 {
	int (*check_quota_file)(struct super_block___26 *, int);
	int (*read_file_info)(struct super_block___26 *, int);
	int (*write_file_info)(struct super_block___26 *, int);
	int (*free_file_info)(struct super_block___26 *, int);
	int (*read_dqblk)(struct dquot___25 *);
	int (*commit_dqblk)(struct dquot___25 *);
	int (*release_dqblk)(struct dquot___25 *);
	int (*get_next_id)(struct super_block___26 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___25 {
	int (*write_dquot)(struct dquot___25 *);
	struct dquot___25 * (*alloc_dquot)(struct super_block___26 *, int);
	void (*destroy_dquot)(struct dquot___25 *);
	int (*acquire_dquot)(struct dquot___25 *);
	int (*release_dquot)(struct dquot___25 *);
	int (*mark_dirty)(struct dquot___25 *);
	int (*write_info)(struct super_block___26 *, int);
	qsize_t * (*get_reserved_space)(struct inode___28 *);
	int (*get_projid)(struct inode___28 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___28 *, qsize_t *);
	int (*get_next_id)(struct super_block___26 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___25 {
	int (*quota_on)(struct super_block___26 *, int, int, const struct path___25 *);
	int (*quota_off)(struct super_block___26 *, int);
	int (*quota_enable)(struct super_block___26 *, unsigned int);
	int (*quota_disable)(struct super_block___26 *, unsigned int);
	int (*quota_sync)(struct super_block___26 *, int);
	int (*set_info)(struct super_block___26 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___26 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___26 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___26 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___26 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___26 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___25 {
	int (*writepage)(struct page___26 *, struct writeback_control___3 *);
	int (*readpage)(struct file___26 *, struct page___26 *);
	int (*writepages)(struct address_space___25 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___26 *);
	int (*readpages)(struct file___26 *, struct address_space___25 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___26 *, struct address_space___25 *, loff_t, unsigned int, unsigned int, struct page___26 **, void **);
	int (*write_end)(struct file___26 *, struct address_space___25 *, loff_t, unsigned int, unsigned int, struct page___26 *, void *);
	sector_t (*bmap)(struct address_space___25 *, sector_t);
	void (*invalidatepage)(struct page___26 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___26 *, gfp_t);
	void (*freepage)(struct page___26 *);
	ssize_t (*direct_IO)(struct kiocb___26 *, struct iov_iter___10 *);
	int (*migratepage)(struct address_space___25 *, struct page___26 *, struct page___26 *, enum migrate_mode);
	bool (*isolate_page)(struct page___26 *, isolate_mode_t);
	void (*putback_page)(struct page___26 *);
	int (*launder_page)(struct page___26 *);
	int (*is_partially_uptodate)(struct page___26 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___26 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___25 *, struct page___26 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___26 *, sector_t *);
	void (*swap_deactivate)(struct file___26 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___26 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___28 *bd_inode;
	struct super_block___26 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___26 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___25 {
	struct dentry___27 * (*lookup)(struct inode___28 *, struct dentry___27 *, unsigned int);
	const char * (*get_link)(struct dentry___27 *, struct inode___28 *, struct delayed_call *);
	int (*permission)(struct inode___28 *, int);
	struct posix_acl * (*get_acl)(struct inode___28 *, int);
	int (*readlink)(struct dentry___27 *, char *, int);
	int (*create)(struct inode___28 *, struct dentry___27 *, umode_t, bool);
	int (*link)(struct dentry___27 *, struct inode___28 *, struct dentry___27 *);
	int (*unlink)(struct inode___28 *, struct dentry___27 *);
	int (*symlink)(struct inode___28 *, struct dentry___27 *, const char *);
	int (*mkdir)(struct inode___28 *, struct dentry___27 *, umode_t);
	int (*rmdir)(struct inode___28 *, struct dentry___27 *);
	int (*mknod)(struct inode___28 *, struct dentry___27 *, umode_t, dev_t);
	int (*rename)(struct inode___28 *, struct dentry___27 *, struct inode___28 *, struct dentry___27 *, unsigned int);
	int (*setattr)(struct dentry___27 *, struct iattr___26 *);
	int (*getattr)(const struct path___25 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___27 *, char *, size_t);
	int (*fiemap)(struct inode___28 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___28 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___28 *, struct dentry___27 *, struct file___26 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___28 *, struct dentry___27 *, umode_t);
	int (*set_acl)(struct inode___28 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___25 {
	void (*fl_copy_lock)(struct file_lock___26 *, struct file_lock___26 *);
	void (*fl_release_private)(struct file_lock___26 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___25;

struct file_lock___26 {
	struct file_lock___26 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___26 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___25 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___25 *fl_ops;
	const struct lock_manager_operations___25 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___25 {
	int (*lm_compare_owner)(struct file_lock___26 *, struct file_lock___26 *);
	long unsigned int (*lm_owner_key)(struct file_lock___26 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___26 *);
	int (*lm_grant)(struct file_lock___26 *, int);
	bool (*lm_break)(struct file_lock___26 *);
	int (*lm_change)(struct file_lock___26 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___26 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___25 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___25 *fa_next;
	struct file___26 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___25 {
	const char *name;
	int fs_flags;
	struct dentry___27 * (*mount)(struct file_system_type___25 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___26 *);
	struct module___23 *owner;
	struct file_system_type___25 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___25 {
	struct inode___28 * (*alloc_inode)(struct super_block___26 *);
	void (*destroy_inode)(struct inode___28 *);
	void (*dirty_inode)(struct inode___28 *, int);
	int (*write_inode)(struct inode___28 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___28 *);
	void (*evict_inode)(struct inode___28 *);
	void (*put_super)(struct super_block___26 *);
	int (*sync_fs)(struct super_block___26 *, int);
	int (*freeze_super)(struct super_block___26 *);
	int (*freeze_fs)(struct super_block___26 *);
	int (*thaw_super)(struct super_block___26 *);
	int (*unfreeze_fs)(struct super_block___26 *);
	int (*statfs)(struct dentry___27 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___26 *, int *, char *);
	void (*umount_begin)(struct super_block___26 *);
	int (*show_options)(struct seq_file___23 *, struct dentry___27 *);
	int (*show_devname)(struct seq_file___23 *, struct dentry___27 *);
	int (*show_path)(struct seq_file___23 *, struct dentry___27 *);
	int (*show_stats)(struct seq_file___23 *, struct dentry___27 *);
	ssize_t (*quota_read)(struct super_block___26 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___26 *, int, const char *, size_t, loff_t);
	struct dquot___25 ** (*get_dquots)(struct inode___28 *);
	int (*bdev_try_to_free_page)(struct super_block___26 *, struct page___26 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___26 *, struct shrink_control___2 *);
	long int (*free_cached_objects)(struct super_block___26 *, struct shrink_control___2 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct nf_bridge_info___2;

struct sk_buff___4 {
	union {
		struct {
			struct sk_buff___4 *next;
			struct sk_buff___4 *prev;
			union {
				struct net_device___5 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___4 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___2 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___2;

struct netns_frags___2 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___2 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv4___2 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct sock *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock **tcp_sk;
	struct netns_frags___2 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct dst_ops___4 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___4 *);
	struct dst_entry___2 * (*check)(struct dst_entry___2 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___2 *);
	unsigned int (*mtu)(const struct dst_entry___2 *);
	u32 * (*cow_metrics)(struct dst_entry___2 *, long unsigned int);
	void (*destroy)(struct dst_entry___2 *);
	void (*ifdown)(struct dst_entry___2 *, struct net_device___5 *, int);
	struct dst_entry___2 * (*negative_advice)(struct dst_entry___2 *);
	void (*link_failure)(struct sk_buff___4 *);
	void (*update_pmtu)(struct dst_entry___2 *, struct sock *, struct sk_buff___4 *, u32);
	void (*redirect)(struct dst_entry___2 *, struct sock *, struct sk_buff___4 *);
	int (*local_out)(struct net___5 *, struct sock *, struct sk_buff___4 *);
	struct neighbour___2 * (*neigh_lookup)(const struct dst_entry___2 *, struct sk_buff___4 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___2 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___3 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___2 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___4 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct sock *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops *notifier_ops;
	struct fib_notifier_ops *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_nf_frag___2 {
	struct netns_frags___2 frags;
};

struct netns_xfrm___3 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___4 xfrm4_dst_ops;
	struct dst_ops___4 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct net___5 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___16 *user_ns;
	struct ucounts___16 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___2 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___5 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___2 ipv4;
	struct netns_ipv6___3 ipv6;
	struct netns_sctp sctp;
	struct netns_nf nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___2 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock *nfnl;
	struct sock *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___3 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___2 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kernfs_root___23;

struct kernfs_elem_dir___23 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___23 *root;
};

struct kernfs_syscall_ops___23;

struct kernfs_root___23 {
	struct kernfs_node___23 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___23 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___23 {
	struct kernfs_node___23 *target_kn;
};

struct kernfs_ops___23;

struct kernfs_elem_attr___23 {
	const struct kernfs_ops___23 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___23 *notify_next;
};

struct kernfs_node___23 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___23 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___23 dir;
		struct kernfs_elem_symlink___23 symlink;
		struct kernfs_elem_attr___23 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___23;

struct kernfs_ops___23 {
	int (*open)(struct kernfs_open_file___23 *);
	void (*release)(struct kernfs_open_file___23 *);
	int (*seq_show)(struct seq_file___23 *, void *);
	void * (*seq_start)(struct seq_file___23 *, loff_t *);
	void * (*seq_next)(struct seq_file___23 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___23 *, void *);
	ssize_t (*read)(struct kernfs_open_file___23 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___23 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___23 *, struct vm_area_struct___26 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___23 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___23 {
	int (*remount_fs)(struct kernfs_root___23 *, int *, char *);
	int (*show_options)(struct seq_file___23 *, struct kernfs_root___23 *);
	int (*mkdir)(struct kernfs_node___23 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___23 *);
	int (*rename)(struct kernfs_node___23 *, struct kernfs_node___23 *, const char *);
	int (*show_path)(struct seq_file___23 *, struct kernfs_node___23 *, struct kernfs_root___23 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___23 {
	struct kernfs_node___23 *kn;
	struct file___26 *file;
	struct seq_file___23 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___25 *vm_ops;
};

struct bin_attribute___21;

struct attribute_group___21 {
	const char *name;
	umode_t (*is_visible)(struct kobject___24 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___24 *, struct bin_attribute___21 *, int);
	struct attribute **attrs;
	struct bin_attribute___21 **bin_attrs;
};

struct bin_attribute___21 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___26 *, struct kobject___24 *, struct bin_attribute___21 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___26 *, struct kobject___24 *, struct bin_attribute___21 *, char *, loff_t, size_t);
	int (*mmap)(struct file___26 *, struct kobject___24 *, struct bin_attribute___21 *, struct vm_area_struct___26 *);
};

struct sysfs_ops___23 {
	ssize_t (*show)(struct kobject___24 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___24 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___23;

struct kset___23 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___24 kobj;
	const struct kset_uevent_ops___23 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___23 {
	void (*release)(struct kobject___24 *);
	const struct sysfs_ops___23 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___24 *);
	const void * (*namespace)(struct kobject___24 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___23 {
	int (* const filter)(struct kset___23 *, struct kobject___24 *);
	const char * (* const name)(struct kset___23 *, struct kobject___24 *);
	int (* const uevent)(struct kset___23 *, struct kobject___24 *, struct kobj_uevent_env *);
};

struct kobj_attribute___24 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___24 *, struct kobj_attribute___24 *, char *);
	ssize_t (*store)(struct kobject___24 *, struct kobj_attribute___24 *, const char *, size_t);
};

struct dev_pm_ops___21 {
	int (*prepare)(struct device___21 *);
	void (*complete)(struct device___21 *);
	int (*suspend)(struct device___21 *);
	int (*resume)(struct device___21 *);
	int (*freeze)(struct device___21 *);
	int (*thaw)(struct device___21 *);
	int (*poweroff)(struct device___21 *);
	int (*restore)(struct device___21 *);
	int (*suspend_late)(struct device___21 *);
	int (*resume_early)(struct device___21 *);
	int (*freeze_late)(struct device___21 *);
	int (*thaw_early)(struct device___21 *);
	int (*poweroff_late)(struct device___21 *);
	int (*restore_early)(struct device___21 *);
	int (*suspend_noirq)(struct device___21 *);
	int (*resume_noirq)(struct device___21 *);
	int (*freeze_noirq)(struct device___21 *);
	int (*thaw_noirq)(struct device___21 *);
	int (*poweroff_noirq)(struct device___21 *);
	int (*restore_noirq)(struct device___21 *);
	int (*runtime_suspend)(struct device___21 *);
	int (*runtime_resume)(struct device___21 *);
	int (*runtime_idle)(struct device___21 *);
};

struct dev_pm_domain___21 {
	struct dev_pm_ops___21 ops;
	void (*detach)(struct device___21 *, bool);
	int (*activate)(struct device___21 *);
	void (*sync)(struct device___21 *);
	void (*dismiss)(struct device___21 *);
};

struct bus_type___21 {
	const char *name;
	const char *dev_name;
	struct device___21 *dev_root;
	const struct attribute_group___21 **bus_groups;
	const struct attribute_group___21 **dev_groups;
	const struct attribute_group___21 **drv_groups;
	int (*match)(struct device___21 *, struct device_driver___21 *);
	int (*uevent)(struct device___21 *, struct kobj_uevent_env *);
	int (*probe)(struct device___21 *);
	int (*remove)(struct device___21 *);
	void (*shutdown)(struct device___21 *);
	int (*online)(struct device___21 *);
	int (*offline)(struct device___21 *);
	int (*suspend)(struct device___21 *, pm_message_t);
	int (*resume)(struct device___21 *);
	int (*num_vf)(struct device___21 *);
	int (*dma_configure)(struct device___21 *);
	const struct dev_pm_ops___21 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___21 {
	const char *name;
	struct bus_type___21 *bus;
	struct module___23 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___21 *);
	int (*remove)(struct device___21 *);
	void (*shutdown)(struct device___21 *);
	int (*suspend)(struct device___21 *, pm_message_t);
	int (*resume)(struct device___21 *);
	const struct attribute_group___21 **groups;
	const struct dev_pm_ops___21 *pm;
	void (*coredump)(struct device___21 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___21 {
	const char *name;
	const struct attribute_group___21 **groups;
	int (*uevent)(struct device___21 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___21 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___21 *);
	const struct dev_pm_ops___21 *pm;
};

struct class___21 {
	const char *name;
	struct module___23 *owner;
	const struct attribute_group___21 **class_groups;
	const struct attribute_group___21 **dev_groups;
	struct kobject___24 *dev_kobj;
	int (*dev_uevent)(struct device___21 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___21 *, umode_t *);
	void (*class_release)(struct class___21 *);
	void (*dev_release)(struct device___21 *);
	int (*shutdown_pre)(struct device___21 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___21 *);
	const struct dev_pm_ops___21 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___5 {
	void * (*alloc)(struct device___21 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___21 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___21 *, struct vm_area_struct___26 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___21 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___21 *, struct page___26 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___21 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___21 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___21 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___21 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___21 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___21 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___21 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___21 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___21 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___21 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___21 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___21 *, u64);
	u64 (*get_required_mask)(struct device___21 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___17;

struct fwnode_handle___17 {
	struct fwnode_handle___17 *secondary;
	const struct fwnode_operations___17 *ops;
};

typedef void compound_page_dtor___25(struct page___26 *);

struct fwnode_reference_args___17;

struct fwnode_endpoint___17;

struct fwnode_operations___17 {
	struct fwnode_handle___17 * (*get)(struct fwnode_handle___17 *);
	void (*put)(struct fwnode_handle___17 *);
	bool (*device_is_available)(const struct fwnode_handle___17 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___17 *, const struct device___21 *);
	bool (*property_present)(const struct fwnode_handle___17 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___17 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___17 *, const char *, const char **, size_t);
	struct fwnode_handle___17 * (*get_parent)(const struct fwnode_handle___17 *);
	struct fwnode_handle___17 * (*get_next_child_node)(const struct fwnode_handle___17 *, struct fwnode_handle___17 *);
	struct fwnode_handle___17 * (*get_named_child_node)(const struct fwnode_handle___17 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___17 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___17 *);
	struct fwnode_handle___17 * (*graph_get_next_endpoint)(const struct fwnode_handle___17 *, struct fwnode_handle___17 *);
	struct fwnode_handle___17 * (*graph_get_remote_endpoint)(const struct fwnode_handle___17 *);
	struct fwnode_handle___17 * (*graph_get_port_parent)(struct fwnode_handle___17 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___17 *, struct fwnode_endpoint___17 *);
};

struct fwnode_endpoint___17 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___17 *local_fwnode;
};

struct fwnode_reference_args___17 {
	struct fwnode_handle___17 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___3;

struct pipe_buffer___3 {
	struct page___26 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___3 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___3 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___3 *, struct pipe_buffer___3 *);
	void (*release)(struct pipe_inode_info___3 *, struct pipe_buffer___3 *);
	int (*steal)(struct pipe_inode_info___3 *, struct pipe_buffer___3 *);
	union {
		bool (*get)(struct pipe_inode_info___3 *, struct pipe_buffer___3 *);
		struct {
			void (*get)(struct pipe_inode_info___3 *, struct pipe_buffer___3 *);
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
};

struct nf_bridge_info___2 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___2 = 0,
		BRNF_PROTO_8021Q___2 = 1,
		BRNF_PROTO_PPPOE___2 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___5 *physindev;
	struct net_device___5 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

struct sk_buff_head___2 {
	struct sk_buff___4 *next;
	struct sk_buff___4 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct kernel_param_ops___20 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___20 *);
	int (*get)(char *, const struct kernel_param___20 *);
	void (*free)(void *);
};

struct kparam_array___20;

struct kernel_param___20 {
	const char *name;
	struct module___23 *mod;
	const struct kernel_param_ops___20 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___20 *arr;
	};
};

struct kparam_array___20 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___20 *ops;
	void *elem;
};

struct module_attribute___20 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___20 *, struct module_kobject___20 *, char *);
	ssize_t (*store)(struct module_attribute___20 *, struct module_kobject___20 *, const char *, size_t);
	void (*setup)(struct module___23 *, const char *);
	int (*test)(struct module___23 *);
	void (*free)(struct module___23 *);
};

struct ethtool_ops___2 {
	int (*get_settings)(struct net_device___5 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___5 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___5 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___5 *);
	void (*get_regs)(struct net_device___5 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___5 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___5 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___5 *);
	void (*set_msglevel)(struct net_device___5 *, u32);
	int (*nway_reset)(struct net_device___5 *);
	u32 (*get_link)(struct net_device___5 *);
	int (*get_eeprom_len)(struct net_device___5 *);
	int (*get_eeprom)(struct net_device___5 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___5 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___5 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___5 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___5 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___5 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___5 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___5 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___5 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___5 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___5 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___5 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___5 *);
	void (*complete)(struct net_device___5 *);
	u32 (*get_priv_flags)(struct net_device___5 *);
	int (*set_priv_flags)(struct net_device___5 *, u32);
	int (*get_sset_count)(struct net_device___5 *, int);
	int (*get_rxnfc)(struct net_device___5 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___5 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___5 *, struct ethtool_flash *);
	int (*reset)(struct net_device___5 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___5 *);
	u32 (*get_rxfh_indir_size)(struct net_device___5 *);
	int (*get_rxfh)(struct net_device___5 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___5 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___5 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___5 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___5 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___5 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___5 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___5 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___5 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___5 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___5 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___5 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___5 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___5 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___5 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___5 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___5 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___5 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___5 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___5 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___5 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___5 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	int (*get_fecparam)(struct net_device___5 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___5 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___5 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___5 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___5 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___2;

struct inet_frags___2 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___2 *, const void *);
	void (*destructor)(struct inet_frag_queue___2 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___2 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___4 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___4 *fragments_tail;
	struct sk_buff___4 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___2 *net;
	struct callback_head rcu;
};

struct sk_buff_head___3 {
	struct sk_buff___3 *next;
	struct sk_buff___3 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct neigh_table___2;

struct neigh_parms___2;

struct neigh_ops___2;

struct neighbour___2 {
	struct neighbour___2 *next;
	struct neigh_table___2 *tbl;
	struct neigh_parms___2 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___3 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___2 *, struct sk_buff___3 *);
	const struct neigh_ops___2 *ops;
	struct callback_head rcu;
	struct net_device___4 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct ucounts___16 {
	struct hlist_node node;
	struct user_namespace___16 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

typedef int (*key_restrict_link_func_t___25)(struct key___26 *, const struct key_type *, const union key_payload *, struct key___26 *);

struct key_restriction___26;

struct key___26 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___26 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___26 *restrict_link;
};

struct key_restriction___26 {
	key_restrict_link_func_t___25 check;
	struct key___26 *key;
	struct key_type *keytype;
};

struct seq_operations___20 {
	void * (*start)(struct seq_file___23 *, loff_t *);
	void (*stop)(struct seq_file___23 *, void *);
	void * (*next)(struct seq_file___23 *, void *, loff_t *);
	int (*show)(struct seq_file___23 *, void *);
};

struct pernet_operations___2 {
	struct list_head list;
	int (*init)(struct net___5 *);
	void (*exit)(struct net___5 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___2 {
	int (*ieee_getets)(struct net_device___5 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___5 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___5 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___5 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___5 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___5 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___5 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___5 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___5 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___5 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___5 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___5 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___5 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___5 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___5 *);
	u8 (*setstate)(struct net_device___5 *, u8);
	void (*getpermhwaddr)(struct net_device___5 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___5 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___5 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___5 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___5 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___5 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___5 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___5 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___5 *, int, u8 *);
	void (*setpfccfg)(struct net_device___5 *, int, u8);
	void (*getpfccfg)(struct net_device___5 *, int, u8 *);
	u8 (*setall)(struct net_device___5 *);
	u8 (*getcap)(struct net_device___5 *, int, u8 *);
	int (*getnumtcs)(struct net_device___5 *, int, u8 *);
	int (*setnumtcs)(struct net_device___5 *, int, u8);
	u8 (*getpfcstate)(struct net_device___5 *);
	void (*setpfcstate)(struct net_device___5 *, u8);
	void (*getbcncfg)(struct net_device___5 *, int, u32 *);
	void (*setbcncfg)(struct net_device___5 *, int, u32);
	void (*getbcnrp)(struct net_device___5 *, int, u8 *);
	void (*setbcnrp)(struct net_device___5 *, int, u8);
	int (*setapp)(struct net_device___5 *, u8, u16, u8);
	int (*getapp)(struct net_device___5 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___5 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___5 *, int, u8);
	u8 (*getdcbx)(struct net_device___5 *);
	u8 (*setdcbx)(struct net_device___5 *, u8);
	int (*peer_getappinfo)(struct net_device___5 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___5 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___5 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___5 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___5 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___5 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___15 {
	refcount_t count;
	struct ns_common___2 ns;
	struct user_namespace___16 *user_ns;
	struct ucounts___16 *ucounts;
	struct css_set___15 *root_cset;
};

struct cgroup_bpf___2 {
	struct bpf_prog_array___2 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___2 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___15;

typedef void (*kthread_work_func_t___15)(struct kthread_work___15 *);

struct kthread_worker___15;

struct kthread_work___15 {
	struct list_head node;
	kthread_work_func_t___15 func;
	struct kthread_worker___15 *worker;
	int canceling;
};

struct kthread_worker___15 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___27 *task;
	struct kthread_work___15 *current_work;
};

struct kthread_delayed_work___15 {
	struct kthread_work___15 work;
	struct timer_list timer;
};

struct psi_group___15 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___15 *poll_kworker;
	struct kthread_delayed_work___15 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___15 {
	struct kernfs_node___23 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___15;

struct cgroup_subsys_state___15 {
	struct cgroup___15 *cgroup;
	struct cgroup_subsys___15 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___15 *parent;
};

struct cgroup_root___15;

struct cgroup_rstat_cpu___15;

struct cgroup___15 {
	struct cgroup_subsys_state___15 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___23 *kn;
	struct cgroup_file___15 procs_file;
	struct cgroup_file___15 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___15 *subsys[13];
	struct cgroup_root___15 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___15 *dom_cgrp;
	struct cgroup_rstat_cpu___15 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___2 bpf;
	atomic_t congestion_count;
	struct cgroup___15 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___15 psi;
	int ancestor_ids[0];
};

struct cftype___15;

struct cgroup_subsys___15 {
	struct cgroup_subsys_state___15 * (*css_alloc)(struct cgroup_subsys_state___15 *);
	int (*css_online)(struct cgroup_subsys_state___15 *);
	void (*css_offline)(struct cgroup_subsys_state___15 *);
	void (*css_released)(struct cgroup_subsys_state___15 *);
	void (*css_free)(struct cgroup_subsys_state___15 *);
	void (*css_reset)(struct cgroup_subsys_state___15 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___15 *, int);
	int (*css_extra_stat_show)(struct seq_file___23 *, struct cgroup_subsys_state___15 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___27 *);
	void (*cancel_fork)(struct task_struct___27 *);
	void (*fork)(struct task_struct___27 *);
	void (*exit)(struct task_struct___27 *);
	void (*free)(struct task_struct___27 *);
	void (*bind)(struct cgroup_subsys_state___15 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___15 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___15 *dfl_cftypes;
	struct cftype___15 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___15 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___15 *updated_children;
	struct cgroup___15 *updated_next;
};

struct cgroup_root___15 {
	struct kernfs_root___23 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___15 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___15 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___15 *ss;
	struct list_head node;
	struct kernfs_ops___23 *kf_ops;
	int (*open)(struct kernfs_open_file___23 *);
	void (*release)(struct kernfs_open_file___23 *);
	u64 (*read_u64)(struct cgroup_subsys_state___15 *, struct cftype___15 *);
	s64 (*read_s64)(struct cgroup_subsys_state___15 *, struct cftype___15 *);
	int (*seq_show)(struct seq_file___23 *, void *);
	void * (*seq_start)(struct seq_file___23 *, loff_t *);
	void * (*seq_next)(struct seq_file___23 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___23 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___15 *, struct cftype___15 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___15 *, struct cftype___15 *, s64);
	ssize_t (*write)(struct kernfs_open_file___23 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___23 *, struct poll_table_struct___6 *);
};

struct xdp_rxq_info___2 {
	struct net_device___5 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___2 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___5 *dev_rx;
};

struct netlink_callback___2 {
	struct sk_buff___4 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___2 *);
	int (*dump)(struct sk_buff___4 *, struct netlink_callback___2 *);
	int (*done)(struct netlink_callback___2 *);
	void *data;
	struct module___23 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___2 {
	int (*create)(struct sk_buff___4 *, struct net_device___5 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___4 *, unsigned char *);
	int (*cache)(const struct neighbour___2 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___5 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___2 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___2 *, int);
	int poll_owner;
	struct net_device___5 *dev;
	struct sk_buff___4 *gro_list;
	struct sk_buff___4 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___2 {
	struct net_device___5 *dev;
	struct Qdisc___2 *qdisc;
	struct Qdisc___2 *qdisc_sleeping;
	struct kobject___24 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___5 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___2 {
	struct sk_buff___4 *head;
	struct sk_buff___4 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___2;

struct Qdisc___2 {
	int (*enqueue)(struct sk_buff___4 *, struct Qdisc___2 *, struct sk_buff___4 **);
	struct sk_buff___4 * (*dequeue)(struct Qdisc___2 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___2 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___2 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___2 gso_skb;
	struct qdisc_skb_head___2 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___2 *next_sched;
	struct sk_buff_head___2 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___2 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___24 kobj;
	struct net_device___5 *dev;
	long: 64;
	struct xdp_rxq_info___2 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___2)(struct net_device___5 *, struct sk_buff___4 *, struct net_device___5 *);

struct netdev_bpf___2 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___2 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___2 *prog;
			const struct bpf_prog_offload_ops___2 *ops;
		} verifier;
		struct {
			struct bpf_prog___2 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___2 *offmap;
		};
		struct {
			struct xdp_umem *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___2 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___4 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___2 {
	int (*tls_dev_add)(struct net_device___5 *, struct sock *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___5 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___5 *, struct sock *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct neigh_parms___3;

struct net_device_ops___2 {
	int (*ndo_init)(struct net_device___5 *);
	void (*ndo_uninit)(struct net_device___5 *);
	int (*ndo_open)(struct net_device___5 *);
	int (*ndo_stop)(struct net_device___5 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___4 *, struct net_device___5 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___4 *, struct net_device___5 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___5 *, struct sk_buff___4 *, struct net_device___5 *, select_queue_fallback_t___2);
	void (*ndo_change_rx_flags)(struct net_device___5 *, int);
	void (*ndo_set_rx_mode)(struct net_device___5 *);
	int (*ndo_set_mac_address)(struct net_device___5 *, void *);
	int (*ndo_validate_addr)(struct net_device___5 *);
	int (*ndo_do_ioctl)(struct net_device___5 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___5 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___5 *, int);
	int (*ndo_neigh_setup)(struct net_device___5 *, struct neigh_parms___3 *);
	void (*ndo_tx_timeout)(struct net_device___5 *);
	void (*ndo_get_stats64)(struct net_device___5 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___5 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___5 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___5 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___5 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___5 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___5 *);
	int (*ndo_netpoll_setup)(struct net_device___5 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___5 *);
	int (*ndo_set_vf_mac)(struct net_device___5 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___5 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___5 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___5 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___5 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___5 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___5 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___5 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___5 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___5 *, int, struct sk_buff___4 *);
	int (*ndo_set_vf_guid)(struct net_device___5 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___5 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___5 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___5 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___5 *, const struct sk_buff___4 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___5 *, struct net_device___5 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___5 *, struct net_device___5 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___5 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___5 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___5 *, struct neighbour___2 *);
	void (*ndo_neigh_destroy)(struct net_device___5 *, struct neighbour___2 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___5 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___5 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___5 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___4 *, struct netlink_callback___2 *, struct net_device___5 *, struct net_device___5 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___5 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___5 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___4 *, u32, u32, struct net_device___5 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___5 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___5 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___5 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___5 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___5 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___5 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___5 *, struct net_device___5 *);
	void (*ndo_dfwd_del_station)(struct net_device___5 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___5 *);
	int (*ndo_set_tx_maxrate)(struct net_device___5 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___5 *);
	int (*ndo_change_proto_down)(struct net_device___5 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___5 *, struct sk_buff___4 *);
	void (*ndo_set_rx_headroom)(struct net_device___5 *, int);
	int (*ndo_bpf)(struct net_device___5 *, struct netdev_bpf___2 *);
	int (*ndo_xdp_xmit)(struct net_device___5 *, int, struct xdp_frame___2 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___5 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___5 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct net_device___6;

struct sk_buff___5;

struct sock___4;

struct dst_entry___3;

struct l3mdev_ops___2 {
	u32 (*l3mdev_fib_table)(const struct net_device___6 *);
	struct sk_buff___5 * (*l3mdev_l3_rcv)(struct net_device___6 *, struct sk_buff___5 *, u16);
	struct sk_buff___5 * (*l3mdev_l3_out)(struct net_device___6 *, struct sock___4 *, struct sk_buff___5 *, u16);
	struct dst_entry___3 * (*l3mdev_link_scope_lookup)(const struct net_device___6 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct net_device___7;

struct neighbour___3;

struct sk_buff___6;

struct net___6;

struct ndisc_ops___2 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___7 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___7 *, struct neighbour___3 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___7 *, u8, struct neighbour___3 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___7 *, struct sk_buff___6 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___6 *, struct net_device___7 *, const struct prefix_info *, struct inet6_dev___2 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct tcf_proto___2;

struct mini_Qdisc___2 {
	struct tcf_proto___2 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___2 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___5 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___5 *, struct net_device___5 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___5 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___5 *, struct list_head *);
	size_t (*get_size)(const struct net_device___5 *);
	int (*fill_info)(struct sk_buff___4 *, const struct net_device___5 *);
	size_t (*get_xstats_size)(const struct net_device___5 *);
	int (*fill_xstats)(struct sk_buff___4 *, const struct net_device___5 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___5 *, struct net_device___5 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___5 *, const struct net_device___5 *);
	int (*fill_slave_info)(struct sk_buff___4 *, const struct net_device___5 *, const struct net_device___5 *);
	struct net___5 * (*get_link_net)(const struct net_device___5 *);
	size_t (*get_linkxstats_size)(const struct net_device___5 *, int);
	int (*fill_linkxstats)(struct sk_buff___4 *, const struct net_device___5 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___2 {
	struct list_head poll_list;
	struct sk_buff_head___2 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___2 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___2 *output_queue;
	struct Qdisc___2 **output_queue_tailp;
	struct sk_buff___4 *completion_queue;
	struct sk_buff_head___2 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___2 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___2 input_pkt_queue;
	struct napi_struct___2 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct gnet_dump___2 {
	spinlock_t *lock;
	struct sk_buff___4 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___2;

struct Qdisc_ops___2 {
	struct Qdisc_ops___2 *next;
	const struct Qdisc_class_ops___2 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___4 *, struct Qdisc___2 *, struct sk_buff___4 **);
	struct sk_buff___4 * (*dequeue)(struct Qdisc___2 *);
	struct sk_buff___4 * (*peek)(struct Qdisc___2 *);
	int (*init)(struct Qdisc___2 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___2 *);
	void (*destroy)(struct Qdisc___2 *);
	int (*change)(struct Qdisc___2 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___2 *);
	int (*change_tx_queue_len)(struct Qdisc___2 *, unsigned int);
	int (*dump)(struct Qdisc___2 *, struct sk_buff___4 *);
	int (*dump_stats)(struct Qdisc___2 *, struct gnet_dump___2 *);
	void (*ingress_block_set)(struct Qdisc___2 *, u32);
	void (*egress_block_set)(struct Qdisc___2 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___2 *);
	u32 (*egress_block_get)(struct Qdisc___2 *);
	struct module___23 *owner;
};

struct tcf_block___2;

struct Qdisc_class_ops___2 {
	unsigned int flags;
	struct netdev_queue___2 * (*select_queue)(struct Qdisc___2 *, struct tcmsg *);
	int (*graft)(struct Qdisc___2 *, long unsigned int, struct Qdisc___2 *, struct Qdisc___2 **, struct netlink_ext_ack *);
	struct Qdisc___2 * (*leaf)(struct Qdisc___2 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___2 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___2 *, u32);
	int (*change)(struct Qdisc___2 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___2 *, long unsigned int);
	void (*walk)(struct Qdisc___2 *, struct qdisc_walker *);
	struct tcf_block___2 * (*tcf_block)(struct Qdisc___2 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___2 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___2 *, long unsigned int);
	int (*dump)(struct Qdisc___2 *, long unsigned int, struct sk_buff___4 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___2 *, long unsigned int, struct gnet_dump___2 *);
};

struct tcf_chain___2;

struct tcf_block___2 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___5 *net;
	struct Qdisc___2 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___2 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___2;

struct tcf_proto_ops___2;

struct tcf_proto___2 {
	struct tcf_proto___2 *next;
	void *root;
	int (*classify)(struct sk_buff___4 *, const struct tcf_proto___2 *, struct tcf_result___2 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___2 *ops;
	struct tcf_chain___2 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___2 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___2 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___2 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___4 *, const struct tcf_proto___2 *, struct tcf_result___2 *);
	int (*init)(struct tcf_proto___2 *);
	void (*destroy)(struct tcf_proto___2 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___2 *, u32);
	void (*put)(struct tcf_proto___2 *, void *);
	int (*change)(struct net___5 *, struct sk_buff___4 *, struct tcf_proto___2 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___2 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___2 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___2 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___5 *, struct tcf_chain___2 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___5 *, struct tcf_proto___2 *, void *, struct sk_buff___4 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___4 *, struct net___5 *, void *);
	struct module___23 *owner;
	int flags;
};

struct tcf_chain___2 {
	struct mutex filter_chain_lock;
	struct tcf_proto___2 *filter_chain;
	struct list_head list;
	struct tcf_block___2 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___2 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct bpf_binary_header {
	u32 pages;
	u8 image[0];
};

struct bpf_redirect_info___2 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___15 *map;
	struct bpf_map___15 *map_to_flush;
	u32 kern_flags;
};

struct jit_ctx {
	const struct bpf_prog___2 *prog;
	int idx;
	int epilogue_offset;
	int *offset;
	__le32 *image;
	u32 stack_size;
};

struct arm64_jit_data {
	struct bpf_binary_header *header;
	u8 *image;
	struct jit_ctx ctx;
};

typedef u64 hfn_t;

typedef hfn_t kvm_pfn_t;

struct gfn_to_hva_cache {
	u64 generation;
	gpa_t gpa;
	long unsigned int hva;
	long unsigned int len;
	struct kvm_memory_slot *memslot;
};

struct kvm_vcpu___3;

struct kvm_io_device___2;

struct kvm_io_device_ops___2 {
	int (*read)(struct kvm_vcpu___3 *, struct kvm_io_device___2 *, gpa_t, int, void *);
	int (*write)(struct kvm_vcpu___3 *, struct kvm_io_device___2 *, gpa_t, int, const void *);
	void (*destructor)(struct kvm_io_device___2 *);
};

struct preempt_ops___2;

struct preempt_notifier___2 {
	struct hlist_node link;
	struct preempt_ops___2 *ops;
};

struct kvm_cpu_context___2 {
	struct kvm_regs gp_regs;
	union {
		u64 sys_regs[101];
		u32 copro[202];
	};
	struct kvm_vcpu___3 *__hyp_running_vcpu;
};

typedef struct kvm_cpu_context___2 kvm_cpu_context_t___2;

struct page___27;

struct its_vm___2;

struct its_vpe___2 {
	struct page___27 *vpt_page;
	struct its_vm___2 *its_vm;
	int irq;
	irq_hw_number_t vpe_db_lpi;
	int vpe_proxy_event;
	u16 col_idx;
	u16 vpe_id;
	bool idai;
	bool pending_last;
};

struct vgic_v3_cpu_if___2 {
	u32 vgic_hcr;
	u32 vgic_vmcr;
	u32 vgic_sre;
	u32 vgic_ap0r[4];
	u32 vgic_ap1r[4];
	u64 vgic_lr[16];
	struct its_vpe___2 its_vpe;
};

struct vgic_irq___2 {
	raw_spinlock_t irq_lock;
	struct list_head lpi_list;
	struct list_head ap_list;
	struct kvm_vcpu___3 *vcpu;
	struct kvm_vcpu___3 *target_vcpu;
	u32 intid;
	bool line_level;
	bool pending_latch;
	bool active;
	bool enabled;
	bool hw;
	struct kref refcount;
	u32 hwintid;
	unsigned int host_irq;
	union {
		u8 targets;
		u32 mpidr;
	};
	u8 source;
	u8 active_source;
	u8 priority;
	u8 group;
	enum vgic_irq_config config;
	bool (*get_input_level)(int);
	void *owner;
};

struct kvm_io_device___2 {
	const struct kvm_io_device_ops___2 *ops;
};

struct vgic_its___3;

struct vgic_io_device___2 {
	gpa_t base_addr;
	union {
		struct kvm_vcpu___3 *redist_vcpu;
		struct vgic_its___3 *its;
	};
	const struct vgic_register_region *regions;
	enum iodev_type iodev_type;
	int nr_regions;
	struct kvm_io_device___2 dev;
};

struct vgic_cpu___2 {
	union {
		struct vgic_v2_cpu_if vgic_v2;
		struct vgic_v3_cpu_if___2 vgic_v3;
	};
	unsigned int used_lrs;
	struct vgic_irq___2 private_irqs[32];
	raw_spinlock_t ap_list_lock;
	struct list_head ap_list_head;
	struct vgic_io_device___2 rd_iodev;
	struct vgic_io_device___2 sgi_iodev;
	struct vgic_redist_region *rdreg;
	u64 pendbaser;
	bool lpis_enabled;
	u32 num_pri_bits;
	u32 num_id_bits;
};

struct arch_timer_context___2 {
	struct kvm_vcpu___3 *vcpu;
	u32 cnt_ctl;
	u64 cnt_cval;
	struct kvm_irq_level irq;
	u64 cntvoff;
	struct hrtimer hrtimer;
	bool loaded;
	u32 host_timer_irq;
	u32 host_timer_irq_flags;
};

struct arch_timer_cpu___2 {
	struct arch_timer_context___2 timers[2];
	struct hrtimer bg_timer;
	bool enabled;
};

struct perf_event___12;

struct kvm_pmc___2 {
	u8 idx;
	struct perf_event___12 *perf_event;
	u64 bitmask;
};

struct kvm_pmu___2 {
	int irq_num;
	struct kvm_pmc___2 pmc[32];
	bool ready;
	bool created;
	bool irq_level;
};

struct kvm_vcpu_arch___2 {
	struct kvm_cpu_context___2 ctxt;
	void *sve_state;
	unsigned int sve_max_vl;
	u64 hcr_el2;
	u32 mdcr_el2;
	struct kvm_vcpu_fault_info fault;
	u64 workaround_flags;
	u64 flags;
	struct kvm_guest_debug_arch *debug_ptr;
	struct kvm_guest_debug_arch vcpu_debug_state;
	struct kvm_guest_debug_arch external_debug_state;
	kvm_cpu_context_t___2 *host_cpu_context;
	struct thread_info *host_thread_info;
	struct user_fpsimd_state *host_fpsimd_state;
	struct {
		struct kvm_guest_debug_arch regs;
		u64 pmscr_el1;
	} host_debug_state;
	struct vgic_cpu___2 vgic_cpu;
	struct arch_timer_cpu___2 timer_cpu;
	struct kvm_pmu___2 pmu;
	struct {
		u32 mdscr_el1;
	} guest_debug_preserved;
	bool power_off;
	bool pause;
	struct kvm_decode mmio_decode;
	struct kvm_mmu_memory_cache mmu_page_cache;
	int target;
	long unsigned int features[1];
	bool has_run_once;
	u64 vsesr_el2;
	struct vcpu_reset_state reset_state;
	bool sysregs_loaded_on_cpu;
};

struct kvm___3;

struct pid___22;

struct dentry___28;

struct kvm_vcpu___3 {
	struct kvm___3 *kvm;
	struct preempt_notifier___2 preempt_notifier;
	int cpu;
	int vcpu_id;
	int srcu_idx;
	int mode;
	u64 requests;
	long unsigned int guest_debug;
	int pre_pcpu;
	struct list_head blocked_vcpu_list;
	struct mutex mutex;
	struct kvm_run *run;
	int guest_xcr0_loaded;
	struct swait_queue_head wq;
	struct pid___22 *pid;
	int sigset_active;
	sigset_t sigset;
	struct kvm_vcpu_stat stat;
	unsigned int halt_poll_ns;
	bool valid_wakeup;
	int mmio_needed;
	int mmio_read_completed;
	int mmio_is_write;
	int mmio_cur_fragment;
	int mmio_nr_fragments;
	struct kvm_mmio_fragment mmio_fragments[2];
	struct {
		bool in_spin_loop;
		bool dy_eligible;
	} spin_loop;
	bool preempted;
	struct kvm_vcpu_arch___2 arch;
	struct dentry___28 *debugfs_dentry;
	long: 64;
};

struct module___24;

struct file___27;

struct kiocb___27;

struct iov_iter___11;

struct poll_table_struct___15;

struct vm_area_struct___27;

struct inode___29;

struct file_lock___27;

struct seq_file___24;

struct file_operations___27 {
	struct module___24 *owner;
	loff_t (*llseek)(struct file___27 *, loff_t, int);
	ssize_t (*read)(struct file___27 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___27 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___27 *, struct iov_iter___11 *);
	ssize_t (*write_iter)(struct kiocb___27 *, struct iov_iter___11 *);
	int (*iopoll)(struct kiocb___27 *, bool);
	int (*iterate)(struct file___27 *, struct dir_context *);
	int (*iterate_shared)(struct file___27 *, struct dir_context *);
	__poll_t (*poll)(struct file___27 *, struct poll_table_struct___15 *);
	long int (*unlocked_ioctl)(struct file___27 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___27 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___27 *, struct vm_area_struct___27 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___29 *, struct file___27 *);
	int (*flush)(struct file___27 *, fl_owner_t);
	int (*release)(struct inode___29 *, struct file___27 *);
	int (*fsync)(struct file___27 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___27 *, int);
	int (*lock)(struct file___27 *, int, struct file_lock___27 *);
	ssize_t (*sendpage)(struct file___27 *, struct page___27 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___27 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___27 *, int, struct file_lock___27 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___27 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___27 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___27 *, long int, struct file_lock___27 **, void **);
	long int (*fallocate)(struct file___27 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___24 *, struct file___27 *);
	ssize_t (*copy_file_range)(struct file___27 *, loff_t, struct file___27 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___27 *, loff_t, struct file___27 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___27 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct task_struct___28;

struct preempt_ops___2 {
	void (*sched_in)(struct preempt_notifier___2 *, int);
	void (*sched_out)(struct preempt_notifier___2 *, struct task_struct___28 *);
};

struct vmacache___26 {
	u64 seqnum;
	struct vm_area_struct___27 *vmas[4];
};

struct page_frag___26 {
	struct page___27 *page;
	__u32 offset;
	__u32 size;
};

struct debug_info___12 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___12 *hbp_break[16];
	struct perf_event___12 *hbp_watch[16];
};

struct thread_struct___12 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___12 debug;
	long: 64;
};

struct mm_struct___27;

struct mem_cgroup___9;

struct cred___26;

struct nsproxy___25;

struct signal_struct___24;

struct bio_list___10;

struct backing_dev_info___10;

struct css_set___16;

struct perf_event_context___12;

struct vm_struct___21;

struct task_struct___28 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___28 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___27 *mm;
	struct mm_struct___27 *active_mm;
	struct vmacache___26 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___28 *real_parent;
	struct task_struct___28 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___28 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___9 *active_memcg;
	long int rh_reserved2;
	struct pid___22 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___22 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___22 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___26 *ptracer_cred;
	const struct cred___26 *real_cred;
	const struct cred___26 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___25 *nsproxy;
	struct signal_struct___24 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___28 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___10 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___10 *backing_dev_info;
	struct io_context___3 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___16 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___12 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___26 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___9 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___28 *oom_reaper_list;
	struct vm_struct___21 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___12 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct secondary_data___27 {
	void *stack;
	struct task_struct___28 *task;
	long int status;
};

struct hw_perf_event___12 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___28 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___12)(struct perf_event___12 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___12;

struct fasync_struct___26;

struct pid_namespace___22;

struct trace_event_call___10;

struct perf_cgroup___12;

struct perf_event___12 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___12 *group_leader;
	struct pmu___12 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___12 hw;
	struct perf_event_context___12 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___12 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___28 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___26 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___12 *);
	struct callback_head callback_head;
	struct pid_namespace___22 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___12 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___12 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___10 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___12 *cgrp;
	struct list_head sb_list;
};

struct key___27;

struct user_struct___26 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___27 *uid_keyring;
	struct key___27 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct upid___22 {
	int nr;
	struct pid_namespace___22 *ns;
};

struct user_namespace___17;

struct ucounts___17;

struct pid_namespace___22 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___28 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___22 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___28 *proc_self;
	struct dentry___28 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___17 *user_ns;
	struct ucounts___17 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___2 ns;
};

struct pid___22 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___22 numbers[1];
};

struct rw_semaphore___27 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___28 *owner;
};

struct user_namespace___17 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___17 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___2 ns;
	long unsigned int flags;
	struct key___27 *persistent_keyring_register;
	struct rw_semaphore___27 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___17 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___27 *pgtable_t___26;

struct address_space___26;

struct dev_pagemap___26;

struct page___27 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___26 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___27 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___26 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___27 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___26 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___9 *mem_cgroup;
};

struct vm_operations_struct___26;

struct vm_area_struct___27 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___27 *vm_next;
	struct vm_area_struct___27 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___27 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___26 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___27 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___26;

struct mm_struct___27 {
	struct {
		struct vm_area_struct___27 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___27 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___27 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___26 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___28 *owner;
		struct user_namespace___17 *user_ns;
		struct file___27 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___26 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup___16;

struct cgroup_subsys___16;

struct cgroup_subsys_state___16 {
	struct cgroup___16 *cgroup;
	struct cgroup_subsys___16 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___16 *parent;
};

struct kernfs_node___24;

struct cgroup_file___16 {
	struct kernfs_node___24 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___9;

struct mem_cgroup___9 {
	struct cgroup_subsys_state___16 css;
	struct mem_cgroup_id___5 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___16 events_file;
	struct cgroup_file___16 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___28 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___9 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cred___26 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___27 *session_keyring;
	struct key___27 *process_keyring;
	struct key___27 *thread_keyring;
	struct key___27 *request_key_auth;
	void *security;
	struct user_struct___26 *user;
	struct user_namespace___17 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___16;

struct nsproxy___25 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___22 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___16 *cgroup_ns;
};

struct signal_struct___24 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___28 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___28 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___22 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___22 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___27 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___22 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___10;

struct bio_list___10 {
	struct bio___10 *head;
	struct bio___10 *tail;
};

struct bdi_writeback_congested___10;

struct bdi_writeback___10 {
	struct backing_dev_info___10 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___10 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___16 *memcg_css;
	struct cgroup_subsys_state___16 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___22;

struct backing_dev_info___10 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___10 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___22 *dev;
	struct device___22 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___28 *debug_dir;
	struct dentry___28 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___16 {
	struct cgroup_subsys_state___16 *subsys[13];
	refcount_t refcount;
	struct css_set___16 *dom_cset;
	struct cgroup___16 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___16 *mg_src_cgrp;
	struct cgroup___16 *mg_dst_cgrp;
	struct css_set___16 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___12 {
	struct pmu___12 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___28 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___12 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___21 {
	struct vm_struct___21 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___27 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___24 {
	struct task_struct___28 task;
	long unsigned int stack[8192];
};

struct pglist_data___26;

struct lruvec___26 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___26 *pgdat;
};

struct zone___26 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___26 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___26 {
	struct zone___26 *zone;
	int zone_idx;
};

struct zonelist___26 {
	struct zoneref___26 _zonerefs[25];
};

struct pglist_data___26 {
	struct zone___26 node_zones[3];
	struct zonelist___26 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___28 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___28 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___26 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___26 {
	struct rw_semaphore___27 rwsem;
	struct notifier_block *head;
};

struct address_space_operations___26;

struct address_space___26 {
	struct inode___29 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___27 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___26 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___26)(struct vm_area_struct___27 *, long unsigned int, const struct page___27 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___26)(struct page___27 *, void *);

struct dev_pagemap___26 {
	dev_page_fault_t___26 page_fault;
	dev_page_free_t___26 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___22 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___26 {
	struct vfsmount *mnt;
	struct dentry___28 *dentry;
};

struct fown_struct___22 {
	rwlock_t lock;
	struct pid___22 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___27 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___26 f_path;
	struct inode___29 *f_inode;
	const struct file_operations___27 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___22 f_owner;
	const struct cred___26 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___26 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___26;

struct vm_operations_struct___26 {
	void (*open)(struct vm_area_struct___27 *);
	void (*close)(struct vm_area_struct___27 *);
	int (*split)(struct vm_area_struct___27 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___27 *);
	vm_fault_t (*fault)(struct vm_fault___26 *);
	vm_fault_t (*huge_fault)(struct vm_fault___26 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___26 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___27 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___26 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___26 *);
	int (*access)(struct vm_area_struct___27 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___27 *);
	int (*set_policy)(struct vm_area_struct___27 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___27 *, long unsigned int);
	struct page___27 * (*find_special_page)(struct vm_area_struct___27 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___26 {
	struct task_struct___28 *task;
	struct core_thread___26 *next;
};

struct core_state___26 {
	atomic_t nr_threads;
	struct core_thread___26 dumper;
	struct completion startup;
};

struct vm_fault___26 {
	struct vm_area_struct___27 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___27 *cow_page;
	struct mem_cgroup___9 *memcg;
	struct page___27 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___26 prealloc_pte;
};

struct shrink_control___9 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___9 *memcg;
};

struct shrinker___9 {
	long unsigned int (*count_objects)(struct shrinker___9 *, struct shrink_control___9 *);
	long unsigned int (*scan_objects)(struct shrinker___9 *, struct shrink_control___9 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct trace_print_flags {
	long unsigned int mask;
	const char *name;
};

struct kset___24;

struct kobj_type___24;

struct kobject___25 {
	const char *name;
	struct list_head entry;
	struct kobject___25 *parent;
	struct kset___24 *kset;
	struct kobj_type___24 *ktype;
	struct kernfs_node___24 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___22 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___22 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___22;

struct bus_type___22;

struct device_driver___22;

struct dev_pm_domain___22;

struct device_node___8;

struct fwnode_handle___18;

struct class___22;

struct attribute_group___22;

struct device___22 {
	struct device___22 *parent;
	struct device_private *p;
	struct kobject___25 kobj;
	const char *init_name;
	const struct device_type___22 *type;
	struct mutex mutex;
	struct bus_type___22 *bus;
	struct device_driver___22 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___22 power;
	struct dev_pm_domain___22 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___8 *of_node;
	struct fwnode_handle___18 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___22 *class;
	const struct attribute_group___22 **groups;
	void (*release)(struct device___22 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___26;

struct super_block___27;

struct dentry___28 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___28 *d_parent;
	struct qstr d_name;
	struct inode___29 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___26 *d_op;
	struct super_block___27 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___26;

struct block_device___27;

struct inode___29 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___26 *i_op;
	struct super_block___27 *i_sb;
	struct address_space___26 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___27 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___10 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___27 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___26 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___27 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___26 {
	int (*d_revalidate)(struct dentry___28 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___28 *, unsigned int);
	int (*d_hash)(const struct dentry___28 *, struct qstr *);
	int (*d_compare)(const struct dentry___28 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___28 *);
	int (*d_init)(struct dentry___28 *);
	void (*d_release)(struct dentry___28 *);
	void (*d_prune)(struct dentry___28 *);
	void (*d_iput)(struct dentry___28 *, struct inode___29 *);
	char * (*d_dname)(struct dentry___28 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___26 *);
	int (*d_manage)(const struct path___26 *, bool);
	struct dentry___28 * (*d_real)(struct dentry___28 *, const struct inode___29 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___26;

struct mem_dqinfo___26 {
	struct quota_format_type___26 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___26;

struct quota_info___26 {
	unsigned int flags;
	struct rw_semaphore___27 dqio_sem;
	struct inode___29 *files[3];
	struct mem_dqinfo___26 info[3];
	const struct quota_format_ops___26 *ops[3];
};

struct rcuwait___26 {
	struct task_struct___28 *task;
};

struct percpu_rw_semaphore___26 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___27 rw_sem;
	struct rcuwait___26 writer;
	int readers_block;
};

struct sb_writers___26 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___26 rw_sem[3];
};

struct file_system_type___26;

struct super_operations___26;

struct dquot_operations___26;

struct quotactl_ops___26;

struct super_block___27 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___26 *s_type;
	const struct super_operations___26 *s_op;
	const struct dquot_operations___26 *dq_op;
	const struct quotactl_ops___26 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___28 *s_root;
	struct rw_semaphore___27 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___27 *s_bdev;
	struct backing_dev_info___10 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___26 s_dquot;
	struct sb_writers___26 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___26 *s_d_op;
	int cleancache_poolid;
	struct shrinker___9 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___17 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___27 {
	struct file___27 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___27 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___27 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___27 *ia_file;
};

struct dquot___26 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___27 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___26 {
	int qf_fmt_id;
	const struct quota_format_ops___26 *qf_ops;
	struct module___24 *qf_owner;
	struct quota_format_type___26 *qf_next;
};

struct quota_format_ops___26 {
	int (*check_quota_file)(struct super_block___27 *, int);
	int (*read_file_info)(struct super_block___27 *, int);
	int (*write_file_info)(struct super_block___27 *, int);
	int (*free_file_info)(struct super_block___27 *, int);
	int (*read_dqblk)(struct dquot___26 *);
	int (*commit_dqblk)(struct dquot___26 *);
	int (*release_dqblk)(struct dquot___26 *);
	int (*get_next_id)(struct super_block___27 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___26 {
	int (*write_dquot)(struct dquot___26 *);
	struct dquot___26 * (*alloc_dquot)(struct super_block___27 *, int);
	void (*destroy_dquot)(struct dquot___26 *);
	int (*acquire_dquot)(struct dquot___26 *);
	int (*release_dquot)(struct dquot___26 *);
	int (*mark_dirty)(struct dquot___26 *);
	int (*write_info)(struct super_block___27 *, int);
	qsize_t * (*get_reserved_space)(struct inode___29 *);
	int (*get_projid)(struct inode___29 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___29 *, qsize_t *);
	int (*get_next_id)(struct super_block___27 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___26 {
	int (*quota_on)(struct super_block___27 *, int, int, const struct path___26 *);
	int (*quota_off)(struct super_block___27 *, int);
	int (*quota_enable)(struct super_block___27 *, unsigned int);
	int (*quota_disable)(struct super_block___27 *, unsigned int);
	int (*quota_sync)(struct super_block___27 *, int);
	int (*set_info)(struct super_block___27 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___27 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___27 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___27 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___27 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___27 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___21 {
	struct kobject___25 kobj;
	struct module___24 *mod;
	struct kobject___25 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___21 {
	struct module___24 *mod;
	struct latch_tree_node node;
};

struct module_layout___21 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___21 mtn;
};

struct module_attribute___21;

struct kernel_param___21;

struct module___24 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___21 mkobj;
	struct module_attribute___21 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___25 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___21 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___21 core_layout;
	struct module_layout___21 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___10 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___9;

struct swap_info_struct___7;

struct address_space_operations___26 {
	int (*writepage)(struct page___27 *, struct writeback_control___9 *);
	int (*readpage)(struct file___27 *, struct page___27 *);
	int (*writepages)(struct address_space___26 *, struct writeback_control___9 *);
	int (*set_page_dirty)(struct page___27 *);
	int (*readpages)(struct file___27 *, struct address_space___26 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___27 *, struct address_space___26 *, loff_t, unsigned int, unsigned int, struct page___27 **, void **);
	int (*write_end)(struct file___27 *, struct address_space___26 *, loff_t, unsigned int, unsigned int, struct page___27 *, void *);
	sector_t (*bmap)(struct address_space___26 *, sector_t);
	void (*invalidatepage)(struct page___27 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___27 *, gfp_t);
	void (*freepage)(struct page___27 *);
	ssize_t (*direct_IO)(struct kiocb___27 *, struct iov_iter___11 *);
	int (*migratepage)(struct address_space___26 *, struct page___27 *, struct page___27 *, enum migrate_mode);
	bool (*isolate_page)(struct page___27 *, isolate_mode_t);
	void (*putback_page)(struct page___27 *);
	int (*launder_page)(struct page___27 *);
	int (*is_partially_uptodate)(struct page___27 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___27 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___26 *, struct page___27 *);
	int (*swap_activate)(struct swap_info_struct___7 *, struct file___27 *, sector_t *);
	void (*swap_deactivate)(struct file___27 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___9 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___10 *wb;
	struct inode___29 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___10;

struct iov_iter___11 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___10 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct swap_info_struct___7 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___27 *bdev;
	struct file___27 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___27 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___29 *bd_inode;
	struct super_block___27 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___27 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___10 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___26 {
	struct dentry___28 * (*lookup)(struct inode___29 *, struct dentry___28 *, unsigned int);
	const char * (*get_link)(struct dentry___28 *, struct inode___29 *, struct delayed_call *);
	int (*permission)(struct inode___29 *, int);
	struct posix_acl * (*get_acl)(struct inode___29 *, int);
	int (*readlink)(struct dentry___28 *, char *, int);
	int (*create)(struct inode___29 *, struct dentry___28 *, umode_t, bool);
	int (*link)(struct dentry___28 *, struct inode___29 *, struct dentry___28 *);
	int (*unlink)(struct inode___29 *, struct dentry___28 *);
	int (*symlink)(struct inode___29 *, struct dentry___28 *, const char *);
	int (*mkdir)(struct inode___29 *, struct dentry___28 *, umode_t);
	int (*rmdir)(struct inode___29 *, struct dentry___28 *);
	int (*mknod)(struct inode___29 *, struct dentry___28 *, umode_t, dev_t);
	int (*rename)(struct inode___29 *, struct dentry___28 *, struct inode___29 *, struct dentry___28 *, unsigned int);
	int (*setattr)(struct dentry___28 *, struct iattr___27 *);
	int (*getattr)(const struct path___26 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___28 *, char *, size_t);
	int (*fiemap)(struct inode___29 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___29 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___29 *, struct dentry___28 *, struct file___27 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___29 *, struct dentry___28 *, umode_t);
	int (*set_acl)(struct inode___29 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___26 {
	void (*fl_copy_lock)(struct file_lock___27 *, struct file_lock___27 *);
	void (*fl_release_private)(struct file_lock___27 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___26;

struct file_lock___27 {
	struct file_lock___27 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___27 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___26 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___26 *fl_ops;
	const struct lock_manager_operations___26 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___26 {
	int (*lm_compare_owner)(struct file_lock___27 *, struct file_lock___27 *);
	long unsigned int (*lm_owner_key)(struct file_lock___27 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___27 *);
	int (*lm_grant)(struct file_lock___27 *, int);
	bool (*lm_break)(struct file_lock___27 *);
	int (*lm_change)(struct file_lock___27 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___27 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___26 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___26 *fa_next;
	struct file___27 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___26 {
	const char *name;
	int fs_flags;
	struct dentry___28 * (*mount)(struct file_system_type___26 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___27 *);
	struct module___24 *owner;
	struct file_system_type___26 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___26 {
	struct inode___29 * (*alloc_inode)(struct super_block___27 *);
	void (*destroy_inode)(struct inode___29 *);
	void (*dirty_inode)(struct inode___29 *, int);
	int (*write_inode)(struct inode___29 *, struct writeback_control___9 *);
	int (*drop_inode)(struct inode___29 *);
	void (*evict_inode)(struct inode___29 *);
	void (*put_super)(struct super_block___27 *);
	int (*sync_fs)(struct super_block___27 *, int);
	int (*freeze_super)(struct super_block___27 *);
	int (*freeze_fs)(struct super_block___27 *);
	int (*thaw_super)(struct super_block___27 *);
	int (*unfreeze_fs)(struct super_block___27 *);
	int (*statfs)(struct dentry___28 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___27 *, int *, char *);
	void (*umount_begin)(struct super_block___27 *);
	int (*show_options)(struct seq_file___24 *, struct dentry___28 *);
	int (*show_devname)(struct seq_file___24 *, struct dentry___28 *);
	int (*show_path)(struct seq_file___24 *, struct dentry___28 *);
	int (*show_stats)(struct seq_file___24 *, struct dentry___28 *);
	ssize_t (*quota_read)(struct super_block___27 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___27 *, int, const char *, size_t, loff_t);
	struct dquot___26 ** (*get_dquots)(struct inode___29 *);
	int (*bdev_try_to_free_page)(struct super_block___27 *, struct page___27 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___27 *, struct shrink_control___9 *);
	long int (*free_cached_objects)(struct super_block___27 *, struct shrink_control___9 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___14)(struct file___27 *, wait_queue_head_t *, struct poll_table_struct___15 *);

struct poll_table_struct___15 {
	poll_queue_proc___14 _qproc;
	__poll_t _key;
};

struct seq_operations___21;

struct seq_file___24 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___21 *op;
	int poll_event;
	const struct file___27 *file;
	void *private;
};

typedef void bio_end_io_t___10(struct bio___10 *);

struct bio_vec___10 {
	struct page___27 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___10;

struct bio_set___10;

struct bio___10 {
	struct bio___10 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___10 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___10 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___10 *bi_io_vec;
	struct bio_set___10 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___10 bi_inline_vecs[0];
};

struct kobj_attribute___25 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___25 *, struct kobj_attribute___25 *, char *);
	ssize_t (*store)(struct kobject___25 *, struct kobj_attribute___25 *, const char *, size_t);
};

typedef void compound_page_dtor___26(struct page___27 *);

struct mmu_notifier___2;

struct mmu_notifier_ops___2 {
	int flags;
	void (*release)(struct mmu_notifier___2 *, struct mm_struct___27 *);
	int (*clear_flush_young)(struct mmu_notifier___2 *, struct mm_struct___27 *, long unsigned int, long unsigned int);
	int (*clear_young)(struct mmu_notifier___2 *, struct mm_struct___27 *, long unsigned int, long unsigned int);
	int (*test_young)(struct mmu_notifier___2 *, struct mm_struct___27 *, long unsigned int);
	void (*change_pte)(struct mmu_notifier___2 *, struct mm_struct___27 *, long unsigned int, pte_t);
	void (*invalidate_range_start)(struct mmu_notifier___2 *, struct mm_struct___27 *, long unsigned int, long unsigned int);
	void (*invalidate_range_end)(struct mmu_notifier___2 *, struct mm_struct___27 *, long unsigned int, long unsigned int);
	void (*invalidate_range)(struct mmu_notifier___2 *, struct mm_struct___27 *, long unsigned int, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mmu_notifier___2 {
	struct hlist_node hlist;
	const struct mmu_notifier_ops___2 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct kernfs_root___24;

struct kernfs_elem_dir___24 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___24 *root;
};

struct kernfs_syscall_ops___24;

struct kernfs_root___24 {
	struct kernfs_node___24 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___24 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___24 {
	struct kernfs_node___24 *target_kn;
};

struct kernfs_ops___24;

struct kernfs_elem_attr___24 {
	const struct kernfs_ops___24 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___24 *notify_next;
};

struct kernfs_node___24 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___24 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___24 dir;
		struct kernfs_elem_symlink___24 symlink;
		struct kernfs_elem_attr___24 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___24;

struct kernfs_ops___24 {
	int (*open)(struct kernfs_open_file___24 *);
	void (*release)(struct kernfs_open_file___24 *);
	int (*seq_show)(struct seq_file___24 *, void *);
	void * (*seq_start)(struct seq_file___24 *, loff_t *);
	void * (*seq_next)(struct seq_file___24 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___24 *, void *);
	ssize_t (*read)(struct kernfs_open_file___24 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___24 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___24 *, struct vm_area_struct___27 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___24 *, struct poll_table_struct___15 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___24 {
	int (*remount_fs)(struct kernfs_root___24 *, int *, char *);
	int (*show_options)(struct seq_file___24 *, struct kernfs_root___24 *);
	int (*mkdir)(struct kernfs_node___24 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___24 *);
	int (*rename)(struct kernfs_node___24 *, struct kernfs_node___24 *, const char *);
	int (*show_path)(struct seq_file___24 *, struct kernfs_node___24 *, struct kernfs_root___24 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___24 {
	struct kernfs_node___24 *kn;
	struct file___27 *file;
	struct seq_file___24 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___26 *vm_ops;
};

struct bin_attribute___22;

struct attribute_group___22 {
	const char *name;
	umode_t (*is_visible)(struct kobject___25 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___25 *, struct bin_attribute___22 *, int);
	struct attribute **attrs;
	struct bin_attribute___22 **bin_attrs;
};

struct bin_attribute___22 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___27 *, struct kobject___25 *, struct bin_attribute___22 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___27 *, struct kobject___25 *, struct bin_attribute___22 *, char *, loff_t, size_t);
	int (*mmap)(struct file___27 *, struct kobject___25 *, struct bin_attribute___22 *, struct vm_area_struct___27 *);
};

struct sysfs_ops___24 {
	ssize_t (*show)(struct kobject___25 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___25 *, struct attribute *, const char *, size_t);
};

enum kobject_action {
	KOBJ_ADD = 0,
	KOBJ_REMOVE = 1,
	KOBJ_CHANGE = 2,
	KOBJ_MOVE = 3,
	KOBJ_ONLINE = 4,
	KOBJ_OFFLINE = 5,
	KOBJ_BIND = 6,
	KOBJ_UNBIND = 7,
	KOBJ_MAX = 8,
};

struct kset_uevent_ops___24;

struct kset___24 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___25 kobj;
	const struct kset_uevent_ops___24 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___24 {
	void (*release)(struct kobject___25 *);
	const struct sysfs_ops___24 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___25 *);
	const void * (*namespace)(struct kobject___25 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___24 {
	int (* const filter)(struct kset___24 *, struct kobject___25 *);
	const char * (* const name)(struct kset___24 *, struct kobject___25 *);
	int (* const uevent)(struct kset___24 *, struct kobject___25 *, struct kobj_uevent_env *);
};

struct fwnode_operations___18;

struct fwnode_handle___18 {
	struct fwnode_handle___18 *secondary;
	const struct fwnode_operations___18 *ops;
};

struct property___8;

struct device_node___8 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___18 fwnode;
	struct property___8 *properties;
	struct property___8 *deadprops;
	struct device_node___8 *parent;
	struct device_node___8 *child;
	struct device_node___8 *sibling;
	struct kobject___25 kobj;
	long unsigned int _flags;
	void *data;
};

struct swait_queue {
	struct task_struct___28 *task;
	struct list_head task_list;
};

struct kvm_sregs {};

struct kvm_fpu {};

struct kvm_userspace_memory_region {
	__u32 slot;
	__u32 flags;
	__u64 guest_phys_addr;
	__u64 memory_size;
	__u64 userspace_addr;
};

struct kvm_coalesced_mmio_zone {
	__u64 addr;
	__u32 size;
	union {
		__u32 pad;
		__u32 pio;
	};
};

struct kvm_translation {
	__u64 linear_address;
	__u64 physical_address;
	__u8 valid;
	__u8 writeable;
	__u8 usermode;
	__u8 pad[5];
};

struct kvm_dirty_log {
	__u32 slot;
	__u32 padding1;
	union {
		void *dirty_bitmap;
		__u64 padding2;
	};
};

struct kvm_clear_dirty_log {
	__u32 slot;
	__u32 num_pages;
	__u64 first_page;
	union {
		void *dirty_bitmap;
		__u64 padding2;
	};
};

struct kvm_signal_mask {
	__u32 len;
	__u8 sigset[0];
};

struct kvm_mp_state {
	__u32 mp_state;
};

struct kvm_guest_debug {
	__u32 control;
	__u32 pad;
	struct kvm_guest_debug_arch arch;
};

struct kvm_ioeventfd {
	__u64 datamatch;
	__u64 addr;
	__u32 len;
	__s32 fd;
	__u32 flags;
	__u8 pad[36];
};

struct kvm_enable_cap {
	__u32 cap;
	__u32 flags;
	__u64 args[4];
	__u8 pad[64];
};

struct kvm_irq_routing_irqchip {
	__u32 irqchip;
	__u32 pin;
};

struct kvm_irq_routing_msi {
	__u32 address_lo;
	__u32 address_hi;
	__u32 data;
	union {
		__u32 pad;
		__u32 devid;
	};
};

struct kvm_irq_routing_s390_adapter {
	__u64 ind_addr;
	__u64 summary_addr;
	__u64 ind_offset;
	__u32 summary_offset;
	__u32 adapter_id;
};

struct kvm_irq_routing_hv_sint {
	__u32 vcpu;
	__u32 sint;
};

struct kvm_irq_routing_entry {
	__u32 gsi;
	__u32 type;
	__u32 flags;
	__u32 pad;
	union {
		struct kvm_irq_routing_irqchip irqchip;
		struct kvm_irq_routing_msi msi;
		struct kvm_irq_routing_s390_adapter adapter;
		struct kvm_irq_routing_hv_sint hv_sint;
		__u32 pad[8];
	} u;
};

struct kvm_irq_routing {
	__u32 nr;
	__u32 flags;
	struct kvm_irq_routing_entry entries[0];
};

struct kvm_irqfd {
	__u32 fd;
	__u32 gsi;
	__u32 flags;
	__u32 resamplefd;
	__u8 pad[16];
};

struct kvm_msi {
	__u32 address_lo;
	__u32 address_hi;
	__u32 data;
	__u32 flags;
	__u32 devid;
	__u8 pad[12];
};

struct kvm_create_device {
	__u32 type;
	__u32 fd;
	__u32 flags;
};

enum kvm_device_type {
	KVM_DEV_TYPE_FSL_MPIC_20 = 1,
	KVM_DEV_TYPE_FSL_MPIC_42 = 2,
	KVM_DEV_TYPE_XICS = 3,
	KVM_DEV_TYPE_VFIO = 4,
	KVM_DEV_TYPE_ARM_VGIC_V2 = 5,
	KVM_DEV_TYPE_FLIC = 6,
	KVM_DEV_TYPE_ARM_VGIC_V3 = 7,
	KVM_DEV_TYPE_ARM_VGIC_ITS = 8,
	KVM_DEV_TYPE_XIVE = 9,
	KVM_DEV_TYPE_MAX = 10,
};

struct its_vm___2 {
	struct fwnode_handle___18 *fwnode;
	struct irq_domain *domain;
	struct page___27 *vprop_page;
	struct its_vpe___2 **vpes;
	int nr_vpes;
	irq_hw_number_t db_lpi_base;
	long unsigned int *db_bitmap;
	int nr_db_lpis;
	u32 vlpi_count[16];
};

struct kvm_device___2;

struct vgic_its___3 {
	gpa_t vgic_its_base;
	bool enabled;
	struct vgic_io_device___2 iodev;
	struct kvm_device___2 *dev;
	u64 baser_device_table;
	u64 baser_coll_table;
	struct mutex cmd_lock;
	u64 cbaser;
	u32 creadr;
	u32 cwriter;
	u32 abi_rev;
	struct mutex its_lock;
	struct list_head device_list;
	struct list_head collection_list;
};

struct kvm_device_ops___2;

struct kvm_device___2 {
	struct kvm_device_ops___2 *ops;
	struct kvm___3 *kvm;
	void *private;
	struct list_head vm_node;
};

struct vgic_dist___2 {
	bool in_kernel;
	bool ready;
	bool initialized;
	u32 vgic_model;
	u32 implementation_rev;
	bool v2_groups_user_writable;
	bool msis_require_devid;
	int nr_spis;
	gpa_t vgic_dist_base;
	union {
		gpa_t vgic_cpu_base;
		struct list_head rd_regions;
	};
	bool enabled;
	struct vgic_irq___2 *spis;
	struct vgic_io_device___2 dist_iodev;
	bool has_its;
	u64 propbaser;
	raw_spinlock_t lpi_list_lock;
	struct list_head lpi_list_head;
	int lpi_list_count;
	struct vgic_state_iter *iter;
	struct its_vm___2 its_vm;
};

struct fwnode_reference_args___18;

struct fwnode_endpoint___18;

struct fwnode_operations___18 {
	struct fwnode_handle___18 * (*get)(struct fwnode_handle___18 *);
	void (*put)(struct fwnode_handle___18 *);
	bool (*device_is_available)(const struct fwnode_handle___18 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___18 *, const struct device___22 *);
	bool (*property_present)(const struct fwnode_handle___18 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___18 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___18 *, const char *, const char **, size_t);
	struct fwnode_handle___18 * (*get_parent)(const struct fwnode_handle___18 *);
	struct fwnode_handle___18 * (*get_next_child_node)(const struct fwnode_handle___18 *, struct fwnode_handle___18 *);
	struct fwnode_handle___18 * (*get_named_child_node)(const struct fwnode_handle___18 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___18 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___18 *);
	struct fwnode_handle___18 * (*graph_get_next_endpoint)(const struct fwnode_handle___18 *, struct fwnode_handle___18 *);
	struct fwnode_handle___18 * (*graph_get_remote_endpoint)(const struct fwnode_handle___18 *);
	struct fwnode_handle___18 * (*graph_get_port_parent)(struct fwnode_handle___18 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___18 *, struct fwnode_endpoint___18 *);
};

struct fwnode_endpoint___18 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___18 *local_fwnode;
};

struct fwnode_reference_args___18 {
	struct fwnode_handle___18 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct property___8 {
	char *name;
	int length;
	void *value;
	struct property___8 *next;
	long unsigned int _flags;
	struct bin_attribute___22 attr;
};

struct cgroup_namespace___16 {
	refcount_t count;
	struct ns_common___2 ns;
	struct user_namespace___17 *user_ns;
	struct ucounts___17 *ucounts;
	struct css_set___16 *root_cset;
};

struct ucounts___17 {
	struct hlist_node node;
	struct user_namespace___17 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct kernel_param_ops___21 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___21 *);
	int (*get)(char *, const struct kernel_param___21 *);
	void (*free)(void *);
};

struct kparam_array___21;

struct kernel_param___21 {
	const char *name;
	struct module___24 *mod;
	const struct kernel_param_ops___21 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___21 *arr;
	};
};

struct kparam_array___21 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___21 *ops;
	void *elem;
};

struct module_attribute___21 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___21 *, struct module_kobject___21 *, char *);
	ssize_t (*store)(struct module_attribute___21 *, struct module_kobject___21 *, const char *, size_t);
	void (*setup)(struct module___24 *, const char *);
	int (*test)(struct module___24 *);
	void (*free)(struct module___24 *);
};

struct trace_event_class___10;

struct trace_event_call___10 {
	struct list_head list;
	struct trace_event_class___10 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___2 *prog_array;
	int (*perf_perm)(struct trace_event_call___10 *, struct perf_event___12 *);
};

typedef int (*key_restrict_link_func_t___26)(struct key___27 *, const struct key_type *, const union key_payload *, struct key___27 *);

struct key_restriction___27;

struct key___27 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___27 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___27 *restrict_link;
};

struct key_restriction___27 {
	key_restrict_link_func_t___26 check;
	struct key___27 *key;
	struct key_type *keytype;
};

struct dev_pm_ops___22 {
	int (*prepare)(struct device___22 *);
	void (*complete)(struct device___22 *);
	int (*suspend)(struct device___22 *);
	int (*resume)(struct device___22 *);
	int (*freeze)(struct device___22 *);
	int (*thaw)(struct device___22 *);
	int (*poweroff)(struct device___22 *);
	int (*restore)(struct device___22 *);
	int (*suspend_late)(struct device___22 *);
	int (*resume_early)(struct device___22 *);
	int (*freeze_late)(struct device___22 *);
	int (*thaw_early)(struct device___22 *);
	int (*poweroff_late)(struct device___22 *);
	int (*restore_early)(struct device___22 *);
	int (*suspend_noirq)(struct device___22 *);
	int (*resume_noirq)(struct device___22 *);
	int (*freeze_noirq)(struct device___22 *);
	int (*thaw_noirq)(struct device___22 *);
	int (*poweroff_noirq)(struct device___22 *);
	int (*restore_noirq)(struct device___22 *);
	int (*runtime_suspend)(struct device___22 *);
	int (*runtime_resume)(struct device___22 *);
	int (*runtime_idle)(struct device___22 *);
};

struct dev_pm_domain___22 {
	struct dev_pm_ops___22 ops;
	void (*detach)(struct device___22 *, bool);
	int (*activate)(struct device___22 *);
	void (*sync)(struct device___22 *);
	void (*dismiss)(struct device___22 *);
};

struct bus_type___22 {
	const char *name;
	const char *dev_name;
	struct device___22 *dev_root;
	const struct attribute_group___22 **bus_groups;
	const struct attribute_group___22 **dev_groups;
	const struct attribute_group___22 **drv_groups;
	int (*match)(struct device___22 *, struct device_driver___22 *);
	int (*uevent)(struct device___22 *, struct kobj_uevent_env *);
	int (*probe)(struct device___22 *);
	int (*remove)(struct device___22 *);
	void (*shutdown)(struct device___22 *);
	int (*online)(struct device___22 *);
	int (*offline)(struct device___22 *);
	int (*suspend)(struct device___22 *, pm_message_t);
	int (*resume)(struct device___22 *);
	int (*num_vf)(struct device___22 *);
	int (*dma_configure)(struct device___22 *);
	const struct dev_pm_ops___22 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___22 {
	const char *name;
	struct bus_type___22 *bus;
	struct module___24 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___22 *);
	int (*remove)(struct device___22 *);
	void (*shutdown)(struct device___22 *);
	int (*suspend)(struct device___22 *, pm_message_t);
	int (*resume)(struct device___22 *);
	const struct attribute_group___22 **groups;
	const struct dev_pm_ops___22 *pm;
	void (*coredump)(struct device___22 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___22 {
	const char *name;
	const struct attribute_group___22 **groups;
	int (*uevent)(struct device___22 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___22 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___22 *);
	const struct dev_pm_ops___22 *pm;
};

struct class___22 {
	const char *name;
	struct module___24 *owner;
	const struct attribute_group___22 **class_groups;
	const struct attribute_group___22 **dev_groups;
	struct kobject___25 *dev_kobj;
	int (*dev_uevent)(struct device___22 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___22 *, umode_t *);
	void (*class_release)(struct class___22 *);
	void (*dev_release)(struct device___22 *);
	int (*shutdown_pre)(struct device___22 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___22 *);
	const struct dev_pm_ops___22 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___20 {
	struct device___22 dev;
};

struct seq_operations___21 {
	void * (*start)(struct seq_file___24 *, loff_t *);
	void (*stop)(struct seq_file___24 *, void *);
	void * (*next)(struct seq_file___24 *, void *, loff_t *);
	int (*show)(struct seq_file___24 *, void *);
};

struct bpf_map___16;

struct bpf_map_ops___16 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___16 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___16 *, struct file___27 *);
	void (*map_free)(struct bpf_map___16 *);
	int (*map_get_next_key)(struct bpf_map___16 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___16 *);
	void * (*map_lookup_elem)(struct bpf_map___16 *, void *);
	int (*map_update_elem)(struct bpf_map___16 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___16 *, void *);
	int (*map_push_elem)(struct bpf_map___16 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___16 *, void *);
	int (*map_peek_elem)(struct bpf_map___16 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___16 *, struct file___27 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___16 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___16 *, void *, struct seq_file___24 *);
	int (*map_check_btf)(const struct bpf_map___16 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___16 {
	const struct bpf_map_ops___16 *ops;
	struct bpf_map___16 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___26 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___16;

typedef void (*kthread_work_func_t___16)(struct kthread_work___16 *);

struct kthread_worker___16;

struct kthread_work___16 {
	struct list_head node;
	kthread_work_func_t___16 func;
	struct kthread_worker___16 *worker;
	int canceling;
};

struct kthread_worker___16 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___28 *task;
	struct kthread_work___16 *current_work;
};

struct kthread_delayed_work___16 {
	struct kthread_work___16 work;
	struct timer_list timer;
};

struct psi_group___16 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___16 *poll_kworker;
	struct kthread_delayed_work___16 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___16;

struct cgroup_rstat_cpu___16;

struct cgroup___16 {
	struct cgroup_subsys_state___16 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___24 *kn;
	struct cgroup_file___16 procs_file;
	struct cgroup_file___16 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___16 *subsys[13];
	struct cgroup_root___16 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___16 *dom_cgrp;
	struct cgroup_rstat_cpu___16 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___2 bpf;
	atomic_t congestion_count;
	struct cgroup___16 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___16 psi;
	int ancestor_ids[0];
};

struct cftype___16;

struct cgroup_subsys___16 {
	struct cgroup_subsys_state___16 * (*css_alloc)(struct cgroup_subsys_state___16 *);
	int (*css_online)(struct cgroup_subsys_state___16 *);
	void (*css_offline)(struct cgroup_subsys_state___16 *);
	void (*css_released)(struct cgroup_subsys_state___16 *);
	void (*css_free)(struct cgroup_subsys_state___16 *);
	void (*css_reset)(struct cgroup_subsys_state___16 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___16 *, int);
	int (*css_extra_stat_show)(struct seq_file___24 *, struct cgroup_subsys_state___16 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___28 *);
	void (*cancel_fork)(struct task_struct___28 *);
	void (*fork)(struct task_struct___28 *);
	void (*exit)(struct task_struct___28 *);
	void (*free)(struct task_struct___28 *);
	void (*bind)(struct cgroup_subsys_state___16 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___16 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___16 *dfl_cftypes;
	struct cftype___16 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___16 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___16 *updated_children;
	struct cgroup___16 *updated_next;
};

struct cgroup_root___16 {
	struct kernfs_root___24 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___16 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___16 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___16 *ss;
	struct list_head node;
	struct kernfs_ops___24 *kf_ops;
	int (*open)(struct kernfs_open_file___24 *);
	void (*release)(struct kernfs_open_file___24 *);
	u64 (*read_u64)(struct cgroup_subsys_state___16 *, struct cftype___16 *);
	s64 (*read_s64)(struct cgroup_subsys_state___16 *, struct cftype___16 *);
	int (*seq_show)(struct seq_file___24 *, void *);
	void * (*seq_start)(struct seq_file___24 *, loff_t *);
	void * (*seq_next)(struct seq_file___24 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___24 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___16 *, struct cftype___16 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___16 *, struct cftype___16 *, s64);
	ssize_t (*write)(struct kernfs_open_file___24 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___24 *, struct poll_table_struct___15 *);
};

struct perf_cpu_context___12;

struct pmu___12 {
	struct list_head entry;
	struct module___24 *module;
	struct device___22 *dev;
	const struct attribute_group___22 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___12 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___12 *);
	void (*pmu_disable)(struct pmu___12 *);
	int (*event_init)(struct perf_event___12 *);
	void (*event_mapped)(struct perf_event___12 *, struct mm_struct___27 *);
	void (*event_unmapped)(struct perf_event___12 *, struct mm_struct___27 *);
	int (*add)(struct perf_event___12 *, int);
	void (*del)(struct perf_event___12 *, int);
	void (*start)(struct perf_event___12 *, int);
	void (*stop)(struct perf_event___12 *, int);
	void (*read)(struct perf_event___12 *);
	void (*start_txn)(struct pmu___12 *, unsigned int);
	int (*commit_txn)(struct pmu___12 *);
	void (*cancel_txn)(struct pmu___12 *);
	int (*event_idx)(struct perf_event___12 *);
	void (*sched_task)(struct perf_event_context___12 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___12 *);
	int (*filter_match)(struct perf_event___12 *);
	int (*check_period)(struct perf_event___12 *, u64);
};

struct perf_cpu_context___12 {
	struct perf_event_context___12 ctx;
	struct perf_event_context___12 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___12 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___12 {
	struct cgroup_subsys_state___16 css;
	struct perf_cgroup_info *info;
};

struct kvm_arch___2 {
	struct kvm_vmid vmid;
	pgd_t *pgd;
	phys_addr_t pgd_phys;
	u64 vtcr;
	int *last_vcpu_ran;
	int max_vcpus;
	struct vgic_dist___2 vgic;
	u32 psci_version;
};

struct kvm_io_range___2 {
	gpa_t addr;
	int len;
	struct kvm_io_device___2 *dev;
};

struct kvm_io_bus___2 {
	int dev_count;
	int ioeventfd_count;
	struct kvm_io_range___2 range[0];
};

enum {
	OUTSIDE_GUEST_MODE = 0,
	IN_GUEST_MODE = 1,
	EXITING_GUEST_MODE = 2,
	READING_SHADOW_PAGE_TABLES = 3,
};

struct kvm_stat_data___2;

struct kvm___3 {
	spinlock_t mmu_lock;
	struct mutex slots_lock;
	struct mm_struct___27 *mm;
	struct kvm_memslots *memslots[1];
	struct kvm_vcpu___3 *vcpus[512];
	atomic_t online_vcpus;
	int created_vcpus;
	int last_boosted_vcpu;
	struct list_head vm_list;
	struct mutex lock;
	struct kvm_io_bus___2 *buses[4];
	struct {
		spinlock_t lock;
		struct list_head items;
		struct list_head resampler_list;
		struct mutex resampler_lock;
	} irqfds;
	struct list_head ioeventfds;
	struct kvm_vm_stat stat;
	struct kvm_arch___2 arch;
	refcount_t users_count;
	struct kvm_coalesced_mmio_ring *coalesced_mmio_ring;
	spinlock_t ring_lock;
	struct list_head coalesced_zones;
	struct mutex irq_lock;
	struct kvm_irq_routing_table *irq_routing;
	struct hlist_head irq_ack_notifier_list;
	struct mmu_notifier___2 mmu_notifier;
	long unsigned int mmu_notifier_seq;
	long int mmu_notifier_count;
	long int tlbs_dirty;
	struct list_head devices;
	bool manual_dirty_log_protect;
	struct dentry___28 *debugfs_dentry;
	struct kvm_stat_data___2 **debugfs_stat_data;
	struct srcu_struct srcu;
	struct srcu_struct irq_srcu;
	pid_t userspace_pid;
};

struct kvm_stat_data___2 {
	int offset;
	int mode;
	struct kvm___3 *kvm;
};

enum kvm_mr_change {
	KVM_MR_CREATE = 0,
	KVM_MR_DELETE = 1,
	KVM_MR_MOVE = 2,
	KVM_MR_FLAGS_ONLY = 3,
};

struct kvm_device_ops___2 {
	const char *name;
	int (*create)(struct kvm_device___2 *, u32);
	void (*init)(struct kvm_device___2 *);
	void (*destroy)(struct kvm_device___2 *);
	void (*release)(struct kvm_device___2 *);
	int (*set_attr)(struct kvm_device___2 *, struct kvm_device_attr *);
	int (*get_attr)(struct kvm_device___2 *, struct kvm_device_attr *);
	int (*has_attr)(struct kvm_device___2 *, struct kvm_device_attr *);
	long int (*ioctl)(struct kvm_device___2 *, unsigned int, long unsigned int);
	int (*mmap)(struct kvm_device___2 *, struct vm_area_struct___27 *);
};

typedef int (*kvm_vm_thread_fn_t)(struct kvm___3 *, uintptr_t);

struct miscdevice {
	int minor;
	const char *name;
	const struct file_operations___27 *fops;
	struct list_head list;
	struct device___22 *parent;
	struct device___22 *this_device;
	const struct attribute_group___22 **groups;
	const char *nodename;
	umode_t mode;
};

struct syscore_ops {
	struct list_head node;
	int (*suspend)();
	void (*resume)();
	void (*shutdown)();
};

struct bdi_writeback_congested___10 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___10 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___10 {
	struct bio___10 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___10 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___10 bip_inline_vecs[0];
};

struct bio_set___10 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___10 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___9 {
	struct mem_cgroup___9 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___9 {
	struct lruvec___26 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___9 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___9 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct hstate___3 {
	int next_nid_to_alloc;
	int next_nid_to_free;
	unsigned int order;
	long unsigned int mask;
	long unsigned int max_huge_pages;
	long unsigned int nr_huge_pages;
	long unsigned int free_huge_pages;
	long unsigned int resv_huge_pages;
	long unsigned int surplus_huge_pages;
	long unsigned int nr_overcommit_huge_pages;
	struct list_head hugepage_activelist;
	struct list_head hugepage_freelists[8];
	unsigned int nr_huge_pages_node[8];
	unsigned int free_huge_pages_node[8];
	unsigned int surplus_huge_pages_node[8];
	struct cftype___16 cgroup_files[5];
	char name[32];
};

struct trace_event_class___10 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___10 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___10 *);
	struct list_head * (*get_fields)(struct trace_event_call___10 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___10 *);
};

struct trace_event_file___4;

struct trace_event_buffer___4 {
	struct ring_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___4 *trace_file;
	void *entry;
	long unsigned int flags;
	int pc;
};

struct trace_event_file___4 {
	struct list_head list;
	struct trace_event_call___10 *event_call;
	struct event_filter *filter;
	struct dentry___28 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_kvm_userspace_exit {
	struct trace_entry ent;
	__u32 reason;
	int errno;
	char __data[0];
};

struct trace_event_raw_kvm_vcpu_wakeup {
	struct trace_entry ent;
	__u64 ns;
	bool waited;
	bool valid;
	char __data[0];
};

struct trace_event_raw_kvm_set_irq {
	struct trace_entry ent;
	unsigned int gsi;
	int level;
	int irq_source_id;
	char __data[0];
};

struct trace_event_raw_kvm_ack_irq {
	struct trace_entry ent;
	unsigned int irqchip;
	unsigned int pin;
	char __data[0];
};

struct trace_event_raw_kvm_mmio {
	struct trace_entry ent;
	u32 type;
	u32 len;
	u64 gpa;
	u64 val;
	char __data[0];
};

struct trace_event_raw_kvm_fpu {
	struct trace_entry ent;
	u32 load;
	char __data[0];
};

struct trace_event_raw_kvm_age_page {
	struct trace_entry ent;
	u64 hva;
	u64 gfn;
	u8 level;
	u8 referenced;
	char __data[0];
};

struct trace_event_raw_kvm_halt_poll_ns {
	struct trace_entry ent;
	bool grow;
	unsigned int vcpu_id;
	unsigned int new;
	unsigned int old;
	char __data[0];
};

struct trace_event_data_offsets_kvm_userspace_exit {};

struct trace_event_data_offsets_kvm_vcpu_wakeup {};

struct trace_event_data_offsets_kvm_set_irq {};

struct trace_event_data_offsets_kvm_ack_irq {};

struct trace_event_data_offsets_kvm_mmio {};

struct trace_event_data_offsets_kvm_fpu {};

struct trace_event_data_offsets_kvm_age_page {};

struct trace_event_data_offsets_kvm_halt_poll_ns {};

struct kvm_vm_worker_thread_context {
	struct kvm___3 *kvm;
	struct task_struct___28 *parent;
	struct completion init_done;
	kvm_vm_thread_fn_t thread_fn;
	uintptr_t data;
	int err;
};

struct kvm_coalesced_mmio_dev {
	struct list_head list;
	struct kvm_io_device___2 dev;
	struct kvm___3 *kvm;
	struct kvm_coalesced_mmio_zone zone;
};

enum {
	WORK_STRUCT_PENDING_BIT = 0,
	WORK_STRUCT_DELAYED_BIT = 1,
	WORK_STRUCT_PWQ_BIT = 2,
	WORK_STRUCT_LINKED_BIT = 3,
	WORK_STRUCT_COLOR_SHIFT = 4,
	WORK_STRUCT_COLOR_BITS = 4,
	WORK_STRUCT_PENDING = 1,
	WORK_STRUCT_DELAYED = 2,
	WORK_STRUCT_PWQ = 4,
	WORK_STRUCT_LINKED = 8,
	WORK_STRUCT_STATIC = 0,
	WORK_NR_COLORS = 15,
	WORK_NO_COLOR = 15,
	WORK_CPU_UNBOUND = 4096,
	WORK_STRUCT_FLAG_BITS = 8,
	WORK_OFFQ_FLAG_BASE = 4,
	__WORK_OFFQ_CANCELING = 4,
	WORK_OFFQ_CANCELING = 16,
	WORK_OFFQ_FLAG_BITS = 1,
	WORK_OFFQ_POOL_SHIFT = 5,
	WORK_OFFQ_LEFT = 59,
	WORK_OFFQ_POOL_BITS = 31,
	WORK_OFFQ_POOL_NONE = 2147483647,
	WORK_STRUCT_FLAG_MASK = 255,
	WORK_STRUCT_WQ_DATA_MASK = 4294967040,
	WORK_STRUCT_NO_POOL = 4294967264,
	WORK_BUSY_PENDING = 1,
	WORK_BUSY_RUNNING = 2,
	WORKER_DESC_LEN = 24,
};

struct wait_queue_entry;

typedef int (*wait_queue_func_t)(struct wait_queue_entry *, unsigned int, int, void *);

struct wait_queue_entry {
	unsigned int flags;
	void *private;
	wait_queue_func_t func;
	struct list_head entry;
};

typedef struct wait_queue_entry wait_queue_entry_t;

struct irq_bypass_consumer;

struct irq_bypass_producer {
	struct list_head node;
	void *token;
	int irq;
	int (*add_consumer)(struct irq_bypass_producer *, struct irq_bypass_consumer *);
	void (*del_consumer)(struct irq_bypass_producer *, struct irq_bypass_consumer *);
	void (*stop)(struct irq_bypass_producer *);
	void (*start)(struct irq_bypass_producer *);
};

struct irq_bypass_consumer {
	struct list_head node;
	void *token;
	int (*add_producer)(struct irq_bypass_consumer *, struct irq_bypass_producer *);
	void (*del_producer)(struct irq_bypass_consumer *, struct irq_bypass_producer *);
	void (*stop)(struct irq_bypass_consumer *);
	void (*start)(struct irq_bypass_consumer *);
};

enum {
	kvm_ioeventfd_flag_nr_datamatch = 0,
	kvm_ioeventfd_flag_nr_pio = 1,
	kvm_ioeventfd_flag_nr_deassign = 2,
	kvm_ioeventfd_flag_nr_virtio_ccw_notify = 3,
	kvm_ioeventfd_flag_nr_fast_mmio = 4,
	kvm_ioeventfd_flag_nr_max = 5,
};

struct fd {
	struct file___27 *file;
	unsigned int flags;
};

struct kvm_s390_adapter_int {
	u64 ind_addr;
	u64 summary_addr;
	u64 ind_offset;
	u32 summary_offset;
	u32 adapter_id;
};

struct kvm_hv_sint {
	u32 vcpu;
	u32 sint;
};

struct kvm_kernel_irq_routing_entry {
	u32 gsi;
	u32 type;
	int (*set)(struct kvm_kernel_irq_routing_entry *, struct kvm___3 *, int, int, bool);
	union {
		struct {
			unsigned int irqchip;
			unsigned int pin;
		} irqchip;
		struct {
			u32 address_lo;
			u32 address_hi;
			u32 data;
			u32 flags;
			u32 devid;
		} msi;
		struct kvm_s390_adapter_int adapter;
		struct kvm_hv_sint hv_sint;
	};
	struct hlist_node link;
};

struct kvm_irq_ack_notifier {
	struct hlist_node link;
	unsigned int gsi;
	void (*irq_acked)(struct kvm_irq_ack_notifier *);
};

typedef struct poll_table_struct___15 poll_table;

struct kvm_kernel_irqfd_resampler {
	struct kvm___3 *kvm;
	struct list_head list;
	struct kvm_irq_ack_notifier notifier;
	struct list_head link;
};

struct kvm_kernel_irqfd {
	struct kvm___3 *kvm;
	wait_queue_entry_t wait;
	struct kvm_kernel_irq_routing_entry irq_entry;
	seqcount_t irq_entry_sc;
	int gsi;
	struct work_struct inject;
	struct kvm_kernel_irqfd_resampler *resampler;
	struct eventfd_ctx *resamplefd;
	struct list_head resampler_link;
	struct eventfd_ctx *eventfd;
	struct list_head list;
	poll_table pt;
	struct work_struct shutdown;
	struct irq_bypass_consumer consumer;
	struct irq_bypass_producer *producer;
};

struct _ioeventfd {
	struct list_head list;
	u64 addr;
	int length;
	struct eventfd_ctx *eventfd;
	u64 datamatch;
	struct kvm_io_device___2 dev;
	u8 bus_idx;
	bool wildcard;
};

struct file___28;

struct fd___2 {
	struct file___28 *file;
	unsigned int flags;
};

struct dentry___29;

struct path___27 {
	struct vfsmount *mnt;
	struct dentry___29 *dentry;
};

struct pid___23;

struct fown_struct___23 {
	rwlock_t lock;
	struct pid___23 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct inode___30;

struct file_operations___28;

struct cred___27;

struct address_space___27;

struct file___28 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___27 f_path;
	struct inode___30 *f_inode;
	const struct file_operations___28 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___23 f_owner;
	const struct cred___27 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___27 *f_mapping;
	errseq_t f_wb_err;
};

struct module___25;

struct kiocb___28;

struct poll_table_struct___16;

struct vm_area_struct___28;

struct file_lock___28;

struct page___28;

struct seq_file___25;

struct file_operations___28 {
	struct module___25 *owner;
	loff_t (*llseek)(struct file___28 *, loff_t, int);
	ssize_t (*read)(struct file___28 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___28 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___28 *, struct iov_iter___11 *);
	ssize_t (*write_iter)(struct kiocb___28 *, struct iov_iter___11 *);
	int (*iopoll)(struct kiocb___28 *, bool);
	int (*iterate)(struct file___28 *, struct dir_context *);
	int (*iterate_shared)(struct file___28 *, struct dir_context *);
	__poll_t (*poll)(struct file___28 *, struct poll_table_struct___16 *);
	long int (*unlocked_ioctl)(struct file___28 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___28 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___28 *, struct vm_area_struct___28 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___30 *, struct file___28 *);
	int (*flush)(struct file___28 *, fl_owner_t);
	int (*release)(struct inode___30 *, struct file___28 *);
	int (*fsync)(struct file___28 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___28 *, int);
	int (*lock)(struct file___28 *, int, struct file_lock___28 *);
	ssize_t (*sendpage)(struct file___28 *, struct page___28 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___28 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___28 *, int, struct file_lock___28 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___28 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___28 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___28 *, long int, struct file_lock___28 **, void **);
	long int (*fallocate)(struct file___28 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___25 *, struct file___28 *);
	ssize_t (*copy_file_range)(struct file___28 *, loff_t, struct file___28 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___28 *, loff_t, struct file___28 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___28 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct preempt_notifier___3;

struct task_struct___29;

struct preempt_ops___3 {
	void (*sched_in)(struct preempt_notifier___3 *, int);
	void (*sched_out)(struct preempt_notifier___3 *, struct task_struct___29 *);
};

struct preempt_notifier___3 {
	struct hlist_node link;
	struct preempt_ops___3 *ops;
};

struct vmacache___27 {
	u64 seqnum;
	struct vm_area_struct___28 *vmas[4];
};

struct page_frag___27 {
	struct page___28 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___13;

struct debug_info___13 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___13 *hbp_break[16];
	struct perf_event___13 *hbp_watch[16];
};

struct thread_struct___13 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___13 debug;
	long: 64;
};

struct mm_struct___28;

struct nsproxy___26;

struct signal_struct___25;

struct css_set___17;

struct perf_event_context___13;

struct vm_struct___22;

struct task_struct___29 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___29 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___28 *mm;
	struct mm_struct___28 *active_mm;
	struct vmacache___27 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___29 *real_parent;
	struct task_struct___29 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___29 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___23 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___23 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___23 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___27 *ptracer_cred;
	const struct cred___27 *real_cred;
	const struct cred___27 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___26 *nsproxy;
	struct signal_struct___25 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___29 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___3 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___17 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___13 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___27 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___29 *oom_reaper_list;
	struct vm_struct___22 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___13 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct secondary_data___28 {
	void *stack;
	struct task_struct___29 *task;
	long int status;
};

struct hw_perf_event___13 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___29 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___13)(struct perf_event___13 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___13;

struct fasync_struct___27;

struct pid_namespace___23;

struct perf_cgroup___13;

struct perf_event___13 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___13 *group_leader;
	struct pmu___13 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___13 hw;
	struct perf_event_context___13 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___13 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___29 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___27 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___13 *);
	struct callback_head callback_head;
	struct pid_namespace___23 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___13 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___13 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___5 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___13 *cgrp;
	struct list_head sb_list;
};

struct key___28;

struct user_struct___27 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___28 *uid_keyring;
	struct key___28 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct upid___23 {
	int nr;
	struct pid_namespace___23 *ns;
};

struct user_namespace___18;

struct ucounts___18;

struct pid_namespace___23 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___29 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___23 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___29 *proc_self;
	struct dentry___29 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___18 *user_ns;
	struct ucounts___18 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___2 ns;
};

struct pid___23 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___23 numbers[1];
};

struct rw_semaphore___28 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___29 *owner;
};

struct user_namespace___18 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___18 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___2 ns;
	long unsigned int flags;
	struct key___28 *persistent_keyring_register;
	struct rw_semaphore___28 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___18 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___28 *pgtable_t___27;

struct dev_pagemap___27;

struct page___28 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___27 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___28 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___27 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___28 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___27 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct vm_operations_struct___27;

struct vm_area_struct___28 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___28 *vm_next;
	struct vm_area_struct___28 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___28 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___27 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___28 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___27;

struct mm_struct___28 {
	struct {
		struct vm_area_struct___28 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___28 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___28 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___27 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___29 *owner;
		struct user_namespace___18 *user_ns;
		struct file___28 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___27 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___27 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___28 *session_keyring;
	struct key___28 *process_keyring;
	struct key___28 *thread_keyring;
	struct key___28 *request_key_auth;
	void *security;
	struct user_struct___27 *user;
	struct user_namespace___18 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___17;

struct nsproxy___26 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___23 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___17 *cgroup_ns;
};

struct signal_struct___25 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___29 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___29 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___23 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___23 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___28 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___23 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___17;

struct cgroup___17;

struct css_set___17 {
	struct cgroup_subsys_state___17 *subsys[13];
	refcount_t refcount;
	struct css_set___17 *dom_cset;
	struct cgroup___17 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___17 *mg_src_cgrp;
	struct cgroup___17 *mg_dst_cgrp;
	struct css_set___17 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___13 {
	struct pmu___13 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___29 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___13 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___22 {
	struct vm_struct___22 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___28 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___25 {
	struct task_struct___29 task;
	long unsigned int stack[8192];
};

struct pglist_data___27;

struct lruvec___27 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___27 *pgdat;
};

struct zone___27 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___27 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___27 {
	struct zone___27 *zone;
	int zone_idx;
};

struct zonelist___27 {
	struct zoneref___27 _zonerefs[25];
};

struct pglist_data___27 {
	struct zone___27 node_zones[3];
	struct zonelist___27 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___29 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___29 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___27 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___27 {
	struct rw_semaphore___28 rwsem;
	struct notifier_block *head;
};

struct address_space_operations___27;

struct address_space___27 {
	struct inode___30 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___28 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___27 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___27)(struct vm_area_struct___28 *, long unsigned int, const struct page___28 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___27)(struct page___28 *, void *);

struct device___23;

struct dev_pagemap___27 {
	dev_page_fault_t___27 page_fault;
	dev_page_free_t___27 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___23 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct vm_fault___27;

struct vm_operations_struct___27 {
	void (*open)(struct vm_area_struct___28 *);
	void (*close)(struct vm_area_struct___28 *);
	int (*split)(struct vm_area_struct___28 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___28 *);
	vm_fault_t (*fault)(struct vm_fault___27 *);
	vm_fault_t (*huge_fault)(struct vm_fault___27 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___27 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___28 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___27 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___27 *);
	int (*access)(struct vm_area_struct___28 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___28 *);
	int (*set_policy)(struct vm_area_struct___28 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___28 *, long unsigned int);
	struct page___28 * (*find_special_page)(struct vm_area_struct___28 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___27 {
	struct task_struct___29 *task;
	struct core_thread___27 *next;
};

struct core_state___27 {
	atomic_t nr_threads;
	struct core_thread___27 dumper;
	struct completion startup;
};

struct vm_fault___27 {
	struct vm_area_struct___28 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___28 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___28 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___27 prealloc_pte;
};

struct kset___25;

struct kobj_type___25;

struct kernfs_node___25;

struct kobject___26 {
	const char *name;
	struct list_head entry;
	struct kobject___26 *parent;
	struct kset___25 *kset;
	struct kobj_type___25 *ktype;
	struct kernfs_node___25 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___23 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___23 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___23;

struct bus_type___23;

struct device_driver___23;

struct dev_pm_domain___23;

struct device_node___9;

struct fwnode_handle___19;

struct class___23;

struct attribute_group___23;

struct iommu_fwspec___2;

struct device___23 {
	struct device___23 *parent;
	struct device_private *p;
	struct kobject___26 kobj;
	const char *init_name;
	const struct device_type___23 *type;
	struct mutex mutex;
	struct bus_type___23 *bus;
	struct device_driver___23 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___23 power;
	struct dev_pm_domain___23 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___9 *of_node;
	struct fwnode_handle___19 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___23 *class;
	const struct attribute_group___23 **groups;
	void (*release)(struct device___23 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec___2 *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___27;

struct super_block___28;

struct dentry___29 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___29 *d_parent;
	struct qstr d_name;
	struct inode___30 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___27 *d_op;
	struct super_block___28 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___27;

struct block_device___28;

struct inode___30 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___27 *i_op;
	struct super_block___28 *i_sb;
	struct address_space___27 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___28 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___28 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___27 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___28 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___27 {
	int (*d_revalidate)(struct dentry___29 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___29 *, unsigned int);
	int (*d_hash)(const struct dentry___29 *, struct qstr *);
	int (*d_compare)(const struct dentry___29 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___29 *);
	int (*d_init)(struct dentry___29 *);
	void (*d_release)(struct dentry___29 *);
	void (*d_prune)(struct dentry___29 *);
	void (*d_iput)(struct dentry___29 *, struct inode___30 *);
	char * (*d_dname)(struct dentry___29 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___27 *);
	int (*d_manage)(const struct path___27 *, bool);
	struct dentry___29 * (*d_real)(struct dentry___29 *, const struct inode___30 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___27;

struct mem_dqinfo___27 {
	struct quota_format_type___27 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___27;

struct quota_info___27 {
	unsigned int flags;
	struct rw_semaphore___28 dqio_sem;
	struct inode___30 *files[3];
	struct mem_dqinfo___27 info[3];
	const struct quota_format_ops___27 *ops[3];
};

struct rcuwait___27 {
	struct task_struct___29 *task;
};

struct percpu_rw_semaphore___27 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___28 rw_sem;
	struct rcuwait___27 writer;
	int readers_block;
};

struct sb_writers___27 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___27 rw_sem[3];
};

struct file_system_type___27;

struct super_operations___27;

struct dquot_operations___27;

struct quotactl_ops___27;

struct super_block___28 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___27 *s_type;
	const struct super_operations___27 *s_op;
	const struct dquot_operations___27 *dq_op;
	const struct quotactl_ops___27 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___29 *s_root;
	struct rw_semaphore___28 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___28 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___27 s_dquot;
	struct sb_writers___27 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___27 *s_d_op;
	int cleancache_poolid;
	struct shrinker___9 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___18 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___28 {
	struct file___28 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___28 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___28 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___28 *ia_file;
};

struct dquot___27 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___28 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___27 {
	int qf_fmt_id;
	const struct quota_format_ops___27 *qf_ops;
	struct module___25 *qf_owner;
	struct quota_format_type___27 *qf_next;
};

struct quota_format_ops___27 {
	int (*check_quota_file)(struct super_block___28 *, int);
	int (*read_file_info)(struct super_block___28 *, int);
	int (*write_file_info)(struct super_block___28 *, int);
	int (*free_file_info)(struct super_block___28 *, int);
	int (*read_dqblk)(struct dquot___27 *);
	int (*commit_dqblk)(struct dquot___27 *);
	int (*release_dqblk)(struct dquot___27 *);
	int (*get_next_id)(struct super_block___28 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___27 {
	int (*write_dquot)(struct dquot___27 *);
	struct dquot___27 * (*alloc_dquot)(struct super_block___28 *, int);
	void (*destroy_dquot)(struct dquot___27 *);
	int (*acquire_dquot)(struct dquot___27 *);
	int (*release_dquot)(struct dquot___27 *);
	int (*mark_dirty)(struct dquot___27 *);
	int (*write_info)(struct super_block___28 *, int);
	qsize_t * (*get_reserved_space)(struct inode___30 *);
	int (*get_projid)(struct inode___30 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___30 *, qsize_t *);
	int (*get_next_id)(struct super_block___28 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___27 {
	int (*quota_on)(struct super_block___28 *, int, int, const struct path___27 *);
	int (*quota_off)(struct super_block___28 *, int);
	int (*quota_enable)(struct super_block___28 *, unsigned int);
	int (*quota_disable)(struct super_block___28 *, unsigned int);
	int (*quota_sync)(struct super_block___28 *, int);
	int (*set_info)(struct super_block___28 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___28 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___28 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___28 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___28 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___28 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___22 {
	struct kobject___26 kobj;
	struct module___25 *mod;
	struct kobject___26 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___22 {
	struct module___25 *mod;
	struct latch_tree_node node;
};

struct module_layout___22 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___22 mtn;
};

struct module_attribute___22;

struct kernel_param___22;

struct module___25 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___22 mkobj;
	struct module_attribute___22 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___26 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___22 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___22 core_layout;
	struct module_layout___22 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___27 {
	int (*writepage)(struct page___28 *, struct writeback_control___3 *);
	int (*readpage)(struct file___28 *, struct page___28 *);
	int (*writepages)(struct address_space___27 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___28 *);
	int (*readpages)(struct file___28 *, struct address_space___27 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___28 *, struct address_space___27 *, loff_t, unsigned int, unsigned int, struct page___28 **, void **);
	int (*write_end)(struct file___28 *, struct address_space___27 *, loff_t, unsigned int, unsigned int, struct page___28 *, void *);
	sector_t (*bmap)(struct address_space___27 *, sector_t);
	void (*invalidatepage)(struct page___28 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___28 *, gfp_t);
	void (*freepage)(struct page___28 *);
	ssize_t (*direct_IO)(struct kiocb___28 *, struct iov_iter___11 *);
	int (*migratepage)(struct address_space___27 *, struct page___28 *, struct page___28 *, enum migrate_mode);
	bool (*isolate_page)(struct page___28 *, isolate_mode_t);
	void (*putback_page)(struct page___28 *);
	int (*launder_page)(struct page___28 *);
	int (*is_partially_uptodate)(struct page___28 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___28 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___27 *, struct page___28 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___28 *, sector_t *);
	void (*swap_deactivate)(struct file___28 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___28 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___30 *bd_inode;
	struct super_block___28 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___28 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___27 {
	struct dentry___29 * (*lookup)(struct inode___30 *, struct dentry___29 *, unsigned int);
	const char * (*get_link)(struct dentry___29 *, struct inode___30 *, struct delayed_call *);
	int (*permission)(struct inode___30 *, int);
	struct posix_acl * (*get_acl)(struct inode___30 *, int);
	int (*readlink)(struct dentry___29 *, char *, int);
	int (*create)(struct inode___30 *, struct dentry___29 *, umode_t, bool);
	int (*link)(struct dentry___29 *, struct inode___30 *, struct dentry___29 *);
	int (*unlink)(struct inode___30 *, struct dentry___29 *);
	int (*symlink)(struct inode___30 *, struct dentry___29 *, const char *);
	int (*mkdir)(struct inode___30 *, struct dentry___29 *, umode_t);
	int (*rmdir)(struct inode___30 *, struct dentry___29 *);
	int (*mknod)(struct inode___30 *, struct dentry___29 *, umode_t, dev_t);
	int (*rename)(struct inode___30 *, struct dentry___29 *, struct inode___30 *, struct dentry___29 *, unsigned int);
	int (*setattr)(struct dentry___29 *, struct iattr___28 *);
	int (*getattr)(const struct path___27 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___29 *, char *, size_t);
	int (*fiemap)(struct inode___30 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___30 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___30 *, struct dentry___29 *, struct file___28 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___30 *, struct dentry___29 *, umode_t);
	int (*set_acl)(struct inode___30 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___27 {
	void (*fl_copy_lock)(struct file_lock___28 *, struct file_lock___28 *);
	void (*fl_release_private)(struct file_lock___28 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___27;

struct file_lock___28 {
	struct file_lock___28 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___28 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___27 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___27 *fl_ops;
	const struct lock_manager_operations___27 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___27 {
	int (*lm_compare_owner)(struct file_lock___28 *, struct file_lock___28 *);
	long unsigned int (*lm_owner_key)(struct file_lock___28 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___28 *);
	int (*lm_grant)(struct file_lock___28 *, int);
	bool (*lm_break)(struct file_lock___28 *);
	int (*lm_change)(struct file_lock___28 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___28 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___27 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___27 *fa_next;
	struct file___28 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___27 {
	const char *name;
	int fs_flags;
	struct dentry___29 * (*mount)(struct file_system_type___27 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___28 *);
	struct module___25 *owner;
	struct file_system_type___27 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___27 {
	struct inode___30 * (*alloc_inode)(struct super_block___28 *);
	void (*destroy_inode)(struct inode___30 *);
	void (*dirty_inode)(struct inode___30 *, int);
	int (*write_inode)(struct inode___30 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___30 *);
	void (*evict_inode)(struct inode___30 *);
	void (*put_super)(struct super_block___28 *);
	int (*sync_fs)(struct super_block___28 *, int);
	int (*freeze_super)(struct super_block___28 *);
	int (*freeze_fs)(struct super_block___28 *);
	int (*thaw_super)(struct super_block___28 *);
	int (*unfreeze_fs)(struct super_block___28 *);
	int (*statfs)(struct dentry___29 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___28 *, int *, char *);
	void (*umount_begin)(struct super_block___28 *);
	int (*show_options)(struct seq_file___25 *, struct dentry___29 *);
	int (*show_devname)(struct seq_file___25 *, struct dentry___29 *);
	int (*show_path)(struct seq_file___25 *, struct dentry___29 *);
	int (*show_stats)(struct seq_file___25 *, struct dentry___29 *);
	ssize_t (*quota_read)(struct super_block___28 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___28 *, int, const char *, size_t, loff_t);
	struct dquot___27 ** (*get_dquots)(struct inode___30 *);
	int (*bdev_try_to_free_page)(struct super_block___28 *, struct page___28 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___28 *, struct shrink_control___9 *);
	long int (*free_cached_objects)(struct super_block___28 *, struct shrink_control___9 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___15)(struct file___28 *, wait_queue_head_t *, struct poll_table_struct___16 *);

struct poll_table_struct___16 {
	poll_queue_proc___15 _qproc;
	__poll_t _key;
};

struct seq_operations___22;

struct seq_file___25 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___22 *op;
	int poll_event;
	const struct file___28 *file;
	void *private;
};

struct kobj_attribute___26 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___26 *, struct kobj_attribute___26 *, char *);
	ssize_t (*store)(struct kobject___26 *, struct kobj_attribute___26 *, const char *, size_t);
};

typedef void compound_page_dtor___27(struct page___28 *);

struct mmu_notifier___3;

struct mmu_notifier_ops___3 {
	int flags;
	void (*release)(struct mmu_notifier___3 *, struct mm_struct___28 *);
	int (*clear_flush_young)(struct mmu_notifier___3 *, struct mm_struct___28 *, long unsigned int, long unsigned int);
	int (*clear_young)(struct mmu_notifier___3 *, struct mm_struct___28 *, long unsigned int, long unsigned int);
	int (*test_young)(struct mmu_notifier___3 *, struct mm_struct___28 *, long unsigned int);
	void (*change_pte)(struct mmu_notifier___3 *, struct mm_struct___28 *, long unsigned int, pte_t);
	void (*invalidate_range_start)(struct mmu_notifier___3 *, struct mm_struct___28 *, long unsigned int, long unsigned int);
	void (*invalidate_range_end)(struct mmu_notifier___3 *, struct mm_struct___28 *, long unsigned int, long unsigned int);
	void (*invalidate_range)(struct mmu_notifier___3 *, struct mm_struct___28 *, long unsigned int, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mmu_notifier___3 {
	struct hlist_node hlist;
	const struct mmu_notifier_ops___3 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct kernfs_root___25;

struct kernfs_elem_dir___25 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___25 *root;
};

struct kernfs_syscall_ops___25;

struct kernfs_root___25 {
	struct kernfs_node___25 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___25 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___25 {
	struct kernfs_node___25 *target_kn;
};

struct kernfs_ops___25;

struct kernfs_elem_attr___25 {
	const struct kernfs_ops___25 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___25 *notify_next;
};

struct kernfs_node___25 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___25 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___25 dir;
		struct kernfs_elem_symlink___25 symlink;
		struct kernfs_elem_attr___25 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___25;

struct kernfs_ops___25 {
	int (*open)(struct kernfs_open_file___25 *);
	void (*release)(struct kernfs_open_file___25 *);
	int (*seq_show)(struct seq_file___25 *, void *);
	void * (*seq_start)(struct seq_file___25 *, loff_t *);
	void * (*seq_next)(struct seq_file___25 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___25 *, void *);
	ssize_t (*read)(struct kernfs_open_file___25 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___25 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___25 *, struct vm_area_struct___28 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___25 *, struct poll_table_struct___16 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___25 {
	int (*remount_fs)(struct kernfs_root___25 *, int *, char *);
	int (*show_options)(struct seq_file___25 *, struct kernfs_root___25 *);
	int (*mkdir)(struct kernfs_node___25 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___25 *);
	int (*rename)(struct kernfs_node___25 *, struct kernfs_node___25 *, const char *);
	int (*show_path)(struct seq_file___25 *, struct kernfs_node___25 *, struct kernfs_root___25 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___25 {
	struct kernfs_node___25 *kn;
	struct file___28 *file;
	struct seq_file___25 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___27 *vm_ops;
};

struct bin_attribute___23;

struct attribute_group___23 {
	const char *name;
	umode_t (*is_visible)(struct kobject___26 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___26 *, struct bin_attribute___23 *, int);
	struct attribute **attrs;
	struct bin_attribute___23 **bin_attrs;
};

struct bin_attribute___23 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___28 *, struct kobject___26 *, struct bin_attribute___23 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___28 *, struct kobject___26 *, struct bin_attribute___23 *, char *, loff_t, size_t);
	int (*mmap)(struct file___28 *, struct kobject___26 *, struct bin_attribute___23 *, struct vm_area_struct___28 *);
};

struct sysfs_ops___25 {
	ssize_t (*show)(struct kobject___26 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___26 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___25;

struct kset___25 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___26 kobj;
	const struct kset_uevent_ops___25 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___25 {
	void (*release)(struct kobject___26 *);
	const struct sysfs_ops___25 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___26 *);
	const void * (*namespace)(struct kobject___26 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___25 {
	int (* const filter)(struct kset___25 *, struct kobject___26 *);
	const char * (* const name)(struct kset___25 *, struct kobject___26 *);
	int (* const uevent)(struct kset___25 *, struct kobject___26 *, struct kobj_uevent_env *);
};

struct fwnode_operations___19;

struct fwnode_handle___19 {
	struct fwnode_handle___19 *secondary;
	const struct fwnode_operations___19 *ops;
};

struct property___9;

struct device_node___9 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___19 fwnode;
	struct property___9 *properties;
	struct property___9 *deadprops;
	struct device_node___9 *parent;
	struct device_node___9 *child;
	struct device_node___9 *sibling;
	struct kobject___26 kobj;
	long unsigned int _flags;
	void *data;
};

struct kvm_io_device___3;

struct kvm_io_device_ops___3 {
	int (*read)(struct kvm_vcpu___2 *, struct kvm_io_device___3 *, gpa_t, int, void *);
	int (*write)(struct kvm_vcpu___2 *, struct kvm_io_device___3 *, gpa_t, int, const void *);
	void (*destructor)(struct kvm_io_device___3 *);
};

struct kvm_cpu_context___3 {
	struct kvm_regs gp_regs;
	union {
		u64 sys_regs[101];
		u32 copro[202];
	};
	struct kvm_vcpu___2 *__hyp_running_vcpu;
};

typedef struct kvm_cpu_context___3 kvm_cpu_context_t___3;

struct its_vm___3;

struct its_vpe___3 {
	struct page___28 *vpt_page;
	struct its_vm___3 *its_vm;
	int irq;
	irq_hw_number_t vpe_db_lpi;
	int vpe_proxy_event;
	u16 col_idx;
	u16 vpe_id;
	bool idai;
	bool pending_last;
};

struct vgic_v3_cpu_if___3 {
	u32 vgic_hcr;
	u32 vgic_vmcr;
	u32 vgic_sre;
	u32 vgic_ap0r[4];
	u32 vgic_ap1r[4];
	u64 vgic_lr[16];
	struct its_vpe___3 its_vpe;
};

struct vgic_irq___3 {
	raw_spinlock_t irq_lock;
	struct list_head lpi_list;
	struct list_head ap_list;
	struct kvm_vcpu___2 *vcpu;
	struct kvm_vcpu___2 *target_vcpu;
	u32 intid;
	bool line_level;
	bool pending_latch;
	bool active;
	bool enabled;
	bool hw;
	struct kref refcount;
	u32 hwintid;
	unsigned int host_irq;
	union {
		u8 targets;
		u32 mpidr;
	};
	u8 source;
	u8 active_source;
	u8 priority;
	u8 group;
	enum vgic_irq_config config;
	bool (*get_input_level)(int);
	void *owner;
};

struct kvm_io_device___3 {
	const struct kvm_io_device_ops___3 *ops;
};

struct vgic_io_device___3 {
	gpa_t base_addr;
	union {
		struct kvm_vcpu___2 *redist_vcpu;
		struct vgic_its___2 *its;
	};
	const struct vgic_register_region *regions;
	enum iodev_type iodev_type;
	int nr_regions;
	struct kvm_io_device___3 dev;
};

struct vgic_cpu___3 {
	union {
		struct vgic_v2_cpu_if vgic_v2;
		struct vgic_v3_cpu_if___3 vgic_v3;
	};
	unsigned int used_lrs;
	struct vgic_irq___3 private_irqs[32];
	raw_spinlock_t ap_list_lock;
	struct list_head ap_list_head;
	struct vgic_io_device___3 rd_iodev;
	struct vgic_io_device___3 sgi_iodev;
	struct vgic_redist_region *rdreg;
	u64 pendbaser;
	bool lpis_enabled;
	u32 num_pri_bits;
	u32 num_id_bits;
};

struct arch_timer_context___3 {
	struct kvm_vcpu___2 *vcpu;
	u32 cnt_ctl;
	u64 cnt_cval;
	struct kvm_irq_level irq;
	u64 cntvoff;
	struct hrtimer hrtimer;
	bool loaded;
	u32 host_timer_irq;
	u32 host_timer_irq_flags;
};

struct arch_timer_cpu___3 {
	struct arch_timer_context___3 timers[2];
	struct hrtimer bg_timer;
	bool enabled;
};

struct kvm_pmc___3 {
	u8 idx;
	struct perf_event___13 *perf_event;
	u64 bitmask;
};

struct kvm_pmu___3 {
	int irq_num;
	struct kvm_pmc___3 pmc[32];
	bool ready;
	bool created;
	bool irq_level;
};

struct kvm_vcpu_arch___3 {
	struct kvm_cpu_context___3 ctxt;
	void *sve_state;
	unsigned int sve_max_vl;
	u64 hcr_el2;
	u32 mdcr_el2;
	struct kvm_vcpu_fault_info fault;
	u64 workaround_flags;
	u64 flags;
	struct kvm_guest_debug_arch *debug_ptr;
	struct kvm_guest_debug_arch vcpu_debug_state;
	struct kvm_guest_debug_arch external_debug_state;
	kvm_cpu_context_t___3 *host_cpu_context;
	struct thread_info *host_thread_info;
	struct user_fpsimd_state *host_fpsimd_state;
	struct {
		struct kvm_guest_debug_arch regs;
		u64 pmscr_el1;
	} host_debug_state;
	struct vgic_cpu___3 vgic_cpu;
	struct arch_timer_cpu___3 timer_cpu;
	struct kvm_pmu___3 pmu;
	struct {
		u32 mdscr_el1;
	} guest_debug_preserved;
	bool power_off;
	bool pause;
	struct kvm_decode mmio_decode;
	struct kvm_mmu_memory_cache mmu_page_cache;
	int target;
	long unsigned int features[1];
	bool has_run_once;
	u64 vsesr_el2;
	struct vcpu_reset_state reset_state;
	bool sysregs_loaded_on_cpu;
};

struct kvm_vcpu___2 {
	struct kvm___2 *kvm;
	struct preempt_notifier___3 preempt_notifier;
	int cpu;
	int vcpu_id;
	int srcu_idx;
	int mode;
	u64 requests;
	long unsigned int guest_debug;
	int pre_pcpu;
	struct list_head blocked_vcpu_list;
	struct mutex mutex;
	struct kvm_run *run;
	int guest_xcr0_loaded;
	struct swait_queue_head wq;
	struct pid___23 *pid;
	int sigset_active;
	sigset_t sigset;
	struct kvm_vcpu_stat stat;
	unsigned int halt_poll_ns;
	bool valid_wakeup;
	int mmio_needed;
	int mmio_read_completed;
	int mmio_is_write;
	int mmio_cur_fragment;
	int mmio_nr_fragments;
	struct kvm_mmio_fragment mmio_fragments[2];
	struct {
		bool in_spin_loop;
		bool dy_eligible;
	} spin_loop;
	bool preempted;
	struct kvm_vcpu_arch___3 arch;
	struct dentry___29 *debugfs_dentry;
	long: 64;
};

struct its_vm___3 {
	struct fwnode_handle___19 *fwnode;
	struct irq_domain *domain;
	struct page___28 *vprop_page;
	struct its_vpe___3 **vpes;
	int nr_vpes;
	irq_hw_number_t db_lpi_base;
	long unsigned int *db_bitmap;
	int nr_db_lpis;
	u32 vlpi_count[16];
};

struct kvm_device___3;

struct vgic_its___2 {
	gpa_t vgic_its_base;
	bool enabled;
	struct vgic_io_device___3 iodev;
	struct kvm_device___3 *dev;
	u64 baser_device_table;
	u64 baser_coll_table;
	struct mutex cmd_lock;
	u64 cbaser;
	u32 creadr;
	u32 cwriter;
	u32 abi_rev;
	struct mutex its_lock;
	struct list_head device_list;
	struct list_head collection_list;
};

struct kvm_device_ops___3;

struct kvm_device___3 {
	struct kvm_device_ops___3 *ops;
	struct kvm___2 *kvm;
	void *private;
	struct list_head vm_node;
};

struct vgic_dist___3 {
	bool in_kernel;
	bool ready;
	bool initialized;
	u32 vgic_model;
	u32 implementation_rev;
	bool v2_groups_user_writable;
	bool msis_require_devid;
	int nr_spis;
	gpa_t vgic_dist_base;
	union {
		gpa_t vgic_cpu_base;
		struct list_head rd_regions;
	};
	bool enabled;
	struct vgic_irq___3 *spis;
	struct vgic_io_device___3 dist_iodev;
	bool has_its;
	u64 propbaser;
	raw_spinlock_t lpi_list_lock;
	struct list_head lpi_list_head;
	int lpi_list_count;
	struct vgic_state_iter *iter;
	struct its_vm___3 its_vm;
};

struct fwnode_reference_args___19;

struct fwnode_endpoint___19;

struct fwnode_operations___19 {
	struct fwnode_handle___19 * (*get)(struct fwnode_handle___19 *);
	void (*put)(struct fwnode_handle___19 *);
	bool (*device_is_available)(const struct fwnode_handle___19 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___19 *, const struct device___23 *);
	bool (*property_present)(const struct fwnode_handle___19 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___19 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___19 *, const char *, const char **, size_t);
	struct fwnode_handle___19 * (*get_parent)(const struct fwnode_handle___19 *);
	struct fwnode_handle___19 * (*get_next_child_node)(const struct fwnode_handle___19 *, struct fwnode_handle___19 *);
	struct fwnode_handle___19 * (*get_named_child_node)(const struct fwnode_handle___19 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___19 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___19 *);
	struct fwnode_handle___19 * (*graph_get_next_endpoint)(const struct fwnode_handle___19 *, struct fwnode_handle___19 *);
	struct fwnode_handle___19 * (*graph_get_remote_endpoint)(const struct fwnode_handle___19 *);
	struct fwnode_handle___19 * (*graph_get_port_parent)(struct fwnode_handle___19 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___19 *, struct fwnode_endpoint___19 *);
};

struct fwnode_endpoint___19 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___19 *local_fwnode;
};

struct fwnode_reference_args___19 {
	struct fwnode_handle___19 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct property___9 {
	char *name;
	int length;
	void *value;
	struct property___9 *next;
	long unsigned int _flags;
	struct bin_attribute___23 attr;
};

struct of_phandle_args___2 {
	struct device_node___9 *np;
	int args_count;
	uint32_t args[16];
};

struct cgroup_namespace___17 {
	refcount_t count;
	struct ns_common___2 ns;
	struct user_namespace___18 *user_ns;
	struct ucounts___18 *ucounts;
	struct css_set___17 *root_cset;
};

struct ucounts___18 {
	struct hlist_node node;
	struct user_namespace___18 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct kernel_param_ops___22 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___22 *);
	int (*get)(char *, const struct kernel_param___22 *);
	void (*free)(void *);
};

struct kparam_array___22;

struct kernel_param___22 {
	const char *name;
	struct module___25 *mod;
	const struct kernel_param_ops___22 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___22 *arr;
	};
};

struct kparam_array___22 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___22 *ops;
	void *elem;
};

struct module_attribute___22 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___22 *, struct module_kobject___22 *, char *);
	ssize_t (*store)(struct module_attribute___22 *, struct module_kobject___22 *, const char *, size_t);
	void (*setup)(struct module___25 *, const char *);
	int (*test)(struct module___25 *);
	void (*free)(struct module___25 *);
};

typedef int (*key_restrict_link_func_t___27)(struct key___28 *, const struct key_type *, const union key_payload *, struct key___28 *);

struct key_restriction___28;

struct key___28 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___28 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___28 *restrict_link;
};

struct key_restriction___28 {
	key_restrict_link_func_t___27 check;
	struct key___28 *key;
	struct key_type *keytype;
};

struct dev_pm_ops___23 {
	int (*prepare)(struct device___23 *);
	void (*complete)(struct device___23 *);
	int (*suspend)(struct device___23 *);
	int (*resume)(struct device___23 *);
	int (*freeze)(struct device___23 *);
	int (*thaw)(struct device___23 *);
	int (*poweroff)(struct device___23 *);
	int (*restore)(struct device___23 *);
	int (*suspend_late)(struct device___23 *);
	int (*resume_early)(struct device___23 *);
	int (*freeze_late)(struct device___23 *);
	int (*thaw_early)(struct device___23 *);
	int (*poweroff_late)(struct device___23 *);
	int (*restore_early)(struct device___23 *);
	int (*suspend_noirq)(struct device___23 *);
	int (*resume_noirq)(struct device___23 *);
	int (*freeze_noirq)(struct device___23 *);
	int (*thaw_noirq)(struct device___23 *);
	int (*poweroff_noirq)(struct device___23 *);
	int (*restore_noirq)(struct device___23 *);
	int (*runtime_suspend)(struct device___23 *);
	int (*runtime_resume)(struct device___23 *);
	int (*runtime_idle)(struct device___23 *);
};

struct dev_pm_domain___23 {
	struct dev_pm_ops___23 ops;
	void (*detach)(struct device___23 *, bool);
	int (*activate)(struct device___23 *);
	void (*sync)(struct device___23 *);
	void (*dismiss)(struct device___23 *);
};

struct iommu_ops___2;

struct bus_type___23 {
	const char *name;
	const char *dev_name;
	struct device___23 *dev_root;
	const struct attribute_group___23 **bus_groups;
	const struct attribute_group___23 **dev_groups;
	const struct attribute_group___23 **drv_groups;
	int (*match)(struct device___23 *, struct device_driver___23 *);
	int (*uevent)(struct device___23 *, struct kobj_uevent_env *);
	int (*probe)(struct device___23 *);
	int (*remove)(struct device___23 *);
	void (*shutdown)(struct device___23 *);
	int (*online)(struct device___23 *);
	int (*offline)(struct device___23 *);
	int (*suspend)(struct device___23 *, pm_message_t);
	int (*resume)(struct device___23 *);
	int (*num_vf)(struct device___23 *);
	int (*dma_configure)(struct device___23 *);
	const struct dev_pm_ops___23 *pm;
	const struct iommu_ops___2 *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___23 {
	const char *name;
	struct bus_type___23 *bus;
	struct module___25 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___23 *);
	int (*remove)(struct device___23 *);
	void (*shutdown)(struct device___23 *);
	int (*suspend)(struct device___23 *, pm_message_t);
	int (*resume)(struct device___23 *);
	const struct attribute_group___23 **groups;
	const struct dev_pm_ops___23 *pm;
	void (*coredump)(struct device___23 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct iommu_domain___2;

struct iommu_ops___2 {
	bool (*capable)(enum iommu_cap);
	struct iommu_domain___2 * (*domain_alloc)(unsigned int);
	void (*domain_free)(struct iommu_domain___2 *);
	int (*attach_dev)(struct iommu_domain___2 *, struct device___23 *);
	void (*detach_dev)(struct iommu_domain___2 *, struct device___23 *);
	int (*map)(struct iommu_domain___2 *, long unsigned int, phys_addr_t, size_t, int);
	size_t (*unmap)(struct iommu_domain___2 *, long unsigned int, size_t);
	void (*flush_iotlb_all)(struct iommu_domain___2 *);
	void (*iotlb_range_add)(struct iommu_domain___2 *, long unsigned int, size_t);
	void (*iotlb_sync)(struct iommu_domain___2 *);
	phys_addr_t (*iova_to_phys)(struct iommu_domain___2 *, dma_addr_t);
	int (*add_device)(struct device___23 *);
	void (*remove_device)(struct device___23 *);
	struct iommu_group * (*device_group)(struct device___23 *);
	int (*domain_get_attr)(struct iommu_domain___2 *, enum iommu_attr, void *);
	int (*domain_set_attr)(struct iommu_domain___2 *, enum iommu_attr, void *);
	void (*get_resv_regions)(struct device___23 *, struct list_head *);
	void (*put_resv_regions)(struct device___23 *, struct list_head *);
	void (*apply_resv_region)(struct device___23 *, struct iommu_domain___2 *, struct iommu_resv_region *);
	int (*domain_window_enable)(struct iommu_domain___2 *, u32, phys_addr_t, u64, int);
	void (*domain_window_disable)(struct iommu_domain___2 *, u32);
	int (*domain_set_windows)(struct iommu_domain___2 *, u32);
	u32 (*domain_get_windows)(struct iommu_domain___2 *);
	int (*of_xlate)(struct device___23 *, struct of_phandle_args___2 *);
	bool (*is_attach_deferred)(struct iommu_domain___2 *, struct device___23 *);
	long unsigned int pgsize_bitmap;
};

struct device_type___23 {
	const char *name;
	const struct attribute_group___23 **groups;
	int (*uevent)(struct device___23 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___23 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___23 *);
	const struct dev_pm_ops___23 *pm;
};

struct class___23 {
	const char *name;
	struct module___25 *owner;
	const struct attribute_group___23 **class_groups;
	const struct attribute_group___23 **dev_groups;
	struct kobject___26 *dev_kobj;
	int (*dev_uevent)(struct device___23 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___23 *, umode_t *);
	void (*class_release)(struct class___23 *);
	void (*dev_release)(struct device___23 *);
	int (*shutdown_pre)(struct device___23 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___23 *);
	const struct dev_pm_ops___23 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct iommu_fwspec___2 {
	const struct iommu_ops___2 *ops;
	struct fwnode_handle___19 *iommu_fwnode;
	void *iommu_priv;
	unsigned int num_ids;
	u32 ids[1];
};

struct node___21 {
	struct device___23 dev;
};

struct seq_operations___22 {
	void * (*start)(struct seq_file___25 *, loff_t *);
	void (*stop)(struct seq_file___25 *, void *);
	void * (*next)(struct seq_file___25 *, void *, loff_t *);
	int (*show)(struct seq_file___25 *, void *);
};

struct bpf_map___17;

struct bpf_map_ops___17 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___17 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___17 *, struct file___28 *);
	void (*map_free)(struct bpf_map___17 *);
	int (*map_get_next_key)(struct bpf_map___17 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___17 *);
	void * (*map_lookup_elem)(struct bpf_map___17 *, void *);
	int (*map_update_elem)(struct bpf_map___17 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___17 *, void *);
	int (*map_push_elem)(struct bpf_map___17 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___17 *, void *);
	int (*map_peek_elem)(struct bpf_map___17 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___17 *, struct file___28 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___17 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___17 *, void *, struct seq_file___25 *);
	int (*map_check_btf)(const struct bpf_map___17 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___17 {
	const struct bpf_map_ops___17 *ops;
	struct bpf_map___17 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___27 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___17;

typedef void (*kthread_work_func_t___17)(struct kthread_work___17 *);

struct kthread_worker___17;

struct kthread_work___17 {
	struct list_head node;
	kthread_work_func_t___17 func;
	struct kthread_worker___17 *worker;
	int canceling;
};

struct kthread_worker___17 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___29 *task;
	struct kthread_work___17 *current_work;
};

struct kthread_delayed_work___17 {
	struct kthread_work___17 work;
	struct timer_list timer;
};

struct psi_group___17 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___17 *poll_kworker;
	struct kthread_delayed_work___17 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___17 {
	struct kernfs_node___25 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___17;

struct cgroup_subsys_state___17 {
	struct cgroup___17 *cgroup;
	struct cgroup_subsys___17 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___17 *parent;
};

struct cgroup_root___17;

struct cgroup_rstat_cpu___17;

struct cgroup___17 {
	struct cgroup_subsys_state___17 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___25 *kn;
	struct cgroup_file___17 procs_file;
	struct cgroup_file___17 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___17 *subsys[13];
	struct cgroup_root___17 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___17 *dom_cgrp;
	struct cgroup_rstat_cpu___17 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___2 bpf;
	atomic_t congestion_count;
	struct cgroup___17 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___17 psi;
	int ancestor_ids[0];
};

struct cftype___17;

struct cgroup_subsys___17 {
	struct cgroup_subsys_state___17 * (*css_alloc)(struct cgroup_subsys_state___17 *);
	int (*css_online)(struct cgroup_subsys_state___17 *);
	void (*css_offline)(struct cgroup_subsys_state___17 *);
	void (*css_released)(struct cgroup_subsys_state___17 *);
	void (*css_free)(struct cgroup_subsys_state___17 *);
	void (*css_reset)(struct cgroup_subsys_state___17 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___17 *, int);
	int (*css_extra_stat_show)(struct seq_file___25 *, struct cgroup_subsys_state___17 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___29 *);
	void (*cancel_fork)(struct task_struct___29 *);
	void (*fork)(struct task_struct___29 *);
	void (*exit)(struct task_struct___29 *);
	void (*free)(struct task_struct___29 *);
	void (*bind)(struct cgroup_subsys_state___17 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___17 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___17 *dfl_cftypes;
	struct cftype___17 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___17 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___17 *updated_children;
	struct cgroup___17 *updated_next;
};

struct cgroup_root___17 {
	struct kernfs_root___25 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___17 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___17 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___17 *ss;
	struct list_head node;
	struct kernfs_ops___25 *kf_ops;
	int (*open)(struct kernfs_open_file___25 *);
	void (*release)(struct kernfs_open_file___25 *);
	u64 (*read_u64)(struct cgroup_subsys_state___17 *, struct cftype___17 *);
	s64 (*read_s64)(struct cgroup_subsys_state___17 *, struct cftype___17 *);
	int (*seq_show)(struct seq_file___25 *, void *);
	void * (*seq_start)(struct seq_file___25 *, loff_t *);
	void * (*seq_next)(struct seq_file___25 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___25 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___17 *, struct cftype___17 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___17 *, struct cftype___17 *, s64);
	ssize_t (*write)(struct kernfs_open_file___25 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___25 *, struct poll_table_struct___16 *);
};

struct perf_cpu_context___13;

struct pmu___13 {
	struct list_head entry;
	struct module___25 *module;
	struct device___23 *dev;
	const struct attribute_group___23 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___13 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___13 *);
	void (*pmu_disable)(struct pmu___13 *);
	int (*event_init)(struct perf_event___13 *);
	void (*event_mapped)(struct perf_event___13 *, struct mm_struct___28 *);
	void (*event_unmapped)(struct perf_event___13 *, struct mm_struct___28 *);
	int (*add)(struct perf_event___13 *, int);
	void (*del)(struct perf_event___13 *, int);
	void (*start)(struct perf_event___13 *, int);
	void (*stop)(struct perf_event___13 *, int);
	void (*read)(struct perf_event___13 *);
	void (*start_txn)(struct pmu___13 *, unsigned int);
	int (*commit_txn)(struct pmu___13 *);
	void (*cancel_txn)(struct pmu___13 *);
	int (*event_idx)(struct perf_event___13 *);
	void (*sched_task)(struct perf_event_context___13 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___13 *);
	int (*filter_match)(struct perf_event___13 *);
	int (*check_period)(struct perf_event___13 *, u64);
};

struct perf_cpu_context___13 {
	struct perf_event_context___13 ctx;
	struct perf_event_context___13 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___13 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___13 {
	struct cgroup_subsys_state___17 css;
	struct perf_cgroup_info *info;
};

struct kvm_arch___3 {
	struct kvm_vmid vmid;
	pgd_t *pgd;
	phys_addr_t pgd_phys;
	u64 vtcr;
	int *last_vcpu_ran;
	int max_vcpus;
	struct vgic_dist___3 vgic;
	u32 psci_version;
};

struct kvm_io_range___3 {
	gpa_t addr;
	int len;
	struct kvm_io_device___3 *dev;
};

struct kvm_io_bus___3 {
	int dev_count;
	int ioeventfd_count;
	struct kvm_io_range___3 range[0];
};

struct kvm_stat_data___3;

struct kvm___2 {
	spinlock_t mmu_lock;
	struct mutex slots_lock;
	struct mm_struct___28 *mm;
	struct kvm_memslots *memslots[1];
	struct kvm_vcpu___2 *vcpus[512];
	atomic_t online_vcpus;
	int created_vcpus;
	int last_boosted_vcpu;
	struct list_head vm_list;
	struct mutex lock;
	struct kvm_io_bus___3 *buses[4];
	struct {
		spinlock_t lock;
		struct list_head items;
		struct list_head resampler_list;
		struct mutex resampler_lock;
	} irqfds;
	struct list_head ioeventfds;
	struct kvm_vm_stat stat;
	struct kvm_arch___3 arch;
	refcount_t users_count;
	struct kvm_coalesced_mmio_ring *coalesced_mmio_ring;
	spinlock_t ring_lock;
	struct list_head coalesced_zones;
	struct mutex irq_lock;
	struct kvm_irq_routing_table *irq_routing;
	struct hlist_head irq_ack_notifier_list;
	struct mmu_notifier___3 mmu_notifier;
	long unsigned int mmu_notifier_seq;
	long int mmu_notifier_count;
	long int tlbs_dirty;
	struct list_head devices;
	bool manual_dirty_log_protect;
	struct dentry___29 *debugfs_dentry;
	struct kvm_stat_data___3 **debugfs_stat_data;
	struct srcu_struct srcu;
	struct srcu_struct irq_srcu;
	pid_t userspace_pid;
};

struct kvm_stat_data___3 {
	int offset;
	int mode;
	struct kvm___2 *kvm;
};

struct kvm_device_ops___3 {
	const char *name;
	int (*create)(struct kvm_device___3 *, u32);
	void (*init)(struct kvm_device___3 *);
	void (*destroy)(struct kvm_device___3 *);
	void (*release)(struct kvm_device___3 *);
	int (*set_attr)(struct kvm_device___3 *, struct kvm_device_attr *);
	int (*get_attr)(struct kvm_device___3 *, struct kvm_device_attr *);
	int (*has_attr)(struct kvm_device___3 *, struct kvm_device_attr *);
	long int (*ioctl)(struct kvm_device___3 *, unsigned int, long unsigned int);
	int (*mmap)(struct kvm_device___3 *, struct vm_area_struct___28 *);
};

typedef int (*iommu_fault_handler_t___2)(struct iommu_domain___2 *, struct device___23 *, long unsigned int, int, void *);

struct iommu_domain___2 {
	unsigned int type;
	const struct iommu_ops___2 *ops;
	long unsigned int pgsize_bitmap;
	iommu_fault_handler_t___2 handler;
	void *handler_token;
	struct iommu_domain_geometry geometry;
	void *iova_cookie;
};

struct vfio_group;

struct kvm_vfio_group {
	struct list_head node;
	struct vfio_group *vfio_group;
};

struct kvm_vfio {
	struct list_head group_list;
	struct mutex lock;
	bool noncoherent;
};

struct kvm_vcpu_init {
	__u32 target;
	__u32 features[7];
};

struct kvm_vcpu_events {
	struct {
		__u8 serror_pending;
		__u8 serror_has_esr;
		__u8 pad[6];
		__u64 serror_esr;
	} exception;
	__u32 reserved[12];
};

struct kvm_reg_list {
	__u64 n;
	__u64 reg[0];
};

struct kvm_one_reg {
	__u64 id;
	__u64 addr;
};

struct kvm_arm_device_addr {
	__u64 id;
	__u64 addr;
};

struct timer_map {
	struct arch_timer_context___2 *direct_vtimer;
	struct arch_timer_context___2 *direct_ptimer;
	struct arch_timer_context___2 *emul_ptimer;
};

struct trace_event_raw_kvm_entry {
	struct trace_entry ent;
	long unsigned int vcpu_pc;
	char __data[0];
};

struct trace_event_raw_kvm_exit {
	struct trace_entry ent;
	int ret;
	unsigned int esr_ec;
	long unsigned int vcpu_pc;
	char __data[0];
};

struct trace_event_raw_kvm_guest_fault {
	struct trace_entry ent;
	long unsigned int vcpu_pc;
	long unsigned int hsr;
	long unsigned int hxfar;
	long long unsigned int ipa;
	char __data[0];
};

struct trace_event_raw_kvm_access_fault {
	struct trace_entry ent;
	long unsigned int ipa;
	char __data[0];
};

struct trace_event_raw_kvm_irq_line {
	struct trace_entry ent;
	unsigned int type;
	int vcpu_idx;
	int irq_num;
	int level;
	char __data[0];
};

struct trace_event_raw_kvm_mmio_emulate {
	struct trace_entry ent;
	long unsigned int vcpu_pc;
	long unsigned int instr;
	long unsigned int cpsr;
	char __data[0];
};

struct trace_event_raw_kvm_unmap_hva_range {
	struct trace_entry ent;
	long unsigned int start;
	long unsigned int end;
	char __data[0];
};

struct trace_event_raw_kvm_set_spte_hva {
	struct trace_entry ent;
	long unsigned int hva;
	char __data[0];
};

struct trace_event_raw_kvm_age_hva {
	struct trace_entry ent;
	long unsigned int start;
	long unsigned int end;
	char __data[0];
};

struct trace_event_raw_kvm_test_age_hva {
	struct trace_entry ent;
	long unsigned int hva;
	char __data[0];
};

struct trace_event_raw_kvm_set_way_flush {
	struct trace_entry ent;
	long unsigned int vcpu_pc;
	bool cache;
	char __data[0];
};

struct trace_event_raw_kvm_toggle_cache {
	struct trace_entry ent;
	long unsigned int vcpu_pc;
	bool was;
	bool now;
	char __data[0];
};

struct trace_event_raw_kvm_timer_update_irq {
	struct trace_entry ent;
	long unsigned int vcpu_id;
	__u32 irq;
	int level;
	char __data[0];
};

struct trace_event_raw_kvm_get_timer_map {
	struct trace_entry ent;
	long unsigned int vcpu_id;
	int direct_vtimer;
	int direct_ptimer;
	int emul_ptimer;
	char __data[0];
};

struct trace_event_raw_kvm_timer_save_state {
	struct trace_entry ent;
	long unsigned int ctl;
	long long unsigned int cval;
	int timer_idx;
	char __data[0];
};

struct trace_event_raw_kvm_timer_restore_state {
	struct trace_entry ent;
	long unsigned int ctl;
	long long unsigned int cval;
	int timer_idx;
	char __data[0];
};

struct trace_event_raw_kvm_timer_hrtimer_expire {
	struct trace_entry ent;
	int timer_idx;
	char __data[0];
};

struct trace_event_raw_kvm_timer_emulate {
	struct trace_entry ent;
	int timer_idx;
	bool should_fire;
	char __data[0];
};

struct trace_event_data_offsets_kvm_entry {};

struct trace_event_data_offsets_kvm_exit {};

struct trace_event_data_offsets_kvm_guest_fault {};

struct trace_event_data_offsets_kvm_access_fault {};

struct trace_event_data_offsets_kvm_irq_line {};

struct trace_event_data_offsets_kvm_mmio_emulate {};

struct trace_event_data_offsets_kvm_unmap_hva_range {};

struct trace_event_data_offsets_kvm_set_spte_hva {};

struct trace_event_data_offsets_kvm_age_hva {};

struct trace_event_data_offsets_kvm_test_age_hva {};

struct trace_event_data_offsets_kvm_set_way_flush {};

struct trace_event_data_offsets_kvm_toggle_cache {};

struct trace_event_data_offsets_kvm_timer_update_irq {};

struct trace_event_data_offsets_kvm_get_timer_map {};

struct trace_event_data_offsets_kvm_timer_save_state {};

struct trace_event_data_offsets_kvm_timer_restore_state {};

struct trace_event_data_offsets_kvm_timer_hrtimer_expire {};

struct trace_event_data_offsets_kvm_timer_emulate {};

typedef long unsigned int hva_t;

struct hugepage_subpool___2 {
	spinlock_t lock;
	long int count;
	long int max_hpages;
	long int used_hpages;
	struct hstate___3 *hstate;
	long int min_hpages;
	long int rsv_hpages;
};

struct hugetlbfs_sb_info___2 {
	long int max_inodes;
	long int free_inodes;
	spinlock_t stat_lock;
	struct hstate___3 *hstate;
	struct hugepage_subpool___2 *spool;
	kuid_t uid;
	kgid_t gid;
	umode_t mode;
};

enum exception_type {
	except_type_sync = 0,
	except_type_irq = 128,
	except_type_fiq = 256,
	except_type_serror = 384,
};

struct sys_reg_params;

struct sys_reg_desc {
	const char *name;
	u8 Op0;
	u8 Op1;
	u8 CRn;
	u8 CRm;
	u8 Op2;
	bool (*access)(struct kvm_vcpu___3 *, struct sys_reg_params *, const struct sys_reg_desc *);
	void (*reset)(struct kvm_vcpu___3 *, const struct sys_reg_desc *);
	int reg;
	u64 val;
	int (*__get_user)(struct kvm_vcpu___3 *, const struct sys_reg_desc *, const struct kvm_one_reg *, void *);
	int (*set_user)(struct kvm_vcpu___3 *, const struct sys_reg_desc *, const struct kvm_one_reg *, void *);
	unsigned int (*visibility)(const struct kvm_vcpu___3 *, const struct sys_reg_desc *);
};

struct sys_reg_params {
	u8 Op0;
	u8 Op1;
	u8 CRn;
	u8 CRm;
	u8 Op2;
	u64 regval;
	bool is_write;
	bool is_aarch32;
	bool is_32bit;
};

struct trace_event_raw_kvm_wfx_arm64 {
	struct trace_entry ent;
	long unsigned int vcpu_pc;
	bool is_wfe;
	char __data[0];
};

struct trace_event_raw_kvm_hvc_arm64 {
	struct trace_entry ent;
	long unsigned int vcpu_pc;
	long unsigned int r0;
	long unsigned int imm;
	char __data[0];
};

struct trace_event_raw_kvm_arm_setup_debug {
	struct trace_entry ent;
	struct kvm_vcpu___3 *vcpu;
	__u32 guest_debug;
	char __data[0];
};

struct trace_event_raw_kvm_arm_clear_debug {
	struct trace_entry ent;
	__u32 guest_debug;
	char __data[0];
};

struct trace_event_raw_kvm_arm_set_dreg32 {
	struct trace_entry ent;
	const char *name;
	__u32 value;
	char __data[0];
};

struct trace_event_raw_kvm_arm_set_regset {
	struct trace_entry ent;
	const char *name;
	int len;
	u64 ctrls[16];
	u64 values[16];
	char __data[0];
};

struct trace_event_raw_trap_reg {
	struct trace_entry ent;
	const char *fn;
	int reg;
	bool is_write;
	u64 write_value;
	char __data[0];
};

struct trace_event_raw_kvm_handle_sys_reg {
	struct trace_entry ent;
	long unsigned int hsr;
	char __data[0];
};

struct trace_event_raw_kvm_sys_access {
	struct trace_entry ent;
	long unsigned int vcpu_pc;
	bool is_write;
	const char *name;
	u8 Op0;
	u8 Op1;
	u8 CRn;
	u8 CRm;
	u8 Op2;
	char __data[0];
};

struct trace_event_raw_kvm_set_guest_debug {
	struct trace_entry ent;
	struct kvm_vcpu___3 *vcpu;
	__u32 guest_debug;
	char __data[0];
};

struct trace_event_data_offsets_kvm_wfx_arm64 {};

struct trace_event_data_offsets_kvm_hvc_arm64 {};

struct trace_event_data_offsets_kvm_arm_setup_debug {};

struct trace_event_data_offsets_kvm_arm_clear_debug {};

struct trace_event_data_offsets_kvm_arm_set_dreg32 {};

struct trace_event_data_offsets_kvm_arm_set_regset {};

struct trace_event_data_offsets_trap_reg {};

struct trace_event_data_offsets_kvm_handle_sys_reg {};

struct trace_event_data_offsets_kvm_sys_access {};

struct trace_event_data_offsets_kvm_set_guest_debug {};

typedef int (*exit_handle_fn)(struct kvm_vcpu___3 *, struct kvm_run *);

struct sve_state_reg_region {
	unsigned int koffset;
	unsigned int klen;
	unsigned int upad;
};

enum kvm_arch_timer_regs {
	TIMER_REG_CNT = 0,
	TIMER_REG_CVAL = 1,
	TIMER_REG_TVAL = 2,
	TIMER_REG_CTL = 3,
};

struct kvm_sys_reg_table {
	const struct sys_reg_desc *table;
	size_t num;
};

struct kvm_sys_reg_target_table {
	struct kvm_sys_reg_table table64;
	struct kvm_sys_reg_table table32;
};

struct vgic_vmcr {
	u32 grpen0;
	u32 grpen1;
	u32 ackctl;
	u32 fiqen;
	u32 cbpr;
	u32 eoim;
	u32 abpr;
	u32 bpr;
	u32 pmr;
};

struct module___26;

struct file___29;

struct kiocb___29;

struct poll_table_struct___17;

struct vm_area_struct___29;

struct inode___31;

struct file_lock___29;

struct page___29;

struct seq_file___26;

struct file_operations___29 {
	struct module___26 *owner;
	loff_t (*llseek)(struct file___29 *, loff_t, int);
	ssize_t (*read)(struct file___29 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___29 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___29 *, struct iov_iter___11 *);
	ssize_t (*write_iter)(struct kiocb___29 *, struct iov_iter___11 *);
	int (*iopoll)(struct kiocb___29 *, bool);
	int (*iterate)(struct file___29 *, struct dir_context *);
	int (*iterate_shared)(struct file___29 *, struct dir_context *);
	__poll_t (*poll)(struct file___29 *, struct poll_table_struct___17 *);
	long int (*unlocked_ioctl)(struct file___29 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___29 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___29 *, struct vm_area_struct___29 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___31 *, struct file___29 *);
	int (*flush)(struct file___29 *, fl_owner_t);
	int (*release)(struct inode___31 *, struct file___29 *);
	int (*fsync)(struct file___29 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___29 *, int);
	int (*lock)(struct file___29 *, int, struct file_lock___29 *);
	ssize_t (*sendpage)(struct file___29 *, struct page___29 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___29 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___29 *, int, struct file_lock___29 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___29 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___29 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___29 *, long int, struct file_lock___29 **, void **);
	long int (*fallocate)(struct file___29 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___26 *, struct file___29 *);
	ssize_t (*copy_file_range)(struct file___29 *, loff_t, struct file___29 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___29 *, loff_t, struct file___29 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___29 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct preempt_notifier___4;

struct task_struct___30;

struct preempt_ops___4 {
	void (*sched_in)(struct preempt_notifier___4 *, int);
	void (*sched_out)(struct preempt_notifier___4 *, struct task_struct___30 *);
};

struct preempt_notifier___4 {
	struct hlist_node link;
	struct preempt_ops___4 *ops;
};

struct vmacache___28 {
	u64 seqnum;
	struct vm_area_struct___29 *vmas[4];
};

struct page_frag___28 {
	struct page___29 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___14;

struct debug_info___14 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___14 *hbp_break[16];
	struct perf_event___14 *hbp_watch[16];
};

struct thread_struct___14 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___14 debug;
	long: 64;
};

struct mm_struct___29;

struct pid___24;

struct cred___28;

struct nsproxy___27;

struct signal_struct___26;

struct css_set___18;

struct perf_event_context___14;

struct vm_struct___23;

struct task_struct___30 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___30 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___29 *mm;
	struct mm_struct___29 *active_mm;
	struct vmacache___28 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___30 *real_parent;
	struct task_struct___30 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___30 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___24 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___24 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___24 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___28 *ptracer_cred;
	const struct cred___28 *real_cred;
	const struct cred___28 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___27 *nsproxy;
	struct signal_struct___26 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___30 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___3 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___18 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___14 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___28 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___30 *oom_reaper_list;
	struct vm_struct___23 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___14 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct secondary_data___29 {
	void *stack;
	struct task_struct___30 *task;
	long int status;
};

struct hw_perf_event___14 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___30 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___14)(struct perf_event___14 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___14;

struct fasync_struct___28;

struct pid_namespace___24;

struct trace_event_call___11;

struct perf_cgroup___14;

struct perf_event___14 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___14 *group_leader;
	struct pmu___14 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___14 hw;
	struct perf_event_context___14 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___14 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___30 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___28 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___14 *);
	struct callback_head callback_head;
	struct pid_namespace___24 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___14 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___14 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___11 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___14 *cgrp;
	struct list_head sb_list;
};

struct irqaction___3 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___3 *next;
	irq_handler_t thread_fn;
	struct task_struct___30 *thread;
	struct irqaction___3 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_desc___3;

typedef void (*irq_flow_handler_t___3)(struct irq_desc___3 *);

struct irq_chip___4;

struct irq_data___4 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data *common;
	struct irq_chip___4 *chip;
	struct irq_domain *domain;
	struct irq_data___4 *parent_data;
	void *chip_data;
};

struct kset___26;

struct kobj_type___26;

struct kernfs_node___26;

struct kobject___27 {
	const char *name;
	struct list_head entry;
	struct kobject___27 *parent;
	struct kset___26 *kset;
	struct kobj_type___26 *ktype;
	struct kernfs_node___26 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct irq_desc___3 {
	struct irq_common_data irq_common_data;
	struct irq_data___4 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___3 handle_irq;
	struct irqaction___3 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int irq_count;
	unsigned int tot_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___27 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___26 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___29 *pgtable_t___28;

struct address_space___28;

struct dev_pagemap___28;

struct page___29 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___28 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___29 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___28 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___29 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___28 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___28;

struct lruvec___28 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___28 *pgdat;
};

struct zone___28 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___28 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___28 {
	struct zone___28 *zone;
	int zone_idx;
};

struct zonelist___28 {
	struct zoneref___28 _zonerefs[25];
};

struct pglist_data___28 {
	struct zone___28 node_zones[3];
	struct zonelist___28 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___30 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___30 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___28 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___29 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___30 *owner;
};

struct blocking_notifier_head___28 {
	struct rw_semaphore___29 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___28;

struct vm_area_struct___29 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___29 *vm_next;
	struct vm_area_struct___29 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___29 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___28 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___29 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___28;

struct user_namespace___19;

struct mm_struct___29 {
	struct {
		struct vm_area_struct___29 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___29 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___29 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___28 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___30 *owner;
		struct user_namespace___19 *user_ns;
		struct file___29 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___28 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___28;

struct address_space___28 {
	struct inode___31 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___29 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___28 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___28)(struct vm_area_struct___29 *, long unsigned int, const struct page___29 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___28)(struct page___29 *, void *);

struct device___24;

struct dev_pagemap___28 {
	dev_page_fault_t___28 page_fault;
	dev_page_free_t___28 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___24 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct dentry___30;

struct path___28 {
	struct vfsmount *mnt;
	struct dentry___30 *dentry;
};

struct fown_struct___24 {
	rwlock_t lock;
	struct pid___24 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___29 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___28 f_path;
	struct inode___31 *f_inode;
	const struct file_operations___29 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___24 f_owner;
	const struct cred___28 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___28 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___28;

struct vm_operations_struct___28 {
	void (*open)(struct vm_area_struct___29 *);
	void (*close)(struct vm_area_struct___29 *);
	int (*split)(struct vm_area_struct___29 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___29 *);
	vm_fault_t (*fault)(struct vm_fault___28 *);
	vm_fault_t (*huge_fault)(struct vm_fault___28 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___28 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___29 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___28 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___28 *);
	int (*access)(struct vm_area_struct___29 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___29 *);
	int (*set_policy)(struct vm_area_struct___29 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___29 *, long unsigned int);
	struct page___29 * (*find_special_page)(struct vm_area_struct___29 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___28 {
	struct task_struct___30 *task;
	struct core_thread___28 *next;
};

struct core_state___28 {
	atomic_t nr_threads;
	struct core_thread___28 dumper;
	struct completion startup;
};

struct key___29;

struct ucounts___19;

struct user_namespace___19 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___19 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___2 ns;
	long unsigned int flags;
	struct key___29 *persistent_keyring_register;
	struct rw_semaphore___29 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___19 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___28 {
	struct vm_area_struct___29 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___29 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___29 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___28 prealloc_pte;
};

struct upid___24 {
	int nr;
	struct pid_namespace___24 *ns;
};

struct pid_namespace___24 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___30 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___24 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___30 *proc_self;
	struct dentry___30 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___19 *user_ns;
	struct ucounts___19 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___2 ns;
};

struct pid___24 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___24 numbers[1];
};

struct user_struct___28 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___29 *uid_keyring;
	struct key___29 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___28 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___29 *session_keyring;
	struct key___29 *process_keyring;
	struct key___29 *thread_keyring;
	struct key___29 *request_key_auth;
	void *security;
	struct user_struct___28 *user;
	struct user_namespace___19 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___18;

struct nsproxy___27 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___24 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___18 *cgroup_ns;
};

struct signal_struct___26 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___30 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___30 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___24 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___24 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___29 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___24 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___18;

struct cgroup___18;

struct css_set___18 {
	struct cgroup_subsys_state___18 *subsys[13];
	refcount_t refcount;
	struct css_set___18 *dom_cset;
	struct cgroup___18 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___18 *mg_src_cgrp;
	struct cgroup___18 *mg_dst_cgrp;
	struct css_set___18 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___14 {
	struct pmu___14 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___30 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___14 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___23 {
	struct vm_struct___23 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___29 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___26 {
	struct task_struct___30 task;
	long unsigned int stack[8192];
};

struct fwnode_operations___20;

struct fwnode_handle___20 {
	struct fwnode_handle___20 *secondary;
	const struct fwnode_operations___20 *ops;
};

struct fwnode_reference_args___20;

struct fwnode_endpoint___20;

struct fwnode_operations___20 {
	struct fwnode_handle___20 * (*get)(struct fwnode_handle___20 *);
	void (*put)(struct fwnode_handle___20 *);
	bool (*device_is_available)(const struct fwnode_handle___20 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___20 *, const struct device___24 *);
	bool (*property_present)(const struct fwnode_handle___20 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___20 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___20 *, const char *, const char **, size_t);
	struct fwnode_handle___20 * (*get_parent)(const struct fwnode_handle___20 *);
	struct fwnode_handle___20 * (*get_next_child_node)(const struct fwnode_handle___20 *, struct fwnode_handle___20 *);
	struct fwnode_handle___20 * (*get_named_child_node)(const struct fwnode_handle___20 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___20 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___20 *);
	struct fwnode_handle___20 * (*graph_get_next_endpoint)(const struct fwnode_handle___20 *, struct fwnode_handle___20 *);
	struct fwnode_handle___20 * (*graph_get_remote_endpoint)(const struct fwnode_handle___20 *);
	struct fwnode_handle___20 * (*graph_get_port_parent)(struct fwnode_handle___20 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___20 *, struct fwnode_endpoint___20 *);
};

struct fwnode_endpoint___20 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___20 *local_fwnode;
};

struct fwnode_reference_args___20 {
	struct fwnode_handle___20 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct dev_pm_info___24 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___24 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___24;

struct bus_type___24;

struct device_driver___24;

struct dev_pm_domain___24;

struct device_node___10;

struct class___24;

struct attribute_group___24;

struct device___24 {
	struct device___24 *parent;
	struct device_private *p;
	struct kobject___27 kobj;
	const char *init_name;
	const struct device_type___24 *type;
	struct mutex mutex;
	struct bus_type___24 *bus;
	struct device_driver___24 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___24 power;
	struct dev_pm_domain___24 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___10 *of_node;
	struct fwnode_handle___20 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___24 *class;
	const struct attribute_group___24 **groups;
	void (*release)(struct device___24 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct msi_desc {
	struct list_head list;
	unsigned int irq;
	unsigned int nvec_used;
	struct device___24 *dev;
	struct msi_msg msg;
	struct irq_affinity_desc *affinity;
	const void *iommu_cookie;
	union {
		struct {
			u32 masked;
			struct {
				u8 is_msix: 1;
				u8 multiple: 3;
				u8 multi_cap: 3;
				u8 maskbit: 1;
				u8 is_64: 1;
				u16 entry_nr;
				unsigned int default_irq;
			} msi_attrib;
			union {
				u8 mask_pos;
				void *mask_base;
			};
		};
		struct platform_msi_desc platform;
		struct fsl_mc_msi_desc fsl_mc;
	};
};

struct irq_chip___4 {
	struct device___24 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___4 *);
	void (*irq_shutdown)(struct irq_data___4 *);
	void (*irq_enable)(struct irq_data___4 *);
	void (*irq_disable)(struct irq_data___4 *);
	void (*irq_ack)(struct irq_data___4 *);
	void (*irq_mask)(struct irq_data___4 *);
	void (*irq_mask_ack)(struct irq_data___4 *);
	void (*irq_unmask)(struct irq_data___4 *);
	void (*irq_eoi)(struct irq_data___4 *);
	int (*irq_set_affinity)(struct irq_data___4 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___4 *);
	int (*irq_set_type)(struct irq_data___4 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___4 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___4 *);
	void (*irq_bus_sync_unlock)(struct irq_data___4 *);
	void (*irq_cpu_online)(struct irq_data___4 *);
	void (*irq_cpu_offline)(struct irq_data___4 *);
	void (*irq_suspend)(struct irq_data___4 *);
	void (*irq_resume)(struct irq_data___4 *);
	void (*irq_pm_shutdown)(struct irq_data___4 *);
	void (*irq_calc_mask)(struct irq_data___4 *);
	void (*irq_print_chip)(struct irq_data___4 *, struct seq_file___26 *);
	int (*irq_request_resources)(struct irq_data___4 *);
	void (*irq_release_resources)(struct irq_data___4 *);
	void (*irq_compose_msi_msg)(struct irq_data___4 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___4 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___4 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___4 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___4 *, void *);
	void (*ipi_send_single)(struct irq_data___4 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___4 *, const struct cpumask *);
	long unsigned int flags;
};

struct seq_operations___23;

struct seq_file___26 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___23 *op;
	int poll_event;
	const struct file___29 *file;
	void *private;
};

struct kernfs_root___26;

struct kernfs_elem_dir___26 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___26 *root;
};

struct kernfs_syscall_ops___26;

struct kernfs_root___26 {
	struct kernfs_node___26 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___26 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___26 {
	struct kernfs_node___26 *target_kn;
};

struct kernfs_ops___26;

struct kernfs_elem_attr___26 {
	const struct kernfs_ops___26 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___26 *notify_next;
};

struct kernfs_node___26 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___26 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___26 dir;
		struct kernfs_elem_symlink___26 symlink;
		struct kernfs_elem_attr___26 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___26;

struct kernfs_ops___26 {
	int (*open)(struct kernfs_open_file___26 *);
	void (*release)(struct kernfs_open_file___26 *);
	int (*seq_show)(struct seq_file___26 *, void *);
	void * (*seq_start)(struct seq_file___26 *, loff_t *);
	void * (*seq_next)(struct seq_file___26 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___26 *, void *);
	ssize_t (*read)(struct kernfs_open_file___26 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___26 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___26 *, struct vm_area_struct___29 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___26 *, struct poll_table_struct___17 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___26 {
	int (*remount_fs)(struct kernfs_root___26 *, int *, char *);
	int (*show_options)(struct seq_file___26 *, struct kernfs_root___26 *);
	int (*mkdir)(struct kernfs_node___26 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___26 *);
	int (*rename)(struct kernfs_node___26 *, struct kernfs_node___26 *, const char *);
	int (*show_path)(struct seq_file___26 *, struct kernfs_node___26 *, struct kernfs_root___26 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___26 {
	struct kernfs_node___26 *kn;
	struct file___29 *file;
	struct seq_file___26 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___28 *vm_ops;
};

typedef void (*poll_queue_proc___16)(struct file___29 *, wait_queue_head_t *, struct poll_table_struct___17 *);

struct poll_table_struct___17 {
	poll_queue_proc___16 _qproc;
	__poll_t _key;
};

struct bin_attribute___24;

struct attribute_group___24 {
	const char *name;
	umode_t (*is_visible)(struct kobject___27 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___27 *, struct bin_attribute___24 *, int);
	struct attribute **attrs;
	struct bin_attribute___24 **bin_attrs;
};

struct bin_attribute___24 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___29 *, struct kobject___27 *, struct bin_attribute___24 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___29 *, struct kobject___27 *, struct bin_attribute___24 *, char *, loff_t, size_t);
	int (*mmap)(struct file___29 *, struct kobject___27 *, struct bin_attribute___24 *, struct vm_area_struct___29 *);
};

struct sysfs_ops___26 {
	ssize_t (*show)(struct kobject___27 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___27 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___26;

struct kset___26 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___27 kobj;
	const struct kset_uevent_ops___26 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___26 {
	void (*release)(struct kobject___27 *);
	const struct sysfs_ops___26 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___27 *);
	const void * (*namespace)(struct kobject___27 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___26 {
	int (* const filter)(struct kset___26 *, struct kobject___27 *);
	const char * (* const name)(struct kset___26 *, struct kobject___27 *);
	int (* const uevent)(struct kset___26 *, struct kobject___27 *, struct kobj_uevent_env *);
};

struct kobj_attribute___27 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___27 *, struct kobj_attribute___27 *, char *);
	ssize_t (*store)(struct kobject___27 *, struct kobj_attribute___27 *, const char *, size_t);
};

struct module_kobject___23 {
	struct kobject___27 kobj;
	struct module___26 *mod;
	struct kobject___27 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___23 {
	struct module___26 *mod;
	struct latch_tree_node node;
};

struct module_layout___23 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___23 mtn;
};

struct module_attribute___23;

struct kernel_param___23;

struct module___26 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___23 mkobj;
	struct module_attribute___23 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___27 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___23 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___23 core_layout;
	struct module_layout___23 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___11 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___28;

struct super_block___29;

struct dentry___30 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___30 *d_parent;
	struct qstr d_name;
	struct inode___31 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___28 *d_op;
	struct super_block___29 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___28;

struct block_device___29;

struct inode___31 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___28 *i_op;
	struct super_block___29 *i_sb;
	struct address_space___28 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___29 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___29 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___28 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___29 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___28 {
	int (*d_revalidate)(struct dentry___30 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___30 *, unsigned int);
	int (*d_hash)(const struct dentry___30 *, struct qstr *);
	int (*d_compare)(const struct dentry___30 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___30 *);
	int (*d_init)(struct dentry___30 *);
	void (*d_release)(struct dentry___30 *);
	void (*d_prune)(struct dentry___30 *);
	void (*d_iput)(struct dentry___30 *, struct inode___31 *);
	char * (*d_dname)(struct dentry___30 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___28 *);
	int (*d_manage)(const struct path___28 *, bool);
	struct dentry___30 * (*d_real)(struct dentry___30 *, const struct inode___31 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___28;

struct mem_dqinfo___28 {
	struct quota_format_type___28 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___28;

struct quota_info___28 {
	unsigned int flags;
	struct rw_semaphore___29 dqio_sem;
	struct inode___31 *files[3];
	struct mem_dqinfo___28 info[3];
	const struct quota_format_ops___28 *ops[3];
};

struct rcuwait___28 {
	struct task_struct___30 *task;
};

struct percpu_rw_semaphore___28 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___29 rw_sem;
	struct rcuwait___28 writer;
	int readers_block;
};

struct sb_writers___28 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___28 rw_sem[3];
};

struct file_system_type___28;

struct super_operations___28;

struct dquot_operations___28;

struct quotactl_ops___28;

struct super_block___29 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___28 *s_type;
	const struct super_operations___28 *s_op;
	const struct dquot_operations___28 *dq_op;
	const struct quotactl_ops___28 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___30 *s_root;
	struct rw_semaphore___29 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___29 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___28 s_dquot;
	struct sb_writers___28 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___28 *s_d_op;
	int cleancache_poolid;
	struct shrinker___9 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___19 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___29 {
	struct file___29 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___29 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___29 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___29 *ia_file;
};

struct dquot___28 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___29 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___28 {
	int qf_fmt_id;
	const struct quota_format_ops___28 *qf_ops;
	struct module___26 *qf_owner;
	struct quota_format_type___28 *qf_next;
};

struct quota_format_ops___28 {
	int (*check_quota_file)(struct super_block___29 *, int);
	int (*read_file_info)(struct super_block___29 *, int);
	int (*write_file_info)(struct super_block___29 *, int);
	int (*free_file_info)(struct super_block___29 *, int);
	int (*read_dqblk)(struct dquot___28 *);
	int (*commit_dqblk)(struct dquot___28 *);
	int (*release_dqblk)(struct dquot___28 *);
	int (*get_next_id)(struct super_block___29 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___28 {
	int (*write_dquot)(struct dquot___28 *);
	struct dquot___28 * (*alloc_dquot)(struct super_block___29 *, int);
	void (*destroy_dquot)(struct dquot___28 *);
	int (*acquire_dquot)(struct dquot___28 *);
	int (*release_dquot)(struct dquot___28 *);
	int (*mark_dirty)(struct dquot___28 *);
	int (*write_info)(struct super_block___29 *, int);
	qsize_t * (*get_reserved_space)(struct inode___31 *);
	int (*get_projid)(struct inode___31 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___31 *, qsize_t *);
	int (*get_next_id)(struct super_block___29 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___28 {
	int (*quota_on)(struct super_block___29 *, int, int, const struct path___28 *);
	int (*quota_off)(struct super_block___29 *, int);
	int (*quota_enable)(struct super_block___29 *, unsigned int);
	int (*quota_disable)(struct super_block___29 *, unsigned int);
	int (*quota_sync)(struct super_block___29 *, int);
	int (*set_info)(struct super_block___29 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___29 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___29 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___29 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___29 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___29 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___28 {
	int (*writepage)(struct page___29 *, struct writeback_control___3 *);
	int (*readpage)(struct file___29 *, struct page___29 *);
	int (*writepages)(struct address_space___28 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___29 *);
	int (*readpages)(struct file___29 *, struct address_space___28 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___29 *, struct address_space___28 *, loff_t, unsigned int, unsigned int, struct page___29 **, void **);
	int (*write_end)(struct file___29 *, struct address_space___28 *, loff_t, unsigned int, unsigned int, struct page___29 *, void *);
	sector_t (*bmap)(struct address_space___28 *, sector_t);
	void (*invalidatepage)(struct page___29 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___29 *, gfp_t);
	void (*freepage)(struct page___29 *);
	ssize_t (*direct_IO)(struct kiocb___29 *, struct iov_iter___11 *);
	int (*migratepage)(struct address_space___28 *, struct page___29 *, struct page___29 *, enum migrate_mode);
	bool (*isolate_page)(struct page___29 *, isolate_mode_t);
	void (*putback_page)(struct page___29 *);
	int (*launder_page)(struct page___29 *);
	int (*is_partially_uptodate)(struct page___29 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___29 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___28 *, struct page___29 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___29 *, sector_t *);
	void (*swap_deactivate)(struct file___29 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___29 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___31 *bd_inode;
	struct super_block___29 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___29 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___28 {
	struct dentry___30 * (*lookup)(struct inode___31 *, struct dentry___30 *, unsigned int);
	const char * (*get_link)(struct dentry___30 *, struct inode___31 *, struct delayed_call *);
	int (*permission)(struct inode___31 *, int);
	struct posix_acl * (*get_acl)(struct inode___31 *, int);
	int (*readlink)(struct dentry___30 *, char *, int);
	int (*create)(struct inode___31 *, struct dentry___30 *, umode_t, bool);
	int (*link)(struct dentry___30 *, struct inode___31 *, struct dentry___30 *);
	int (*unlink)(struct inode___31 *, struct dentry___30 *);
	int (*symlink)(struct inode___31 *, struct dentry___30 *, const char *);
	int (*mkdir)(struct inode___31 *, struct dentry___30 *, umode_t);
	int (*rmdir)(struct inode___31 *, struct dentry___30 *);
	int (*mknod)(struct inode___31 *, struct dentry___30 *, umode_t, dev_t);
	int (*rename)(struct inode___31 *, struct dentry___30 *, struct inode___31 *, struct dentry___30 *, unsigned int);
	int (*setattr)(struct dentry___30 *, struct iattr___29 *);
	int (*getattr)(const struct path___28 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___30 *, char *, size_t);
	int (*fiemap)(struct inode___31 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___31 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___31 *, struct dentry___30 *, struct file___29 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___31 *, struct dentry___30 *, umode_t);
	int (*set_acl)(struct inode___31 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___28 {
	void (*fl_copy_lock)(struct file_lock___29 *, struct file_lock___29 *);
	void (*fl_release_private)(struct file_lock___29 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___28;

struct file_lock___29 {
	struct file_lock___29 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___29 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___28 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___28 *fl_ops;
	const struct lock_manager_operations___28 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___28 {
	int (*lm_compare_owner)(struct file_lock___29 *, struct file_lock___29 *);
	long unsigned int (*lm_owner_key)(struct file_lock___29 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___29 *);
	int (*lm_grant)(struct file_lock___29 *, int);
	bool (*lm_break)(struct file_lock___29 *);
	int (*lm_change)(struct file_lock___29 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___29 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___28 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___28 *fa_next;
	struct file___29 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___28 {
	const char *name;
	int fs_flags;
	struct dentry___30 * (*mount)(struct file_system_type___28 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___29 *);
	struct module___26 *owner;
	struct file_system_type___28 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___28 {
	struct inode___31 * (*alloc_inode)(struct super_block___29 *);
	void (*destroy_inode)(struct inode___31 *);
	void (*dirty_inode)(struct inode___31 *, int);
	int (*write_inode)(struct inode___31 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___31 *);
	void (*evict_inode)(struct inode___31 *);
	void (*put_super)(struct super_block___29 *);
	int (*sync_fs)(struct super_block___29 *, int);
	int (*freeze_super)(struct super_block___29 *);
	int (*freeze_fs)(struct super_block___29 *);
	int (*thaw_super)(struct super_block___29 *);
	int (*unfreeze_fs)(struct super_block___29 *);
	int (*statfs)(struct dentry___30 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___29 *, int *, char *);
	void (*umount_begin)(struct super_block___29 *);
	int (*show_options)(struct seq_file___26 *, struct dentry___30 *);
	int (*show_devname)(struct seq_file___26 *, struct dentry___30 *);
	int (*show_path)(struct seq_file___26 *, struct dentry___30 *);
	int (*show_stats)(struct seq_file___26 *, struct dentry___30 *);
	ssize_t (*quota_read)(struct super_block___29 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___29 *, int, const char *, size_t, loff_t);
	struct dquot___28 ** (*get_dquots)(struct inode___31 *);
	int (*bdev_try_to_free_page)(struct super_block___29 *, struct page___29 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___29 *, struct shrink_control___9 *);
	long int (*free_cached_objects)(struct super_block___29 *, struct shrink_control___9 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___28(struct page___29 *);

struct mmu_notifier___4;

struct mmu_notifier_ops___4 {
	int flags;
	void (*release)(struct mmu_notifier___4 *, struct mm_struct___29 *);
	int (*clear_flush_young)(struct mmu_notifier___4 *, struct mm_struct___29 *, long unsigned int, long unsigned int);
	int (*clear_young)(struct mmu_notifier___4 *, struct mm_struct___29 *, long unsigned int, long unsigned int);
	int (*test_young)(struct mmu_notifier___4 *, struct mm_struct___29 *, long unsigned int);
	void (*change_pte)(struct mmu_notifier___4 *, struct mm_struct___29 *, long unsigned int, pte_t);
	void (*invalidate_range_start)(struct mmu_notifier___4 *, struct mm_struct___29 *, long unsigned int, long unsigned int);
	void (*invalidate_range_end)(struct mmu_notifier___4 *, struct mm_struct___29 *, long unsigned int, long unsigned int);
	void (*invalidate_range)(struct mmu_notifier___4 *, struct mm_struct___29 *, long unsigned int, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mmu_notifier___4 {
	struct hlist_node hlist;
	const struct mmu_notifier_ops___4 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct property___10;

struct device_node___10 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___20 fwnode;
	struct property___10 *properties;
	struct property___10 *deadprops;
	struct device_node___10 *parent;
	struct device_node___10 *child;
	struct device_node___10 *sibling;
	struct kobject___27 kobj;
	long unsigned int _flags;
	void *data;
};

struct kvm_vcpu___4;

struct kvm_io_device___4;

struct kvm_io_device_ops___4 {
	int (*read)(struct kvm_vcpu___4 *, struct kvm_io_device___4 *, gpa_t, int, void *);
	int (*write)(struct kvm_vcpu___4 *, struct kvm_io_device___4 *, gpa_t, int, const void *);
	void (*destructor)(struct kvm_io_device___4 *);
};

struct kvm_cpu_context___4 {
	struct kvm_regs gp_regs;
	union {
		u64 sys_regs[101];
		u32 copro[202];
	};
	struct kvm_vcpu___4 *__hyp_running_vcpu;
};

typedef struct kvm_cpu_context___4 kvm_cpu_context_t___4;

struct its_vm___4;

struct its_vpe___4 {
	struct page___29 *vpt_page;
	struct its_vm___4 *its_vm;
	int irq;
	irq_hw_number_t vpe_db_lpi;
	int vpe_proxy_event;
	u16 col_idx;
	u16 vpe_id;
	bool idai;
	bool pending_last;
};

struct vgic_v3_cpu_if___4 {
	u32 vgic_hcr;
	u32 vgic_vmcr;
	u32 vgic_sre;
	u32 vgic_ap0r[4];
	u32 vgic_ap1r[4];
	u64 vgic_lr[16];
	struct its_vpe___4 its_vpe;
};

struct vgic_irq___4 {
	raw_spinlock_t irq_lock;
	struct list_head lpi_list;
	struct list_head ap_list;
	struct kvm_vcpu___4 *vcpu;
	struct kvm_vcpu___4 *target_vcpu;
	u32 intid;
	bool line_level;
	bool pending_latch;
	bool active;
	bool enabled;
	bool hw;
	struct kref refcount;
	u32 hwintid;
	unsigned int host_irq;
	union {
		u8 targets;
		u32 mpidr;
	};
	u8 source;
	u8 active_source;
	u8 priority;
	u8 group;
	enum vgic_irq_config config;
	bool (*get_input_level)(int);
	void *owner;
};

struct kvm_io_device___4 {
	const struct kvm_io_device_ops___4 *ops;
};

struct vgic_its___4;

struct vgic_io_device___4 {
	gpa_t base_addr;
	union {
		struct kvm_vcpu___4 *redist_vcpu;
		struct vgic_its___4 *its;
	};
	const struct vgic_register_region *regions;
	enum iodev_type iodev_type;
	int nr_regions;
	struct kvm_io_device___4 dev;
};

struct vgic_cpu___4 {
	union {
		struct vgic_v2_cpu_if vgic_v2;
		struct vgic_v3_cpu_if___4 vgic_v3;
	};
	unsigned int used_lrs;
	struct vgic_irq___4 private_irqs[32];
	raw_spinlock_t ap_list_lock;
	struct list_head ap_list_head;
	struct vgic_io_device___4 rd_iodev;
	struct vgic_io_device___4 sgi_iodev;
	struct vgic_redist_region *rdreg;
	u64 pendbaser;
	bool lpis_enabled;
	u32 num_pri_bits;
	u32 num_id_bits;
};

struct arch_timer_context___4 {
	struct kvm_vcpu___4 *vcpu;
	u32 cnt_ctl;
	u64 cnt_cval;
	struct kvm_irq_level irq;
	u64 cntvoff;
	struct hrtimer hrtimer;
	bool loaded;
	u32 host_timer_irq;
	u32 host_timer_irq_flags;
};

struct arch_timer_cpu___4 {
	struct arch_timer_context___4 timers[2];
	struct hrtimer bg_timer;
	bool enabled;
};

struct kvm_pmc___4 {
	u8 idx;
	struct perf_event___14 *perf_event;
	u64 bitmask;
};

struct kvm_pmu___4 {
	int irq_num;
	struct kvm_pmc___4 pmc[32];
	bool ready;
	bool created;
	bool irq_level;
};

struct kvm_vcpu_arch___4 {
	struct kvm_cpu_context___4 ctxt;
	void *sve_state;
	unsigned int sve_max_vl;
	u64 hcr_el2;
	u32 mdcr_el2;
	struct kvm_vcpu_fault_info fault;
	u64 workaround_flags;
	u64 flags;
	struct kvm_guest_debug_arch *debug_ptr;
	struct kvm_guest_debug_arch vcpu_debug_state;
	struct kvm_guest_debug_arch external_debug_state;
	kvm_cpu_context_t___4 *host_cpu_context;
	struct thread_info *host_thread_info;
	struct user_fpsimd_state *host_fpsimd_state;
	struct {
		struct kvm_guest_debug_arch regs;
		u64 pmscr_el1;
	} host_debug_state;
	struct vgic_cpu___4 vgic_cpu;
	struct arch_timer_cpu___4 timer_cpu;
	struct kvm_pmu___4 pmu;
	struct {
		u32 mdscr_el1;
	} guest_debug_preserved;
	bool power_off;
	bool pause;
	struct kvm_decode mmio_decode;
	struct kvm_mmu_memory_cache mmu_page_cache;
	int target;
	long unsigned int features[1];
	bool has_run_once;
	u64 vsesr_el2;
	struct vcpu_reset_state reset_state;
	bool sysregs_loaded_on_cpu;
};

struct kvm___4;

struct kvm_vcpu___4 {
	struct kvm___4 *kvm;
	struct preempt_notifier___4 preempt_notifier;
	int cpu;
	int vcpu_id;
	int srcu_idx;
	int mode;
	u64 requests;
	long unsigned int guest_debug;
	int pre_pcpu;
	struct list_head blocked_vcpu_list;
	struct mutex mutex;
	struct kvm_run *run;
	int guest_xcr0_loaded;
	struct swait_queue_head wq;
	struct pid___24 *pid;
	int sigset_active;
	sigset_t sigset;
	struct kvm_vcpu_stat stat;
	unsigned int halt_poll_ns;
	bool valid_wakeup;
	int mmio_needed;
	int mmio_read_completed;
	int mmio_is_write;
	int mmio_cur_fragment;
	int mmio_nr_fragments;
	struct kvm_mmio_fragment mmio_fragments[2];
	struct {
		bool in_spin_loop;
		bool dy_eligible;
	} spin_loop;
	bool preempted;
	struct kvm_vcpu_arch___4 arch;
	struct dentry___30 *debugfs_dentry;
	long: 64;
};

struct its_vm___4 {
	struct fwnode_handle___20 *fwnode;
	struct irq_domain *domain;
	struct page___29 *vprop_page;
	struct its_vpe___4 **vpes;
	int nr_vpes;
	irq_hw_number_t db_lpi_base;
	long unsigned int *db_bitmap;
	int nr_db_lpis;
	u32 vlpi_count[16];
};

struct kvm_device___4;

struct vgic_its___4 {
	gpa_t vgic_its_base;
	bool enabled;
	struct vgic_io_device___4 iodev;
	struct kvm_device___4 *dev;
	u64 baser_device_table;
	u64 baser_coll_table;
	struct mutex cmd_lock;
	u64 cbaser;
	u32 creadr;
	u32 cwriter;
	u32 abi_rev;
	struct mutex its_lock;
	struct list_head device_list;
	struct list_head collection_list;
};

struct kvm_device_ops___4;

struct kvm_device___4 {
	struct kvm_device_ops___4 *ops;
	struct kvm___4 *kvm;
	void *private;
	struct list_head vm_node;
};

struct vgic_dist___4 {
	bool in_kernel;
	bool ready;
	bool initialized;
	u32 vgic_model;
	u32 implementation_rev;
	bool v2_groups_user_writable;
	bool msis_require_devid;
	int nr_spis;
	gpa_t vgic_dist_base;
	union {
		gpa_t vgic_cpu_base;
		struct list_head rd_regions;
	};
	bool enabled;
	struct vgic_irq___4 *spis;
	struct vgic_io_device___4 dist_iodev;
	bool has_its;
	u64 propbaser;
	raw_spinlock_t lpi_list_lock;
	struct list_head lpi_list_head;
	int lpi_list_count;
	struct vgic_state_iter *iter;
	struct its_vm___4 its_vm;
};

struct property___10 {
	char *name;
	int length;
	void *value;
	struct property___10 *next;
	long unsigned int _flags;
	struct bin_attribute___24 attr;
};

struct cgroup_namespace___18 {
	refcount_t count;
	struct ns_common___2 ns;
	struct user_namespace___19 *user_ns;
	struct ucounts___19 *ucounts;
	struct css_set___18 *root_cset;
};

struct ucounts___19 {
	struct hlist_node node;
	struct user_namespace___19 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct kernel_param_ops___23 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___23 *);
	int (*get)(char *, const struct kernel_param___23 *);
	void (*free)(void *);
};

struct kparam_array___23;

struct kernel_param___23 {
	const char *name;
	struct module___26 *mod;
	const struct kernel_param_ops___23 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___23 *arr;
	};
};

struct kparam_array___23 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___23 *ops;
	void *elem;
};

struct module_attribute___23 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___23 *, struct module_kobject___23 *, char *);
	ssize_t (*store)(struct module_attribute___23 *, struct module_kobject___23 *, const char *, size_t);
	void (*setup)(struct module___26 *, const char *);
	int (*test)(struct module___26 *);
	void (*free)(struct module___26 *);
};

struct trace_event_class___11;

struct trace_event_call___11 {
	struct list_head list;
	struct trace_event_class___11 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___2 *prog_array;
	int (*perf_perm)(struct trace_event_call___11 *, struct perf_event___14 *);
};

typedef int (*key_restrict_link_func_t___28)(struct key___29 *, const struct key_type *, const union key_payload *, struct key___29 *);

struct key_restriction___29;

struct key___29 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___29 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___29 *restrict_link;
};

struct key_restriction___29 {
	key_restrict_link_func_t___28 check;
	struct key___29 *key;
	struct key_type *keytype;
};

struct dev_pm_ops___24 {
	int (*prepare)(struct device___24 *);
	void (*complete)(struct device___24 *);
	int (*suspend)(struct device___24 *);
	int (*resume)(struct device___24 *);
	int (*freeze)(struct device___24 *);
	int (*thaw)(struct device___24 *);
	int (*poweroff)(struct device___24 *);
	int (*restore)(struct device___24 *);
	int (*suspend_late)(struct device___24 *);
	int (*resume_early)(struct device___24 *);
	int (*freeze_late)(struct device___24 *);
	int (*thaw_early)(struct device___24 *);
	int (*poweroff_late)(struct device___24 *);
	int (*restore_early)(struct device___24 *);
	int (*suspend_noirq)(struct device___24 *);
	int (*resume_noirq)(struct device___24 *);
	int (*freeze_noirq)(struct device___24 *);
	int (*thaw_noirq)(struct device___24 *);
	int (*poweroff_noirq)(struct device___24 *);
	int (*restore_noirq)(struct device___24 *);
	int (*runtime_suspend)(struct device___24 *);
	int (*runtime_resume)(struct device___24 *);
	int (*runtime_idle)(struct device___24 *);
};

struct dev_pm_domain___24 {
	struct dev_pm_ops___24 ops;
	void (*detach)(struct device___24 *, bool);
	int (*activate)(struct device___24 *);
	void (*sync)(struct device___24 *);
	void (*dismiss)(struct device___24 *);
};

struct bus_type___24 {
	const char *name;
	const char *dev_name;
	struct device___24 *dev_root;
	const struct attribute_group___24 **bus_groups;
	const struct attribute_group___24 **dev_groups;
	const struct attribute_group___24 **drv_groups;
	int (*match)(struct device___24 *, struct device_driver___24 *);
	int (*uevent)(struct device___24 *, struct kobj_uevent_env *);
	int (*probe)(struct device___24 *);
	int (*remove)(struct device___24 *);
	void (*shutdown)(struct device___24 *);
	int (*online)(struct device___24 *);
	int (*offline)(struct device___24 *);
	int (*suspend)(struct device___24 *, pm_message_t);
	int (*resume)(struct device___24 *);
	int (*num_vf)(struct device___24 *);
	int (*dma_configure)(struct device___24 *);
	const struct dev_pm_ops___24 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___24 {
	const char *name;
	struct bus_type___24 *bus;
	struct module___26 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___24 *);
	int (*remove)(struct device___24 *);
	void (*shutdown)(struct device___24 *);
	int (*suspend)(struct device___24 *, pm_message_t);
	int (*resume)(struct device___24 *);
	const struct attribute_group___24 **groups;
	const struct dev_pm_ops___24 *pm;
	void (*coredump)(struct device___24 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___24 {
	const char *name;
	const struct attribute_group___24 **groups;
	int (*uevent)(struct device___24 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___24 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___24 *);
	const struct dev_pm_ops___24 *pm;
};

struct class___24 {
	const char *name;
	struct module___26 *owner;
	const struct attribute_group___24 **class_groups;
	const struct attribute_group___24 **dev_groups;
	struct kobject___27 *dev_kobj;
	int (*dev_uevent)(struct device___24 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___24 *, umode_t *);
	void (*class_release)(struct class___24 *);
	void (*dev_release)(struct device___24 *);
	int (*shutdown_pre)(struct device___24 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___24 *);
	const struct dev_pm_ops___24 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___22 {
	struct device___24 dev;
};

struct seq_operations___23 {
	void * (*start)(struct seq_file___26 *, loff_t *);
	void (*stop)(struct seq_file___26 *, void *);
	void * (*next)(struct seq_file___26 *, void *, loff_t *);
	int (*show)(struct seq_file___26 *, void *);
};

struct bpf_map___18;

struct bpf_map_ops___18 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___18 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___18 *, struct file___29 *);
	void (*map_free)(struct bpf_map___18 *);
	int (*map_get_next_key)(struct bpf_map___18 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___18 *);
	void * (*map_lookup_elem)(struct bpf_map___18 *, void *);
	int (*map_update_elem)(struct bpf_map___18 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___18 *, void *);
	int (*map_push_elem)(struct bpf_map___18 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___18 *, void *);
	int (*map_peek_elem)(struct bpf_map___18 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___18 *, struct file___29 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___18 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___18 *, void *, struct seq_file___26 *);
	int (*map_check_btf)(const struct bpf_map___18 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___18 {
	const struct bpf_map_ops___18 *ops;
	struct bpf_map___18 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___28 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___18;

typedef void (*kthread_work_func_t___18)(struct kthread_work___18 *);

struct kthread_worker___18;

struct kthread_work___18 {
	struct list_head node;
	kthread_work_func_t___18 func;
	struct kthread_worker___18 *worker;
	int canceling;
};

struct kthread_worker___18 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___30 *task;
	struct kthread_work___18 *current_work;
};

struct kthread_delayed_work___18 {
	struct kthread_work___18 work;
	struct timer_list timer;
};

struct psi_group___18 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___18 *poll_kworker;
	struct kthread_delayed_work___18 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___18 {
	struct kernfs_node___26 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___18;

struct cgroup_subsys_state___18 {
	struct cgroup___18 *cgroup;
	struct cgroup_subsys___18 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___18 *parent;
};

struct cgroup_root___18;

struct cgroup_rstat_cpu___18;

struct cgroup___18 {
	struct cgroup_subsys_state___18 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___26 *kn;
	struct cgroup_file___18 procs_file;
	struct cgroup_file___18 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___18 *subsys[13];
	struct cgroup_root___18 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___18 *dom_cgrp;
	struct cgroup_rstat_cpu___18 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___2 bpf;
	atomic_t congestion_count;
	struct cgroup___18 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___18 psi;
	int ancestor_ids[0];
};

struct cftype___18;

struct cgroup_subsys___18 {
	struct cgroup_subsys_state___18 * (*css_alloc)(struct cgroup_subsys_state___18 *);
	int (*css_online)(struct cgroup_subsys_state___18 *);
	void (*css_offline)(struct cgroup_subsys_state___18 *);
	void (*css_released)(struct cgroup_subsys_state___18 *);
	void (*css_free)(struct cgroup_subsys_state___18 *);
	void (*css_reset)(struct cgroup_subsys_state___18 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___18 *, int);
	int (*css_extra_stat_show)(struct seq_file___26 *, struct cgroup_subsys_state___18 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___30 *);
	void (*cancel_fork)(struct task_struct___30 *);
	void (*fork)(struct task_struct___30 *);
	void (*exit)(struct task_struct___30 *);
	void (*free)(struct task_struct___30 *);
	void (*bind)(struct cgroup_subsys_state___18 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___18 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___18 *dfl_cftypes;
	struct cftype___18 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___18 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___18 *updated_children;
	struct cgroup___18 *updated_next;
};

struct cgroup_root___18 {
	struct kernfs_root___26 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___18 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___18 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___18 *ss;
	struct list_head node;
	struct kernfs_ops___26 *kf_ops;
	int (*open)(struct kernfs_open_file___26 *);
	void (*release)(struct kernfs_open_file___26 *);
	u64 (*read_u64)(struct cgroup_subsys_state___18 *, struct cftype___18 *);
	s64 (*read_s64)(struct cgroup_subsys_state___18 *, struct cftype___18 *);
	int (*seq_show)(struct seq_file___26 *, void *);
	void * (*seq_start)(struct seq_file___26 *, loff_t *);
	void * (*seq_next)(struct seq_file___26 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___26 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___18 *, struct cftype___18 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___18 *, struct cftype___18 *, s64);
	ssize_t (*write)(struct kernfs_open_file___26 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___26 *, struct poll_table_struct___17 *);
};

struct perf_cpu_context___14;

struct pmu___14 {
	struct list_head entry;
	struct module___26 *module;
	struct device___24 *dev;
	const struct attribute_group___24 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___14 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___14 *);
	void (*pmu_disable)(struct pmu___14 *);
	int (*event_init)(struct perf_event___14 *);
	void (*event_mapped)(struct perf_event___14 *, struct mm_struct___29 *);
	void (*event_unmapped)(struct perf_event___14 *, struct mm_struct___29 *);
	int (*add)(struct perf_event___14 *, int);
	void (*del)(struct perf_event___14 *, int);
	void (*start)(struct perf_event___14 *, int);
	void (*stop)(struct perf_event___14 *, int);
	void (*read)(struct perf_event___14 *);
	void (*start_txn)(struct pmu___14 *, unsigned int);
	int (*commit_txn)(struct pmu___14 *);
	void (*cancel_txn)(struct pmu___14 *);
	int (*event_idx)(struct perf_event___14 *);
	void (*sched_task)(struct perf_event_context___14 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___14 *);
	int (*filter_match)(struct perf_event___14 *);
	int (*check_period)(struct perf_event___14 *, u64);
};

struct perf_cpu_context___14 {
	struct perf_event_context___14 ctx;
	struct perf_event_context___14 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___14 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___14 {
	struct cgroup_subsys_state___18 css;
	struct perf_cgroup_info *info;
};

struct kvm_arch___4 {
	struct kvm_vmid vmid;
	pgd_t *pgd;
	phys_addr_t pgd_phys;
	u64 vtcr;
	int *last_vcpu_ran;
	int max_vcpus;
	struct vgic_dist___4 vgic;
	u32 psci_version;
};

struct kvm_io_range___4 {
	gpa_t addr;
	int len;
	struct kvm_io_device___4 *dev;
};

struct kvm_io_bus___4 {
	int dev_count;
	int ioeventfd_count;
	struct kvm_io_range___4 range[0];
};

struct kvm_stat_data___4;

struct kvm___4 {
	spinlock_t mmu_lock;
	struct mutex slots_lock;
	struct mm_struct___29 *mm;
	struct kvm_memslots *memslots[1];
	struct kvm_vcpu___4 *vcpus[512];
	atomic_t online_vcpus;
	int created_vcpus;
	int last_boosted_vcpu;
	struct list_head vm_list;
	struct mutex lock;
	struct kvm_io_bus___4 *buses[4];
	struct {
		spinlock_t lock;
		struct list_head items;
		struct list_head resampler_list;
		struct mutex resampler_lock;
	} irqfds;
	struct list_head ioeventfds;
	struct kvm_vm_stat stat;
	struct kvm_arch___4 arch;
	refcount_t users_count;
	struct kvm_coalesced_mmio_ring *coalesced_mmio_ring;
	spinlock_t ring_lock;
	struct list_head coalesced_zones;
	struct mutex irq_lock;
	struct kvm_irq_routing_table *irq_routing;
	struct hlist_head irq_ack_notifier_list;
	struct mmu_notifier___4 mmu_notifier;
	long unsigned int mmu_notifier_seq;
	long int mmu_notifier_count;
	long int tlbs_dirty;
	struct list_head devices;
	bool manual_dirty_log_protect;
	struct dentry___30 *debugfs_dentry;
	struct kvm_stat_data___4 **debugfs_stat_data;
	struct srcu_struct srcu;
	struct srcu_struct irq_srcu;
	pid_t userspace_pid;
};

struct kvm_stat_data___4 {
	int offset;
	int mode;
	struct kvm___4 *kvm;
};

struct kvm_device_ops___4 {
	const char *name;
	int (*create)(struct kvm_device___4 *, u32);
	void (*init)(struct kvm_device___4 *);
	void (*destroy)(struct kvm_device___4 *);
	void (*release)(struct kvm_device___4 *);
	int (*set_attr)(struct kvm_device___4 *, struct kvm_device_attr *);
	int (*get_attr)(struct kvm_device___4 *, struct kvm_device_attr *);
	int (*has_attr)(struct kvm_device___4 *, struct kvm_device_attr *);
	long int (*ioctl)(struct kvm_device___4 *, unsigned int, long unsigned int);
	int (*mmap)(struct kvm_device___4 *, struct vm_area_struct___29 *);
};

struct hstate___4 {
	int next_nid_to_alloc;
	int next_nid_to_free;
	unsigned int order;
	long unsigned int mask;
	long unsigned int max_huge_pages;
	long unsigned int nr_huge_pages;
	long unsigned int free_huge_pages;
	long unsigned int resv_huge_pages;
	long unsigned int surplus_huge_pages;
	long unsigned int nr_overcommit_huge_pages;
	struct list_head hugepage_activelist;
	struct list_head hugepage_freelists[8];
	unsigned int nr_huge_pages_node[8];
	unsigned int free_huge_pages_node[8];
	unsigned int surplus_huge_pages_node[8];
	struct cftype___18 cgroup_files[5];
	char name[32];
};

struct trace_event_class___11 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___11 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___11 *);
	struct list_head * (*get_fields)(struct trace_event_call___11 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___11 *);
};

struct trace_event_file___5;

struct trace_event_buffer___5 {
	struct ring_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___5 *trace_file;
	void *entry;
	long unsigned int flags;
	int pc;
};

struct trace_event_file___5 {
	struct list_head list;
	struct trace_event_call___11 *event_call;
	struct event_filter *filter;
	struct dentry___30 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_vgic_update_irq_pending {
	struct trace_entry ent;
	long unsigned int vcpu_id;
	__u32 irq;
	bool level;
	char __data[0];
};

struct trace_event_data_offsets_vgic_update_irq_pending {};

enum gic_type {
	GIC_V2 = 0,
	GIC_V3 = 1,
};

struct gic_kvm_info {
	enum gic_type type;
	struct resource vcpu;
	unsigned int maint_irq;
	struct resource vctrl;
	bool has_v4;
};

struct module___27;

struct file___30;

struct kiocb___30;

struct vm_area_struct___30;

struct inode___32;

struct file_lock___30;

struct page___30;

struct seq_file___27;

struct file_operations___30 {
	struct module___27 *owner;
	loff_t (*llseek)(struct file___30 *, loff_t, int);
	ssize_t (*read)(struct file___30 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___30 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___30 *, struct iov_iter___11 *);
	ssize_t (*write_iter)(struct kiocb___30 *, struct iov_iter___11 *);
	int (*iopoll)(struct kiocb___30 *, bool);
	int (*iterate)(struct file___30 *, struct dir_context *);
	int (*iterate_shared)(struct file___30 *, struct dir_context *);
	__poll_t (*poll)(struct file___30 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___30 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___30 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___30 *, struct vm_area_struct___30 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___32 *, struct file___30 *);
	int (*flush)(struct file___30 *, fl_owner_t);
	int (*release)(struct inode___32 *, struct file___30 *);
	int (*fsync)(struct file___30 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___30 *, int);
	int (*lock)(struct file___30 *, int, struct file_lock___30 *);
	ssize_t (*sendpage)(struct file___30 *, struct page___30 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___30 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___30 *, int, struct file_lock___30 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___30 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___30 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___30 *, long int, struct file_lock___30 **, void **);
	long int (*fallocate)(struct file___30 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___27 *, struct file___30 *);
	ssize_t (*copy_file_range)(struct file___30 *, loff_t, struct file___30 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___30 *, loff_t, struct file___30 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___30 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct perf_event___15;

struct debug_info___15 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___15 *hbp_break[16];
	struct perf_event___15 *hbp_watch[16];
};

struct task_struct___31;

struct hw_perf_event___15 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___31 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___15)(struct perf_event___15 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___15;

struct perf_event_context___15;

struct fasync_struct___29;

struct pid_namespace___25;

struct perf_cgroup___15;

struct perf_event___15 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___15 *group_leader;
	struct pmu___15 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___15 hw;
	struct perf_event_context___15 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___15 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___31 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___29 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___15 *);
	struct callback_head callback_head;
	struct pid_namespace___25 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___15 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___15 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___5 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___15 *cgrp;
	struct list_head sb_list;
};

struct thread_struct___15 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___15 debug;
	long: 64;
};

struct vmacache___29 {
	u64 seqnum;
	struct vm_area_struct___30 *vmas[4];
};

struct page_frag___29 {
	struct page___30 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___30;

struct pid___25;

struct cred___29;

struct nsproxy___28;

struct signal_struct___27;

struct css_set___19;

struct vm_struct___24;

struct task_struct___31 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___31 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___30 *mm;
	struct mm_struct___30 *active_mm;
	struct vmacache___29 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___31 *real_parent;
	struct task_struct___31 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___31 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___25 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___25 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___25 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___29 *ptracer_cred;
	const struct cred___29 *real_cred;
	const struct cred___29 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___28 *nsproxy;
	struct signal_struct___27 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___31 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___3 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___19 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___15 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___29 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___31 *oom_reaper_list;
	struct vm_struct___24 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___15 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct preempt_notifier___5;

struct preempt_ops___5 {
	void (*sched_in)(struct preempt_notifier___5 *, int);
	void (*sched_out)(struct preempt_notifier___5 *, struct task_struct___31 *);
};

struct preempt_notifier___5 {
	struct hlist_node link;
	struct preempt_ops___5 *ops;
};

typedef struct page___30 *pgtable_t___29;

struct address_space___29;

struct dev_pagemap___29;

struct page___30 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___29 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___30 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___29 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___30 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___29 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___29;

struct lruvec___29 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___29 *pgdat;
};

struct zone___29 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___29 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___29 {
	struct zone___29 *zone;
	int zone_idx;
};

struct zonelist___29 {
	struct zoneref___29 _zonerefs[25];
};

struct pglist_data___29 {
	struct zone___29 node_zones[3];
	struct zonelist___29 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___31 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___31 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___29 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___30 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___31 *owner;
};

struct secondary_data___30 {
	void *stack;
	struct task_struct___31 *task;
	long int status;
};

struct blocking_notifier_head___29 {
	struct rw_semaphore___30 rwsem;
	struct notifier_block *head;
};

struct key___30;

struct ucounts___20;

struct user_namespace___20 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___20 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___2 ns;
	long unsigned int flags;
	struct key___30 *persistent_keyring_register;
	struct rw_semaphore___30 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___20 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_root___27;

struct kernfs_elem_dir___27 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___27 *root;
};

struct kernfs_node___27;

struct kernfs_syscall_ops___27;

struct kernfs_root___27 {
	struct kernfs_node___27 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___27 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___27 {
	struct kernfs_node___27 *target_kn;
};

struct kernfs_ops___27;

struct kernfs_elem_attr___27 {
	const struct kernfs_ops___27 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___27 *notify_next;
};

struct kernfs_node___27 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___27 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___27 dir;
		struct kernfs_elem_symlink___27 symlink;
		struct kernfs_elem_attr___27 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___27;

struct kernfs_ops___27 {
	int (*open)(struct kernfs_open_file___27 *);
	void (*release)(struct kernfs_open_file___27 *);
	int (*seq_show)(struct seq_file___27 *, void *);
	void * (*seq_start)(struct seq_file___27 *, loff_t *);
	void * (*seq_next)(struct seq_file___27 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___27 *, void *);
	ssize_t (*read)(struct kernfs_open_file___27 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___27 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___27 *, struct vm_area_struct___30 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___27 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___27 {
	int (*remount_fs)(struct kernfs_root___27 *, int *, char *);
	int (*show_options)(struct seq_file___27 *, struct kernfs_root___27 *);
	int (*mkdir)(struct kernfs_node___27 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___27 *);
	int (*rename)(struct kernfs_node___27 *, struct kernfs_node___27 *, const char *);
	int (*show_path)(struct seq_file___27 *, struct kernfs_node___27 *, struct kernfs_root___27 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___24;

struct seq_file___27 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___24 *op;
	int poll_event;
	const struct file___30 *file;
	void *private;
};

struct vm_operations_struct___29;

struct kernfs_open_file___27 {
	struct kernfs_node___27 *kn;
	struct file___30 *file;
	struct seq_file___27 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___29 *vm_ops;
};

struct dentry___31;

struct path___29 {
	struct vfsmount *mnt;
	struct dentry___31 *dentry;
};

struct fown_struct___25 {
	rwlock_t lock;
	struct pid___25 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___30 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___29 f_path;
	struct inode___32 *f_inode;
	const struct file_operations___30 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___25 f_owner;
	const struct cred___29 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___29 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___29;

struct vm_operations_struct___29 {
	void (*open)(struct vm_area_struct___30 *);
	void (*close)(struct vm_area_struct___30 *);
	int (*split)(struct vm_area_struct___30 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___30 *);
	vm_fault_t (*fault)(struct vm_fault___29 *);
	vm_fault_t (*huge_fault)(struct vm_fault___29 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___29 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___30 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___29 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___29 *);
	int (*access)(struct vm_area_struct___30 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___30 *);
	int (*set_policy)(struct vm_area_struct___30 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___30 *, long unsigned int);
	struct page___30 * (*find_special_page)(struct vm_area_struct___30 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_area_struct___30 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___30 *vm_next;
	struct vm_area_struct___30 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___30 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___29 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___30 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___28;

struct bin_attribute___25;

struct attribute_group___25 {
	const char *name;
	umode_t (*is_visible)(struct kobject___28 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___28 *, struct bin_attribute___25 *, int);
	struct attribute **attrs;
	struct bin_attribute___25 **bin_attrs;
};

struct kset___27;

struct kobj_type___27;

struct kobject___28 {
	const char *name;
	struct list_head entry;
	struct kobject___28 *parent;
	struct kset___27 *kset;
	struct kobj_type___27 *ktype;
	struct kernfs_node___27 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___25 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___30 *, struct kobject___28 *, struct bin_attribute___25 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___30 *, struct kobject___28 *, struct bin_attribute___25 *, char *, loff_t, size_t);
	int (*mmap)(struct file___30 *, struct kobject___28 *, struct bin_attribute___25 *, struct vm_area_struct___30 *);
};

struct sysfs_ops___27 {
	ssize_t (*show)(struct kobject___28 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___28 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___27;

struct kset___27 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___28 kobj;
	const struct kset_uevent_ops___27 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___27 {
	void (*release)(struct kobject___28 *);
	const struct sysfs_ops___27 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___28 *);
	const void * (*namespace)(struct kobject___28 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___27 {
	int (* const filter)(struct kset___27 *, struct kobject___28 *);
	const char * (* const name)(struct kset___27 *, struct kobject___28 *);
	int (* const uevent)(struct kset___27 *, struct kobject___28 *, struct kobj_uevent_env *);
};

struct kobj_attribute___28 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___28 *, struct kobj_attribute___28 *, char *);
	ssize_t (*store)(struct kobject___28 *, struct kobj_attribute___28 *, const char *, size_t);
};

struct fwnode_operations___21;

struct fwnode_handle___21 {
	struct fwnode_handle___21 *secondary;
	const struct fwnode_operations___21 *ops;
};

struct device___25;

struct fwnode_reference_args___21;

struct fwnode_endpoint___21;

struct fwnode_operations___21 {
	struct fwnode_handle___21 * (*get)(struct fwnode_handle___21 *);
	void (*put)(struct fwnode_handle___21 *);
	bool (*device_is_available)(const struct fwnode_handle___21 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___21 *, const struct device___25 *);
	bool (*property_present)(const struct fwnode_handle___21 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___21 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___21 *, const char *, const char **, size_t);
	struct fwnode_handle___21 * (*get_parent)(const struct fwnode_handle___21 *);
	struct fwnode_handle___21 * (*get_next_child_node)(const struct fwnode_handle___21 *, struct fwnode_handle___21 *);
	struct fwnode_handle___21 * (*get_named_child_node)(const struct fwnode_handle___21 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___21 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___21 *);
	struct fwnode_handle___21 * (*graph_get_next_endpoint)(const struct fwnode_handle___21 *, struct fwnode_handle___21 *);
	struct fwnode_handle___21 * (*graph_get_remote_endpoint)(const struct fwnode_handle___21 *);
	struct fwnode_handle___21 * (*graph_get_port_parent)(struct fwnode_handle___21 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___21 *, struct fwnode_endpoint___21 *);
};

struct fwnode_endpoint___21 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___21 *local_fwnode;
};

struct fwnode_reference_args___21 {
	struct fwnode_handle___21 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct dev_pm_info___25 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___25 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___25;

struct bus_type___25;

struct device_driver___25;

struct dev_pm_domain___25;

struct irq_domain___2;

struct device_node___11;

struct class___25;

struct device___25 {
	struct device___25 *parent;
	struct device_private *p;
	struct kobject___28 kobj;
	const char *init_name;
	const struct device_type___25 *type;
	struct mutex mutex;
	struct bus_type___25 *bus;
	struct device_driver___25 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___25 power;
	struct dev_pm_domain___25 *pm_domain;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___11 *of_node;
	struct fwnode_handle___21 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___25 *class;
	const struct attribute_group___25 **groups;
	void (*release)(struct device___25 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct property___11 {
	char *name;
	int length;
	void *value;
	struct property___11 *next;
	long unsigned int _flags;
	struct bin_attribute___25 attr;
};

struct device_node___11 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___21 fwnode;
	struct property___11 *properties;
	struct property___11 *deadprops;
	struct device_node___11 *parent;
	struct device_node___11 *child;
	struct device_node___11 *sibling;
	struct kobject___28 kobj;
	long unsigned int _flags;
	void *data;
};

struct irq_fwspec___2 {
	struct fwnode_handle___21 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_data___5;

struct irq_domain_ops___2 {
	int (*match)(struct irq_domain___2 *, struct device_node___11 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___2 *, struct irq_fwspec___2 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___2 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___2 *, unsigned int);
	int (*xlate)(struct irq_domain___2 *, struct device_node___11 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___2 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___2 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___2 *, struct irq_data___5 *, bool);
	void (*deactivate)(struct irq_domain___2 *, struct irq_data___5 *);
	int (*translate)(struct irq_domain___2 *, struct irq_fwspec___2 *, long unsigned int *, unsigned int *);
};

struct irq_domain_chip_generic___2;

struct irq_domain___2 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___2 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___21 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___2 *gc;
	struct irq_domain___2 *parent;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_direct_max_irq;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_tree_mutex;
	unsigned int linear_revmap[0];
};

struct user_struct___29 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___30 *uid_keyring;
	struct key___30 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct upid___25 {
	int nr;
	struct pid_namespace___25 *ns;
};

struct pid_namespace___25 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___31 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___25 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___31 *proc_self;
	struct dentry___31 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___20 *user_ns;
	struct ucounts___20 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___2 ns;
};

struct pid___25 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___25 numbers[1];
};

struct core_state___29;

struct mm_struct___30 {
	struct {
		struct vm_area_struct___30 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___30 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___30 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___29 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___31 *owner;
		struct user_namespace___20 *user_ns;
		struct file___30 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___29 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___29 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___30 *session_keyring;
	struct key___30 *process_keyring;
	struct key___30 *thread_keyring;
	struct key___30 *request_key_auth;
	void *security;
	struct user_struct___29 *user;
	struct user_namespace___20 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___19;

struct nsproxy___28 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___25 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___19 *cgroup_ns;
};

struct signal_struct___27 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___31 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___31 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___25 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___25 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___30 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___25 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___19;

struct cgroup___19;

struct css_set___19 {
	struct cgroup_subsys_state___19 *subsys[13];
	refcount_t refcount;
	struct css_set___19 *dom_cset;
	struct cgroup___19 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___19 *mg_src_cgrp;
	struct cgroup___19 *mg_dst_cgrp;
	struct css_set___19 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___15 {
	struct pmu___15 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___31 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___15 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___24 {
	struct vm_struct___24 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___30 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___27 {
	struct task_struct___31 task;
	long unsigned int stack[8192];
};

struct address_space_operations___29;

struct address_space___29 {
	struct inode___32 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___30 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___29 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___29)(struct vm_area_struct___30 *, long unsigned int, const struct page___30 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___29)(struct page___30 *, void *);

struct dev_pagemap___29 {
	dev_page_fault_t___29 page_fault;
	dev_page_free_t___29 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___25 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___29 {
	struct task_struct___31 *task;
	struct core_thread___29 *next;
};

struct core_state___29 {
	atomic_t nr_threads;
	struct core_thread___29 dumper;
	struct completion startup;
};

struct vm_fault___29 {
	struct vm_area_struct___30 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___30 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___30 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___29 prealloc_pte;
};

struct dentry_operations___29;

struct super_block___30;

struct dentry___31 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___31 *d_parent;
	struct qstr d_name;
	struct inode___32 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___29 *d_op;
	struct super_block___30 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___29;

struct block_device___30;

struct inode___32 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___29 *i_op;
	struct super_block___30 *i_sb;
	struct address_space___29 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___30 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___30 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___29 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___30 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___29 {
	int (*d_revalidate)(struct dentry___31 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___31 *, unsigned int);
	int (*d_hash)(const struct dentry___31 *, struct qstr *);
	int (*d_compare)(const struct dentry___31 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___31 *);
	int (*d_init)(struct dentry___31 *);
	void (*d_release)(struct dentry___31 *);
	void (*d_prune)(struct dentry___31 *);
	void (*d_iput)(struct dentry___31 *, struct inode___32 *);
	char * (*d_dname)(struct dentry___31 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___29 *);
	int (*d_manage)(const struct path___29 *, bool);
	struct dentry___31 * (*d_real)(struct dentry___31 *, const struct inode___32 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___29;

struct mem_dqinfo___29 {
	struct quota_format_type___29 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___29;

struct quota_info___29 {
	unsigned int flags;
	struct rw_semaphore___30 dqio_sem;
	struct inode___32 *files[3];
	struct mem_dqinfo___29 info[3];
	const struct quota_format_ops___29 *ops[3];
};

struct rcuwait___29 {
	struct task_struct___31 *task;
};

struct percpu_rw_semaphore___29 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___30 rw_sem;
	struct rcuwait___29 writer;
	int readers_block;
};

struct sb_writers___29 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___29 rw_sem[3];
};

struct file_system_type___29;

struct super_operations___29;

struct dquot_operations___29;

struct quotactl_ops___29;

struct super_block___30 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___29 *s_type;
	const struct super_operations___29 *s_op;
	const struct dquot_operations___29 *dq_op;
	const struct quotactl_ops___29 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___31 *s_root;
	struct rw_semaphore___30 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___30 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___29 s_dquot;
	struct sb_writers___29 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___29 *s_d_op;
	int cleancache_poolid;
	struct shrinker___9 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___20 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___30 {
	struct file___30 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___30 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___30 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___30 *ia_file;
};

struct dquot___29 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___30 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___29 {
	int qf_fmt_id;
	const struct quota_format_ops___29 *qf_ops;
	struct module___27 *qf_owner;
	struct quota_format_type___29 *qf_next;
};

struct quota_format_ops___29 {
	int (*check_quota_file)(struct super_block___30 *, int);
	int (*read_file_info)(struct super_block___30 *, int);
	int (*write_file_info)(struct super_block___30 *, int);
	int (*free_file_info)(struct super_block___30 *, int);
	int (*read_dqblk)(struct dquot___29 *);
	int (*commit_dqblk)(struct dquot___29 *);
	int (*release_dqblk)(struct dquot___29 *);
	int (*get_next_id)(struct super_block___30 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___29 {
	int (*write_dquot)(struct dquot___29 *);
	struct dquot___29 * (*alloc_dquot)(struct super_block___30 *, int);
	void (*destroy_dquot)(struct dquot___29 *);
	int (*acquire_dquot)(struct dquot___29 *);
	int (*release_dquot)(struct dquot___29 *);
	int (*mark_dirty)(struct dquot___29 *);
	int (*write_info)(struct super_block___30 *, int);
	qsize_t * (*get_reserved_space)(struct inode___32 *);
	int (*get_projid)(struct inode___32 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___32 *, qsize_t *);
	int (*get_next_id)(struct super_block___30 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___29 {
	int (*quota_on)(struct super_block___30 *, int, int, const struct path___29 *);
	int (*quota_off)(struct super_block___30 *, int);
	int (*quota_enable)(struct super_block___30 *, unsigned int);
	int (*quota_disable)(struct super_block___30 *, unsigned int);
	int (*quota_sync)(struct super_block___30 *, int);
	int (*set_info)(struct super_block___30 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___30 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___30 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___30 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___30 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___30 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___24 {
	struct kobject___28 kobj;
	struct module___27 *mod;
	struct kobject___28 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___24 {
	struct module___27 *mod;
	struct latch_tree_node node;
};

struct module_layout___24 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___24 mtn;
};

struct module_attribute___24;

struct kernel_param___24;

struct module___27 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___24 mkobj;
	struct module_attribute___24 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___28 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___24 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___24 core_layout;
	struct module_layout___24 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___29 {
	int (*writepage)(struct page___30 *, struct writeback_control___3 *);
	int (*readpage)(struct file___30 *, struct page___30 *);
	int (*writepages)(struct address_space___29 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___30 *);
	int (*readpages)(struct file___30 *, struct address_space___29 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___30 *, struct address_space___29 *, loff_t, unsigned int, unsigned int, struct page___30 **, void **);
	int (*write_end)(struct file___30 *, struct address_space___29 *, loff_t, unsigned int, unsigned int, struct page___30 *, void *);
	sector_t (*bmap)(struct address_space___29 *, sector_t);
	void (*invalidatepage)(struct page___30 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___30 *, gfp_t);
	void (*freepage)(struct page___30 *);
	ssize_t (*direct_IO)(struct kiocb___30 *, struct iov_iter___11 *);
	int (*migratepage)(struct address_space___29 *, struct page___30 *, struct page___30 *, enum migrate_mode);
	bool (*isolate_page)(struct page___30 *, isolate_mode_t);
	void (*putback_page)(struct page___30 *);
	int (*launder_page)(struct page___30 *);
	int (*is_partially_uptodate)(struct page___30 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___30 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___29 *, struct page___30 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___30 *, sector_t *);
	void (*swap_deactivate)(struct file___30 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___30 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___32 *bd_inode;
	struct super_block___30 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___30 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___29 {
	struct dentry___31 * (*lookup)(struct inode___32 *, struct dentry___31 *, unsigned int);
	const char * (*get_link)(struct dentry___31 *, struct inode___32 *, struct delayed_call *);
	int (*permission)(struct inode___32 *, int);
	struct posix_acl * (*get_acl)(struct inode___32 *, int);
	int (*readlink)(struct dentry___31 *, char *, int);
	int (*create)(struct inode___32 *, struct dentry___31 *, umode_t, bool);
	int (*link)(struct dentry___31 *, struct inode___32 *, struct dentry___31 *);
	int (*unlink)(struct inode___32 *, struct dentry___31 *);
	int (*symlink)(struct inode___32 *, struct dentry___31 *, const char *);
	int (*mkdir)(struct inode___32 *, struct dentry___31 *, umode_t);
	int (*rmdir)(struct inode___32 *, struct dentry___31 *);
	int (*mknod)(struct inode___32 *, struct dentry___31 *, umode_t, dev_t);
	int (*rename)(struct inode___32 *, struct dentry___31 *, struct inode___32 *, struct dentry___31 *, unsigned int);
	int (*setattr)(struct dentry___31 *, struct iattr___30 *);
	int (*getattr)(const struct path___29 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___31 *, char *, size_t);
	int (*fiemap)(struct inode___32 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___32 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___32 *, struct dentry___31 *, struct file___30 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___32 *, struct dentry___31 *, umode_t);
	int (*set_acl)(struct inode___32 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___29 {
	void (*fl_copy_lock)(struct file_lock___30 *, struct file_lock___30 *);
	void (*fl_release_private)(struct file_lock___30 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___29;

struct file_lock___30 {
	struct file_lock___30 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___30 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___29 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___29 *fl_ops;
	const struct lock_manager_operations___29 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___29 {
	int (*lm_compare_owner)(struct file_lock___30 *, struct file_lock___30 *);
	long unsigned int (*lm_owner_key)(struct file_lock___30 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___30 *);
	int (*lm_grant)(struct file_lock___30 *, int);
	bool (*lm_break)(struct file_lock___30 *);
	int (*lm_change)(struct file_lock___30 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___30 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___29 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___29 *fa_next;
	struct file___30 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___29 {
	const char *name;
	int fs_flags;
	struct dentry___31 * (*mount)(struct file_system_type___29 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___30 *);
	struct module___27 *owner;
	struct file_system_type___29 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___29 {
	struct inode___32 * (*alloc_inode)(struct super_block___30 *);
	void (*destroy_inode)(struct inode___32 *);
	void (*dirty_inode)(struct inode___32 *, int);
	int (*write_inode)(struct inode___32 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___32 *);
	void (*evict_inode)(struct inode___32 *);
	void (*put_super)(struct super_block___30 *);
	int (*sync_fs)(struct super_block___30 *, int);
	int (*freeze_super)(struct super_block___30 *);
	int (*freeze_fs)(struct super_block___30 *);
	int (*thaw_super)(struct super_block___30 *);
	int (*unfreeze_fs)(struct super_block___30 *);
	int (*statfs)(struct dentry___31 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___30 *, int *, char *);
	void (*umount_begin)(struct super_block___30 *);
	int (*show_options)(struct seq_file___27 *, struct dentry___31 *);
	int (*show_devname)(struct seq_file___27 *, struct dentry___31 *);
	int (*show_path)(struct seq_file___27 *, struct dentry___31 *);
	int (*show_stats)(struct seq_file___27 *, struct dentry___31 *);
	ssize_t (*quota_read)(struct super_block___30 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___30 *, int, const char *, size_t, loff_t);
	struct dquot___29 ** (*get_dquots)(struct inode___32 *);
	int (*bdev_try_to_free_page)(struct super_block___30 *, struct page___30 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___30 *, struct shrink_control___9 *);
	long int (*free_cached_objects)(struct super_block___30 *, struct shrink_control___9 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___29(struct page___30 *);

struct mmu_notifier___5;

struct mmu_notifier_ops___5 {
	int flags;
	void (*release)(struct mmu_notifier___5 *, struct mm_struct___30 *);
	int (*clear_flush_young)(struct mmu_notifier___5 *, struct mm_struct___30 *, long unsigned int, long unsigned int);
	int (*clear_young)(struct mmu_notifier___5 *, struct mm_struct___30 *, long unsigned int, long unsigned int);
	int (*test_young)(struct mmu_notifier___5 *, struct mm_struct___30 *, long unsigned int);
	void (*change_pte)(struct mmu_notifier___5 *, struct mm_struct___30 *, long unsigned int, pte_t);
	void (*invalidate_range_start)(struct mmu_notifier___5 *, struct mm_struct___30 *, long unsigned int, long unsigned int);
	void (*invalidate_range_end)(struct mmu_notifier___5 *, struct mm_struct___30 *, long unsigned int, long unsigned int);
	void (*invalidate_range)(struct mmu_notifier___5 *, struct mm_struct___30 *, long unsigned int, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mmu_notifier___5 {
	struct hlist_node hlist;
	const struct mmu_notifier_ops___5 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct kvm_vcpu___5;

struct kvm_io_device___5;

struct kvm_io_device_ops___5 {
	int (*read)(struct kvm_vcpu___5 *, struct kvm_io_device___5 *, gpa_t, int, void *);
	int (*write)(struct kvm_vcpu___5 *, struct kvm_io_device___5 *, gpa_t, int, const void *);
	void (*destructor)(struct kvm_io_device___5 *);
};

struct kvm_cpu_context___5 {
	struct kvm_regs gp_regs;
	union {
		u64 sys_regs[101];
		u32 copro[202];
	};
	struct kvm_vcpu___5 *__hyp_running_vcpu;
};

typedef struct kvm_cpu_context___5 kvm_cpu_context_t___5;

struct its_vm___5;

struct its_vpe___5 {
	struct page___30 *vpt_page;
	struct its_vm___5 *its_vm;
	int irq;
	irq_hw_number_t vpe_db_lpi;
	int vpe_proxy_event;
	u16 col_idx;
	u16 vpe_id;
	bool idai;
	bool pending_last;
};

struct vgic_v3_cpu_if___5 {
	u32 vgic_hcr;
	u32 vgic_vmcr;
	u32 vgic_sre;
	u32 vgic_ap0r[4];
	u32 vgic_ap1r[4];
	u64 vgic_lr[16];
	struct its_vpe___5 its_vpe;
};

struct vgic_irq___5 {
	raw_spinlock_t irq_lock;
	struct list_head lpi_list;
	struct list_head ap_list;
	struct kvm_vcpu___5 *vcpu;
	struct kvm_vcpu___5 *target_vcpu;
	u32 intid;
	bool line_level;
	bool pending_latch;
	bool active;
	bool enabled;
	bool hw;
	struct kref refcount;
	u32 hwintid;
	unsigned int host_irq;
	union {
		u8 targets;
		u32 mpidr;
	};
	u8 source;
	u8 active_source;
	u8 priority;
	u8 group;
	enum vgic_irq_config config;
	bool (*get_input_level)(int);
	void *owner;
};

struct kvm_io_device___5 {
	const struct kvm_io_device_ops___5 *ops;
};

struct vgic_its___5;

struct vgic_io_device___5 {
	gpa_t base_addr;
	union {
		struct kvm_vcpu___5 *redist_vcpu;
		struct vgic_its___5 *its;
	};
	const struct vgic_register_region *regions;
	enum iodev_type iodev_type;
	int nr_regions;
	struct kvm_io_device___5 dev;
};

struct vgic_cpu___5 {
	union {
		struct vgic_v2_cpu_if vgic_v2;
		struct vgic_v3_cpu_if___5 vgic_v3;
	};
	unsigned int used_lrs;
	struct vgic_irq___5 private_irqs[32];
	raw_spinlock_t ap_list_lock;
	struct list_head ap_list_head;
	struct vgic_io_device___5 rd_iodev;
	struct vgic_io_device___5 sgi_iodev;
	struct vgic_redist_region *rdreg;
	u64 pendbaser;
	bool lpis_enabled;
	u32 num_pri_bits;
	u32 num_id_bits;
};

struct arch_timer_context___5 {
	struct kvm_vcpu___5 *vcpu;
	u32 cnt_ctl;
	u64 cnt_cval;
	struct kvm_irq_level irq;
	u64 cntvoff;
	struct hrtimer hrtimer;
	bool loaded;
	u32 host_timer_irq;
	u32 host_timer_irq_flags;
};

struct arch_timer_cpu___5 {
	struct arch_timer_context___5 timers[2];
	struct hrtimer bg_timer;
	bool enabled;
};

struct kvm_pmc___5 {
	u8 idx;
	struct perf_event___15 *perf_event;
	u64 bitmask;
};

struct kvm_pmu___5 {
	int irq_num;
	struct kvm_pmc___5 pmc[32];
	bool ready;
	bool created;
	bool irq_level;
};

struct kvm_vcpu_arch___5 {
	struct kvm_cpu_context___5 ctxt;
	void *sve_state;
	unsigned int sve_max_vl;
	u64 hcr_el2;
	u32 mdcr_el2;
	struct kvm_vcpu_fault_info fault;
	u64 workaround_flags;
	u64 flags;
	struct kvm_guest_debug_arch *debug_ptr;
	struct kvm_guest_debug_arch vcpu_debug_state;
	struct kvm_guest_debug_arch external_debug_state;
	kvm_cpu_context_t___5 *host_cpu_context;
	struct thread_info *host_thread_info;
	struct user_fpsimd_state *host_fpsimd_state;
	struct {
		struct kvm_guest_debug_arch regs;
		u64 pmscr_el1;
	} host_debug_state;
	struct vgic_cpu___5 vgic_cpu;
	struct arch_timer_cpu___5 timer_cpu;
	struct kvm_pmu___5 pmu;
	struct {
		u32 mdscr_el1;
	} guest_debug_preserved;
	bool power_off;
	bool pause;
	struct kvm_decode mmio_decode;
	struct kvm_mmu_memory_cache mmu_page_cache;
	int target;
	long unsigned int features[1];
	bool has_run_once;
	u64 vsesr_el2;
	struct vcpu_reset_state reset_state;
	bool sysregs_loaded_on_cpu;
};

struct kvm___5;

struct kvm_vcpu___5 {
	struct kvm___5 *kvm;
	struct preempt_notifier___5 preempt_notifier;
	int cpu;
	int vcpu_id;
	int srcu_idx;
	int mode;
	u64 requests;
	long unsigned int guest_debug;
	int pre_pcpu;
	struct list_head blocked_vcpu_list;
	struct mutex mutex;
	struct kvm_run *run;
	int guest_xcr0_loaded;
	struct swait_queue_head wq;
	struct pid___25 *pid;
	int sigset_active;
	sigset_t sigset;
	struct kvm_vcpu_stat stat;
	unsigned int halt_poll_ns;
	bool valid_wakeup;
	int mmio_needed;
	int mmio_read_completed;
	int mmio_is_write;
	int mmio_cur_fragment;
	int mmio_nr_fragments;
	struct kvm_mmio_fragment mmio_fragments[2];
	struct {
		bool in_spin_loop;
		bool dy_eligible;
	} spin_loop;
	bool preempted;
	struct kvm_vcpu_arch___5 arch;
	struct dentry___31 *debugfs_dentry;
	long: 64;
};

struct its_vm___5 {
	struct fwnode_handle___21 *fwnode;
	struct irq_domain___2 *domain;
	struct page___30 *vprop_page;
	struct its_vpe___5 **vpes;
	int nr_vpes;
	irq_hw_number_t db_lpi_base;
	long unsigned int *db_bitmap;
	int nr_db_lpis;
	u32 vlpi_count[16];
};

struct kvm_device___5;

struct vgic_its___5 {
	gpa_t vgic_its_base;
	bool enabled;
	struct vgic_io_device___5 iodev;
	struct kvm_device___5 *dev;
	u64 baser_device_table;
	u64 baser_coll_table;
	struct mutex cmd_lock;
	u64 cbaser;
	u32 creadr;
	u32 cwriter;
	u32 abi_rev;
	struct mutex its_lock;
	struct list_head device_list;
	struct list_head collection_list;
};

struct kvm_device_ops___5;

struct kvm_device___5 {
	struct kvm_device_ops___5 *ops;
	struct kvm___5 *kvm;
	void *private;
	struct list_head vm_node;
};

struct vgic_dist___5 {
	bool in_kernel;
	bool ready;
	bool initialized;
	u32 vgic_model;
	u32 implementation_rev;
	bool v2_groups_user_writable;
	bool msis_require_devid;
	int nr_spis;
	gpa_t vgic_dist_base;
	union {
		gpa_t vgic_cpu_base;
		struct list_head rd_regions;
	};
	bool enabled;
	struct vgic_irq___5 *spis;
	struct vgic_io_device___5 dist_iodev;
	bool has_its;
	u64 propbaser;
	raw_spinlock_t lpi_list_lock;
	struct list_head lpi_list_head;
	int lpi_list_count;
	struct vgic_state_iter *iter;
	struct its_vm___5 its_vm;
};

struct cgroup_namespace___19 {
	refcount_t count;
	struct ns_common___2 ns;
	struct user_namespace___20 *user_ns;
	struct ucounts___20 *ucounts;
	struct css_set___19 *root_cset;
};

struct ucounts___20 {
	struct hlist_node node;
	struct user_namespace___20 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct kernel_param_ops___24 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___24 *);
	int (*get)(char *, const struct kernel_param___24 *);
	void (*free)(void *);
};

struct kparam_array___24;

struct kernel_param___24 {
	const char *name;
	struct module___27 *mod;
	const struct kernel_param_ops___24 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___24 *arr;
	};
};

struct kparam_array___24 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___24 *ops;
	void *elem;
};

struct module_attribute___24 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___24 *, struct module_kobject___24 *, char *);
	ssize_t (*store)(struct module_attribute___24 *, struct module_kobject___24 *, const char *, size_t);
	void (*setup)(struct module___27 *, const char *);
	int (*test)(struct module___27 *);
	void (*free)(struct module___27 *);
};

typedef int (*key_restrict_link_func_t___29)(struct key___30 *, const struct key_type *, const union key_payload *, struct key___30 *);

struct key_restriction___30;

struct key___30 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___30 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___30 *restrict_link;
};

struct key_restriction___30 {
	key_restrict_link_func_t___29 check;
	struct key___30 *key;
	struct key_type *keytype;
};

struct dev_pm_ops___25 {
	int (*prepare)(struct device___25 *);
	void (*complete)(struct device___25 *);
	int (*suspend)(struct device___25 *);
	int (*resume)(struct device___25 *);
	int (*freeze)(struct device___25 *);
	int (*thaw)(struct device___25 *);
	int (*poweroff)(struct device___25 *);
	int (*restore)(struct device___25 *);
	int (*suspend_late)(struct device___25 *);
	int (*resume_early)(struct device___25 *);
	int (*freeze_late)(struct device___25 *);
	int (*thaw_early)(struct device___25 *);
	int (*poweroff_late)(struct device___25 *);
	int (*restore_early)(struct device___25 *);
	int (*suspend_noirq)(struct device___25 *);
	int (*resume_noirq)(struct device___25 *);
	int (*freeze_noirq)(struct device___25 *);
	int (*thaw_noirq)(struct device___25 *);
	int (*poweroff_noirq)(struct device___25 *);
	int (*restore_noirq)(struct device___25 *);
	int (*runtime_suspend)(struct device___25 *);
	int (*runtime_resume)(struct device___25 *);
	int (*runtime_idle)(struct device___25 *);
};

struct dev_pm_domain___25 {
	struct dev_pm_ops___25 ops;
	void (*detach)(struct device___25 *, bool);
	int (*activate)(struct device___25 *);
	void (*sync)(struct device___25 *);
	void (*dismiss)(struct device___25 *);
};

struct bus_type___25 {
	const char *name;
	const char *dev_name;
	struct device___25 *dev_root;
	const struct attribute_group___25 **bus_groups;
	const struct attribute_group___25 **dev_groups;
	const struct attribute_group___25 **drv_groups;
	int (*match)(struct device___25 *, struct device_driver___25 *);
	int (*uevent)(struct device___25 *, struct kobj_uevent_env *);
	int (*probe)(struct device___25 *);
	int (*remove)(struct device___25 *);
	void (*shutdown)(struct device___25 *);
	int (*online)(struct device___25 *);
	int (*offline)(struct device___25 *);
	int (*suspend)(struct device___25 *, pm_message_t);
	int (*resume)(struct device___25 *);
	int (*num_vf)(struct device___25 *);
	int (*dma_configure)(struct device___25 *);
	const struct dev_pm_ops___25 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___25 {
	const char *name;
	struct bus_type___25 *bus;
	struct module___27 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___25 *);
	int (*remove)(struct device___25 *);
	void (*shutdown)(struct device___25 *);
	int (*suspend)(struct device___25 *, pm_message_t);
	int (*resume)(struct device___25 *);
	const struct attribute_group___25 **groups;
	const struct dev_pm_ops___25 *pm;
	void (*coredump)(struct device___25 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___25 {
	const char *name;
	const struct attribute_group___25 **groups;
	int (*uevent)(struct device___25 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___25 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___25 *);
	const struct dev_pm_ops___25 *pm;
};

struct class___25 {
	const char *name;
	struct module___27 *owner;
	const struct attribute_group___25 **class_groups;
	const struct attribute_group___25 **dev_groups;
	struct kobject___28 *dev_kobj;
	int (*dev_uevent)(struct device___25 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___25 *, umode_t *);
	void (*class_release)(struct class___25 *);
	void (*dev_release)(struct device___25 *);
	int (*shutdown_pre)(struct device___25 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___25 *);
	const struct dev_pm_ops___25 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___23 {
	struct device___25 dev;
};

struct seq_operations___24 {
	void * (*start)(struct seq_file___27 *, loff_t *);
	void (*stop)(struct seq_file___27 *, void *);
	void * (*next)(struct seq_file___27 *, void *, loff_t *);
	int (*show)(struct seq_file___27 *, void *);
};

struct bpf_map___19;

struct bpf_map_ops___19 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___19 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___19 *, struct file___30 *);
	void (*map_free)(struct bpf_map___19 *);
	int (*map_get_next_key)(struct bpf_map___19 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___19 *);
	void * (*map_lookup_elem)(struct bpf_map___19 *, void *);
	int (*map_update_elem)(struct bpf_map___19 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___19 *, void *);
	int (*map_push_elem)(struct bpf_map___19 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___19 *, void *);
	int (*map_peek_elem)(struct bpf_map___19 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___19 *, struct file___30 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___19 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___19 *, void *, struct seq_file___27 *);
	int (*map_check_btf)(const struct bpf_map___19 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___19 {
	const struct bpf_map_ops___19 *ops;
	struct bpf_map___19 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___29 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___19;

typedef void (*kthread_work_func_t___19)(struct kthread_work___19 *);

struct kthread_worker___19;

struct kthread_work___19 {
	struct list_head node;
	kthread_work_func_t___19 func;
	struct kthread_worker___19 *worker;
	int canceling;
};

struct kthread_worker___19 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___31 *task;
	struct kthread_work___19 *current_work;
};

struct kthread_delayed_work___19 {
	struct kthread_work___19 work;
	struct timer_list timer;
};

struct psi_group___19 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___19 *poll_kworker;
	struct kthread_delayed_work___19 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___19 {
	struct kernfs_node___27 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___19;

struct cgroup_subsys_state___19 {
	struct cgroup___19 *cgroup;
	struct cgroup_subsys___19 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___19 *parent;
};

struct cgroup_root___19;

struct cgroup_rstat_cpu___19;

struct cgroup___19 {
	struct cgroup_subsys_state___19 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___27 *kn;
	struct cgroup_file___19 procs_file;
	struct cgroup_file___19 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___19 *subsys[13];
	struct cgroup_root___19 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___19 *dom_cgrp;
	struct cgroup_rstat_cpu___19 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___2 bpf;
	atomic_t congestion_count;
	struct cgroup___19 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___19 psi;
	int ancestor_ids[0];
};

struct cftype___19;

struct cgroup_subsys___19 {
	struct cgroup_subsys_state___19 * (*css_alloc)(struct cgroup_subsys_state___19 *);
	int (*css_online)(struct cgroup_subsys_state___19 *);
	void (*css_offline)(struct cgroup_subsys_state___19 *);
	void (*css_released)(struct cgroup_subsys_state___19 *);
	void (*css_free)(struct cgroup_subsys_state___19 *);
	void (*css_reset)(struct cgroup_subsys_state___19 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___19 *, int);
	int (*css_extra_stat_show)(struct seq_file___27 *, struct cgroup_subsys_state___19 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___31 *);
	void (*cancel_fork)(struct task_struct___31 *);
	void (*fork)(struct task_struct___31 *);
	void (*exit)(struct task_struct___31 *);
	void (*free)(struct task_struct___31 *);
	void (*bind)(struct cgroup_subsys_state___19 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___19 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___19 *dfl_cftypes;
	struct cftype___19 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___19 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___19 *updated_children;
	struct cgroup___19 *updated_next;
};

struct cgroup_root___19 {
	struct kernfs_root___27 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___19 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___19 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___19 *ss;
	struct list_head node;
	struct kernfs_ops___27 *kf_ops;
	int (*open)(struct kernfs_open_file___27 *);
	void (*release)(struct kernfs_open_file___27 *);
	u64 (*read_u64)(struct cgroup_subsys_state___19 *, struct cftype___19 *);
	s64 (*read_s64)(struct cgroup_subsys_state___19 *, struct cftype___19 *);
	int (*seq_show)(struct seq_file___27 *, void *);
	void * (*seq_start)(struct seq_file___27 *, loff_t *);
	void * (*seq_next)(struct seq_file___27 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___27 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___19 *, struct cftype___19 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___19 *, struct cftype___19 *, s64);
	ssize_t (*write)(struct kernfs_open_file___27 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___27 *, struct poll_table_struct___6 *);
};

struct perf_cpu_context___15;

struct pmu___15 {
	struct list_head entry;
	struct module___27 *module;
	struct device___25 *dev;
	const struct attribute_group___25 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___15 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___15 *);
	void (*pmu_disable)(struct pmu___15 *);
	int (*event_init)(struct perf_event___15 *);
	void (*event_mapped)(struct perf_event___15 *, struct mm_struct___30 *);
	void (*event_unmapped)(struct perf_event___15 *, struct mm_struct___30 *);
	int (*add)(struct perf_event___15 *, int);
	void (*del)(struct perf_event___15 *, int);
	void (*start)(struct perf_event___15 *, int);
	void (*stop)(struct perf_event___15 *, int);
	void (*read)(struct perf_event___15 *);
	void (*start_txn)(struct pmu___15 *, unsigned int);
	int (*commit_txn)(struct pmu___15 *);
	void (*cancel_txn)(struct pmu___15 *);
	int (*event_idx)(struct perf_event___15 *);
	void (*sched_task)(struct perf_event_context___15 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___15 *);
	int (*filter_match)(struct perf_event___15 *);
	int (*check_period)(struct perf_event___15 *, u64);
};

struct perf_cpu_context___15 {
	struct perf_event_context___15 ctx;
	struct perf_event_context___15 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___15 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___15 {
	struct cgroup_subsys_state___19 css;
	struct perf_cgroup_info *info;
};

struct kvm_arch___5 {
	struct kvm_vmid vmid;
	pgd_t *pgd;
	phys_addr_t pgd_phys;
	u64 vtcr;
	int *last_vcpu_ran;
	int max_vcpus;
	struct vgic_dist___5 vgic;
	u32 psci_version;
};

struct kvm_io_range___5 {
	gpa_t addr;
	int len;
	struct kvm_io_device___5 *dev;
};

struct kvm_io_bus___5 {
	int dev_count;
	int ioeventfd_count;
	struct kvm_io_range___5 range[0];
};

struct kvm_stat_data___5;

struct kvm___5 {
	spinlock_t mmu_lock;
	struct mutex slots_lock;
	struct mm_struct___30 *mm;
	struct kvm_memslots *memslots[1];
	struct kvm_vcpu___5 *vcpus[512];
	atomic_t online_vcpus;
	int created_vcpus;
	int last_boosted_vcpu;
	struct list_head vm_list;
	struct mutex lock;
	struct kvm_io_bus___5 *buses[4];
	struct {
		spinlock_t lock;
		struct list_head items;
		struct list_head resampler_list;
		struct mutex resampler_lock;
	} irqfds;
	struct list_head ioeventfds;
	struct kvm_vm_stat stat;
	struct kvm_arch___5 arch;
	refcount_t users_count;
	struct kvm_coalesced_mmio_ring *coalesced_mmio_ring;
	spinlock_t ring_lock;
	struct list_head coalesced_zones;
	struct mutex irq_lock;
	struct kvm_irq_routing_table *irq_routing;
	struct hlist_head irq_ack_notifier_list;
	struct mmu_notifier___5 mmu_notifier;
	long unsigned int mmu_notifier_seq;
	long int mmu_notifier_count;
	long int tlbs_dirty;
	struct list_head devices;
	bool manual_dirty_log_protect;
	struct dentry___31 *debugfs_dentry;
	struct kvm_stat_data___5 **debugfs_stat_data;
	struct srcu_struct srcu;
	struct srcu_struct irq_srcu;
	pid_t userspace_pid;
};

struct kvm_stat_data___5 {
	int offset;
	int mode;
	struct kvm___5 *kvm;
};

struct kvm_device_ops___5 {
	const char *name;
	int (*create)(struct kvm_device___5 *, u32);
	void (*init)(struct kvm_device___5 *);
	void (*destroy)(struct kvm_device___5 *);
	void (*release)(struct kvm_device___5 *);
	int (*set_attr)(struct kvm_device___5 *, struct kvm_device_attr *);
	int (*get_attr)(struct kvm_device___5 *, struct kvm_device_attr *);
	int (*has_attr)(struct kvm_device___5 *, struct kvm_device_attr *);
	long int (*ioctl)(struct kvm_device___5 *, unsigned int, long unsigned int);
	int (*mmap)(struct kvm_device___5 *, struct vm_area_struct___30 *);
};

struct hstate___5 {
	int next_nid_to_alloc;
	int next_nid_to_free;
	unsigned int order;
	long unsigned int mask;
	long unsigned int max_huge_pages;
	long unsigned int nr_huge_pages;
	long unsigned int free_huge_pages;
	long unsigned int resv_huge_pages;
	long unsigned int surplus_huge_pages;
	long unsigned int nr_overcommit_huge_pages;
	struct list_head hugepage_activelist;
	struct list_head hugepage_freelists[8];
	unsigned int nr_huge_pages_node[8];
	unsigned int free_huge_pages_node[8];
	unsigned int surplus_huge_pages_node[8];
	struct cftype___19 cgroup_files[5];
	char name[32];
};

struct module___28;

struct file___31;

struct kiocb___31;

struct vm_area_struct___31;

struct inode___33;

struct file_lock___31;

struct page___31;

struct seq_file___28;

struct file_operations___31 {
	struct module___28 *owner;
	loff_t (*llseek)(struct file___31 *, loff_t, int);
	ssize_t (*read)(struct file___31 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___31 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___31 *, struct iov_iter___11 *);
	ssize_t (*write_iter)(struct kiocb___31 *, struct iov_iter___11 *);
	int (*iopoll)(struct kiocb___31 *, bool);
	int (*iterate)(struct file___31 *, struct dir_context *);
	int (*iterate_shared)(struct file___31 *, struct dir_context *);
	__poll_t (*poll)(struct file___31 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___31 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___31 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___31 *, struct vm_area_struct___31 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___33 *, struct file___31 *);
	int (*flush)(struct file___31 *, fl_owner_t);
	int (*release)(struct inode___33 *, struct file___31 *);
	int (*fsync)(struct file___31 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___31 *, int);
	int (*lock)(struct file___31 *, int, struct file_lock___31 *);
	ssize_t (*sendpage)(struct file___31 *, struct page___31 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___31 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___31 *, int, struct file_lock___31 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___31 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___31 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___31 *, long int, struct file_lock___31 **, void **);
	long int (*fallocate)(struct file___31 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___28 *, struct file___31 *);
	ssize_t (*copy_file_range)(struct file___31 *, loff_t, struct file___31 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___31 *, loff_t, struct file___31 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___31 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct preempt_notifier___6;

struct task_struct___32;

struct preempt_ops___6 {
	void (*sched_in)(struct preempt_notifier___6 *, int);
	void (*sched_out)(struct preempt_notifier___6 *, struct task_struct___32 *);
};

struct preempt_notifier___6 {
	struct hlist_node link;
	struct preempt_ops___6 *ops;
};

struct vmacache___30 {
	u64 seqnum;
	struct vm_area_struct___31 *vmas[4];
};

struct page_frag___30 {
	struct page___31 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___16;

struct debug_info___16 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___16 *hbp_break[16];
	struct perf_event___16 *hbp_watch[16];
};

struct thread_struct___16 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___16 debug;
	long: 64;
};

struct mm_struct___31;

struct pid___26;

struct cred___30;

struct nsproxy___29;

struct signal_struct___28;

struct css_set___20;

struct perf_event_context___16;

struct vm_struct___25;

struct task_struct___32 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___32 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___31 *mm;
	struct mm_struct___31 *active_mm;
	struct vmacache___30 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___32 *real_parent;
	struct task_struct___32 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___32 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___26 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___26 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___26 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___30 *ptracer_cred;
	const struct cred___30 *real_cred;
	const struct cred___30 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___29 *nsproxy;
	struct signal_struct___28 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___32 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___3 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___20 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___16 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___30 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___32 *oom_reaper_list;
	struct vm_struct___25 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___16 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct secondary_data___31 {
	void *stack;
	struct task_struct___32 *task;
	long int status;
};

struct hw_perf_event___16 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___32 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___16)(struct perf_event___16 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___16;

struct fasync_struct___30;

struct pid_namespace___26;

struct perf_cgroup___16;

struct perf_event___16 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___16 *group_leader;
	struct pmu___16 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___16 hw;
	struct perf_event_context___16 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___16 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___32 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___30 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___16 *);
	struct callback_head callback_head;
	struct pid_namespace___26 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___16 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___16 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___5 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___16 *cgrp;
	struct list_head sb_list;
};

struct irqaction___4 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___4 *next;
	irq_handler_t thread_fn;
	struct task_struct___32 *thread;
	struct irqaction___4 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_desc___4;

typedef void (*irq_flow_handler_t___4)(struct irq_desc___4 *);

struct msi_desc___3;

struct irq_common_data___2 {
	unsigned int state_use_accessors;
	unsigned int node;
	void *handler_data;
	struct msi_desc___3 *msi_desc;
	cpumask_var_t affinity;
	cpumask_var_t effective_affinity;
};

struct irq_chip___5;

struct irq_domain___3;

struct irq_data___6 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___2 *common;
	struct irq_chip___5 *chip;
	struct irq_domain___3 *domain;
	struct irq_data___6 *parent_data;
	void *chip_data;
};

struct kset___28;

struct kobj_type___28;

struct kernfs_node___28;

struct kobject___29 {
	const char *name;
	struct list_head entry;
	struct kobject___29 *parent;
	struct kset___28 *kset;
	struct kobj_type___28 *ktype;
	struct kernfs_node___28 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct irq_desc___4 {
	struct irq_common_data___2 irq_common_data;
	struct irq_data___6 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___4 handle_irq;
	struct irqaction___4 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int irq_count;
	unsigned int tot_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___29 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___28 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___31 *pgtable_t___30;

struct address_space___30;

struct dev_pagemap___30;

struct page___31 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___30 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___31 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___30 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___31 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___30 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___30;

struct lruvec___30 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___30 *pgdat;
};

struct zone___30 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___30 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___30 {
	struct zone___30 *zone;
	int zone_idx;
};

struct zonelist___30 {
	struct zoneref___30 _zonerefs[25];
};

struct pglist_data___30 {
	struct zone___30 node_zones[3];
	struct zonelist___30 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___32 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___32 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___30 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___31 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___32 *owner;
};

struct blocking_notifier_head___30 {
	struct rw_semaphore___31 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___30;

struct vm_area_struct___31 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___31 *vm_next;
	struct vm_area_struct___31 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___31 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___30 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___31 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___30;

struct user_namespace___21;

struct mm_struct___31 {
	struct {
		struct vm_area_struct___31 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___31 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___31 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___30 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___32 *owner;
		struct user_namespace___21 *user_ns;
		struct file___31 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___30 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___30;

struct address_space___30 {
	struct inode___33 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___31 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___30 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___30)(struct vm_area_struct___31 *, long unsigned int, const struct page___31 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___30)(struct page___31 *, void *);

struct device___26;

struct dev_pagemap___30 {
	dev_page_fault_t___30 page_fault;
	dev_page_free_t___30 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___26 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct dentry___32;

struct path___30 {
	struct vfsmount *mnt;
	struct dentry___32 *dentry;
};

struct fown_struct___26 {
	rwlock_t lock;
	struct pid___26 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___31 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___30 f_path;
	struct inode___33 *f_inode;
	const struct file_operations___31 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___26 f_owner;
	const struct cred___30 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___30 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___30;

struct vm_operations_struct___30 {
	void (*open)(struct vm_area_struct___31 *);
	void (*close)(struct vm_area_struct___31 *);
	int (*split)(struct vm_area_struct___31 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___31 *);
	vm_fault_t (*fault)(struct vm_fault___30 *);
	vm_fault_t (*huge_fault)(struct vm_fault___30 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___30 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___31 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___30 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___30 *);
	int (*access)(struct vm_area_struct___31 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___31 *);
	int (*set_policy)(struct vm_area_struct___31 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___31 *, long unsigned int);
	struct page___31 * (*find_special_page)(struct vm_area_struct___31 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___30 {
	struct task_struct___32 *task;
	struct core_thread___30 *next;
};

struct core_state___30 {
	atomic_t nr_threads;
	struct core_thread___30 dumper;
	struct completion startup;
};

struct key___31;

struct ucounts___21;

struct user_namespace___21 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___21 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___2 ns;
	long unsigned int flags;
	struct key___31 *persistent_keyring_register;
	struct rw_semaphore___31 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___21 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___30 {
	struct vm_area_struct___31 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___31 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___31 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___30 prealloc_pte;
};

struct upid___26 {
	int nr;
	struct pid_namespace___26 *ns;
};

struct pid_namespace___26 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___32 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___26 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___32 *proc_self;
	struct dentry___32 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___21 *user_ns;
	struct ucounts___21 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___2 ns;
};

struct pid___26 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___26 numbers[1];
};

struct user_struct___30 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___31 *uid_keyring;
	struct key___31 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___30 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___31 *session_keyring;
	struct key___31 *process_keyring;
	struct key___31 *thread_keyring;
	struct key___31 *request_key_auth;
	void *security;
	struct user_struct___30 *user;
	struct user_namespace___21 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___20;

struct nsproxy___29 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___26 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___20 *cgroup_ns;
};

struct signal_struct___28 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___32 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___32 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___26 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___26 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___31 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___26 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___20;

struct cgroup___20;

struct css_set___20 {
	struct cgroup_subsys_state___20 *subsys[13];
	refcount_t refcount;
	struct css_set___20 *dom_cset;
	struct cgroup___20 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___20 *mg_src_cgrp;
	struct cgroup___20 *mg_dst_cgrp;
	struct css_set___20 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___16 {
	struct pmu___16 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___32 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___16 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___25 {
	struct vm_struct___25 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___31 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___28 {
	struct task_struct___32 task;
	long unsigned int stack[8192];
};

struct fwnode_operations___22;

struct fwnode_handle___22 {
	struct fwnode_handle___22 *secondary;
	const struct fwnode_operations___22 *ops;
};

struct fwnode_reference_args___22;

struct fwnode_endpoint___22;

struct fwnode_operations___22 {
	struct fwnode_handle___22 * (*get)(struct fwnode_handle___22 *);
	void (*put)(struct fwnode_handle___22 *);
	bool (*device_is_available)(const struct fwnode_handle___22 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___22 *, const struct device___26 *);
	bool (*property_present)(const struct fwnode_handle___22 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___22 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___22 *, const char *, const char **, size_t);
	struct fwnode_handle___22 * (*get_parent)(const struct fwnode_handle___22 *);
	struct fwnode_handle___22 * (*get_next_child_node)(const struct fwnode_handle___22 *, struct fwnode_handle___22 *);
	struct fwnode_handle___22 * (*get_named_child_node)(const struct fwnode_handle___22 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___22 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___22 *);
	struct fwnode_handle___22 * (*graph_get_next_endpoint)(const struct fwnode_handle___22 *, struct fwnode_handle___22 *);
	struct fwnode_handle___22 * (*graph_get_remote_endpoint)(const struct fwnode_handle___22 *);
	struct fwnode_handle___22 * (*graph_get_port_parent)(struct fwnode_handle___22 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___22 *, struct fwnode_endpoint___22 *);
};

struct fwnode_endpoint___22 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___22 *local_fwnode;
};

struct fwnode_reference_args___22 {
	struct fwnode_handle___22 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct dev_pm_info___26 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___26 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___26;

struct bus_type___26;

struct device_driver___26;

struct dev_pm_domain___26;

struct device_node___12;

struct class___26;

struct attribute_group___26;

struct device___26 {
	struct device___26 *parent;
	struct device_private *p;
	struct kobject___29 kobj;
	const char *init_name;
	const struct device_type___26 *type;
	struct mutex mutex;
	struct bus_type___26 *bus;
	struct device_driver___26 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___26 power;
	struct dev_pm_domain___26 *pm_domain;
	struct irq_domain___3 *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___12 *of_node;
	struct fwnode_handle___22 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___26 *class;
	const struct attribute_group___26 **groups;
	void (*release)(struct device___26 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

enum {
	IRQ_TYPE_NONE = 0,
	IRQ_TYPE_EDGE_RISING = 1,
	IRQ_TYPE_EDGE_FALLING = 2,
	IRQ_TYPE_EDGE_BOTH = 3,
	IRQ_TYPE_LEVEL_HIGH = 4,
	IRQ_TYPE_LEVEL_LOW = 8,
	IRQ_TYPE_LEVEL_MASK = 12,
	IRQ_TYPE_SENSE_MASK = 15,
	IRQ_TYPE_DEFAULT = 15,
	IRQ_TYPE_PROBE = 16,
	IRQ_LEVEL = 256,
	IRQ_PER_CPU = 512,
	IRQ_NOPROBE = 1024,
	IRQ_NOREQUEST = 2048,
	IRQ_NOAUTOEN = 4096,
	IRQ_NO_BALANCING = 8192,
	IRQ_MOVE_PCNTXT = 16384,
	IRQ_NESTED_THREAD = 32768,
	IRQ_NOTHREAD = 65536,
	IRQ_PER_CPU_DEVID = 131072,
	IRQ_IS_POLLED = 262144,
	IRQ_DISABLE_UNLAZY = 524288,
};

struct msi_desc___3 {
	struct list_head list;
	unsigned int irq;
	unsigned int nvec_used;
	struct device___26 *dev;
	struct msi_msg msg;
	struct irq_affinity_desc *affinity;
	const void *iommu_cookie;
	union {
		struct {
			u32 masked;
			struct {
				u8 is_msix: 1;
				u8 multiple: 3;
				u8 multi_cap: 3;
				u8 maskbit: 1;
				u8 is_64: 1;
				u16 entry_nr;
				unsigned int default_irq;
			} msi_attrib;
			union {
				u8 mask_pos;
				void *mask_base;
			};
		};
		struct platform_msi_desc platform;
		struct fsl_mc_msi_desc fsl_mc;
	};
};

struct irq_chip___5 {
	struct device___26 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___6 *);
	void (*irq_shutdown)(struct irq_data___6 *);
	void (*irq_enable)(struct irq_data___6 *);
	void (*irq_disable)(struct irq_data___6 *);
	void (*irq_ack)(struct irq_data___6 *);
	void (*irq_mask)(struct irq_data___6 *);
	void (*irq_mask_ack)(struct irq_data___6 *);
	void (*irq_unmask)(struct irq_data___6 *);
	void (*irq_eoi)(struct irq_data___6 *);
	int (*irq_set_affinity)(struct irq_data___6 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___6 *);
	int (*irq_set_type)(struct irq_data___6 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___6 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___6 *);
	void (*irq_bus_sync_unlock)(struct irq_data___6 *);
	void (*irq_cpu_online)(struct irq_data___6 *);
	void (*irq_cpu_offline)(struct irq_data___6 *);
	void (*irq_suspend)(struct irq_data___6 *);
	void (*irq_resume)(struct irq_data___6 *);
	void (*irq_pm_shutdown)(struct irq_data___6 *);
	void (*irq_calc_mask)(struct irq_data___6 *);
	void (*irq_print_chip)(struct irq_data___6 *, struct seq_file___28 *);
	int (*irq_request_resources)(struct irq_data___6 *);
	void (*irq_release_resources)(struct irq_data___6 *);
	void (*irq_compose_msi_msg)(struct irq_data___6 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___6 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___6 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___6 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___6 *, void *);
	void (*ipi_send_single)(struct irq_data___6 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___6 *, const struct cpumask *);
	long unsigned int flags;
};

struct irq_domain_ops___3;

struct irq_domain_chip_generic___3;

struct irq_domain___3 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___3 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___22 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___3 *gc;
	struct irq_domain___3 *parent;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_direct_max_irq;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_tree_mutex;
	unsigned int linear_revmap[0];
};

struct seq_operations___25;

struct seq_file___28 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___25 *op;
	int poll_event;
	const struct file___31 *file;
	void *private;
};

struct kernfs_root___28;

struct kernfs_elem_dir___28 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___28 *root;
};

struct kernfs_syscall_ops___28;

struct kernfs_root___28 {
	struct kernfs_node___28 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___28 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___28 {
	struct kernfs_node___28 *target_kn;
};

struct kernfs_ops___28;

struct kernfs_elem_attr___28 {
	const struct kernfs_ops___28 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___28 *notify_next;
};

struct kernfs_node___28 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___28 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___28 dir;
		struct kernfs_elem_symlink___28 symlink;
		struct kernfs_elem_attr___28 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___28;

struct kernfs_ops___28 {
	int (*open)(struct kernfs_open_file___28 *);
	void (*release)(struct kernfs_open_file___28 *);
	int (*seq_show)(struct seq_file___28 *, void *);
	void * (*seq_start)(struct seq_file___28 *, loff_t *);
	void * (*seq_next)(struct seq_file___28 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___28 *, void *);
	ssize_t (*read)(struct kernfs_open_file___28 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___28 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___28 *, struct vm_area_struct___31 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___28 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___28 {
	int (*remount_fs)(struct kernfs_root___28 *, int *, char *);
	int (*show_options)(struct seq_file___28 *, struct kernfs_root___28 *);
	int (*mkdir)(struct kernfs_node___28 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___28 *);
	int (*rename)(struct kernfs_node___28 *, struct kernfs_node___28 *, const char *);
	int (*show_path)(struct seq_file___28 *, struct kernfs_node___28 *, struct kernfs_root___28 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___28 {
	struct kernfs_node___28 *kn;
	struct file___31 *file;
	struct seq_file___28 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___30 *vm_ops;
};

struct bin_attribute___26;

struct attribute_group___26 {
	const char *name;
	umode_t (*is_visible)(struct kobject___29 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___29 *, struct bin_attribute___26 *, int);
	struct attribute **attrs;
	struct bin_attribute___26 **bin_attrs;
};

struct bin_attribute___26 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___31 *, struct kobject___29 *, struct bin_attribute___26 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___31 *, struct kobject___29 *, struct bin_attribute___26 *, char *, loff_t, size_t);
	int (*mmap)(struct file___31 *, struct kobject___29 *, struct bin_attribute___26 *, struct vm_area_struct___31 *);
};

struct sysfs_ops___28 {
	ssize_t (*show)(struct kobject___29 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___29 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___28;

struct kset___28 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___29 kobj;
	const struct kset_uevent_ops___28 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___28 {
	void (*release)(struct kobject___29 *);
	const struct sysfs_ops___28 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___29 *);
	const void * (*namespace)(struct kobject___29 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___28 {
	int (* const filter)(struct kset___28 *, struct kobject___29 *);
	const char * (* const name)(struct kset___28 *, struct kobject___29 *);
	int (* const uevent)(struct kset___28 *, struct kobject___29 *, struct kobj_uevent_env *);
};

struct kobj_attribute___29 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___29 *, struct kobj_attribute___29 *, char *);
	ssize_t (*store)(struct kobject___29 *, struct kobj_attribute___29 *, const char *, size_t);
};

struct module_kobject___25 {
	struct kobject___29 kobj;
	struct module___28 *mod;
	struct kobject___29 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___25 {
	struct module___28 *mod;
	struct latch_tree_node node;
};

struct module_layout___25 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___25 mtn;
};

struct module_attribute___25;

struct kernel_param___25;

struct module___28 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___25 mkobj;
	struct module_attribute___25 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___29 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___25 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___25 core_layout;
	struct module_layout___25 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip_type___2 {
	struct irq_chip___5 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___4 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___2 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___2 *);
	void (*resume)(struct irq_chip_generic___2 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___3 *domain;
	struct list_head list;
	struct irq_chip_type___2 chip_types[0];
};

struct irq_domain_chip_generic___3 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___2 *gc[0];
};

struct property___12 {
	char *name;
	int length;
	void *value;
	struct property___12 *next;
	long unsigned int _flags;
	struct bin_attribute___26 attr;
};

struct device_node___12 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___22 fwnode;
	struct property___12 *properties;
	struct property___12 *deadprops;
	struct device_node___12 *parent;
	struct device_node___12 *child;
	struct device_node___12 *sibling;
	struct kobject___29 kobj;
	long unsigned int _flags;
	void *data;
};

struct irq_fwspec___3 {
	struct fwnode_handle___22 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___3 {
	int (*match)(struct irq_domain___3 *, struct device_node___12 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___3 *, struct irq_fwspec___3 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___3 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___3 *, unsigned int);
	int (*xlate)(struct irq_domain___3 *, struct device_node___12 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___3 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___3 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___3 *, struct irq_data___6 *, bool);
	void (*deactivate)(struct irq_domain___3 *, struct irq_data___6 *);
	int (*translate)(struct irq_domain___3 *, struct irq_fwspec___3 *, long unsigned int *, unsigned int *);
};

struct dentry_operations___30;

struct super_block___31;

struct dentry___32 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___32 *d_parent;
	struct qstr d_name;
	struct inode___33 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___30 *d_op;
	struct super_block___31 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___30;

struct block_device___31;

struct inode___33 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___30 *i_op;
	struct super_block___31 *i_sb;
	struct address_space___30 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___31 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___31 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___30 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___31 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___30 {
	int (*d_revalidate)(struct dentry___32 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___32 *, unsigned int);
	int (*d_hash)(const struct dentry___32 *, struct qstr *);
	int (*d_compare)(const struct dentry___32 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___32 *);
	int (*d_init)(struct dentry___32 *);
	void (*d_release)(struct dentry___32 *);
	void (*d_prune)(struct dentry___32 *);
	void (*d_iput)(struct dentry___32 *, struct inode___33 *);
	char * (*d_dname)(struct dentry___32 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___30 *);
	int (*d_manage)(const struct path___30 *, bool);
	struct dentry___32 * (*d_real)(struct dentry___32 *, const struct inode___33 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___30;

struct mem_dqinfo___30 {
	struct quota_format_type___30 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___30;

struct quota_info___30 {
	unsigned int flags;
	struct rw_semaphore___31 dqio_sem;
	struct inode___33 *files[3];
	struct mem_dqinfo___30 info[3];
	const struct quota_format_ops___30 *ops[3];
};

struct rcuwait___30 {
	struct task_struct___32 *task;
};

struct percpu_rw_semaphore___30 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___31 rw_sem;
	struct rcuwait___30 writer;
	int readers_block;
};

struct sb_writers___30 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___30 rw_sem[3];
};

struct file_system_type___30;

struct super_operations___30;

struct dquot_operations___30;

struct quotactl_ops___30;

struct super_block___31 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___30 *s_type;
	const struct super_operations___30 *s_op;
	const struct dquot_operations___30 *dq_op;
	const struct quotactl_ops___30 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___32 *s_root;
	struct rw_semaphore___31 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___31 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___30 s_dquot;
	struct sb_writers___30 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___30 *s_d_op;
	int cleancache_poolid;
	struct shrinker___9 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___21 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___31 {
	struct file___31 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___31 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___31 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___31 *ia_file;
};

struct dquot___30 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___31 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___30 {
	int qf_fmt_id;
	const struct quota_format_ops___30 *qf_ops;
	struct module___28 *qf_owner;
	struct quota_format_type___30 *qf_next;
};

struct quota_format_ops___30 {
	int (*check_quota_file)(struct super_block___31 *, int);
	int (*read_file_info)(struct super_block___31 *, int);
	int (*write_file_info)(struct super_block___31 *, int);
	int (*free_file_info)(struct super_block___31 *, int);
	int (*read_dqblk)(struct dquot___30 *);
	int (*commit_dqblk)(struct dquot___30 *);
	int (*release_dqblk)(struct dquot___30 *);
	int (*get_next_id)(struct super_block___31 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___30 {
	int (*write_dquot)(struct dquot___30 *);
	struct dquot___30 * (*alloc_dquot)(struct super_block___31 *, int);
	void (*destroy_dquot)(struct dquot___30 *);
	int (*acquire_dquot)(struct dquot___30 *);
	int (*release_dquot)(struct dquot___30 *);
	int (*mark_dirty)(struct dquot___30 *);
	int (*write_info)(struct super_block___31 *, int);
	qsize_t * (*get_reserved_space)(struct inode___33 *);
	int (*get_projid)(struct inode___33 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___33 *, qsize_t *);
	int (*get_next_id)(struct super_block___31 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___30 {
	int (*quota_on)(struct super_block___31 *, int, int, const struct path___30 *);
	int (*quota_off)(struct super_block___31 *, int);
	int (*quota_enable)(struct super_block___31 *, unsigned int);
	int (*quota_disable)(struct super_block___31 *, unsigned int);
	int (*quota_sync)(struct super_block___31 *, int);
	int (*set_info)(struct super_block___31 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___31 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___31 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___31 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___31 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___31 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___30 {
	int (*writepage)(struct page___31 *, struct writeback_control___3 *);
	int (*readpage)(struct file___31 *, struct page___31 *);
	int (*writepages)(struct address_space___30 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___31 *);
	int (*readpages)(struct file___31 *, struct address_space___30 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___31 *, struct address_space___30 *, loff_t, unsigned int, unsigned int, struct page___31 **, void **);
	int (*write_end)(struct file___31 *, struct address_space___30 *, loff_t, unsigned int, unsigned int, struct page___31 *, void *);
	sector_t (*bmap)(struct address_space___30 *, sector_t);
	void (*invalidatepage)(struct page___31 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___31 *, gfp_t);
	void (*freepage)(struct page___31 *);
	ssize_t (*direct_IO)(struct kiocb___31 *, struct iov_iter___11 *);
	int (*migratepage)(struct address_space___30 *, struct page___31 *, struct page___31 *, enum migrate_mode);
	bool (*isolate_page)(struct page___31 *, isolate_mode_t);
	void (*putback_page)(struct page___31 *);
	int (*launder_page)(struct page___31 *);
	int (*is_partially_uptodate)(struct page___31 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___31 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___30 *, struct page___31 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___31 *, sector_t *);
	void (*swap_deactivate)(struct file___31 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___31 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___33 *bd_inode;
	struct super_block___31 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___31 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___30 {
	struct dentry___32 * (*lookup)(struct inode___33 *, struct dentry___32 *, unsigned int);
	const char * (*get_link)(struct dentry___32 *, struct inode___33 *, struct delayed_call *);
	int (*permission)(struct inode___33 *, int);
	struct posix_acl * (*get_acl)(struct inode___33 *, int);
	int (*readlink)(struct dentry___32 *, char *, int);
	int (*create)(struct inode___33 *, struct dentry___32 *, umode_t, bool);
	int (*link)(struct dentry___32 *, struct inode___33 *, struct dentry___32 *);
	int (*unlink)(struct inode___33 *, struct dentry___32 *);
	int (*symlink)(struct inode___33 *, struct dentry___32 *, const char *);
	int (*mkdir)(struct inode___33 *, struct dentry___32 *, umode_t);
	int (*rmdir)(struct inode___33 *, struct dentry___32 *);
	int (*mknod)(struct inode___33 *, struct dentry___32 *, umode_t, dev_t);
	int (*rename)(struct inode___33 *, struct dentry___32 *, struct inode___33 *, struct dentry___32 *, unsigned int);
	int (*setattr)(struct dentry___32 *, struct iattr___31 *);
	int (*getattr)(const struct path___30 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___32 *, char *, size_t);
	int (*fiemap)(struct inode___33 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___33 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___33 *, struct dentry___32 *, struct file___31 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___33 *, struct dentry___32 *, umode_t);
	int (*set_acl)(struct inode___33 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___30 {
	void (*fl_copy_lock)(struct file_lock___31 *, struct file_lock___31 *);
	void (*fl_release_private)(struct file_lock___31 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___30;

struct file_lock___31 {
	struct file_lock___31 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___31 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___30 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___30 *fl_ops;
	const struct lock_manager_operations___30 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___30 {
	int (*lm_compare_owner)(struct file_lock___31 *, struct file_lock___31 *);
	long unsigned int (*lm_owner_key)(struct file_lock___31 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___31 *);
	int (*lm_grant)(struct file_lock___31 *, int);
	bool (*lm_break)(struct file_lock___31 *);
	int (*lm_change)(struct file_lock___31 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___31 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___30 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___30 *fa_next;
	struct file___31 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___30 {
	const char *name;
	int fs_flags;
	struct dentry___32 * (*mount)(struct file_system_type___30 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___31 *);
	struct module___28 *owner;
	struct file_system_type___30 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___30 {
	struct inode___33 * (*alloc_inode)(struct super_block___31 *);
	void (*destroy_inode)(struct inode___33 *);
	void (*dirty_inode)(struct inode___33 *, int);
	int (*write_inode)(struct inode___33 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___33 *);
	void (*evict_inode)(struct inode___33 *);
	void (*put_super)(struct super_block___31 *);
	int (*sync_fs)(struct super_block___31 *, int);
	int (*freeze_super)(struct super_block___31 *);
	int (*freeze_fs)(struct super_block___31 *);
	int (*thaw_super)(struct super_block___31 *);
	int (*unfreeze_fs)(struct super_block___31 *);
	int (*statfs)(struct dentry___32 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___31 *, int *, char *);
	void (*umount_begin)(struct super_block___31 *);
	int (*show_options)(struct seq_file___28 *, struct dentry___32 *);
	int (*show_devname)(struct seq_file___28 *, struct dentry___32 *);
	int (*show_path)(struct seq_file___28 *, struct dentry___32 *);
	int (*show_stats)(struct seq_file___28 *, struct dentry___32 *);
	ssize_t (*quota_read)(struct super_block___31 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___31 *, int, const char *, size_t, loff_t);
	struct dquot___30 ** (*get_dquots)(struct inode___33 *);
	int (*bdev_try_to_free_page)(struct super_block___31 *, struct page___31 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___31 *, struct shrink_control___9 *);
	long int (*free_cached_objects)(struct super_block___31 *, struct shrink_control___9 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___30(struct page___31 *);

struct mmu_notifier___6;

struct mmu_notifier_ops___6 {
	int flags;
	void (*release)(struct mmu_notifier___6 *, struct mm_struct___31 *);
	int (*clear_flush_young)(struct mmu_notifier___6 *, struct mm_struct___31 *, long unsigned int, long unsigned int);
	int (*clear_young)(struct mmu_notifier___6 *, struct mm_struct___31 *, long unsigned int, long unsigned int);
	int (*test_young)(struct mmu_notifier___6 *, struct mm_struct___31 *, long unsigned int);
	void (*change_pte)(struct mmu_notifier___6 *, struct mm_struct___31 *, long unsigned int, pte_t);
	void (*invalidate_range_start)(struct mmu_notifier___6 *, struct mm_struct___31 *, long unsigned int, long unsigned int);
	void (*invalidate_range_end)(struct mmu_notifier___6 *, struct mm_struct___31 *, long unsigned int, long unsigned int);
	void (*invalidate_range)(struct mmu_notifier___6 *, struct mm_struct___31 *, long unsigned int, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mmu_notifier___6 {
	struct hlist_node hlist;
	const struct mmu_notifier_ops___6 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct kvm_vcpu___6;

struct kvm_io_device___6;

struct kvm_io_device_ops___6 {
	int (*read)(struct kvm_vcpu___6 *, struct kvm_io_device___6 *, gpa_t, int, void *);
	int (*write)(struct kvm_vcpu___6 *, struct kvm_io_device___6 *, gpa_t, int, const void *);
	void (*destructor)(struct kvm_io_device___6 *);
};

struct kvm_cpu_context___6 {
	struct kvm_regs gp_regs;
	union {
		u64 sys_regs[101];
		u32 copro[202];
	};
	struct kvm_vcpu___6 *__hyp_running_vcpu;
};

typedef struct kvm_cpu_context___6 kvm_cpu_context_t___6;

struct its_vm___6;

struct its_vpe___6 {
	struct page___31 *vpt_page;
	struct its_vm___6 *its_vm;
	int irq;
	irq_hw_number_t vpe_db_lpi;
	int vpe_proxy_event;
	u16 col_idx;
	u16 vpe_id;
	bool idai;
	bool pending_last;
};

struct vgic_v3_cpu_if___6 {
	u32 vgic_hcr;
	u32 vgic_vmcr;
	u32 vgic_sre;
	u32 vgic_ap0r[4];
	u32 vgic_ap1r[4];
	u64 vgic_lr[16];
	struct its_vpe___6 its_vpe;
};

struct vgic_irq___6 {
	raw_spinlock_t irq_lock;
	struct list_head lpi_list;
	struct list_head ap_list;
	struct kvm_vcpu___6 *vcpu;
	struct kvm_vcpu___6 *target_vcpu;
	u32 intid;
	bool line_level;
	bool pending_latch;
	bool active;
	bool enabled;
	bool hw;
	struct kref refcount;
	u32 hwintid;
	unsigned int host_irq;
	union {
		u8 targets;
		u32 mpidr;
	};
	u8 source;
	u8 active_source;
	u8 priority;
	u8 group;
	enum vgic_irq_config config;
	bool (*get_input_level)(int);
	void *owner;
};

struct kvm_io_device___6 {
	const struct kvm_io_device_ops___6 *ops;
};

struct vgic_its___6;

struct vgic_io_device___6 {
	gpa_t base_addr;
	union {
		struct kvm_vcpu___6 *redist_vcpu;
		struct vgic_its___6 *its;
	};
	const struct vgic_register_region *regions;
	enum iodev_type iodev_type;
	int nr_regions;
	struct kvm_io_device___6 dev;
};

struct vgic_cpu___6 {
	union {
		struct vgic_v2_cpu_if vgic_v2;
		struct vgic_v3_cpu_if___6 vgic_v3;
	};
	unsigned int used_lrs;
	struct vgic_irq___6 private_irqs[32];
	raw_spinlock_t ap_list_lock;
	struct list_head ap_list_head;
	struct vgic_io_device___6 rd_iodev;
	struct vgic_io_device___6 sgi_iodev;
	struct vgic_redist_region *rdreg;
	u64 pendbaser;
	bool lpis_enabled;
	u32 num_pri_bits;
	u32 num_id_bits;
};

struct arch_timer_context___6 {
	struct kvm_vcpu___6 *vcpu;
	u32 cnt_ctl;
	u64 cnt_cval;
	struct kvm_irq_level irq;
	u64 cntvoff;
	struct hrtimer hrtimer;
	bool loaded;
	u32 host_timer_irq;
	u32 host_timer_irq_flags;
};

struct arch_timer_cpu___6 {
	struct arch_timer_context___6 timers[2];
	struct hrtimer bg_timer;
	bool enabled;
};

struct kvm_pmc___6 {
	u8 idx;
	struct perf_event___16 *perf_event;
	u64 bitmask;
};

struct kvm_pmu___6 {
	int irq_num;
	struct kvm_pmc___6 pmc[32];
	bool ready;
	bool created;
	bool irq_level;
};

struct kvm_vcpu_arch___6 {
	struct kvm_cpu_context___6 ctxt;
	void *sve_state;
	unsigned int sve_max_vl;
	u64 hcr_el2;
	u32 mdcr_el2;
	struct kvm_vcpu_fault_info fault;
	u64 workaround_flags;
	u64 flags;
	struct kvm_guest_debug_arch *debug_ptr;
	struct kvm_guest_debug_arch vcpu_debug_state;
	struct kvm_guest_debug_arch external_debug_state;
	kvm_cpu_context_t___6 *host_cpu_context;
	struct thread_info *host_thread_info;
	struct user_fpsimd_state *host_fpsimd_state;
	struct {
		struct kvm_guest_debug_arch regs;
		u64 pmscr_el1;
	} host_debug_state;
	struct vgic_cpu___6 vgic_cpu;
	struct arch_timer_cpu___6 timer_cpu;
	struct kvm_pmu___6 pmu;
	struct {
		u32 mdscr_el1;
	} guest_debug_preserved;
	bool power_off;
	bool pause;
	struct kvm_decode mmio_decode;
	struct kvm_mmu_memory_cache mmu_page_cache;
	int target;
	long unsigned int features[1];
	bool has_run_once;
	u64 vsesr_el2;
	struct vcpu_reset_state reset_state;
	bool sysregs_loaded_on_cpu;
};

struct kvm___6;

struct kvm_vcpu___6 {
	struct kvm___6 *kvm;
	struct preempt_notifier___6 preempt_notifier;
	int cpu;
	int vcpu_id;
	int srcu_idx;
	int mode;
	u64 requests;
	long unsigned int guest_debug;
	int pre_pcpu;
	struct list_head blocked_vcpu_list;
	struct mutex mutex;
	struct kvm_run *run;
	int guest_xcr0_loaded;
	struct swait_queue_head wq;
	struct pid___26 *pid;
	int sigset_active;
	sigset_t sigset;
	struct kvm_vcpu_stat stat;
	unsigned int halt_poll_ns;
	bool valid_wakeup;
	int mmio_needed;
	int mmio_read_completed;
	int mmio_is_write;
	int mmio_cur_fragment;
	int mmio_nr_fragments;
	struct kvm_mmio_fragment mmio_fragments[2];
	struct {
		bool in_spin_loop;
		bool dy_eligible;
	} spin_loop;
	bool preempted;
	struct kvm_vcpu_arch___6 arch;
	struct dentry___32 *debugfs_dentry;
	long: 64;
};

struct its_vm___6 {
	struct fwnode_handle___22 *fwnode;
	struct irq_domain___3 *domain;
	struct page___31 *vprop_page;
	struct its_vpe___6 **vpes;
	int nr_vpes;
	irq_hw_number_t db_lpi_base;
	long unsigned int *db_bitmap;
	int nr_db_lpis;
	u32 vlpi_count[16];
};

struct its_vlpi_map {
	struct its_vm___6 *vm;
	struct its_vpe___6 *vpe;
	u32 vintid;
	u8 properties;
	bool db_enabled;
};

struct kvm_device___6;

struct vgic_its___6 {
	gpa_t vgic_its_base;
	bool enabled;
	struct vgic_io_device___6 iodev;
	struct kvm_device___6 *dev;
	u64 baser_device_table;
	u64 baser_coll_table;
	struct mutex cmd_lock;
	u64 cbaser;
	u32 creadr;
	u32 cwriter;
	u32 abi_rev;
	struct mutex its_lock;
	struct list_head device_list;
	struct list_head collection_list;
};

struct kvm_device_ops___6;

struct kvm_device___6 {
	struct kvm_device_ops___6 *ops;
	struct kvm___6 *kvm;
	void *private;
	struct list_head vm_node;
};

struct vgic_dist___6 {
	bool in_kernel;
	bool ready;
	bool initialized;
	u32 vgic_model;
	u32 implementation_rev;
	bool v2_groups_user_writable;
	bool msis_require_devid;
	int nr_spis;
	gpa_t vgic_dist_base;
	union {
		gpa_t vgic_cpu_base;
		struct list_head rd_regions;
	};
	bool enabled;
	struct vgic_irq___6 *spis;
	struct vgic_io_device___6 dist_iodev;
	bool has_its;
	u64 propbaser;
	raw_spinlock_t lpi_list_lock;
	struct list_head lpi_list_head;
	int lpi_list_count;
	struct vgic_state_iter *iter;
	struct its_vm___6 its_vm;
};

struct cgroup_namespace___20 {
	refcount_t count;
	struct ns_common___2 ns;
	struct user_namespace___21 *user_ns;
	struct ucounts___21 *ucounts;
	struct css_set___20 *root_cset;
};

struct ucounts___21 {
	struct hlist_node node;
	struct user_namespace___21 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct kernel_param_ops___25 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___25 *);
	int (*get)(char *, const struct kernel_param___25 *);
	void (*free)(void *);
};

struct kparam_array___25;

struct kernel_param___25 {
	const char *name;
	struct module___28 *mod;
	const struct kernel_param_ops___25 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___25 *arr;
	};
};

struct kparam_array___25 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___25 *ops;
	void *elem;
};

struct module_attribute___25 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___25 *, struct module_kobject___25 *, char *);
	ssize_t (*store)(struct module_attribute___25 *, struct module_kobject___25 *, const char *, size_t);
	void (*setup)(struct module___28 *, const char *);
	int (*test)(struct module___28 *);
	void (*free)(struct module___28 *);
};

typedef int (*key_restrict_link_func_t___30)(struct key___31 *, const struct key_type *, const union key_payload *, struct key___31 *);

struct key_restriction___31;

struct key___31 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___31 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___31 *restrict_link;
};

struct key_restriction___31 {
	key_restrict_link_func_t___30 check;
	struct key___31 *key;
	struct key_type *keytype;
};

struct dev_pm_ops___26 {
	int (*prepare)(struct device___26 *);
	void (*complete)(struct device___26 *);
	int (*suspend)(struct device___26 *);
	int (*resume)(struct device___26 *);
	int (*freeze)(struct device___26 *);
	int (*thaw)(struct device___26 *);
	int (*poweroff)(struct device___26 *);
	int (*restore)(struct device___26 *);
	int (*suspend_late)(struct device___26 *);
	int (*resume_early)(struct device___26 *);
	int (*freeze_late)(struct device___26 *);
	int (*thaw_early)(struct device___26 *);
	int (*poweroff_late)(struct device___26 *);
	int (*restore_early)(struct device___26 *);
	int (*suspend_noirq)(struct device___26 *);
	int (*resume_noirq)(struct device___26 *);
	int (*freeze_noirq)(struct device___26 *);
	int (*thaw_noirq)(struct device___26 *);
	int (*poweroff_noirq)(struct device___26 *);
	int (*restore_noirq)(struct device___26 *);
	int (*runtime_suspend)(struct device___26 *);
	int (*runtime_resume)(struct device___26 *);
	int (*runtime_idle)(struct device___26 *);
};

struct dev_pm_domain___26 {
	struct dev_pm_ops___26 ops;
	void (*detach)(struct device___26 *, bool);
	int (*activate)(struct device___26 *);
	void (*sync)(struct device___26 *);
	void (*dismiss)(struct device___26 *);
};

struct bus_type___26 {
	const char *name;
	const char *dev_name;
	struct device___26 *dev_root;
	const struct attribute_group___26 **bus_groups;
	const struct attribute_group___26 **dev_groups;
	const struct attribute_group___26 **drv_groups;
	int (*match)(struct device___26 *, struct device_driver___26 *);
	int (*uevent)(struct device___26 *, struct kobj_uevent_env *);
	int (*probe)(struct device___26 *);
	int (*remove)(struct device___26 *);
	void (*shutdown)(struct device___26 *);
	int (*online)(struct device___26 *);
	int (*offline)(struct device___26 *);
	int (*suspend)(struct device___26 *, pm_message_t);
	int (*resume)(struct device___26 *);
	int (*num_vf)(struct device___26 *);
	int (*dma_configure)(struct device___26 *);
	const struct dev_pm_ops___26 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___26 {
	const char *name;
	struct bus_type___26 *bus;
	struct module___28 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___26 *);
	int (*remove)(struct device___26 *);
	void (*shutdown)(struct device___26 *);
	int (*suspend)(struct device___26 *, pm_message_t);
	int (*resume)(struct device___26 *);
	const struct attribute_group___26 **groups;
	const struct dev_pm_ops___26 *pm;
	void (*coredump)(struct device___26 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___26 {
	const char *name;
	const struct attribute_group___26 **groups;
	int (*uevent)(struct device___26 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___26 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___26 *);
	const struct dev_pm_ops___26 *pm;
};

struct class___26 {
	const char *name;
	struct module___28 *owner;
	const struct attribute_group___26 **class_groups;
	const struct attribute_group___26 **dev_groups;
	struct kobject___29 *dev_kobj;
	int (*dev_uevent)(struct device___26 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___26 *, umode_t *);
	void (*class_release)(struct class___26 *);
	void (*dev_release)(struct device___26 *);
	int (*shutdown_pre)(struct device___26 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___26 *);
	const struct dev_pm_ops___26 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___24 {
	struct device___26 dev;
};

struct seq_operations___25 {
	void * (*start)(struct seq_file___28 *, loff_t *);
	void (*stop)(struct seq_file___28 *, void *);
	void * (*next)(struct seq_file___28 *, void *, loff_t *);
	int (*show)(struct seq_file___28 *, void *);
};

struct bpf_map___20;

struct bpf_map_ops___20 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___20 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___20 *, struct file___31 *);
	void (*map_free)(struct bpf_map___20 *);
	int (*map_get_next_key)(struct bpf_map___20 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___20 *);
	void * (*map_lookup_elem)(struct bpf_map___20 *, void *);
	int (*map_update_elem)(struct bpf_map___20 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___20 *, void *);
	int (*map_push_elem)(struct bpf_map___20 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___20 *, void *);
	int (*map_peek_elem)(struct bpf_map___20 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___20 *, struct file___31 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___20 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___20 *, void *, struct seq_file___28 *);
	int (*map_check_btf)(const struct bpf_map___20 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___20 {
	const struct bpf_map_ops___20 *ops;
	struct bpf_map___20 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___30 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___20;

typedef void (*kthread_work_func_t___20)(struct kthread_work___20 *);

struct kthread_worker___20;

struct kthread_work___20 {
	struct list_head node;
	kthread_work_func_t___20 func;
	struct kthread_worker___20 *worker;
	int canceling;
};

struct kthread_worker___20 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___32 *task;
	struct kthread_work___20 *current_work;
};

struct kthread_delayed_work___20 {
	struct kthread_work___20 work;
	struct timer_list timer;
};

struct psi_group___20 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___20 *poll_kworker;
	struct kthread_delayed_work___20 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___20 {
	struct kernfs_node___28 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___20;

struct cgroup_subsys_state___20 {
	struct cgroup___20 *cgroup;
	struct cgroup_subsys___20 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___20 *parent;
};

struct cgroup_root___20;

struct cgroup_rstat_cpu___20;

struct cgroup___20 {
	struct cgroup_subsys_state___20 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___28 *kn;
	struct cgroup_file___20 procs_file;
	struct cgroup_file___20 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___20 *subsys[13];
	struct cgroup_root___20 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___20 *dom_cgrp;
	struct cgroup_rstat_cpu___20 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___2 bpf;
	atomic_t congestion_count;
	struct cgroup___20 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___20 psi;
	int ancestor_ids[0];
};

struct cftype___20;

struct cgroup_subsys___20 {
	struct cgroup_subsys_state___20 * (*css_alloc)(struct cgroup_subsys_state___20 *);
	int (*css_online)(struct cgroup_subsys_state___20 *);
	void (*css_offline)(struct cgroup_subsys_state___20 *);
	void (*css_released)(struct cgroup_subsys_state___20 *);
	void (*css_free)(struct cgroup_subsys_state___20 *);
	void (*css_reset)(struct cgroup_subsys_state___20 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___20 *, int);
	int (*css_extra_stat_show)(struct seq_file___28 *, struct cgroup_subsys_state___20 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___32 *);
	void (*cancel_fork)(struct task_struct___32 *);
	void (*fork)(struct task_struct___32 *);
	void (*exit)(struct task_struct___32 *);
	void (*free)(struct task_struct___32 *);
	void (*bind)(struct cgroup_subsys_state___20 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___20 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___20 *dfl_cftypes;
	struct cftype___20 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___20 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___20 *updated_children;
	struct cgroup___20 *updated_next;
};

struct cgroup_root___20 {
	struct kernfs_root___28 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___20 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___20 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___20 *ss;
	struct list_head node;
	struct kernfs_ops___28 *kf_ops;
	int (*open)(struct kernfs_open_file___28 *);
	void (*release)(struct kernfs_open_file___28 *);
	u64 (*read_u64)(struct cgroup_subsys_state___20 *, struct cftype___20 *);
	s64 (*read_s64)(struct cgroup_subsys_state___20 *, struct cftype___20 *);
	int (*seq_show)(struct seq_file___28 *, void *);
	void * (*seq_start)(struct seq_file___28 *, loff_t *);
	void * (*seq_next)(struct seq_file___28 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___28 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___20 *, struct cftype___20 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___20 *, struct cftype___20 *, s64);
	ssize_t (*write)(struct kernfs_open_file___28 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___28 *, struct poll_table_struct___6 *);
};

struct perf_cpu_context___16;

struct pmu___16 {
	struct list_head entry;
	struct module___28 *module;
	struct device___26 *dev;
	const struct attribute_group___26 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___16 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___16 *);
	void (*pmu_disable)(struct pmu___16 *);
	int (*event_init)(struct perf_event___16 *);
	void (*event_mapped)(struct perf_event___16 *, struct mm_struct___31 *);
	void (*event_unmapped)(struct perf_event___16 *, struct mm_struct___31 *);
	int (*add)(struct perf_event___16 *, int);
	void (*del)(struct perf_event___16 *, int);
	void (*start)(struct perf_event___16 *, int);
	void (*stop)(struct perf_event___16 *, int);
	void (*read)(struct perf_event___16 *);
	void (*start_txn)(struct pmu___16 *, unsigned int);
	int (*commit_txn)(struct pmu___16 *);
	void (*cancel_txn)(struct pmu___16 *);
	int (*event_idx)(struct perf_event___16 *);
	void (*sched_task)(struct perf_event_context___16 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___16 *);
	int (*filter_match)(struct perf_event___16 *);
	int (*check_period)(struct perf_event___16 *, u64);
};

struct perf_cpu_context___16 {
	struct perf_event_context___16 ctx;
	struct perf_event_context___16 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___16 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___16 {
	struct cgroup_subsys_state___20 css;
	struct perf_cgroup_info *info;
};

struct kvm_arch___6 {
	struct kvm_vmid vmid;
	pgd_t *pgd;
	phys_addr_t pgd_phys;
	u64 vtcr;
	int *last_vcpu_ran;
	int max_vcpus;
	struct vgic_dist___6 vgic;
	u32 psci_version;
};

struct kvm_io_range___6 {
	gpa_t addr;
	int len;
	struct kvm_io_device___6 *dev;
};

struct kvm_io_bus___6 {
	int dev_count;
	int ioeventfd_count;
	struct kvm_io_range___6 range[0];
};

struct kvm_stat_data___6;

struct kvm___6 {
	spinlock_t mmu_lock;
	struct mutex slots_lock;
	struct mm_struct___31 *mm;
	struct kvm_memslots *memslots[1];
	struct kvm_vcpu___6 *vcpus[512];
	atomic_t online_vcpus;
	int created_vcpus;
	int last_boosted_vcpu;
	struct list_head vm_list;
	struct mutex lock;
	struct kvm_io_bus___6 *buses[4];
	struct {
		spinlock_t lock;
		struct list_head items;
		struct list_head resampler_list;
		struct mutex resampler_lock;
	} irqfds;
	struct list_head ioeventfds;
	struct kvm_vm_stat stat;
	struct kvm_arch___6 arch;
	refcount_t users_count;
	struct kvm_coalesced_mmio_ring *coalesced_mmio_ring;
	spinlock_t ring_lock;
	struct list_head coalesced_zones;
	struct mutex irq_lock;
	struct kvm_irq_routing_table *irq_routing;
	struct hlist_head irq_ack_notifier_list;
	struct mmu_notifier___6 mmu_notifier;
	long unsigned int mmu_notifier_seq;
	long int mmu_notifier_count;
	long int tlbs_dirty;
	struct list_head devices;
	bool manual_dirty_log_protect;
	struct dentry___32 *debugfs_dentry;
	struct kvm_stat_data___6 **debugfs_stat_data;
	struct srcu_struct srcu;
	struct srcu_struct irq_srcu;
	pid_t userspace_pid;
};

struct kvm_kernel_irq_routing_entry___2 {
	u32 gsi;
	u32 type;
	int (*set)(struct kvm_kernel_irq_routing_entry___2 *, struct kvm___6 *, int, int, bool);
	union {
		struct {
			unsigned int irqchip;
			unsigned int pin;
		} irqchip;
		struct {
			u32 address_lo;
			u32 address_hi;
			u32 data;
			u32 flags;
			u32 devid;
		} msi;
		struct kvm_s390_adapter_int adapter;
		struct kvm_hv_sint hv_sint;
	};
	struct hlist_node link;
};

struct kvm_stat_data___6 {
	int offset;
	int mode;
	struct kvm___6 *kvm;
};

struct kvm_device_ops___6 {
	const char *name;
	int (*create)(struct kvm_device___6 *, u32);
	void (*init)(struct kvm_device___6 *);
	void (*destroy)(struct kvm_device___6 *);
	void (*release)(struct kvm_device___6 *);
	int (*set_attr)(struct kvm_device___6 *, struct kvm_device_attr *);
	int (*get_attr)(struct kvm_device___6 *, struct kvm_device_attr *);
	int (*has_attr)(struct kvm_device___6 *, struct kvm_device_attr *);
	long int (*ioctl)(struct kvm_device___6 *, unsigned int, long unsigned int);
	int (*mmap)(struct kvm_device___6 *, struct vm_area_struct___31 *);
};

struct kvm_vcpu___7;

struct kvm_io_device___7;

struct kvm_io_device_ops___7 {
	int (*read)(struct kvm_vcpu___7 *, struct kvm_io_device___7 *, gpa_t, int, void *);
	int (*write)(struct kvm_vcpu___7 *, struct kvm_io_device___7 *, gpa_t, int, const void *);
	void (*destructor)(struct kvm_io_device___7 *);
};

struct kvm_cpu_context___7 {
	struct kvm_regs gp_regs;
	union {
		u64 sys_regs[101];
		u32 copro[202];
	};
	struct kvm_vcpu___7 *__hyp_running_vcpu;
};

typedef struct kvm_cpu_context___7 kvm_cpu_context_t___7;

struct vgic_irq___7 {
	raw_spinlock_t irq_lock;
	struct list_head lpi_list;
	struct list_head ap_list;
	struct kvm_vcpu___7 *vcpu;
	struct kvm_vcpu___7 *target_vcpu;
	u32 intid;
	bool line_level;
	bool pending_latch;
	bool active;
	bool enabled;
	bool hw;
	struct kref refcount;
	u32 hwintid;
	unsigned int host_irq;
	union {
		u8 targets;
		u32 mpidr;
	};
	u8 source;
	u8 active_source;
	u8 priority;
	u8 group;
	enum vgic_irq_config config;
	bool (*get_input_level)(int);
	void *owner;
};

struct kvm_io_device___7 {
	const struct kvm_io_device_ops___7 *ops;
};

struct vgic_its___7;

struct vgic_register_region___2;

struct vgic_io_device___7 {
	gpa_t base_addr;
	union {
		struct kvm_vcpu___7 *redist_vcpu;
		struct vgic_its___7 *its;
	};
	const struct vgic_register_region___2 *regions;
	enum iodev_type iodev_type;
	int nr_regions;
	struct kvm_io_device___7 dev;
};

struct vgic_cpu___7 {
	union {
		struct vgic_v2_cpu_if vgic_v2;
		struct vgic_v3_cpu_if___5 vgic_v3;
	};
	unsigned int used_lrs;
	struct vgic_irq___7 private_irqs[32];
	raw_spinlock_t ap_list_lock;
	struct list_head ap_list_head;
	struct vgic_io_device___7 rd_iodev;
	struct vgic_io_device___7 sgi_iodev;
	struct vgic_redist_region *rdreg;
	u64 pendbaser;
	bool lpis_enabled;
	u32 num_pri_bits;
	u32 num_id_bits;
};

struct arch_timer_context___7 {
	struct kvm_vcpu___7 *vcpu;
	u32 cnt_ctl;
	u64 cnt_cval;
	struct kvm_irq_level irq;
	u64 cntvoff;
	struct hrtimer hrtimer;
	bool loaded;
	u32 host_timer_irq;
	u32 host_timer_irq_flags;
};

struct arch_timer_cpu___7 {
	struct arch_timer_context___7 timers[2];
	struct hrtimer bg_timer;
	bool enabled;
};

struct kvm_vcpu_arch___7 {
	struct kvm_cpu_context___7 ctxt;
	void *sve_state;
	unsigned int sve_max_vl;
	u64 hcr_el2;
	u32 mdcr_el2;
	struct kvm_vcpu_fault_info fault;
	u64 workaround_flags;
	u64 flags;
	struct kvm_guest_debug_arch *debug_ptr;
	struct kvm_guest_debug_arch vcpu_debug_state;
	struct kvm_guest_debug_arch external_debug_state;
	kvm_cpu_context_t___7 *host_cpu_context;
	struct thread_info *host_thread_info;
	struct user_fpsimd_state *host_fpsimd_state;
	struct {
		struct kvm_guest_debug_arch regs;
		u64 pmscr_el1;
	} host_debug_state;
	struct vgic_cpu___7 vgic_cpu;
	struct arch_timer_cpu___7 timer_cpu;
	struct kvm_pmu___5 pmu;
	struct {
		u32 mdscr_el1;
	} guest_debug_preserved;
	bool power_off;
	bool pause;
	struct kvm_decode mmio_decode;
	struct kvm_mmu_memory_cache mmu_page_cache;
	int target;
	long unsigned int features[1];
	bool has_run_once;
	u64 vsesr_el2;
	struct vcpu_reset_state reset_state;
	bool sysregs_loaded_on_cpu;
};

struct kvm___7;

struct kvm_vcpu___7 {
	struct kvm___7 *kvm;
	struct preempt_notifier___5 preempt_notifier;
	int cpu;
	int vcpu_id;
	int srcu_idx;
	int mode;
	u64 requests;
	long unsigned int guest_debug;
	int pre_pcpu;
	struct list_head blocked_vcpu_list;
	struct mutex mutex;
	struct kvm_run *run;
	int guest_xcr0_loaded;
	struct swait_queue_head wq;
	struct pid___25 *pid;
	int sigset_active;
	sigset_t sigset;
	struct kvm_vcpu_stat stat;
	unsigned int halt_poll_ns;
	bool valid_wakeup;
	int mmio_needed;
	int mmio_read_completed;
	int mmio_is_write;
	int mmio_cur_fragment;
	int mmio_nr_fragments;
	struct kvm_mmio_fragment mmio_fragments[2];
	struct {
		bool in_spin_loop;
		bool dy_eligible;
	} spin_loop;
	bool preempted;
	struct kvm_vcpu_arch___7 arch;
	struct dentry___31 *debugfs_dentry;
	long: 64;
};

struct kvm_device___7;

struct vgic_its___7 {
	gpa_t vgic_its_base;
	bool enabled;
	struct vgic_io_device___7 iodev;
	struct kvm_device___7 *dev;
	u64 baser_device_table;
	u64 baser_coll_table;
	struct mutex cmd_lock;
	u64 cbaser;
	u32 creadr;
	u32 cwriter;
	u32 abi_rev;
	struct mutex its_lock;
	struct list_head device_list;
	struct list_head collection_list;
};

struct vgic_register_region___2 {
	unsigned int reg_offset;
	unsigned int len;
	unsigned int bits_per_irq;
	unsigned int access_flags;
	union {
		long unsigned int (*read)(struct kvm_vcpu___7 *, gpa_t, unsigned int);
		long unsigned int (*its_read)(struct kvm___7 *, struct vgic_its___7 *, gpa_t, unsigned int);
	};
	union {
		void (*write)(struct kvm_vcpu___7 *, gpa_t, unsigned int, long unsigned int);
		void (*its_write)(struct kvm___7 *, struct vgic_its___7 *, gpa_t, unsigned int, long unsigned int);
	};
	long unsigned int (*uaccess_read)(struct kvm_vcpu___7 *, gpa_t, unsigned int);
	union {
		int (*uaccess_write)(struct kvm_vcpu___7 *, gpa_t, unsigned int, long unsigned int);
		int (*uaccess_its_write)(struct kvm___7 *, struct vgic_its___7 *, gpa_t, unsigned int, long unsigned int);
	};
};

struct kvm_device_ops___7;

struct kvm_device___7 {
	struct kvm_device_ops___7 *ops;
	struct kvm___7 *kvm;
	void *private;
	struct list_head vm_node;
};

struct vgic_dist___7 {
	bool in_kernel;
	bool ready;
	bool initialized;
	u32 vgic_model;
	u32 implementation_rev;
	bool v2_groups_user_writable;
	bool msis_require_devid;
	int nr_spis;
	gpa_t vgic_dist_base;
	union {
		gpa_t vgic_cpu_base;
		struct list_head rd_regions;
	};
	bool enabled;
	struct vgic_irq___7 *spis;
	struct vgic_io_device___7 dist_iodev;
	bool has_its;
	u64 propbaser;
	raw_spinlock_t lpi_list_lock;
	struct list_head lpi_list_head;
	int lpi_list_count;
	struct vgic_state_iter *iter;
	struct its_vm___5 its_vm;
};

struct kvm_arch___7 {
	struct kvm_vmid vmid;
	pgd_t *pgd;
	phys_addr_t pgd_phys;
	u64 vtcr;
	int *last_vcpu_ran;
	int max_vcpus;
	struct vgic_dist___7 vgic;
	u32 psci_version;
};

struct kvm_io_range___7 {
	gpa_t addr;
	int len;
	struct kvm_io_device___7 *dev;
};

struct kvm_io_bus___7 {
	int dev_count;
	int ioeventfd_count;
	struct kvm_io_range___7 range[0];
};

struct kvm_stat_data___7;

struct kvm___7 {
	spinlock_t mmu_lock;
	struct mutex slots_lock;
	struct mm_struct___30 *mm;
	struct kvm_memslots *memslots[1];
	struct kvm_vcpu___7 *vcpus[512];
	atomic_t online_vcpus;
	int created_vcpus;
	int last_boosted_vcpu;
	struct list_head vm_list;
	struct mutex lock;
	struct kvm_io_bus___7 *buses[4];
	struct {
		spinlock_t lock;
		struct list_head items;
		struct list_head resampler_list;
		struct mutex resampler_lock;
	} irqfds;
	struct list_head ioeventfds;
	struct kvm_vm_stat stat;
	struct kvm_arch___7 arch;
	refcount_t users_count;
	struct kvm_coalesced_mmio_ring *coalesced_mmio_ring;
	spinlock_t ring_lock;
	struct list_head coalesced_zones;
	struct mutex irq_lock;
	struct kvm_irq_routing_table *irq_routing;
	struct hlist_head irq_ack_notifier_list;
	struct mmu_notifier___5 mmu_notifier;
	long unsigned int mmu_notifier_seq;
	long int mmu_notifier_count;
	long int tlbs_dirty;
	struct list_head devices;
	bool manual_dirty_log_protect;
	struct dentry___31 *debugfs_dentry;
	struct kvm_stat_data___7 **debugfs_stat_data;
	struct srcu_struct srcu;
	struct srcu_struct irq_srcu;
	pid_t userspace_pid;
};

struct kvm_stat_data___7 {
	int offset;
	int mode;
	struct kvm___7 *kvm;
};

struct kvm_device_ops___7 {
	const char *name;
	int (*create)(struct kvm_device___7 *, u32);
	void (*init)(struct kvm_device___7 *);
	void (*destroy)(struct kvm_device___7 *);
	void (*release)(struct kvm_device___7 *);
	int (*set_attr)(struct kvm_device___7 *, struct kvm_device_attr *);
	int (*get_attr)(struct kvm_device___7 *, struct kvm_device_attr *);
	int (*has_attr)(struct kvm_device___7 *, struct kvm_device_attr *);
	long int (*ioctl)(struct kvm_device___7 *, unsigned int, long unsigned int);
	int (*mmap)(struct kvm_device___7 *, struct vm_area_struct___30 *);
};

struct vgic_reg_attr {
	struct kvm_vcpu___7 *vcpu;
	gpa_t addr;
};

struct vgic_reg_attr___2 {
	struct kvm_vcpu___2 *vcpu;
	gpa_t addr;
};

struct its_vlpi_map___2 {
	struct its_vm___5 *vm;
	struct its_vpe___5 *vpe;
	u32 vintid;
	u8 properties;
	bool db_enabled;
};

struct its_device {
	struct list_head dev_list;
	struct list_head itt_head;
	u32 num_eventid_bits;
	gpa_t itt_addr;
	u32 device_id;
};

struct its_collection {
	struct list_head coll_list;
	u32 collection_id;
	u32 target_addr;
};

struct its_ite {
	struct list_head ite_list;
	struct vgic_irq___7 *irq;
	struct its_collection *collection;
	u32 event_id;
};

struct vgic_its_abi {
	int cte_esz;
	int dte_esz;
	int ite_esz;
	int (*save_tables)(struct vgic_its___7 *);
	int (*restore_tables)(struct vgic_its___7 *);
	int (*commit)(struct vgic_its___7 *);
};

typedef int (*entry_fn_t)(struct vgic_its___7 *, u32, void *, void *);

struct vgic_state_iter {
	int nr_cpus;
	int nr_spis;
	int nr_lpis;
	int dist_id;
	int vcpu_id;
	int intid;
	int lpi_idx;
	u32 *lpi_array;
};

struct cyclecounter {
	u64 (*read)(const struct cyclecounter *);
	u64 mask;
	u32 mult;
	u32 shift;
};

struct timecounter {
	const struct cyclecounter *cc;
	u64 cycle_last;
	u64 nsec;
	u64 mask;
	u64 frac;
};

struct arch_timer_kvm_info {
	struct timecounter timecounter;
	int virtual_irq;
	int physical_irq;
};

enum hrtimer_mode {
	HRTIMER_MODE_ABS = 0,
	HRTIMER_MODE_REL = 1,
	HRTIMER_MODE_PINNED = 2,
	HRTIMER_MODE_SOFT = 4,
	HRTIMER_MODE_ABS_PINNED = 2,
	HRTIMER_MODE_REL_PINNED = 3,
	HRTIMER_MODE_ABS_SOFT = 4,
	HRTIMER_MODE_REL_SOFT = 5,
	HRTIMER_MODE_ABS_PINNED_SOFT = 6,
	HRTIMER_MODE_REL_PINNED_SOFT = 7,
};

struct msi_desc___4 {
	struct list_head list;
	unsigned int irq;
	unsigned int nvec_used;
	struct device___25 *dev;
	struct msi_msg msg;
	struct irq_affinity_desc *affinity;
	const void *iommu_cookie;
	union {
		struct {
			u32 masked;
			struct {
				u8 is_msix: 1;
				u8 multiple: 3;
				u8 multi_cap: 3;
				u8 maskbit: 1;
				u8 is_64: 1;
				u16 entry_nr;
				unsigned int default_irq;
			} msi_attrib;
			union {
				u8 mask_pos;
				void *mask_base;
			};
		};
		struct platform_msi_desc platform;
		struct fsl_mc_msi_desc fsl_mc;
	};
};

struct irq_common_data___3;

struct irq_chip___6;

struct irq_data___7 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___3 *common;
	struct irq_chip___6 *chip;
	struct irq_domain *domain;
	struct irq_data___7 *parent_data;
	void *chip_data;
};

struct irq_chip___6 {
	struct device___25 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___7 *);
	void (*irq_shutdown)(struct irq_data___7 *);
	void (*irq_enable)(struct irq_data___7 *);
	void (*irq_disable)(struct irq_data___7 *);
	void (*irq_ack)(struct irq_data___7 *);
	void (*irq_mask)(struct irq_data___7 *);
	void (*irq_mask_ack)(struct irq_data___7 *);
	void (*irq_unmask)(struct irq_data___7 *);
	void (*irq_eoi)(struct irq_data___7 *);
	int (*irq_set_affinity)(struct irq_data___7 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___7 *);
	int (*irq_set_type)(struct irq_data___7 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___7 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___7 *);
	void (*irq_bus_sync_unlock)(struct irq_data___7 *);
	void (*irq_cpu_online)(struct irq_data___7 *);
	void (*irq_cpu_offline)(struct irq_data___7 *);
	void (*irq_suspend)(struct irq_data___7 *);
	void (*irq_resume)(struct irq_data___7 *);
	void (*irq_pm_shutdown)(struct irq_data___7 *);
	void (*irq_calc_mask)(struct irq_data___7 *);
	void (*irq_print_chip)(struct irq_data___7 *, struct seq_file___27 *);
	int (*irq_request_resources)(struct irq_data___7 *);
	void (*irq_release_resources)(struct irq_data___7 *);
	void (*irq_compose_msi_msg)(struct irq_data___7 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___7 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___7 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___7 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___7 *, void *);
	void (*ipi_send_single)(struct irq_data___7 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___7 *, const struct cpumask *);
	long unsigned int flags;
};

struct timer_map___2 {
	struct arch_timer_context___7 *direct_vtimer;
	struct arch_timer_context___7 *direct_ptimer;
	struct arch_timer_context___7 *emul_ptimer;
};

struct irq_common_data___3 {
	unsigned int state_use_accessors;
	unsigned int node;
	void *handler_data;
	struct msi_desc___4 *msi_desc;
	cpumask_var_t affinity;
	cpumask_var_t effective_affinity;
};

struct tlb_inv_context {
	long unsigned int flags;
	u64 tcr;
	u64 sctlr;
};

typedef void (*exitcall_t)();

struct crypto_async_request;

typedef void (*crypto_completion_t)(struct crypto_async_request *, int);

struct crypto_tfm;

struct crypto_async_request {
	struct list_head list;
	crypto_completion_t complete;
	void *data;
	struct crypto_tfm *tfm;
	u32 flags;
};

struct crypto_ablkcipher;

struct ablkcipher_request;

struct ablkcipher_tfm {
	int (*setkey)(struct crypto_ablkcipher *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request *);
	int (*decrypt)(struct ablkcipher_request *);
	struct crypto_ablkcipher *base;
	unsigned int ivsize;
	unsigned int reqsize;
};

struct blkcipher_desc;

struct blkcipher_tfm {
	void *iv;
	int (*setkey)(struct crypto_tfm *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc *, struct scatterlist *, struct scatterlist *, unsigned int);
};

struct cipher_tfm {
	int (*cit_setkey)(struct crypto_tfm *, const u8 *, unsigned int);
	void (*cit_encrypt_one)(struct crypto_tfm *, u8 *, const u8 *);
	void (*cit_decrypt_one)(struct crypto_tfm *, u8 *, const u8 *);
};

struct compress_tfm {
	int (*cot_compress)(struct crypto_tfm *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*cot_decompress)(struct crypto_tfm *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg;

struct crypto_tfm {
	u32 crt_flags;
	union {
		struct ablkcipher_tfm ablkcipher;
		struct blkcipher_tfm blkcipher;
		struct cipher_tfm cipher;
		struct compress_tfm compress;
	} crt_u;
	void (*exit)(struct crypto_tfm *);
	struct crypto_alg *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct ablkcipher_request {
	struct crypto_async_request base;
	unsigned int nbytes;
	void *info;
	struct scatterlist *src;
	struct scatterlist *dst;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_blkcipher;

struct blkcipher_desc {
	struct crypto_blkcipher *tfm;
	void *info;
	u32 flags;
};

struct crypto_blkcipher {
	struct crypto_tfm base;
};

struct skcipher_givcrypt_request;

struct ablkcipher_alg {
	int (*setkey)(struct crypto_ablkcipher *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request *);
	int (*decrypt)(struct ablkcipher_request *);
	int (*givencrypt)(struct skcipher_givcrypt_request *);
	int (*givdecrypt)(struct skcipher_givcrypt_request *);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct crypto_ablkcipher {
	struct crypto_tfm base;
};

struct blkcipher_alg {
	int (*setkey)(struct crypto_tfm *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc *, struct scatterlist *, struct scatterlist *, unsigned int);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct cipher_alg {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm *, u8 *, const u8 *);
};

struct compress_alg {
	int (*coa_compress)(struct crypto_tfm *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_type;

struct crypto_alg {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type *cra_type;
	union {
		struct ablkcipher_alg ablkcipher;
		struct blkcipher_alg blkcipher;
		struct cipher_alg cipher;
		struct compress_alg compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm *);
	void (*cra_exit)(struct crypto_tfm *);
	void (*cra_destroy)(struct crypto_alg *);
	struct module___10 *cra_module;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct crypto_alg___2;

struct crypto_tfm___2;

struct crypto_instance;

struct crypto_type {
	unsigned int (*ctxsize)(struct crypto_alg___2 *, u32, u32);
	unsigned int (*extsize)(struct crypto_alg___2 *);
	int (*init)(struct crypto_tfm___2 *, u32, u32);
	int (*init_tfm)(struct crypto_tfm___2 *);
	void (*show)(struct seq_file___9 *, struct crypto_alg___2 *);
	int (*report)(struct sk_buff___4 *, struct crypto_alg___2 *);
	void (*free)(struct crypto_instance *);
	unsigned int type;
	unsigned int maskclear;
	unsigned int maskset;
	unsigned int tfmsize;
};

struct crypto_aes_ctx {
	u32 key_enc[60];
	u32 key_dec[60];
	u32 key_length;
};

struct cpu_feature {
	__u16 feature;
};

struct aes_block {
	u8 b[16];
};

struct crypto_async_request___2;

typedef void (*crypto_completion_t___2)(struct crypto_async_request___2 *, int);

struct crypto_async_request___2 {
	struct list_head list;
	crypto_completion_t___2 complete;
	void *data;
	struct crypto_tfm___2 *tfm;
	u32 flags;
};

struct crypto_ablkcipher___2;

struct ablkcipher_request___2;

struct ablkcipher_tfm___2 {
	int (*setkey)(struct crypto_ablkcipher___2 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___2 *);
	int (*decrypt)(struct ablkcipher_request___2 *);
	struct crypto_ablkcipher___2 *base;
	unsigned int ivsize;
	unsigned int reqsize;
};

struct blkcipher_desc___2;

struct blkcipher_tfm___2 {
	void *iv;
	int (*setkey)(struct crypto_tfm___2 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___2 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___2 *, struct scatterlist *, struct scatterlist *, unsigned int);
};

struct cipher_tfm___2 {
	int (*cit_setkey)(struct crypto_tfm___2 *, const u8 *, unsigned int);
	void (*cit_encrypt_one)(struct crypto_tfm___2 *, u8 *, const u8 *);
	void (*cit_decrypt_one)(struct crypto_tfm___2 *, u8 *, const u8 *);
};

struct compress_tfm___2 {
	int (*cot_compress)(struct crypto_tfm___2 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*cot_decompress)(struct crypto_tfm___2 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_tfm___2 {
	u32 crt_flags;
	union {
		struct ablkcipher_tfm___2 ablkcipher;
		struct blkcipher_tfm___2 blkcipher;
		struct cipher_tfm___2 cipher;
		struct compress_tfm___2 compress;
	} crt_u;
	void (*exit)(struct crypto_tfm___2 *);
	struct crypto_alg___2 *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct ablkcipher_request___2 {
	struct crypto_async_request___2 base;
	unsigned int nbytes;
	void *info;
	struct scatterlist *src;
	struct scatterlist *dst;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_blkcipher___2;

struct blkcipher_desc___2 {
	struct crypto_blkcipher___2 *tfm;
	void *info;
	u32 flags;
};

struct crypto_blkcipher___2 {
	struct crypto_tfm___2 base;
};

struct ablkcipher_alg___2 {
	int (*setkey)(struct crypto_ablkcipher___2 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___2 *);
	int (*decrypt)(struct ablkcipher_request___2 *);
	int (*givencrypt)(struct skcipher_givcrypt_request *);
	int (*givdecrypt)(struct skcipher_givcrypt_request *);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct crypto_ablkcipher___2 {
	struct crypto_tfm___2 base;
};

struct skcipher_givcrypt_request {
	u64 seq;
	u8 *giv;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ablkcipher_request___2 creq;
};

struct blkcipher_alg___2 {
	int (*setkey)(struct crypto_tfm___2 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___2 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___2 *, struct scatterlist *, struct scatterlist *, unsigned int);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct cipher_alg___2 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___2 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___2 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___2 *, u8 *, const u8 *);
};

struct compress_alg___2 {
	int (*coa_compress)(struct crypto_tfm___2 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___2 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___2 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type *cra_type;
	union {
		struct ablkcipher_alg___2 ablkcipher;
		struct blkcipher_alg___2 blkcipher;
		struct cipher_alg___2 cipher;
		struct compress_alg___2 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___2 *);
	void (*cra_exit)(struct crypto_tfm___2 *);
	void (*cra_destroy)(struct crypto_alg___2 *);
	struct module___23 *cra_module;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct crypto_template;

struct crypto_instance {
	struct crypto_alg___2 alg;
	struct crypto_template *tmpl;
	struct hlist_node list;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct rtattr;

struct crypto_template {
	struct list_head list;
	struct hlist_head instances;
	struct module___23 *module;
	struct crypto_instance * (*alloc)(struct rtattr **);
	void (*free)(struct crypto_instance *);
	int (*create)(struct crypto_template *, struct rtattr **);
	char name[128];
};

struct scatter_walk {
	struct scatterlist *sg;
	unsigned int offset;
};

struct aead_request {
	struct crypto_async_request___2 base;
	unsigned int assoclen;
	unsigned int cryptlen;
	u8 *iv;
	struct scatterlist *src;
	struct scatterlist *dst;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_aead;

struct aead_alg {
	int (*setkey)(struct crypto_aead *, const u8 *, unsigned int);
	int (*setauthsize)(struct crypto_aead *, unsigned int);
	int (*encrypt)(struct aead_request *);
	int (*decrypt)(struct aead_request *);
	int (*init)(struct crypto_aead *);
	void (*exit)(struct crypto_aead *);
	const char *geniv;
	unsigned int ivsize;
	unsigned int maxauthsize;
	unsigned int chunksize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_alg___2 base;
};

struct crypto_aead {
	unsigned int authsize;
	unsigned int reqsize;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_tfm___2 base;
};

struct skcipher_walk {
	union {
		struct {
			struct page___26 *page;
			long unsigned int offset;
		} phys;
		struct {
			u8 *page;
			void *addr;
		} virt;
	} src;
	union {
		struct {
			struct page___26 *page;
			long unsigned int offset;
		} phys;
		struct {
			u8 *page;
			void *addr;
		} virt;
	} dst;
	struct scatter_walk in;
	unsigned int nbytes;
	struct scatter_walk out;
	unsigned int total;
	struct list_head buffers;
	u8 *page;
	u8 *buffer;
	u8 *oiv;
	void *iv;
	unsigned int ivsize;
	int flags;
	unsigned int blocksize;
	unsigned int stride;
	unsigned int alignmask;
};

struct crypto_shash;

struct shash_desc {
	struct crypto_shash *tfm;
	u32 flags;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_shash {
	unsigned int descsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_tfm___2 base;
};

struct shash_alg {
	int (*init)(struct shash_desc *);
	int (*update)(struct shash_desc *, const u8 *, unsigned int);
	int (*final)(struct shash_desc *, u8 *);
	int (*finup)(struct shash_desc *, const u8 *, unsigned int, u8 *);
	int (*digest)(struct shash_desc *, const u8 *, unsigned int, u8 *);
	int (*export)(struct shash_desc *, void *);
	int (*import)(struct shash_desc *, const void *);
	int (*setkey)(struct crypto_shash *, const u8 *, unsigned int);
	unsigned int descsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int digestsize;
	unsigned int statesize;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_alg___2 base;
};

struct skcipher_request {
	unsigned int cryptlen;
	u8 *iv;
	struct scatterlist *src;
	struct scatterlist *dst;
	struct crypto_async_request___2 base;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_skcipher {
	int (*setkey)(struct crypto_skcipher *, const u8 *, unsigned int);
	int (*encrypt)(struct skcipher_request *);
	int (*decrypt)(struct skcipher_request *);
	unsigned int ivsize;
	unsigned int reqsize;
	unsigned int keysize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_tfm___2 base;
};

struct skcipher_alg {
	int (*setkey)(struct crypto_skcipher *, const u8 *, unsigned int);
	int (*encrypt)(struct skcipher_request *);
	int (*decrypt)(struct skcipher_request *);
	int (*init)(struct crypto_skcipher *);
	void (*exit)(struct crypto_skcipher *);
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
	unsigned int chunksize;
	unsigned int walksize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_alg___2 base;
};

typedef struct {
	__be64 a;
	__be64 b;
} be128;

struct crypto_aes_xts_ctx {
	struct crypto_aes_ctx key1;
	int: 32;
	struct crypto_aes_ctx key2;
	int: 32;
};

struct mac_tfm_ctx {
	struct crypto_aes_ctx key;
	int: 32;
	u8 consts[0];
};

struct mac_desc_ctx {
	unsigned int len;
	u8 dg[16];
};

struct simd_skcipher_alg;

typedef struct {
	u32 revision;
	void *parent_handle;
	efi_system_table_t *system_table;
	void *device_handle;
	void *file_path;
	void *reserved;
	u32 load_options_size;
	void *load_options;
	void *image_base;
	__u64 image_size;
	unsigned int image_code_type;
	unsigned int image_data_type;
	long unsigned int unload;
} efi_loaded_image_t;

struct _efi_file_handle {
	u64 revision;
	efi_status_t (*open)(struct _efi_file_handle *, struct _efi_file_handle **, efi_char16_t *, u64, u64);
	efi_status_t (*close)(struct _efi_file_handle *);
	void *delete;
	efi_status_t (*read)(struct _efi_file_handle *, long unsigned int *, void *);
	void *write;
	void *get_position;
	void *set_position;
	efi_status_t (*get_info)(struct _efi_file_handle *, efi_guid_t *, long unsigned int *, void *);
	void *set_info;
	void *flush;
};

typedef struct _efi_file_handle efi_file_handle_t;

struct _efi_file_io_interface {
	u64 revision;
	int (*open_volume)(struct _efi_file_io_interface *, efi_file_handle_t **);
};

typedef struct _efi_file_io_interface efi_file_io_interface_t;

enum efi_secureboot_mode {
	efi_secureboot_mode_unset = 0,
	efi_secureboot_mode_unknown = 1,
	efi_secureboot_mode_disabled = 2,
	efi_secureboot_mode_enabled = 3,
};

struct efi_simple_text_output_protocol {
	void *reset;
	efi_status_t (*output_string)(void *, void *);
	void *test_string;
};

struct linux_efi_memreserve {
	int size;
	atomic_t count;
	phys_addr_t next;
	struct {
		phys_addr_t base;
		phys_addr_t size;
	} entry[0];
};

struct efi_boot_memmap {
	efi_memory_desc_t **map;
	long unsigned int *map_size;
	long unsigned int *desc_size;
	u32 *desc_ver;
	long unsigned int *key_ptr;
	long unsigned int *buff_size;
};

typedef struct {
	u64 size;
	u64 file_size;
	u64 phys_size;
	efi_time_t create_time;
	efi_time_t last_access_time;
	efi_time_t modification_time;
	__u64 attribute;
	efi_char16_t filename[1];
} efi_file_info_t;

typedef efi_status_t (*efi_exit_boot_map_processing)(efi_system_table_t *, struct efi_boot_memmap *, void *);

struct file_info {
	efi_file_handle_t *handle;
	u64 size;
};

typedef struct {
	efi_guid_t guid;
	long unsigned int table;
} efi_config_table_t;

struct exit_boot_struct {
	efi_memory_desc_t *runtime_map;
	int *runtime_entry_count;
	void *new_fdt_addr;
};

struct efi_pixel_bitmask {
	u32 red_mask;
	u32 green_mask;
	u32 blue_mask;
	u32 reserved_mask;
};

struct efi_graphics_output_mode_info {
	u32 version;
	u32 horizontal_resolution;
	u32 vertical_resolution;
	int pixel_format;
	struct efi_pixel_bitmask pixel_information;
	u32 pixels_per_scan_line;
};

struct efi_graphics_output_protocol_mode_64 {
	u32 max_mode;
	u32 mode;
	u64 info;
	u64 size_of_info;
	u64 frame_buffer_base;
	u64 frame_buffer_size;
};

struct efi_graphics_output_protocol_mode {
	u32 max_mode;
	u32 mode;
	long unsigned int info;
	long unsigned int size_of_info;
	u64 frame_buffer_base;
	long unsigned int frame_buffer_size;
};

struct efi_graphics_output_protocol_64 {
	u64 query_mode;
	u64 set_mode;
	u64 blt;
	u64 mode;
};

struct efi_graphics_output_protocol {
	long unsigned int query_mode;
	long unsigned int set_mode;
	long unsigned int blt;
	struct efi_graphics_output_protocol_mode *mode;
};

typedef efi_status_t (*efi_graphics_output_protocol_query_mode)(struct efi_graphics_output_protocol *, u32, long unsigned int *, struct efi_graphics_output_mode_info **);

struct fdt_reserve_entry {
	fdt64_t address;
	fdt64_t size;
};

struct fdt_node_header {
	fdt32_t tag;
	char name[0];
};

struct fdt_property {
	fdt32_t tag;
	fdt32_t len;
	fdt32_t nameoff;
	char data[0];
};

struct linux_efi_random_seed {
	u32 size;
	u8 bits[0];
};

struct efi_rng_protocol {
	efi_status_t (*get_info)(struct efi_rng_protocol *, long unsigned int *, efi_guid_t *);
	efi_status_t (*get_rng)(struct efi_rng_protocol *, efi_guid_t *, long unsigned int, u8 *);
};

typedef u32 efi_tcg2_event_log_format;

typedef struct {
	void *get_capability;
	efi_status_t (*get_event_log)(efi_handle_t, efi_tcg2_event_log_format, efi_physical_addr_t *, efi_physical_addr_t *, efi_bool_t *);
	void *hash_log_extend_event;
	void *submit_command;
	void *get_active_pcr_banks;
	void *set_active_pcr_banks;
	void *get_result_of_set_active_pcr_banks;
} efi_tcg2_protocol_t;

struct linux_efi_tpm_eventlog {
	u32 size;
	u8 version;
	u8 log[0];
};

struct tcpa_event {
	u32 pcr_index;
	u32 event_type;
	u8 pcr_value[20];
	u32 event_size;
	u8 event_data[0];
};

struct module___29;

struct file___32;

struct kiocb___32;

struct iov_iter___12;

struct poll_table_struct___18;

struct vm_area_struct___32;

struct inode___34;

struct file_lock___32;

struct page___32;

struct pipe_inode_info___4;

struct seq_file___29;

struct file_operations___32 {
	struct module___29 *owner;
	loff_t (*llseek)(struct file___32 *, loff_t, int);
	ssize_t (*read)(struct file___32 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___32 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___32 *, struct iov_iter___12 *);
	ssize_t (*write_iter)(struct kiocb___32 *, struct iov_iter___12 *);
	int (*iopoll)(struct kiocb___32 *, bool);
	int (*iterate)(struct file___32 *, struct dir_context *);
	int (*iterate_shared)(struct file___32 *, struct dir_context *);
	__poll_t (*poll)(struct file___32 *, struct poll_table_struct___18 *);
	long int (*unlocked_ioctl)(struct file___32 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___32 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___32 *, struct vm_area_struct___32 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___34 *, struct file___32 *);
	int (*flush)(struct file___32 *, fl_owner_t);
	int (*release)(struct inode___34 *, struct file___32 *);
	int (*fsync)(struct file___32 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___32 *, int);
	int (*lock)(struct file___32 *, int, struct file_lock___32 *);
	ssize_t (*sendpage)(struct file___32 *, struct page___32 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___32 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___32 *, int, struct file_lock___32 *);
	ssize_t (*splice_write)(struct pipe_inode_info___4 *, struct file___32 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___32 *, loff_t *, struct pipe_inode_info___4 *, size_t, unsigned int);
	int (*setlease)(struct file___32 *, long int, struct file_lock___32 **, void **);
	long int (*fallocate)(struct file___32 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___29 *, struct file___32 *);
	ssize_t (*copy_file_range)(struct file___32 *, loff_t, struct file___32 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___32 *, loff_t, struct file___32 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___32 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___31 {
	u64 seqnum;
	struct vm_area_struct___32 *vmas[4];
};

struct page_frag___31 {
	struct page___32 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___17;

struct debug_info___17 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___17 *hbp_break[16];
	struct perf_event___17 *hbp_watch[16];
};

struct thread_struct___17 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___17 debug;
	long: 64;
};

struct mm_struct___32;

struct mem_cgroup___10;

struct pid___27;

struct cred___31;

struct fs_struct___2;

struct files_struct___2;

struct nsproxy___30;

struct signal_struct___29;

struct bio_list___11;

struct backing_dev_info___11;

struct io_context___6;

struct css_set___21;

struct perf_event_context___17;

struct request_queue___7;

struct vm_struct___26;

struct task_struct___33 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___33 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___32 *mm;
	struct mm_struct___32 *active_mm;
	struct vmacache___31 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___33 *real_parent;
	struct task_struct___33 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___33 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___10 *active_memcg;
	long int rh_reserved2;
	struct pid___27 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___27 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___27 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___31 *ptracer_cred;
	const struct cred___31 *real_cred;
	const struct cred___31 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct___2 *fs;
	struct files_struct___2 *files;
	struct nsproxy___30 *nsproxy;
	struct signal_struct___29 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___33 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___11 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___11 *backing_dev_info;
	struct io_context___6 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___21 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___17 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___4 *splice_pipe;
	struct page_frag___31 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___10 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___7 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___33 *oom_reaper_list;
	struct vm_struct___26 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___17 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___17 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___33 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___17)(struct perf_event___17 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___17;

struct fasync_struct___31;

struct pid_namespace___27;

struct trace_event_call___12;

struct perf_cgroup___17;

struct perf_event___17 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___17 *group_leader;
	struct pmu___17 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___17 hw;
	struct perf_event_context___17 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___17 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___33 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___31 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___17 *);
	struct callback_head callback_head;
	struct pid_namespace___27 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___17 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___17 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___12 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___17 *cgrp;
	struct list_head sb_list;
};

typedef struct page___32 *pgtable_t___31;

struct address_space___31;

struct dev_pagemap___31;

struct page___32 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___31 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___32 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___31 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___32 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___31 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___10 *mem_cgroup;
};

struct pglist_data___31;

struct lruvec___31 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___31 *pgdat;
};

struct zone___31 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___31 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___31 {
	struct zone___31 *zone;
	int zone_idx;
};

struct zonelist___31 {
	struct zoneref___31 _zonerefs[25];
};

struct pglist_data___31 {
	struct zone___31 node_zones[3];
	struct zonelist___31 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___33 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___33 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___31 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___32 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___33 *owner;
};

struct secondary_data___32 {
	void *stack;
	struct task_struct___33 *task;
	long int status;
};

enum tk_offsets {
	TK_OFFS_REAL = 0,
	TK_OFFS_BOOT = 1,
	TK_OFFS_TAI = 2,
	TK_OFFS_MAX = 3,
};

struct blocking_notifier_head___31 {
	struct rw_semaphore___32 rwsem;
	struct notifier_block *head;
};

struct cgroup___21;

struct cgroup_subsys___21;

struct cgroup_subsys_state___21 {
	struct cgroup___21 *cgroup;
	struct cgroup_subsys___21 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___21 *parent;
};

struct mem_cgroup_id___7 {
	int id;
	union {
		refcount_t ref;
		struct {
			atomic_t ref;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
};

struct kernfs_node___29;

struct cgroup_file___21 {
	struct kernfs_node___29 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___10;

struct mem_cgroup___10 {
	struct cgroup_subsys_state___21 css;
	struct mem_cgroup_id___7 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___21 events_file;
	struct cgroup_file___21 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___33 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___10 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct upid___27 {
	int nr;
	struct pid_namespace___27 *ns;
};

struct vfsmount___4;

struct dentry___33;

struct user_namespace___22;

struct ucounts___22;

struct pid_namespace___27 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___33 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___27 *parent;
	struct vfsmount___4 *proc_mnt;
	struct dentry___33 *proc_self;
	struct dentry___33 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___22 *user_ns;
	struct ucounts___22 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___2 ns;
};

struct pid___27 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___27 numbers[1];
};

struct key___32;

struct user_namespace___22 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___22 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___2 ns;
	long unsigned int flags;
	struct key___32 *persistent_keyring_register;
	struct rw_semaphore___32 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___22 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct user_struct___31 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___32 *uid_keyring;
	struct key___32 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct anon_vma___2;

struct vm_operations_struct___31;

struct vm_area_struct___32 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___32 *vm_next;
	struct vm_area_struct___32 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___32 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma___2 *anon_vma;
	const struct vm_operations_struct___31 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___32 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct linux_binfmt___3;

struct core_state___31;

struct mm_struct___32 {
	struct {
		struct vm_area_struct___32 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___32 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___32 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___3 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___31 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___33 *owner;
		struct user_namespace___22 *user_ns;
		struct file___32 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___31 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___31 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___32 *session_keyring;
	struct key___32 *process_keyring;
	struct key___32 *thread_keyring;
	struct key___32 *request_key_auth;
	void *security;
	struct user_struct___31 *user;
	struct user_namespace___22 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct path___31 {
	struct vfsmount___4 *mnt;
	struct dentry___33 *dentry;
};

struct fs_struct___2 {
	int users;
	spinlock_t lock;
	seqcount_t seq;
	int umask;
	int in_exec;
	struct path___31 root;
	struct path___31 pwd;
};

struct fdtable {
	unsigned int max_fds;
	struct file___32 **fd;
	long unsigned int *close_on_exec;
	long unsigned int *open_fds;
	long unsigned int *full_fds_bits;
	struct callback_head rcu;
};

struct files_struct___2 {
	atomic_t count;
	bool resize_in_progress;
	wait_queue_head_t resize_wait;
	struct fdtable *fdt;
	struct fdtable fdtab;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t file_lock;
	unsigned int next_fd;
	long unsigned int close_on_exec_init[1];
	long unsigned int open_fds_init[1];
	long unsigned int full_fds_bits_init[1];
	struct file___32 *fd_array[64];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct uts_namespace___6;

struct net___7;

struct cgroup_namespace___21;

struct nsproxy___30 {
	atomic_t count;
	struct uts_namespace___6 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___27 *pid_ns_for_children;
	struct net___7 *net_ns;
	struct cgroup_namespace___21 *cgroup_ns;
};

struct tty_struct___3;

struct signal_struct___29 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___33 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___33 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___27 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___27 *tty_old_pgrp;
	int leader;
	struct tty_struct___3 *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___32 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___27 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___11;

struct bio_list___11 {
	struct bio___11 *head;
	struct bio___11 *tail;
};

struct bdi_writeback_congested___11;

struct bdi_writeback___11 {
	struct backing_dev_info___11 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___11 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___21 *memcg_css;
	struct cgroup_subsys_state___21 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___27;

struct backing_dev_info___11 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___11 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___27 *dev;
	struct device___27 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___33 *debug_dir;
	struct dentry___33 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___6;

struct io_context___6 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___6 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___21 {
	struct cgroup_subsys_state___21 *subsys[13];
	refcount_t refcount;
	struct css_set___21 *dom_cset;
	struct cgroup___21 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___21 *mg_src_cgrp;
	struct cgroup___21 *mg_dst_cgrp;
	struct css_set___21 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct robust_list {
	struct robust_list *next;
};

struct robust_list_head {
	struct robust_list list;
	long int futex_offset;
	struct robust_list *list_op_pending;
};

struct perf_event_context___17 {
	struct pmu___17 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___33 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___17 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___4;

struct pipe_inode_info___4 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___32 *tmp_page;
	struct fasync_struct___31 *fasync_readers;
	struct fasync_struct___31 *fasync_writers;
	struct pipe_buffer___4 *bufs;
	struct user_struct___31 *user;
};

typedef blk_qc_t make_request_fn___6(struct request_queue___7 *, struct bio___11 *);

struct request___7;

typedef int dma_drain_needed_fn___6(struct request___7 *);

struct kset___29;

struct kobj_type___29;

struct kobject___30 {
	const char *name;
	struct list_head entry;
	struct kobject___30 *parent;
	struct kset___29 *kset;
	struct kobj_type___29 *ktype;
	struct kernfs_node___29 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___6;

struct bsg_class_device___6 {
	struct device___27 *class_dev;
	int minor;
	struct request_queue___7 *queue;
	const struct bsg_ops___6 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___11 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___11 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___6;

struct request_queue___7 {
	struct list_head queue_head;
	struct request___7 *last_merge;
	struct elevator_queue___6 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___6 *make_request_fn;
	dma_drain_needed_fn___6 *dma_drain_needed;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___11 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___30 kobj;
	struct kobject___30 *mq_kobj;
	struct blk_integrity integrity;
	struct device___27 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide38;
		union {		};
	};
	struct bsg_class_device___6 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___11 bio_split;
	struct dentry___33 *debugfs_dir;
	struct dentry___33 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___26 {
	struct vm_struct___26 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___32 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___29 {
	struct task_struct___33 task;
	long unsigned int stack[8192];
};

struct address_space_operations___31;

struct address_space___31 {
	struct inode___34 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___32 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___31 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___31)(struct vm_area_struct___32 *, long unsigned int, const struct page___32 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___31)(struct page___32 *, void *);

struct dev_pagemap___31 {
	dev_page_fault_t___31 page_fault;
	dev_page_free_t___31 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___27 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct fown_struct___27 {
	rwlock_t lock;
	struct pid___27 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___32 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___31 f_path;
	struct inode___34 *f_inode;
	const struct file_operations___32 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___27 f_owner;
	const struct cred___31 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___31 *f_mapping;
	errseq_t f_wb_err;
};

struct anon_vma___2 {
	struct anon_vma___2 *root;
	struct rw_semaphore___32 rwsem;
	atomic_t refcount;
	unsigned int degree;
	struct anon_vma___2 *parent;
	struct rb_root_cached rb_root;
};

struct vm_fault___31;

struct vm_operations_struct___31 {
	void (*open)(struct vm_area_struct___32 *);
	void (*close)(struct vm_area_struct___32 *);
	int (*split)(struct vm_area_struct___32 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___32 *);
	vm_fault_t (*fault)(struct vm_fault___31 *);
	vm_fault_t (*huge_fault)(struct vm_fault___31 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___31 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___32 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___31 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___31 *);
	int (*access)(struct vm_area_struct___32 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___32 *);
	int (*set_policy)(struct vm_area_struct___32 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___32 *, long unsigned int);
	struct page___32 * (*find_special_page)(struct vm_area_struct___32 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___31 {
	struct task_struct___33 *task;
	struct core_thread___31 *next;
};

struct core_state___31 {
	atomic_t nr_threads;
	struct core_thread___31 dumper;
	struct completion startup;
};

struct linux_binprm___3;

struct coredump_params___2;

struct linux_binfmt___3 {
	struct list_head lh;
	struct module___29 *module;
	int (*load_binary)(struct linux_binprm___3 *);
	int (*load_shlib)(struct file___32 *);
	int (*core_dump)(struct coredump_params___2 *);
	long unsigned int min_coredump;
};

struct vm_fault___31 {
	struct vm_area_struct___32 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___32 *cow_page;
	struct mem_cgroup___10 *memcg;
	struct page___32 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___31 prealloc_pte;
};

struct key_restriction___32;

struct key___32 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___32 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___32 *restrict_link;
};

typedef int (*key_restrict_link_func_t___31)(struct key___32 *, const struct key_type *, const union key_payload *, struct key___32 *);

struct key_restriction___32 {
	key_restrict_link_func_t___31 check;
	struct key___32 *key;
	struct key_type *keytype;
};

struct multiprocess_signals {
	sigset_t signal;
	struct hlist_node node;
};

struct tty_driver___4;

struct tty_operations___3;

struct tty_ldisc___3;

struct tty_port___3;

struct tty_struct___3 {
	int magic;
	struct kref kref;
	struct device___27 *dev;
	struct tty_driver___4 *driver;
	const struct tty_operations___3 *ops;
	int index;
	struct ld_semaphore ldisc_sem;
	struct tty_ldisc___3 *ldisc;
	struct mutex atomic_write_lock;
	struct mutex legacy_mutex;
	struct mutex throttle_mutex;
	struct rw_semaphore___32 termios_rwsem;
	struct mutex winsize_mutex;
	spinlock_t ctrl_lock;
	spinlock_t flow_lock;
	struct ktermios termios;
	struct ktermios termios_locked;
	struct termiox *termiox;
	char name[64];
	struct pid___27 *pgrp;
	struct pid___27 *session;
	long unsigned int flags;
	int count;
	struct winsize winsize;
	long unsigned int stopped: 1;
	long unsigned int flow_stopped: 1;
	int: 30;
	long unsigned int unused: 62;
	int hw_stopped;
	long unsigned int ctrl_status: 8;
	long unsigned int packet: 1;
	int: 23;
	long unsigned int unused_ctrl: 55;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___3 *link;
	struct fasync_struct___31 *fasync;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	spinlock_t files_lock;
	struct list_head tty_files;
	int closing;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___3 *port;
};

typedef int (*proc_visitor)(struct task_struct___33 *, void *);

struct kernfs_root___29;

struct kernfs_elem_dir___29 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___29 *root;
};

struct kernfs_syscall_ops___29;

struct kernfs_root___29 {
	struct kernfs_node___29 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___29 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___29 {
	struct kernfs_node___29 *target_kn;
};

struct kernfs_ops___29;

struct kernfs_elem_attr___29 {
	const struct kernfs_ops___29 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___29 *notify_next;
};

struct kernfs_node___29 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___29 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___29 dir;
		struct kernfs_elem_symlink___29 symlink;
		struct kernfs_elem_attr___29 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___29;

struct kernfs_ops___29 {
	int (*open)(struct kernfs_open_file___29 *);
	void (*release)(struct kernfs_open_file___29 *);
	int (*seq_show)(struct seq_file___29 *, void *);
	void * (*seq_start)(struct seq_file___29 *, loff_t *);
	void * (*seq_next)(struct seq_file___29 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___29 *, void *);
	ssize_t (*read)(struct kernfs_open_file___29 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___29 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___29 *, struct vm_area_struct___32 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___29 *, struct poll_table_struct___18 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___29 {
	int (*remount_fs)(struct kernfs_root___29 *, int *, char *);
	int (*show_options)(struct seq_file___29 *, struct kernfs_root___29 *);
	int (*mkdir)(struct kernfs_node___29 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___29 *);
	int (*rename)(struct kernfs_node___29 *, struct kernfs_node___29 *, const char *);
	int (*show_path)(struct seq_file___29 *, struct kernfs_node___29 *, struct kernfs_root___29 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___26;

struct seq_file___29 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___26 *op;
	int poll_event;
	const struct file___32 *file;
	void *private;
};

struct kernfs_open_file___29 {
	struct kernfs_node___29 *kn;
	struct file___32 *file;
	struct seq_file___29 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___31 *vm_ops;
};

typedef void (*poll_queue_proc___17)(struct file___32 *, wait_queue_head_t *, struct poll_table_struct___18 *);

struct poll_table_struct___18 {
	poll_queue_proc___17 _qproc;
	__poll_t _key;
};

struct bin_attribute___27;

struct attribute_group___27 {
	const char *name;
	umode_t (*is_visible)(struct kobject___30 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___30 *, struct bin_attribute___27 *, int);
	struct attribute **attrs;
	struct bin_attribute___27 **bin_attrs;
};

struct bin_attribute___27 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___32 *, struct kobject___30 *, struct bin_attribute___27 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___32 *, struct kobject___30 *, struct bin_attribute___27 *, char *, loff_t, size_t);
	int (*mmap)(struct file___32 *, struct kobject___30 *, struct bin_attribute___27 *, struct vm_area_struct___32 *);
};

struct sysfs_ops___29 {
	ssize_t (*show)(struct kobject___30 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___30 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___29;

struct kset___29 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___30 kobj;
	const struct kset_uevent_ops___29 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___29 {
	void (*release)(struct kobject___30 *);
	const struct sysfs_ops___29 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___30 *);
	const void * (*namespace)(struct kobject___30 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___29 {
	int (* const filter)(struct kset___29 *, struct kobject___30 *);
	const char * (* const name)(struct kset___29 *, struct kobject___30 *);
	int (* const uevent)(struct kset___29 *, struct kobject___30 *, struct kobj_uevent_env *);
};

struct kobj_attribute___30 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___30 *, struct kobj_attribute___30 *, char *);
	ssize_t (*store)(struct kobject___30 *, struct kobj_attribute___30 *, const char *, size_t);
};

struct kernel_param___26;

struct kernel_param_ops___26 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___26 *);
	int (*get)(char *, const struct kernel_param___26 *);
	void (*free)(void *);
};

struct kparam_array___26;

struct kernel_param___26 {
	const char *name;
	struct module___29 *mod;
	const struct kernel_param_ops___26 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___26 *arr;
	};
};

struct kparam_array___26 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___26 *ops;
	void *elem;
};

struct module_kobject___26 {
	struct kobject___30 kobj;
	struct module___29 *mod;
	struct kobject___30 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___26 {
	struct module___29 *mod;
	struct latch_tree_node node;
};

struct module_layout___26 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___26 mtn;
};

struct module_attribute___26;

struct module___29 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___26 mkobj;
	struct module_attribute___26 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___30 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___26 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___26 core_layout;
	struct module_layout___26 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___12 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___26 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___26 *, struct module_kobject___26 *, char *);
	ssize_t (*store)(struct module_attribute___26 *, struct module_kobject___26 *, const char *, size_t);
	void (*setup)(struct module___29 *, const char *);
	int (*test)(struct module___29 *);
	void (*free)(struct module___29 *);
};

struct trace_event_class___12;

struct trace_event_call___12 {
	struct list_head list;
	struct trace_event_class___12 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___2 *prog_array;
	int (*perf_perm)(struct trace_event_call___12 *, struct perf_event___17 *);
};

struct dentry_operations___31;

struct super_block___32;

struct dentry___33 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___33 *d_parent;
	struct qstr d_name;
	struct inode___34 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___31 *d_op;
	struct super_block___32 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___31;

struct block_device___32;

struct cdev___9;

struct inode___34 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___31 *i_op;
	struct super_block___32 *i_sb;
	struct address_space___31 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___32 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___11 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___32 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___31 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___4 *i_pipe;
		struct block_device___32 *i_bdev;
		struct cdev___9 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___31 {
	int (*d_revalidate)(struct dentry___33 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___33 *, unsigned int);
	int (*d_hash)(const struct dentry___33 *, struct qstr *);
	int (*d_compare)(const struct dentry___33 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___33 *);
	int (*d_init)(struct dentry___33 *);
	void (*d_release)(struct dentry___33 *);
	void (*d_prune)(struct dentry___33 *);
	void (*d_iput)(struct dentry___33 *, struct inode___34 *);
	char * (*d_dname)(struct dentry___33 *, char *, int);
	struct vfsmount___4 * (*d_automount)(struct path___31 *);
	int (*d_manage)(const struct path___31 *, bool);
	struct dentry___33 * (*d_real)(struct dentry___33 *, const struct inode___34 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___31;

struct mem_dqinfo___31 {
	struct quota_format_type___31 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___31;

struct quota_info___31 {
	unsigned int flags;
	struct rw_semaphore___32 dqio_sem;
	struct inode___34 *files[3];
	struct mem_dqinfo___31 info[3];
	const struct quota_format_ops___31 *ops[3];
};

struct rcuwait___31 {
	struct task_struct___33 *task;
};

struct percpu_rw_semaphore___31 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___32 rw_sem;
	struct rcuwait___31 writer;
	int readers_block;
};

struct sb_writers___31 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___31 rw_sem[3];
};

struct shrink_control___10;

struct shrinker___10 {
	long unsigned int (*count_objects)(struct shrinker___10 *, struct shrink_control___10 *);
	long unsigned int (*scan_objects)(struct shrinker___10 *, struct shrink_control___10 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___31;

struct super_operations___31;

struct dquot_operations___31;

struct quotactl_ops___31;

struct super_block___32 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___31 *s_type;
	const struct super_operations___31 *s_op;
	const struct dquot_operations___31 *dq_op;
	const struct quotactl_ops___31 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___33 *s_root;
	struct rw_semaphore___32 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___32 *s_bdev;
	struct backing_dev_info___11 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___31 s_dquot;
	struct sb_writers___31 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___31 *s_d_op;
	int cleancache_poolid;
	struct shrinker___10 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___22 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___4 {
	struct dentry___33 *mnt_root;
	struct super_block___32 *mnt_sb;
	int mnt_flags;
};

struct shrink_control___10 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___10 *memcg;
};

struct io_cq___6 {
	struct request_queue___7 *q;
	struct io_context___6 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

enum {
	IOPRIO_CLASS_NONE = 0,
	IOPRIO_CLASS_RT = 1,
	IOPRIO_CLASS_BE = 2,
	IOPRIO_CLASS_IDLE = 3,
};

struct kiocb___32 {
	struct file___32 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___32 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___32 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___32 *ia_file;
};

struct dquot___31 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___32 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___31 {
	int qf_fmt_id;
	const struct quota_format_ops___31 *qf_ops;
	struct module___29 *qf_owner;
	struct quota_format_type___31 *qf_next;
};

struct quota_format_ops___31 {
	int (*check_quota_file)(struct super_block___32 *, int);
	int (*read_file_info)(struct super_block___32 *, int);
	int (*write_file_info)(struct super_block___32 *, int);
	int (*free_file_info)(struct super_block___32 *, int);
	int (*read_dqblk)(struct dquot___31 *);
	int (*commit_dqblk)(struct dquot___31 *);
	int (*release_dqblk)(struct dquot___31 *);
	int (*get_next_id)(struct super_block___32 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___31 {
	int (*write_dquot)(struct dquot___31 *);
	struct dquot___31 * (*alloc_dquot)(struct super_block___32 *, int);
	void (*destroy_dquot)(struct dquot___31 *);
	int (*acquire_dquot)(struct dquot___31 *);
	int (*release_dquot)(struct dquot___31 *);
	int (*mark_dirty)(struct dquot___31 *);
	int (*write_info)(struct super_block___32 *, int);
	qsize_t * (*get_reserved_space)(struct inode___34 *);
	int (*get_projid)(struct inode___34 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___34 *, qsize_t *);
	int (*get_next_id)(struct super_block___32 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___31 {
	int (*quota_on)(struct super_block___32 *, int, int, const struct path___31 *);
	int (*quota_off)(struct super_block___32 *, int);
	int (*quota_enable)(struct super_block___32 *, unsigned int);
	int (*quota_disable)(struct super_block___32 *, unsigned int);
	int (*quota_sync)(struct super_block___32 *, int);
	int (*set_info)(struct super_block___32 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___32 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___32 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___32 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___32 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___32 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___10;

struct swap_info_struct___8;

struct address_space_operations___31 {
	int (*writepage)(struct page___32 *, struct writeback_control___10 *);
	int (*readpage)(struct file___32 *, struct page___32 *);
	int (*writepages)(struct address_space___31 *, struct writeback_control___10 *);
	int (*set_page_dirty)(struct page___32 *);
	int (*readpages)(struct file___32 *, struct address_space___31 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___32 *, struct address_space___31 *, loff_t, unsigned int, unsigned int, struct page___32 **, void **);
	int (*write_end)(struct file___32 *, struct address_space___31 *, loff_t, unsigned int, unsigned int, struct page___32 *, void *);
	sector_t (*bmap)(struct address_space___31 *, sector_t);
	void (*invalidatepage)(struct page___32 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___32 *, gfp_t);
	void (*freepage)(struct page___32 *);
	ssize_t (*direct_IO)(struct kiocb___32 *, struct iov_iter___12 *);
	int (*migratepage)(struct address_space___31 *, struct page___32 *, struct page___32 *, enum migrate_mode);
	bool (*isolate_page)(struct page___32 *, isolate_mode_t);
	void (*putback_page)(struct page___32 *);
	int (*launder_page)(struct page___32 *);
	int (*is_partially_uptodate)(struct page___32 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___32 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___31 *, struct page___32 *);
	int (*swap_activate)(struct swap_info_struct___8 *, struct file___32 *, sector_t *);
	void (*swap_deactivate)(struct file___32 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___10 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___11 *wb;
	struct inode___34 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___11;

struct iov_iter___12 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___11 *bvec;
		struct pipe_inode_info___4 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct swap_info_struct___8 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___32 *bdev;
	struct file___32 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct hd_struct___6;

struct gendisk___6;

struct block_device___32 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___34 *bd_inode;
	struct super_block___32 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___32 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___6 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___6 *bd_disk;
	struct request_queue___7 *bd_queue;
	struct backing_dev_info___11 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___27 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___27 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___27;

struct bus_type___27;

struct device_driver___27;

struct dev_pm_domain___27;

struct dma_map_ops___6;

struct fwnode_handle___23;

struct class___27;

struct device___27 {
	struct device___27 *parent;
	struct device_private *p;
	struct kobject___30 kobj;
	const char *init_name;
	const struct device_type___27 *type;
	struct mutex mutex;
	struct bus_type___27 *bus;
	struct device_driver___27 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___27 power;
	struct dev_pm_domain___27 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___6 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___23 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___27 *class;
	const struct attribute_group___27 **groups;
	void (*release)(struct device___27 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___6 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___27 __dev;
	struct kobject___30 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___6;

struct block_device_operations___6;

struct gendisk___6 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___6 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___6 *part_tbl;
	struct hd_struct___6 part0;
	const struct block_device_operations___6 *fops;
	struct request_queue___7 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___32 lookup_sem;
	struct kobject___30 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___30 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___9 {
	struct kobject___30 kobj;
	struct module___29 *owner;
	const struct file_operations___32 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___31 {
	struct dentry___33 * (*lookup)(struct inode___34 *, struct dentry___33 *, unsigned int);
	const char * (*get_link)(struct dentry___33 *, struct inode___34 *, struct delayed_call *);
	int (*permission)(struct inode___34 *, int);
	struct posix_acl * (*get_acl)(struct inode___34 *, int);
	int (*readlink)(struct dentry___33 *, char *, int);
	int (*create)(struct inode___34 *, struct dentry___33 *, umode_t, bool);
	int (*link)(struct dentry___33 *, struct inode___34 *, struct dentry___33 *);
	int (*unlink)(struct inode___34 *, struct dentry___33 *);
	int (*symlink)(struct inode___34 *, struct dentry___33 *, const char *);
	int (*mkdir)(struct inode___34 *, struct dentry___33 *, umode_t);
	int (*rmdir)(struct inode___34 *, struct dentry___33 *);
	int (*mknod)(struct inode___34 *, struct dentry___33 *, umode_t, dev_t);
	int (*rename)(struct inode___34 *, struct dentry___33 *, struct inode___34 *, struct dentry___33 *, unsigned int);
	int (*setattr)(struct dentry___33 *, struct iattr___32 *);
	int (*getattr)(const struct path___31 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___33 *, char *, size_t);
	int (*fiemap)(struct inode___34 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___34 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___34 *, struct dentry___33 *, struct file___32 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___34 *, struct dentry___33 *, umode_t);
	int (*set_acl)(struct inode___34 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___31 {
	void (*fl_copy_lock)(struct file_lock___32 *, struct file_lock___32 *);
	void (*fl_release_private)(struct file_lock___32 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___31;

struct file_lock___32 {
	struct file_lock___32 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___32 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___31 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___31 *fl_ops;
	const struct lock_manager_operations___31 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___31 {
	int (*lm_compare_owner)(struct file_lock___32 *, struct file_lock___32 *);
	long unsigned int (*lm_owner_key)(struct file_lock___32 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___32 *);
	int (*lm_grant)(struct file_lock___32 *, int);
	bool (*lm_break)(struct file_lock___32 *);
	int (*lm_change)(struct file_lock___32 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___32 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___31 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___31 *fa_next;
	struct file___32 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___31 {
	const char *name;
	int fs_flags;
	struct dentry___33 * (*mount)(struct file_system_type___31 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___32 *);
	struct module___29 *owner;
	struct file_system_type___31 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___31 {
	struct inode___34 * (*alloc_inode)(struct super_block___32 *);
	void (*destroy_inode)(struct inode___34 *);
	void (*dirty_inode)(struct inode___34 *, int);
	int (*write_inode)(struct inode___34 *, struct writeback_control___10 *);
	int (*drop_inode)(struct inode___34 *);
	void (*evict_inode)(struct inode___34 *);
	void (*put_super)(struct super_block___32 *);
	int (*sync_fs)(struct super_block___32 *, int);
	int (*freeze_super)(struct super_block___32 *);
	int (*freeze_fs)(struct super_block___32 *);
	int (*thaw_super)(struct super_block___32 *);
	int (*unfreeze_fs)(struct super_block___32 *);
	int (*statfs)(struct dentry___33 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___32 *, int *, char *);
	void (*umount_begin)(struct super_block___32 *);
	int (*show_options)(struct seq_file___29 *, struct dentry___33 *);
	int (*show_devname)(struct seq_file___29 *, struct dentry___33 *);
	int (*show_path)(struct seq_file___29 *, struct dentry___33 *);
	int (*show_stats)(struct seq_file___29 *, struct dentry___33 *);
	ssize_t (*quota_read)(struct super_block___32 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___32 *, int, const char *, size_t, loff_t);
	struct dquot___31 ** (*get_dquots)(struct inode___34 *);
	int (*bdev_try_to_free_page)(struct super_block___32 *, struct page___32 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___32 *, struct shrink_control___10 *);
	long int (*free_cached_objects)(struct super_block___32 *, struct shrink_control___10 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___11(struct bio___11 *);

struct bio_vec___11 {
	struct page___32 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___11;

struct bio___11 {
	struct bio___11 *bi_next;
	struct gendisk___6 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___11 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___11 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___11 *bi_io_vec;
	struct bio_set___11 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___11 bi_inline_vecs[0];
};

typedef void compound_page_dtor___31(struct page___32 *);

struct linux_binprm___3 {
	char buf[256];
	struct vm_area_struct___32 *vma;
	long unsigned int vma_pages;
	struct mm_struct___32 *mm;
	long unsigned int p;
	unsigned int called_set_creds: 1;
	unsigned int cap_elevated: 1;
	unsigned int secureexec: 1;
	unsigned int recursion_depth;
	struct file___32 *file;
	struct cred___31 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
};

struct coredump_params___2 {
	union {
		const kernel_siginfo_t *siginfo;
		struct {
			const siginfo_t *siginfo;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	struct pt_regs *regs;
	struct file___32 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
};

struct uts_namespace___6 {
	struct kref kref;
	struct new_utsname name;
	struct user_namespace___22 *user_ns;
	struct ucounts___22 *ucounts;
	struct ns_common___2 ns;
};

struct dst_ops___5 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___5 *);
	struct dst_entry___2 * (*check)(struct dst_entry___2 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___2 *);
	unsigned int (*mtu)(const struct dst_entry___2 *);
	u32 * (*cow_metrics)(struct dst_entry___2 *, long unsigned int);
	void (*destroy)(struct dst_entry___2 *);
	void (*ifdown)(struct dst_entry___2 *, struct net_device *, int);
	struct dst_entry___2 * (*negative_advice)(struct dst_entry___2 *);
	void (*link_failure)(struct sk_buff___4 *);
	void (*update_pmtu)(struct dst_entry___2 *, struct sock *, struct sk_buff___4 *, u32);
	void (*redirect)(struct dst_entry___2 *, struct sock *, struct sk_buff___4 *);
	int (*local_out)(struct net___7 *, struct sock *, struct sk_buff___4 *);
	struct neighbour___2 * (*neigh_lookup)(const struct dst_entry___2 *, struct sk_buff___4 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___2 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___4 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___2 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___5 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct sock *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops *notifier_ops;
	struct fib_notifier_ops *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_xfrm___4 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___5 xfrm4_dst_ops;
	struct dst_ops___5 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct net___7 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___22 *user_ns;
	struct ucounts___22 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___2 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___2 ipv4;
	struct netns_ipv6___4 ipv6;
	struct netns_sctp sctp;
	struct netns_nf nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___2 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock *nfnl;
	struct sock *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___4 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cgroup_namespace___21 {
	refcount_t count;
	struct ns_common___2 ns;
	struct user_namespace___22 *user_ns;
	struct ucounts___22 *ucounts;
	struct css_set___21 *root_cset;
};

struct dev_pm_ops___27 {
	int (*prepare)(struct device___27 *);
	void (*complete)(struct device___27 *);
	int (*suspend)(struct device___27 *);
	int (*resume)(struct device___27 *);
	int (*freeze)(struct device___27 *);
	int (*thaw)(struct device___27 *);
	int (*poweroff)(struct device___27 *);
	int (*restore)(struct device___27 *);
	int (*suspend_late)(struct device___27 *);
	int (*resume_early)(struct device___27 *);
	int (*freeze_late)(struct device___27 *);
	int (*thaw_early)(struct device___27 *);
	int (*poweroff_late)(struct device___27 *);
	int (*restore_early)(struct device___27 *);
	int (*suspend_noirq)(struct device___27 *);
	int (*resume_noirq)(struct device___27 *);
	int (*freeze_noirq)(struct device___27 *);
	int (*thaw_noirq)(struct device___27 *);
	int (*poweroff_noirq)(struct device___27 *);
	int (*restore_noirq)(struct device___27 *);
	int (*runtime_suspend)(struct device___27 *);
	int (*runtime_resume)(struct device___27 *);
	int (*runtime_idle)(struct device___27 *);
};

struct dev_pm_domain___27 {
	struct dev_pm_ops___27 ops;
	void (*detach)(struct device___27 *, bool);
	int (*activate)(struct device___27 *);
	void (*sync)(struct device___27 *);
	void (*dismiss)(struct device___27 *);
};

struct bus_type___27 {
	const char *name;
	const char *dev_name;
	struct device___27 *dev_root;
	const struct attribute_group___27 **bus_groups;
	const struct attribute_group___27 **dev_groups;
	const struct attribute_group___27 **drv_groups;
	int (*match)(struct device___27 *, struct device_driver___27 *);
	int (*uevent)(struct device___27 *, struct kobj_uevent_env *);
	int (*probe)(struct device___27 *);
	int (*remove)(struct device___27 *);
	void (*shutdown)(struct device___27 *);
	int (*online)(struct device___27 *);
	int (*offline)(struct device___27 *);
	int (*suspend)(struct device___27 *, pm_message_t);
	int (*resume)(struct device___27 *);
	int (*num_vf)(struct device___27 *);
	int (*dma_configure)(struct device___27 *);
	const struct dev_pm_ops___27 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___27 {
	const char *name;
	struct bus_type___27 *bus;
	struct module___29 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___27 *);
	int (*remove)(struct device___27 *);
	void (*shutdown)(struct device___27 *);
	int (*suspend)(struct device___27 *, pm_message_t);
	int (*resume)(struct device___27 *);
	const struct attribute_group___27 **groups;
	const struct dev_pm_ops___27 *pm;
	void (*coredump)(struct device___27 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___27 {
	const char *name;
	const struct attribute_group___27 **groups;
	int (*uevent)(struct device___27 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___27 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___27 *);
	const struct dev_pm_ops___27 *pm;
};

struct class___27 {
	const char *name;
	struct module___29 *owner;
	const struct attribute_group___27 **class_groups;
	const struct attribute_group___27 **dev_groups;
	struct kobject___30 *dev_kobj;
	int (*dev_uevent)(struct device___27 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___27 *, umode_t *);
	void (*class_release)(struct class___27 *);
	void (*dev_release)(struct device___27 *);
	int (*shutdown_pre)(struct device___27 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___27 *);
	const struct dev_pm_ops___27 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___6 {
	void * (*alloc)(struct device___27 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___27 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___27 *, struct vm_area_struct___32 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___27 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___27 *, struct page___32 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___27 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___27 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___27 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___27 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___27 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___27 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide55;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___27 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___27 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___27 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___27 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___27 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___27 *, u64);
	u64 (*get_required_mask)(struct device___27 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___23;

struct fwnode_handle___23 {
	struct fwnode_handle___23 *secondary;
	const struct fwnode_operations___23 *ops;
};

struct node___25 {
	struct device___27 dev;
};

struct seq_operations___26 {
	void * (*start)(struct seq_file___29 *, loff_t *);
	void (*stop)(struct seq_file___29 *, void *);
	void * (*next)(struct seq_file___29 *, void *, loff_t *);
	int (*show)(struct seq_file___29 *, void *);
};

struct ucounts___22 {
	struct hlist_node node;
	struct user_namespace___22 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___21;

struct bpf_map_ops___21 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___21 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___21 *, struct file___32 *);
	void (*map_free)(struct bpf_map___21 *);
	int (*map_get_next_key)(struct bpf_map___21 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___21 *);
	void * (*map_lookup_elem)(struct bpf_map___21 *, void *);
	int (*map_update_elem)(struct bpf_map___21 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___21 *, void *);
	int (*map_push_elem)(struct bpf_map___21 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___21 *, void *);
	int (*map_peek_elem)(struct bpf_map___21 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___21 *, struct file___32 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___21 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___21 *, void *, struct seq_file___29 *);
	int (*map_check_btf)(const struct bpf_map___21 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___21 {
	const struct bpf_map_ops___21 *ops;
	struct bpf_map___21 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___31 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___21;

typedef void (*kthread_work_func_t___21)(struct kthread_work___21 *);

struct kthread_worker___21;

struct kthread_work___21 {
	struct list_head node;
	kthread_work_func_t___21 func;
	struct kthread_worker___21 *worker;
	int canceling;
};

struct kthread_worker___21 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___33 *task;
	struct kthread_work___21 *current_work;
};

struct kthread_delayed_work___21 {
	struct kthread_work___21 work;
	struct timer_list timer;
};

struct psi_group___21 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___21 *poll_kworker;
	struct kthread_delayed_work___21 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___21;

struct cgroup_rstat_cpu___21;

struct cgroup___21 {
	struct cgroup_subsys_state___21 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___29 *kn;
	struct cgroup_file___21 procs_file;
	struct cgroup_file___21 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___21 *subsys[13];
	struct cgroup_root___21 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___21 *dom_cgrp;
	struct cgroup_rstat_cpu___21 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___2 bpf;
	atomic_t congestion_count;
	struct cgroup___21 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___21 psi;
	int ancestor_ids[0];
};

struct cftype___21;

struct cgroup_subsys___21 {
	struct cgroup_subsys_state___21 * (*css_alloc)(struct cgroup_subsys_state___21 *);
	int (*css_online)(struct cgroup_subsys_state___21 *);
	void (*css_offline)(struct cgroup_subsys_state___21 *);
	void (*css_released)(struct cgroup_subsys_state___21 *);
	void (*css_free)(struct cgroup_subsys_state___21 *);
	void (*css_reset)(struct cgroup_subsys_state___21 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___21 *, int);
	int (*css_extra_stat_show)(struct seq_file___29 *, struct cgroup_subsys_state___21 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___33 *);
	void (*cancel_fork)(struct task_struct___33 *);
	void (*fork)(struct task_struct___33 *);
	void (*exit)(struct task_struct___33 *);
	void (*free)(struct task_struct___33 *);
	void (*bind)(struct cgroup_subsys_state___21 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___21 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___21 *dfl_cftypes;
	struct cftype___21 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___21 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___21 *updated_children;
	struct cgroup___21 *updated_next;
};

struct cgroup_root___21 {
	struct kernfs_root___29 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___21 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___21 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___21 *ss;
	struct list_head node;
	struct kernfs_ops___29 *kf_ops;
	int (*open)(struct kernfs_open_file___29 *);
	void (*release)(struct kernfs_open_file___29 *);
	u64 (*read_u64)(struct cgroup_subsys_state___21 *, struct cftype___21 *);
	s64 (*read_s64)(struct cgroup_subsys_state___21 *, struct cftype___21 *);
	int (*seq_show)(struct seq_file___29 *, void *);
	void * (*seq_start)(struct seq_file___29 *, loff_t *);
	void * (*seq_next)(struct seq_file___29 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___29 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___21 *, struct cftype___21 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___21 *, struct cftype___21 *, s64);
	ssize_t (*write)(struct kernfs_open_file___29 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___29 *, struct poll_table_struct___18 *);
};

struct hstate___6 {
	int next_nid_to_alloc;
	int next_nid_to_free;
	unsigned int order;
	long unsigned int mask;
	long unsigned int max_huge_pages;
	long unsigned int nr_huge_pages;
	long unsigned int free_huge_pages;
	long unsigned int resv_huge_pages;
	long unsigned int surplus_huge_pages;
	long unsigned int nr_overcommit_huge_pages;
	struct list_head hugepage_activelist;
	struct list_head hugepage_freelists[8];
	unsigned int nr_huge_pages_node[8];
	unsigned int free_huge_pages_node[8];
	unsigned int surplus_huge_pages_node[8];
	struct cftype___21 cgroup_files[5];
	char name[32];
};

struct bdi_writeback_congested___11 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___11 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___11 {
	struct bio___11 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___11 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___11 bip_inline_vecs[0];
};

struct mem_cgroup_reclaim_iter___10 {
	struct mem_cgroup___10 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___10 {
	struct lruvec___31 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___10 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___10 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct perf_cpu_context___17;

struct pmu___17 {
	struct list_head entry;
	struct module___29 *module;
	struct device___27 *dev;
	const struct attribute_group___27 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___17 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___17 *);
	void (*pmu_disable)(struct pmu___17 *);
	int (*event_init)(struct perf_event___17 *);
	void (*event_mapped)(struct perf_event___17 *, struct mm_struct___32 *);
	void (*event_unmapped)(struct perf_event___17 *, struct mm_struct___32 *);
	int (*add)(struct perf_event___17 *, int);
	void (*del)(struct perf_event___17 *, int);
	void (*start)(struct perf_event___17 *, int);
	void (*stop)(struct perf_event___17 *, int);
	void (*read)(struct perf_event___17 *);
	void (*start_txn)(struct pmu___17 *, unsigned int);
	int (*commit_txn)(struct pmu___17 *);
	void (*cancel_txn)(struct pmu___17 *);
	int (*event_idx)(struct perf_event___17 *);
	void (*sched_task)(struct perf_event_context___17 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___17 *);
	int (*filter_match)(struct perf_event___17 *);
	int (*check_period)(struct perf_event___17 *, u64);
};

struct perf_cpu_context___17 {
	struct perf_event_context___17 ctx;
	struct perf_event_context___17 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___17 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___17 {
	struct cgroup_subsys_state___21 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___12 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___12 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___12 *);
	struct list_head * (*get_fields)(struct trace_event_call___12 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___12 *);
};

struct trace_event_file___6;

struct trace_event_buffer___6 {
	struct ring_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___6 *trace_file;
	void *entry;
	long unsigned int flags;
	int pc;
};

struct trace_event_file___6 {
	struct list_head list;
	struct trace_event_call___12 *event_call;
	struct event_filter *filter;
	struct dentry___33 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct syscall_metadata___3 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___12 *enter_event;
	struct trace_event_call___12 *exit_event;
};

struct tty_operations___3 {
	struct tty_struct___3 * (*lookup)(struct tty_driver___4 *, struct file___32 *, int);
	int (*install)(struct tty_driver___4 *, struct tty_struct___3 *);
	void (*remove)(struct tty_driver___4 *, struct tty_struct___3 *);
	int (*open)(struct tty_struct___3 *, struct file___32 *);
	void (*close)(struct tty_struct___3 *, struct file___32 *);
	void (*shutdown)(struct tty_struct___3 *);
	void (*cleanup)(struct tty_struct___3 *);
	int (*write)(struct tty_struct___3 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___3 *, unsigned char);
	void (*flush_chars)(struct tty_struct___3 *);
	int (*write_room)(struct tty_struct___3 *);
	int (*chars_in_buffer)(struct tty_struct___3 *);
	int (*ioctl)(struct tty_struct___3 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___3 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___3 *, struct ktermios *);
	void (*throttle)(struct tty_struct___3 *);
	void (*unthrottle)(struct tty_struct___3 *);
	void (*stop)(struct tty_struct___3 *);
	void (*start)(struct tty_struct___3 *);
	void (*hangup)(struct tty_struct___3 *);
	int (*break_ctl)(struct tty_struct___3 *, int);
	void (*flush_buffer)(struct tty_struct___3 *);
	void (*set_ldisc)(struct tty_struct___3 *);
	void (*wait_until_sent)(struct tty_struct___3 *, int);
	void (*send_xchar)(struct tty_struct___3 *, char);
	int (*tiocmget)(struct tty_struct___3 *);
	int (*tiocmset)(struct tty_struct___3 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___3 *, struct winsize *);
	int (*set_termiox)(struct tty_struct___3 *, struct termiox *);
	int (*get_icount)(struct tty_struct___3 *, struct serial_icounter_struct *);
	void (*show_fdinfo)(struct tty_struct___3 *, struct seq_file___29 *);
	int (*poll_init)(struct tty_driver___4 *, int, char *);
	int (*poll_get_char)(struct tty_driver___4 *, int);
	void (*poll_put_char)(struct tty_driver___4 *, int, char);
	int (*proc_show)(struct seq_file___29 *, void *);
};

struct tty_driver___4 {
	int magic;
	struct kref kref;
	struct cdev___9 **cdevs;
	struct module___29 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___4 *other;
	struct tty_struct___3 **ttys;
	struct tty_port___3 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___3 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___3;

struct tty_port_client_operations___3;

struct tty_port___3 {
	struct tty_bufhead buf;
	struct tty_struct___3 *tty;
	struct tty_struct___3 *itty;
	const struct tty_port_operations___3 *ops;
	const struct tty_port_client_operations___3 *client_ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	unsigned char low_latency: 1;
	struct mutex mutex;
	struct mutex buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
	void *client_data;
};

struct tty_ldisc_ops___3 {
	int magic;
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___3 *);
	void (*close)(struct tty_struct___3 *);
	void (*flush_buffer)(struct tty_struct___3 *);
	ssize_t (*read)(struct tty_struct___3 *, struct file___32 *, unsigned char *, size_t);
	ssize_t (*write)(struct tty_struct___3 *, struct file___32 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___3 *, struct file___32 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___3 *, struct file___32 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___3 *, struct ktermios *);
	__poll_t (*poll)(struct tty_struct___3 *, struct file___32 *, struct poll_table_struct___18 *);
	int (*hangup)(struct tty_struct___3 *);
	void (*receive_buf)(struct tty_struct___3 *, const unsigned char *, char *, int);
	void (*write_wakeup)(struct tty_struct___3 *);
	void (*dcd_change)(struct tty_struct___3 *, unsigned int);
	int (*receive_buf2)(struct tty_struct___3 *, const unsigned char *, char *, int);
	struct module___29 *owner;
	int refcount;
};

struct tty_ldisc___3 {
	struct tty_ldisc_ops___3 *ops;
	struct tty_struct___3 *tty;
};

struct tty_port_operations___3 {
	int (*carrier_raised)(struct tty_port___3 *);
	void (*dtr_rts)(struct tty_port___3 *, int);
	void (*shutdown)(struct tty_port___3 *);
	int (*activate)(struct tty_port___3 *, struct tty_struct___3 *);
	void (*destruct)(struct tty_port___3 *);
};

struct tty_port_client_operations___3 {
	int (*receive_buf)(struct tty_port___3 *, const unsigned char *, const unsigned char *, size_t);
	void (*write_wakeup)(struct tty_port___3 *);
};

struct disk_part_tbl___6 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___6 *last_lookup;
	struct hd_struct___6 *part[0];
};

struct block_device_operations___6 {
	int (*open)(struct block_device___32 *, fmode_t);
	void (*release)(struct gendisk___6 *, fmode_t);
	int (*rw_page)(struct block_device___32 *, sector_t, struct page___32 *, unsigned int);
	int (*ioctl)(struct block_device___32 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___32 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___6 *, unsigned int);
	int (*media_changed)(struct gendisk___6 *);
	void (*unlock_native_capacity)(struct gendisk___6 *);
	int (*revalidate_disk)(struct gendisk___6 *);
	int (*getgeo)(struct block_device___32 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___32 *, long unsigned int);
	int (*report_zones)(struct gendisk___6 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___29 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___6 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___7 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___7 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___7 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___6(struct request___7 *, blk_status_t);

struct request___7 {
	struct request_queue___7 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___11 *bio;
	struct bio___11 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___11 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___6 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___6 *saved_end_io;
		} flush;
	};
	struct gendisk___6 *rq_disk;
	struct hd_struct___6 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___6 *end_io;
	void *end_io_data;
	struct request___7 *next_rq;
};

struct fwnode_reference_args___23;

struct fwnode_endpoint___23;

struct fwnode_operations___23 {
	struct fwnode_handle___23 * (*get)(struct fwnode_handle___23 *);
	void (*put)(struct fwnode_handle___23 *);
	bool (*device_is_available)(const struct fwnode_handle___23 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___23 *, const struct device___27 *);
	bool (*property_present)(const struct fwnode_handle___23 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___23 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___23 *, const char *, const char **, size_t);
	struct fwnode_handle___23 * (*get_parent)(const struct fwnode_handle___23 *);
	struct fwnode_handle___23 * (*get_next_child_node)(const struct fwnode_handle___23 *, struct fwnode_handle___23 *);
	struct fwnode_handle___23 * (*get_named_child_node)(const struct fwnode_handle___23 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___23 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___23 *);
	struct fwnode_handle___23 * (*graph_get_next_endpoint)(const struct fwnode_handle___23 *, struct fwnode_handle___23 *);
	struct fwnode_handle___23 * (*graph_get_remote_endpoint)(const struct fwnode_handle___23 *);
	struct fwnode_handle___23 * (*graph_get_port_parent)(struct fwnode_handle___23 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___23 *, struct fwnode_endpoint___23 *);
};

struct fwnode_endpoint___23 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___23 *local_fwnode;
};

struct fwnode_reference_args___23 {
	struct fwnode_handle___23 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct elevator_type___6;

struct elevator_mq_ops___6 {
	int (*init_sched)(struct request_queue___7 *, struct elevator_type___6 *);
	void (*exit_sched)(struct elevator_queue___6 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	bool (*allow_merge)(struct request_queue___7 *, struct request___7 *, struct bio___11 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx *, struct bio___11 *);
	int (*request_merge)(struct request_queue___7 *, struct request___7 **, struct bio___11 *);
	void (*request_merged)(struct request_queue___7 *, struct request___7 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___7 *, struct request___7 *, struct request___7 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___7 *, struct bio___11 *);
	void (*finish_request)(struct request___7 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___7 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___7 *, u64);
	void (*started_request)(struct request___7 *);
	void (*requeue_request)(struct request___7 *);
	struct request___7 * (*former_request)(struct request_queue___7 *, struct request___7 *);
	struct request___7 * (*next_request)(struct request_queue___7 *, struct request___7 *);
	void (*init_icq)(struct io_cq___6 *);
	void (*exit_icq)(struct io_cq___6 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide37;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___6;

struct elevator_type___6 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___6 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___6 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___29 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___6 {
	struct elevator_type___6 *type;
	void *elevator_data;
	struct kobject___30 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___6 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___6 *, char *);
	ssize_t (*store)(struct elevator_queue___6 *, const char *, size_t);
};

struct trace_event_raw_task_newtask {
	struct trace_entry ent;
	pid_t pid;
	char comm[16];
	long unsigned int clone_flags;
	short int oom_score_adj;
	char __data[0];
};

struct trace_event_raw_task_rename {
	struct trace_entry ent;
	pid_t pid;
	char oldcomm[16];
	char newcomm[16];
	short int oom_score_adj;
	char __data[0];
};

struct trace_event_data_offsets_task_newtask {};

struct trace_event_data_offsets_task_rename {};

struct pipe_buf_operations___4;

struct pipe_buffer___4 {
	struct page___32 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___4 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___4 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___4 *, struct pipe_buffer___4 *);
	void (*release)(struct pipe_inode_info___4 *, struct pipe_buffer___4 *);
	int (*steal)(struct pipe_inode_info___4 *, struct pipe_buffer___4 *);
	union {
		bool (*get)(struct pipe_inode_info___4 *, struct pipe_buffer___4 *);
		struct {
			void (*get)(struct pipe_inode_info___4 *, struct pipe_buffer___4 *);
		} __UNIQUE_ID_rh_kabi_hide58;
		union {		};
	};
};

struct module___30;

struct file___33;

struct kiocb___33;

struct poll_table_struct___19;

struct vm_area_struct___33;

struct inode___35;

struct file_lock___33;

struct page___33;

struct seq_file___30;

struct file_operations___33 {
	struct module___30 *owner;
	loff_t (*llseek)(struct file___33 *, loff_t, int);
	ssize_t (*read)(struct file___33 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___33 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___33 *, struct iov_iter___12 *);
	ssize_t (*write_iter)(struct kiocb___33 *, struct iov_iter___12 *);
	int (*iopoll)(struct kiocb___33 *, bool);
	int (*iterate)(struct file___33 *, struct dir_context *);
	int (*iterate_shared)(struct file___33 *, struct dir_context *);
	__poll_t (*poll)(struct file___33 *, struct poll_table_struct___19 *);
	long int (*unlocked_ioctl)(struct file___33 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___33 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___33 *, struct vm_area_struct___33 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___35 *, struct file___33 *);
	int (*flush)(struct file___33 *, fl_owner_t);
	int (*release)(struct inode___35 *, struct file___33 *);
	int (*fsync)(struct file___33 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___33 *, int);
	int (*lock)(struct file___33 *, int, struct file_lock___33 *);
	ssize_t (*sendpage)(struct file___33 *, struct page___33 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___33 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___33 *, int, struct file_lock___33 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___33 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___33 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___33 *, long int, struct file_lock___33 **, void **);
	long int (*fallocate)(struct file___33 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___30 *, struct file___33 *);
	ssize_t (*copy_file_range)(struct file___33 *, loff_t, struct file___33 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___33 *, loff_t, struct file___33 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___33 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___32 {
	u64 seqnum;
	struct vm_area_struct___33 *vmas[4];
};

struct page_frag___32 {
	struct page___33 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___18;

struct debug_info___18 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___18 *hbp_break[16];
	struct perf_event___18 *hbp_watch[16];
};

struct thread_struct___18 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___18 debug;
	long: 64;
};

struct mm_struct___33;

struct pid___28;

struct cred___32;

struct nsproxy___31;

struct signal_struct___30;

struct css_set___22;

struct perf_event_context___18;

struct task_struct___34 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___34 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___33 *mm;
	struct mm_struct___33 *active_mm;
	struct vmacache___32 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___34 *real_parent;
	struct task_struct___34 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___34 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___28 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___28 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___28 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___32 *ptracer_cred;
	const struct cred___32 *real_cred;
	const struct cred___32 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___31 *nsproxy;
	struct signal_struct___30 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___34 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___6 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___22 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___18 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___32 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___34 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___18 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___18 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___34 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___18)(struct perf_event___18 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___18;

struct fasync_struct___32;

struct pid_namespace___28;

struct trace_event_call___13;

struct perf_cgroup___18;

struct perf_event___18 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___18 *group_leader;
	struct pmu___18 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___18 hw;
	struct perf_event_context___18 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___18 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___34 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___32 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___18 *);
	struct callback_head callback_head;
	struct pid_namespace___28 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___18 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___18 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___13 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___18 *cgrp;
	struct list_head sb_list;
};

typedef struct page___33 *pgtable_t___32;

struct address_space___32;

struct dev_pagemap___32;

struct page___33 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___32 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___33 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___32 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___33 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___32 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___32;

struct lruvec___32 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___32 *pgdat;
};

struct zone___32 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___32 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___32 {
	struct zone___32 *zone;
	int zone_idx;
};

struct zonelist___32 {
	struct zoneref___32 _zonerefs[25];
};

struct pglist_data___32 {
	struct zone___32 node_zones[3];
	struct zonelist___32 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___34 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___34 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___32 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___33 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___34 *owner;
};

struct secondary_data___33 {
	void *stack;
	struct task_struct___34 *task;
	long int status;
};

struct blocking_notifier_head___32 {
	struct rw_semaphore___33 rwsem;
	struct notifier_block *head;
};

struct key___33;

struct ucounts___23;

struct user_namespace___23 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___23 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___2 ns;
	long unsigned int flags;
	struct key___33 *persistent_keyring_register;
	struct rw_semaphore___33 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___23 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dentry___34;

struct path___32 {
	struct vfsmount *mnt;
	struct dentry___34 *dentry;
};

struct fown_struct___28 {
	rwlock_t lock;
	struct pid___28 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___33 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___32 f_path;
	struct inode___35 *f_inode;
	const struct file_operations___33 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___28 f_owner;
	const struct cred___32 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___32 *f_mapping;
	errseq_t f_wb_err;
};

struct user_struct___32;

struct cred___32 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___33 *session_keyring;
	struct key___33 *process_keyring;
	struct key___33 *thread_keyring;
	struct key___33 *request_key_auth;
	void *security;
	struct user_struct___32 *user;
	struct user_namespace___23 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___30;

struct kernfs_elem_dir___30 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___30 *root;
};

struct kernfs_node___30;

struct kernfs_syscall_ops___30;

struct kernfs_root___30 {
	struct kernfs_node___30 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___30 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___30 {
	struct kernfs_node___30 *target_kn;
};

struct kernfs_ops___30;

struct kernfs_elem_attr___30 {
	const struct kernfs_ops___30 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___30 *notify_next;
};

struct kernfs_node___30 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___30 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___30 dir;
		struct kernfs_elem_symlink___30 symlink;
		struct kernfs_elem_attr___30 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___30;

struct kernfs_ops___30 {
	int (*open)(struct kernfs_open_file___30 *);
	void (*release)(struct kernfs_open_file___30 *);
	int (*seq_show)(struct seq_file___30 *, void *);
	void * (*seq_start)(struct seq_file___30 *, loff_t *);
	void * (*seq_next)(struct seq_file___30 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___30 *, void *);
	ssize_t (*read)(struct kernfs_open_file___30 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___30 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___30 *, struct vm_area_struct___33 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___30 *, struct poll_table_struct___19 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___30 {
	int (*remount_fs)(struct kernfs_root___30 *, int *, char *);
	int (*show_options)(struct seq_file___30 *, struct kernfs_root___30 *);
	int (*mkdir)(struct kernfs_node___30 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___30 *);
	int (*rename)(struct kernfs_node___30 *, struct kernfs_node___30 *, const char *);
	int (*show_path)(struct seq_file___30 *, struct kernfs_node___30 *, struct kernfs_root___30 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___27;

struct seq_file___30 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___27 *op;
	int poll_event;
	const struct file___33 *file;
	void *private;
};

struct vm_operations_struct___32;

struct kernfs_open_file___30 {
	struct kernfs_node___30 *kn;
	struct file___33 *file;
	struct seq_file___30 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___32 *vm_ops;
};

struct vm_fault___32;

struct vm_operations_struct___32 {
	void (*open)(struct vm_area_struct___33 *);
	void (*close)(struct vm_area_struct___33 *);
	int (*split)(struct vm_area_struct___33 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___33 *);
	vm_fault_t (*fault)(struct vm_fault___32 *);
	vm_fault_t (*huge_fault)(struct vm_fault___32 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___32 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___33 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___32 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___32 *);
	int (*access)(struct vm_area_struct___33 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___33 *);
	int (*set_policy)(struct vm_area_struct___33 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___33 *, long unsigned int);
	struct page___33 * (*find_special_page)(struct vm_area_struct___33 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___18)(struct file___33 *, wait_queue_head_t *, struct poll_table_struct___19 *);

struct poll_table_struct___19 {
	poll_queue_proc___18 _qproc;
	__poll_t _key;
};

struct vm_area_struct___33 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___33 *vm_next;
	struct vm_area_struct___33 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___33 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___32 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___33 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___31;

struct bin_attribute___28;

struct attribute_group___28 {
	const char *name;
	umode_t (*is_visible)(struct kobject___31 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___31 *, struct bin_attribute___28 *, int);
	struct attribute **attrs;
	struct bin_attribute___28 **bin_attrs;
};

struct kset___30;

struct kobj_type___30;

struct kobject___31 {
	const char *name;
	struct list_head entry;
	struct kobject___31 *parent;
	struct kset___30 *kset;
	struct kobj_type___30 *ktype;
	struct kernfs_node___30 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___28 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___33 *, struct kobject___31 *, struct bin_attribute___28 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___33 *, struct kobject___31 *, struct bin_attribute___28 *, char *, loff_t, size_t);
	int (*mmap)(struct file___33 *, struct kobject___31 *, struct bin_attribute___28 *, struct vm_area_struct___33 *);
};

struct sysfs_ops___30 {
	ssize_t (*show)(struct kobject___31 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___31 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___30;

struct kset___30 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___31 kobj;
	const struct kset_uevent_ops___30 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___30 {
	void (*release)(struct kobject___31 *);
	const struct sysfs_ops___30 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___31 *);
	const void * (*namespace)(struct kobject___31 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___30 {
	int (* const filter)(struct kset___30 *, struct kobject___31 *);
	const char * (* const name)(struct kset___30 *, struct kobject___31 *);
	int (* const uevent)(struct kset___30 *, struct kobject___31 *, struct kobj_uevent_env *);
};

struct kobj_attribute___31 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___31 *, struct kobj_attribute___31 *, char *);
	ssize_t (*store)(struct kobject___31 *, struct kobj_attribute___31 *, const char *, size_t);
};

struct kernel_param___27;

struct kernel_param_ops___27 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___27 *);
	int (*get)(char *, const struct kernel_param___27 *);
	void (*free)(void *);
};

struct kparam_array___27;

struct kernel_param___27 {
	const char *name;
	struct module___30 *mod;
	const struct kernel_param_ops___27 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___27 *arr;
	};
};

struct kparam_array___27 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___27 *ops;
	void *elem;
};

struct module_kobject___27 {
	struct kobject___31 kobj;
	struct module___30 *mod;
	struct kobject___31 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___27 {
	struct module___30 *mod;
	struct latch_tree_node node;
};

struct module_layout___27 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___27 mtn;
};

struct module_attribute___27;

struct module___30 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___27 mkobj;
	struct module_attribute___27 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___31 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___27 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___27 core_layout;
	struct module_layout___27 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___13 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___27 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___27 *, struct module_kobject___27 *, char *);
	ssize_t (*store)(struct module_attribute___27 *, struct module_kobject___27 *, const char *, size_t);
	void (*setup)(struct module___30 *, const char *);
	int (*test)(struct module___30 *);
	void (*free)(struct module___30 *);
};

struct trace_event_class___13;

struct trace_event_call___13 {
	struct list_head list;
	struct trace_event_class___13 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___2 *prog_array;
	int (*perf_perm)(struct trace_event_call___13 *, struct perf_event___18 *);
};

struct dentry_operations___32;

struct super_block___33;

struct dentry___34 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___34 *d_parent;
	struct qstr d_name;
	struct inode___35 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___32 *d_op;
	struct super_block___33 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___32;

struct address_space___32 {
	struct inode___35 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___33 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___32 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___32;

struct block_device___33;

struct inode___35 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___32 *i_op;
	struct super_block___33 *i_sb;
	struct address_space___32 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___33 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___33 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___32 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___33 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___32 {
	int (*d_revalidate)(struct dentry___34 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___34 *, unsigned int);
	int (*d_hash)(const struct dentry___34 *, struct qstr *);
	int (*d_compare)(const struct dentry___34 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___34 *);
	int (*d_init)(struct dentry___34 *);
	void (*d_release)(struct dentry___34 *);
	void (*d_prune)(struct dentry___34 *);
	void (*d_iput)(struct dentry___34 *, struct inode___35 *);
	char * (*d_dname)(struct dentry___34 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___32 *);
	int (*d_manage)(const struct path___32 *, bool);
	struct dentry___34 * (*d_real)(struct dentry___34 *, const struct inode___35 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___32;

struct mem_dqinfo___32 {
	struct quota_format_type___32 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___32;

struct quota_info___32 {
	unsigned int flags;
	struct rw_semaphore___33 dqio_sem;
	struct inode___35 *files[3];
	struct mem_dqinfo___32 info[3];
	const struct quota_format_ops___32 *ops[3];
};

struct rcuwait___32 {
	struct task_struct___34 *task;
};

struct percpu_rw_semaphore___32 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___33 rw_sem;
	struct rcuwait___32 writer;
	int readers_block;
};

struct sb_writers___32 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___32 rw_sem[3];
};

struct file_system_type___32;

struct super_operations___32;

struct dquot_operations___32;

struct quotactl_ops___32;

struct super_block___33 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___32 *s_type;
	const struct super_operations___32 *s_op;
	const struct dquot_operations___32 *dq_op;
	const struct quotactl_ops___32 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___34 *s_root;
	struct rw_semaphore___33 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___33 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___32 s_dquot;
	struct sb_writers___32 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___32 *s_d_op;
	int cleancache_poolid;
	struct shrinker___10 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___23 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct upid___28 {
	int nr;
	struct pid_namespace___28 *ns;
};

struct pid_namespace___28 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___34 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___28 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___34 *proc_self;
	struct dentry___34 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___23 *user_ns;
	struct ucounts___23 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___2 ns;
};

struct pid___28 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___28 numbers[1];
};

struct core_state___32;

struct mm_struct___33 {
	struct {
		struct vm_area_struct___33 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___33 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___33 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___32 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___34 *owner;
		struct user_namespace___23 *user_ns;
		struct file___33 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___32 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___32)(struct vm_area_struct___33 *, long unsigned int, const struct page___33 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___32)(struct page___33 *, void *);

struct device___28;

struct dev_pagemap___32 {
	dev_page_fault_t___32 page_fault;
	dev_page_free_t___32 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___28 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___32 {
	struct task_struct___34 *task;
	struct core_thread___32 *next;
};

struct core_state___32 {
	atomic_t nr_threads;
	struct core_thread___32 dumper;
	struct completion startup;
};

struct vm_fault___32 {
	struct vm_area_struct___33 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___33 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___33 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___32 prealloc_pte;
};

struct user_struct___32 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___33 *uid_keyring;
	struct key___33 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cgroup_namespace___22;

struct nsproxy___31 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___28 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___22 *cgroup_ns;
};

struct signal_struct___30 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___34 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___34 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___28 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___28 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___33 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___28 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___22;

struct cgroup___22;

struct css_set___22 {
	struct cgroup_subsys_state___22 *subsys[13];
	refcount_t refcount;
	struct css_set___22 *dom_cset;
	struct cgroup___22 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___22 *mg_src_cgrp;
	struct cgroup___22 *mg_dst_cgrp;
	struct css_set___22 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___18 {
	struct pmu___18 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___34 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___18 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

union thread_union___30 {
	struct task_struct___34 task;
	long unsigned int stack[8192];
};

struct kiocb___33 {
	struct file___33 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___33 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___33 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___33 *ia_file;
};

struct dquot___32 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___33 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___32 {
	int qf_fmt_id;
	const struct quota_format_ops___32 *qf_ops;
	struct module___30 *qf_owner;
	struct quota_format_type___32 *qf_next;
};

struct quota_format_ops___32 {
	int (*check_quota_file)(struct super_block___33 *, int);
	int (*read_file_info)(struct super_block___33 *, int);
	int (*write_file_info)(struct super_block___33 *, int);
	int (*free_file_info)(struct super_block___33 *, int);
	int (*read_dqblk)(struct dquot___32 *);
	int (*commit_dqblk)(struct dquot___32 *);
	int (*release_dqblk)(struct dquot___32 *);
	int (*get_next_id)(struct super_block___33 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___32 {
	int (*write_dquot)(struct dquot___32 *);
	struct dquot___32 * (*alloc_dquot)(struct super_block___33 *, int);
	void (*destroy_dquot)(struct dquot___32 *);
	int (*acquire_dquot)(struct dquot___32 *);
	int (*release_dquot)(struct dquot___32 *);
	int (*mark_dirty)(struct dquot___32 *);
	int (*write_info)(struct super_block___33 *, int);
	qsize_t * (*get_reserved_space)(struct inode___35 *);
	int (*get_projid)(struct inode___35 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___35 *, qsize_t *);
	int (*get_next_id)(struct super_block___33 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___32 {
	int (*quota_on)(struct super_block___33 *, int, int, const struct path___32 *);
	int (*quota_off)(struct super_block___33 *, int);
	int (*quota_enable)(struct super_block___33 *, unsigned int);
	int (*quota_disable)(struct super_block___33 *, unsigned int);
	int (*quota_sync)(struct super_block___33 *, int);
	int (*set_info)(struct super_block___33 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___33 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___33 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___33 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___33 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___33 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___32 {
	int (*writepage)(struct page___33 *, struct writeback_control___3 *);
	int (*readpage)(struct file___33 *, struct page___33 *);
	int (*writepages)(struct address_space___32 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___33 *);
	int (*readpages)(struct file___33 *, struct address_space___32 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___33 *, struct address_space___32 *, loff_t, unsigned int, unsigned int, struct page___33 **, void **);
	int (*write_end)(struct file___33 *, struct address_space___32 *, loff_t, unsigned int, unsigned int, struct page___33 *, void *);
	sector_t (*bmap)(struct address_space___32 *, sector_t);
	void (*invalidatepage)(struct page___33 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___33 *, gfp_t);
	void (*freepage)(struct page___33 *);
	ssize_t (*direct_IO)(struct kiocb___33 *, struct iov_iter___12 *);
	int (*migratepage)(struct address_space___32 *, struct page___33 *, struct page___33 *, enum migrate_mode);
	bool (*isolate_page)(struct page___33 *, isolate_mode_t);
	void (*putback_page)(struct page___33 *);
	int (*launder_page)(struct page___33 *);
	int (*is_partially_uptodate)(struct page___33 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___33 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___32 *, struct page___33 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___33 *, sector_t *);
	void (*swap_deactivate)(struct file___33 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___33 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___35 *bd_inode;
	struct super_block___33 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___33 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___32 {
	struct dentry___34 * (*lookup)(struct inode___35 *, struct dentry___34 *, unsigned int);
	const char * (*get_link)(struct dentry___34 *, struct inode___35 *, struct delayed_call *);
	int (*permission)(struct inode___35 *, int);
	struct posix_acl * (*get_acl)(struct inode___35 *, int);
	int (*readlink)(struct dentry___34 *, char *, int);
	int (*create)(struct inode___35 *, struct dentry___34 *, umode_t, bool);
	int (*link)(struct dentry___34 *, struct inode___35 *, struct dentry___34 *);
	int (*unlink)(struct inode___35 *, struct dentry___34 *);
	int (*symlink)(struct inode___35 *, struct dentry___34 *, const char *);
	int (*mkdir)(struct inode___35 *, struct dentry___34 *, umode_t);
	int (*rmdir)(struct inode___35 *, struct dentry___34 *);
	int (*mknod)(struct inode___35 *, struct dentry___34 *, umode_t, dev_t);
	int (*rename)(struct inode___35 *, struct dentry___34 *, struct inode___35 *, struct dentry___34 *, unsigned int);
	int (*setattr)(struct dentry___34 *, struct iattr___33 *);
	int (*getattr)(const struct path___32 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___34 *, char *, size_t);
	int (*fiemap)(struct inode___35 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___35 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___35 *, struct dentry___34 *, struct file___33 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___35 *, struct dentry___34 *, umode_t);
	int (*set_acl)(struct inode___35 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___32 {
	void (*fl_copy_lock)(struct file_lock___33 *, struct file_lock___33 *);
	void (*fl_release_private)(struct file_lock___33 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___32;

struct file_lock___33 {
	struct file_lock___33 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___33 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___32 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___32 *fl_ops;
	const struct lock_manager_operations___32 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___32 {
	int (*lm_compare_owner)(struct file_lock___33 *, struct file_lock___33 *);
	long unsigned int (*lm_owner_key)(struct file_lock___33 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___33 *);
	int (*lm_grant)(struct file_lock___33 *, int);
	bool (*lm_break)(struct file_lock___33 *);
	int (*lm_change)(struct file_lock___33 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___33 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___32 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___32 *fa_next;
	struct file___33 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___32 {
	const char *name;
	int fs_flags;
	struct dentry___34 * (*mount)(struct file_system_type___32 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___33 *);
	struct module___30 *owner;
	struct file_system_type___32 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___32 {
	struct inode___35 * (*alloc_inode)(struct super_block___33 *);
	void (*destroy_inode)(struct inode___35 *);
	void (*dirty_inode)(struct inode___35 *, int);
	int (*write_inode)(struct inode___35 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___35 *);
	void (*evict_inode)(struct inode___35 *);
	void (*put_super)(struct super_block___33 *);
	int (*sync_fs)(struct super_block___33 *, int);
	int (*freeze_super)(struct super_block___33 *);
	int (*freeze_fs)(struct super_block___33 *);
	int (*thaw_super)(struct super_block___33 *);
	int (*unfreeze_fs)(struct super_block___33 *);
	int (*statfs)(struct dentry___34 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___33 *, int *, char *);
	void (*umount_begin)(struct super_block___33 *);
	int (*show_options)(struct seq_file___30 *, struct dentry___34 *);
	int (*show_devname)(struct seq_file___30 *, struct dentry___34 *);
	int (*show_path)(struct seq_file___30 *, struct dentry___34 *);
	int (*show_stats)(struct seq_file___30 *, struct dentry___34 *);
	ssize_t (*quota_read)(struct super_block___33 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___33 *, int, const char *, size_t, loff_t);
	struct dquot___32 ** (*get_dquots)(struct inode___35 *);
	int (*bdev_try_to_free_page)(struct super_block___33 *, struct page___33 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___33 *, struct shrink_control___10 *);
	long int (*free_cached_objects)(struct super_block___33 *, struct shrink_control___10 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*key_restrict_link_func_t___32)(struct key___33 *, const struct key_type *, const union key_payload *, struct key___33 *);

struct key_restriction___33;

struct key___33 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___33 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___33 *restrict_link;
};

struct key_restriction___33 {
	key_restrict_link_func_t___32 check;
	struct key___33 *key;
	struct key_type *keytype;
};

struct seq_operations___27 {
	void * (*start)(struct seq_file___30 *, loff_t *);
	void (*stop)(struct seq_file___30 *, void *);
	void * (*next)(struct seq_file___30 *, void *, loff_t *);
	int (*show)(struct seq_file___30 *, void *);
};

struct dev_pm_info___28 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___28 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___28;

struct bus_type___28;

struct device_driver___28;

struct dev_pm_domain___28;

struct class___28;

struct device___28 {
	struct device___28 *parent;
	struct device_private *p;
	struct kobject___31 kobj;
	const char *init_name;
	const struct device_type___28 *type;
	struct mutex mutex;
	struct bus_type___28 *bus;
	struct device_driver___28 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___28 power;
	struct dev_pm_domain___28 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___28 *class;
	const struct attribute_group___28 **groups;
	void (*release)(struct device___28 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

typedef void compound_page_dtor___32(struct page___33 *);

struct cgroup_namespace___22 {
	refcount_t count;
	struct ns_common___2 ns;
	struct user_namespace___23 *user_ns;
	struct ucounts___23 *ucounts;
	struct css_set___22 *root_cset;
};

struct ucounts___23 {
	struct hlist_node node;
	struct user_namespace___23 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct dev_pm_ops___28 {
	int (*prepare)(struct device___28 *);
	void (*complete)(struct device___28 *);
	int (*suspend)(struct device___28 *);
	int (*resume)(struct device___28 *);
	int (*freeze)(struct device___28 *);
	int (*thaw)(struct device___28 *);
	int (*poweroff)(struct device___28 *);
	int (*restore)(struct device___28 *);
	int (*suspend_late)(struct device___28 *);
	int (*resume_early)(struct device___28 *);
	int (*freeze_late)(struct device___28 *);
	int (*thaw_early)(struct device___28 *);
	int (*poweroff_late)(struct device___28 *);
	int (*restore_early)(struct device___28 *);
	int (*suspend_noirq)(struct device___28 *);
	int (*resume_noirq)(struct device___28 *);
	int (*freeze_noirq)(struct device___28 *);
	int (*thaw_noirq)(struct device___28 *);
	int (*poweroff_noirq)(struct device___28 *);
	int (*restore_noirq)(struct device___28 *);
	int (*runtime_suspend)(struct device___28 *);
	int (*runtime_resume)(struct device___28 *);
	int (*runtime_idle)(struct device___28 *);
};

struct dev_pm_domain___28 {
	struct dev_pm_ops___28 ops;
	void (*detach)(struct device___28 *, bool);
	int (*activate)(struct device___28 *);
	void (*sync)(struct device___28 *);
	void (*dismiss)(struct device___28 *);
};

struct bus_type___28 {
	const char *name;
	const char *dev_name;
	struct device___28 *dev_root;
	const struct attribute_group___28 **bus_groups;
	const struct attribute_group___28 **dev_groups;
	const struct attribute_group___28 **drv_groups;
	int (*match)(struct device___28 *, struct device_driver___28 *);
	int (*uevent)(struct device___28 *, struct kobj_uevent_env *);
	int (*probe)(struct device___28 *);
	int (*remove)(struct device___28 *);
	void (*shutdown)(struct device___28 *);
	int (*online)(struct device___28 *);
	int (*offline)(struct device___28 *);
	int (*suspend)(struct device___28 *, pm_message_t);
	int (*resume)(struct device___28 *);
	int (*num_vf)(struct device___28 *);
	int (*dma_configure)(struct device___28 *);
	const struct dev_pm_ops___28 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___28 {
	const char *name;
	struct bus_type___28 *bus;
	struct module___30 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___28 *);
	int (*remove)(struct device___28 *);
	void (*shutdown)(struct device___28 *);
	int (*suspend)(struct device___28 *, pm_message_t);
	int (*resume)(struct device___28 *);
	const struct attribute_group___28 **groups;
	const struct dev_pm_ops___28 *pm;
	void (*coredump)(struct device___28 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___28 {
	const char *name;
	const struct attribute_group___28 **groups;
	int (*uevent)(struct device___28 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___28 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___28 *);
	const struct dev_pm_ops___28 *pm;
};

struct class___28 {
	const char *name;
	struct module___30 *owner;
	const struct attribute_group___28 **class_groups;
	const struct attribute_group___28 **dev_groups;
	struct kobject___31 *dev_kobj;
	int (*dev_uevent)(struct device___28 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___28 *, umode_t *);
	void (*class_release)(struct class___28 *);
	void (*dev_release)(struct device___28 *);
	int (*shutdown_pre)(struct device___28 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___28 *);
	const struct dev_pm_ops___28 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___26 {
	struct device___28 dev;
};

struct bpf_map___22;

struct bpf_map_ops___22 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___22 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___22 *, struct file___33 *);
	void (*map_free)(struct bpf_map___22 *);
	int (*map_get_next_key)(struct bpf_map___22 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___22 *);
	void * (*map_lookup_elem)(struct bpf_map___22 *, void *);
	int (*map_update_elem)(struct bpf_map___22 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___22 *, void *);
	int (*map_push_elem)(struct bpf_map___22 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___22 *, void *);
	int (*map_peek_elem)(struct bpf_map___22 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___22 *, struct file___33 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___22 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___22 *, void *, struct seq_file___30 *);
	int (*map_check_btf)(const struct bpf_map___22 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___22 {
	const struct bpf_map_ops___22 *ops;
	struct bpf_map___22 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___32 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___22;

typedef void (*kthread_work_func_t___22)(struct kthread_work___22 *);

struct kthread_worker___22;

struct kthread_work___22 {
	struct list_head node;
	kthread_work_func_t___22 func;
	struct kthread_worker___22 *worker;
	int canceling;
};

struct kthread_worker___22 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___34 *task;
	struct kthread_work___22 *current_work;
};

struct kthread_delayed_work___22 {
	struct kthread_work___22 work;
	struct timer_list timer;
};

struct psi_group___22 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___22 *poll_kworker;
	struct kthread_delayed_work___22 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___22 {
	struct kernfs_node___30 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___22;

struct cgroup_subsys_state___22 {
	struct cgroup___22 *cgroup;
	struct cgroup_subsys___22 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___22 *parent;
};

struct cgroup_root___22;

struct cgroup_rstat_cpu___22;

struct cgroup___22 {
	struct cgroup_subsys_state___22 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___30 *kn;
	struct cgroup_file___22 procs_file;
	struct cgroup_file___22 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___22 *subsys[13];
	struct cgroup_root___22 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___22 *dom_cgrp;
	struct cgroup_rstat_cpu___22 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___2 bpf;
	atomic_t congestion_count;
	struct cgroup___22 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___22 psi;
	int ancestor_ids[0];
};

struct cftype___22;

struct cgroup_subsys___22 {
	struct cgroup_subsys_state___22 * (*css_alloc)(struct cgroup_subsys_state___22 *);
	int (*css_online)(struct cgroup_subsys_state___22 *);
	void (*css_offline)(struct cgroup_subsys_state___22 *);
	void (*css_released)(struct cgroup_subsys_state___22 *);
	void (*css_free)(struct cgroup_subsys_state___22 *);
	void (*css_reset)(struct cgroup_subsys_state___22 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___22 *, int);
	int (*css_extra_stat_show)(struct seq_file___30 *, struct cgroup_subsys_state___22 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___34 *);
	void (*cancel_fork)(struct task_struct___34 *);
	void (*fork)(struct task_struct___34 *);
	void (*exit)(struct task_struct___34 *);
	void (*free)(struct task_struct___34 *);
	void (*bind)(struct cgroup_subsys_state___22 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___22 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___22 *dfl_cftypes;
	struct cftype___22 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___22 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___22 *updated_children;
	struct cgroup___22 *updated_next;
};

struct cgroup_root___22 {
	struct kernfs_root___30 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___22 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___22 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___22 *ss;
	struct list_head node;
	struct kernfs_ops___30 *kf_ops;
	int (*open)(struct kernfs_open_file___30 *);
	void (*release)(struct kernfs_open_file___30 *);
	u64 (*read_u64)(struct cgroup_subsys_state___22 *, struct cftype___22 *);
	s64 (*read_s64)(struct cgroup_subsys_state___22 *, struct cftype___22 *);
	int (*seq_show)(struct seq_file___30 *, void *);
	void * (*seq_start)(struct seq_file___30 *, loff_t *);
	void * (*seq_next)(struct seq_file___30 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___30 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___22 *, struct cftype___22 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___22 *, struct cftype___22 *, s64);
	ssize_t (*write)(struct kernfs_open_file___30 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___30 *, struct poll_table_struct___19 *);
};

struct perf_cpu_context___18;

struct pmu___18 {
	struct list_head entry;
	struct module___30 *module;
	struct device___28 *dev;
	const struct attribute_group___28 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___18 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___18 *);
	void (*pmu_disable)(struct pmu___18 *);
	int (*event_init)(struct perf_event___18 *);
	void (*event_mapped)(struct perf_event___18 *, struct mm_struct___33 *);
	void (*event_unmapped)(struct perf_event___18 *, struct mm_struct___33 *);
	int (*add)(struct perf_event___18 *, int);
	void (*del)(struct perf_event___18 *, int);
	void (*start)(struct perf_event___18 *, int);
	void (*stop)(struct perf_event___18 *, int);
	void (*read)(struct perf_event___18 *);
	void (*start_txn)(struct pmu___18 *, unsigned int);
	int (*commit_txn)(struct pmu___18 *);
	void (*cancel_txn)(struct pmu___18 *);
	int (*event_idx)(struct perf_event___18 *);
	void (*sched_task)(struct perf_event_context___18 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___18 *);
	int (*filter_match)(struct perf_event___18 *);
	int (*check_period)(struct perf_event___18 *, u64);
};

struct perf_cpu_context___18 {
	struct perf_event_context___18 ctx;
	struct perf_event_context___18 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___18 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___18 {
	struct cgroup_subsys_state___22 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___13 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___13 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___13 *);
	struct list_head * (*get_fields)(struct trace_event_call___13 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___13 *);
};

struct syscall_metadata___4 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___13 *enter_event;
	struct trace_event_call___13 *exit_event;
};

struct __va_list {
	void *__stack;
	void *__gr_top;
	void *__vr_top;
	int __gr_offs;
	int __vr_offs;
};

typedef struct __va_list __gnuc_va_list;

typedef __gnuc_va_list va_list;

enum kmsg_dump_reason {
	KMSG_DUMP_UNDEF = 0,
	KMSG_DUMP_PANIC = 1,
	KMSG_DUMP_OOPS = 2,
	KMSG_DUMP_EMERG = 3,
	KMSG_DUMP_RESTART = 4,
	KMSG_DUMP_HALT = 5,
	KMSG_DUMP_POWEROFF = 6,
};

struct consw___3 {
	struct module___25 *owner;
	const char * (*con_startup)();
	void (*con_init)(struct vc_data *, int);
	void (*con_deinit)(struct vc_data *);
	void (*con_clear)(struct vc_data *, int, int, int, int);
	void (*con_putc)(struct vc_data *, int, int, int);
	void (*con_putcs)(struct vc_data *, const short unsigned int *, int, int, int);
	void (*con_cursor)(struct vc_data *, int);
	bool (*con_scroll)(struct vc_data *, unsigned int, unsigned int, enum con_scroll, unsigned int);
	int (*con_switch)(struct vc_data *);
	int (*con_blank)(struct vc_data *, int, int);
	int (*con_font_set)(struct vc_data *, struct console_font *, unsigned int);
	int (*con_font_get)(struct vc_data *, struct console_font *);
	int (*con_font_default)(struct vc_data *, struct console_font *, char *);
	int (*con_font_copy)(struct vc_data *, int);
	int (*con_resize)(struct vc_data *, unsigned int, unsigned int, unsigned int);
	void (*con_set_palette)(struct vc_data *, const unsigned char *);
	void (*con_scrolldelta)(struct vc_data *, int);
	int (*con_set_origin)(struct vc_data *);
	void (*con_save_screen)(struct vc_data *);
	u8 (*con_build_attr)(struct vc_data *, u8, u8, u8, u8, u8, u8);
	void (*con_invert_region)(struct vc_data *, u16 *, int);
	u16 * (*con_screen_pos)(struct vc_data *, int);
	long unsigned int (*con_getxy)(struct vc_data *, long unsigned int, int *, int *);
	void (*con_flush_scrollback)(struct vc_data *);
	int (*con_debug_enter)(struct vc_data *);
	int (*con_debug_leave)(struct vc_data *);
};

struct warn_args {
	const char *fmt;
	va_list args;
};

struct module___31;

struct file___34;

struct kiocb___34;

struct iov_iter___13;

struct poll_table_struct___20;

struct vm_area_struct___34;

struct inode___36;

struct file_lock___34;

struct page___34;

struct seq_file___31;

struct file_operations___34 {
	struct module___31 *owner;
	loff_t (*llseek)(struct file___34 *, loff_t, int);
	ssize_t (*read)(struct file___34 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___34 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___34 *, struct iov_iter___13 *);
	ssize_t (*write_iter)(struct kiocb___34 *, struct iov_iter___13 *);
	int (*iopoll)(struct kiocb___34 *, bool);
	int (*iterate)(struct file___34 *, struct dir_context *);
	int (*iterate_shared)(struct file___34 *, struct dir_context *);
	__poll_t (*poll)(struct file___34 *, struct poll_table_struct___20 *);
	long int (*unlocked_ioctl)(struct file___34 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___34 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___34 *, struct vm_area_struct___34 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___36 *, struct file___34 *);
	int (*flush)(struct file___34 *, fl_owner_t);
	int (*release)(struct inode___36 *, struct file___34 *);
	int (*fsync)(struct file___34 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___34 *, int);
	int (*lock)(struct file___34 *, int, struct file_lock___34 *);
	ssize_t (*sendpage)(struct file___34 *, struct page___34 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___34 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___34 *, int, struct file_lock___34 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___34 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___34 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___34 *, long int, struct file_lock___34 **, void **);
	long int (*fallocate)(struct file___34 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___31 *, struct file___34 *);
	ssize_t (*copy_file_range)(struct file___34 *, loff_t, struct file___34 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___34 *, loff_t, struct file___34 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___34 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___33 {
	u64 seqnum;
	struct vm_area_struct___34 *vmas[4];
};

struct page_frag___33 {
	struct page___34 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___19;

struct debug_info___19 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___19 *hbp_break[16];
	struct perf_event___19 *hbp_watch[16];
};

struct thread_struct___19 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___19 debug;
	long: 64;
};

struct mm_struct___34;

struct mem_cgroup___11;

struct pid___29;

struct cred___33;

struct nsproxy___32;

struct signal_struct___31;

struct bio_list___12;

struct backing_dev_info___12;

struct css_set___23;

struct perf_event_context___19;

struct vm_struct___27;

struct task_struct___35 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___35 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___34 *mm;
	struct mm_struct___34 *active_mm;
	struct vmacache___33 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___35 *real_parent;
	struct task_struct___35 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___35 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___11 *active_memcg;
	long int rh_reserved2;
	struct pid___29 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___29 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___29 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___33 *ptracer_cred;
	const struct cred___33 *real_cred;
	const struct cred___33 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___32 *nsproxy;
	struct signal_struct___31 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___35 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___12 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___12 *backing_dev_info;
	struct io_context___6 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___23 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___19 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___33 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___11 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___35 *oom_reaper_list;
	struct vm_struct___27 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___19 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___19 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___35 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___19)(struct perf_event___19 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___19;

struct fasync_struct___33;

struct pid_namespace___29;

struct trace_event_call___14;

struct perf_cgroup___19;

struct perf_event___19 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___19 *group_leader;
	struct pmu___19 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___19 hw;
	struct perf_event_context___19 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___19 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___35 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___33 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___19 *);
	struct callback_head callback_head;
	struct pid_namespace___29 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___19 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___19 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___14 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___19 *cgrp;
	struct list_head sb_list;
};

struct dentry_operations___33;

struct super_block___34;

struct dentry___35 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___35 *d_parent;
	struct qstr d_name;
	struct inode___36 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___33 *d_op;
	struct super_block___34 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct rw_semaphore___34 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___35 *owner;
};

struct address_space_operations___33;

struct address_space___33 {
	struct inode___36 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___34 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___33 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___33;

struct bdi_writeback___12;

struct block_device___34;

struct inode___36 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___33 *i_op;
	struct super_block___34 *i_sb;
	struct address_space___33 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___34 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___12 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___34 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___33 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___34 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___33;

struct dentry_operations___33 {
	int (*d_revalidate)(struct dentry___35 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___35 *, unsigned int);
	int (*d_hash)(const struct dentry___35 *, struct qstr *);
	int (*d_compare)(const struct dentry___35 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___35 *);
	int (*d_init)(struct dentry___35 *);
	void (*d_release)(struct dentry___35 *);
	void (*d_prune)(struct dentry___35 *);
	void (*d_iput)(struct dentry___35 *, struct inode___36 *);
	char * (*d_dname)(struct dentry___35 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___33 *);
	int (*d_manage)(const struct path___33 *, bool);
	struct dentry___35 * (*d_real)(struct dentry___35 *, const struct inode___36 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___33;

struct mem_dqinfo___33 {
	struct quota_format_type___33 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___33;

struct quota_info___33 {
	unsigned int flags;
	struct rw_semaphore___34 dqio_sem;
	struct inode___36 *files[3];
	struct mem_dqinfo___33 info[3];
	const struct quota_format_ops___33 *ops[3];
};

struct rcuwait___33 {
	struct task_struct___35 *task;
};

struct percpu_rw_semaphore___33 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___34 rw_sem;
	struct rcuwait___33 writer;
	int readers_block;
};

struct sb_writers___33 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___33 rw_sem[3];
};

struct shrink_control___11;

struct shrinker___11 {
	long unsigned int (*count_objects)(struct shrinker___11 *, struct shrink_control___11 *);
	long unsigned int (*scan_objects)(struct shrinker___11 *, struct shrink_control___11 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___33;

struct super_operations___33;

struct dquot_operations___33;

struct quotactl_ops___33;

struct user_namespace___24;

struct super_block___34 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___33 *s_type;
	const struct super_operations___33 *s_op;
	const struct dquot_operations___33 *dq_op;
	const struct quotactl_ops___33 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___35 *s_root;
	struct rw_semaphore___34 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___34 *s_bdev;
	struct backing_dev_info___12 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___33 s_dquot;
	struct sb_writers___33 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___33 *s_d_op;
	int cleancache_poolid;
	struct shrinker___11 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___24 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct path___33 {
	struct vfsmount *mnt;
	struct dentry___35 *dentry;
};

struct key___34;

struct ucounts___24;

struct user_namespace___24 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___24 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___2 ns;
	long unsigned int flags;
	struct key___34 *persistent_keyring_register;
	struct rw_semaphore___34 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___24 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct shrink_control___11 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___11 *memcg;
};

struct cgroup___23;

struct cgroup_subsys___23;

struct cgroup_subsys_state___23 {
	struct cgroup___23 *cgroup;
	struct cgroup_subsys___23 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___23 *parent;
};

struct mem_cgroup_id___8 {
	int id;
	union {
		refcount_t ref;
		struct {
			atomic_t ref;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
};

struct kernfs_node___31;

struct cgroup_file___23 {
	struct kernfs_node___31 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___11;

struct mem_cgroup___11 {
	struct cgroup_subsys_state___23 css;
	struct mem_cgroup_id___8 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___23 events_file;
	struct cgroup_file___23 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___35 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___11 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___34 *pgtable_t___33;

struct dev_pagemap___33;

struct page___34 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___33 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___34 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___33 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___34 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___33 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___11 *mem_cgroup;
};

struct pglist_data___33;

struct lruvec___33 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___33 *pgdat;
};

struct zone___33 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___33 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___33 {
	struct zone___33 *zone;
	int zone_idx;
};

struct zonelist___33 {
	struct zoneref___33 _zonerefs[25];
};

struct pglist_data___33 {
	struct zone___33 node_zones[3];
	struct zonelist___33 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___35 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___35 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___33 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___34 {
	void *stack;
	struct task_struct___35 *task;
	long int status;
};

struct clock_event_device___5;

struct arch_timer_erratum_workaround___5 {
	enum arch_timer_erratum_match_type match_type;
	const void *id;
	const char *desc;
	u32 (*read_cntp_tval_el0)();
	u32 (*read_cntv_tval_el0)();
	u64 (*read_cntpct_el0)();
	u64 (*read_cntvct_el0)();
	int (*set_next_event_phys)(long unsigned int, struct clock_event_device___5 *);
	int (*set_next_event_virt)(long unsigned int, struct clock_event_device___5 *);
};

struct clock_event_device___5 {
	void (*event_handler)(struct clock_event_device___5 *);
	int (*set_next_event)(long unsigned int, struct clock_event_device___5 *);
	int (*set_next_ktime)(ktime_t, struct clock_event_device___5 *);
	ktime_t next_event;
	u64 max_delta_ns;
	u64 min_delta_ns;
	u32 mult;
	u32 shift;
	enum clock_event_state state_use_accessors;
	unsigned int features;
	long unsigned int retries;
	int (*set_state_periodic)(struct clock_event_device___5 *);
	int (*set_state_oneshot)(struct clock_event_device___5 *);
	int (*set_state_oneshot_stopped)(struct clock_event_device___5 *);
	int (*set_state_shutdown)(struct clock_event_device___5 *);
	int (*tick_resume)(struct clock_event_device___5 *);
	void (*broadcast)(const struct cpumask *);
	void (*suspend)(struct clock_event_device___5 *);
	void (*resume)(struct clock_event_device___5 *);
	long unsigned int min_delta_ticks;
	long unsigned int max_delta_ticks;
	const char *name;
	int rating;
	int irq;
	int bound_on;
	const struct cpumask *cpumask;
	struct list_head list;
	struct module___31 *owner;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct blocking_notifier_head___33 {
	struct rw_semaphore___34 rwsem;
	struct notifier_block *head;
};

struct upid___29 {
	int nr;
	struct pid_namespace___29 *ns;
};

struct pid_namespace___29 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___35 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___29 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___35 *proc_self;
	struct dentry___35 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___24 *user_ns;
	struct ucounts___24 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___2 ns;
};

struct pid___29 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___29 numbers[1];
};

struct vm_operations_struct___33;

struct vm_area_struct___34 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___34 *vm_next;
	struct vm_area_struct___34 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___34 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___33 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___34 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___33;

struct mm_struct___34 {
	struct {
		struct vm_area_struct___34 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___34 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___34 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___33 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___35 *owner;
		struct user_namespace___24 *user_ns;
		struct file___34 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___33 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___33)(struct vm_area_struct___34 *, long unsigned int, const struct page___34 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___33)(struct page___34 *, void *);

struct device___29;

struct dev_pagemap___33 {
	dev_page_fault_t___33 page_fault;
	dev_page_free_t___33 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___29 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct fown_struct___29 {
	rwlock_t lock;
	struct pid___29 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___34 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___33 f_path;
	struct inode___36 *f_inode;
	const struct file_operations___34 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___29 f_owner;
	const struct cred___33 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___33 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___33;

struct vm_operations_struct___33 {
	void (*open)(struct vm_area_struct___34 *);
	void (*close)(struct vm_area_struct___34 *);
	int (*split)(struct vm_area_struct___34 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___34 *);
	vm_fault_t (*fault)(struct vm_fault___33 *);
	vm_fault_t (*huge_fault)(struct vm_fault___33 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___33 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___34 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___33 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___33 *);
	int (*access)(struct vm_area_struct___34 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___34 *);
	int (*set_policy)(struct vm_area_struct___34 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___34 *, long unsigned int);
	struct page___34 * (*find_special_page)(struct vm_area_struct___34 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___33 {
	struct task_struct___35 *task;
	struct core_thread___33 *next;
};

struct core_state___33 {
	atomic_t nr_threads;
	struct core_thread___33 dumper;
	struct completion startup;
};

struct vm_fault___33 {
	struct vm_area_struct___34 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___34 *cow_page;
	struct mem_cgroup___11 *memcg;
	struct page___34 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___33 prealloc_pte;
};

struct user_struct___33 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___34 *uid_keyring;
	struct key___34 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___33 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___34 *session_keyring;
	struct key___34 *process_keyring;
	struct key___34 *thread_keyring;
	struct key___34 *request_key_auth;
	void *security;
	struct user_struct___33 *user;
	struct user_namespace___24 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___23;

struct nsproxy___32 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___29 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___23 *cgroup_ns;
};

struct signal_struct___31 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___35 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___35 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___29 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___29 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___34 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___29 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___12;

struct bio_list___12 {
	struct bio___12 *head;
	struct bio___12 *tail;
};

struct bdi_writeback_congested___12;

struct bdi_writeback___12 {
	struct backing_dev_info___12 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___12 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___23 *memcg_css;
	struct cgroup_subsys_state___23 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___12 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___12 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___29 *dev;
	struct device___29 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___35 *debug_dir;
	struct dentry___35 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___23 {
	struct cgroup_subsys_state___23 *subsys[13];
	refcount_t refcount;
	struct css_set___23 *dom_cset;
	struct cgroup___23 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___23 *mg_src_cgrp;
	struct cgroup___23 *mg_dst_cgrp;
	struct css_set___23 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___19 {
	struct pmu___19 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___35 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___19 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___27 {
	struct vm_struct___27 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___34 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___31 {
	struct task_struct___35 task;
	long unsigned int stack[8192];
};

struct kiocb___34 {
	struct file___34 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___34 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___34 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___34 *ia_file;
};

struct dquot___33 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___34 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___33 {
	int qf_fmt_id;
	const struct quota_format_ops___33 *qf_ops;
	struct module___31 *qf_owner;
	struct quota_format_type___33 *qf_next;
};

struct quota_format_ops___33 {
	int (*check_quota_file)(struct super_block___34 *, int);
	int (*read_file_info)(struct super_block___34 *, int);
	int (*write_file_info)(struct super_block___34 *, int);
	int (*free_file_info)(struct super_block___34 *, int);
	int (*read_dqblk)(struct dquot___33 *);
	int (*commit_dqblk)(struct dquot___33 *);
	int (*release_dqblk)(struct dquot___33 *);
	int (*get_next_id)(struct super_block___34 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___33 {
	int (*write_dquot)(struct dquot___33 *);
	struct dquot___33 * (*alloc_dquot)(struct super_block___34 *, int);
	void (*destroy_dquot)(struct dquot___33 *);
	int (*acquire_dquot)(struct dquot___33 *);
	int (*release_dquot)(struct dquot___33 *);
	int (*mark_dirty)(struct dquot___33 *);
	int (*write_info)(struct super_block___34 *, int);
	qsize_t * (*get_reserved_space)(struct inode___36 *);
	int (*get_projid)(struct inode___36 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___36 *, qsize_t *);
	int (*get_next_id)(struct super_block___34 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___33 {
	int (*quota_on)(struct super_block___34 *, int, int, const struct path___33 *);
	int (*quota_off)(struct super_block___34 *, int);
	int (*quota_enable)(struct super_block___34 *, unsigned int);
	int (*quota_disable)(struct super_block___34 *, unsigned int);
	int (*quota_sync)(struct super_block___34 *, int);
	int (*set_info)(struct super_block___34 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___34 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___34 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___34 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___34 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___34 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___31;

struct kobj_type___31;

struct kobject___32 {
	const char *name;
	struct list_head entry;
	struct kobject___32 *parent;
	struct kset___31 *kset;
	struct kobj_type___31 *ktype;
	struct kernfs_node___31 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___28 {
	struct kobject___32 kobj;
	struct module___31 *mod;
	struct kobject___32 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___28 {
	struct module___31 *mod;
	struct latch_tree_node node;
};

struct module_layout___28 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___28 mtn;
};

struct module_attribute___28;

struct kernel_param___28;

struct module___31 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___28 mkobj;
	struct module_attribute___28 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___32 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___28 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___28 core_layout;
	struct module_layout___28 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___14 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___11;

struct swap_info_struct___9;

struct address_space_operations___33 {
	int (*writepage)(struct page___34 *, struct writeback_control___11 *);
	int (*readpage)(struct file___34 *, struct page___34 *);
	int (*writepages)(struct address_space___33 *, struct writeback_control___11 *);
	int (*set_page_dirty)(struct page___34 *);
	int (*readpages)(struct file___34 *, struct address_space___33 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___34 *, struct address_space___33 *, loff_t, unsigned int, unsigned int, struct page___34 **, void **);
	int (*write_end)(struct file___34 *, struct address_space___33 *, loff_t, unsigned int, unsigned int, struct page___34 *, void *);
	sector_t (*bmap)(struct address_space___33 *, sector_t);
	void (*invalidatepage)(struct page___34 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___34 *, gfp_t);
	void (*freepage)(struct page___34 *);
	ssize_t (*direct_IO)(struct kiocb___34 *, struct iov_iter___13 *);
	int (*migratepage)(struct address_space___33 *, struct page___34 *, struct page___34 *, enum migrate_mode);
	bool (*isolate_page)(struct page___34 *, isolate_mode_t);
	void (*putback_page)(struct page___34 *);
	int (*launder_page)(struct page___34 *);
	int (*is_partially_uptodate)(struct page___34 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___34 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___33 *, struct page___34 *);
	int (*swap_activate)(struct swap_info_struct___9 *, struct file___34 *, sector_t *);
	void (*swap_deactivate)(struct file___34 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___11 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___12 *wb;
	struct inode___36 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___12;

struct iov_iter___13 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___12 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct swap_info_struct___9 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___34 *bdev;
	struct file___34 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___34 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___36 *bd_inode;
	struct super_block___34 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___34 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___12 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___33 {
	struct dentry___35 * (*lookup)(struct inode___36 *, struct dentry___35 *, unsigned int);
	const char * (*get_link)(struct dentry___35 *, struct inode___36 *, struct delayed_call *);
	int (*permission)(struct inode___36 *, int);
	struct posix_acl * (*get_acl)(struct inode___36 *, int);
	int (*readlink)(struct dentry___35 *, char *, int);
	int (*create)(struct inode___36 *, struct dentry___35 *, umode_t, bool);
	int (*link)(struct dentry___35 *, struct inode___36 *, struct dentry___35 *);
	int (*unlink)(struct inode___36 *, struct dentry___35 *);
	int (*symlink)(struct inode___36 *, struct dentry___35 *, const char *);
	int (*mkdir)(struct inode___36 *, struct dentry___35 *, umode_t);
	int (*rmdir)(struct inode___36 *, struct dentry___35 *);
	int (*mknod)(struct inode___36 *, struct dentry___35 *, umode_t, dev_t);
	int (*rename)(struct inode___36 *, struct dentry___35 *, struct inode___36 *, struct dentry___35 *, unsigned int);
	int (*setattr)(struct dentry___35 *, struct iattr___34 *);
	int (*getattr)(const struct path___33 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___35 *, char *, size_t);
	int (*fiemap)(struct inode___36 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___36 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___36 *, struct dentry___35 *, struct file___34 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___36 *, struct dentry___35 *, umode_t);
	int (*set_acl)(struct inode___36 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___33 {
	void (*fl_copy_lock)(struct file_lock___34 *, struct file_lock___34 *);
	void (*fl_release_private)(struct file_lock___34 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___33;

struct file_lock___34 {
	struct file_lock___34 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___34 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___33 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___33 *fl_ops;
	const struct lock_manager_operations___33 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___33 {
	int (*lm_compare_owner)(struct file_lock___34 *, struct file_lock___34 *);
	long unsigned int (*lm_owner_key)(struct file_lock___34 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___34 *);
	int (*lm_grant)(struct file_lock___34 *, int);
	bool (*lm_break)(struct file_lock___34 *);
	int (*lm_change)(struct file_lock___34 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___34 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___33 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___33 *fa_next;
	struct file___34 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___33 {
	const char *name;
	int fs_flags;
	struct dentry___35 * (*mount)(struct file_system_type___33 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___34 *);
	struct module___31 *owner;
	struct file_system_type___33 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___33 {
	struct inode___36 * (*alloc_inode)(struct super_block___34 *);
	void (*destroy_inode)(struct inode___36 *);
	void (*dirty_inode)(struct inode___36 *, int);
	int (*write_inode)(struct inode___36 *, struct writeback_control___11 *);
	int (*drop_inode)(struct inode___36 *);
	void (*evict_inode)(struct inode___36 *);
	void (*put_super)(struct super_block___34 *);
	int (*sync_fs)(struct super_block___34 *, int);
	int (*freeze_super)(struct super_block___34 *);
	int (*freeze_fs)(struct super_block___34 *);
	int (*thaw_super)(struct super_block___34 *);
	int (*unfreeze_fs)(struct super_block___34 *);
	int (*statfs)(struct dentry___35 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___34 *, int *, char *);
	void (*umount_begin)(struct super_block___34 *);
	int (*show_options)(struct seq_file___31 *, struct dentry___35 *);
	int (*show_devname)(struct seq_file___31 *, struct dentry___35 *);
	int (*show_path)(struct seq_file___31 *, struct dentry___35 *);
	int (*show_stats)(struct seq_file___31 *, struct dentry___35 *);
	ssize_t (*quota_read)(struct super_block___34 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___34 *, int, const char *, size_t, loff_t);
	struct dquot___33 ** (*get_dquots)(struct inode___36 *);
	int (*bdev_try_to_free_page)(struct super_block___34 *, struct page___34 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___34 *, struct shrink_control___11 *);
	long int (*free_cached_objects)(struct super_block___34 *, struct shrink_control___11 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___19)(struct file___34 *, wait_queue_head_t *, struct poll_table_struct___20 *);

struct poll_table_struct___20 {
	poll_queue_proc___19 _qproc;
	__poll_t _key;
};

struct seq_operations___28;

struct seq_file___31 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___28 *op;
	int poll_event;
	const struct file___34 *file;
	void *private;
};

typedef void bio_end_io_t___12(struct bio___12 *);

struct bio_vec___12 {
	struct page___34 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___12;

struct bio_set___12;

struct bio___12 {
	struct bio___12 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___12 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___12 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___12 *bi_io_vec;
	struct bio_set___12 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___12 bi_inline_vecs[0];
};

typedef int (*key_restrict_link_func_t___33)(struct key___34 *, const struct key_type *, const union key_payload *, struct key___34 *);

struct key_restriction___34;

struct key___34 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___34 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___34 *restrict_link;
};

struct key_restriction___34 {
	key_restrict_link_func_t___33 check;
	struct key___34 *key;
	struct key_type *keytype;
};

struct kernfs_root___31;

struct kernfs_elem_dir___31 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___31 *root;
};

struct kernfs_syscall_ops___31;

struct kernfs_root___31 {
	struct kernfs_node___31 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___31 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___31 {
	struct kernfs_node___31 *target_kn;
};

struct kernfs_ops___31;

struct kernfs_elem_attr___31 {
	const struct kernfs_ops___31 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___31 *notify_next;
};

struct kernfs_node___31 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___31 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___31 dir;
		struct kernfs_elem_symlink___31 symlink;
		struct kernfs_elem_attr___31 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___31;

struct kernfs_ops___31 {
	int (*open)(struct kernfs_open_file___31 *);
	void (*release)(struct kernfs_open_file___31 *);
	int (*seq_show)(struct seq_file___31 *, void *);
	void * (*seq_start)(struct seq_file___31 *, loff_t *);
	void * (*seq_next)(struct seq_file___31 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___31 *, void *);
	ssize_t (*read)(struct kernfs_open_file___31 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___31 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___31 *, struct vm_area_struct___34 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___31 *, struct poll_table_struct___20 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___31 {
	int (*remount_fs)(struct kernfs_root___31 *, int *, char *);
	int (*show_options)(struct seq_file___31 *, struct kernfs_root___31 *);
	int (*mkdir)(struct kernfs_node___31 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___31 *);
	int (*rename)(struct kernfs_node___31 *, struct kernfs_node___31 *, const char *);
	int (*show_path)(struct seq_file___31 *, struct kernfs_node___31 *, struct kernfs_root___31 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___31 {
	struct kernfs_node___31 *kn;
	struct file___34 *file;
	struct seq_file___31 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___33 *vm_ops;
};

struct bin_attribute___29;

struct attribute_group___29 {
	const char *name;
	umode_t (*is_visible)(struct kobject___32 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___32 *, struct bin_attribute___29 *, int);
	struct attribute **attrs;
	struct bin_attribute___29 **bin_attrs;
};

struct bin_attribute___29 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___34 *, struct kobject___32 *, struct bin_attribute___29 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___34 *, struct kobject___32 *, struct bin_attribute___29 *, char *, loff_t, size_t);
	int (*mmap)(struct file___34 *, struct kobject___32 *, struct bin_attribute___29 *, struct vm_area_struct___34 *);
};

struct sysfs_ops___31 {
	ssize_t (*show)(struct kobject___32 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___32 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___31;

struct kset___31 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___32 kobj;
	const struct kset_uevent_ops___31 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___31 {
	void (*release)(struct kobject___32 *);
	const struct sysfs_ops___31 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___32 *);
	const void * (*namespace)(struct kobject___32 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___31 {
	int (* const filter)(struct kset___31 *, struct kobject___32 *);
	const char * (* const name)(struct kset___31 *, struct kobject___32 *);
	int (* const uevent)(struct kset___31 *, struct kobject___32 *, struct kobj_uevent_env *);
};

struct kobj_attribute___32 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___32 *, struct kobj_attribute___32 *, char *);
	ssize_t (*store)(struct kobject___32 *, struct kobj_attribute___32 *, const char *, size_t);
};

struct fwnode_operations___24;

struct fwnode_handle___24 {
	struct fwnode_handle___24 *secondary;
	const struct fwnode_operations___24 *ops;
};

struct fwnode_reference_args___24;

struct fwnode_endpoint___24;

struct fwnode_operations___24 {
	struct fwnode_handle___24 * (*get)(struct fwnode_handle___24 *);
	void (*put)(struct fwnode_handle___24 *);
	bool (*device_is_available)(const struct fwnode_handle___24 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___24 *, const struct device___29 *);
	bool (*property_present)(const struct fwnode_handle___24 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___24 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___24 *, const char *, const char **, size_t);
	struct fwnode_handle___24 * (*get_parent)(const struct fwnode_handle___24 *);
	struct fwnode_handle___24 * (*get_next_child_node)(const struct fwnode_handle___24 *, struct fwnode_handle___24 *);
	struct fwnode_handle___24 * (*get_named_child_node)(const struct fwnode_handle___24 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___24 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___24 *);
	struct fwnode_handle___24 * (*graph_get_next_endpoint)(const struct fwnode_handle___24 *, struct fwnode_handle___24 *);
	struct fwnode_handle___24 * (*graph_get_remote_endpoint)(const struct fwnode_handle___24 *);
	struct fwnode_handle___24 * (*graph_get_port_parent)(struct fwnode_handle___24 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___24 *, struct fwnode_endpoint___24 *);
};

struct fwnode_endpoint___24 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___24 *local_fwnode;
};

struct fwnode_reference_args___24 {
	struct fwnode_handle___24 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct dev_pm_qos___3;

struct dev_pm_info___29 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___29 *, s32);
	struct dev_pm_qos___3 *qos;
};

struct device_type___29;

struct bus_type___29;

struct device_driver___29;

struct dev_pm_domain___29;

struct device_node___13;

struct class___29;

struct device___29 {
	struct device___29 *parent;
	struct device_private *p;
	struct kobject___32 kobj;
	const char *init_name;
	const struct device_type___29 *type;
	struct mutex mutex;
	struct bus_type___29 *bus;
	struct device_driver___29 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___29 power;
	struct dev_pm_domain___29 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___13 *of_node;
	struct fwnode_handle___24 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___29 *class;
	const struct attribute_group___29 **groups;
	void (*release)(struct device___29 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct property___13 {
	char *name;
	int length;
	void *value;
	struct property___13 *next;
	long unsigned int _flags;
	struct bin_attribute___29 attr;
};

struct device_node___13 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___24 fwnode;
	struct property___13 *properties;
	struct property___13 *deadprops;
	struct device_node___13 *parent;
	struct device_node___13 *child;
	struct device_node___13 *sibling;
	struct kobject___32 kobj;
	long unsigned int _flags;
	void *data;
};

enum hk_flags {
	HK_FLAG_TIMER = 1,
	HK_FLAG_RCU = 2,
	HK_FLAG_MISC = 4,
	HK_FLAG_SCHED = 8,
	HK_FLAG_TICK = 16,
	HK_FLAG_DOMAIN = 32,
	HK_FLAG_WQ = 64,
};

struct dev_pm_ops___29 {
	int (*prepare)(struct device___29 *);
	void (*complete)(struct device___29 *);
	int (*suspend)(struct device___29 *);
	int (*resume)(struct device___29 *);
	int (*freeze)(struct device___29 *);
	int (*thaw)(struct device___29 *);
	int (*poweroff)(struct device___29 *);
	int (*restore)(struct device___29 *);
	int (*suspend_late)(struct device___29 *);
	int (*resume_early)(struct device___29 *);
	int (*freeze_late)(struct device___29 *);
	int (*thaw_early)(struct device___29 *);
	int (*poweroff_late)(struct device___29 *);
	int (*restore_early)(struct device___29 *);
	int (*suspend_noirq)(struct device___29 *);
	int (*resume_noirq)(struct device___29 *);
	int (*freeze_noirq)(struct device___29 *);
	int (*thaw_noirq)(struct device___29 *);
	int (*poweroff_noirq)(struct device___29 *);
	int (*restore_noirq)(struct device___29 *);
	int (*runtime_suspend)(struct device___29 *);
	int (*runtime_resume)(struct device___29 *);
	int (*runtime_idle)(struct device___29 *);
};

struct pm_qos_constraints___2 {
	struct plist_head list;
	s32 target_value;
	s32 default_value;
	s32 no_constraint_value;
	enum pm_qos_type type;
	struct blocking_notifier_head___33 *notifiers;
};

struct dev_pm_qos_request___2;

struct dev_pm_qos___3 {
	struct pm_qos_constraints___2 resume_latency;
	struct pm_qos_constraints___2 latency_tolerance;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___2 *resume_latency_req;
	struct dev_pm_qos_request___2 *latency_tolerance_req;
	struct dev_pm_qos_request___2 *flags_req;
};

struct dev_pm_domain___29 {
	struct dev_pm_ops___29 ops;
	void (*detach)(struct device___29 *, bool);
	int (*activate)(struct device___29 *);
	void (*sync)(struct device___29 *);
	void (*dismiss)(struct device___29 *);
};

struct bus_type___29 {
	const char *name;
	const char *dev_name;
	struct device___29 *dev_root;
	const struct attribute_group___29 **bus_groups;
	const struct attribute_group___29 **dev_groups;
	const struct attribute_group___29 **drv_groups;
	int (*match)(struct device___29 *, struct device_driver___29 *);
	int (*uevent)(struct device___29 *, struct kobj_uevent_env *);
	int (*probe)(struct device___29 *);
	int (*remove)(struct device___29 *);
	void (*shutdown)(struct device___29 *);
	int (*online)(struct device___29 *);
	int (*offline)(struct device___29 *);
	int (*suspend)(struct device___29 *, pm_message_t);
	int (*resume)(struct device___29 *);
	int (*num_vf)(struct device___29 *);
	int (*dma_configure)(struct device___29 *);
	const struct dev_pm_ops___29 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___29 {
	const char *name;
	struct bus_type___29 *bus;
	struct module___31 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___29 *);
	int (*remove)(struct device___29 *);
	void (*shutdown)(struct device___29 *);
	int (*suspend)(struct device___29 *, pm_message_t);
	int (*resume)(struct device___29 *);
	const struct attribute_group___29 **groups;
	const struct dev_pm_ops___29 *pm;
	void (*coredump)(struct device___29 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___29 {
	const char *name;
	const struct attribute_group___29 **groups;
	int (*uevent)(struct device___29 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___29 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___29 *);
	const struct dev_pm_ops___29 *pm;
};

struct class___29 {
	const char *name;
	struct module___31 *owner;
	const struct attribute_group___29 **class_groups;
	const struct attribute_group___29 **dev_groups;
	struct kobject___32 *dev_kobj;
	int (*dev_uevent)(struct device___29 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___29 *, umode_t *);
	void (*class_release)(struct class___29 *);
	void (*dev_release)(struct device___29 *);
	int (*shutdown_pre)(struct device___29 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___29 *);
	const struct dev_pm_ops___29 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct device_attribute___4 {
	struct attribute attr;
	ssize_t (*show)(struct device___29 *, struct device_attribute___4 *, char *);
	ssize_t (*store)(struct device___29 *, struct device_attribute___4 *, const char *, size_t);
};

struct node___27 {
	struct device___29 dev;
};

enum cpuhp_smt_control {
	CPU_SMT_ENABLED = 0,
	CPU_SMT_DISABLED = 1,
	CPU_SMT_FORCE_DISABLED = 2,
	CPU_SMT_NOT_SUPPORTED = 3,
};

typedef void compound_page_dtor___33(struct page___34 *);

struct kthread_work___23;

typedef void (*kthread_work_func_t___23)(struct kthread_work___23 *);

struct kthread_worker___23;

struct kthread_work___23 {
	struct list_head node;
	kthread_work_func_t___23 func;
	struct kthread_worker___23 *worker;
	int canceling;
};

struct kthread_worker___23 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___35 *task;
	struct kthread_work___23 *current_work;
};

struct kthread_delayed_work___23 {
	struct kthread_work___23 work;
	struct timer_list timer;
};

struct seq_operations___28 {
	void * (*start)(struct seq_file___31 *, loff_t *);
	void (*stop)(struct seq_file___31 *, void *);
	void * (*next)(struct seq_file___31 *, void *, loff_t *);
	int (*show)(struct seq_file___31 *, void *);
};

struct cgroup_namespace___23 {
	refcount_t count;
	struct ns_common___2 ns;
	struct user_namespace___24 *user_ns;
	struct ucounts___24 *ucounts;
	struct css_set___23 *root_cset;
};

struct ucounts___24 {
	struct hlist_node node;
	struct user_namespace___24 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___23;

struct bpf_map_ops___23 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___23 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___23 *, struct file___34 *);
	void (*map_free)(struct bpf_map___23 *);
	int (*map_get_next_key)(struct bpf_map___23 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___23 *);
	void * (*map_lookup_elem)(struct bpf_map___23 *, void *);
	int (*map_update_elem)(struct bpf_map___23 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___23 *, void *);
	int (*map_push_elem)(struct bpf_map___23 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___23 *, void *);
	int (*map_peek_elem)(struct bpf_map___23 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___23 *, struct file___34 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___23 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___23 *, void *, struct seq_file___31 *);
	int (*map_check_btf)(const struct bpf_map___23 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___23 {
	const struct bpf_map_ops___23 *ops;
	struct bpf_map___23 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___33 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct psi_group___23 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___23 *poll_kworker;
	struct kthread_delayed_work___23 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___23;

struct cgroup_rstat_cpu___23;

struct cgroup___23 {
	struct cgroup_subsys_state___23 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___31 *kn;
	struct cgroup_file___23 procs_file;
	struct cgroup_file___23 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___23 *subsys[13];
	struct cgroup_root___23 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___23 *dom_cgrp;
	struct cgroup_rstat_cpu___23 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___2 bpf;
	atomic_t congestion_count;
	struct cgroup___23 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___23 psi;
	int ancestor_ids[0];
};

struct cftype___23;

struct cgroup_subsys___23 {
	struct cgroup_subsys_state___23 * (*css_alloc)(struct cgroup_subsys_state___23 *);
	int (*css_online)(struct cgroup_subsys_state___23 *);
	void (*css_offline)(struct cgroup_subsys_state___23 *);
	void (*css_released)(struct cgroup_subsys_state___23 *);
	void (*css_free)(struct cgroup_subsys_state___23 *);
	void (*css_reset)(struct cgroup_subsys_state___23 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___23 *, int);
	int (*css_extra_stat_show)(struct seq_file___31 *, struct cgroup_subsys_state___23 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___35 *);
	void (*cancel_fork)(struct task_struct___35 *);
	void (*fork)(struct task_struct___35 *);
	void (*exit)(struct task_struct___35 *);
	void (*free)(struct task_struct___35 *);
	void (*bind)(struct cgroup_subsys_state___23 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___23 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___23 *dfl_cftypes;
	struct cftype___23 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___23 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___23 *updated_children;
	struct cgroup___23 *updated_next;
};

struct cgroup_root___23 {
	struct kernfs_root___31 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___23 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___23 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___23 *ss;
	struct list_head node;
	struct kernfs_ops___31 *kf_ops;
	int (*open)(struct kernfs_open_file___31 *);
	void (*release)(struct kernfs_open_file___31 *);
	u64 (*read_u64)(struct cgroup_subsys_state___23 *, struct cftype___23 *);
	s64 (*read_s64)(struct cgroup_subsys_state___23 *, struct cftype___23 *);
	int (*seq_show)(struct seq_file___31 *, void *);
	void * (*seq_start)(struct seq_file___31 *, loff_t *);
	void * (*seq_next)(struct seq_file___31 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___31 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___23 *, struct cftype___23 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___23 *, struct cftype___23 *, s64);
	ssize_t (*write)(struct kernfs_open_file___31 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___31 *, struct poll_table_struct___20 *);
};

struct bdi_writeback_congested___12 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___12 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___12 {
	struct bio___12 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___12 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___12 bip_inline_vecs[0];
};

struct bio_set___12 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___12 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___11 {
	struct mem_cgroup___11 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___11 {
	struct lruvec___33 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___11 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___11 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct irq_chip___7;

struct irq_data___8 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___3 *common;
	struct irq_chip___7 *chip;
	struct irq_domain *domain;
	struct irq_data___8 *parent_data;
	void *chip_data;
};

struct irq_chip___7 {
	struct device___29 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___8 *);
	void (*irq_shutdown)(struct irq_data___8 *);
	void (*irq_enable)(struct irq_data___8 *);
	void (*irq_disable)(struct irq_data___8 *);
	void (*irq_ack)(struct irq_data___8 *);
	void (*irq_mask)(struct irq_data___8 *);
	void (*irq_mask_ack)(struct irq_data___8 *);
	void (*irq_unmask)(struct irq_data___8 *);
	void (*irq_eoi)(struct irq_data___8 *);
	int (*irq_set_affinity)(struct irq_data___8 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___8 *);
	int (*irq_set_type)(struct irq_data___8 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___8 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___8 *);
	void (*irq_bus_sync_unlock)(struct irq_data___8 *);
	void (*irq_cpu_online)(struct irq_data___8 *);
	void (*irq_cpu_offline)(struct irq_data___8 *);
	void (*irq_suspend)(struct irq_data___8 *);
	void (*irq_resume)(struct irq_data___8 *);
	void (*irq_pm_shutdown)(struct irq_data___8 *);
	void (*irq_calc_mask)(struct irq_data___8 *);
	void (*irq_print_chip)(struct irq_data___8 *, struct seq_file___31 *);
	int (*irq_request_resources)(struct irq_data___8 *);
	void (*irq_release_resources)(struct irq_data___8 *);
	void (*irq_compose_msi_msg)(struct irq_data___8 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___8 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___8 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___8 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___8 *, void *);
	void (*ipi_send_single)(struct irq_data___8 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___8 *, const struct cpumask *);
	long unsigned int flags;
};

struct smp_hotplug_thread {
	struct task_struct___35 **store;
	struct list_head list;
	int (*thread_should_run)(unsigned int);
	void (*thread_fn)(unsigned int);
	void (*create)(unsigned int);
	void (*setup)(unsigned int);
	void (*cleanup)(unsigned int, bool);
	void (*park)(unsigned int);
	void (*unpark)(unsigned int);
	cpumask_var_t cpumask;
	bool selfparking;
	const char *thread_comm;
};

struct dev_pm_qos_request___2 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___29 *dev;
};

struct kernel_param_ops___28 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___28 *);
	int (*get)(char *, const struct kernel_param___28 *);
	void (*free)(void *);
};

struct kparam_array___28;

struct kernel_param___28 {
	const char *name;
	struct module___31 *mod;
	const struct kernel_param_ops___28 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___28 *arr;
	};
};

struct kparam_array___28 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___28 *ops;
	void *elem;
};

struct module_attribute___28 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___28 *, struct module_kobject___28 *, char *);
	ssize_t (*store)(struct module_attribute___28 *, struct module_kobject___28 *, const char *, size_t);
	void (*setup)(struct module___31 *, const char *);
	int (*test)(struct module___31 *);
	void (*free)(struct module___31 *);
};

struct trace_event_class___14;

struct trace_event_call___14 {
	struct list_head list;
	struct trace_event_class___14 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___2 *prog_array;
	int (*perf_perm)(struct trace_event_call___14 *, struct perf_event___19 *);
};

struct perf_cpu_context___19;

struct pmu___19 {
	struct list_head entry;
	struct module___31 *module;
	struct device___29 *dev;
	const struct attribute_group___29 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___19 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___19 *);
	void (*pmu_disable)(struct pmu___19 *);
	int (*event_init)(struct perf_event___19 *);
	void (*event_mapped)(struct perf_event___19 *, struct mm_struct___34 *);
	void (*event_unmapped)(struct perf_event___19 *, struct mm_struct___34 *);
	int (*add)(struct perf_event___19 *, int);
	void (*del)(struct perf_event___19 *, int);
	void (*start)(struct perf_event___19 *, int);
	void (*stop)(struct perf_event___19 *, int);
	void (*read)(struct perf_event___19 *);
	void (*start_txn)(struct pmu___19 *, unsigned int);
	int (*commit_txn)(struct pmu___19 *);
	void (*cancel_txn)(struct pmu___19 *);
	int (*event_idx)(struct perf_event___19 *);
	void (*sched_task)(struct perf_event_context___19 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___19 *);
	int (*filter_match)(struct perf_event___19 *);
	int (*check_period)(struct perf_event___19 *, u64);
};

struct perf_cpu_context___19 {
	struct perf_event_context___19 ctx;
	struct perf_event_context___19 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___19 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___19 {
	struct cgroup_subsys_state___23 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___14 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___14 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___14 *);
	struct list_head * (*get_fields)(struct trace_event_call___14 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___14 *);
};

struct trace_event_file___7;

struct trace_event_buffer___7 {
	struct ring_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___7 *trace_file;
	void *entry;
	long unsigned int flags;
	int pc;
};

struct trace_event_file___7 {
	struct list_head list;
	struct trace_event_call___14 *event_call;
	struct event_filter *filter;
	struct dentry___35 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_cpuhp_enter {
	struct trace_entry ent;
	unsigned int cpu;
	int target;
	int idx;
	void *fun;
	char __data[0];
};

struct trace_event_raw_cpuhp_multi_enter {
	struct trace_entry ent;
	unsigned int cpu;
	int target;
	int idx;
	void *fun;
	char __data[0];
};

struct trace_event_raw_cpuhp_exit {
	struct trace_entry ent;
	unsigned int cpu;
	int state;
	int idx;
	int ret;
	char __data[0];
};

struct trace_event_data_offsets_cpuhp_enter {};

struct trace_event_data_offsets_cpuhp_multi_enter {};

struct trace_event_data_offsets_cpuhp_exit {};

struct cpuhp_cpu_state {
	enum cpuhp_state state;
	enum cpuhp_state target;
	enum cpuhp_state fail;
	struct task_struct___35 *thread;
	bool should_run;
	bool rollback;
	bool single;
	bool bringup;
	bool booted_once;
	struct hlist_node *node;
	struct hlist_node *last;
	enum cpuhp_state cb_state;
	int result;
	struct completion done_up;
	struct completion done_down;
};

struct cpuhp_step {
	const char *name;
	union {
		int (*single)(unsigned int);
		int (*multi)(unsigned int, struct hlist_node *);
	} startup;
	union {
		int (*single)(unsigned int);
		int (*multi)(unsigned int, struct hlist_node *);
	} teardown;
	struct hlist_head list;
	bool skip_onerr;
	bool cant_stop;
	bool multi_instance;
};

enum cpu_mitigations {
	CPU_MITIGATIONS_OFF = 0,
	CPU_MITIGATIONS_AUTO = 1,
	CPU_MITIGATIONS_AUTO_NOSMT = 2,
};

typedef __kernel_long_t __kernel_suseconds_t;

struct module___32;

struct file___35;

struct kiocb___35;

struct iov_iter___14;

struct poll_table_struct___21;

struct vm_area_struct___35;

struct inode___37;

struct file_lock___35;

struct page___35;

struct pipe_inode_info___5;

struct seq_file___32;

struct file_operations___35 {
	struct module___32 *owner;
	loff_t (*llseek)(struct file___35 *, loff_t, int);
	ssize_t (*read)(struct file___35 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___35 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___35 *, struct iov_iter___14 *);
	ssize_t (*write_iter)(struct kiocb___35 *, struct iov_iter___14 *);
	int (*iopoll)(struct kiocb___35 *, bool);
	int (*iterate)(struct file___35 *, struct dir_context *);
	int (*iterate_shared)(struct file___35 *, struct dir_context *);
	__poll_t (*poll)(struct file___35 *, struct poll_table_struct___21 *);
	long int (*unlocked_ioctl)(struct file___35 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___35 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___35 *, struct vm_area_struct___35 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___37 *, struct file___35 *);
	int (*flush)(struct file___35 *, fl_owner_t);
	int (*release)(struct inode___37 *, struct file___35 *);
	int (*fsync)(struct file___35 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___35 *, int);
	int (*lock)(struct file___35 *, int, struct file_lock___35 *);
	ssize_t (*sendpage)(struct file___35 *, struct page___35 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___35 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___35 *, int, struct file_lock___35 *);
	ssize_t (*splice_write)(struct pipe_inode_info___5 *, struct file___35 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___35 *, loff_t *, struct pipe_inode_info___5 *, size_t, unsigned int);
	int (*setlease)(struct file___35 *, long int, struct file_lock___35 **, void **);
	long int (*fallocate)(struct file___35 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___32 *, struct file___35 *);
	ssize_t (*copy_file_range)(struct file___35 *, loff_t, struct file___35 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___35 *, loff_t, struct file___35 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___35 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct timeval {
	__kernel_time_t tv_sec;
	__kernel_suseconds_t tv_usec;
};

struct vmacache___34 {
	u64 seqnum;
	struct vm_area_struct___35 *vmas[4];
};

struct page_frag___34 {
	struct page___35 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___20;

struct debug_info___20 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___20 *hbp_break[16];
	struct perf_event___20 *hbp_watch[16];
};

struct thread_struct___20 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___20 debug;
	long: 64;
};

struct mm_struct___35;

struct mem_cgroup___12;

struct pid___30;

struct cred___34;

struct fs_struct___3;

struct files_struct___3;

struct nsproxy___33;

struct signal_struct___32;

struct bio_list___13;

struct backing_dev_info___13;

struct io_context___7;

struct css_set___24;

struct perf_event_context___20;

struct request_queue___8;

struct vm_struct___28;

struct task_struct___36 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___36 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___35 *mm;
	struct mm_struct___35 *active_mm;
	struct vmacache___34 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___36 *real_parent;
	struct task_struct___36 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___36 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___12 *active_memcg;
	long int rh_reserved2;
	struct pid___30 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___30 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___30 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___34 *ptracer_cred;
	const struct cred___34 *real_cred;
	const struct cred___34 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct___3 *fs;
	struct files_struct___3 *files;
	struct nsproxy___33 *nsproxy;
	struct signal_struct___32 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___36 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___13 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___13 *backing_dev_info;
	struct io_context___7 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___24 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___20 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___5 *splice_pipe;
	struct page_frag___34 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___12 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___8 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___36 *oom_reaper_list;
	struct vm_struct___28 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___20 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___20 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___36 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___20)(struct perf_event___20 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___20;

struct fasync_struct___34;

struct pid_namespace___30;

struct trace_event_call___15;

struct perf_cgroup___20;

struct perf_event___20 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___20 *group_leader;
	struct pmu___20 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___20 hw;
	struct perf_event_context___20 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___20 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___36 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___34 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___20 *);
	struct callback_head callback_head;
	struct pid_namespace___30 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___20 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___20 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___15 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___20 *cgrp;
	struct list_head sb_list;
};

typedef struct page___35 *pgtable_t___34;

struct address_space___34;

struct dev_pagemap___34;

struct page___35 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___34 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___35 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___34 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___35 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___34 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___12 *mem_cgroup;
};

struct pglist_data___34;

struct lruvec___34 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___34 *pgdat;
};

struct zone___34 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___34 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___34 {
	struct zone___34 *zone;
	int zone_idx;
};

struct zonelist___34 {
	struct zoneref___34 _zonerefs[25];
};

struct pglist_data___34 {
	struct zone___34 node_zones[3];
	struct zonelist___34 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___36 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___36 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___34 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___35 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___36 *owner;
};

struct secondary_data___35 {
	void *stack;
	struct task_struct___36 *task;
	long int status;
};

struct blocking_notifier_head___34 {
	struct rw_semaphore___35 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___34;

struct vm_area_struct___35 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___35 *vm_next;
	struct vm_area_struct___35 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___35 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___34 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___35 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct linux_binfmt___4;

struct core_state___34;

struct user_namespace___25;

struct mm_struct___35 {
	struct {
		struct vm_area_struct___35 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___35 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___35 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___4 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___34 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___36 *owner;
		struct user_namespace___25 *user_ns;
		struct file___35 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___34 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___34;

struct address_space___34 {
	struct inode___37 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___35 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___34 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___34)(struct vm_area_struct___35 *, long unsigned int, const struct page___35 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___34)(struct page___35 *, void *);

struct device___30;

struct dev_pagemap___34 {
	dev_page_fault_t___34 page_fault;
	dev_page_free_t___34 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___30 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct cgroup___24;

struct cgroup_subsys___24;

struct cgroup_subsys_state___24 {
	struct cgroup___24 *cgroup;
	struct cgroup_subsys___24 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___24 *parent;
};

struct mem_cgroup_id___9 {
	int id;
	union {
		refcount_t ref;
		struct {
			atomic_t ref;
		} __UNIQUE_ID_rh_kabi_hide49;
		union {		};
	};
};

struct kernfs_node___32;

struct cgroup_file___24 {
	struct kernfs_node___32 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___12;

struct mem_cgroup___12 {
	struct cgroup_subsys_state___24 css;
	struct mem_cgroup_id___9 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___24 events_file;
	struct cgroup_file___24 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___36 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___12 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct vfsmount___5;

struct dentry___36;

struct path___34 {
	struct vfsmount___5 *mnt;
	struct dentry___36 *dentry;
};

struct fown_struct___30 {
	rwlock_t lock;
	struct pid___30 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___35 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___34 f_path;
	struct inode___37 *f_inode;
	const struct file_operations___35 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___30 f_owner;
	const struct cred___34 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___34 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___34;

struct vm_operations_struct___34 {
	void (*open)(struct vm_area_struct___35 *);
	void (*close)(struct vm_area_struct___35 *);
	int (*split)(struct vm_area_struct___35 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___35 *);
	vm_fault_t (*fault)(struct vm_fault___34 *);
	vm_fault_t (*huge_fault)(struct vm_fault___34 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___34 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___35 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___34 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___34 *);
	int (*access)(struct vm_area_struct___35 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___35 *);
	int (*set_policy)(struct vm_area_struct___35 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___35 *, long unsigned int);
	struct page___35 * (*find_special_page)(struct vm_area_struct___35 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___34 {
	struct task_struct___36 *task;
	struct core_thread___34 *next;
};

struct core_state___34 {
	atomic_t nr_threads;
	struct core_thread___34 dumper;
	struct completion startup;
};

struct linux_binprm___4;

struct coredump_params___3;

struct linux_binfmt___4 {
	struct list_head lh;
	struct module___32 *module;
	int (*load_binary)(struct linux_binprm___4 *);
	int (*load_shlib)(struct file___35 *);
	int (*core_dump)(struct coredump_params___3 *);
	long unsigned int min_coredump;
};

struct key___35;

struct ucounts___25;

struct user_namespace___25 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___25 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___2 ns;
	long unsigned int flags;
	struct key___35 *persistent_keyring_register;
	struct rw_semaphore___35 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___25 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___34 {
	struct vm_area_struct___35 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___35 *cow_page;
	struct mem_cgroup___12 *memcg;
	struct page___35 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___34 prealloc_pte;
};

struct shrink_control___12 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___12 *memcg;
};

struct shrinker___12 {
	long unsigned int (*count_objects)(struct shrinker___12 *, struct shrink_control___12 *);
	long unsigned int (*scan_objects)(struct shrinker___12 *, struct shrink_control___12 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct rusage {
	struct timeval ru_utime;
	struct timeval ru_stime;
	__kernel_long_t ru_maxrss;
	__kernel_long_t ru_ixrss;
	__kernel_long_t ru_idrss;
	__kernel_long_t ru_isrss;
	__kernel_long_t ru_minflt;
	__kernel_long_t ru_majflt;
	__kernel_long_t ru_nswap;
	__kernel_long_t ru_inblock;
	__kernel_long_t ru_oublock;
	__kernel_long_t ru_msgsnd;
	__kernel_long_t ru_msgrcv;
	__kernel_long_t ru_nsignals;
	__kernel_long_t ru_nvcsw;
	__kernel_long_t ru_nivcsw;
};

struct upid___30 {
	int nr;
	struct pid_namespace___30 *ns;
};

struct pid_namespace___30 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___36 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___30 *parent;
	struct vfsmount___5 *proc_mnt;
	struct dentry___36 *proc_self;
	struct dentry___36 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___25 *user_ns;
	struct ucounts___25 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___2 ns;
};

struct pid___30 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___30 numbers[1];
};

struct user_struct___34 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___35 *uid_keyring;
	struct key___35 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___34 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___35 *session_keyring;
	struct key___35 *process_keyring;
	struct key___35 *thread_keyring;
	struct key___35 *request_key_auth;
	void *security;
	struct user_struct___34 *user;
	struct user_namespace___25 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct fs_struct___3 {
	int users;
	spinlock_t lock;
	seqcount_t seq;
	int umask;
	int in_exec;
	struct path___34 root;
	struct path___34 pwd;
};

struct fdtable___2 {
	unsigned int max_fds;
	struct file___35 **fd;
	long unsigned int *close_on_exec;
	long unsigned int *open_fds;
	long unsigned int *full_fds_bits;
	struct callback_head rcu;
};

struct files_struct___3 {
	atomic_t count;
	bool resize_in_progress;
	wait_queue_head_t resize_wait;
	struct fdtable___2 *fdt;
	struct fdtable___2 fdtab;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t file_lock;
	unsigned int next_fd;
	long unsigned int close_on_exec_init[1];
	long unsigned int open_fds_init[1];
	long unsigned int full_fds_bits_init[1];
	struct file___35 *fd_array[64];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct uts_namespace___7;

struct net___8;

struct cgroup_namespace___24;

struct nsproxy___33 {
	atomic_t count;
	struct uts_namespace___7 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___30 *pid_ns_for_children;
	struct net___8 *net_ns;
	struct cgroup_namespace___24 *cgroup_ns;
};

struct tty_struct___4;

struct signal_struct___32 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___36 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___36 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___30 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___30 *tty_old_pgrp;
	int leader;
	struct tty_struct___4 *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___35 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___30 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___13;

struct bio_list___13 {
	struct bio___13 *head;
	struct bio___13 *tail;
};

struct bdi_writeback_congested___13;

struct bdi_writeback___13 {
	struct backing_dev_info___13 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___13 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___24 *memcg_css;
	struct cgroup_subsys_state___24 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___13 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___13 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___30 *dev;
	struct device___30 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___36 *debug_dir;
	struct dentry___36 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___7;

struct io_context___7 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___7 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___24 {
	struct cgroup_subsys_state___24 *subsys[13];
	refcount_t refcount;
	struct css_set___24 *dom_cset;
	struct cgroup___24 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___24 *mg_src_cgrp;
	struct cgroup___24 *mg_dst_cgrp;
	struct css_set___24 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___20 {
	struct pmu___20 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___36 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___20 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___5;

struct pipe_inode_info___5 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___35 *tmp_page;
	struct fasync_struct___34 *fasync_readers;
	struct fasync_struct___34 *fasync_writers;
	struct pipe_buffer___5 *bufs;
	struct user_struct___34 *user;
};

typedef blk_qc_t make_request_fn___7(struct request_queue___8 *, struct bio___13 *);

struct request___8;

typedef int dma_drain_needed_fn___7(struct request___8 *);

struct kset___32;

struct kobj_type___32;

struct kobject___33 {
	const char *name;
	struct list_head entry;
	struct kobject___33 *parent;
	struct kset___32 *kset;
	struct kobj_type___32 *ktype;
	struct kernfs_node___32 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___7;

struct bsg_class_device___7 {
	struct device___30 *class_dev;
	int minor;
	struct request_queue___8 *queue;
	const struct bsg_ops___7 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___13 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___13 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___7;

struct blkcg_gq___4;

struct request_queue___8 {
	struct list_head queue_head;
	struct request___8 *last_merge;
	struct elevator_queue___7 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___7 *make_request_fn;
	dma_drain_needed_fn___7 *dma_drain_needed;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___13 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___33 kobj;
	struct kobject___33 *mq_kobj;
	struct blk_integrity integrity;
	struct device___30 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___4 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide38;
		union {		};
	};
	struct bsg_class_device___7 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___13 bio_split;
	struct dentry___36 *debugfs_dir;
	struct dentry___36 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___28 {
	struct vm_struct___28 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___35 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___32 {
	struct task_struct___36 task;
	long unsigned int stack[8192];
};

struct dev_pm_info___30 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___30 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___30;

struct bus_type___30;

struct device_driver___30;

struct dev_pm_domain___30;

struct dma_map_ops___7;

struct fwnode_handle___25;

struct class___30;

struct attribute_group___30;

struct device___30 {
	struct device___30 *parent;
	struct device_private *p;
	struct kobject___33 kobj;
	const char *init_name;
	const struct device_type___30 *type;
	struct mutex mutex;
	struct bus_type___30 *bus;
	struct device_driver___30 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___30 power;
	struct dev_pm_domain___30 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___7 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___25 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___30 *class;
	const struct attribute_group___30 **groups;
	void (*release)(struct device___30 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___34;

struct super_block___35;

struct dentry___36 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___36 *d_parent;
	struct qstr d_name;
	struct inode___37 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___34 *d_op;
	struct super_block___35 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___34;

struct block_device___35;

struct cdev___10;

struct inode___37 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___34 *i_op;
	struct super_block___35 *i_sb;
	struct address_space___34 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___35 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___13 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___35 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___34 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___5 *i_pipe;
		struct block_device___35 *i_bdev;
		struct cdev___10 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___34 {
	int (*d_revalidate)(struct dentry___36 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___36 *, unsigned int);
	int (*d_hash)(const struct dentry___36 *, struct qstr *);
	int (*d_compare)(const struct dentry___36 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___36 *);
	int (*d_init)(struct dentry___36 *);
	void (*d_release)(struct dentry___36 *);
	void (*d_prune)(struct dentry___36 *);
	void (*d_iput)(struct dentry___36 *, struct inode___37 *);
	char * (*d_dname)(struct dentry___36 *, char *, int);
	struct vfsmount___5 * (*d_automount)(struct path___34 *);
	int (*d_manage)(const struct path___34 *, bool);
	struct dentry___36 * (*d_real)(struct dentry___36 *, const struct inode___37 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___34;

struct mem_dqinfo___34 {
	struct quota_format_type___34 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___34;

struct quota_info___34 {
	unsigned int flags;
	struct rw_semaphore___35 dqio_sem;
	struct inode___37 *files[3];
	struct mem_dqinfo___34 info[3];
	const struct quota_format_ops___34 *ops[3];
};

struct rcuwait___34 {
	struct task_struct___36 *task;
};

struct percpu_rw_semaphore___34 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___35 rw_sem;
	struct rcuwait___34 writer;
	int readers_block;
};

struct sb_writers___34 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___34 rw_sem[3];
};

struct file_system_type___34;

struct super_operations___34;

struct dquot_operations___34;

struct quotactl_ops___34;

struct super_block___35 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___34 *s_type;
	const struct super_operations___34 *s_op;
	const struct dquot_operations___34 *dq_op;
	const struct quotactl_ops___34 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___36 *s_root;
	struct rw_semaphore___35 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___35 *s_bdev;
	struct backing_dev_info___13 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___34 s_dquot;
	struct sb_writers___34 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___34 *s_d_op;
	int cleancache_poolid;
	struct shrinker___12 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___25 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___5 {
	struct dentry___36 *mnt_root;
	struct super_block___35 *mnt_sb;
	int mnt_flags;
};

struct io_cq___7 {
	struct request_queue___8 *q;
	struct io_context___7 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___35 {
	struct file___35 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___35 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___35 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___35 *ia_file;
};

struct dquot___34 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___35 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___34 {
	int qf_fmt_id;
	const struct quota_format_ops___34 *qf_ops;
	struct module___32 *qf_owner;
	struct quota_format_type___34 *qf_next;
};

struct quota_format_ops___34 {
	int (*check_quota_file)(struct super_block___35 *, int);
	int (*read_file_info)(struct super_block___35 *, int);
	int (*write_file_info)(struct super_block___35 *, int);
	int (*free_file_info)(struct super_block___35 *, int);
	int (*read_dqblk)(struct dquot___34 *);
	int (*commit_dqblk)(struct dquot___34 *);
	int (*release_dqblk)(struct dquot___34 *);
	int (*get_next_id)(struct super_block___35 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___34 {
	int (*write_dquot)(struct dquot___34 *);
	struct dquot___34 * (*alloc_dquot)(struct super_block___35 *, int);
	void (*destroy_dquot)(struct dquot___34 *);
	int (*acquire_dquot)(struct dquot___34 *);
	int (*release_dquot)(struct dquot___34 *);
	int (*mark_dirty)(struct dquot___34 *);
	int (*write_info)(struct super_block___35 *, int);
	qsize_t * (*get_reserved_space)(struct inode___37 *);
	int (*get_projid)(struct inode___37 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___37 *, qsize_t *);
	int (*get_next_id)(struct super_block___35 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___34 {
	int (*quota_on)(struct super_block___35 *, int, int, const struct path___34 *);
	int (*quota_off)(struct super_block___35 *, int);
	int (*quota_enable)(struct super_block___35 *, unsigned int);
	int (*quota_disable)(struct super_block___35 *, unsigned int);
	int (*quota_sync)(struct super_block___35 *, int);
	int (*set_info)(struct super_block___35 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___35 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___35 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___35 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___35 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___35 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___29 {
	struct kobject___33 kobj;
	struct module___32 *mod;
	struct kobject___33 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___29 {
	struct module___32 *mod;
	struct latch_tree_node node;
};

struct module_layout___29 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___29 mtn;
};

struct module_attribute___29;

struct kernel_param___29;

struct module___32 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___29 mkobj;
	struct module_attribute___29 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___33 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___29 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___29 core_layout;
	struct module_layout___29 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___15 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___12;

struct address_space_operations___34 {
	int (*writepage)(struct page___35 *, struct writeback_control___12 *);
	int (*readpage)(struct file___35 *, struct page___35 *);
	int (*writepages)(struct address_space___34 *, struct writeback_control___12 *);
	int (*set_page_dirty)(struct page___35 *);
	int (*readpages)(struct file___35 *, struct address_space___34 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___35 *, struct address_space___34 *, loff_t, unsigned int, unsigned int, struct page___35 **, void **);
	int (*write_end)(struct file___35 *, struct address_space___34 *, loff_t, unsigned int, unsigned int, struct page___35 *, void *);
	sector_t (*bmap)(struct address_space___34 *, sector_t);
	void (*invalidatepage)(struct page___35 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___35 *, gfp_t);
	void (*freepage)(struct page___35 *);
	ssize_t (*direct_IO)(struct kiocb___35 *, struct iov_iter___14 *);
	int (*migratepage)(struct address_space___34 *, struct page___35 *, struct page___35 *, enum migrate_mode);
	bool (*isolate_page)(struct page___35 *, isolate_mode_t);
	void (*putback_page)(struct page___35 *);
	int (*launder_page)(struct page___35 *);
	int (*is_partially_uptodate)(struct page___35 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___35 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___34 *, struct page___35 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___35 *, sector_t *);
	void (*swap_deactivate)(struct file___35 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___12 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___13 *wb;
	struct inode___37 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___13;

struct iov_iter___14 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___13 *bvec;
		struct pipe_inode_info___5 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct hd_struct___7;

struct gendisk___7;

struct block_device___35 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___37 *bd_inode;
	struct super_block___35 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___35 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___7 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___7 *bd_disk;
	struct request_queue___8 *bd_queue;
	struct backing_dev_info___13 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct hd_struct___7 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___30 __dev;
	struct kobject___33 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___7;

struct block_device_operations___7;

struct gendisk___7 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___7 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___7 *part_tbl;
	struct hd_struct___7 part0;
	const struct block_device_operations___7 *fops;
	struct request_queue___8 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___35 lookup_sem;
	struct kobject___33 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___33 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___10 {
	struct kobject___33 kobj;
	struct module___32 *owner;
	const struct file_operations___35 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___34 {
	struct dentry___36 * (*lookup)(struct inode___37 *, struct dentry___36 *, unsigned int);
	const char * (*get_link)(struct dentry___36 *, struct inode___37 *, struct delayed_call *);
	int (*permission)(struct inode___37 *, int);
	struct posix_acl * (*get_acl)(struct inode___37 *, int);
	int (*readlink)(struct dentry___36 *, char *, int);
	int (*create)(struct inode___37 *, struct dentry___36 *, umode_t, bool);
	int (*link)(struct dentry___36 *, struct inode___37 *, struct dentry___36 *);
	int (*unlink)(struct inode___37 *, struct dentry___36 *);
	int (*symlink)(struct inode___37 *, struct dentry___36 *, const char *);
	int (*mkdir)(struct inode___37 *, struct dentry___36 *, umode_t);
	int (*rmdir)(struct inode___37 *, struct dentry___36 *);
	int (*mknod)(struct inode___37 *, struct dentry___36 *, umode_t, dev_t);
	int (*rename)(struct inode___37 *, struct dentry___36 *, struct inode___37 *, struct dentry___36 *, unsigned int);
	int (*setattr)(struct dentry___36 *, struct iattr___35 *);
	int (*getattr)(const struct path___34 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___36 *, char *, size_t);
	int (*fiemap)(struct inode___37 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___37 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___37 *, struct dentry___36 *, struct file___35 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___37 *, struct dentry___36 *, umode_t);
	int (*set_acl)(struct inode___37 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___34 {
	void (*fl_copy_lock)(struct file_lock___35 *, struct file_lock___35 *);
	void (*fl_release_private)(struct file_lock___35 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___34;

struct file_lock___35 {
	struct file_lock___35 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___35 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___34 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___34 *fl_ops;
	const struct lock_manager_operations___34 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___34 {
	int (*lm_compare_owner)(struct file_lock___35 *, struct file_lock___35 *);
	long unsigned int (*lm_owner_key)(struct file_lock___35 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___35 *);
	int (*lm_grant)(struct file_lock___35 *, int);
	bool (*lm_break)(struct file_lock___35 *);
	int (*lm_change)(struct file_lock___35 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___35 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___34 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___34 *fa_next;
	struct file___35 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___34 {
	const char *name;
	int fs_flags;
	struct dentry___36 * (*mount)(struct file_system_type___34 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___35 *);
	struct module___32 *owner;
	struct file_system_type___34 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___34 {
	struct inode___37 * (*alloc_inode)(struct super_block___35 *);
	void (*destroy_inode)(struct inode___37 *);
	void (*dirty_inode)(struct inode___37 *, int);
	int (*write_inode)(struct inode___37 *, struct writeback_control___12 *);
	int (*drop_inode)(struct inode___37 *);
	void (*evict_inode)(struct inode___37 *);
	void (*put_super)(struct super_block___35 *);
	int (*sync_fs)(struct super_block___35 *, int);
	int (*freeze_super)(struct super_block___35 *);
	int (*freeze_fs)(struct super_block___35 *);
	int (*thaw_super)(struct super_block___35 *);
	int (*unfreeze_fs)(struct super_block___35 *);
	int (*statfs)(struct dentry___36 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___35 *, int *, char *);
	void (*umount_begin)(struct super_block___35 *);
	int (*show_options)(struct seq_file___32 *, struct dentry___36 *);
	int (*show_devname)(struct seq_file___32 *, struct dentry___36 *);
	int (*show_path)(struct seq_file___32 *, struct dentry___36 *);
	int (*show_stats)(struct seq_file___32 *, struct dentry___36 *);
	ssize_t (*quota_read)(struct super_block___35 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___35 *, int, const char *, size_t, loff_t);
	struct dquot___34 ** (*get_dquots)(struct inode___37 *);
	int (*bdev_try_to_free_page)(struct super_block___35 *, struct page___35 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___35 *, struct shrink_control___12 *);
	long int (*free_cached_objects)(struct super_block___35 *, struct shrink_control___12 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___20)(struct file___35 *, wait_queue_head_t *, struct poll_table_struct___21 *);

struct poll_table_struct___21 {
	poll_queue_proc___20 _qproc;
	__poll_t _key;
};

struct seq_operations___29;

struct seq_file___32 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___29 *op;
	int poll_event;
	const struct file___35 *file;
	void *private;
};

typedef void bio_end_io_t___13(struct bio___13 *);

struct bio_vec___13 {
	struct page___35 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___13;

struct bio___13 {
	struct bio___13 *bi_next;
	struct gendisk___7 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___13 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___4 *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___13 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___13 *bi_io_vec;
	struct bio_set___13 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___13 bi_inline_vecs[0];
};

struct kobj_attribute___33 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___33 *, struct kobj_attribute___33 *, char *);
	ssize_t (*store)(struct kobject___33 *, struct kobj_attribute___33 *, const char *, size_t);
};

typedef void compound_page_dtor___34(struct page___35 *);

typedef int (*key_restrict_link_func_t___34)(struct key___35 *, const struct key_type *, const union key_payload *, struct key___35 *);

struct key_restriction___35;

struct key___35 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___35 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___35 *restrict_link;
};

struct key_restriction___35 {
	key_restrict_link_func_t___34 check;
	struct key___35 *key;
	struct key_type *keytype;
};

struct tty_driver___5;

struct tty_operations___4;

struct tty_ldisc___4;

struct tty_port___4;

struct tty_struct___4 {
	int magic;
	struct kref kref;
	struct device___30 *dev;
	struct tty_driver___5 *driver;
	const struct tty_operations___4 *ops;
	int index;
	struct ld_semaphore ldisc_sem;
	struct tty_ldisc___4 *ldisc;
	struct mutex atomic_write_lock;
	struct mutex legacy_mutex;
	struct mutex throttle_mutex;
	struct rw_semaphore___35 termios_rwsem;
	struct mutex winsize_mutex;
	spinlock_t ctrl_lock;
	spinlock_t flow_lock;
	struct ktermios termios;
	struct ktermios termios_locked;
	struct termiox *termiox;
	char name[64];
	struct pid___30 *pgrp;
	struct pid___30 *session;
	long unsigned int flags;
	int count;
	struct winsize winsize;
	long unsigned int stopped: 1;
	long unsigned int flow_stopped: 1;
	int: 30;
	long unsigned int unused: 62;
	int hw_stopped;
	long unsigned int ctrl_status: 8;
	long unsigned int packet: 1;
	int: 23;
	long unsigned int unused_ctrl: 55;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___4 *link;
	struct fasync_struct___34 *fasync;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	spinlock_t files_lock;
	struct list_head tty_files;
	int closing;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___4 *port;
};

struct kernfs_root___32;

struct kernfs_elem_dir___32 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___32 *root;
};

struct kernfs_syscall_ops___32;

struct kernfs_root___32 {
	struct kernfs_node___32 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___32 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___32 {
	struct kernfs_node___32 *target_kn;
};

struct kernfs_ops___32;

struct kernfs_elem_attr___32 {
	const struct kernfs_ops___32 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___32 *notify_next;
};

struct kernfs_node___32 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___32 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___32 dir;
		struct kernfs_elem_symlink___32 symlink;
		struct kernfs_elem_attr___32 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___32;

struct kernfs_ops___32 {
	int (*open)(struct kernfs_open_file___32 *);
	void (*release)(struct kernfs_open_file___32 *);
	int (*seq_show)(struct seq_file___32 *, void *);
	void * (*seq_start)(struct seq_file___32 *, loff_t *);
	void * (*seq_next)(struct seq_file___32 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___32 *, void *);
	ssize_t (*read)(struct kernfs_open_file___32 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___32 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___32 *, struct vm_area_struct___35 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___32 *, struct poll_table_struct___21 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___32 {
	int (*remount_fs)(struct kernfs_root___32 *, int *, char *);
	int (*show_options)(struct seq_file___32 *, struct kernfs_root___32 *);
	int (*mkdir)(struct kernfs_node___32 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___32 *);
	int (*rename)(struct kernfs_node___32 *, struct kernfs_node___32 *, const char *);
	int (*show_path)(struct seq_file___32 *, struct kernfs_node___32 *, struct kernfs_root___32 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___32 {
	struct kernfs_node___32 *kn;
	struct file___35 *file;
	struct seq_file___32 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___34 *vm_ops;
};

struct bin_attribute___30;

struct attribute_group___30 {
	const char *name;
	umode_t (*is_visible)(struct kobject___33 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___33 *, struct bin_attribute___30 *, int);
	struct attribute **attrs;
	struct bin_attribute___30 **bin_attrs;
};

struct bin_attribute___30 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___35 *, struct kobject___33 *, struct bin_attribute___30 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___35 *, struct kobject___33 *, struct bin_attribute___30 *, char *, loff_t, size_t);
	int (*mmap)(struct file___35 *, struct kobject___33 *, struct bin_attribute___30 *, struct vm_area_struct___35 *);
};

struct sysfs_ops___32 {
	ssize_t (*show)(struct kobject___33 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___33 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___32;

struct kset___32 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___33 kobj;
	const struct kset_uevent_ops___32 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___32 {
	void (*release)(struct kobject___33 *);
	const struct sysfs_ops___32 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___33 *);
	const void * (*namespace)(struct kobject___33 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___32 {
	int (* const filter)(struct kset___32 *, struct kobject___33 *);
	const char * (* const name)(struct kset___32 *, struct kobject___33 *);
	int (* const uevent)(struct kset___32 *, struct kobject___33 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___29 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___29 *);
	int (*get)(char *, const struct kernel_param___29 *);
	void (*free)(void *);
};

struct kparam_array___29;

struct kernel_param___29 {
	const char *name;
	struct module___32 *mod;
	const struct kernel_param_ops___29 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___29 *arr;
	};
};

struct kparam_array___29 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___29 *ops;
	void *elem;
};

struct module_attribute___29 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___29 *, struct module_kobject___29 *, char *);
	ssize_t (*store)(struct module_attribute___29 *, struct module_kobject___29 *, const char *, size_t);
	void (*setup)(struct module___32 *, const char *);
	int (*test)(struct module___32 *);
	void (*free)(struct module___32 *);
};

struct trace_event_class___15;

struct trace_event_call___15 {
	struct list_head list;
	struct trace_event_class___15 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___2 *prog_array;
	int (*perf_perm)(struct trace_event_call___15 *, struct perf_event___20 *);
};

struct dev_pm_ops___30 {
	int (*prepare)(struct device___30 *);
	void (*complete)(struct device___30 *);
	int (*suspend)(struct device___30 *);
	int (*resume)(struct device___30 *);
	int (*freeze)(struct device___30 *);
	int (*thaw)(struct device___30 *);
	int (*poweroff)(struct device___30 *);
	int (*restore)(struct device___30 *);
	int (*suspend_late)(struct device___30 *);
	int (*resume_early)(struct device___30 *);
	int (*freeze_late)(struct device___30 *);
	int (*thaw_early)(struct device___30 *);
	int (*poweroff_late)(struct device___30 *);
	int (*restore_early)(struct device___30 *);
	int (*suspend_noirq)(struct device___30 *);
	int (*resume_noirq)(struct device___30 *);
	int (*freeze_noirq)(struct device___30 *);
	int (*thaw_noirq)(struct device___30 *);
	int (*poweroff_noirq)(struct device___30 *);
	int (*restore_noirq)(struct device___30 *);
	int (*runtime_suspend)(struct device___30 *);
	int (*runtime_resume)(struct device___30 *);
	int (*runtime_idle)(struct device___30 *);
};

struct dev_pm_domain___30 {
	struct dev_pm_ops___30 ops;
	void (*detach)(struct device___30 *, bool);
	int (*activate)(struct device___30 *);
	void (*sync)(struct device___30 *);
	void (*dismiss)(struct device___30 *);
};

struct bus_type___30 {
	const char *name;
	const char *dev_name;
	struct device___30 *dev_root;
	const struct attribute_group___30 **bus_groups;
	const struct attribute_group___30 **dev_groups;
	const struct attribute_group___30 **drv_groups;
	int (*match)(struct device___30 *, struct device_driver___30 *);
	int (*uevent)(struct device___30 *, struct kobj_uevent_env *);
	int (*probe)(struct device___30 *);
	int (*remove)(struct device___30 *);
	void (*shutdown)(struct device___30 *);
	int (*online)(struct device___30 *);
	int (*offline)(struct device___30 *);
	int (*suspend)(struct device___30 *, pm_message_t);
	int (*resume)(struct device___30 *);
	int (*num_vf)(struct device___30 *);
	int (*dma_configure)(struct device___30 *);
	const struct dev_pm_ops___30 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___30 {
	const char *name;
	struct bus_type___30 *bus;
	struct module___32 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___30 *);
	int (*remove)(struct device___30 *);
	void (*shutdown)(struct device___30 *);
	int (*suspend)(struct device___30 *, pm_message_t);
	int (*resume)(struct device___30 *);
	const struct attribute_group___30 **groups;
	const struct dev_pm_ops___30 *pm;
	void (*coredump)(struct device___30 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___30 {
	const char *name;
	const struct attribute_group___30 **groups;
	int (*uevent)(struct device___30 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___30 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___30 *);
	const struct dev_pm_ops___30 *pm;
};

struct class___30 {
	const char *name;
	struct module___32 *owner;
	const struct attribute_group___30 **class_groups;
	const struct attribute_group___30 **dev_groups;
	struct kobject___33 *dev_kobj;
	int (*dev_uevent)(struct device___30 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___30 *, umode_t *);
	void (*class_release)(struct class___30 *);
	void (*dev_release)(struct device___30 *);
	int (*shutdown_pre)(struct device___30 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___30 *);
	const struct dev_pm_ops___30 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___7 {
	void * (*alloc)(struct device___30 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___30 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___30 *, struct vm_area_struct___35 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___30 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___30 *, struct page___35 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___30 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___30 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___30 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___30 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___30 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___30 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide50;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___30 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___30 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___30 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___30 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___30 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___30 *, u64);
	u64 (*get_required_mask)(struct device___30 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___25;

struct fwnode_handle___25 {
	struct fwnode_handle___25 *secondary;
	const struct fwnode_operations___25 *ops;
};

struct seq_operations___29 {
	void * (*start)(struct seq_file___32 *, loff_t *);
	void (*stop)(struct seq_file___32 *, void *);
	void * (*next)(struct seq_file___32 *, void *, loff_t *);
	int (*show)(struct seq_file___32 *, void *);
};

struct tty_operations___4 {
	struct tty_struct___4 * (*lookup)(struct tty_driver___5 *, struct file___35 *, int);
	int (*install)(struct tty_driver___5 *, struct tty_struct___4 *);
	void (*remove)(struct tty_driver___5 *, struct tty_struct___4 *);
	int (*open)(struct tty_struct___4 *, struct file___35 *);
	void (*close)(struct tty_struct___4 *, struct file___35 *);
	void (*shutdown)(struct tty_struct___4 *);
	void (*cleanup)(struct tty_struct___4 *);
	int (*write)(struct tty_struct___4 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___4 *, unsigned char);
	void (*flush_chars)(struct tty_struct___4 *);
	int (*write_room)(struct tty_struct___4 *);
	int (*chars_in_buffer)(struct tty_struct___4 *);
	int (*ioctl)(struct tty_struct___4 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___4 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___4 *, struct ktermios *);
	void (*throttle)(struct tty_struct___4 *);
	void (*unthrottle)(struct tty_struct___4 *);
	void (*stop)(struct tty_struct___4 *);
	void (*start)(struct tty_struct___4 *);
	void (*hangup)(struct tty_struct___4 *);
	int (*break_ctl)(struct tty_struct___4 *, int);
	void (*flush_buffer)(struct tty_struct___4 *);
	void (*set_ldisc)(struct tty_struct___4 *);
	void (*wait_until_sent)(struct tty_struct___4 *, int);
	void (*send_xchar)(struct tty_struct___4 *, char);
	int (*tiocmget)(struct tty_struct___4 *);
	int (*tiocmset)(struct tty_struct___4 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___4 *, struct winsize *);
	int (*set_termiox)(struct tty_struct___4 *, struct termiox *);
	int (*get_icount)(struct tty_struct___4 *, struct serial_icounter_struct *);
	void (*show_fdinfo)(struct tty_struct___4 *, struct seq_file___32 *);
	int (*poll_init)(struct tty_driver___5 *, int, char *);
	int (*poll_get_char)(struct tty_driver___5 *, int);
	void (*poll_put_char)(struct tty_driver___5 *, int, char);
	int (*proc_show)(struct seq_file___32 *, void *);
};

struct tty_driver___5 {
	int magic;
	struct kref kref;
	struct cdev___10 **cdevs;
	struct module___32 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___5 *other;
	struct tty_struct___4 **ttys;
	struct tty_port___4 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___4 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___4;

struct tty_port_client_operations___4;

struct tty_port___4 {
	struct tty_bufhead buf;
	struct tty_struct___4 *tty;
	struct tty_struct___4 *itty;
	const struct tty_port_operations___4 *ops;
	const struct tty_port_client_operations___4 *client_ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	unsigned char low_latency: 1;
	struct mutex mutex;
	struct mutex buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
	void *client_data;
};

struct tty_ldisc_ops___4 {
	int magic;
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___4 *);
	void (*close)(struct tty_struct___4 *);
	void (*flush_buffer)(struct tty_struct___4 *);
	ssize_t (*read)(struct tty_struct___4 *, struct file___35 *, unsigned char *, size_t);
	ssize_t (*write)(struct tty_struct___4 *, struct file___35 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___4 *, struct file___35 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___4 *, struct file___35 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___4 *, struct ktermios *);
	__poll_t (*poll)(struct tty_struct___4 *, struct file___35 *, struct poll_table_struct___21 *);
	int (*hangup)(struct tty_struct___4 *);
	void (*receive_buf)(struct tty_struct___4 *, const unsigned char *, char *, int);
	void (*write_wakeup)(struct tty_struct___4 *);
	void (*dcd_change)(struct tty_struct___4 *, unsigned int);
	int (*receive_buf2)(struct tty_struct___4 *, const unsigned char *, char *, int);
	struct module___32 *owner;
	int refcount;
};

struct tty_ldisc___4 {
	struct tty_ldisc_ops___4 *ops;
	struct tty_struct___4 *tty;
};

struct tty_port_operations___4 {
	int (*carrier_raised)(struct tty_port___4 *);
	void (*dtr_rts)(struct tty_port___4 *, int);
	void (*shutdown)(struct tty_port___4 *);
	int (*activate)(struct tty_port___4 *, struct tty_struct___4 *);
	void (*destruct)(struct tty_port___4 *);
};

struct tty_port_client_operations___4 {
	int (*receive_buf)(struct tty_port___4 *, const unsigned char *, const unsigned char *, size_t);
	void (*write_wakeup)(struct tty_port___4 *);
};

struct node___28 {
	struct device___30 dev;
};

struct linux_binprm___4 {
	char buf[256];
	struct vm_area_struct___35 *vma;
	long unsigned int vma_pages;
	struct mm_struct___35 *mm;
	long unsigned int p;
	unsigned int called_set_creds: 1;
	unsigned int cap_elevated: 1;
	unsigned int secureexec: 1;
	unsigned int recursion_depth;
	struct file___35 *file;
	struct cred___34 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
};

struct coredump_params___3 {
	union {
		const kernel_siginfo_t *siginfo;
		struct {
			const siginfo_t *siginfo;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	struct pt_regs *regs;
	struct file___35 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
};

struct uts_namespace___7 {
	struct kref kref;
	struct new_utsname name;
	struct user_namespace___25 *user_ns;
	struct ucounts___25 *ucounts;
	struct ns_common___2 ns;
};

struct dst_ops___6 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___6 *);
	struct dst_entry___2 * (*check)(struct dst_entry___2 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___2 *);
	unsigned int (*mtu)(const struct dst_entry___2 *);
	u32 * (*cow_metrics)(struct dst_entry___2 *, long unsigned int);
	void (*destroy)(struct dst_entry___2 *);
	void (*ifdown)(struct dst_entry___2 *, struct net_device *, int);
	struct dst_entry___2 * (*negative_advice)(struct dst_entry___2 *);
	void (*link_failure)(struct sk_buff___4 *);
	void (*update_pmtu)(struct dst_entry___2 *, struct sock *, struct sk_buff___4 *, u32);
	void (*redirect)(struct dst_entry___2 *, struct sock *, struct sk_buff___4 *);
	int (*local_out)(struct net___8 *, struct sock *, struct sk_buff___4 *);
	struct neighbour___2 * (*neigh_lookup)(const struct dst_entry___2 *, struct sk_buff___4 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___2 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___5 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___2 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___6 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct sock *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops *notifier_ops;
	struct fib_notifier_ops *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_xfrm___5 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___6 xfrm4_dst_ops;
	struct dst_ops___6 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct net___8 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___25 *user_ns;
	struct ucounts___25 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___2 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___2 ipv4;
	struct netns_ipv6___5 ipv6;
	struct netns_sctp sctp;
	struct netns_nf nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___2 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock *nfnl;
	struct sock *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___5 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cgroup_namespace___24 {
	refcount_t count;
	struct ns_common___2 ns;
	struct user_namespace___25 *user_ns;
	struct ucounts___25 *ucounts;
	struct css_set___24 *root_cset;
};

struct ucounts___25 {
	struct hlist_node node;
	struct user_namespace___25 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct kthread_work___24;

typedef void (*kthread_work_func_t___24)(struct kthread_work___24 *);

struct kthread_worker___24;

struct kthread_work___24 {
	struct list_head node;
	kthread_work_func_t___24 func;
	struct kthread_worker___24 *worker;
	int canceling;
};

struct kthread_worker___24 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___36 *task;
	struct kthread_work___24 *current_work;
};

struct kthread_delayed_work___24 {
	struct kthread_work___24 work;
	struct timer_list timer;
};

struct bpf_map___24;

struct bpf_map_ops___24 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___24 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___24 *, struct file___35 *);
	void (*map_free)(struct bpf_map___24 *);
	int (*map_get_next_key)(struct bpf_map___24 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___24 *);
	void * (*map_lookup_elem)(struct bpf_map___24 *, void *);
	int (*map_update_elem)(struct bpf_map___24 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___24 *, void *);
	int (*map_push_elem)(struct bpf_map___24 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___24 *, void *);
	int (*map_peek_elem)(struct bpf_map___24 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___24 *, struct file___35 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___24 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___24 *, void *, struct seq_file___32 *);
	int (*map_check_btf)(const struct bpf_map___24 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___24 {
	const struct bpf_map_ops___24 *ops;
	struct bpf_map___24 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___34 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct psi_group___24 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___24 *poll_kworker;
	struct kthread_delayed_work___24 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___24;

struct cgroup_rstat_cpu___24;

struct cgroup___24 {
	struct cgroup_subsys_state___24 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___32 *kn;
	struct cgroup_file___24 procs_file;
	struct cgroup_file___24 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___24 *subsys[13];
	struct cgroup_root___24 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___24 *dom_cgrp;
	struct cgroup_rstat_cpu___24 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___2 bpf;
	atomic_t congestion_count;
	struct cgroup___24 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___24 psi;
	int ancestor_ids[0];
};

struct cftype___24;

struct cgroup_subsys___24 {
	struct cgroup_subsys_state___24 * (*css_alloc)(struct cgroup_subsys_state___24 *);
	int (*css_online)(struct cgroup_subsys_state___24 *);
	void (*css_offline)(struct cgroup_subsys_state___24 *);
	void (*css_released)(struct cgroup_subsys_state___24 *);
	void (*css_free)(struct cgroup_subsys_state___24 *);
	void (*css_reset)(struct cgroup_subsys_state___24 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___24 *, int);
	int (*css_extra_stat_show)(struct seq_file___32 *, struct cgroup_subsys_state___24 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___36 *);
	void (*cancel_fork)(struct task_struct___36 *);
	void (*fork)(struct task_struct___36 *);
	void (*exit)(struct task_struct___36 *);
	void (*free)(struct task_struct___36 *);
	void (*bind)(struct cgroup_subsys_state___24 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___24 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___24 *dfl_cftypes;
	struct cftype___24 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___24 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___24 *updated_children;
	struct cgroup___24 *updated_next;
};

struct cgroup_root___24 {
	struct kernfs_root___32 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___24 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___24 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___24 *ss;
	struct list_head node;
	struct kernfs_ops___32 *kf_ops;
	int (*open)(struct kernfs_open_file___32 *);
	void (*release)(struct kernfs_open_file___32 *);
	u64 (*read_u64)(struct cgroup_subsys_state___24 *, struct cftype___24 *);
	s64 (*read_s64)(struct cgroup_subsys_state___24 *, struct cftype___24 *);
	int (*seq_show)(struct seq_file___32 *, void *);
	void * (*seq_start)(struct seq_file___32 *, loff_t *);
	void * (*seq_next)(struct seq_file___32 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___32 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___24 *, struct cftype___24 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___24 *, struct cftype___24 *, s64);
	ssize_t (*write)(struct kernfs_open_file___32 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___32 *, struct poll_table_struct___21 *);
};

struct perf_cpu_context___20;

struct pmu___20 {
	struct list_head entry;
	struct module___32 *module;
	struct device___30 *dev;
	const struct attribute_group___30 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___20 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___20 *);
	void (*pmu_disable)(struct pmu___20 *);
	int (*event_init)(struct perf_event___20 *);
	void (*event_mapped)(struct perf_event___20 *, struct mm_struct___35 *);
	void (*event_unmapped)(struct perf_event___20 *, struct mm_struct___35 *);
	int (*add)(struct perf_event___20 *, int);
	void (*del)(struct perf_event___20 *, int);
	void (*start)(struct perf_event___20 *, int);
	void (*stop)(struct perf_event___20 *, int);
	void (*read)(struct perf_event___20 *);
	void (*start_txn)(struct pmu___20 *, unsigned int);
	int (*commit_txn)(struct pmu___20 *);
	void (*cancel_txn)(struct pmu___20 *);
	int (*event_idx)(struct perf_event___20 *);
	void (*sched_task)(struct perf_event_context___20 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___20 *);
	int (*filter_match)(struct perf_event___20 *);
	int (*check_period)(struct perf_event___20 *, u64);
};

struct perf_cpu_context___20 {
	struct perf_event_context___20 ctx;
	struct perf_event_context___20 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___20 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___20 {
	struct cgroup_subsys_state___24 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___15 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___15 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___15 *);
	struct list_head * (*get_fields)(struct trace_event_call___15 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___15 *);
};

struct syscall_metadata___5 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___15 *enter_event;
	struct trace_event_call___15 *exit_event;
};

struct pipe_buf_operations___5;

struct pipe_buffer___5 {
	struct page___35 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___5 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___5 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___5 *, struct pipe_buffer___5 *);
	void (*release)(struct pipe_inode_info___5 *, struct pipe_buffer___5 *);
	int (*steal)(struct pipe_inode_info___5 *, struct pipe_buffer___5 *);
	union {
		bool (*get)(struct pipe_inode_info___5 *, struct pipe_buffer___5 *);
		struct {
			void (*get)(struct pipe_inode_info___5 *, struct pipe_buffer___5 *);
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
};

struct bio_integrity_payload___13 {
	struct bio___13 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___13 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___13 bip_inline_vecs[0];
};

struct blkcg___4;

struct blkg_policy_data___4;

struct blkcg_gq___4 {
	struct request_queue___8 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___4 *blkcg;
	struct bdi_writeback_congested___13 *wb_congested;
	struct blkcg_gq___4 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_rwstat stat_bytes;
	struct blkg_rwstat stat_ios;
	struct blkg_policy_data___4 *pd[5];
	struct callback_head callback_head;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
};

struct disk_part_tbl___7 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___7 *last_lookup;
	struct hd_struct___7 *part[0];
};

struct block_device_operations___7 {
	int (*open)(struct block_device___35 *, fmode_t);
	void (*release)(struct gendisk___7 *, fmode_t);
	int (*rw_page)(struct block_device___35 *, sector_t, struct page___35 *, unsigned int);
	int (*ioctl)(struct block_device___35 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___35 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___7 *, unsigned int);
	int (*media_changed)(struct gendisk___7 *);
	void (*unlock_native_capacity)(struct gendisk___7 *);
	int (*revalidate_disk)(struct gendisk___7 *);
	int (*getgeo)(struct block_device___35 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___35 *, long unsigned int);
	int (*report_zones)(struct gendisk___7 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___32 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bdi_writeback_congested___13 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___13 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bsg_ops___7 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___8 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___8 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___8 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___7(struct request___8 *, blk_status_t);

struct request___8 {
	struct request_queue___8 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___13 *bio;
	struct bio___13 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___13 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___7 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___7 *saved_end_io;
		} flush;
	};
	struct gendisk___7 *rq_disk;
	struct hd_struct___7 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___7 *end_io;
	void *end_io_data;
	struct request___8 *next_rq;
};

struct fwnode_reference_args___25;

struct fwnode_endpoint___25;

struct fwnode_operations___25 {
	struct fwnode_handle___25 * (*get)(struct fwnode_handle___25 *);
	void (*put)(struct fwnode_handle___25 *);
	bool (*device_is_available)(const struct fwnode_handle___25 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___25 *, const struct device___30 *);
	bool (*property_present)(const struct fwnode_handle___25 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___25 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___25 *, const char *, const char **, size_t);
	struct fwnode_handle___25 * (*get_parent)(const struct fwnode_handle___25 *);
	struct fwnode_handle___25 * (*get_next_child_node)(const struct fwnode_handle___25 *, struct fwnode_handle___25 *);
	struct fwnode_handle___25 * (*get_named_child_node)(const struct fwnode_handle___25 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___25 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___25 *);
	struct fwnode_handle___25 * (*graph_get_next_endpoint)(const struct fwnode_handle___25 *, struct fwnode_handle___25 *);
	struct fwnode_handle___25 * (*graph_get_remote_endpoint)(const struct fwnode_handle___25 *);
	struct fwnode_handle___25 * (*graph_get_port_parent)(struct fwnode_handle___25 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___25 *, struct fwnode_endpoint___25 *);
};

struct fwnode_endpoint___25 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___25 *local_fwnode;
};

struct fwnode_reference_args___25 {
	struct fwnode_handle___25 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct elevator_type___7;

struct elevator_mq_ops___7 {
	int (*init_sched)(struct request_queue___8 *, struct elevator_type___7 *);
	void (*exit_sched)(struct elevator_queue___7 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	bool (*allow_merge)(struct request_queue___8 *, struct request___8 *, struct bio___13 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx *, struct bio___13 *);
	int (*request_merge)(struct request_queue___8 *, struct request___8 **, struct bio___13 *);
	void (*request_merged)(struct request_queue___8 *, struct request___8 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___8 *, struct request___8 *, struct request___8 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___8 *, struct bio___13 *);
	void (*finish_request)(struct request___8 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___8 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___8 *, u64);
	void (*started_request)(struct request___8 *);
	void (*requeue_request)(struct request___8 *);
	struct request___8 * (*former_request)(struct request_queue___8 *, struct request___8 *);
	struct request___8 * (*next_request)(struct request_queue___8 *, struct request___8 *);
	void (*init_icq)(struct io_cq___7 *);
	void (*exit_icq)(struct io_cq___7 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide37;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___7;

struct elevator_type___7 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___7 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___7 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___32 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___7 {
	struct elevator_type___7 *type;
	void *elevator_data;
	struct kobject___33 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___7 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___7 *, char *);
	ssize_t (*store)(struct elevator_queue___7 *, const char *, size_t);
};

struct mem_cgroup_reclaim_iter___12 {
	struct mem_cgroup___12 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___12 {
	struct lruvec___34 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___12 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___12 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct blkcg_policy_data___4;

struct blkcg___4 {
	struct cgroup_subsys_state___24 css;
	spinlock_t lock;
	struct xarray blkg_tree;
	struct blkcg_gq___4 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___4 *cpd[5];
	struct list_head all_blkcgs_node;
	struct list_head cgwb_list;
	refcount_t cgwb_refcnt;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct blkcg_policy_data___4 {
	struct blkcg___4 *blkcg;
	int plid;
};

struct blkg_policy_data___4 {
	struct blkcg_gq___4 *blkg;
	int plid;
};

struct waitid_info {
	pid_t pid;
	uid_t uid;
	int status;
	int cause;
};

struct wait_opts {
	enum pid_type wo_type;
	int wo_flags;
	struct pid___30 *wo_pid;
	struct waitid_info *wo_info;
	int wo_stat;
	struct rusage *wo_rusage;
	wait_queue_entry_t child_wait;
	int notask_error;
};

struct clock_event_device___6;

struct arch_timer_erratum_workaround___6 {
	enum arch_timer_erratum_match_type match_type;
	const void *id;
	const char *desc;
	u32 (*read_cntp_tval_el0)();
	u32 (*read_cntv_tval_el0)();
	u64 (*read_cntpct_el0)();
	u64 (*read_cntvct_el0)();
	int (*set_next_event_phys)(long unsigned int, struct clock_event_device___6 *);
	int (*set_next_event_virt)(long unsigned int, struct clock_event_device___6 *);
};

struct clock_event_device___6 {
	void (*event_handler)(struct clock_event_device___6 *);
	int (*set_next_event)(long unsigned int, struct clock_event_device___6 *);
	int (*set_next_ktime)(ktime_t, struct clock_event_device___6 *);
	ktime_t next_event;
	u64 max_delta_ns;
	u64 min_delta_ns;
	u32 mult;
	u32 shift;
	enum clock_event_state state_use_accessors;
	unsigned int features;
	long unsigned int retries;
	int (*set_state_periodic)(struct clock_event_device___6 *);
	int (*set_state_oneshot)(struct clock_event_device___6 *);
	int (*set_state_oneshot_stopped)(struct clock_event_device___6 *);
	int (*set_state_shutdown)(struct clock_event_device___6 *);
	int (*tick_resume)(struct clock_event_device___6 *);
	void (*broadcast)(const struct cpumask *);
	void (*suspend)(struct clock_event_device___6 *);
	void (*resume)(struct clock_event_device___6 *);
	long unsigned int min_delta_ticks;
	long unsigned int max_delta_ticks;
	const char *name;
	int rating;
	int irq;
	int bound_on;
	const struct cpumask *cpumask;
	struct list_head list;
	struct module___24 *owner;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irqaction___5 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___5 *next;
	irq_handler_t thread_fn;
	struct task_struct___28 *thread;
	struct irqaction___5 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct softirq_action {
	void (*action)(struct softirq_action *);
};

struct tasklet_struct {
	struct tasklet_struct *next;
	long unsigned int state;
	atomic_t count;
	void (*func)(long unsigned int);
	long unsigned int data;
};

enum {
	TASKLET_STATE_SCHED = 0,
	TASKLET_STATE_RUN = 1,
};

struct tasklet_hrtimer {
	struct hrtimer timer;
	struct tasklet_struct tasklet;
	enum hrtimer_restart (*function)(struct hrtimer *);
};

struct smp_hotplug_thread___2 {
	struct task_struct___28 **store;
	struct list_head list;
	int (*thread_should_run)(unsigned int);
	void (*thread_fn)(unsigned int);
	void (*create)(unsigned int);
	void (*setup)(unsigned int);
	void (*cleanup)(unsigned int, bool);
	void (*park)(unsigned int);
	void (*unpark)(unsigned int);
	cpumask_var_t cpumask;
	bool selfparking;
	const char *thread_comm;
};

struct irq_chip___8;

struct irq_data___9 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___3 *common;
	struct irq_chip___8 *chip;
	struct irq_domain *domain;
	struct irq_data___9 *parent_data;
	void *chip_data;
};

struct irq_chip___8 {
	struct device___22 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___9 *);
	void (*irq_shutdown)(struct irq_data___9 *);
	void (*irq_enable)(struct irq_data___9 *);
	void (*irq_disable)(struct irq_data___9 *);
	void (*irq_ack)(struct irq_data___9 *);
	void (*irq_mask)(struct irq_data___9 *);
	void (*irq_mask_ack)(struct irq_data___9 *);
	void (*irq_unmask)(struct irq_data___9 *);
	void (*irq_eoi)(struct irq_data___9 *);
	int (*irq_set_affinity)(struct irq_data___9 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___9 *);
	int (*irq_set_type)(struct irq_data___9 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___9 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___9 *);
	void (*irq_bus_sync_unlock)(struct irq_data___9 *);
	void (*irq_cpu_online)(struct irq_data___9 *);
	void (*irq_cpu_offline)(struct irq_data___9 *);
	void (*irq_suspend)(struct irq_data___9 *);
	void (*irq_resume)(struct irq_data___9 *);
	void (*irq_pm_shutdown)(struct irq_data___9 *);
	void (*irq_calc_mask)(struct irq_data___9 *);
	void (*irq_print_chip)(struct irq_data___9 *, struct seq_file___24 *);
	int (*irq_request_resources)(struct irq_data___9 *);
	void (*irq_release_resources)(struct irq_data___9 *);
	void (*irq_compose_msi_msg)(struct irq_data___9 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___9 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___9 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___9 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___9 *, void *);
	void (*ipi_send_single)(struct irq_data___9 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___9 *, const struct cpumask *);
	long unsigned int flags;
};

struct trace_event_raw_irq_handler_entry {
	struct trace_entry ent;
	int irq;
	u32 __data_loc_name;
	char __data[0];
};

struct trace_event_raw_irq_handler_exit {
	struct trace_entry ent;
	int irq;
	int ret;
	char __data[0];
};

struct trace_event_raw_softirq {
	struct trace_entry ent;
	unsigned int vec;
	char __data[0];
};

struct trace_event_data_offsets_irq_handler_entry {
	u32 name;
};

struct trace_event_data_offsets_irq_handler_exit {};

struct trace_event_data_offsets_softirq {};

struct tasklet_head {
	struct tasklet_struct *head;
	struct tasklet_struct **tail;
};

enum {
	IORES_DESC_NONE = 0,
	IORES_DESC_CRASH_KERNEL = 1,
	IORES_DESC_ACPI_TABLES = 2,
	IORES_DESC_ACPI_NV_STORAGE = 3,
	IORES_DESC_PERSISTENT_MEMORY = 4,
	IORES_DESC_PERSISTENT_MEMORY_LEGACY = 5,
	IORES_DESC_DEVICE_PRIVATE_MEMORY = 6,
	IORES_DESC_DEVICE_PUBLIC_MEMORY = 7,
	IORES_DESC_RESERVED = 8,
};

typedef void (*dr_release_t)(struct device___26 *, void *);

enum {
	REGION_INTERSECTS = 0,
	REGION_DISJOINT = 1,
	REGION_MIXED = 2,
};

struct resource_constraint {
	resource_size_t min;
	resource_size_t max;
	resource_size_t align;
	resource_size_t (*alignf)(void *, const struct resource *, resource_size_t, resource_size_t);
	void *alignf_data;
};

enum {
	MAX_IORES_LEVEL = 5,
};

struct region_devres {
	struct resource *parent;
	resource_size_t start;
	resource_size_t n;
};

struct module___33;

struct file___36;

struct kiocb___36;

struct iov_iter___15;

struct poll_table_struct___22;

struct vm_area_struct___36;

struct inode___38;

struct file_lock___36;

struct page___36;

struct pipe_inode_info___6;

struct seq_file___33;

struct file_operations___36 {
	struct module___33 *owner;
	loff_t (*llseek)(struct file___36 *, loff_t, int);
	ssize_t (*read)(struct file___36 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___36 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___36 *, struct iov_iter___15 *);
	ssize_t (*write_iter)(struct kiocb___36 *, struct iov_iter___15 *);
	int (*iopoll)(struct kiocb___36 *, bool);
	int (*iterate)(struct file___36 *, struct dir_context *);
	int (*iterate_shared)(struct file___36 *, struct dir_context *);
	__poll_t (*poll)(struct file___36 *, struct poll_table_struct___22 *);
	long int (*unlocked_ioctl)(struct file___36 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___36 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___36 *, struct vm_area_struct___36 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___38 *, struct file___36 *);
	int (*flush)(struct file___36 *, fl_owner_t);
	int (*release)(struct inode___38 *, struct file___36 *);
	int (*fsync)(struct file___36 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___36 *, int);
	int (*lock)(struct file___36 *, int, struct file_lock___36 *);
	ssize_t (*sendpage)(struct file___36 *, struct page___36 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___36 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___36 *, int, struct file_lock___36 *);
	ssize_t (*splice_write)(struct pipe_inode_info___6 *, struct file___36 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___36 *, loff_t *, struct pipe_inode_info___6 *, size_t, unsigned int);
	int (*setlease)(struct file___36 *, long int, struct file_lock___36 **, void **);
	long int (*fallocate)(struct file___36 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___33 *, struct file___36 *);
	ssize_t (*copy_file_range)(struct file___36 *, loff_t, struct file___36 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___36 *, loff_t, struct file___36 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___36 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___35 {
	u64 seqnum;
	struct vm_area_struct___36 *vmas[4];
};

struct page_frag___35 {
	struct page___36 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___21;

struct debug_info___21 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___21 *hbp_break[16];
	struct perf_event___21 *hbp_watch[16];
};

struct thread_struct___21 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___21 debug;
	long: 64;
};

struct mm_struct___36;

struct mem_cgroup___13;

struct pid___31;

struct cred___35;

struct nsproxy___34;

struct signal_struct___33;

struct bio_list___14;

struct backing_dev_info___14;

struct io_context___8;

struct css_set___25;

struct perf_event_context___21;

struct request_queue___9;

struct vm_struct___29;

struct task_struct___37 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___37 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___36 *mm;
	struct mm_struct___36 *active_mm;
	struct vmacache___35 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___37 *real_parent;
	struct task_struct___37 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___37 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___13 *active_memcg;
	long int rh_reserved2;
	struct pid___31 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___31 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___31 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___35 *ptracer_cred;
	const struct cred___35 *real_cred;
	const struct cred___35 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___34 *nsproxy;
	struct signal_struct___33 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___37 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___14 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___14 *backing_dev_info;
	struct io_context___8 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___25 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___21 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___6 *splice_pipe;
	struct page_frag___35 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___13 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___9 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___37 *oom_reaper_list;
	struct vm_struct___29 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___21 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___21 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___37 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___21)(struct perf_event___21 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___21;

struct fasync_struct___35;

struct pid_namespace___31;

struct bpf_prog___3;

struct trace_event_call___16;

struct perf_cgroup___21;

struct perf_event___21 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___21 *group_leader;
	struct pmu___21 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___21 hw;
	struct perf_event_context___21 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___21 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___37 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___35 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___21 *);
	struct callback_head callback_head;
	struct pid_namespace___31 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___21 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___21 orig_overflow_handler;
	struct bpf_prog___3 *prog;
	struct trace_event_call___16 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___21 *cgrp;
	struct list_head sb_list;
};

struct rw_semaphore___36 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___37 *owner;
};

struct key___36;

struct ucounts___26;

struct user_namespace___26 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___26 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___2 ns;
	long unsigned int flags;
	struct key___36 *persistent_keyring_register;
	struct rw_semaphore___36 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___26 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___36 *pgtable_t___35;

struct address_space___35;

struct dev_pagemap___35;

struct page___36 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___35 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___36 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___35 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___36 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___35 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___13 *mem_cgroup;
};

struct pglist_data___35;

struct lruvec___35 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___35 *pgdat;
};

struct zone___35 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___35 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___35 {
	struct zone___35 *zone;
	int zone_idx;
};

struct zonelist___35 {
	struct zoneref___35 _zonerefs[25];
};

struct pglist_data___35 {
	struct zone___35 node_zones[3];
	struct zonelist___35 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___37 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___37 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___35 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___36 {
	void *stack;
	struct task_struct___37 *task;
	long int status;
};

struct blocking_notifier_head___35 {
	struct rw_semaphore___36 rwsem;
	struct notifier_block *head;
};

struct vfsmount___6;

struct dentry___37;

struct path___35 {
	struct vfsmount___6 *mnt;
	struct dentry___37 *dentry;
};

struct fown_struct___31 {
	rwlock_t lock;
	struct pid___31 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___36 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___35 f_path;
	struct inode___38 *f_inode;
	const struct file_operations___36 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___31 f_owner;
	const struct cred___35 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___35 *f_mapping;
	errseq_t f_wb_err;
};

struct user_struct___35;

struct cred___35 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___36 *session_keyring;
	struct key___36 *process_keyring;
	struct key___36 *thread_keyring;
	struct key___36 *request_key_auth;
	void *security;
	struct user_struct___35 *user;
	struct user_namespace___26 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___33;

struct kernfs_elem_dir___33 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___33 *root;
};

struct kernfs_node___33;

struct kernfs_syscall_ops___33;

struct kernfs_root___33 {
	struct kernfs_node___33 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___33 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___33 {
	struct kernfs_node___33 *target_kn;
};

struct kernfs_ops___33;

struct kernfs_elem_attr___33 {
	const struct kernfs_ops___33 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___33 *notify_next;
};

struct kernfs_node___33 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___33 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___33 dir;
		struct kernfs_elem_symlink___33 symlink;
		struct kernfs_elem_attr___33 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___33;

struct kernfs_ops___33 {
	int (*open)(struct kernfs_open_file___33 *);
	void (*release)(struct kernfs_open_file___33 *);
	int (*seq_show)(struct seq_file___33 *, void *);
	void * (*seq_start)(struct seq_file___33 *, loff_t *);
	void * (*seq_next)(struct seq_file___33 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___33 *, void *);
	ssize_t (*read)(struct kernfs_open_file___33 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___33 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___33 *, struct vm_area_struct___36 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___33 *, struct poll_table_struct___22 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___33 {
	int (*remount_fs)(struct kernfs_root___33 *, int *, char *);
	int (*show_options)(struct seq_file___33 *, struct kernfs_root___33 *);
	int (*mkdir)(struct kernfs_node___33 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___33 *);
	int (*rename)(struct kernfs_node___33 *, struct kernfs_node___33 *, const char *);
	int (*show_path)(struct seq_file___33 *, struct kernfs_node___33 *, struct kernfs_root___33 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___30;

struct seq_file___33 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___30 *op;
	int poll_event;
	const struct file___36 *file;
	void *private;
};

struct vm_operations_struct___35;

struct kernfs_open_file___33 {
	struct kernfs_node___33 *kn;
	struct file___36 *file;
	struct seq_file___33 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___35 *vm_ops;
};

struct vm_fault___35;

struct vm_operations_struct___35 {
	void (*open)(struct vm_area_struct___36 *);
	void (*close)(struct vm_area_struct___36 *);
	int (*split)(struct vm_area_struct___36 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___36 *);
	vm_fault_t (*fault)(struct vm_fault___35 *);
	vm_fault_t (*huge_fault)(struct vm_fault___35 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___35 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___36 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___35 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___35 *);
	int (*access)(struct vm_area_struct___36 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___36 *);
	int (*set_policy)(struct vm_area_struct___36 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___36 *, long unsigned int);
	struct page___36 * (*find_special_page)(struct vm_area_struct___36 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___21)(struct file___36 *, wait_queue_head_t *, struct poll_table_struct___22 *);

struct poll_table_struct___22 {
	poll_queue_proc___21 _qproc;
	__poll_t _key;
};

struct vm_area_struct___36 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___36 *vm_next;
	struct vm_area_struct___36 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___36 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___35 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___36 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sock___5;

struct kobj_ns_type_operations___2 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___5 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct net___9;

typedef struct {
	struct net___9 *net;
} possible_net_t___3;

struct proto___2;

struct sock_common___2 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___2 *skc_prot;
	possible_net_t___3 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___5 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___7;

struct sk_buff_head___4 {
	struct sk_buff___7 *next;
	struct sk_buff___7 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___2;

struct socket_wq___2;

struct dst_entry___4;

struct socket___2;

struct net_device___8;

struct sock___5 {
	struct sock_common___2 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___4 sk_error_queue;
	struct sk_buff_head___4 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___7 *head;
		struct sk_buff___7 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___2 *sk_filter;
	union {
		struct socket_wq___2 *sk_wq;
		struct socket_wq___2 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___4 *sk_rx_dst;
	struct dst_entry___4 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___7 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___4 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___35 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___2 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___31 *sk_peer_pid;
	const struct cred___35 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___2 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___13 *sk_memcg;
	void (*sk_state_change)(struct sock___5 *);
	void (*sk_data_ready)(struct sock___5 *);
	void (*sk_write_space)(struct sock___5 *);
	void (*sk_error_report)(struct sock___5 *);
	int (*sk_backlog_rcv)(struct sock___5 *, struct sk_buff___7 *);
	struct sk_buff___7 * (*sk_validate_xmit_skb)(struct sock___5 *, struct net_device___8 *, struct sk_buff___7 *);
	void (*sk_destruct)(struct sock___5 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kobject___34;

struct bin_attribute___31;

struct attribute_group___31 {
	const char *name;
	umode_t (*is_visible)(struct kobject___34 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___34 *, struct bin_attribute___31 *, int);
	struct attribute **attrs;
	struct bin_attribute___31 **bin_attrs;
};

struct kset___33;

struct kobj_type___33;

struct kobject___34 {
	const char *name;
	struct list_head entry;
	struct kobject___34 *parent;
	struct kset___33 *kset;
	struct kobj_type___33 *ktype;
	struct kernfs_node___33 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___31 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___36 *, struct kobject___34 *, struct bin_attribute___31 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___36 *, struct kobject___34 *, struct bin_attribute___31 *, char *, loff_t, size_t);
	int (*mmap)(struct file___36 *, struct kobject___34 *, struct bin_attribute___31 *, struct vm_area_struct___36 *);
};

struct sysfs_ops___33 {
	ssize_t (*show)(struct kobject___34 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___34 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___33;

struct kset___33 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___34 kobj;
	const struct kset_uevent_ops___33 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___33 {
	void (*release)(struct kobject___34 *);
	const struct sysfs_ops___33 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___2 * (*child_ns_type)(struct kobject___34 *);
	const void * (*namespace)(struct kobject___34 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___33 {
	int (* const filter)(struct kset___33 *, struct kobject___34 *);
	const char * (* const name)(struct kset___33 *, struct kobject___34 *);
	int (* const uevent)(struct kset___33 *, struct kobject___34 *, struct kobj_uevent_env *);
};

struct kobj_attribute___34 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___34 *, struct kobj_attribute___34 *, char *);
	ssize_t (*store)(struct kobject___34 *, struct kobj_attribute___34 *, const char *, size_t);
};

struct kernel_param___30;

struct kernel_param_ops___30 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___30 *);
	int (*get)(char *, const struct kernel_param___30 *);
	void (*free)(void *);
};

struct kparam_array___30;

struct kernel_param___30 {
	const char *name;
	struct module___33 *mod;
	const struct kernel_param_ops___30 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___30 *arr;
	};
};

struct kparam_array___30 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___30 *ops;
	void *elem;
};

struct module_kobject___30 {
	struct kobject___34 kobj;
	struct module___33 *mod;
	struct kobject___34 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___30 {
	struct module___33 *mod;
	struct latch_tree_node node;
};

struct module_layout___30 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___30 mtn;
};

struct module_attribute___30;

struct module___33 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___30 mkobj;
	struct module_attribute___30 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___34 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___30 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___30 core_layout;
	struct module_layout___30 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___16 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___30 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___30 *, struct module_kobject___30 *, char *);
	ssize_t (*store)(struct module_attribute___30 *, struct module_kobject___30 *, const char *, size_t);
	void (*setup)(struct module___33 *, const char *);
	int (*test)(struct module___33 *);
	void (*free)(struct module___33 *);
};

struct trace_event_class___16;

struct bpf_prog_array___3;

struct trace_event_call___16 {
	struct list_head list;
	struct trace_event_class___16 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___3 *prog_array;
	int (*perf_perm)(struct trace_event_call___16 *, struct perf_event___21 *);
};

struct dentry_operations___35;

struct super_block___36;

struct dentry___37 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___37 *d_parent;
	struct qstr d_name;
	struct inode___38 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___35 *d_op;
	struct super_block___36 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___35;

struct address_space___35 {
	struct inode___38 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___36 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___35 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___35;

struct bdi_writeback___14;

struct block_device___36;

struct cdev___11;

struct inode___38 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___35 *i_op;
	struct super_block___36 *i_sb;
	struct address_space___35 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___36 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___14 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___36 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___35 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___6 *i_pipe;
		struct block_device___36 *i_bdev;
		struct cdev___11 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___35 {
	int (*d_revalidate)(struct dentry___37 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___37 *, unsigned int);
	int (*d_hash)(const struct dentry___37 *, struct qstr *);
	int (*d_compare)(const struct dentry___37 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___37 *);
	int (*d_init)(struct dentry___37 *);
	void (*d_release)(struct dentry___37 *);
	void (*d_prune)(struct dentry___37 *);
	void (*d_iput)(struct dentry___37 *, struct inode___38 *);
	char * (*d_dname)(struct dentry___37 *, char *, int);
	struct vfsmount___6 * (*d_automount)(struct path___35 *);
	int (*d_manage)(const struct path___35 *, bool);
	struct dentry___37 * (*d_real)(struct dentry___37 *, const struct inode___38 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___35;

struct mem_dqinfo___35 {
	struct quota_format_type___35 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___35;

struct quota_info___35 {
	unsigned int flags;
	struct rw_semaphore___36 dqio_sem;
	struct inode___38 *files[3];
	struct mem_dqinfo___35 info[3];
	const struct quota_format_ops___35 *ops[3];
};

struct rcuwait___35 {
	struct task_struct___37 *task;
};

struct percpu_rw_semaphore___35 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___36 rw_sem;
	struct rcuwait___35 writer;
	int readers_block;
};

struct sb_writers___35 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___35 rw_sem[3];
};

struct shrink_control___13;

struct shrinker___13 {
	long unsigned int (*count_objects)(struct shrinker___13 *, struct shrink_control___13 *);
	long unsigned int (*scan_objects)(struct shrinker___13 *, struct shrink_control___13 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___35;

struct super_operations___35;

struct dquot_operations___35;

struct quotactl_ops___35;

struct super_block___36 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___35 *s_type;
	const struct super_operations___35 *s_op;
	const struct dquot_operations___35 *dq_op;
	const struct quotactl_ops___35 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___37 *s_root;
	struct rw_semaphore___36 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___36 *s_bdev;
	struct backing_dev_info___14 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___35 s_dquot;
	struct sb_writers___35 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___35 *s_d_op;
	int cleancache_poolid;
	struct shrinker___13 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___26 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___6 {
	struct dentry___37 *mnt_root;
	struct super_block___36 *mnt_sb;
	int mnt_flags;
};

struct shrink_control___13 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___13 *memcg;
};

struct cgroup___25;

struct cgroup_subsys___25;

struct cgroup_subsys_state___25 {
	struct cgroup___25 *cgroup;
	struct cgroup_subsys___25 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___25 *parent;
};

struct cgroup_file___25 {
	struct kernfs_node___33 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___13;

struct mem_cgroup___13 {
	struct cgroup_subsys_state___25 css;
	struct mem_cgroup_id___2 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___25 events_file;
	struct cgroup_file___25 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___37 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___13 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct upid___31 {
	int nr;
	struct pid_namespace___31 *ns;
};

struct pid_namespace___31 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___37 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___31 *parent;
	struct vfsmount___6 *proc_mnt;
	struct dentry___37 *proc_self;
	struct dentry___37 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___2 ns;
};

struct pid___31 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___31 numbers[1];
};

struct linux_binfmt___5;

struct core_state___35;

struct mm_struct___36 {
	struct {
		struct vm_area_struct___36 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___36 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___36 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___5 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___35 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___37 *owner;
		struct user_namespace___26 *user_ns;
		struct file___36 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___35 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___35)(struct vm_area_struct___36 *, long unsigned int, const struct page___36 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___35)(struct page___36 *, void *);

struct device___31;

struct dev_pagemap___35 {
	dev_page_fault_t___35 page_fault;
	dev_page_free_t___35 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___31 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___35 {
	struct task_struct___37 *task;
	struct core_thread___35 *next;
};

struct core_state___35 {
	atomic_t nr_threads;
	struct core_thread___35 dumper;
	struct completion startup;
};

struct linux_binprm___5;

struct coredump_params___4;

struct linux_binfmt___5 {
	struct list_head lh;
	struct module___33 *module;
	int (*load_binary)(struct linux_binprm___5 *);
	int (*load_shlib)(struct file___36 *);
	int (*core_dump)(struct coredump_params___4 *);
	long unsigned int min_coredump;
};

struct vm_fault___35 {
	struct vm_area_struct___36 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___36 *cow_page;
	struct mem_cgroup___13 *memcg;
	struct page___36 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___35 prealloc_pte;
};

struct user_struct___35 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___36 *uid_keyring;
	struct key___36 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct uts_namespace___8;

struct cgroup_namespace___25;

struct nsproxy___34 {
	atomic_t count;
	struct uts_namespace___8 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___31 *pid_ns_for_children;
	struct net___9 *net_ns;
	struct cgroup_namespace___25 *cgroup_ns;
};

struct signal_struct___33 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___37 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___37 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___31 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___31 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___36 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___31 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide35;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___14;

struct bio_list___14 {
	struct bio___14 *head;
	struct bio___14 *tail;
};

struct bdi_writeback_congested___14;

struct bdi_writeback___14 {
	struct backing_dev_info___14 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___14 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___25 *memcg_css;
	struct cgroup_subsys_state___25 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___14 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___14 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___31 *dev;
	struct device___31 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___37 *debug_dir;
	struct dentry___37 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___8;

struct io_context___8 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___8 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___25 {
	struct cgroup_subsys_state___25 *subsys[13];
	refcount_t refcount;
	struct css_set___25 *dom_cset;
	struct cgroup___25 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___25 *mg_src_cgrp;
	struct cgroup___25 *mg_dst_cgrp;
	struct css_set___25 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___21 {
	struct pmu___21 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___37 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___21 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___6;

struct pipe_inode_info___6 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___36 *tmp_page;
	struct fasync_struct___35 *fasync_readers;
	struct fasync_struct___35 *fasync_writers;
	struct pipe_buffer___6 *bufs;
	struct user_struct___35 *user;
};

typedef blk_qc_t make_request_fn___8(struct request_queue___9 *, struct bio___14 *);

struct request___9;

typedef int dma_drain_needed_fn___8(struct request___9 *);

struct bsg_ops___8;

struct bsg_class_device___8 {
	struct device___31 *class_dev;
	int minor;
	struct request_queue___9 *queue;
	const struct bsg_ops___8 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___14 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___14 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___8;

struct blkcg_gq___5;

struct request_queue___9 {
	struct list_head queue_head;
	struct request___9 *last_merge;
	struct elevator_queue___8 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___8 *make_request_fn;
	dma_drain_needed_fn___8 *dma_drain_needed;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___14 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___34 kobj;
	struct kobject___34 *mq_kobj;
	struct blk_integrity integrity;
	struct device___31 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___5 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide80;
		union {		};
	};
	struct bsg_class_device___8 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___14 bio_split;
	struct dentry___37 *debugfs_dir;
	struct dentry___37 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___29 {
	struct vm_struct___29 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___36 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___33 {
	struct task_struct___37 task;
	long unsigned int stack[8192];
};

struct io_cq___8 {
	struct request_queue___9 *q;
	struct io_context___8 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___36 {
	struct file___36 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___36 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___36 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___36 *ia_file;
};

struct dquot___35 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___36 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___35 {
	int qf_fmt_id;
	const struct quota_format_ops___35 *qf_ops;
	struct module___33 *qf_owner;
	struct quota_format_type___35 *qf_next;
};

struct quota_format_ops___35 {
	int (*check_quota_file)(struct super_block___36 *, int);
	int (*read_file_info)(struct super_block___36 *, int);
	int (*write_file_info)(struct super_block___36 *, int);
	int (*free_file_info)(struct super_block___36 *, int);
	int (*read_dqblk)(struct dquot___35 *);
	int (*commit_dqblk)(struct dquot___35 *);
	int (*release_dqblk)(struct dquot___35 *);
	int (*get_next_id)(struct super_block___36 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___35 {
	int (*write_dquot)(struct dquot___35 *);
	struct dquot___35 * (*alloc_dquot)(struct super_block___36 *, int);
	void (*destroy_dquot)(struct dquot___35 *);
	int (*acquire_dquot)(struct dquot___35 *);
	int (*release_dquot)(struct dquot___35 *);
	int (*mark_dirty)(struct dquot___35 *);
	int (*write_info)(struct super_block___36 *, int);
	qsize_t * (*get_reserved_space)(struct inode___38 *);
	int (*get_projid)(struct inode___38 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___38 *, qsize_t *);
	int (*get_next_id)(struct super_block___36 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___35 {
	int (*quota_on)(struct super_block___36 *, int, int, const struct path___35 *);
	int (*quota_off)(struct super_block___36 *, int);
	int (*quota_enable)(struct super_block___36 *, unsigned int);
	int (*quota_disable)(struct super_block___36 *, unsigned int);
	int (*quota_sync)(struct super_block___36 *, int);
	int (*set_info)(struct super_block___36 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___36 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___36 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___36 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___36 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___36 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___13;

struct swap_info_struct___10;

struct address_space_operations___35 {
	int (*writepage)(struct page___36 *, struct writeback_control___13 *);
	int (*readpage)(struct file___36 *, struct page___36 *);
	int (*writepages)(struct address_space___35 *, struct writeback_control___13 *);
	int (*set_page_dirty)(struct page___36 *);
	int (*readpages)(struct file___36 *, struct address_space___35 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___36 *, struct address_space___35 *, loff_t, unsigned int, unsigned int, struct page___36 **, void **);
	int (*write_end)(struct file___36 *, struct address_space___35 *, loff_t, unsigned int, unsigned int, struct page___36 *, void *);
	sector_t (*bmap)(struct address_space___35 *, sector_t);
	void (*invalidatepage)(struct page___36 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___36 *, gfp_t);
	void (*freepage)(struct page___36 *);
	ssize_t (*direct_IO)(struct kiocb___36 *, struct iov_iter___15 *);
	int (*migratepage)(struct address_space___35 *, struct page___36 *, struct page___36 *, enum migrate_mode);
	bool (*isolate_page)(struct page___36 *, isolate_mode_t);
	void (*putback_page)(struct page___36 *);
	int (*launder_page)(struct page___36 *);
	int (*is_partially_uptodate)(struct page___36 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___36 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___35 *, struct page___36 *);
	int (*swap_activate)(struct swap_info_struct___10 *, struct file___36 *, sector_t *);
	void (*swap_deactivate)(struct file___36 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___13 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___14 *wb;
	struct inode___38 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___14;

struct iov_iter___15 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___14 *bvec;
		struct pipe_inode_info___6 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct swap_info_struct___10 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___36 *bdev;
	struct file___36 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct hd_struct___8;

struct gendisk___8;

struct block_device___36 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___38 *bd_inode;
	struct super_block___36 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___36 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___8 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___8 *bd_disk;
	struct request_queue___9 *bd_queue;
	struct backing_dev_info___14 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___31 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___31 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___31;

struct bus_type___31;

struct device_driver___31;

struct dev_pm_domain___31;

struct dma_map_ops___8;

struct fwnode_handle___26;

struct class___31;

struct device___31 {
	struct device___31 *parent;
	struct device_private *p;
	struct kobject___34 kobj;
	const char *init_name;
	const struct device_type___31 *type;
	struct mutex mutex;
	struct bus_type___31 *bus;
	struct device_driver___31 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___31 power;
	struct dev_pm_domain___31 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___8 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___26 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___31 *class;
	const struct attribute_group___31 **groups;
	void (*release)(struct device___31 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___8 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___31 __dev;
	struct kobject___34 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___8;

struct block_device_operations___8;

struct gendisk___8 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___8 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___8 *part_tbl;
	struct hd_struct___8 part0;
	const struct block_device_operations___8 *fops;
	struct request_queue___9 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___36 lookup_sem;
	struct kobject___34 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___34 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___11 {
	struct kobject___34 kobj;
	struct module___33 *owner;
	const struct file_operations___36 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___35 {
	struct dentry___37 * (*lookup)(struct inode___38 *, struct dentry___37 *, unsigned int);
	const char * (*get_link)(struct dentry___37 *, struct inode___38 *, struct delayed_call *);
	int (*permission)(struct inode___38 *, int);
	struct posix_acl * (*get_acl)(struct inode___38 *, int);
	int (*readlink)(struct dentry___37 *, char *, int);
	int (*create)(struct inode___38 *, struct dentry___37 *, umode_t, bool);
	int (*link)(struct dentry___37 *, struct inode___38 *, struct dentry___37 *);
	int (*unlink)(struct inode___38 *, struct dentry___37 *);
	int (*symlink)(struct inode___38 *, struct dentry___37 *, const char *);
	int (*mkdir)(struct inode___38 *, struct dentry___37 *, umode_t);
	int (*rmdir)(struct inode___38 *, struct dentry___37 *);
	int (*mknod)(struct inode___38 *, struct dentry___37 *, umode_t, dev_t);
	int (*rename)(struct inode___38 *, struct dentry___37 *, struct inode___38 *, struct dentry___37 *, unsigned int);
	int (*setattr)(struct dentry___37 *, struct iattr___36 *);
	int (*getattr)(const struct path___35 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___37 *, char *, size_t);
	int (*fiemap)(struct inode___38 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___38 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___38 *, struct dentry___37 *, struct file___36 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___38 *, struct dentry___37 *, umode_t);
	int (*set_acl)(struct inode___38 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___35 {
	void (*fl_copy_lock)(struct file_lock___36 *, struct file_lock___36 *);
	void (*fl_release_private)(struct file_lock___36 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___35;

struct file_lock___36 {
	struct file_lock___36 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___36 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___35 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___35 *fl_ops;
	const struct lock_manager_operations___35 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___35 {
	int (*lm_compare_owner)(struct file_lock___36 *, struct file_lock___36 *);
	long unsigned int (*lm_owner_key)(struct file_lock___36 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___36 *);
	int (*lm_grant)(struct file_lock___36 *, int);
	bool (*lm_break)(struct file_lock___36 *);
	int (*lm_change)(struct file_lock___36 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___36 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___35 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___35 *fa_next;
	struct file___36 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___35 {
	const char *name;
	int fs_flags;
	struct dentry___37 * (*mount)(struct file_system_type___35 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___36 *);
	struct module___33 *owner;
	struct file_system_type___35 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___35 {
	struct inode___38 * (*alloc_inode)(struct super_block___36 *);
	void (*destroy_inode)(struct inode___38 *);
	void (*dirty_inode)(struct inode___38 *, int);
	int (*write_inode)(struct inode___38 *, struct writeback_control___13 *);
	int (*drop_inode)(struct inode___38 *);
	void (*evict_inode)(struct inode___38 *);
	void (*put_super)(struct super_block___36 *);
	int (*sync_fs)(struct super_block___36 *, int);
	int (*freeze_super)(struct super_block___36 *);
	int (*freeze_fs)(struct super_block___36 *);
	int (*thaw_super)(struct super_block___36 *);
	int (*unfreeze_fs)(struct super_block___36 *);
	int (*statfs)(struct dentry___37 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___36 *, int *, char *);
	void (*umount_begin)(struct super_block___36 *);
	int (*show_options)(struct seq_file___33 *, struct dentry___37 *);
	int (*show_devname)(struct seq_file___33 *, struct dentry___37 *);
	int (*show_path)(struct seq_file___33 *, struct dentry___37 *);
	int (*show_stats)(struct seq_file___33 *, struct dentry___37 *);
	ssize_t (*quota_read)(struct super_block___36 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___36 *, int, const char *, size_t, loff_t);
	struct dquot___35 ** (*get_dquots)(struct inode___38 *);
	int (*bdev_try_to_free_page)(struct super_block___36 *, struct page___36 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___36 *, struct shrink_control___13 *);
	long int (*free_cached_objects)(struct super_block___36 *, struct shrink_control___13 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___14(struct bio___14 *);

struct bio_vec___14 {
	struct page___36 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___14;

struct bio___14 {
	struct bio___14 *bi_next;
	struct gendisk___8 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___14 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___5 *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___14 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___14 *bi_io_vec;
	struct bio_set___14 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___14 bi_inline_vecs[0];
};

typedef void compound_page_dtor___35(struct page___36 *);

typedef int (*key_restrict_link_func_t___35)(struct key___36 *, const struct key_type *, const union key_payload *, struct key___36 *);

struct key_restriction___36;

struct key___36 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___36 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___36 *restrict_link;
};

struct key_restriction___36 {
	key_restrict_link_func_t___35 check;
	struct key___36 *key;
	struct key_type *keytype;
};

struct seq_operations___30 {
	void * (*start)(struct seq_file___33 *, loff_t *);
	void (*stop)(struct seq_file___33 *, void *);
	void * (*next)(struct seq_file___33 *, void *, loff_t *);
	int (*show)(struct seq_file___33 *, void *);
};

struct uts_namespace___8 {
	struct kref kref;
	struct new_utsname name;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct ns_common___2 ns;
};

struct inet_frags___3;

struct netns_frags___3 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___3 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_rules_ops___2;

struct fib_notifier_ops___2;

struct netns_ipv4___3 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___2 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___5 *fibnl;
	struct sock___5 **icmp_sk;
	struct sock___5 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___5 **tcp_sk;
	struct netns_frags___3 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___2 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___2 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___2 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___4;

struct dst_ops___7 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___7 *);
	struct dst_entry___4 * (*check)(struct dst_entry___4 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___4 *);
	unsigned int (*mtu)(const struct dst_entry___4 *);
	u32 * (*cow_metrics)(struct dst_entry___4 *, long unsigned int);
	void (*destroy)(struct dst_entry___4 *);
	void (*ifdown)(struct dst_entry___4 *, struct net_device___8 *, int);
	struct dst_entry___4 * (*negative_advice)(struct dst_entry___4 *);
	void (*link_failure)(struct sk_buff___7 *);
	void (*update_pmtu)(struct dst_entry___4 *, struct sock___5 *, struct sk_buff___7 *, u32);
	void (*redirect)(struct dst_entry___4 *, struct sock___5 *, struct sk_buff___7 *);
	int (*local_out)(struct net___9 *, struct sock___5 *, struct sk_buff___7 *);
	struct neighbour___4 * (*neigh_lookup)(const struct dst_entry___4 *, struct sk_buff___7 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___4 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___6 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___3 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___7 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___2 *fib6_rules_ops;
	struct sock___5 **icmp_sk;
	struct sock___5 *ndisc_sk;
	struct sock___5 *tcp_sk;
	struct sock___5 *igmp_sk;
	struct sock___5 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___2 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___2 *notifier_ops;
	struct fib_notifier_ops___2 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___2 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___5 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___3 {
	struct netns_frags___3 frags;
};

struct netns_xfrm___6 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___5 *nlsk;
	struct sock___5 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___7 xfrm4_dst_ops;
	struct dst_ops___7 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct net___9 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___2 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___5 *rtnl;
	struct sock___5 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___8 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___3 ipv4;
	struct netns_ipv6___6 ipv6;
	struct netns_sctp___2 sctp;
	struct netns_nf nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___3 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___5 *nfnl;
	struct sock___5 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___6 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___5 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___3 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cgroup_namespace___25 {
	refcount_t count;
	struct ns_common___2 ns;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct css_set___25 *root_cset;
};

struct ucounts___26 {
	struct hlist_node node;
	struct user_namespace___26 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___25;

struct bpf_map_ops___25 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___25 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___25 *, struct file___36 *);
	void (*map_free)(struct bpf_map___25 *);
	int (*map_get_next_key)(struct bpf_map___25 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___25 *);
	void * (*map_lookup_elem)(struct bpf_map___25 *, void *);
	int (*map_update_elem)(struct bpf_map___25 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___25 *, void *);
	int (*map_push_elem)(struct bpf_map___25 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___25 *, void *);
	int (*map_peek_elem)(struct bpf_map___25 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___25 *, struct file___36 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___25 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___25 *, void *, struct seq_file___33 *);
	int (*map_check_btf)(const struct bpf_map___25 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___25 {
	const struct bpf_map_ops___25 *ops;
	struct bpf_map___25 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___35 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___3;

struct bpf_map_dev_ops___3 {
	int (*map_get_next_key)(struct bpf_offloaded_map___3 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___3 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___3 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___3 *, void *);
};

struct bpf_offloaded_map___3 {
	struct bpf_map___25 map;
	struct net_device___8 *netdev;
	const struct bpf_map_dev_ops___3 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

typedef rx_handler_result_t rx_handler_func_t___3(struct sk_buff___7 **);

struct net_device_ops___3;

struct ethtool_ops___3;

struct l3mdev_ops___3;

struct ndisc_ops___3;

struct xfrmdev_ops___3;

struct tlsdev_ops___3;

struct header_ops___3;

struct inet6_dev___3;

struct netdev_rx_queue___3;

struct mini_Qdisc___3;

struct netdev_queue___3;

struct Qdisc___3;

struct rtnl_link_ops___3;

struct dcbnl_rtnl_ops___3;

struct net_device___8 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___3 *netdev_ops;
	const struct ethtool_ops___3 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___3 *l3mdev_ops;
	const struct ndisc_ops___3 *ndisc_ops;
	const struct xfrmdev_ops___3 *xfrmdev_ops;
	const struct tlsdev_ops___3 *tlsdev_ops;
	const struct header_ops___3 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___33 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___3 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___3 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___3 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___3 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___3 *miniq_ingress;
	struct netdev_queue___3 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___3 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___3 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___3 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___3 = 0,
		NETREG_REGISTERED___3 = 1,
		NETREG_UNREGISTERING___3 = 2,
		NETREG_UNREGISTERED___3 = 3,
		NETREG_RELEASED___3 = 4,
		NETREG_DUMMY___3 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___3 = 0,
		RTNL_LINK_INITIALIZING___3 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___8 *);
	struct netpoll_info *npinfo;
	possible_net_t___3 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___31 dev;
	const struct attribute_group___31 *sysfs_groups[4];
	const struct attribute_group___31 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___3 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___3 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide52;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct bpf_prog_ops___3 {
	int (*test_run)(struct bpf_prog___3 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_aux___3;

struct bpf_prog___3 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___3 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

struct bpf_verifier_ops___3 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___3 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___3 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___3 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___3 *, u32 *);
};

struct bpf_prog_offload_ops___3 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___3 *);
	int (*translate)(struct bpf_prog___3 *);
	void (*destroy)(struct bpf_prog___3 *);
};

struct bpf_prog_offload___3 {
	struct bpf_prog___3 *prog;
	struct net_device___8 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___3 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___3 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___3 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___3 *ops;
	struct bpf_map___25 **used_maps;
	struct bpf_prog___3 *prog;
	struct user_struct___35 *user;
	u64 load_time;
	struct bpf_map___25 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___3 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___3 {
	struct bpf_prog___3 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___3 {
	struct callback_head rcu;
	struct bpf_prog_array_item___3 items[0];
};

struct cgroup_bpf___3 {
	struct bpf_prog_array___3 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___3 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___25;

typedef void (*kthread_work_func_t___25)(struct kthread_work___25 *);

struct kthread_worker___25;

struct kthread_work___25 {
	struct list_head node;
	kthread_work_func_t___25 func;
	struct kthread_worker___25 *worker;
	int canceling;
};

struct kthread_worker___25 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___37 *task;
	struct kthread_work___25 *current_work;
};

struct kthread_delayed_work___25 {
	struct kthread_work___25 work;
	struct timer_list timer;
};

struct psi_group___25 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___25 *poll_kworker;
	struct kthread_delayed_work___25 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___25;

struct cgroup_rstat_cpu___25;

struct cgroup___25 {
	struct cgroup_subsys_state___25 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___33 *kn;
	struct cgroup_file___25 procs_file;
	struct cgroup_file___25 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___25 *subsys[13];
	struct cgroup_root___25 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___25 *dom_cgrp;
	struct cgroup_rstat_cpu___25 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___3 bpf;
	atomic_t congestion_count;
	struct cgroup___25 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___25 psi;
	int ancestor_ids[0];
};

struct cftype___25;

struct cgroup_subsys___25 {
	struct cgroup_subsys_state___25 * (*css_alloc)(struct cgroup_subsys_state___25 *);
	int (*css_online)(struct cgroup_subsys_state___25 *);
	void (*css_offline)(struct cgroup_subsys_state___25 *);
	void (*css_released)(struct cgroup_subsys_state___25 *);
	void (*css_free)(struct cgroup_subsys_state___25 *);
	void (*css_reset)(struct cgroup_subsys_state___25 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___25 *, int);
	int (*css_extra_stat_show)(struct seq_file___33 *, struct cgroup_subsys_state___25 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___37 *);
	void (*cancel_fork)(struct task_struct___37 *);
	void (*fork)(struct task_struct___37 *);
	void (*exit)(struct task_struct___37 *);
	void (*free)(struct task_struct___37 *);
	void (*bind)(struct cgroup_subsys_state___25 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___25 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___25 *dfl_cftypes;
	struct cftype___25 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___25 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___25 *updated_children;
	struct cgroup___25 *updated_next;
};

struct cgroup_root___25 {
	struct kernfs_root___33 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___25 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___25 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___25 *ss;
	struct list_head node;
	struct kernfs_ops___33 *kf_ops;
	int (*open)(struct kernfs_open_file___33 *);
	void (*release)(struct kernfs_open_file___33 *);
	u64 (*read_u64)(struct cgroup_subsys_state___25 *, struct cftype___25 *);
	s64 (*read_s64)(struct cgroup_subsys_state___25 *, struct cftype___25 *);
	int (*seq_show)(struct seq_file___33 *, void *);
	void * (*seq_start)(struct seq_file___33 *, loff_t *);
	void * (*seq_next)(struct seq_file___33 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___33 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___25 *, struct cftype___25 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___25 *, struct cftype___25 *, s64);
	ssize_t (*write)(struct kernfs_open_file___33 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___33 *, struct poll_table_struct___22 *);
};

struct bdi_writeback_congested___14 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___14 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___14 {
	struct bio___14 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___14 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___14 bip_inline_vecs[0];
};

struct blkcg___5;

struct blkg_policy_data___5;

struct blkcg_gq___5 {
	struct request_queue___9 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___5 *blkcg;
	struct bdi_writeback_congested___14 *wb_congested;
	struct blkcg_gq___5 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_rwstat stat_bytes;
	struct blkg_rwstat stat_ios;
	struct blkg_policy_data___5 *pd[5];
	struct callback_head callback_head;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
};

struct mem_cgroup_reclaim_iter___13 {
	struct mem_cgroup___13 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___13 {
	struct lruvec___35 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___13 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___13 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct dev_pm_ops___31 {
	int (*prepare)(struct device___31 *);
	void (*complete)(struct device___31 *);
	int (*suspend)(struct device___31 *);
	int (*resume)(struct device___31 *);
	int (*freeze)(struct device___31 *);
	int (*thaw)(struct device___31 *);
	int (*poweroff)(struct device___31 *);
	int (*restore)(struct device___31 *);
	int (*suspend_late)(struct device___31 *);
	int (*resume_early)(struct device___31 *);
	int (*freeze_late)(struct device___31 *);
	int (*thaw_early)(struct device___31 *);
	int (*poweroff_late)(struct device___31 *);
	int (*restore_early)(struct device___31 *);
	int (*suspend_noirq)(struct device___31 *);
	int (*resume_noirq)(struct device___31 *);
	int (*freeze_noirq)(struct device___31 *);
	int (*thaw_noirq)(struct device___31 *);
	int (*poweroff_noirq)(struct device___31 *);
	int (*restore_noirq)(struct device___31 *);
	int (*runtime_suspend)(struct device___31 *);
	int (*runtime_resume)(struct device___31 *);
	int (*runtime_idle)(struct device___31 *);
};

struct dev_pm_domain___31 {
	struct dev_pm_ops___31 ops;
	void (*detach)(struct device___31 *, bool);
	int (*activate)(struct device___31 *);
	void (*sync)(struct device___31 *);
	void (*dismiss)(struct device___31 *);
};

struct bus_type___31 {
	const char *name;
	const char *dev_name;
	struct device___31 *dev_root;
	const struct attribute_group___31 **bus_groups;
	const struct attribute_group___31 **dev_groups;
	const struct attribute_group___31 **drv_groups;
	int (*match)(struct device___31 *, struct device_driver___31 *);
	int (*uevent)(struct device___31 *, struct kobj_uevent_env *);
	int (*probe)(struct device___31 *);
	int (*remove)(struct device___31 *);
	void (*shutdown)(struct device___31 *);
	int (*online)(struct device___31 *);
	int (*offline)(struct device___31 *);
	int (*suspend)(struct device___31 *, pm_message_t);
	int (*resume)(struct device___31 *);
	int (*num_vf)(struct device___31 *);
	int (*dma_configure)(struct device___31 *);
	const struct dev_pm_ops___31 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___31 {
	const char *name;
	struct bus_type___31 *bus;
	struct module___33 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___31 *);
	int (*remove)(struct device___31 *);
	void (*shutdown)(struct device___31 *);
	int (*suspend)(struct device___31 *, pm_message_t);
	int (*resume)(struct device___31 *);
	const struct attribute_group___31 **groups;
	const struct dev_pm_ops___31 *pm;
	void (*coredump)(struct device___31 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___31 {
	const char *name;
	const struct attribute_group___31 **groups;
	int (*uevent)(struct device___31 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___31 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___31 *);
	const struct dev_pm_ops___31 *pm;
};

struct class___31 {
	const char *name;
	struct module___33 *owner;
	const struct attribute_group___31 **class_groups;
	const struct attribute_group___31 **dev_groups;
	struct kobject___34 *dev_kobj;
	int (*dev_uevent)(struct device___31 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___31 *, umode_t *);
	void (*class_release)(struct class___31 *);
	void (*dev_release)(struct device___31 *);
	int (*shutdown_pre)(struct device___31 *);
	const struct kobj_ns_type_operations___2 *ns_type;
	const void * (*namespace)(struct device___31 *);
	const struct dev_pm_ops___31 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___8 {
	void * (*alloc)(struct device___31 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___31 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___31 *, struct vm_area_struct___36 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___31 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___31 *, struct page___36 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___31 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___31 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___31 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___31 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___31 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___31 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide36;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___31 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___31 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___31 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___31 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___31 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___31 *, u64);
	u64 (*get_required_mask)(struct device___31 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___26;

struct fwnode_handle___26 {
	struct fwnode_handle___26 *secondary;
	const struct fwnode_operations___26 *ops;
};

struct node___29 {
	struct device___31 dev;
};

struct msghdr___2 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___15 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___36 *msg_iocb;
};

struct socket_wq___2 {
	wait_queue_head_t wait;
	struct fasync_struct___35 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___2;

struct socket___2 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___2 *wq;
	struct file___36 *file;
	struct sock___5 *sk;
	const struct proto_ops___2 *ops;
};

typedef int (*sk_read_actor_t___2)(read_descriptor_t *, struct sk_buff___7 *, unsigned int, size_t);

struct proto_ops___2 {
	int family;
	struct module___33 *owner;
	int (*release)(struct socket___2 *);
	int (*bind)(struct socket___2 *, struct sockaddr *, int);
	int (*connect)(struct socket___2 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___2 *, struct socket___2 *);
	int (*accept)(struct socket___2 *, struct socket___2 *, int, bool);
	int (*getname)(struct socket___2 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___36 *, struct socket___2 *, struct poll_table_struct___22 *);
	int (*ioctl)(struct socket___2 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___2 *, int);
	int (*shutdown)(struct socket___2 *, int);
	int (*setsockopt)(struct socket___2 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___2 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___2 *, struct msghdr___2 *, size_t);
	int (*recvmsg)(struct socket___2 *, struct msghdr___2 *, size_t, int);
	int (*mmap)(struct file___36 *, struct socket___2 *, struct vm_area_struct___36 *);
	ssize_t (*sendpage)(struct socket___2 *, struct page___36 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___2 *, loff_t *, struct pipe_inode_info___6 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___5 *, int);
	int (*peek_len)(struct socket___2 *);
	int (*read_sock)(struct sock___5 *, read_descriptor_t *, sk_read_actor_t___2);
	int (*sendpage_locked)(struct sock___5 *, struct page___36 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___5 *, struct msghdr___2 *, size_t);
	int (*set_rcvlowat)(struct sock___5 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct nf_bridge_info___3;

struct sk_buff___7 {
	union {
		struct {
			struct sk_buff___7 *next;
			struct sk_buff___7 *prev;
			union {
				struct net_device___8 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___5 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___7 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___3 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct hstate___7 {
	int next_nid_to_alloc;
	int next_nid_to_free;
	unsigned int order;
	long unsigned int mask;
	long unsigned int max_huge_pages;
	long unsigned int nr_huge_pages;
	long unsigned int free_huge_pages;
	long unsigned int resv_huge_pages;
	long unsigned int surplus_huge_pages;
	long unsigned int nr_overcommit_huge_pages;
	struct list_head hugepage_activelist;
	struct list_head hugepage_freelists[8];
	unsigned int nr_huge_pages_node[8];
	unsigned int free_huge_pages_node[8];
	unsigned int surplus_huge_pages_node[8];
	struct cftype___25 cgroup_files[5];
	char name[32];
};

struct perf_cpu_context___21;

struct pmu___21 {
	struct list_head entry;
	struct module___33 *module;
	struct device___31 *dev;
	const struct attribute_group___31 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___21 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___21 *);
	void (*pmu_disable)(struct pmu___21 *);
	int (*event_init)(struct perf_event___21 *);
	void (*event_mapped)(struct perf_event___21 *, struct mm_struct___36 *);
	void (*event_unmapped)(struct perf_event___21 *, struct mm_struct___36 *);
	int (*add)(struct perf_event___21 *, int);
	void (*del)(struct perf_event___21 *, int);
	void (*start)(struct perf_event___21 *, int);
	void (*stop)(struct perf_event___21 *, int);
	void (*read)(struct perf_event___21 *);
	void (*start_txn)(struct pmu___21 *, unsigned int);
	int (*commit_txn)(struct pmu___21 *);
	void (*cancel_txn)(struct pmu___21 *);
	int (*event_idx)(struct perf_event___21 *);
	void (*sched_task)(struct perf_event_context___21 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___21 *);
	int (*filter_match)(struct perf_event___21 *);
	int (*check_period)(struct perf_event___21 *, u64);
};

struct perf_cpu_context___21 {
	struct perf_event_context___21 ctx;
	struct perf_event_context___21 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___21 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___21 {
	struct cgroup_subsys_state___25 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___16 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___16 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___16 *);
	struct list_head * (*get_fields)(struct trace_event_call___16 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___16 *);
};

struct fwnode_reference_args___26;

struct fwnode_endpoint___26;

struct fwnode_operations___26 {
	struct fwnode_handle___26 * (*get)(struct fwnode_handle___26 *);
	void (*put)(struct fwnode_handle___26 *);
	bool (*device_is_available)(const struct fwnode_handle___26 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___26 *, const struct device___31 *);
	bool (*property_present)(const struct fwnode_handle___26 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___26 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___26 *, const char *, const char **, size_t);
	struct fwnode_handle___26 * (*get_parent)(const struct fwnode_handle___26 *);
	struct fwnode_handle___26 * (*get_next_child_node)(const struct fwnode_handle___26 *, struct fwnode_handle___26 *);
	struct fwnode_handle___26 * (*get_named_child_node)(const struct fwnode_handle___26 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___26 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___26 *);
	struct fwnode_handle___26 * (*graph_get_next_endpoint)(const struct fwnode_handle___26 *, struct fwnode_handle___26 *);
	struct fwnode_handle___26 * (*graph_get_remote_endpoint)(const struct fwnode_handle___26 *);
	struct fwnode_handle___26 * (*graph_get_port_parent)(struct fwnode_handle___26 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___26 *, struct fwnode_endpoint___26 *);
};

struct fwnode_endpoint___26 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___26 *local_fwnode;
};

struct fwnode_reference_args___26 {
	struct fwnode_handle___26 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct xdr_buf___2 {
	struct kvec head[1];
	struct kvec tail[1];
	struct page___36 **pages;
	unsigned int page_base;
	unsigned int page_len;
	unsigned int flags;
	unsigned int buflen;
	unsigned int len;
};

struct xdr_stream___2 {
	__be32 *p;
	struct xdr_buf___2 *buf;
	__be32 *end;
	struct kvec *iov;
	struct kvec scratch;
	struct page___36 **page_ptr;
	unsigned int nwords;
};

struct rpc_rqst___2;

typedef void (*kxdreproc_t___2)(struct rpc_rqst___2 *, struct xdr_stream___2 *, const void *);

struct rpc_xprt___2;

struct rpc_task___2;

struct rpc_cred___2;

struct rpc_rqst___2 {
	struct rpc_xprt___2 *rq_xprt;
	struct xdr_buf___2 rq_snd_buf;
	struct xdr_buf___2 rq_rcv_buf;
	struct rpc_task___2 *rq_task;
	struct rpc_cred___2 *rq_cred;
	__be32 rq_xid;
	int rq_cong;
	u32 rq_seqno;
	int rq_enc_pages_num;
	struct page___36 **rq_enc_pages;
	void (*rq_release_snd_buf)(struct rpc_rqst___2 *);
	struct list_head rq_list;
	void *rq_buffer;
	size_t rq_callsize;
	void *rq_rbuffer;
	size_t rq_rcvsize;
	size_t rq_xmit_bytes_sent;
	size_t rq_reply_bytes_recvd;
	struct xdr_buf___2 rq_private_buf;
	long unsigned int rq_majortimeo;
	long unsigned int rq_timeout;
	ktime_t rq_rtt;
	unsigned int rq_retries;
	unsigned int rq_connect_cookie;
	u32 rq_bytes_sent;
	ktime_t rq_xtime;
	int rq_ntrans;
	struct list_head rq_bc_list;
	long unsigned int rq_bc_pa_state;
	struct list_head rq_bc_pa_list;
};

typedef int (*kxdrdproc_t___2)(struct rpc_rqst___2 *, struct xdr_stream___2 *, void *);

struct rpc_procinfo___2;

struct rpc_message___2 {
	const struct rpc_procinfo___2 *rpc_proc;
	void *rpc_argp;
	void *rpc_resp;
	struct rpc_cred___2 *rpc_cred;
};

struct rpc_procinfo___2 {
	u32 p_proc;
	kxdreproc_t___2 p_encode;
	kxdrdproc_t___2 p_decode;
	unsigned int p_arglen;
	unsigned int p_replen;
	unsigned int p_timer;
	u32 p_statidx;
	const char *p_name;
};

struct rpc_auth___2;

struct rpc_credops___2;

struct rpc_cred___2 {
	struct hlist_node cr_hash;
	struct list_head cr_lru;
	struct callback_head cr_rcu;
	struct rpc_auth___2 *cr_auth;
	const struct rpc_credops___2 *cr_ops;
	long unsigned int cr_expire;
	long unsigned int cr_flags;
	atomic_t cr_count;
	kuid_t cr_uid;
};

struct rpc_call_ops___2;

struct rpc_clnt___2;

struct rpc_task___2 {
	atomic_t tk_count;
	int tk_status;
	struct list_head tk_task;
	void (*tk_callback)(struct rpc_task___2 *);
	void (*tk_action)(struct rpc_task___2 *);
	long unsigned int tk_timeout;
	long unsigned int tk_runstate;
	struct rpc_wait_queue *tk_waitqueue;
	union {
		struct work_struct tk_work;
		struct rpc_wait tk_wait;
	} u;
	struct rpc_message___2 tk_msg;
	void *tk_calldata;
	const struct rpc_call_ops___2 *tk_ops;
	struct rpc_clnt___2 *tk_client;
	struct rpc_xprt___2 *tk_xprt;
	struct rpc_rqst___2 *tk_rqstp;
	struct workqueue_struct *tk_workqueue;
	ktime_t tk_start;
	pid_t tk_owner;
	short unsigned int tk_flags;
	short unsigned int tk_timeouts;
	short unsigned int tk_pid;
	unsigned char tk_priority: 2;
	unsigned char tk_garb_retry: 2;
	unsigned char tk_cred_retry: 2;
	unsigned char tk_rebind_retry: 2;
};

struct rpc_call_ops___2 {
	void (*rpc_call_prepare)(struct rpc_task___2 *, void *);
	void (*rpc_call_done)(struct rpc_task___2 *, void *);
	void (*rpc_count_stats)(struct rpc_task___2 *, void *);
	void (*rpc_release)(void *);
};

struct rpc_pipe_dir_head___2 {
	struct list_head pdh_entries;
	struct dentry___37 *pdh_dentry;
};

struct rpc_xprt_switch___2;

struct rpc_xprt_iter_ops___2;

struct rpc_xprt_iter___2 {
	struct rpc_xprt_switch___2 *xpi_xpswitch;
	struct rpc_xprt___2 *xpi_cursor;
	const struct rpc_xprt_iter_ops___2 *xpi_ops;
};

struct rpc_stat___2;

struct rpc_program___2;

struct rpc_clnt___2 {
	atomic_t cl_count;
	unsigned int cl_clid;
	struct list_head cl_clients;
	struct list_head cl_tasks;
	spinlock_t cl_lock;
	struct rpc_xprt___2 *cl_xprt;
	const struct rpc_procinfo___2 *cl_procinfo;
	u32 cl_prog;
	u32 cl_vers;
	u32 cl_maxproc;
	struct rpc_auth___2 *cl_auth;
	struct rpc_stat___2 *cl_stats;
	struct rpc_iostats *cl_metrics;
	unsigned int cl_softrtry: 1;
	unsigned int cl_discrtry: 1;
	unsigned int cl_noretranstimeo: 1;
	unsigned int cl_autobind: 1;
	unsigned int cl_chatty: 1;
	struct rpc_rtt *cl_rtt;
	const struct rpc_timeout *cl_timeout;
	atomic_t cl_swapper;
	int cl_nodelen;
	char cl_nodename[65];
	struct rpc_pipe_dir_head___2 cl_pipedir_objects;
	struct rpc_clnt___2 *cl_parent;
	struct rpc_rtt cl_rtt_default;
	struct rpc_timeout cl_timeout_default;
	const struct rpc_program___2 *cl_program;
	struct dentry___37 *cl_debugfs;
	struct rpc_xprt_iter___2 cl_xpi;
};

struct rpc_xprt_ops___2;

struct rpc_xprt___2 {
	struct kref kref;
	const struct rpc_xprt_ops___2 *ops;
	const struct rpc_timeout *timeout;
	struct __kernel_sockaddr_storage addr;
	size_t addrlen;
	int prot;
	long unsigned int cong;
	long unsigned int cwnd;
	size_t max_payload;
	unsigned int tsh_size;
	struct rpc_wait_queue binding;
	struct rpc_wait_queue sending;
	struct rpc_wait_queue pending;
	struct rpc_wait_queue backlog;
	struct list_head free;
	unsigned int max_reqs;
	unsigned int min_reqs;
	unsigned int num_reqs;
	long unsigned int state;
	unsigned char resvport: 1;
	atomic_t swapper;
	unsigned int bind_index;
	struct list_head xprt_switch;
	long unsigned int bind_timeout;
	long unsigned int reestablish_timeout;
	unsigned int connect_cookie;
	struct work_struct task_cleanup;
	struct timer_list timer;
	long unsigned int last_used;
	long unsigned int idle_timeout;
	long unsigned int connect_timeout;
	long unsigned int max_reconnect_timeout;
	spinlock_t transport_lock;
	spinlock_t reserve_lock;
	spinlock_t recv_lock;
	u32 xid;
	struct rpc_task___2 *snd_task;
	struct svc_xprt *bc_xprt;
	struct svc_serv *bc_serv;
	int bc_alloc_count;
	atomic_t bc_free_slots;
	spinlock_t bc_pa_lock;
	struct list_head bc_pa_list;
	struct list_head recv;
	struct {
		long unsigned int bind_count;
		long unsigned int connect_count;
		long unsigned int connect_start;
		long unsigned int connect_time;
		long unsigned int sends;
		long unsigned int recvs;
		long unsigned int bad_xids;
		long unsigned int max_slots;
		long long unsigned int req_u;
		long long unsigned int bklog_u;
		long long unsigned int sending_u;
		long long unsigned int pending_u;
	} stat;
	struct net___9 *xprt_net;
	const char *servername;
	const char *address_strings[6];
	struct dentry___37 *debugfs;
	atomic_t inject_disconnect;
	struct callback_head rcu;
};

struct inet_frag_queue___3;

struct inet_frags___3 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___3 *, const void *);
	void (*destructor)(struct inet_frag_queue___3 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___3 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___7 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___7 *fragments_tail;
	struct sk_buff___7 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___3 *net;
	struct callback_head rcu;
};

struct fib_rule___2;

struct fib_lookup_arg___2;

struct fib_rules_ops___2 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___2 *, struct flowi *, int, struct fib_lookup_arg___2 *);
	bool (*suppress)(struct fib_rule___2 *, struct fib_lookup_arg___2 *);
	int (*match)(struct fib_rule___2 *, struct flowi *, int);
	int (*configure)(struct fib_rule___2 *, struct sk_buff___7 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___2 *);
	int (*compare)(struct fib_rule___2 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___2 *, struct sk_buff___7 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___2 *);
	void (*flush_cache)(struct fib_rules_ops___2 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___33 *owner;
	struct net___9 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___2 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___9 *);
	int (*fib_dump)(struct net___9 *, struct notifier_block *);
	struct module___33 *owner;
	struct callback_head rcu;
};

struct dst_entry___4 {
	struct net_device___8 *dev;
	struct dst_ops___7 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___7 *);
	int (*output)(struct net___9 *, struct sock___5 *, struct sk_buff___7 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___3;

struct neigh_parms___4;

struct neigh_ops___3;

struct neighbour___4 {
	struct neighbour___4 *next;
	struct neigh_table___3 *tbl;
	struct neigh_parms___4 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___4 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___4 *, struct sk_buff___7 *);
	const struct neigh_ops___3 *ops;
	struct callback_head rcu;
	struct net_device___8 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct pipe_buf_operations___6;

struct pipe_buffer___6 {
	struct page___36 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___6 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___6 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___6 *, struct pipe_buffer___6 *);
	void (*release)(struct pipe_inode_info___6 *, struct pipe_buffer___6 *);
	int (*steal)(struct pipe_inode_info___6 *, struct pipe_buffer___6 *);
	union {
		bool (*get)(struct pipe_inode_info___6 *, struct pipe_buffer___6 *);
		struct {
			void (*get)(struct pipe_inode_info___6 *, struct pipe_buffer___6 *);
		} __UNIQUE_ID_rh_kabi_hide39;
		union {		};
	};
};

struct nf_bridge_info___3 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___3 = 0,
		BRNF_PROTO_8021Q___3 = 1,
		BRNF_PROTO_PPPOE___3 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___8 *physindev;
	struct net_device___8 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

struct pernet_operations___3 {
	struct list_head list;
	int (*init)(struct net___9 *);
	void (*exit)(struct net___9 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct rpc_authops___2;

struct rpc_auth___2 {
	unsigned int au_cslack;
	unsigned int au_rslack;
	unsigned int au_verfsize;
	unsigned int au_flags;
	const struct rpc_authops___2 *au_ops;
	rpc_authflavor_t au_flavor;
	atomic_t au_count;
	struct rpc_cred_cache *au_credcache;
};

struct rpc_credops___2 {
	const char *cr_name;
	int (*cr_init)(struct rpc_auth___2 *, struct rpc_cred___2 *);
	void (*crdestroy)(struct rpc_cred___2 *);
	int (*crmatch)(struct auth_cred *, struct rpc_cred___2 *, int);
	struct rpc_cred___2 * (*crbind)(struct rpc_task___2 *, struct rpc_cred___2 *, int);
	__be32 * (*crmarshal)(struct rpc_task___2 *, __be32 *);
	int (*crrefresh)(struct rpc_task___2 *);
	__be32 * (*crvalidate)(struct rpc_task___2 *, __be32 *);
	int (*crwrap_req)(struct rpc_task___2 *, kxdreproc_t___2, void *, __be32 *, void *);
	int (*crunwrap_resp)(struct rpc_task___2 *, kxdrdproc_t___2, void *, __be32 *, void *);
	int (*crkey_timeout)(struct rpc_cred___2 *);
	bool (*crkey_to_expire)(struct rpc_cred___2 *);
	char * (*crstringify_acceptor)(struct rpc_cred___2 *);
};

struct rpc_authops___2 {
	struct module___33 *owner;
	rpc_authflavor_t au_flavor;
	char *au_name;
	struct rpc_auth___2 * (*create)(struct rpc_auth_create_args *, struct rpc_clnt___2 *);
	void (*destroy)(struct rpc_auth___2 *);
	int (*hash_cred)(struct auth_cred *, unsigned int);
	struct rpc_cred___2 * (*lookup_cred)(struct rpc_auth___2 *, struct auth_cred *, int);
	struct rpc_cred___2 * (*crcreate)(struct rpc_auth___2 *, struct auth_cred *, int, gfp_t);
	int (*list_pseudoflavors)(rpc_authflavor_t *, int);
	rpc_authflavor_t (*info2flavor)(struct rpcsec_gss_info *);
	int (*flavor2info)(rpc_authflavor_t, struct rpcsec_gss_info *);
	int (*key_timeout)(struct rpc_auth___2 *, struct rpc_cred___2 *);
};

struct rpc_xprt_ops___2 {
	void (*set_buffer_size)(struct rpc_xprt___2 *, size_t, size_t);
	int (*reserve_xprt)(struct rpc_xprt___2 *, struct rpc_task___2 *);
	void (*release_xprt)(struct rpc_xprt___2 *, struct rpc_task___2 *);
	void (*alloc_slot)(struct rpc_xprt___2 *, struct rpc_task___2 *);
	void (*free_slot)(struct rpc_xprt___2 *, struct rpc_rqst___2 *);
	void (*rpcbind)(struct rpc_task___2 *);
	void (*set_port)(struct rpc_xprt___2 *, short unsigned int);
	void (*connect)(struct rpc_xprt___2 *, struct rpc_task___2 *);
	int (*buf_alloc)(struct rpc_task___2 *);
	void (*buf_free)(struct rpc_task___2 *);
	int (*send_request)(struct rpc_task___2 *);
	void (*set_retrans_timeout)(struct rpc_task___2 *);
	void (*timer)(struct rpc_xprt___2 *, struct rpc_task___2 *);
	void (*release_request)(struct rpc_task___2 *);
	void (*close)(struct rpc_xprt___2 *);
	void (*destroy)(struct rpc_xprt___2 *);
	void (*set_connect_timeout)(struct rpc_xprt___2 *, long unsigned int, long unsigned int);
	void (*print_stats)(struct rpc_xprt___2 *, struct seq_file___33 *);
	int (*enable_swap)(struct rpc_xprt___2 *);
	void (*disable_swap)(struct rpc_xprt___2 *);
	void (*inject_disconnect)(struct rpc_xprt___2 *);
	int (*bc_setup)(struct rpc_xprt___2 *, unsigned int);
	int (*bc_up)(struct svc_serv *, struct net___9 *);
	size_t (*bc_maxpayload)(struct rpc_xprt___2 *);
	void (*bc_free_rqst)(struct rpc_rqst___2 *);
	void (*bc_destroy)(struct rpc_xprt___2 *, unsigned int);
};

struct rpc_xprt_switch___2 {
	spinlock_t xps_lock;
	struct kref xps_kref;
	unsigned int xps_nxprts;
	struct list_head xps_xprt_list;
	struct net___9 *xps_net;
	const struct rpc_xprt_iter_ops___2 *xps_iter_ops;
	struct callback_head xps_rcu;
};

struct rpc_stat___2 {
	const struct rpc_program___2 *program;
	unsigned int netcnt;
	unsigned int netudpcnt;
	unsigned int nettcpcnt;
	unsigned int nettcpconn;
	unsigned int netreconn;
	unsigned int rpccnt;
	unsigned int rpcretrans;
	unsigned int rpcauthrefresh;
	unsigned int rpcgarbage;
};

struct rpc_version___2;

struct rpc_program___2 {
	const char *name;
	u32 number;
	unsigned int nrvers;
	const struct rpc_version___2 **version;
	struct rpc_stat___2 *stats;
	const char *pipe_dir_name;
};

struct ethtool_ops___3 {
	int (*get_settings)(struct net_device___8 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___8 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___8 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___8 *);
	void (*get_regs)(struct net_device___8 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___8 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___8 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___8 *);
	void (*set_msglevel)(struct net_device___8 *, u32);
	int (*nway_reset)(struct net_device___8 *);
	u32 (*get_link)(struct net_device___8 *);
	int (*get_eeprom_len)(struct net_device___8 *);
	int (*get_eeprom)(struct net_device___8 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___8 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___8 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___8 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___8 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___8 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___8 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___8 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___8 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___8 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___8 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___8 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___8 *);
	void (*complete)(struct net_device___8 *);
	u32 (*get_priv_flags)(struct net_device___8 *);
	int (*set_priv_flags)(struct net_device___8 *, u32);
	int (*get_sset_count)(struct net_device___8 *, int);
	int (*get_rxnfc)(struct net_device___8 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___8 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___8 *, struct ethtool_flash *);
	int (*reset)(struct net_device___8 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___8 *);
	u32 (*get_rxfh_indir_size)(struct net_device___8 *);
	int (*get_rxfh)(struct net_device___8 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___8 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___8 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___8 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___8 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___8 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___8 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___8 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___8 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___8 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___8 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___8 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___8 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___8 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___8 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___8 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___8 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___8 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___8 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___8 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide42;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___8 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___8 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide43;
		union {		};
	};
	int (*get_fecparam)(struct net_device___8 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___8 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___8 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___8 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide44;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___8 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide45;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct dcbnl_rtnl_ops___3 {
	int (*ieee_getets)(struct net_device___8 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___8 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___8 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___8 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___8 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___8 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___8 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___8 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___8 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___8 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___8 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___8 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___8 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___8 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___8 *);
	u8 (*setstate)(struct net_device___8 *, u8);
	void (*getpermhwaddr)(struct net_device___8 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___8 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___8 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___8 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___8 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___8 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___8 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___8 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___8 *, int, u8 *);
	void (*setpfccfg)(struct net_device___8 *, int, u8);
	void (*getpfccfg)(struct net_device___8 *, int, u8 *);
	u8 (*setall)(struct net_device___8 *);
	u8 (*getcap)(struct net_device___8 *, int, u8 *);
	int (*getnumtcs)(struct net_device___8 *, int, u8 *);
	int (*setnumtcs)(struct net_device___8 *, int, u8);
	u8 (*getpfcstate)(struct net_device___8 *);
	void (*setpfcstate)(struct net_device___8 *, u8);
	void (*getbcncfg)(struct net_device___8 *, int, u32 *);
	void (*setbcncfg)(struct net_device___8 *, int, u32);
	void (*getbcnrp)(struct net_device___8 *, int, u8 *);
	void (*setbcnrp)(struct net_device___8 *, int, u8);
	int (*setapp)(struct net_device___8 *, u8, u16, u8);
	int (*getapp)(struct net_device___8 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___8 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___8 *, int, u8);
	u8 (*getdcbx)(struct net_device___8 *);
	u8 (*setdcbx)(struct net_device___8 *, u8);
	int (*peer_getappinfo)(struct net_device___8 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___8 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___8 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___8 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___8 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___8 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct xdp_rxq_info___3 {
	struct net_device___8 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___3 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___8 *dev_rx;
};

struct netlink_callback___3 {
	struct sk_buff___7 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___3 *);
	int (*dump)(struct sk_buff___7 *, struct netlink_callback___3 *);
	int (*done)(struct netlink_callback___3 *);
	void *data;
	struct module___33 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___3 {
	int (*create)(struct sk_buff___7 *, struct net_device___8 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___7 *, unsigned char *);
	int (*cache)(const struct neighbour___4 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___8 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___3 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___3 *, int);
	int poll_owner;
	struct net_device___8 *dev;
	struct sk_buff___7 *gro_list;
	struct sk_buff___7 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___3 {
	struct net_device___8 *dev;
	struct Qdisc___3 *qdisc;
	struct Qdisc___3 *qdisc_sleeping;
	struct kobject___34 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___8 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide46;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___3 {
	struct sk_buff___7 *head;
	struct sk_buff___7 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___3;

struct Qdisc___3 {
	int (*enqueue)(struct sk_buff___7 *, struct Qdisc___3 *, struct sk_buff___7 **);
	struct sk_buff___7 * (*dequeue)(struct Qdisc___3 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___3 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___3 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___4 gso_skb;
	struct qdisc_skb_head___3 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___3 *next_sched;
	struct sk_buff_head___4 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___3 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___34 kobj;
	struct net_device___8 *dev;
	long: 64;
	struct xdp_rxq_info___3 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide47;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___3)(struct net_device___8 *, struct sk_buff___7 *, struct net_device___8 *);

struct netdev_bpf___3 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___3 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___3 *prog;
			const struct bpf_prog_offload_ops___3 *ops;
		} verifier;
		struct {
			struct bpf_prog___3 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___3 *offmap;
		};
		struct {
			struct xdp_umem *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___3 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___7 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___3 {
	int (*tls_dev_add)(struct net_device___8 *, struct sock___5 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___8 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___8 *, struct sock___5 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide48;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___3 {
	int (*ndo_init)(struct net_device___8 *);
	void (*ndo_uninit)(struct net_device___8 *);
	int (*ndo_open)(struct net_device___8 *);
	int (*ndo_stop)(struct net_device___8 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___7 *, struct net_device___8 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___7 *, struct net_device___8 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___8 *, struct sk_buff___7 *, struct net_device___8 *, select_queue_fallback_t___3);
	void (*ndo_change_rx_flags)(struct net_device___8 *, int);
	void (*ndo_set_rx_mode)(struct net_device___8 *);
	int (*ndo_set_mac_address)(struct net_device___8 *, void *);
	int (*ndo_validate_addr)(struct net_device___8 *);
	int (*ndo_do_ioctl)(struct net_device___8 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___8 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___8 *, int);
	int (*ndo_neigh_setup)(struct net_device___8 *, struct neigh_parms___4 *);
	void (*ndo_tx_timeout)(struct net_device___8 *);
	void (*ndo_get_stats64)(struct net_device___8 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___8 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___8 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___8 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___8 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___8 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___8 *);
	int (*ndo_netpoll_setup)(struct net_device___8 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___8 *);
	int (*ndo_set_vf_mac)(struct net_device___8 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___8 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___8 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___8 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___8 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___8 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___8 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___8 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___8 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___8 *, int, struct sk_buff___7 *);
	int (*ndo_set_vf_guid)(struct net_device___8 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___8 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___8 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___8 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___8 *, const struct sk_buff___7 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___8 *, struct net_device___8 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___8 *, struct net_device___8 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___8 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___8 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___8 *, struct neighbour___4 *);
	void (*ndo_neigh_destroy)(struct net_device___8 *, struct neighbour___4 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___8 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___8 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide49;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___8 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___7 *, struct netlink_callback___3 *, struct net_device___8 *, struct net_device___8 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___8 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___8 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide50;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___7 *, u32, u32, struct net_device___8 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___8 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___8 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___8 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___8 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___8 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___8 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___8 *, struct net_device___8 *);
	void (*ndo_dfwd_del_station)(struct net_device___8 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___8 *);
	int (*ndo_set_tx_maxrate)(struct net_device___8 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___8 *);
	int (*ndo_change_proto_down)(struct net_device___8 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___8 *, struct sk_buff___7 *);
	void (*ndo_set_rx_headroom)(struct net_device___8 *, int);
	int (*ndo_bpf)(struct net_device___8 *, struct netdev_bpf___3 *);
	int (*ndo_xdp_xmit)(struct net_device___8 *, int, struct xdp_frame___3 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___8 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___8 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide51;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___4 {
	possible_net_t___3 net;
	struct net_device___8 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___4 *);
	void (*neigh_cleanup)(struct neighbour___4 *);
	struct neigh_table___3 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___3 {
	u32 (*l3mdev_fib_table)(const struct net_device___8 *);
	struct sk_buff___7 * (*l3mdev_l3_rcv)(struct net_device___8 *, struct sk_buff___7 *, u16);
	struct sk_buff___7 * (*l3mdev_l3_out)(struct net_device___8 *, struct sock___5 *, struct sk_buff___7 *, u16);
	struct dst_entry___4 * (*l3mdev_link_scope_lookup)(const struct net_device___8 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct ndisc_ops___3 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___8 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___8 *, struct neighbour___4 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___8 *, u8, struct neighbour___4 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___8 *, struct sk_buff___7 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___9 *, struct net_device___8 *, const struct prefix_info *, struct inet6_dev___3 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___2;

struct inet6_dev___3 {
	struct net_device___8 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___2 *mc_list;
	struct ifmcaddr6___2 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	u8 rndid[8];
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___4 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
};

struct tcf_proto___3;

struct mini_Qdisc___3 {
	struct tcf_proto___3 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___3 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___8 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___9 *, struct net_device___8 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___8 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___8 *, struct list_head *);
	size_t (*get_size)(const struct net_device___8 *);
	int (*fill_info)(struct sk_buff___7 *, const struct net_device___8 *);
	size_t (*get_xstats_size)(const struct net_device___8 *);
	int (*fill_xstats)(struct sk_buff___7 *, const struct net_device___8 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___8 *, struct net_device___8 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___8 *, const struct net_device___8 *);
	int (*fill_slave_info)(struct sk_buff___7 *, const struct net_device___8 *, const struct net_device___8 *);
	struct net___9 * (*get_link_net)(const struct net_device___8 *);
	size_t (*get_linkxstats_size)(const struct net_device___8 *, int);
	int (*fill_linkxstats)(struct sk_buff___7 *, const struct net_device___8 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___3 {
	struct list_head poll_list;
	struct sk_buff_head___4 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___3 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___3 *output_queue;
	struct Qdisc___3 **output_queue_tailp;
	struct sk_buff___7 *completion_queue;
	struct sk_buff_head___4 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___3 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___4 input_pkt_queue;
	struct napi_struct___3 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct gnet_dump___3 {
	spinlock_t *lock;
	struct sk_buff___7 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___3;

struct Qdisc_ops___3 {
	struct Qdisc_ops___3 *next;
	const struct Qdisc_class_ops___3 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___7 *, struct Qdisc___3 *, struct sk_buff___7 **);
	struct sk_buff___7 * (*dequeue)(struct Qdisc___3 *);
	struct sk_buff___7 * (*peek)(struct Qdisc___3 *);
	int (*init)(struct Qdisc___3 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___3 *);
	void (*destroy)(struct Qdisc___3 *);
	int (*change)(struct Qdisc___3 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___3 *);
	int (*change_tx_queue_len)(struct Qdisc___3 *, unsigned int);
	int (*dump)(struct Qdisc___3 *, struct sk_buff___7 *);
	int (*dump_stats)(struct Qdisc___3 *, struct gnet_dump___3 *);
	void (*ingress_block_set)(struct Qdisc___3 *, u32);
	void (*egress_block_set)(struct Qdisc___3 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___3 *);
	u32 (*egress_block_get)(struct Qdisc___3 *);
	struct module___33 *owner;
};

struct tcf_block___3;

struct Qdisc_class_ops___3 {
	unsigned int flags;
	struct netdev_queue___3 * (*select_queue)(struct Qdisc___3 *, struct tcmsg *);
	int (*graft)(struct Qdisc___3 *, long unsigned int, struct Qdisc___3 *, struct Qdisc___3 **, struct netlink_ext_ack *);
	struct Qdisc___3 * (*leaf)(struct Qdisc___3 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___3 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___3 *, u32);
	int (*change)(struct Qdisc___3 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___3 *, long unsigned int);
	void (*walk)(struct Qdisc___3 *, struct qdisc_walker *);
	struct tcf_block___3 * (*tcf_block)(struct Qdisc___3 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___3 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___3 *, long unsigned int);
	int (*dump)(struct Qdisc___3 *, long unsigned int, struct sk_buff___7 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___3 *, long unsigned int, struct gnet_dump___3 *);
};

struct tcf_chain___3;

struct tcf_block___3 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___9 *net;
	struct Qdisc___3 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___3 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___3;

struct tcf_proto_ops___3;

struct tcf_proto___3 {
	struct tcf_proto___3 *next;
	void *root;
	int (*classify)(struct sk_buff___7 *, const struct tcf_proto___3 *, struct tcf_result___3 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___3 *ops;
	struct tcf_chain___3 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___3 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___3 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___3 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___7 *, const struct tcf_proto___3 *, struct tcf_result___3 *);
	int (*init)(struct tcf_proto___3 *);
	void (*destroy)(struct tcf_proto___3 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___3 *, u32);
	void (*put)(struct tcf_proto___3 *, void *);
	int (*change)(struct net___9 *, struct sk_buff___7 *, struct tcf_proto___3 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___3 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___3 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___3 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___9 *, struct tcf_chain___3 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___9 *, struct tcf_proto___3 *, void *, struct sk_buff___7 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___7 *, struct net___9 *, void *);
	struct module___33 *owner;
	int flags;
};

struct tcf_chain___3 {
	struct mutex filter_chain_lock;
	struct tcf_proto___3 *filter_chain;
	struct list_head list;
	struct tcf_block___3 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___3 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___2 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___3 *prog;
};

struct bpf_redirect_info___3 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___25 *map;
	struct bpf_map___25 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___2;

struct neigh_hash_table___2;

struct neigh_table___3 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___8 *, __u32 *);
	bool (*key_eq)(const struct neighbour___4 *, const void *);
	int (*constructor)(struct neighbour___4 *);
	int (*pconstructor)(struct pneigh_entry___2 *);
	void (*pdestructor)(struct pneigh_entry___2 *);
	void (*proxy_redo)(struct sk_buff___7 *);
	char *id;
	struct neigh_parms___4 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___4 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___2 *nht;
	struct pneigh_entry___2 **phash_buckets;
};

struct neigh_ops___3 {
	int family;
	void (*solicit)(struct neighbour___4 *, struct sk_buff___7 *);
	void (*error_report)(struct neighbour___4 *, struct sk_buff___7 *);
	int (*output)(struct neighbour___4 *, struct sk_buff___7 *);
	int (*connected_output)(struct neighbour___4 *, struct sk_buff___7 *);
};

struct pneigh_entry___2 {
	struct pneigh_entry___2 *next;
	possible_net_t___3 net;
	struct net_device___8 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___2 {
	struct neighbour___4 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___2 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___2 *ctarget;
	struct net___9 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___2 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___2 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___2;

struct timewait_sock_ops___2;

struct proto___2 {
	void (*close)(struct sock___5 *, long int);
	int (*pre_connect)(struct sock___5 *, struct sockaddr *, int);
	int (*connect)(struct sock___5 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___5 *, int);
	struct sock___5 * (*accept)(struct sock___5 *, int, int *, bool);
	int (*ioctl)(struct sock___5 *, int, long unsigned int);
	int (*init)(struct sock___5 *);
	void (*destroy)(struct sock___5 *);
	void (*shutdown)(struct sock___5 *, int);
	int (*setsockopt)(struct sock___5 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___5 *, int, int, char *, int *);
	void (*keepalive)(struct sock___5 *, int);
	int (*sendmsg)(struct sock___5 *, struct msghdr___2 *, size_t);
	int (*recvmsg)(struct sock___5 *, struct msghdr___2 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___5 *, struct page___36 *, int, size_t, int);
	int (*bind)(struct sock___5 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___5 *, struct sk_buff___7 *);
	void (*release_cb)(struct sock___5 *);
	int (*hash)(struct sock___5 *);
	void (*unhash)(struct sock___5 *);
	void (*rehash)(struct sock___5 *);
	int (*get_port)(struct sock___5 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___5 *);
	bool (*stream_memory_read)(const struct sock___5 *);
	void (*enter_memory_pressure)(struct sock___5 *);
	void (*leave_memory_pressure)(struct sock___5 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___2 *rsk_prot;
	struct timewait_sock_ops___2 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___33 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___5 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct request_sock___2;

struct request_sock_ops___2 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___5 *, struct request_sock___2 *);
	void (*send_ack)(const struct sock___5 *, struct sk_buff___7 *, struct request_sock___2 *);
	void (*send_reset)(const struct sock___5 *, struct sk_buff___7 *);
	void (*destructor)(struct request_sock___2 *);
	void (*syn_ack_timeout)(const struct request_sock___2 *);
};

struct timewait_sock_ops___2 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___5 *, struct sock___5 *, void *);
	void (*twsk_destructor)(struct sock___5 *);
};

struct request_sock___2 {
	struct sock_common___2 __req_common;
	struct request_sock___2 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___2 *rsk_ops;
	struct sock___5 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___2 {
	struct in6_addr mca_addr;
	struct inet6_dev___3 *idev;
	struct ifmcaddr6___2 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ip6_ra_chain___2 {
	struct ip6_ra_chain___2 *next;
	struct sock___5 *sk;
	int sel;
	void (*destructor)(struct sock___5 *);
};

struct rpc_xprt_iter_ops___2 {
	void (*xpi_rewind)(struct rpc_xprt_iter___2 *);
	struct rpc_xprt___2 * (*xpi_xprt)(struct rpc_xprt_iter___2 *);
	struct rpc_xprt___2 * (*xpi_next)(struct rpc_xprt_iter___2 *);
};

struct rpc_version___2 {
	u32 number;
	unsigned int nrprocs;
	const struct rpc_procinfo___2 *procs;
	unsigned int *counts;
};

struct nfs_open_context___2;

struct nfs_lock_context___2 {
	refcount_t count;
	struct list_head list;
	struct nfs_open_context___2 *open_context;
	fl_owner_t lockowner;
	atomic_t io_count;
};

struct nfs_open_context___2 {
	struct nfs_lock_context___2 lock_context;
	fl_owner_t flock_owner;
	struct dentry___37 *dentry;
	struct rpc_cred___2 *cred;
	struct nfs4_state *state;
	fmode_t mode;
	long unsigned int flags;
	int error;
	struct list_head list;
	struct nfs4_threshold *mdsthreshold;
};

struct nfs_client___2;

struct nfs_server___2 {
	struct nfs_client___2 *nfs_client;
	struct list_head client_link;
	struct list_head master_link;
	struct rpc_clnt___2 *client;
	struct rpc_clnt___2 *client_acl;
	struct nlm_host *nlm_host;
	struct nfs_iostats *io_stats;
	atomic_long_t writeback;
	int flags;
	unsigned int caps;
	unsigned int rsize;
	unsigned int rpages;
	unsigned int wsize;
	unsigned int wpages;
	unsigned int wtmult;
	unsigned int dtsize;
	short unsigned int port;
	unsigned int bsize;
	unsigned int acregmin;
	unsigned int acregmax;
	unsigned int acdirmin;
	unsigned int acdirmax;
	unsigned int namelen;
	unsigned int options;
	unsigned int clone_blksize;
	struct nfs_fsid fsid;
	__u64 maxfilesize;
	struct timespec time_delta;
	long unsigned int mount_time;
	struct super_block___36 *super;
	dev_t s_dev;
	struct nfs_auth_info auth_info;
	struct nfs_fscache_key *fscache_key;
	struct fscache_cookie *fscache;
	u32 pnfs_blksize;
	u32 attr_bitmask[3];
	u32 attr_bitmask_nl[3];
	u32 exclcreat_bitmask[3];
	u32 cache_consistency_bitmask[3];
	u32 acl_bitmask;
	u32 fh_expire_type;
	struct pnfs_layoutdriver_type *pnfs_curr_ld;
	struct rpc_wait_queue roc_rpcwaitq;
	void *pnfs_ld_data;
	struct rb_root state_owners;
	struct ida openowner_id;
	struct ida lockowner_id;
	struct list_head state_owners_lru;
	struct list_head layouts;
	struct list_head delegations;
	long unsigned int mig_gen;
	long unsigned int mig_status;
	void (*destroy)(struct nfs_server___2 *);
	atomic_t active;
	int: 32;
	struct __kernel_sockaddr_storage mountd_address;
	size_t mountd_addrlen;
	u32 mountd_version;
	short unsigned int mountd_port;
	short unsigned int mountd_protocol;
	struct rpc_wait_queue uoc_rpcwaitq;
};

struct nfs_rpc_ops___2;

struct nfs_client___2 {
	refcount_t cl_count;
	atomic_t cl_mds_count;
	seqcount_t cl_callback_count;
	int cl_cons_state;
	long unsigned int cl_res_state;
	long unsigned int cl_flags;
	struct __kernel_sockaddr_storage cl_addr;
	size_t cl_addrlen;
	char *cl_hostname;
	char *cl_acceptor;
	struct list_head cl_share_link;
	struct list_head cl_superblocks;
	struct rpc_clnt___2 *cl_rpcclient;
	const struct nfs_rpc_ops___2 *rpc_ops;
	int cl_proto;
	struct nfs_subversion *cl_nfs_mod;
	u32 cl_minorversion;
	struct rpc_cred___2 *cl_machine_cred;
	struct list_head cl_ds_clients;
	u64 cl_clientid;
	nfs4_verifier cl_confirm;
	long unsigned int cl_state;
	spinlock_t cl_lock;
	long unsigned int cl_lease_time;
	long unsigned int cl_last_renewal;
	struct delayed_work cl_renewd;
	struct rpc_wait_queue cl_rpcwaitq;
	struct idmap *cl_idmap;
	const char *cl_owner_id;
	u32 cl_cb_ident;
	const struct nfs4_minor_version_ops *cl_mvops;
	long unsigned int cl_mig_gen;
	struct nfs4_slot_table *cl_slot_tbl;
	u32 cl_seqid;
	u32 cl_exchange_flags;
	struct nfs4_session *cl_session;
	bool cl_preserve_clid;
	struct nfs41_server_owner *cl_serverowner;
	struct nfs41_server_scope *cl_serverscope;
	struct nfs41_impl_id *cl_implid;
	long unsigned int cl_sp4_flags;
	wait_queue_head_t cl_lock_waitq;
	char cl_ipaddr[48];
	struct fscache_cookie *fscache;
	struct net___9 *cl_net;
};

struct nfs_pgio_args___2 {
	struct nfs4_sequence_args seq_args;
	struct nfs_fh *fh;
	struct nfs_open_context___2 *context;
	struct nfs_lock_context___2 *lock_context;
	nfs4_stateid stateid;
	__u64 offset;
	__u32 count;
	unsigned int pgbase;
	struct page___36 **pages;
	const u32 *bitmask;
	enum nfs3_stable_how stable;
};

struct nfs_pgio_res___2 {
	struct nfs4_sequence_res seq_res;
	struct nfs_fattr *fattr;
	__u32 count;
	__u32 op_status;
	int eof;
	struct nfs_writeverf *verf;
	const struct nfs_server___2 *server;
};

struct nfs_commitres___2 {
	struct nfs4_sequence_res seq_res;
	__u32 op_status;
	struct nfs_fattr *fattr;
	struct nfs_writeverf *verf;
	const struct nfs_server___2 *server;
};

struct nfs_removeres___2 {
	struct nfs4_sequence_res seq_res;
	struct nfs_server___2 *server;
	struct nfs_fattr *dir_attr;
	struct nfs4_change_info cinfo;
};

struct nfs_renameres___2 {
	struct nfs4_sequence_res seq_res;
	struct nfs_server___2 *server;
	struct nfs4_change_info old_cinfo;
	struct nfs_fattr *old_fattr;
	struct nfs4_change_info new_cinfo;
	struct nfs_fattr *new_fattr;
};

struct nfs_entry___2 {
	__u64 ino;
	__u64 cookie;
	__u64 prev_cookie;
	const char *name;
	unsigned int len;
	int eof;
	struct nfs_fh *fh;
	struct nfs_fattr *fattr;
	struct nfs4_label *label;
	unsigned char d_type;
	struct nfs_server___2 *server;
};

struct nfs_page_array___2 {
	struct page___36 **pagevec;
	unsigned int npages;
	struct page___36 *page_array[8];
};

struct nfs_pgio_completion_ops___2;

struct nfs_pgio_header___2 {
	struct inode___38 *inode;
	struct rpc_cred___2 *cred;
	struct list_head pages;
	struct nfs_page *req;
	struct nfs_writeverf verf;
	fmode_t rw_mode;
	struct pnfs_layout_segment *lseg;
	loff_t io_start;
	const struct rpc_call_ops___2 *mds_ops;
	void (*release)(struct nfs_pgio_header___2 *);
	const struct nfs_pgio_completion_ops___2 *completion_ops;
	const struct nfs_rw_ops *rw_ops;
	struct nfs_io_completion *io_completion;
	struct nfs_direct_req *dreq;
	spinlock_t lock;
	int pnfs_error;
	int error;
	long unsigned int good_bytes;
	long unsigned int flags;
	struct rpc_task___2 task;
	struct nfs_fattr fattr;
	struct nfs_pgio_args___2 args;
	struct nfs_pgio_res___2 res;
	long unsigned int timestamp;
	int (*pgio_done_cb)(struct rpc_task___2 *, struct nfs_pgio_header___2 *);
	__u64 mds_offset;
	struct nfs_page_array___2 page_array;
	struct nfs_client___2 *ds_clp;
	int ds_commit_idx;
	int pgio_mirror_idx;
};

struct nfs_pgio_completion_ops___2 {
	void (*error_cleanup)(struct list_head *);
	void (*init_hdr)(struct nfs_pgio_header___2 *);
	void (*completion)(struct nfs_pgio_header___2 *);
	void (*reschedule_io)(struct nfs_pgio_header___2 *);
};

struct nfs_commit_data___2;

struct nfs_commit_info___2;

struct nfs_commit_completion_ops___2 {
	void (*completion)(struct nfs_commit_data___2 *);
	void (*resched_write)(struct nfs_commit_info___2 *, struct nfs_page *);
};

struct nfs_commit_data___2 {
	struct rpc_task___2 task;
	struct inode___38 *inode;
	struct rpc_cred___2 *cred;
	struct nfs_fattr fattr;
	struct nfs_writeverf verf;
	struct list_head pages;
	struct list_head list;
	struct nfs_direct_req *dreq;
	struct nfs_commitargs args;
	struct nfs_commitres___2 res;
	struct nfs_open_context___2 *context;
	struct pnfs_layout_segment *lseg;
	struct nfs_client___2 *ds_clp;
	int ds_commit_index;
	loff_t lwb;
	const struct rpc_call_ops___2 *mds_ops;
	const struct nfs_commit_completion_ops___2 *completion_ops;
	int (*commit_done_cb)(struct rpc_task___2 *, struct nfs_commit_data___2 *);
	long unsigned int flags;
};

struct nfs_commit_info___2 {
	struct inode___38 *inode;
	struct nfs_mds_commit_info *mds;
	struct pnfs_ds_commit_info *ds;
	struct nfs_direct_req *dreq;
	const struct nfs_commit_completion_ops___2 *completion_ops;
};

struct nfs_unlinkdata___2 {
	struct nfs_removeargs args;
	struct nfs_removeres___2 res;
	struct dentry___37 *dentry;
	wait_queue_head_t wq;
	struct rpc_cred___2 *cred;
	struct nfs_fattr dir_attr;
	long int timeout;
};

struct nfs_renamedata___2 {
	struct nfs_renameargs args;
	struct nfs_renameres___2 res;
	struct rpc_cred___2 *cred;
	struct inode___38 *old_dir;
	struct dentry___37 *old_dentry;
	struct nfs_fattr old_fattr;
	struct inode___38 *new_dir;
	struct dentry___37 *new_dentry;
	struct nfs_fattr new_fattr;
	void (*complete)(struct rpc_task___2 *, struct nfs_renamedata___2 *);
	long int timeout;
	bool cancelled;
};

struct nfs_access_entry___2;

struct nfs_rpc_ops___2 {
	u32 version;
	const struct dentry_operations___35 *dentry_ops;
	const struct inode_operations___35 *dir_inode_ops;
	const struct inode_operations___35 *file_inode_ops;
	const struct file_operations___36 *file_ops;
	const struct nlmclnt_operations *nlmclnt_ops;
	int (*getroot)(struct nfs_server___2 *, struct nfs_fh *, struct nfs_fsinfo *);
	struct vfsmount___6 * (*submount)(struct nfs_server___2 *, struct dentry___37 *, struct nfs_fh *, struct nfs_fattr *);
	struct dentry___37 * (*try_mount)(int, const char *, struct nfs_mount_info *, struct nfs_subversion *);
	int (*getattr)(struct nfs_server___2 *, struct nfs_fh *, struct nfs_fattr *, struct nfs4_label *, struct inode___38 *);
	int (*setattr)(struct dentry___37 *, struct nfs_fattr *, struct iattr___36 *);
	int (*lookup)(struct inode___38 *, const struct qstr *, struct nfs_fh *, struct nfs_fattr *, struct nfs4_label *);
	int (*lookupp)(struct inode___38 *, struct nfs_fh *, struct nfs_fattr *, struct nfs4_label *);
	int (*access)(struct inode___38 *, struct nfs_access_entry___2 *);
	int (*readlink)(struct inode___38 *, struct page___36 *, unsigned int, unsigned int);
	int (*create)(struct inode___38 *, struct dentry___37 *, struct iattr___36 *, int);
	int (*remove)(struct inode___38 *, struct dentry___37 *);
	void (*unlink_setup)(struct rpc_message___2 *, struct dentry___37 *, struct inode___38 *);
	void (*unlink_rpc_prepare)(struct rpc_task___2 *, struct nfs_unlinkdata___2 *);
	int (*unlink_done)(struct rpc_task___2 *, struct inode___38 *);
	void (*rename_setup)(struct rpc_message___2 *, struct dentry___37 *, struct dentry___37 *);
	void (*rename_rpc_prepare)(struct rpc_task___2 *, struct nfs_renamedata___2 *);
	int (*rename_done)(struct rpc_task___2 *, struct inode___38 *, struct inode___38 *);
	int (*link)(struct inode___38 *, struct inode___38 *, const struct qstr *);
	int (*symlink)(struct inode___38 *, struct dentry___37 *, struct page___36 *, unsigned int, struct iattr___36 *);
	int (*mkdir)(struct inode___38 *, struct dentry___37 *, struct iattr___36 *);
	int (*rmdir)(struct inode___38 *, const struct qstr *);
	int (*readdir)(struct dentry___37 *, struct rpc_cred___2 *, u64, struct page___36 **, unsigned int, bool);
	int (*mknod)(struct inode___38 *, struct dentry___37 *, struct iattr___36 *, dev_t);
	int (*statfs)(struct nfs_server___2 *, struct nfs_fh *, struct nfs_fsstat *);
	int (*fsinfo)(struct nfs_server___2 *, struct nfs_fh *, struct nfs_fsinfo *);
	int (*pathconf)(struct nfs_server___2 *, struct nfs_fh *, struct nfs_pathconf *);
	int (*set_capabilities)(struct nfs_server___2 *, struct nfs_fh *);
	int (*decode_dirent)(struct xdr_stream___2 *, struct nfs_entry___2 *, bool);
	int (*pgio_rpc_prepare)(struct rpc_task___2 *, struct nfs_pgio_header___2 *);
	void (*read_setup)(struct nfs_pgio_header___2 *, struct rpc_message___2 *);
	int (*read_done)(struct rpc_task___2 *, struct nfs_pgio_header___2 *);
	void (*write_setup)(struct nfs_pgio_header___2 *, struct rpc_message___2 *, struct rpc_clnt___2 **);
	int (*write_done)(struct rpc_task___2 *, struct nfs_pgio_header___2 *);
	void (*commit_setup)(struct nfs_commit_data___2 *, struct rpc_message___2 *, struct rpc_clnt___2 **);
	void (*commit_rpc_prepare)(struct rpc_task___2 *, struct nfs_commit_data___2 *);
	int (*commit_done)(struct rpc_task___2 *, struct nfs_commit_data___2 *);
	int (*lock)(struct file___36 *, int, struct file_lock___36 *);
	int (*lock_check_bounds)(const struct file_lock___36 *);
	void (*clear_acl_cache)(struct inode___38 *);
	void (*close_context)(struct nfs_open_context___2 *, int);
	struct inode___38 * (*open_context)(struct inode___38 *, struct nfs_open_context___2 *, int, struct iattr___36 *, int *);
	int (*have_delegation)(struct inode___38 *, fmode_t);
	struct nfs_client___2 * (*alloc_client)(const struct nfs_client_initdata *);
	struct nfs_client___2 * (*init_client)(struct nfs_client___2 *, const struct nfs_client_initdata *);
	void (*free_client)(struct nfs_client___2 *);
	struct nfs_server___2 * (*create_server)(struct nfs_mount_info *, struct nfs_subversion *);
	struct nfs_server___2 * (*clone_server)(struct nfs_server___2 *, struct nfs_fh *, struct nfs_fattr *, rpc_authflavor_t);
};

struct nfs_access_entry___2 {
	struct rb_node rb_node;
	struct list_head lru;
	struct rpc_cred___2 *cred;
	__u32 mask;
	struct callback_head callback_head;
};

struct disk_part_tbl___8 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___8 *last_lookup;
	struct hd_struct___8 *part[0];
};

struct block_device_operations___8 {
	int (*open)(struct block_device___36 *, fmode_t);
	void (*release)(struct gendisk___8 *, fmode_t);
	int (*rw_page)(struct block_device___36 *, sector_t, struct page___36 *, unsigned int);
	int (*ioctl)(struct block_device___36 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___36 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___8 *, unsigned int);
	int (*media_changed)(struct gendisk___8 *);
	void (*unlock_native_capacity)(struct gendisk___8 *);
	int (*revalidate_disk)(struct gendisk___8 *);
	int (*getgeo)(struct block_device___36 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___36 *, long unsigned int);
	int (*report_zones)(struct gendisk___8 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___33 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___8 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___9 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___9 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___9 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___8(struct request___9 *, blk_status_t);

struct request___9 {
	struct request_queue___9 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___14 *bio;
	struct bio___14 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___14 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___8 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___8 *saved_end_io;
		} flush;
	};
	struct gendisk___8 *rq_disk;
	struct hd_struct___8 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___8 *end_io;
	void *end_io_data;
	struct request___9 *next_rq;
};

struct elevator_type___8;

struct elevator_mq_ops___8 {
	int (*init_sched)(struct request_queue___9 *, struct elevator_type___8 *);
	void (*exit_sched)(struct elevator_queue___8 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	bool (*allow_merge)(struct request_queue___9 *, struct request___9 *, struct bio___14 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx *, struct bio___14 *);
	int (*request_merge)(struct request_queue___9 *, struct request___9 **, struct bio___14 *);
	void (*request_merged)(struct request_queue___9 *, struct request___9 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___9 *, struct request___9 *, struct request___9 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___9 *, struct bio___14 *);
	void (*finish_request)(struct request___9 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___9 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___9 *, u64);
	void (*started_request)(struct request___9 *);
	void (*requeue_request)(struct request___9 *);
	struct request___9 * (*former_request)(struct request_queue___9 *, struct request___9 *);
	struct request___9 * (*next_request)(struct request_queue___9 *, struct request___9 *);
	void (*init_icq)(struct io_cq___8 *);
	void (*exit_icq)(struct io_cq___8 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide79;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___8;

struct elevator_type___8 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___8 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___8 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___33 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___8 {
	struct elevator_type___8 *type;
	void *elevator_data;
	struct kobject___34 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___8 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___8 *, char *);
	ssize_t (*store)(struct elevator_queue___8 *, const char *, size_t);
};

struct blkcg_policy_data___5;

struct blkcg___5 {
	struct cgroup_subsys_state___25 css;
	spinlock_t lock;
	struct xarray blkg_tree;
	struct blkcg_gq___5 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___5 *cpd[5];
	struct list_head all_blkcgs_node;
	struct list_head cgwb_list;
	refcount_t cgwb_refcnt;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct blkcg_policy_data___5 {
	struct blkcg___5 *blkcg;
	int plid;
};

struct blkg_policy_data___5 {
	struct blkcg_gq___5 *blkg;
	int plid;
};

struct linux_binprm___5 {
	char buf[256];
	struct vm_area_struct___36 *vma;
	long unsigned int vma_pages;
	struct mm_struct___36 *mm;
	long unsigned int p;
	unsigned int called_set_creds: 1;
	unsigned int cap_elevated: 1;
	unsigned int secureexec: 1;
	unsigned int recursion_depth;
	struct file___36 *file;
	struct cred___35 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
};

struct coredump_params___4 {
	union {
		const kernel_siginfo_t *siginfo;
		struct {
			const siginfo_t *siginfo;
		} __UNIQUE_ID_rh_kabi_hide93;
		union {		};
	};
	struct pt_regs *regs;
	struct file___36 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
};

struct kimage___9;

typedef void *kexec_load_t___9(struct kimage___9 *, char *, long unsigned int, char *, long unsigned int, char *, long unsigned int);

struct kexec_file_ops___10 {
	kexec_probe_t *probe;
	kexec_load_t___9 *load;
	kexec_cleanup_t *cleanup;
};

struct kimage___9 {
	kimage_entry_t head;
	kimage_entry_t *entry;
	kimage_entry_t *last_entry;
	long unsigned int start;
	struct page___36 *control_code_page;
	struct page___36 *swap_page;
	void *vmcoreinfo_data_copy;
	long unsigned int nr_segments;
	struct kexec_segment segment[16];
	struct list_head control_pages;
	struct list_head dest_pages;
	struct list_head unusable_pages;
	long unsigned int control_page;
	unsigned int type: 1;
	unsigned int preserve_context: 1;
	unsigned int file_mode: 1;
	struct kimage_arch arch;
	void *kernel_buf;
	long unsigned int kernel_buf_len;
	void *initrd_buf;
	long unsigned int initrd_buf_len;
	char *cmdline_buf;
	long unsigned int cmdline_buf_len;
	const struct kexec_file_ops___10 *fops;
	void *image_loader_data;
	struct purgatory_info purgatory_info;
};

enum sysctl_writes_mode {
	SYSCTL_WRITES_LEGACY = 4294967295,
	SYSCTL_WRITES_WARN = 0,
	SYSCTL_WRITES_STRICT = 1,
};

struct do_proc_dointvec_minmax_conv_param {
	int *min;
	int *max;
};

struct do_proc_douintvec_minmax_conv_param {
	unsigned int *min;
	unsigned int *max;
};

struct module___34;

struct file___37;

struct kiocb___37;

struct iov_iter___16;

struct poll_table_struct___23;

struct vm_area_struct___37;

struct inode___39;

struct file_lock___37;

struct page___37;

struct pipe_inode_info___7;

struct seq_file___34;

struct file_operations___37 {
	struct module___34 *owner;
	loff_t (*llseek)(struct file___37 *, loff_t, int);
	ssize_t (*read)(struct file___37 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___37 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___37 *, struct iov_iter___16 *);
	ssize_t (*write_iter)(struct kiocb___37 *, struct iov_iter___16 *);
	int (*iopoll)(struct kiocb___37 *, bool);
	int (*iterate)(struct file___37 *, struct dir_context *);
	int (*iterate_shared)(struct file___37 *, struct dir_context *);
	__poll_t (*poll)(struct file___37 *, struct poll_table_struct___23 *);
	long int (*unlocked_ioctl)(struct file___37 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___37 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___37 *, struct vm_area_struct___37 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___39 *, struct file___37 *);
	int (*flush)(struct file___37 *, fl_owner_t);
	int (*release)(struct inode___39 *, struct file___37 *);
	int (*fsync)(struct file___37 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___37 *, int);
	int (*lock)(struct file___37 *, int, struct file_lock___37 *);
	ssize_t (*sendpage)(struct file___37 *, struct page___37 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___37 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___37 *, int, struct file_lock___37 *);
	ssize_t (*splice_write)(struct pipe_inode_info___7 *, struct file___37 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___37 *, loff_t *, struct pipe_inode_info___7 *, size_t, unsigned int);
	int (*setlease)(struct file___37 *, long int, struct file_lock___37 **, void **);
	long int (*fallocate)(struct file___37 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___34 *, struct file___37 *);
	ssize_t (*copy_file_range)(struct file___37 *, loff_t, struct file___37 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___37 *, loff_t, struct file___37 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___37 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___36 {
	u64 seqnum;
	struct vm_area_struct___37 *vmas[4];
};

struct page_frag___36 {
	struct page___37 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___22;

struct debug_info___22 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___22 *hbp_break[16];
	struct perf_event___22 *hbp_watch[16];
};

struct thread_struct___22 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___22 debug;
	long: 64;
};

struct mm_struct___37;

struct pid___32;

struct cred___36;

struct nsproxy___35;

struct signal_struct___34;

struct css_set___26;

struct perf_event_context___22;

struct vm_struct___30;

struct task_struct___38 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___38 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___37 *mm;
	struct mm_struct___37 *active_mm;
	struct vmacache___36 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___38 *real_parent;
	struct task_struct___38 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___38 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___32 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___32 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___32 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___36 *ptracer_cred;
	const struct cred___36 *real_cred;
	const struct cred___36 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___35 *nsproxy;
	struct signal_struct___34 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___38 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___8 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___26 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___22 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___7 *splice_pipe;
	struct page_frag___36 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___38 *oom_reaper_list;
	struct vm_struct___30 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___22 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___22 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___38 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___22)(struct perf_event___22 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___22;

struct fasync_struct___36;

struct pid_namespace___32;

struct trace_event_call___17;

struct perf_cgroup___22;

struct perf_event___22 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___22 *group_leader;
	struct pmu___22 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___22 hw;
	struct perf_event_context___22 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___22 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___38 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___36 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___22 *);
	struct callback_head callback_head;
	struct pid_namespace___32 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___22 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___22 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___17 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___22 *cgrp;
	struct list_head sb_list;
};

struct rw_semaphore___37 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___38 *owner;
};

struct key___37;

struct ucounts___27;

struct user_namespace___27 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___27 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___2 ns;
	long unsigned int flags;
	struct key___37 *persistent_keyring_register;
	struct rw_semaphore___37 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___27 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct __sysctl_args {
	int *name;
	int nlen;
	void *oldval;
	size_t *oldlenp;
	void *newval;
	size_t newlen;
	long unsigned int __unused[4];
};

enum {
	CTL_KERN = 1,
	CTL_VM = 2,
	CTL_NET = 3,
	CTL_PROC = 4,
	CTL_FS = 5,
	CTL_DEBUG = 6,
	CTL_DEV = 7,
	CTL_BUS = 8,
	CTL_ABI = 9,
	CTL_CPU = 10,
	CTL_ARLAN = 254,
	CTL_S390DBF = 5677,
	CTL_SUNRPC = 7249,
	CTL_PM = 9899,
	CTL_FRV = 9898,
};

enum {
	KERN_OSTYPE = 1,
	KERN_OSRELEASE = 2,
	KERN_OSREV = 3,
	KERN_VERSION = 4,
	KERN_SECUREMASK = 5,
	KERN_PROF = 6,
	KERN_NODENAME = 7,
	KERN_DOMAINNAME = 8,
	KERN_PANIC = 15,
	KERN_REALROOTDEV = 16,
	KERN_SPARC_REBOOT = 21,
	KERN_CTLALTDEL = 22,
	KERN_PRINTK = 23,
	KERN_NAMETRANS = 24,
	KERN_PPC_HTABRECLAIM = 25,
	KERN_PPC_ZEROPAGED = 26,
	KERN_PPC_POWERSAVE_NAP = 27,
	KERN_MODPROBE = 28,
	KERN_SG_BIG_BUFF = 29,
	KERN_ACCT = 30,
	KERN_PPC_L2CR = 31,
	KERN_RTSIGNR = 32,
	KERN_RTSIGMAX = 33,
	KERN_SHMMAX = 34,
	KERN_MSGMAX = 35,
	KERN_MSGMNB = 36,
	KERN_MSGPOOL = 37,
	KERN_SYSRQ = 38,
	KERN_MAX_THREADS = 39,
	KERN_RANDOM = 40,
	KERN_SHMALL = 41,
	KERN_MSGMNI = 42,
	KERN_SEM = 43,
	KERN_SPARC_STOP_A = 44,
	KERN_SHMMNI = 45,
	KERN_OVERFLOWUID = 46,
	KERN_OVERFLOWGID = 47,
	KERN_SHMPATH = 48,
	KERN_HOTPLUG = 49,
	KERN_IEEE_EMULATION_WARNINGS = 50,
	KERN_S390_USER_DEBUG_LOGGING = 51,
	KERN_CORE_USES_PID = 52,
	KERN_TAINTED = 53,
	KERN_CADPID = 54,
	KERN_PIDMAX = 55,
	KERN_CORE_PATTERN = 56,
	KERN_PANIC_ON_OOPS = 57,
	KERN_HPPA_PWRSW = 58,
	KERN_HPPA_UNALIGNED = 59,
	KERN_PRINTK_RATELIMIT = 60,
	KERN_PRINTK_RATELIMIT_BURST = 61,
	KERN_PTY = 62,
	KERN_NGROUPS_MAX = 63,
	KERN_SPARC_SCONS_PWROFF = 64,
	KERN_HZ_TIMER = 65,
	KERN_UNKNOWN_NMI_PANIC = 66,
	KERN_BOOTLOADER_TYPE = 67,
	KERN_RANDOMIZE = 68,
	KERN_SETUID_DUMPABLE = 69,
	KERN_SPIN_RETRY = 70,
	KERN_ACPI_VIDEO_FLAGS = 71,
	KERN_IA64_UNALIGNED = 72,
	KERN_COMPAT_LOG = 73,
	KERN_MAX_LOCK_DEPTH = 74,
	KERN_NMI_WATCHDOG = 75,
	KERN_PANIC_ON_NMI = 76,
	KERN_PANIC_ON_WARN = 77,
};

struct xfs_sysctl_val {
	int min;
	int val;
	int max;
};

typedef struct xfs_sysctl_val xfs_sysctl_val_t;

struct xfs_param {
	xfs_sysctl_val_t sgid_inherit;
	xfs_sysctl_val_t symlink_mode;
	xfs_sysctl_val_t panic_mask;
	xfs_sysctl_val_t error_level;
	xfs_sysctl_val_t syncd_timer;
	xfs_sysctl_val_t stats_clear;
	xfs_sysctl_val_t inherit_sync;
	xfs_sysctl_val_t inherit_nodump;
	xfs_sysctl_val_t inherit_noatim;
	xfs_sysctl_val_t xfs_buf_timer;
	xfs_sysctl_val_t xfs_buf_age;
	xfs_sysctl_val_t inherit_nosym;
	xfs_sysctl_val_t rotorstep;
	xfs_sysctl_val_t inherit_nodfrg;
	xfs_sysctl_val_t fstrm_timer;
	xfs_sysctl_val_t eofb_timer;
	xfs_sysctl_val_t cowb_timer;
};

typedef struct xfs_param xfs_param_t;

struct xfs_globals {
	int log_recovery_delay;
	int mount_delay;
	bool bug_on_assert;
};

struct dentry_operations___36;

struct super_block___37;

struct dentry___38 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___38 *d_parent;
	struct qstr d_name;
	struct inode___39 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___36 *d_op;
	struct super_block___37 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___36;

struct address_space___36 {
	struct inode___39 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___37 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___36 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___36;

struct block_device___37;

struct inode___39 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___36 *i_op;
	struct super_block___37 *i_sb;
	struct address_space___36 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___37 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___37 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___36 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___7 *i_pipe;
		struct block_device___37 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___36;

struct dentry_operations___36 {
	int (*d_revalidate)(struct dentry___38 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___38 *, unsigned int);
	int (*d_hash)(const struct dentry___38 *, struct qstr *);
	int (*d_compare)(const struct dentry___38 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___38 *);
	int (*d_init)(struct dentry___38 *);
	void (*d_release)(struct dentry___38 *);
	void (*d_prune)(struct dentry___38 *);
	void (*d_iput)(struct dentry___38 *, struct inode___39 *);
	char * (*d_dname)(struct dentry___38 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___36 *);
	int (*d_manage)(const struct path___36 *, bool);
	struct dentry___38 * (*d_real)(struct dentry___38 *, const struct inode___39 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___36;

struct mem_dqinfo___36 {
	struct quota_format_type___36 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___36;

struct quota_info___36 {
	unsigned int flags;
	struct rw_semaphore___37 dqio_sem;
	struct inode___39 *files[3];
	struct mem_dqinfo___36 info[3];
	const struct quota_format_ops___36 *ops[3];
};

struct rcuwait___36 {
	struct task_struct___38 *task;
};

struct percpu_rw_semaphore___36 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___37 rw_sem;
	struct rcuwait___36 writer;
	int readers_block;
};

struct sb_writers___36 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___36 rw_sem[3];
};

struct file_system_type___36;

struct super_operations___36;

struct dquot_operations___36;

struct quotactl_ops___36;

struct super_block___37 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___36 *s_type;
	const struct super_operations___36 *s_op;
	const struct dquot_operations___36 *dq_op;
	const struct quotactl_ops___36 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___38 *s_root;
	struct rw_semaphore___37 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___37 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___36 s_dquot;
	struct sb_writers___36 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___36 *s_d_op;
	int cleancache_poolid;
	struct shrinker___13 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___27 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount {
	struct dentry___38 *mnt_root;
	struct super_block___37 *mnt_sb;
	int mnt_flags;
};

struct path___36 {
	struct vfsmount *mnt;
	struct dentry___38 *dentry;
};

typedef struct page___37 *pgtable_t___36;

struct dev_pagemap___36;

struct page___37 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___36 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___37 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___36 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___37 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___36 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___36;

struct lruvec___36 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___36 *pgdat;
};

struct zone___36 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___36 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___36 {
	struct zone___36 *zone;
	int zone_idx;
};

struct zonelist___36 {
	struct zoneref___36 _zonerefs[25];
};

struct pglist_data___36 {
	struct zone___36 node_zones[3];
	struct zonelist___36 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___38 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___38 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___36 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___37 {
	void *stack;
	struct task_struct___38 *task;
	long int status;
};

struct blocking_notifier_head___36 {
	struct rw_semaphore___37 rwsem;
	struct notifier_block *head;
};

struct upid___32 {
	int nr;
	struct pid_namespace___32 *ns;
};

struct pid_namespace___32 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___38 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___32 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___38 *proc_self;
	struct dentry___38 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___27 *user_ns;
	struct ucounts___27 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___2 ns;
};

struct pid___32 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___32 numbers[1];
};

struct vm_operations_struct___36;

struct vm_area_struct___37 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___37 *vm_next;
	struct vm_area_struct___37 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___37 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___36 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___37 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___36;

struct mm_struct___37 {
	struct {
		struct vm_area_struct___37 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___37 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___37 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___36 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___38 *owner;
		struct user_namespace___27 *user_ns;
		struct file___37 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___36 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___36)(struct vm_area_struct___37 *, long unsigned int, const struct page___37 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___36)(struct page___37 *, void *);

struct device___32;

struct dev_pagemap___36 {
	dev_page_fault_t___36 page_fault;
	dev_page_free_t___36 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___32 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct fown_struct___32 {
	rwlock_t lock;
	struct pid___32 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___37 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___36 f_path;
	struct inode___39 *f_inode;
	const struct file_operations___37 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___32 f_owner;
	const struct cred___36 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___36 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___36;

struct vm_operations_struct___36 {
	void (*open)(struct vm_area_struct___37 *);
	void (*close)(struct vm_area_struct___37 *);
	int (*split)(struct vm_area_struct___37 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___37 *);
	vm_fault_t (*fault)(struct vm_fault___36 *);
	vm_fault_t (*huge_fault)(struct vm_fault___36 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___36 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___37 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___36 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___36 *);
	int (*access)(struct vm_area_struct___37 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___37 *);
	int (*set_policy)(struct vm_area_struct___37 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___37 *, long unsigned int);
	struct page___37 * (*find_special_page)(struct vm_area_struct___37 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___36 {
	struct task_struct___38 *task;
	struct core_thread___36 *next;
};

struct core_state___36 {
	atomic_t nr_threads;
	struct core_thread___36 dumper;
	struct completion startup;
};

struct vm_fault___36 {
	struct vm_area_struct___37 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___37 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___37 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___36 prealloc_pte;
};

struct user_struct___36 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___37 *uid_keyring;
	struct key___37 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___36 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___37 *session_keyring;
	struct key___37 *process_keyring;
	struct key___37 *thread_keyring;
	struct key___37 *request_key_auth;
	void *security;
	struct user_struct___36 *user;
	struct user_namespace___27 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___10;

struct cgroup_namespace___26;

struct nsproxy___35 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___32 *pid_ns_for_children;
	struct net___10 *net_ns;
	struct cgroup_namespace___26 *cgroup_ns;
};

struct signal_struct___34 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___38 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___38 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___32 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___32 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___37 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___32 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___26;

struct cgroup___26;

struct css_set___26 {
	struct cgroup_subsys_state___26 *subsys[13];
	refcount_t refcount;
	struct css_set___26 *dom_cset;
	struct cgroup___26 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___26 *mg_src_cgrp;
	struct cgroup___26 *mg_dst_cgrp;
	struct css_set___26 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___22 {
	struct pmu___22 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___38 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___22 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___7;

struct pipe_inode_info___7 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___37 *tmp_page;
	struct fasync_struct___36 *fasync_readers;
	struct fasync_struct___36 *fasync_writers;
	struct pipe_buffer___7 *bufs;
	struct user_struct___36 *user;
};

struct vm_struct___30 {
	struct vm_struct___30 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___37 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___34 {
	struct task_struct___38 task;
	long unsigned int stack[8192];
};

struct kiocb___37 {
	struct file___37 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___37 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___37 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___37 *ia_file;
};

struct dquot___36 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___37 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___36 {
	int qf_fmt_id;
	const struct quota_format_ops___36 *qf_ops;
	struct module___34 *qf_owner;
	struct quota_format_type___36 *qf_next;
};

struct quota_format_ops___36 {
	int (*check_quota_file)(struct super_block___37 *, int);
	int (*read_file_info)(struct super_block___37 *, int);
	int (*write_file_info)(struct super_block___37 *, int);
	int (*free_file_info)(struct super_block___37 *, int);
	int (*read_dqblk)(struct dquot___36 *);
	int (*commit_dqblk)(struct dquot___36 *);
	int (*release_dqblk)(struct dquot___36 *);
	int (*get_next_id)(struct super_block___37 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___36 {
	int (*write_dquot)(struct dquot___36 *);
	struct dquot___36 * (*alloc_dquot)(struct super_block___37 *, int);
	void (*destroy_dquot)(struct dquot___36 *);
	int (*acquire_dquot)(struct dquot___36 *);
	int (*release_dquot)(struct dquot___36 *);
	int (*mark_dirty)(struct dquot___36 *);
	int (*write_info)(struct super_block___37 *, int);
	qsize_t * (*get_reserved_space)(struct inode___39 *);
	int (*get_projid)(struct inode___39 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___39 *, qsize_t *);
	int (*get_next_id)(struct super_block___37 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___36 {
	int (*quota_on)(struct super_block___37 *, int, int, const struct path___36 *);
	int (*quota_off)(struct super_block___37 *, int);
	int (*quota_enable)(struct super_block___37 *, unsigned int);
	int (*quota_disable)(struct super_block___37 *, unsigned int);
	int (*quota_sync)(struct super_block___37 *, int);
	int (*set_info)(struct super_block___37 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___37 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___37 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___37 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___37 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___37 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___34;

struct kobj_type___34;

struct kernfs_node___34;

struct kobject___35 {
	const char *name;
	struct list_head entry;
	struct kobject___35 *parent;
	struct kset___34 *kset;
	struct kobj_type___34 *ktype;
	struct kernfs_node___34 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___31 {
	struct kobject___35 kobj;
	struct module___34 *mod;
	struct kobject___35 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___31 {
	struct module___34 *mod;
	struct latch_tree_node node;
};

struct module_layout___31 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___31 mtn;
};

struct module_attribute___31;

struct kernel_param___31;

struct module___34 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___31 mkobj;
	struct module_attribute___31 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___35 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___31 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___31 core_layout;
	struct module_layout___31 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___17 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___36 {
	int (*writepage)(struct page___37 *, struct writeback_control___3 *);
	int (*readpage)(struct file___37 *, struct page___37 *);
	int (*writepages)(struct address_space___36 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___37 *);
	int (*readpages)(struct file___37 *, struct address_space___36 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___37 *, struct address_space___36 *, loff_t, unsigned int, unsigned int, struct page___37 **, void **);
	int (*write_end)(struct file___37 *, struct address_space___36 *, loff_t, unsigned int, unsigned int, struct page___37 *, void *);
	sector_t (*bmap)(struct address_space___36 *, sector_t);
	void (*invalidatepage)(struct page___37 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___37 *, gfp_t);
	void (*freepage)(struct page___37 *);
	ssize_t (*direct_IO)(struct kiocb___37 *, struct iov_iter___16 *);
	int (*migratepage)(struct address_space___36 *, struct page___37 *, struct page___37 *, enum migrate_mode);
	bool (*isolate_page)(struct page___37 *, isolate_mode_t);
	void (*putback_page)(struct page___37 *);
	int (*launder_page)(struct page___37 *);
	int (*is_partially_uptodate)(struct page___37 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___37 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___36 *, struct page___37 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___37 *, sector_t *);
	void (*swap_deactivate)(struct file___37 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct iov_iter___16 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___3 *bvec;
		struct pipe_inode_info___7 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___37 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___39 *bd_inode;
	struct super_block___37 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___37 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___36 {
	struct dentry___38 * (*lookup)(struct inode___39 *, struct dentry___38 *, unsigned int);
	const char * (*get_link)(struct dentry___38 *, struct inode___39 *, struct delayed_call *);
	int (*permission)(struct inode___39 *, int);
	struct posix_acl * (*get_acl)(struct inode___39 *, int);
	int (*readlink)(struct dentry___38 *, char *, int);
	int (*create)(struct inode___39 *, struct dentry___38 *, umode_t, bool);
	int (*link)(struct dentry___38 *, struct inode___39 *, struct dentry___38 *);
	int (*unlink)(struct inode___39 *, struct dentry___38 *);
	int (*symlink)(struct inode___39 *, struct dentry___38 *, const char *);
	int (*mkdir)(struct inode___39 *, struct dentry___38 *, umode_t);
	int (*rmdir)(struct inode___39 *, struct dentry___38 *);
	int (*mknod)(struct inode___39 *, struct dentry___38 *, umode_t, dev_t);
	int (*rename)(struct inode___39 *, struct dentry___38 *, struct inode___39 *, struct dentry___38 *, unsigned int);
	int (*setattr)(struct dentry___38 *, struct iattr___37 *);
	int (*getattr)(const struct path___36 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___38 *, char *, size_t);
	int (*fiemap)(struct inode___39 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___39 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___39 *, struct dentry___38 *, struct file___37 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___39 *, struct dentry___38 *, umode_t);
	int (*set_acl)(struct inode___39 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___36 {
	void (*fl_copy_lock)(struct file_lock___37 *, struct file_lock___37 *);
	void (*fl_release_private)(struct file_lock___37 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___36;

struct file_lock___37 {
	struct file_lock___37 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___37 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___36 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___36 *fl_ops;
	const struct lock_manager_operations___36 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___36 {
	int (*lm_compare_owner)(struct file_lock___37 *, struct file_lock___37 *);
	long unsigned int (*lm_owner_key)(struct file_lock___37 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___37 *);
	int (*lm_grant)(struct file_lock___37 *, int);
	bool (*lm_break)(struct file_lock___37 *);
	int (*lm_change)(struct file_lock___37 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___37 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___36 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___36 *fa_next;
	struct file___37 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___36 {
	const char *name;
	int fs_flags;
	struct dentry___38 * (*mount)(struct file_system_type___36 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___37 *);
	struct module___34 *owner;
	struct file_system_type___36 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___36 {
	struct inode___39 * (*alloc_inode)(struct super_block___37 *);
	void (*destroy_inode)(struct inode___39 *);
	void (*dirty_inode)(struct inode___39 *, int);
	int (*write_inode)(struct inode___39 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___39 *);
	void (*evict_inode)(struct inode___39 *);
	void (*put_super)(struct super_block___37 *);
	int (*sync_fs)(struct super_block___37 *, int);
	int (*freeze_super)(struct super_block___37 *);
	int (*freeze_fs)(struct super_block___37 *);
	int (*thaw_super)(struct super_block___37 *);
	int (*unfreeze_fs)(struct super_block___37 *);
	int (*statfs)(struct dentry___38 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___37 *, int *, char *);
	void (*umount_begin)(struct super_block___37 *);
	int (*show_options)(struct seq_file___34 *, struct dentry___38 *);
	int (*show_devname)(struct seq_file___34 *, struct dentry___38 *);
	int (*show_path)(struct seq_file___34 *, struct dentry___38 *);
	int (*show_stats)(struct seq_file___34 *, struct dentry___38 *);
	ssize_t (*quota_read)(struct super_block___37 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___37 *, int, const char *, size_t, loff_t);
	struct dquot___36 ** (*get_dquots)(struct inode___39 *);
	int (*bdev_try_to_free_page)(struct super_block___37 *, struct page___37 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___37 *, struct shrink_control___13 *);
	long int (*free_cached_objects)(struct super_block___37 *, struct shrink_control___13 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___22)(struct file___37 *, wait_queue_head_t *, struct poll_table_struct___23 *);

struct poll_table_struct___23 {
	poll_queue_proc___22 _qproc;
	__poll_t _key;
};

struct seq_operations___31;

struct seq_file___34 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___31 *op;
	int poll_event;
	const struct file___37 *file;
	void *private;
};

typedef int (*key_restrict_link_func_t___36)(struct key___37 *, const struct key_type *, const union key_payload *, struct key___37 *);

struct key_restriction___37;

struct key___37 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___37 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___37 *restrict_link;
};

struct key_restriction___37 {
	key_restrict_link_func_t___36 check;
	struct key___37 *key;
	struct key_type *keytype;
};

struct dev_pm_info___32 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___32 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___32;

struct bus_type___32;

struct device_driver___32;

struct dev_pm_domain___32;

struct dma_map_ops___9;

struct fwnode_handle___27;

struct class___32;

struct attribute_group___32;

struct device___32 {
	struct device___32 *parent;
	struct device_private *p;
	struct kobject___35 kobj;
	const char *init_name;
	const struct device_type___32 *type;
	struct mutex mutex;
	struct bus_type___32 *bus;
	struct device_driver___32 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___32 power;
	struct dev_pm_domain___32 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___9 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___27 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___32 *class;
	const struct attribute_group___32 **groups;
	void (*release)(struct device___32 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct kobj_attribute___35 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___35 *, struct kobj_attribute___35 *, char *);
	ssize_t (*store)(struct kobject___35 *, struct kobj_attribute___35 *, const char *, size_t);
};

typedef void compound_page_dtor___36(struct page___37 *);

struct seq_operations___31 {
	void * (*start)(struct seq_file___34 *, loff_t *);
	void (*stop)(struct seq_file___34 *, void *);
	void * (*next)(struct seq_file___34 *, void *, loff_t *);
	int (*show)(struct seq_file___34 *, void *);
};

struct inet_frags___4;

struct netns_frags___4 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___4 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv4___4 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct sock *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock **tcp_sk;
	struct netns_frags___4 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct net_device___9;

struct sk_buff___8;

struct dst_ops___8 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___8 *);
	struct dst_entry___2 * (*check)(struct dst_entry___2 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___2 *);
	unsigned int (*mtu)(const struct dst_entry___2 *);
	u32 * (*cow_metrics)(struct dst_entry___2 *, long unsigned int);
	void (*destroy)(struct dst_entry___2 *);
	void (*ifdown)(struct dst_entry___2 *, struct net_device___9 *, int);
	struct dst_entry___2 * (*negative_advice)(struct dst_entry___2 *);
	void (*link_failure)(struct sk_buff___8 *);
	void (*update_pmtu)(struct dst_entry___2 *, struct sock *, struct sk_buff___8 *, u32);
	void (*redirect)(struct dst_entry___2 *, struct sock *, struct sk_buff___8 *);
	int (*local_out)(struct net___10 *, struct sock *, struct sk_buff___8 *);
	struct neighbour___2 * (*neigh_lookup)(const struct dst_entry___2 *, struct sk_buff___8 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___2 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___7 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___4 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___8 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct sock *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops *notifier_ops;
	struct fib_notifier_ops *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_nf_frag___4 {
	struct netns_frags___4 frags;
};

struct netns_xfrm___7 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___8 xfrm4_dst_ops;
	struct dst_ops___8 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct net___10 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___27 *user_ns;
	struct ucounts___27 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___2 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___9 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___4 ipv4;
	struct netns_ipv6___7 ipv6;
	struct netns_sctp___2 sctp;
	struct netns_nf nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___4 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock *nfnl;
	struct sock *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___7 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cgroup_namespace___26 {
	refcount_t count;
	struct ns_common___2 ns;
	struct user_namespace___27 *user_ns;
	struct ucounts___27 *ucounts;
	struct css_set___26 *root_cset;
};

struct ucounts___27 {
	struct hlist_node node;
	struct user_namespace___27 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct kernfs_root___34;

struct kernfs_elem_dir___34 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___34 *root;
};

struct kernfs_syscall_ops___34;

struct kernfs_root___34 {
	struct kernfs_node___34 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___34 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___34 {
	struct kernfs_node___34 *target_kn;
};

struct kernfs_ops___34;

struct kernfs_elem_attr___34 {
	const struct kernfs_ops___34 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___34 *notify_next;
};

struct kernfs_node___34 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___34 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___34 dir;
		struct kernfs_elem_symlink___34 symlink;
		struct kernfs_elem_attr___34 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___34;

struct kernfs_ops___34 {
	int (*open)(struct kernfs_open_file___34 *);
	void (*release)(struct kernfs_open_file___34 *);
	int (*seq_show)(struct seq_file___34 *, void *);
	void * (*seq_start)(struct seq_file___34 *, loff_t *);
	void * (*seq_next)(struct seq_file___34 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___34 *, void *);
	ssize_t (*read)(struct kernfs_open_file___34 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___34 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___34 *, struct vm_area_struct___37 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___34 *, struct poll_table_struct___23 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___34 {
	int (*remount_fs)(struct kernfs_root___34 *, int *, char *);
	int (*show_options)(struct seq_file___34 *, struct kernfs_root___34 *);
	int (*mkdir)(struct kernfs_node___34 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___34 *);
	int (*rename)(struct kernfs_node___34 *, struct kernfs_node___34 *, const char *);
	int (*show_path)(struct seq_file___34 *, struct kernfs_node___34 *, struct kernfs_root___34 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___34 {
	struct kernfs_node___34 *kn;
	struct file___37 *file;
	struct seq_file___34 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___36 *vm_ops;
};

struct bin_attribute___32;

struct attribute_group___32 {
	const char *name;
	umode_t (*is_visible)(struct kobject___35 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___35 *, struct bin_attribute___32 *, int);
	struct attribute **attrs;
	struct bin_attribute___32 **bin_attrs;
};

struct bin_attribute___32 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___37 *, struct kobject___35 *, struct bin_attribute___32 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___37 *, struct kobject___35 *, struct bin_attribute___32 *, char *, loff_t, size_t);
	int (*mmap)(struct file___37 *, struct kobject___35 *, struct bin_attribute___32 *, struct vm_area_struct___37 *);
};

struct sysfs_ops___34 {
	ssize_t (*show)(struct kobject___35 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___35 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___34;

struct kset___34 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___35 kobj;
	const struct kset_uevent_ops___34 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___34 {
	void (*release)(struct kobject___35 *);
	const struct sysfs_ops___34 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___2 * (*child_ns_type)(struct kobject___35 *);
	const void * (*namespace)(struct kobject___35 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___34 {
	int (* const filter)(struct kset___34 *, struct kobject___35 *);
	const char * (* const name)(struct kset___34 *, struct kobject___35 *);
	int (* const uevent)(struct kset___34 *, struct kobject___35 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___31 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___31 *);
	int (*get)(char *, const struct kernel_param___31 *);
	void (*free)(void *);
};

struct kparam_array___31;

struct kernel_param___31 {
	const char *name;
	struct module___34 *mod;
	const struct kernel_param_ops___31 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___31 *arr;
	};
};

struct kparam_array___31 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___31 *ops;
	void *elem;
};

struct module_attribute___31 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___31 *, struct module_kobject___31 *, char *);
	ssize_t (*store)(struct module_attribute___31 *, struct module_kobject___31 *, const char *, size_t);
	void (*setup)(struct module___34 *, const char *);
	int (*test)(struct module___34 *);
	void (*free)(struct module___34 *);
};

struct trace_event_class___17;

struct trace_event_call___17 {
	struct list_head list;
	struct trace_event_class___17 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___3 *prog_array;
	int (*perf_perm)(struct trace_event_call___17 *, struct perf_event___22 *);
};

struct dev_pm_ops___32 {
	int (*prepare)(struct device___32 *);
	void (*complete)(struct device___32 *);
	int (*suspend)(struct device___32 *);
	int (*resume)(struct device___32 *);
	int (*freeze)(struct device___32 *);
	int (*thaw)(struct device___32 *);
	int (*poweroff)(struct device___32 *);
	int (*restore)(struct device___32 *);
	int (*suspend_late)(struct device___32 *);
	int (*resume_early)(struct device___32 *);
	int (*freeze_late)(struct device___32 *);
	int (*thaw_early)(struct device___32 *);
	int (*poweroff_late)(struct device___32 *);
	int (*restore_early)(struct device___32 *);
	int (*suspend_noirq)(struct device___32 *);
	int (*resume_noirq)(struct device___32 *);
	int (*freeze_noirq)(struct device___32 *);
	int (*thaw_noirq)(struct device___32 *);
	int (*poweroff_noirq)(struct device___32 *);
	int (*restore_noirq)(struct device___32 *);
	int (*runtime_suspend)(struct device___32 *);
	int (*runtime_resume)(struct device___32 *);
	int (*runtime_idle)(struct device___32 *);
};

struct dev_pm_domain___32 {
	struct dev_pm_ops___32 ops;
	void (*detach)(struct device___32 *, bool);
	int (*activate)(struct device___32 *);
	void (*sync)(struct device___32 *);
	void (*dismiss)(struct device___32 *);
};

struct bus_type___32 {
	const char *name;
	const char *dev_name;
	struct device___32 *dev_root;
	const struct attribute_group___32 **bus_groups;
	const struct attribute_group___32 **dev_groups;
	const struct attribute_group___32 **drv_groups;
	int (*match)(struct device___32 *, struct device_driver___32 *);
	int (*uevent)(struct device___32 *, struct kobj_uevent_env *);
	int (*probe)(struct device___32 *);
	int (*remove)(struct device___32 *);
	void (*shutdown)(struct device___32 *);
	int (*online)(struct device___32 *);
	int (*offline)(struct device___32 *);
	int (*suspend)(struct device___32 *, pm_message_t);
	int (*resume)(struct device___32 *);
	int (*num_vf)(struct device___32 *);
	int (*dma_configure)(struct device___32 *);
	const struct dev_pm_ops___32 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___32 {
	const char *name;
	struct bus_type___32 *bus;
	struct module___34 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___32 *);
	int (*remove)(struct device___32 *);
	void (*shutdown)(struct device___32 *);
	int (*suspend)(struct device___32 *, pm_message_t);
	int (*resume)(struct device___32 *);
	const struct attribute_group___32 **groups;
	const struct dev_pm_ops___32 *pm;
	void (*coredump)(struct device___32 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___32 {
	const char *name;
	const struct attribute_group___32 **groups;
	int (*uevent)(struct device___32 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___32 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___32 *);
	const struct dev_pm_ops___32 *pm;
};

struct class___32 {
	const char *name;
	struct module___34 *owner;
	const struct attribute_group___32 **class_groups;
	const struct attribute_group___32 **dev_groups;
	struct kobject___35 *dev_kobj;
	int (*dev_uevent)(struct device___32 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___32 *, umode_t *);
	void (*class_release)(struct class___32 *);
	void (*dev_release)(struct device___32 *);
	int (*shutdown_pre)(struct device___32 *);
	const struct kobj_ns_type_operations___2 *ns_type;
	const void * (*namespace)(struct device___32 *);
	const struct dev_pm_ops___32 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___9 {
	void * (*alloc)(struct device___32 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___32 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___32 *, struct vm_area_struct___37 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___32 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___32 *, struct page___37 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___32 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___32 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___32 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___32 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___32 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___32 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___32 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___32 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___32 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___32 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___32 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___32 *, u64);
	u64 (*get_required_mask)(struct device___32 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___27;

struct fwnode_handle___27 {
	struct fwnode_handle___27 *secondary;
	const struct fwnode_operations___27 *ops;
};

struct node___30 {
	struct device___32 dev;
};

struct bpf_map___26;

struct bpf_map_ops___26 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___26 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___26 *, struct file___37 *);
	void (*map_free)(struct bpf_map___26 *);
	int (*map_get_next_key)(struct bpf_map___26 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___26 *);
	void * (*map_lookup_elem)(struct bpf_map___26 *, void *);
	int (*map_update_elem)(struct bpf_map___26 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___26 *, void *);
	int (*map_push_elem)(struct bpf_map___26 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___26 *, void *);
	int (*map_peek_elem)(struct bpf_map___26 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___26 *, struct file___37 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___26 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___26 *, void *, struct seq_file___34 *);
	int (*map_check_btf)(const struct bpf_map___26 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___26 {
	const struct bpf_map_ops___26 *ops;
	struct bpf_map___26 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___36 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___4;

struct bpf_map_dev_ops___4 {
	int (*map_get_next_key)(struct bpf_offloaded_map___4 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___4 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___4 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___4 *, void *);
};

struct bpf_offloaded_map___4 {
	struct bpf_map___26 map;
	struct net_device___9 *netdev;
	const struct bpf_map_dev_ops___4 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

typedef rx_handler_result_t rx_handler_func_t___4(struct sk_buff___8 **);

typedef struct {
	struct net___10 *net;
} possible_net_t___4;

struct net_device_ops___4;

struct ethtool_ops___4;

struct xfrmdev_ops___4;

struct tlsdev_ops___4;

struct header_ops___4;

struct netdev_rx_queue___4;

struct netdev_queue___4;

struct dcbnl_rtnl_ops___4;

struct net_device___9 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___4 *netdev_ops;
	const struct ethtool_ops___4 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___2 *l3mdev_ops;
	const struct ndisc_ops___2 *ndisc_ops;
	const struct xfrmdev_ops___4 *xfrmdev_ops;
	const struct tlsdev_ops___4 *tlsdev_ops;
	const struct header_ops___4 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___34 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___2 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___4 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___4 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___2 *miniq_ingress;
	struct netdev_queue___4 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___4 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___2 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___2 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___4 = 0,
		NETREG_REGISTERED___4 = 1,
		NETREG_UNREGISTERING___4 = 2,
		NETREG_UNREGISTERED___4 = 3,
		NETREG_RELEASED___4 = 4,
		NETREG_DUMMY___4 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___4 = 0,
		RTNL_LINK_INITIALIZING___4 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___9 *);
	struct netpoll_info *npinfo;
	possible_net_t___4 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___32 dev;
	const struct attribute_group___32 *sysfs_groups[4];
	const struct attribute_group___32 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___2 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___4 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide39;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct kthread_work___26;

typedef void (*kthread_work_func_t___26)(struct kthread_work___26 *);

struct kthread_worker___26;

struct kthread_work___26 {
	struct list_head node;
	kthread_work_func_t___26 func;
	struct kthread_worker___26 *worker;
	int canceling;
};

struct kthread_worker___26 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___38 *task;
	struct kthread_work___26 *current_work;
};

struct kthread_delayed_work___26 {
	struct kthread_work___26 work;
	struct timer_list timer;
};

struct psi_group___26 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___26 *poll_kworker;
	struct kthread_delayed_work___26 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___26 {
	struct kernfs_node___34 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___26;

struct cgroup_subsys_state___26 {
	struct cgroup___26 *cgroup;
	struct cgroup_subsys___26 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___26 *parent;
};

struct cgroup_root___26;

struct cgroup_rstat_cpu___26;

struct cgroup___26 {
	struct cgroup_subsys_state___26 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___34 *kn;
	struct cgroup_file___26 procs_file;
	struct cgroup_file___26 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___26 *subsys[13];
	struct cgroup_root___26 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___26 *dom_cgrp;
	struct cgroup_rstat_cpu___26 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___3 bpf;
	atomic_t congestion_count;
	struct cgroup___26 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___26 psi;
	int ancestor_ids[0];
};

struct cftype___26;

struct cgroup_subsys___26 {
	struct cgroup_subsys_state___26 * (*css_alloc)(struct cgroup_subsys_state___26 *);
	int (*css_online)(struct cgroup_subsys_state___26 *);
	void (*css_offline)(struct cgroup_subsys_state___26 *);
	void (*css_released)(struct cgroup_subsys_state___26 *);
	void (*css_free)(struct cgroup_subsys_state___26 *);
	void (*css_reset)(struct cgroup_subsys_state___26 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___26 *, int);
	int (*css_extra_stat_show)(struct seq_file___34 *, struct cgroup_subsys_state___26 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___38 *);
	void (*cancel_fork)(struct task_struct___38 *);
	void (*fork)(struct task_struct___38 *);
	void (*exit)(struct task_struct___38 *);
	void (*free)(struct task_struct___38 *);
	void (*bind)(struct cgroup_subsys_state___26 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___26 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___26 *dfl_cftypes;
	struct cftype___26 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___26 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___26 *updated_children;
	struct cgroup___26 *updated_next;
};

struct cgroup_root___26 {
	struct kernfs_root___34 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___26 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___26 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___26 *ss;
	struct list_head node;
	struct kernfs_ops___34 *kf_ops;
	int (*open)(struct kernfs_open_file___34 *);
	void (*release)(struct kernfs_open_file___34 *);
	u64 (*read_u64)(struct cgroup_subsys_state___26 *, struct cftype___26 *);
	s64 (*read_s64)(struct cgroup_subsys_state___26 *, struct cftype___26 *);
	int (*seq_show)(struct seq_file___34 *, void *);
	void * (*seq_start)(struct seq_file___34 *, loff_t *);
	void * (*seq_next)(struct seq_file___34 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___34 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___26 *, struct cftype___26 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___26 *, struct cftype___26 *, s64);
	ssize_t (*write)(struct kernfs_open_file___34 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___34 *, struct poll_table_struct___23 *);
};

struct perf_cpu_context___22;

struct pmu___22 {
	struct list_head entry;
	struct module___34 *module;
	struct device___32 *dev;
	const struct attribute_group___32 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___22 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___22 *);
	void (*pmu_disable)(struct pmu___22 *);
	int (*event_init)(struct perf_event___22 *);
	void (*event_mapped)(struct perf_event___22 *, struct mm_struct___37 *);
	void (*event_unmapped)(struct perf_event___22 *, struct mm_struct___37 *);
	int (*add)(struct perf_event___22 *, int);
	void (*del)(struct perf_event___22 *, int);
	void (*start)(struct perf_event___22 *, int);
	void (*stop)(struct perf_event___22 *, int);
	void (*read)(struct perf_event___22 *);
	void (*start_txn)(struct pmu___22 *, unsigned int);
	int (*commit_txn)(struct pmu___22 *);
	void (*cancel_txn)(struct pmu___22 *);
	int (*event_idx)(struct perf_event___22 *);
	void (*sched_task)(struct perf_event_context___22 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___22 *);
	int (*filter_match)(struct perf_event___22 *);
	int (*check_period)(struct perf_event___22 *, u64);
};

struct perf_cpu_context___22 {
	struct perf_event_context___22 ctx;
	struct perf_event_context___22 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___22 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___22 {
	struct cgroup_subsys_state___26 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___17 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___17 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___17 *);
	struct list_head * (*get_fields)(struct trace_event_call___17 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___17 *);
};

struct syscall_metadata___6 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___17 *enter_event;
	struct trace_event_call___17 *exit_event;
};

struct nf_bridge_info___4;

struct sk_buff___8 {
	union {
		struct {
			struct sk_buff___8 *next;
			struct sk_buff___8 *prev;
			union {
				struct net_device___9 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___5 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___8 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___4 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct fwnode_reference_args___27;

struct fwnode_endpoint___27;

struct fwnode_operations___27 {
	struct fwnode_handle___27 * (*get)(struct fwnode_handle___27 *);
	void (*put)(struct fwnode_handle___27 *);
	bool (*device_is_available)(const struct fwnode_handle___27 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___27 *, const struct device___32 *);
	bool (*property_present)(const struct fwnode_handle___27 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___27 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___27 *, const char *, const char **, size_t);
	struct fwnode_handle___27 * (*get_parent)(const struct fwnode_handle___27 *);
	struct fwnode_handle___27 * (*get_next_child_node)(const struct fwnode_handle___27 *, struct fwnode_handle___27 *);
	struct fwnode_handle___27 * (*get_named_child_node)(const struct fwnode_handle___27 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___27 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___27 *);
	struct fwnode_handle___27 * (*graph_get_next_endpoint)(const struct fwnode_handle___27 *, struct fwnode_handle___27 *);
	struct fwnode_handle___27 * (*graph_get_remote_endpoint)(const struct fwnode_handle___27 *);
	struct fwnode_handle___27 * (*graph_get_port_parent)(struct fwnode_handle___27 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___27 *, struct fwnode_endpoint___27 *);
};

struct fwnode_endpoint___27 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___27 *local_fwnode;
};

struct fwnode_reference_args___27 {
	struct fwnode_handle___27 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___7;

struct pipe_buffer___7 {
	struct page___37 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___7 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___7 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___7 *, struct pipe_buffer___7 *);
	void (*release)(struct pipe_inode_info___7 *, struct pipe_buffer___7 *);
	int (*steal)(struct pipe_inode_info___7 *, struct pipe_buffer___7 *);
	union {
		bool (*get)(struct pipe_inode_info___7 *, struct pipe_buffer___7 *);
		struct {
			void (*get)(struct pipe_inode_info___7 *, struct pipe_buffer___7 *);
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
};

struct nf_bridge_info___4 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___4 = 0,
		BRNF_PROTO_8021Q___4 = 1,
		BRNF_PROTO_PPPOE___4 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___9 *physindev;
	struct net_device___9 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

struct sk_buff_head___5 {
	struct sk_buff___8 *next;
	struct sk_buff___8 *prev;
	__u32 qlen;
	spinlock_t lock;
};

enum ethtool_link_mode_bit_indices {
	ETHTOOL_LINK_MODE_10baseT_Half_BIT = 0,
	ETHTOOL_LINK_MODE_10baseT_Full_BIT = 1,
	ETHTOOL_LINK_MODE_100baseT_Half_BIT = 2,
	ETHTOOL_LINK_MODE_100baseT_Full_BIT = 3,
	ETHTOOL_LINK_MODE_1000baseT_Half_BIT = 4,
	ETHTOOL_LINK_MODE_1000baseT_Full_BIT = 5,
	ETHTOOL_LINK_MODE_Autoneg_BIT = 6,
	ETHTOOL_LINK_MODE_TP_BIT = 7,
	ETHTOOL_LINK_MODE_AUI_BIT = 8,
	ETHTOOL_LINK_MODE_MII_BIT = 9,
	ETHTOOL_LINK_MODE_FIBRE_BIT = 10,
	ETHTOOL_LINK_MODE_BNC_BIT = 11,
	ETHTOOL_LINK_MODE_10000baseT_Full_BIT = 12,
	ETHTOOL_LINK_MODE_Pause_BIT = 13,
	ETHTOOL_LINK_MODE_Asym_Pause_BIT = 14,
	ETHTOOL_LINK_MODE_2500baseX_Full_BIT = 15,
	ETHTOOL_LINK_MODE_Backplane_BIT = 16,
	ETHTOOL_LINK_MODE_1000baseKX_Full_BIT = 17,
	ETHTOOL_LINK_MODE_10000baseKX4_Full_BIT = 18,
	ETHTOOL_LINK_MODE_10000baseKR_Full_BIT = 19,
	ETHTOOL_LINK_MODE_10000baseR_FEC_BIT = 20,
	ETHTOOL_LINK_MODE_20000baseMLD2_Full_BIT = 21,
	ETHTOOL_LINK_MODE_20000baseKR2_Full_BIT = 22,
	ETHTOOL_LINK_MODE_40000baseKR4_Full_BIT = 23,
	ETHTOOL_LINK_MODE_40000baseCR4_Full_BIT = 24,
	ETHTOOL_LINK_MODE_40000baseSR4_Full_BIT = 25,
	ETHTOOL_LINK_MODE_40000baseLR4_Full_BIT = 26,
	ETHTOOL_LINK_MODE_56000baseKR4_Full_BIT = 27,
	ETHTOOL_LINK_MODE_56000baseCR4_Full_BIT = 28,
	ETHTOOL_LINK_MODE_56000baseSR4_Full_BIT = 29,
	ETHTOOL_LINK_MODE_56000baseLR4_Full_BIT = 30,
	ETHTOOL_LINK_MODE_25000baseCR_Full_BIT = 31,
	ETHTOOL_LINK_MODE_25000baseKR_Full_BIT = 32,
	ETHTOOL_LINK_MODE_25000baseSR_Full_BIT = 33,
	ETHTOOL_LINK_MODE_50000baseCR2_Full_BIT = 34,
	ETHTOOL_LINK_MODE_50000baseKR2_Full_BIT = 35,
	ETHTOOL_LINK_MODE_100000baseKR4_Full_BIT = 36,
	ETHTOOL_LINK_MODE_100000baseSR4_Full_BIT = 37,
	ETHTOOL_LINK_MODE_100000baseCR4_Full_BIT = 38,
	ETHTOOL_LINK_MODE_100000baseLR4_ER4_Full_BIT = 39,
	ETHTOOL_LINK_MODE_50000baseSR2_Full_BIT = 40,
	ETHTOOL_LINK_MODE_1000baseX_Full_BIT = 41,
	ETHTOOL_LINK_MODE_10000baseCR_Full_BIT = 42,
	ETHTOOL_LINK_MODE_10000baseSR_Full_BIT = 43,
	ETHTOOL_LINK_MODE_10000baseLR_Full_BIT = 44,
	ETHTOOL_LINK_MODE_10000baseLRM_Full_BIT = 45,
	ETHTOOL_LINK_MODE_10000baseER_Full_BIT = 46,
	ETHTOOL_LINK_MODE_2500baseT_Full_BIT = 47,
	ETHTOOL_LINK_MODE_5000baseT_Full_BIT = 48,
	ETHTOOL_LINK_MODE_FEC_NONE_BIT = 49,
	ETHTOOL_LINK_MODE_FEC_RS_BIT = 50,
	ETHTOOL_LINK_MODE_FEC_BASER_BIT = 51,
	ETHTOOL_LINK_MODE_50000baseKR_Full_BIT = 52,
	ETHTOOL_LINK_MODE_50000baseSR_Full_BIT = 53,
	ETHTOOL_LINK_MODE_50000baseCR_Full_BIT = 54,
	ETHTOOL_LINK_MODE_50000baseLR_ER_FR_Full_BIT = 55,
	ETHTOOL_LINK_MODE_50000baseDR_Full_BIT = 56,
	ETHTOOL_LINK_MODE_100000baseKR2_Full_BIT = 57,
	ETHTOOL_LINK_MODE_100000baseSR2_Full_BIT = 58,
	ETHTOOL_LINK_MODE_100000baseCR2_Full_BIT = 59,
	ETHTOOL_LINK_MODE_100000baseLR2_ER2_FR2_Full_BIT = 60,
	ETHTOOL_LINK_MODE_100000baseDR2_Full_BIT = 61,
	ETHTOOL_LINK_MODE_200000baseKR4_Full_BIT = 62,
	ETHTOOL_LINK_MODE_200000baseSR4_Full_BIT = 63,
	ETHTOOL_LINK_MODE_200000baseLR4_ER4_FR4_Full_BIT = 64,
	ETHTOOL_LINK_MODE_200000baseDR4_Full_BIT = 65,
	ETHTOOL_LINK_MODE_200000baseCR4_Full_BIT = 66,
	__ETHTOOL_LINK_MODE_LAST_RH80 = 51,
	__ETHTOOL_LINK_MODE_LAST = 66,
};

struct ethtool_ops___4 {
	int (*get_settings)(struct net_device___9 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___9 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___9 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___9 *);
	void (*get_regs)(struct net_device___9 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___9 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___9 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___9 *);
	void (*set_msglevel)(struct net_device___9 *, u32);
	int (*nway_reset)(struct net_device___9 *);
	u32 (*get_link)(struct net_device___9 *);
	int (*get_eeprom_len)(struct net_device___9 *);
	int (*get_eeprom)(struct net_device___9 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___9 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___9 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___9 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___9 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___9 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___9 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___9 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___9 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___9 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___9 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___9 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___9 *);
	void (*complete)(struct net_device___9 *);
	u32 (*get_priv_flags)(struct net_device___9 *);
	int (*set_priv_flags)(struct net_device___9 *, u32);
	int (*get_sset_count)(struct net_device___9 *, int);
	int (*get_rxnfc)(struct net_device___9 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___9 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___9 *, struct ethtool_flash *);
	int (*reset)(struct net_device___9 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___9 *);
	u32 (*get_rxfh_indir_size)(struct net_device___9 *);
	int (*get_rxfh)(struct net_device___9 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___9 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___9 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___9 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___9 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___9 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___9 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___9 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___9 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___9 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___9 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___9 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___9 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___9 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___9 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___9 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___9 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___9 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___9 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___9 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___9 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___9 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	int (*get_fecparam)(struct net_device___9 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___9 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___9 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___9 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___9 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___4;

struct inet_frags___4 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___4 *, const void *);
	void (*destructor)(struct inet_frag_queue___4 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___4 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___8 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___8 *fragments_tail;
	struct sk_buff___8 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___4 *net;
	struct callback_head rcu;
};

struct pernet_operations___4 {
	struct list_head list;
	int (*init)(struct net___10 *);
	void (*exit)(struct net___10 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___4 {
	int (*ieee_getets)(struct net_device___9 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___9 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___9 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___9 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___9 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___9 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___9 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___9 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___9 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___9 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___9 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___9 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___9 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___9 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___9 *);
	u8 (*setstate)(struct net_device___9 *, u8);
	void (*getpermhwaddr)(struct net_device___9 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___9 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___9 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___9 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___9 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___9 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___9 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___9 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___9 *, int, u8 *);
	void (*setpfccfg)(struct net_device___9 *, int, u8);
	void (*getpfccfg)(struct net_device___9 *, int, u8 *);
	u8 (*setall)(struct net_device___9 *);
	u8 (*getcap)(struct net_device___9 *, int, u8 *);
	int (*getnumtcs)(struct net_device___9 *, int, u8 *);
	int (*setnumtcs)(struct net_device___9 *, int, u8);
	u8 (*getpfcstate)(struct net_device___9 *);
	void (*setpfcstate)(struct net_device___9 *, u8);
	void (*getbcncfg)(struct net_device___9 *, int, u32 *);
	void (*setbcncfg)(struct net_device___9 *, int, u32);
	void (*getbcnrp)(struct net_device___9 *, int, u8 *);
	void (*setbcnrp)(struct net_device___9 *, int, u8);
	int (*setapp)(struct net_device___9 *, u8, u16, u8);
	int (*getapp)(struct net_device___9 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___9 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___9 *, int, u8);
	u8 (*getdcbx)(struct net_device___9 *);
	u8 (*setdcbx)(struct net_device___9 *, u8);
	int (*peer_getappinfo)(struct net_device___9 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___9 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___9 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___9 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___9 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___9 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct xdp_rxq_info___4 {
	struct net_device___9 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___4 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___9 *dev_rx;
};

struct netlink_callback___4 {
	struct sk_buff___8 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___4 *);
	int (*dump)(struct sk_buff___8 *, struct netlink_callback___4 *);
	int (*done)(struct netlink_callback___4 *);
	void *data;
	struct module___34 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___4 {
	int (*create)(struct sk_buff___8 *, struct net_device___9 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___8 *, unsigned char *);
	int (*cache)(const struct neighbour___2 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___9 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___4 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___4 *, int);
	int poll_owner;
	struct net_device___9 *dev;
	struct sk_buff___8 *gro_list;
	struct sk_buff___8 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

enum {
	NAPI_STATE_SCHED = 0,
	NAPI_STATE_MISSED = 1,
	NAPI_STATE_DISABLE = 2,
	NAPI_STATE_NPSVC = 3,
	NAPI_STATE_HASHED = 4,
	NAPI_STATE_NO_BUSY_POLL = 5,
	NAPI_STATE_IN_BUSY_POLL = 6,
};

struct netdev_queue___4 {
	struct net_device___9 *dev;
	struct Qdisc___2 *qdisc;
	struct Qdisc___2 *qdisc_sleeping;
	struct kobject___35 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___9 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct netdev_rx_queue___4 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___35 kobj;
	struct net_device___9 *dev;
	long: 64;
	struct xdp_rxq_info___4 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___4)(struct net_device___9 *, struct sk_buff___8 *, struct net_device___9 *);

struct netdev_bpf___4 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___3 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___3 *prog;
			const struct bpf_prog_offload_ops___3 *ops;
		} verifier;
		struct {
			struct bpf_prog___3 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___4 *offmap;
		};
		struct {
			struct xdp_umem *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___4 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___8 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___4 {
	int (*tls_dev_add)(struct net_device___9 *, struct sock *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___9 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___9 *, struct sock *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide35;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___4 {
	int (*ndo_init)(struct net_device___9 *);
	void (*ndo_uninit)(struct net_device___9 *);
	int (*ndo_open)(struct net_device___9 *);
	int (*ndo_stop)(struct net_device___9 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___8 *, struct net_device___9 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___8 *, struct net_device___9 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___9 *, struct sk_buff___8 *, struct net_device___9 *, select_queue_fallback_t___4);
	void (*ndo_change_rx_flags)(struct net_device___9 *, int);
	void (*ndo_set_rx_mode)(struct net_device___9 *);
	int (*ndo_set_mac_address)(struct net_device___9 *, void *);
	int (*ndo_validate_addr)(struct net_device___9 *);
	int (*ndo_do_ioctl)(struct net_device___9 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___9 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___9 *, int);
	int (*ndo_neigh_setup)(struct net_device___9 *, struct neigh_parms___3 *);
	void (*ndo_tx_timeout)(struct net_device___9 *);
	void (*ndo_get_stats64)(struct net_device___9 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___9 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___9 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___9 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___9 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___9 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___9 *);
	int (*ndo_netpoll_setup)(struct net_device___9 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___9 *);
	int (*ndo_set_vf_mac)(struct net_device___9 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___9 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___9 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___9 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___9 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___9 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___9 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___9 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___9 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___9 *, int, struct sk_buff___8 *);
	int (*ndo_set_vf_guid)(struct net_device___9 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___9 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___9 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___9 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___9 *, const struct sk_buff___8 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___9 *, struct net_device___9 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___9 *, struct net_device___9 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___9 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___9 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___9 *, struct neighbour___2 *);
	void (*ndo_neigh_destroy)(struct net_device___9 *, struct neighbour___2 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___9 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___9 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide36;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___9 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___8 *, struct netlink_callback___4 *, struct net_device___9 *, struct net_device___9 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___9 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___9 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide37;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___8 *, u32, u32, struct net_device___9 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___9 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___9 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___9 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___9 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___9 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___9 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___9 *, struct net_device___9 *);
	void (*ndo_dfwd_del_station)(struct net_device___9 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___9 *);
	int (*ndo_set_tx_maxrate)(struct net_device___9 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___9 *);
	int (*ndo_change_proto_down)(struct net_device___9 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___9 *, struct sk_buff___8 *);
	void (*ndo_set_rx_headroom)(struct net_device___9 *, int);
	int (*ndo_bpf)(struct net_device___9 *, struct netdev_bpf___4 *);
	int (*ndo_xdp_xmit)(struct net_device___9 *, int, struct xdp_frame___4 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___9 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___9 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide38;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct softnet_data___4 {
	struct list_head poll_list;
	struct sk_buff_head___5 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___4 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___2 *output_queue;
	struct Qdisc___2 **output_queue_tailp;
	struct sk_buff___8 *completion_queue;
	struct sk_buff_head___5 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___4 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___5 input_pkt_queue;
	struct napi_struct___4 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module___35;

struct file___38;

struct kiocb___38;

struct poll_table_struct___24;

struct vm_area_struct___38;

struct inode___40;

struct file_lock___38;

struct page___38;

struct seq_file___35;

struct file_operations___38 {
	struct module___35 *owner;
	loff_t (*llseek)(struct file___38 *, loff_t, int);
	ssize_t (*read)(struct file___38 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___38 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___38 *, struct iov_iter___16 *);
	ssize_t (*write_iter)(struct kiocb___38 *, struct iov_iter___16 *);
	int (*iopoll)(struct kiocb___38 *, bool);
	int (*iterate)(struct file___38 *, struct dir_context *);
	int (*iterate_shared)(struct file___38 *, struct dir_context *);
	__poll_t (*poll)(struct file___38 *, struct poll_table_struct___24 *);
	long int (*unlocked_ioctl)(struct file___38 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___38 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___38 *, struct vm_area_struct___38 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___40 *, struct file___38 *);
	int (*flush)(struct file___38 *, fl_owner_t);
	int (*release)(struct inode___40 *, struct file___38 *);
	int (*fsync)(struct file___38 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___38 *, int);
	int (*lock)(struct file___38 *, int, struct file_lock___38 *);
	ssize_t (*sendpage)(struct file___38 *, struct page___38 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___38 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___38 *, int, struct file_lock___38 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___38 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___38 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___38 *, long int, struct file_lock___38 **, void **);
	long int (*fallocate)(struct file___38 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___35 *, struct file___38 *);
	ssize_t (*copy_file_range)(struct file___38 *, loff_t, struct file___38 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___38 *, loff_t, struct file___38 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___38 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___37 {
	u64 seqnum;
	struct vm_area_struct___38 *vmas[4];
};

struct page_frag___37 {
	struct page___38 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___23;

struct debug_info___23 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___23 *hbp_break[16];
	struct perf_event___23 *hbp_watch[16];
};

struct thread_struct___23 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___23 debug;
	long: 64;
};

struct mm_struct___38;

struct pid___33;

struct cred___37;

struct nsproxy___36;

struct signal_struct___35;

struct css_set___27;

struct perf_event_context___23;

struct task_struct___39 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___39 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___38 *mm;
	struct mm_struct___38 *active_mm;
	struct vmacache___37 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___39 *real_parent;
	struct task_struct___39 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___39 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___33 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___33 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___33 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___37 *ptracer_cred;
	const struct cred___37 *real_cred;
	const struct cred___37 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___36 *nsproxy;
	struct signal_struct___35 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___39 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___8 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___27 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___23 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___37 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___39 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___23 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___23 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___39 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___23)(struct perf_event___23 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___23;

struct fasync_struct___37;

struct pid_namespace___33;

struct trace_event_call___18;

struct perf_cgroup___23;

struct perf_event___23 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___23 *group_leader;
	struct pmu___23 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___23 hw;
	struct perf_event_context___23 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___23 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___39 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___37 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___23 *);
	struct callback_head callback_head;
	struct pid_namespace___33 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___23 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___23 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___18 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___23 *cgrp;
	struct list_head sb_list;
};

struct upid___33 {
	int nr;
	struct pid_namespace___33 *ns;
};

struct dentry___39;

struct user_namespace___28;

struct ucounts___28;

struct pid_namespace___33 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___39 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___33 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___39 *proc_self;
	struct dentry___39 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___28 *user_ns;
	struct ucounts___28 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___2 ns;
};

struct pid___33 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___33 numbers[1];
};

struct rw_semaphore___38 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___39 *owner;
};

struct key___38;

struct user_namespace___28 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___28 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___2 ns;
	long unsigned int flags;
	struct key___38 *persistent_keyring_register;
	struct rw_semaphore___38 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___28 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct secondary_data___38 {
	void *stack;
	struct task_struct___39 *task;
	long int status;
};

typedef struct page___38 *pgtable_t___37;

struct address_space___37;

struct dev_pagemap___37;

struct page___38 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___37 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___38 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___37 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___38 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___37 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct user_struct___37 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___38 *uid_keyring;
	struct key___38 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___37;

struct vm_area_struct___38 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___38 *vm_next;
	struct vm_area_struct___38 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___38 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___37 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___38 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___37;

struct mm_struct___38 {
	struct {
		struct vm_area_struct___38 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___38 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___38 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___37 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___39 *owner;
		struct user_namespace___28 *user_ns;
		struct file___38 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___37 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___37 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___38 *session_keyring;
	struct key___38 *process_keyring;
	struct key___38 *thread_keyring;
	struct key___38 *request_key_auth;
	void *security;
	struct user_struct___37 *user;
	struct user_namespace___28 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___27;

struct nsproxy___36 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___33 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___27 *cgroup_ns;
};

struct signal_struct___35 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___39 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___39 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___33 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___33 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___38 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___33 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___27;

struct cgroup___27;

struct css_set___27 {
	struct cgroup_subsys_state___27 *subsys[13];
	refcount_t refcount;
	struct css_set___27 *dom_cset;
	struct cgroup___27 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___27 *mg_src_cgrp;
	struct cgroup___27 *mg_dst_cgrp;
	struct css_set___27 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___23 {
	struct pmu___23 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___39 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___23 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

union thread_union___35 {
	struct task_struct___39 task;
	long unsigned int stack[8192];
};

struct __user_cap_header_struct {
	__u32 version;
	int pid;
};

typedef struct __user_cap_header_struct *cap_user_header_t;

struct __user_cap_data_struct {
	__u32 effective;
	__u32 permitted;
	__u32 inheritable;
};

typedef struct __user_cap_data_struct *cap_user_data_t;

typedef int (*key_restrict_link_func_t___37)(struct key___38 *, const struct key_type *, const union key_payload *, struct key___38 *);

struct key_restriction___38;

struct key___38 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___38 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___38 *restrict_link;
};

struct key_restriction___38 {
	key_restrict_link_func_t___37 check;
	struct key___38 *key;
	struct key_type *keytype;
};

struct pglist_data___37;

struct lruvec___37 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___37 *pgdat;
};

struct zone___37 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___37 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___37 {
	struct zone___37 *zone;
	int zone_idx;
};

struct zonelist___37 {
	struct zoneref___37 _zonerefs[25];
};

struct pglist_data___37 {
	struct zone___37 node_zones[3];
	struct zonelist___37 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___39 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___39 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___37 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___37 {
	struct rw_semaphore___38 rwsem;
	struct notifier_block *head;
};

struct address_space_operations___37;

struct address_space___37 {
	struct inode___40 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___38 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___37 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___37)(struct vm_area_struct___38 *, long unsigned int, const struct page___38 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___37)(struct page___38 *, void *);

struct device___33;

struct dev_pagemap___37 {
	dev_page_fault_t___37 page_fault;
	dev_page_free_t___37 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___33 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___37 {
	struct vfsmount *mnt;
	struct dentry___39 *dentry;
};

struct fown_struct___33 {
	rwlock_t lock;
	struct pid___33 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___38 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___37 f_path;
	struct inode___40 *f_inode;
	const struct file_operations___38 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___33 f_owner;
	const struct cred___37 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___37 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___37;

struct vm_operations_struct___37 {
	void (*open)(struct vm_area_struct___38 *);
	void (*close)(struct vm_area_struct___38 *);
	int (*split)(struct vm_area_struct___38 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___38 *);
	vm_fault_t (*fault)(struct vm_fault___37 *);
	vm_fault_t (*huge_fault)(struct vm_fault___37 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___37 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___38 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___37 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___37 *);
	int (*access)(struct vm_area_struct___38 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___38 *);
	int (*set_policy)(struct vm_area_struct___38 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___38 *, long unsigned int);
	struct page___38 * (*find_special_page)(struct vm_area_struct___38 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___37 {
	struct task_struct___39 *task;
	struct core_thread___37 *next;
};

struct core_state___37 {
	atomic_t nr_threads;
	struct core_thread___37 dumper;
	struct completion startup;
};

struct vm_fault___37 {
	struct vm_area_struct___38 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___38 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___38 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___37 prealloc_pte;
};

struct kset___35;

struct kobj_type___35;

struct kernfs_node___35;

struct kobject___36 {
	const char *name;
	struct list_head entry;
	struct kobject___36 *parent;
	struct kset___35 *kset;
	struct kobj_type___35 *ktype;
	struct kernfs_node___35 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___33 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___33 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___33;

struct bus_type___33;

struct device_driver___33;

struct dev_pm_domain___33;

struct class___33;

struct attribute_group___33;

struct device___33 {
	struct device___33 *parent;
	struct device_private *p;
	struct kobject___36 kobj;
	const char *init_name;
	const struct device_type___33 *type;
	struct mutex mutex;
	struct bus_type___33 *bus;
	struct device_driver___33 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___33 power;
	struct dev_pm_domain___33 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___33 *class;
	const struct attribute_group___33 **groups;
	void (*release)(struct device___33 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___37;

struct super_block___38;

struct dentry___39 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___39 *d_parent;
	struct qstr d_name;
	struct inode___40 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___37 *d_op;
	struct super_block___38 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___37;

struct block_device___38;

struct inode___40 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___37 *i_op;
	struct super_block___38 *i_sb;
	struct address_space___37 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___38 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___38 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___37 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___38 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___37 {
	int (*d_revalidate)(struct dentry___39 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___39 *, unsigned int);
	int (*d_hash)(const struct dentry___39 *, struct qstr *);
	int (*d_compare)(const struct dentry___39 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___39 *);
	int (*d_init)(struct dentry___39 *);
	void (*d_release)(struct dentry___39 *);
	void (*d_prune)(struct dentry___39 *);
	void (*d_iput)(struct dentry___39 *, struct inode___40 *);
	char * (*d_dname)(struct dentry___39 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___37 *);
	int (*d_manage)(const struct path___37 *, bool);
	struct dentry___39 * (*d_real)(struct dentry___39 *, const struct inode___40 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___37;

struct mem_dqinfo___37 {
	struct quota_format_type___37 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___37;

struct quota_info___37 {
	unsigned int flags;
	struct rw_semaphore___38 dqio_sem;
	struct inode___40 *files[3];
	struct mem_dqinfo___37 info[3];
	const struct quota_format_ops___37 *ops[3];
};

struct rcuwait___37 {
	struct task_struct___39 *task;
};

struct percpu_rw_semaphore___37 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___38 rw_sem;
	struct rcuwait___37 writer;
	int readers_block;
};

struct sb_writers___37 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___37 rw_sem[3];
};

struct file_system_type___37;

struct super_operations___37;

struct dquot_operations___37;

struct quotactl_ops___37;

struct super_block___38 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___37 *s_type;
	const struct super_operations___37 *s_op;
	const struct dquot_operations___37 *dq_op;
	const struct quotactl_ops___37 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___39 *s_root;
	struct rw_semaphore___38 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___38 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___37 s_dquot;
	struct sb_writers___37 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___37 *s_d_op;
	int cleancache_poolid;
	struct shrinker___13 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___28 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___38 {
	struct file___38 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___38 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___38 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___38 *ia_file;
};

struct dquot___37 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___38 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___37 {
	int qf_fmt_id;
	const struct quota_format_ops___37 *qf_ops;
	struct module___35 *qf_owner;
	struct quota_format_type___37 *qf_next;
};

struct quota_format_ops___37 {
	int (*check_quota_file)(struct super_block___38 *, int);
	int (*read_file_info)(struct super_block___38 *, int);
	int (*write_file_info)(struct super_block___38 *, int);
	int (*free_file_info)(struct super_block___38 *, int);
	int (*read_dqblk)(struct dquot___37 *);
	int (*commit_dqblk)(struct dquot___37 *);
	int (*release_dqblk)(struct dquot___37 *);
	int (*get_next_id)(struct super_block___38 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___37 {
	int (*write_dquot)(struct dquot___37 *);
	struct dquot___37 * (*alloc_dquot)(struct super_block___38 *, int);
	void (*destroy_dquot)(struct dquot___37 *);
	int (*acquire_dquot)(struct dquot___37 *);
	int (*release_dquot)(struct dquot___37 *);
	int (*mark_dirty)(struct dquot___37 *);
	int (*write_info)(struct super_block___38 *, int);
	qsize_t * (*get_reserved_space)(struct inode___40 *);
	int (*get_projid)(struct inode___40 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___40 *, qsize_t *);
	int (*get_next_id)(struct super_block___38 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___37 {
	int (*quota_on)(struct super_block___38 *, int, int, const struct path___37 *);
	int (*quota_off)(struct super_block___38 *, int);
	int (*quota_enable)(struct super_block___38 *, unsigned int);
	int (*quota_disable)(struct super_block___38 *, unsigned int);
	int (*quota_sync)(struct super_block___38 *, int);
	int (*set_info)(struct super_block___38 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___38 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___38 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___38 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___38 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___38 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___32 {
	struct kobject___36 kobj;
	struct module___35 *mod;
	struct kobject___36 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___32 {
	struct module___35 *mod;
	struct latch_tree_node node;
};

struct module_layout___32 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___32 mtn;
};

struct module_attribute___32;

struct kernel_param___32;

struct module___35 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___32 mkobj;
	struct module_attribute___32 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___36 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___32 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___32 core_layout;
	struct module_layout___32 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___18 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___37 {
	int (*writepage)(struct page___38 *, struct writeback_control___3 *);
	int (*readpage)(struct file___38 *, struct page___38 *);
	int (*writepages)(struct address_space___37 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___38 *);
	int (*readpages)(struct file___38 *, struct address_space___37 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___38 *, struct address_space___37 *, loff_t, unsigned int, unsigned int, struct page___38 **, void **);
	int (*write_end)(struct file___38 *, struct address_space___37 *, loff_t, unsigned int, unsigned int, struct page___38 *, void *);
	sector_t (*bmap)(struct address_space___37 *, sector_t);
	void (*invalidatepage)(struct page___38 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___38 *, gfp_t);
	void (*freepage)(struct page___38 *);
	ssize_t (*direct_IO)(struct kiocb___38 *, struct iov_iter___16 *);
	int (*migratepage)(struct address_space___37 *, struct page___38 *, struct page___38 *, enum migrate_mode);
	bool (*isolate_page)(struct page___38 *, isolate_mode_t);
	void (*putback_page)(struct page___38 *);
	int (*launder_page)(struct page___38 *);
	int (*is_partially_uptodate)(struct page___38 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___38 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___37 *, struct page___38 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___38 *, sector_t *);
	void (*swap_deactivate)(struct file___38 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___38 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___40 *bd_inode;
	struct super_block___38 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___38 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___37 {
	struct dentry___39 * (*lookup)(struct inode___40 *, struct dentry___39 *, unsigned int);
	const char * (*get_link)(struct dentry___39 *, struct inode___40 *, struct delayed_call *);
	int (*permission)(struct inode___40 *, int);
	struct posix_acl * (*get_acl)(struct inode___40 *, int);
	int (*readlink)(struct dentry___39 *, char *, int);
	int (*create)(struct inode___40 *, struct dentry___39 *, umode_t, bool);
	int (*link)(struct dentry___39 *, struct inode___40 *, struct dentry___39 *);
	int (*unlink)(struct inode___40 *, struct dentry___39 *);
	int (*symlink)(struct inode___40 *, struct dentry___39 *, const char *);
	int (*mkdir)(struct inode___40 *, struct dentry___39 *, umode_t);
	int (*rmdir)(struct inode___40 *, struct dentry___39 *);
	int (*mknod)(struct inode___40 *, struct dentry___39 *, umode_t, dev_t);
	int (*rename)(struct inode___40 *, struct dentry___39 *, struct inode___40 *, struct dentry___39 *, unsigned int);
	int (*setattr)(struct dentry___39 *, struct iattr___38 *);
	int (*getattr)(const struct path___37 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___39 *, char *, size_t);
	int (*fiemap)(struct inode___40 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___40 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___40 *, struct dentry___39 *, struct file___38 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___40 *, struct dentry___39 *, umode_t);
	int (*set_acl)(struct inode___40 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___37 {
	void (*fl_copy_lock)(struct file_lock___38 *, struct file_lock___38 *);
	void (*fl_release_private)(struct file_lock___38 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___37;

struct file_lock___38 {
	struct file_lock___38 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___38 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___37 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___37 *fl_ops;
	const struct lock_manager_operations___37 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___37 {
	int (*lm_compare_owner)(struct file_lock___38 *, struct file_lock___38 *);
	long unsigned int (*lm_owner_key)(struct file_lock___38 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___38 *);
	int (*lm_grant)(struct file_lock___38 *, int);
	bool (*lm_break)(struct file_lock___38 *);
	int (*lm_change)(struct file_lock___38 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___38 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___37 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___37 *fa_next;
	struct file___38 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___37 {
	const char *name;
	int fs_flags;
	struct dentry___39 * (*mount)(struct file_system_type___37 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___38 *);
	struct module___35 *owner;
	struct file_system_type___37 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___37 {
	struct inode___40 * (*alloc_inode)(struct super_block___38 *);
	void (*destroy_inode)(struct inode___40 *);
	void (*dirty_inode)(struct inode___40 *, int);
	int (*write_inode)(struct inode___40 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___40 *);
	void (*evict_inode)(struct inode___40 *);
	void (*put_super)(struct super_block___38 *);
	int (*sync_fs)(struct super_block___38 *, int);
	int (*freeze_super)(struct super_block___38 *);
	int (*freeze_fs)(struct super_block___38 *);
	int (*thaw_super)(struct super_block___38 *);
	int (*unfreeze_fs)(struct super_block___38 *);
	int (*statfs)(struct dentry___39 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___38 *, int *, char *);
	void (*umount_begin)(struct super_block___38 *);
	int (*show_options)(struct seq_file___35 *, struct dentry___39 *);
	int (*show_devname)(struct seq_file___35 *, struct dentry___39 *);
	int (*show_path)(struct seq_file___35 *, struct dentry___39 *);
	int (*show_stats)(struct seq_file___35 *, struct dentry___39 *);
	ssize_t (*quota_read)(struct super_block___38 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___38 *, int, const char *, size_t, loff_t);
	struct dquot___37 ** (*get_dquots)(struct inode___40 *);
	int (*bdev_try_to_free_page)(struct super_block___38 *, struct page___38 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___38 *, struct shrink_control___13 *);
	long int (*free_cached_objects)(struct super_block___38 *, struct shrink_control___13 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___23)(struct file___38 *, wait_queue_head_t *, struct poll_table_struct___24 *);

struct poll_table_struct___24 {
	poll_queue_proc___23 _qproc;
	__poll_t _key;
};

struct seq_operations___32;

struct seq_file___35 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___32 *op;
	int poll_event;
	const struct file___38 *file;
	void *private;
};

struct kobj_attribute___36 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___36 *, struct kobj_attribute___36 *, char *);
	ssize_t (*store)(struct kobject___36 *, struct kobj_attribute___36 *, const char *, size_t);
};

typedef void compound_page_dtor___37(struct page___38 *);

struct cgroup_namespace___27 {
	refcount_t count;
	struct ns_common___2 ns;
	struct user_namespace___28 *user_ns;
	struct ucounts___28 *ucounts;
	struct css_set___27 *root_cset;
};

struct ucounts___28 {
	struct hlist_node node;
	struct user_namespace___28 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct seq_operations___32 {
	void * (*start)(struct seq_file___35 *, loff_t *);
	void (*stop)(struct seq_file___35 *, void *);
	void * (*next)(struct seq_file___35 *, void *, loff_t *);
	int (*show)(struct seq_file___35 *, void *);
};

struct kernfs_root___35;

struct kernfs_elem_dir___35 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___35 *root;
};

struct kernfs_syscall_ops___35;

struct kernfs_root___35 {
	struct kernfs_node___35 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___35 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___35 {
	struct kernfs_node___35 *target_kn;
};

struct kernfs_ops___35;

struct kernfs_elem_attr___35 {
	const struct kernfs_ops___35 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___35 *notify_next;
};

struct kernfs_node___35 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___35 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___35 dir;
		struct kernfs_elem_symlink___35 symlink;
		struct kernfs_elem_attr___35 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___35;

struct kernfs_ops___35 {
	int (*open)(struct kernfs_open_file___35 *);
	void (*release)(struct kernfs_open_file___35 *);
	int (*seq_show)(struct seq_file___35 *, void *);
	void * (*seq_start)(struct seq_file___35 *, loff_t *);
	void * (*seq_next)(struct seq_file___35 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___35 *, void *);
	ssize_t (*read)(struct kernfs_open_file___35 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___35 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___35 *, struct vm_area_struct___38 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___35 *, struct poll_table_struct___24 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___35 {
	int (*remount_fs)(struct kernfs_root___35 *, int *, char *);
	int (*show_options)(struct seq_file___35 *, struct kernfs_root___35 *);
	int (*mkdir)(struct kernfs_node___35 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___35 *);
	int (*rename)(struct kernfs_node___35 *, struct kernfs_node___35 *, const char *);
	int (*show_path)(struct seq_file___35 *, struct kernfs_node___35 *, struct kernfs_root___35 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___35 {
	struct kernfs_node___35 *kn;
	struct file___38 *file;
	struct seq_file___35 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___37 *vm_ops;
};

struct bin_attribute___33;

struct attribute_group___33 {
	const char *name;
	umode_t (*is_visible)(struct kobject___36 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___36 *, struct bin_attribute___33 *, int);
	struct attribute **attrs;
	struct bin_attribute___33 **bin_attrs;
};

struct bin_attribute___33 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___38 *, struct kobject___36 *, struct bin_attribute___33 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___38 *, struct kobject___36 *, struct bin_attribute___33 *, char *, loff_t, size_t);
	int (*mmap)(struct file___38 *, struct kobject___36 *, struct bin_attribute___33 *, struct vm_area_struct___38 *);
};

struct sysfs_ops___35 {
	ssize_t (*show)(struct kobject___36 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___36 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___35;

struct kset___35 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___36 kobj;
	const struct kset_uevent_ops___35 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___35 {
	void (*release)(struct kobject___36 *);
	const struct sysfs_ops___35 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___2 * (*child_ns_type)(struct kobject___36 *);
	const void * (*namespace)(struct kobject___36 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___35 {
	int (* const filter)(struct kset___35 *, struct kobject___36 *);
	const char * (* const name)(struct kset___35 *, struct kobject___36 *);
	int (* const uevent)(struct kset___35 *, struct kobject___36 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___32 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___32 *);
	int (*get)(char *, const struct kernel_param___32 *);
	void (*free)(void *);
};

struct kparam_array___32;

struct kernel_param___32 {
	const char *name;
	struct module___35 *mod;
	const struct kernel_param_ops___32 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___32 *arr;
	};
};

struct kparam_array___32 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___32 *ops;
	void *elem;
};

struct module_attribute___32 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___32 *, struct module_kobject___32 *, char *);
	ssize_t (*store)(struct module_attribute___32 *, struct module_kobject___32 *, const char *, size_t);
	void (*setup)(struct module___35 *, const char *);
	int (*test)(struct module___35 *);
	void (*free)(struct module___35 *);
};

struct trace_event_class___18;

struct trace_event_call___18 {
	struct list_head list;
	struct trace_event_class___18 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___3 *prog_array;
	int (*perf_perm)(struct trace_event_call___18 *, struct perf_event___23 *);
};

struct dev_pm_ops___33 {
	int (*prepare)(struct device___33 *);
	void (*complete)(struct device___33 *);
	int (*suspend)(struct device___33 *);
	int (*resume)(struct device___33 *);
	int (*freeze)(struct device___33 *);
	int (*thaw)(struct device___33 *);
	int (*poweroff)(struct device___33 *);
	int (*restore)(struct device___33 *);
	int (*suspend_late)(struct device___33 *);
	int (*resume_early)(struct device___33 *);
	int (*freeze_late)(struct device___33 *);
	int (*thaw_early)(struct device___33 *);
	int (*poweroff_late)(struct device___33 *);
	int (*restore_early)(struct device___33 *);
	int (*suspend_noirq)(struct device___33 *);
	int (*resume_noirq)(struct device___33 *);
	int (*freeze_noirq)(struct device___33 *);
	int (*thaw_noirq)(struct device___33 *);
	int (*poweroff_noirq)(struct device___33 *);
	int (*restore_noirq)(struct device___33 *);
	int (*runtime_suspend)(struct device___33 *);
	int (*runtime_resume)(struct device___33 *);
	int (*runtime_idle)(struct device___33 *);
};

struct dev_pm_domain___33 {
	struct dev_pm_ops___33 ops;
	void (*detach)(struct device___33 *, bool);
	int (*activate)(struct device___33 *);
	void (*sync)(struct device___33 *);
	void (*dismiss)(struct device___33 *);
};

struct bus_type___33 {
	const char *name;
	const char *dev_name;
	struct device___33 *dev_root;
	const struct attribute_group___33 **bus_groups;
	const struct attribute_group___33 **dev_groups;
	const struct attribute_group___33 **drv_groups;
	int (*match)(struct device___33 *, struct device_driver___33 *);
	int (*uevent)(struct device___33 *, struct kobj_uevent_env *);
	int (*probe)(struct device___33 *);
	int (*remove)(struct device___33 *);
	void (*shutdown)(struct device___33 *);
	int (*online)(struct device___33 *);
	int (*offline)(struct device___33 *);
	int (*suspend)(struct device___33 *, pm_message_t);
	int (*resume)(struct device___33 *);
	int (*num_vf)(struct device___33 *);
	int (*dma_configure)(struct device___33 *);
	const struct dev_pm_ops___33 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___33 {
	const char *name;
	struct bus_type___33 *bus;
	struct module___35 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___33 *);
	int (*remove)(struct device___33 *);
	void (*shutdown)(struct device___33 *);
	int (*suspend)(struct device___33 *, pm_message_t);
	int (*resume)(struct device___33 *);
	const struct attribute_group___33 **groups;
	const struct dev_pm_ops___33 *pm;
	void (*coredump)(struct device___33 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___33 {
	const char *name;
	const struct attribute_group___33 **groups;
	int (*uevent)(struct device___33 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___33 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___33 *);
	const struct dev_pm_ops___33 *pm;
};

struct class___33 {
	const char *name;
	struct module___35 *owner;
	const struct attribute_group___33 **class_groups;
	const struct attribute_group___33 **dev_groups;
	struct kobject___36 *dev_kobj;
	int (*dev_uevent)(struct device___33 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___33 *, umode_t *);
	void (*class_release)(struct class___33 *);
	void (*dev_release)(struct device___33 *);
	int (*shutdown_pre)(struct device___33 *);
	const struct kobj_ns_type_operations___2 *ns_type;
	const void * (*namespace)(struct device___33 *);
	const struct dev_pm_ops___33 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___31 {
	struct device___33 dev;
};

struct bpf_map___27;

struct bpf_map_ops___27 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___27 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___27 *, struct file___38 *);
	void (*map_free)(struct bpf_map___27 *);
	int (*map_get_next_key)(struct bpf_map___27 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___27 *);
	void * (*map_lookup_elem)(struct bpf_map___27 *, void *);
	int (*map_update_elem)(struct bpf_map___27 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___27 *, void *);
	int (*map_push_elem)(struct bpf_map___27 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___27 *, void *);
	int (*map_peek_elem)(struct bpf_map___27 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___27 *, struct file___38 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___27 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___27 *, void *, struct seq_file___35 *);
	int (*map_check_btf)(const struct bpf_map___27 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___27 {
	const struct bpf_map_ops___27 *ops;
	struct bpf_map___27 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___37 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___27;

typedef void (*kthread_work_func_t___27)(struct kthread_work___27 *);

struct kthread_worker___27;

struct kthread_work___27 {
	struct list_head node;
	kthread_work_func_t___27 func;
	struct kthread_worker___27 *worker;
	int canceling;
};

struct kthread_worker___27 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___39 *task;
	struct kthread_work___27 *current_work;
};

struct kthread_delayed_work___27 {
	struct kthread_work___27 work;
	struct timer_list timer;
};

struct psi_group___27 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___27 *poll_kworker;
	struct kthread_delayed_work___27 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___27 {
	struct kernfs_node___35 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___27;

struct cgroup_subsys_state___27 {
	struct cgroup___27 *cgroup;
	struct cgroup_subsys___27 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___27 *parent;
};

struct cgroup_root___27;

struct cgroup_rstat_cpu___27;

struct cgroup___27 {
	struct cgroup_subsys_state___27 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___35 *kn;
	struct cgroup_file___27 procs_file;
	struct cgroup_file___27 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___27 *subsys[13];
	struct cgroup_root___27 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___27 *dom_cgrp;
	struct cgroup_rstat_cpu___27 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___3 bpf;
	atomic_t congestion_count;
	struct cgroup___27 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___27 psi;
	int ancestor_ids[0];
};

struct cftype___27;

struct cgroup_subsys___27 {
	struct cgroup_subsys_state___27 * (*css_alloc)(struct cgroup_subsys_state___27 *);
	int (*css_online)(struct cgroup_subsys_state___27 *);
	void (*css_offline)(struct cgroup_subsys_state___27 *);
	void (*css_released)(struct cgroup_subsys_state___27 *);
	void (*css_free)(struct cgroup_subsys_state___27 *);
	void (*css_reset)(struct cgroup_subsys_state___27 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___27 *, int);
	int (*css_extra_stat_show)(struct seq_file___35 *, struct cgroup_subsys_state___27 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___39 *);
	void (*cancel_fork)(struct task_struct___39 *);
	void (*fork)(struct task_struct___39 *);
	void (*exit)(struct task_struct___39 *);
	void (*free)(struct task_struct___39 *);
	void (*bind)(struct cgroup_subsys_state___27 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___27 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___27 *dfl_cftypes;
	struct cftype___27 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___27 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___27 *updated_children;
	struct cgroup___27 *updated_next;
};

struct cgroup_root___27 {
	struct kernfs_root___35 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___27 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___27 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___27 *ss;
	struct list_head node;
	struct kernfs_ops___35 *kf_ops;
	int (*open)(struct kernfs_open_file___35 *);
	void (*release)(struct kernfs_open_file___35 *);
	u64 (*read_u64)(struct cgroup_subsys_state___27 *, struct cftype___27 *);
	s64 (*read_s64)(struct cgroup_subsys_state___27 *, struct cftype___27 *);
	int (*seq_show)(struct seq_file___35 *, void *);
	void * (*seq_start)(struct seq_file___35 *, loff_t *);
	void * (*seq_next)(struct seq_file___35 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___35 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___27 *, struct cftype___27 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___27 *, struct cftype___27 *, s64);
	ssize_t (*write)(struct kernfs_open_file___35 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___35 *, struct poll_table_struct___24 *);
};

struct perf_cpu_context___23;

struct pmu___23 {
	struct list_head entry;
	struct module___35 *module;
	struct device___33 *dev;
	const struct attribute_group___33 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___23 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___23 *);
	void (*pmu_disable)(struct pmu___23 *);
	int (*event_init)(struct perf_event___23 *);
	void (*event_mapped)(struct perf_event___23 *, struct mm_struct___38 *);
	void (*event_unmapped)(struct perf_event___23 *, struct mm_struct___38 *);
	int (*add)(struct perf_event___23 *, int);
	void (*del)(struct perf_event___23 *, int);
	void (*start)(struct perf_event___23 *, int);
	void (*stop)(struct perf_event___23 *, int);
	void (*read)(struct perf_event___23 *);
	void (*start_txn)(struct pmu___23 *, unsigned int);
	int (*commit_txn)(struct pmu___23 *);
	void (*cancel_txn)(struct pmu___23 *);
	int (*event_idx)(struct perf_event___23 *);
	void (*sched_task)(struct perf_event_context___23 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___23 *);
	int (*filter_match)(struct perf_event___23 *);
	int (*check_period)(struct perf_event___23 *, u64);
};

struct perf_cpu_context___23 {
	struct perf_event_context___23 ctx;
	struct perf_event_context___23 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___23 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___23 {
	struct cgroup_subsys_state___27 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___18 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___18 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___18 *);
	struct list_head * (*get_fields)(struct trace_event_call___18 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___18 *);
};

struct syscall_metadata___7 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___18 *enter_event;
	struct trace_event_call___18 *exit_event;
};

struct module___36;

struct file___39;

struct kiocb___39;

struct poll_table_struct___25;

struct vm_area_struct___39;

struct inode___41;

struct file_lock___39;

struct page___39;

struct seq_file___36;

struct file_operations___39 {
	struct module___36 *owner;
	loff_t (*llseek)(struct file___39 *, loff_t, int);
	ssize_t (*read)(struct file___39 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___39 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___39 *, struct iov_iter___16 *);
	ssize_t (*write_iter)(struct kiocb___39 *, struct iov_iter___16 *);
	int (*iopoll)(struct kiocb___39 *, bool);
	int (*iterate)(struct file___39 *, struct dir_context *);
	int (*iterate_shared)(struct file___39 *, struct dir_context *);
	__poll_t (*poll)(struct file___39 *, struct poll_table_struct___25 *);
	long int (*unlocked_ioctl)(struct file___39 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___39 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___39 *, struct vm_area_struct___39 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___41 *, struct file___39 *);
	int (*flush)(struct file___39 *, fl_owner_t);
	int (*release)(struct inode___41 *, struct file___39 *);
	int (*fsync)(struct file___39 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___39 *, int);
	int (*lock)(struct file___39 *, int, struct file_lock___39 *);
	ssize_t (*sendpage)(struct file___39 *, struct page___39 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___39 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___39 *, int, struct file_lock___39 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___39 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___39 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___39 *, long int, struct file_lock___39 **, void **);
	long int (*fallocate)(struct file___39 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___36 *, struct file___39 *);
	ssize_t (*copy_file_range)(struct file___39 *, loff_t, struct file___39 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___39 *, loff_t, struct file___39 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___39 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___38 {
	u64 seqnum;
	struct vm_area_struct___39 *vmas[4];
};

struct page_frag___38 {
	struct page___39 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___24;

struct debug_info___24 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___24 *hbp_break[16];
	struct perf_event___24 *hbp_watch[16];
};

struct thread_struct___24 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___24 debug;
	long: 64;
};

struct pid___34;

struct cred___38;

struct nsproxy___37;

struct signal_struct___36;

struct css_set___28;

struct perf_event_context___24;

struct task_struct___40 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___40 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___2 *mm;
	struct mm_struct___2 *active_mm;
	struct vmacache___38 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___40 *real_parent;
	struct task_struct___40 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___40 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___34 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___34 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___34 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___38 *ptracer_cred;
	const struct cred___38 *real_cred;
	const struct cred___38 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___37 *nsproxy;
	struct signal_struct___36 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___40 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___8 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___28 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___24 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___38 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___40 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___24 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___24 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___40 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___24)(struct perf_event___24 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___24;

struct fasync_struct___38;

struct pid_namespace___34;

struct trace_event_call___19;

struct perf_cgroup___24;

struct perf_event___24 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___24 *group_leader;
	struct pmu___24 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___24 hw;
	struct perf_event_context___24 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___24 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___40 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___38 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___24 *);
	struct callback_head callback_head;
	struct pid_namespace___34 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___24 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___24 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___19 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___24 *cgrp;
	struct list_head sb_list;
};

struct upid___34 {
	int nr;
	struct pid_namespace___34 *ns;
};

struct dentry___40;

struct user_namespace___29;

struct ucounts___29;

struct pid_namespace___34 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___40 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___34 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___40 *proc_self;
	struct dentry___40 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___29 *user_ns;
	struct ucounts___29 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___2 ns;
};

struct pid___34 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___34 numbers[1];
};

struct rw_semaphore___39 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___40 *owner;
};

struct key___39;

struct user_namespace___29 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___29 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___2 ns;
	long unsigned int flags;
	struct key___39 *persistent_keyring_register;
	struct rw_semaphore___39 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___29 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct secondary_data___39 {
	void *stack;
	struct task_struct___40 *task;
	long int status;
};

typedef struct page___39 *pgtable_t___38;

struct address_space___38;

struct dev_pagemap___38;

struct page___39 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___38 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___39 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___38 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___2 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___38 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct user_struct___38;

struct sigqueue {
	struct list_head list;
	int flags;
	kernel_siginfo_t info;
	struct user_struct___38 *user;
};

struct user_struct___38 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___39 *uid_keyring;
	struct key___39 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___38;

struct vm_area_struct___39 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___39 *vm_next;
	struct vm_area_struct___39 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___2 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___38 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___39 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___38;

struct mm_struct___2 {
	struct {
		struct vm_area_struct___39 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___39 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___39 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___38 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___40 *owner;
		struct user_namespace___29 *user_ns;
		struct file___39 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___38 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___38 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___39 *session_keyring;
	struct key___39 *process_keyring;
	struct key___39 *thread_keyring;
	struct key___39 *request_key_auth;
	void *security;
	struct user_struct___38 *user;
	struct user_namespace___29 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___28;

struct nsproxy___37 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___34 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___28 *cgroup_ns;
};

struct signal_struct___36 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___40 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___40 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___34 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___34 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___2 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___34 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___28;

struct cgroup___28;

struct css_set___28 {
	struct cgroup_subsys_state___28 *subsys[13];
	refcount_t refcount;
	struct css_set___28 *dom_cset;
	struct cgroup___28 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___28 *mg_src_cgrp;
	struct cgroup___28 *mg_dst_cgrp;
	struct css_set___28 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___24 {
	struct pmu___24 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___40 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___24 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

union thread_union___36 {
	struct task_struct___40 task;
	long unsigned int stack[8192];
};

struct address_space_operations___38;

struct address_space___38 {
	struct inode___41 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___39 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___38 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___38)(struct vm_area_struct___39 *, long unsigned int, const struct page___39 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___38)(struct page___39 *, void *);

struct device___34;

struct dev_pagemap___38 {
	dev_page_fault_t___38 page_fault;
	dev_page_free_t___38 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___34 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___38 {
	struct vfsmount *mnt;
	struct dentry___40 *dentry;
};

struct fown_struct___34 {
	rwlock_t lock;
	struct pid___34 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___39 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___38 f_path;
	struct inode___41 *f_inode;
	const struct file_operations___39 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___34 f_owner;
	const struct cred___38 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___38 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___38;

struct vm_operations_struct___38 {
	void (*open)(struct vm_area_struct___39 *);
	void (*close)(struct vm_area_struct___39 *);
	int (*split)(struct vm_area_struct___39 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___39 *);
	vm_fault_t (*fault)(struct vm_fault___38 *);
	vm_fault_t (*huge_fault)(struct vm_fault___38 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___38 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___39 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___38 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___38 *);
	int (*access)(struct vm_area_struct___39 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___39 *);
	int (*set_policy)(struct vm_area_struct___39 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___39 *, long unsigned int);
	struct page___39 * (*find_special_page)(struct vm_area_struct___39 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___38 {
	struct task_struct___40 *task;
	struct core_thread___38 *next;
};

struct core_state___38 {
	atomic_t nr_threads;
	struct core_thread___38 dumper;
	struct completion startup;
};

struct vm_fault___38 {
	struct vm_area_struct___39 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___39 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___39 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___38 prealloc_pte;
};

struct pglist_data___38;

struct lruvec___38 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___38 *pgdat;
};

struct zone___38 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___38 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___38 {
	struct zone___38 *zone;
	int zone_idx;
};

struct zonelist___38 {
	struct zoneref___38 _zonerefs[25];
};

struct pglist_data___38 {
	struct zone___38 node_zones[3];
	struct zonelist___38 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___40 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___40 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___38 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___38 {
	struct rw_semaphore___39 rwsem;
	struct notifier_block *head;
};

struct kset___36;

struct kobj_type___36;

struct kernfs_node___36;

struct kobject___37 {
	const char *name;
	struct list_head entry;
	struct kobject___37 *parent;
	struct kset___36 *kset;
	struct kobj_type___36 *ktype;
	struct kernfs_node___36 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___34 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___34 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___34;

struct bus_type___34;

struct device_driver___34;

struct dev_pm_domain___34;

struct class___34;

struct attribute_group___34;

struct device___34 {
	struct device___34 *parent;
	struct device_private *p;
	struct kobject___37 kobj;
	const char *init_name;
	const struct device_type___34 *type;
	struct mutex mutex;
	struct bus_type___34 *bus;
	struct device_driver___34 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___34 power;
	struct dev_pm_domain___34 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___34 *class;
	const struct attribute_group___34 **groups;
	void (*release)(struct device___34 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___38;

struct super_block___39;

struct dentry___40 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___40 *d_parent;
	struct qstr d_name;
	struct inode___41 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___38 *d_op;
	struct super_block___39 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___38;

struct block_device___39;

struct inode___41 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___38 *i_op;
	struct super_block___39 *i_sb;
	struct address_space___38 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___39 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___39 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___38 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___39 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___38 {
	int (*d_revalidate)(struct dentry___40 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___40 *, unsigned int);
	int (*d_hash)(const struct dentry___40 *, struct qstr *);
	int (*d_compare)(const struct dentry___40 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___40 *);
	int (*d_init)(struct dentry___40 *);
	void (*d_release)(struct dentry___40 *);
	void (*d_prune)(struct dentry___40 *);
	void (*d_iput)(struct dentry___40 *, struct inode___41 *);
	char * (*d_dname)(struct dentry___40 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___38 *);
	int (*d_manage)(const struct path___38 *, bool);
	struct dentry___40 * (*d_real)(struct dentry___40 *, const struct inode___41 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___38;

struct mem_dqinfo___38 {
	struct quota_format_type___38 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___38;

struct quota_info___38 {
	unsigned int flags;
	struct rw_semaphore___39 dqio_sem;
	struct inode___41 *files[3];
	struct mem_dqinfo___38 info[3];
	const struct quota_format_ops___38 *ops[3];
};

struct rcuwait___38 {
	struct task_struct___40 *task;
};

struct percpu_rw_semaphore___38 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___39 rw_sem;
	struct rcuwait___38 writer;
	int readers_block;
};

struct sb_writers___38 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___38 rw_sem[3];
};

struct file_system_type___38;

struct super_operations___38;

struct dquot_operations___38;

struct quotactl_ops___38;

struct super_block___39 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___38 *s_type;
	const struct super_operations___38 *s_op;
	const struct dquot_operations___38 *dq_op;
	const struct quotactl_ops___38 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___40 *s_root;
	struct rw_semaphore___39 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___39 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___38 s_dquot;
	struct sb_writers___38 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___38 *s_d_op;
	int cleancache_poolid;
	struct shrinker___13 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___29 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___39 {
	struct file___39 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___39 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___39 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___39 *ia_file;
};

struct dquot___38 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___39 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___38 {
	int qf_fmt_id;
	const struct quota_format_ops___38 *qf_ops;
	struct module___36 *qf_owner;
	struct quota_format_type___38 *qf_next;
};

struct quota_format_ops___38 {
	int (*check_quota_file)(struct super_block___39 *, int);
	int (*read_file_info)(struct super_block___39 *, int);
	int (*write_file_info)(struct super_block___39 *, int);
	int (*free_file_info)(struct super_block___39 *, int);
	int (*read_dqblk)(struct dquot___38 *);
	int (*commit_dqblk)(struct dquot___38 *);
	int (*release_dqblk)(struct dquot___38 *);
	int (*get_next_id)(struct super_block___39 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___38 {
	int (*write_dquot)(struct dquot___38 *);
	struct dquot___38 * (*alloc_dquot)(struct super_block___39 *, int);
	void (*destroy_dquot)(struct dquot___38 *);
	int (*acquire_dquot)(struct dquot___38 *);
	int (*release_dquot)(struct dquot___38 *);
	int (*mark_dirty)(struct dquot___38 *);
	int (*write_info)(struct super_block___39 *, int);
	qsize_t * (*get_reserved_space)(struct inode___41 *);
	int (*get_projid)(struct inode___41 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___41 *, qsize_t *);
	int (*get_next_id)(struct super_block___39 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___38 {
	int (*quota_on)(struct super_block___39 *, int, int, const struct path___38 *);
	int (*quota_off)(struct super_block___39 *, int);
	int (*quota_enable)(struct super_block___39 *, unsigned int);
	int (*quota_disable)(struct super_block___39 *, unsigned int);
	int (*quota_sync)(struct super_block___39 *, int);
	int (*set_info)(struct super_block___39 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___39 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___39 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___39 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___39 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___39 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___33 {
	struct kobject___37 kobj;
	struct module___36 *mod;
	struct kobject___37 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___33 {
	struct module___36 *mod;
	struct latch_tree_node node;
};

struct module_layout___33 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___33 mtn;
};

struct module_attribute___33;

struct kernel_param___33;

struct module___36 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___33 mkobj;
	struct module_attribute___33 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___37 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___33 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___33 core_layout;
	struct module_layout___33 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___19 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___38 {
	int (*writepage)(struct page___39 *, struct writeback_control___3 *);
	int (*readpage)(struct file___39 *, struct page___39 *);
	int (*writepages)(struct address_space___38 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___39 *);
	int (*readpages)(struct file___39 *, struct address_space___38 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___39 *, struct address_space___38 *, loff_t, unsigned int, unsigned int, struct page___39 **, void **);
	int (*write_end)(struct file___39 *, struct address_space___38 *, loff_t, unsigned int, unsigned int, struct page___39 *, void *);
	sector_t (*bmap)(struct address_space___38 *, sector_t);
	void (*invalidatepage)(struct page___39 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___39 *, gfp_t);
	void (*freepage)(struct page___39 *);
	ssize_t (*direct_IO)(struct kiocb___39 *, struct iov_iter___16 *);
	int (*migratepage)(struct address_space___38 *, struct page___39 *, struct page___39 *, enum migrate_mode);
	bool (*isolate_page)(struct page___39 *, isolate_mode_t);
	void (*putback_page)(struct page___39 *);
	int (*launder_page)(struct page___39 *);
	int (*is_partially_uptodate)(struct page___39 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___39 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___38 *, struct page___39 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___39 *, sector_t *);
	void (*swap_deactivate)(struct file___39 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___39 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___41 *bd_inode;
	struct super_block___39 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___39 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___38 {
	struct dentry___40 * (*lookup)(struct inode___41 *, struct dentry___40 *, unsigned int);
	const char * (*get_link)(struct dentry___40 *, struct inode___41 *, struct delayed_call *);
	int (*permission)(struct inode___41 *, int);
	struct posix_acl * (*get_acl)(struct inode___41 *, int);
	int (*readlink)(struct dentry___40 *, char *, int);
	int (*create)(struct inode___41 *, struct dentry___40 *, umode_t, bool);
	int (*link)(struct dentry___40 *, struct inode___41 *, struct dentry___40 *);
	int (*unlink)(struct inode___41 *, struct dentry___40 *);
	int (*symlink)(struct inode___41 *, struct dentry___40 *, const char *);
	int (*mkdir)(struct inode___41 *, struct dentry___40 *, umode_t);
	int (*rmdir)(struct inode___41 *, struct dentry___40 *);
	int (*mknod)(struct inode___41 *, struct dentry___40 *, umode_t, dev_t);
	int (*rename)(struct inode___41 *, struct dentry___40 *, struct inode___41 *, struct dentry___40 *, unsigned int);
	int (*setattr)(struct dentry___40 *, struct iattr___39 *);
	int (*getattr)(const struct path___38 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___40 *, char *, size_t);
	int (*fiemap)(struct inode___41 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___41 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___41 *, struct dentry___40 *, struct file___39 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___41 *, struct dentry___40 *, umode_t);
	int (*set_acl)(struct inode___41 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___38 {
	void (*fl_copy_lock)(struct file_lock___39 *, struct file_lock___39 *);
	void (*fl_release_private)(struct file_lock___39 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___38;

struct file_lock___39 {
	struct file_lock___39 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___39 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___38 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___38 *fl_ops;
	const struct lock_manager_operations___38 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___38 {
	int (*lm_compare_owner)(struct file_lock___39 *, struct file_lock___39 *);
	long unsigned int (*lm_owner_key)(struct file_lock___39 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___39 *);
	int (*lm_grant)(struct file_lock___39 *, int);
	bool (*lm_break)(struct file_lock___39 *);
	int (*lm_change)(struct file_lock___39 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___39 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___38 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___38 *fa_next;
	struct file___39 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___38 {
	const char *name;
	int fs_flags;
	struct dentry___40 * (*mount)(struct file_system_type___38 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___39 *);
	struct module___36 *owner;
	struct file_system_type___38 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___38 {
	struct inode___41 * (*alloc_inode)(struct super_block___39 *);
	void (*destroy_inode)(struct inode___41 *);
	void (*dirty_inode)(struct inode___41 *, int);
	int (*write_inode)(struct inode___41 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___41 *);
	void (*evict_inode)(struct inode___41 *);
	void (*put_super)(struct super_block___39 *);
	int (*sync_fs)(struct super_block___39 *, int);
	int (*freeze_super)(struct super_block___39 *);
	int (*freeze_fs)(struct super_block___39 *);
	int (*thaw_super)(struct super_block___39 *);
	int (*unfreeze_fs)(struct super_block___39 *);
	int (*statfs)(struct dentry___40 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___39 *, int *, char *);
	void (*umount_begin)(struct super_block___39 *);
	int (*show_options)(struct seq_file___36 *, struct dentry___40 *);
	int (*show_devname)(struct seq_file___36 *, struct dentry___40 *);
	int (*show_path)(struct seq_file___36 *, struct dentry___40 *);
	int (*show_stats)(struct seq_file___36 *, struct dentry___40 *);
	ssize_t (*quota_read)(struct super_block___39 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___39 *, int, const char *, size_t, loff_t);
	struct dquot___38 ** (*get_dquots)(struct inode___41 *);
	int (*bdev_try_to_free_page)(struct super_block___39 *, struct page___39 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___39 *, struct shrink_control___13 *);
	long int (*free_cached_objects)(struct super_block___39 *, struct shrink_control___13 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___24)(struct file___39 *, wait_queue_head_t *, struct poll_table_struct___25 *);

struct poll_table_struct___25 {
	poll_queue_proc___24 _qproc;
	__poll_t _key;
};

struct seq_operations___33;

struct seq_file___36 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___33 *op;
	int poll_event;
	const struct file___39 *file;
	void *private;
};

struct kobj_attribute___37 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___37 *, struct kobj_attribute___37 *, char *);
	ssize_t (*store)(struct kobject___37 *, struct kobj_attribute___37 *, const char *, size_t);
};

typedef void compound_page_dtor___38(struct page___39 *);

typedef int (*key_restrict_link_func_t___38)(struct key___39 *, const struct key_type *, const union key_payload *, struct key___39 *);

struct key_restriction___39;

struct key___39 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___39 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___39 *restrict_link;
};

struct key_restriction___39 {
	key_restrict_link_func_t___38 check;
	struct key___39 *key;
	struct key_type *keytype;
};

struct cgroup_namespace___28 {
	refcount_t count;
	struct ns_common___2 ns;
	struct user_namespace___29 *user_ns;
	struct ucounts___29 *ucounts;
	struct css_set___28 *root_cset;
};

struct ucounts___29 {
	struct hlist_node node;
	struct user_namespace___29 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct ptrace_peeksiginfo_args {
	__u64 off;
	__u32 flags;
	__s32 nr;
};

struct seq_operations___33 {
	void * (*start)(struct seq_file___36 *, loff_t *);
	void (*stop)(struct seq_file___36 *, void *);
	void * (*next)(struct seq_file___36 *, void *, loff_t *);
	int (*show)(struct seq_file___36 *, void *);
};

struct kernfs_root___36;

struct kernfs_elem_dir___36 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___36 *root;
};

struct kernfs_syscall_ops___36;

struct kernfs_root___36 {
	struct kernfs_node___36 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___36 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___36 {
	struct kernfs_node___36 *target_kn;
};

struct kernfs_ops___36;

struct kernfs_elem_attr___36 {
	const struct kernfs_ops___36 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___36 *notify_next;
};

struct kernfs_node___36 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___36 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___36 dir;
		struct kernfs_elem_symlink___36 symlink;
		struct kernfs_elem_attr___36 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___36;

struct kernfs_ops___36 {
	int (*open)(struct kernfs_open_file___36 *);
	void (*release)(struct kernfs_open_file___36 *);
	int (*seq_show)(struct seq_file___36 *, void *);
	void * (*seq_start)(struct seq_file___36 *, loff_t *);
	void * (*seq_next)(struct seq_file___36 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___36 *, void *);
	ssize_t (*read)(struct kernfs_open_file___36 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___36 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___36 *, struct vm_area_struct___39 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___36 *, struct poll_table_struct___25 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___36 {
	int (*remount_fs)(struct kernfs_root___36 *, int *, char *);
	int (*show_options)(struct seq_file___36 *, struct kernfs_root___36 *);
	int (*mkdir)(struct kernfs_node___36 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___36 *);
	int (*rename)(struct kernfs_node___36 *, struct kernfs_node___36 *, const char *);
	int (*show_path)(struct seq_file___36 *, struct kernfs_node___36 *, struct kernfs_root___36 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___36 {
	struct kernfs_node___36 *kn;
	struct file___39 *file;
	struct seq_file___36 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___38 *vm_ops;
};

struct bin_attribute___34;

struct attribute_group___34 {
	const char *name;
	umode_t (*is_visible)(struct kobject___37 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___37 *, struct bin_attribute___34 *, int);
	struct attribute **attrs;
	struct bin_attribute___34 **bin_attrs;
};

struct bin_attribute___34 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___39 *, struct kobject___37 *, struct bin_attribute___34 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___39 *, struct kobject___37 *, struct bin_attribute___34 *, char *, loff_t, size_t);
	int (*mmap)(struct file___39 *, struct kobject___37 *, struct bin_attribute___34 *, struct vm_area_struct___39 *);
};

struct sysfs_ops___36 {
	ssize_t (*show)(struct kobject___37 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___37 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___36;

struct kset___36 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___37 kobj;
	const struct kset_uevent_ops___36 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___36 {
	void (*release)(struct kobject___37 *);
	const struct sysfs_ops___36 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___2 * (*child_ns_type)(struct kobject___37 *);
	const void * (*namespace)(struct kobject___37 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___36 {
	int (* const filter)(struct kset___36 *, struct kobject___37 *);
	const char * (* const name)(struct kset___36 *, struct kobject___37 *);
	int (* const uevent)(struct kset___36 *, struct kobject___37 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___33 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___33 *);
	int (*get)(char *, const struct kernel_param___33 *);
	void (*free)(void *);
};

struct kparam_array___33;

struct kernel_param___33 {
	const char *name;
	struct module___36 *mod;
	const struct kernel_param_ops___33 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___33 *arr;
	};
};

struct kparam_array___33 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___33 *ops;
	void *elem;
};

struct module_attribute___33 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___33 *, struct module_kobject___33 *, char *);
	ssize_t (*store)(struct module_attribute___33 *, struct module_kobject___33 *, const char *, size_t);
	void (*setup)(struct module___36 *, const char *);
	int (*test)(struct module___36 *);
	void (*free)(struct module___36 *);
};

struct trace_event_class___19;

struct trace_event_call___19 {
	struct list_head list;
	struct trace_event_class___19 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___3 *prog_array;
	int (*perf_perm)(struct trace_event_call___19 *, struct perf_event___24 *);
};

struct dev_pm_ops___34 {
	int (*prepare)(struct device___34 *);
	void (*complete)(struct device___34 *);
	int (*suspend)(struct device___34 *);
	int (*resume)(struct device___34 *);
	int (*freeze)(struct device___34 *);
	int (*thaw)(struct device___34 *);
	int (*poweroff)(struct device___34 *);
	int (*restore)(struct device___34 *);
	int (*suspend_late)(struct device___34 *);
	int (*resume_early)(struct device___34 *);
	int (*freeze_late)(struct device___34 *);
	int (*thaw_early)(struct device___34 *);
	int (*poweroff_late)(struct device___34 *);
	int (*restore_early)(struct device___34 *);
	int (*suspend_noirq)(struct device___34 *);
	int (*resume_noirq)(struct device___34 *);
	int (*freeze_noirq)(struct device___34 *);
	int (*thaw_noirq)(struct device___34 *);
	int (*poweroff_noirq)(struct device___34 *);
	int (*restore_noirq)(struct device___34 *);
	int (*runtime_suspend)(struct device___34 *);
	int (*runtime_resume)(struct device___34 *);
	int (*runtime_idle)(struct device___34 *);
};

struct dev_pm_domain___34 {
	struct dev_pm_ops___34 ops;
	void (*detach)(struct device___34 *, bool);
	int (*activate)(struct device___34 *);
	void (*sync)(struct device___34 *);
	void (*dismiss)(struct device___34 *);
};

struct bus_type___34 {
	const char *name;
	const char *dev_name;
	struct device___34 *dev_root;
	const struct attribute_group___34 **bus_groups;
	const struct attribute_group___34 **dev_groups;
	const struct attribute_group___34 **drv_groups;
	int (*match)(struct device___34 *, struct device_driver___34 *);
	int (*uevent)(struct device___34 *, struct kobj_uevent_env *);
	int (*probe)(struct device___34 *);
	int (*remove)(struct device___34 *);
	void (*shutdown)(struct device___34 *);
	int (*online)(struct device___34 *);
	int (*offline)(struct device___34 *);
	int (*suspend)(struct device___34 *, pm_message_t);
	int (*resume)(struct device___34 *);
	int (*num_vf)(struct device___34 *);
	int (*dma_configure)(struct device___34 *);
	const struct dev_pm_ops___34 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___34 {
	const char *name;
	struct bus_type___34 *bus;
	struct module___36 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___34 *);
	int (*remove)(struct device___34 *);
	void (*shutdown)(struct device___34 *);
	int (*suspend)(struct device___34 *, pm_message_t);
	int (*resume)(struct device___34 *);
	const struct attribute_group___34 **groups;
	const struct dev_pm_ops___34 *pm;
	void (*coredump)(struct device___34 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___34 {
	const char *name;
	const struct attribute_group___34 **groups;
	int (*uevent)(struct device___34 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___34 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___34 *);
	const struct dev_pm_ops___34 *pm;
};

struct class___34 {
	const char *name;
	struct module___36 *owner;
	const struct attribute_group___34 **class_groups;
	const struct attribute_group___34 **dev_groups;
	struct kobject___37 *dev_kobj;
	int (*dev_uevent)(struct device___34 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___34 *, umode_t *);
	void (*class_release)(struct class___34 *);
	void (*dev_release)(struct device___34 *);
	int (*shutdown_pre)(struct device___34 *);
	const struct kobj_ns_type_operations___2 *ns_type;
	const void * (*namespace)(struct device___34 *);
	const struct dev_pm_ops___34 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___32 {
	struct device___34 dev;
};

struct bpf_map___28;

struct bpf_map_ops___28 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___28 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___28 *, struct file___39 *);
	void (*map_free)(struct bpf_map___28 *);
	int (*map_get_next_key)(struct bpf_map___28 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___28 *);
	void * (*map_lookup_elem)(struct bpf_map___28 *, void *);
	int (*map_update_elem)(struct bpf_map___28 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___28 *, void *);
	int (*map_push_elem)(struct bpf_map___28 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___28 *, void *);
	int (*map_peek_elem)(struct bpf_map___28 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___28 *, struct file___39 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___28 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___28 *, void *, struct seq_file___36 *);
	int (*map_check_btf)(const struct bpf_map___28 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___28 {
	const struct bpf_map_ops___28 *ops;
	struct bpf_map___28 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___38 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___28;

typedef void (*kthread_work_func_t___28)(struct kthread_work___28 *);

struct kthread_worker___28;

struct kthread_work___28 {
	struct list_head node;
	kthread_work_func_t___28 func;
	struct kthread_worker___28 *worker;
	int canceling;
};

struct kthread_worker___28 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___40 *task;
	struct kthread_work___28 *current_work;
};

struct kthread_delayed_work___28 {
	struct kthread_work___28 work;
	struct timer_list timer;
};

struct psi_group___28 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___28 *poll_kworker;
	struct kthread_delayed_work___28 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___28 {
	struct kernfs_node___36 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___28;

struct cgroup_subsys_state___28 {
	struct cgroup___28 *cgroup;
	struct cgroup_subsys___28 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___28 *parent;
};

struct cgroup_root___28;

struct cgroup_rstat_cpu___28;

struct cgroup___28 {
	struct cgroup_subsys_state___28 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___36 *kn;
	struct cgroup_file___28 procs_file;
	struct cgroup_file___28 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___28 *subsys[13];
	struct cgroup_root___28 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___28 *dom_cgrp;
	struct cgroup_rstat_cpu___28 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___3 bpf;
	atomic_t congestion_count;
	struct cgroup___28 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___28 psi;
	int ancestor_ids[0];
};

struct cftype___28;

struct cgroup_subsys___28 {
	struct cgroup_subsys_state___28 * (*css_alloc)(struct cgroup_subsys_state___28 *);
	int (*css_online)(struct cgroup_subsys_state___28 *);
	void (*css_offline)(struct cgroup_subsys_state___28 *);
	void (*css_released)(struct cgroup_subsys_state___28 *);
	void (*css_free)(struct cgroup_subsys_state___28 *);
	void (*css_reset)(struct cgroup_subsys_state___28 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___28 *, int);
	int (*css_extra_stat_show)(struct seq_file___36 *, struct cgroup_subsys_state___28 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___40 *);
	void (*cancel_fork)(struct task_struct___40 *);
	void (*fork)(struct task_struct___40 *);
	void (*exit)(struct task_struct___40 *);
	void (*free)(struct task_struct___40 *);
	void (*bind)(struct cgroup_subsys_state___28 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___28 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___28 *dfl_cftypes;
	struct cftype___28 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___28 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___28 *updated_children;
	struct cgroup___28 *updated_next;
};

struct cgroup_root___28 {
	struct kernfs_root___36 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___28 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___28 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___28 *ss;
	struct list_head node;
	struct kernfs_ops___36 *kf_ops;
	int (*open)(struct kernfs_open_file___36 *);
	void (*release)(struct kernfs_open_file___36 *);
	u64 (*read_u64)(struct cgroup_subsys_state___28 *, struct cftype___28 *);
	s64 (*read_s64)(struct cgroup_subsys_state___28 *, struct cftype___28 *);
	int (*seq_show)(struct seq_file___36 *, void *);
	void * (*seq_start)(struct seq_file___36 *, loff_t *);
	void * (*seq_next)(struct seq_file___36 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___36 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___28 *, struct cftype___28 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___28 *, struct cftype___28 *, s64);
	ssize_t (*write)(struct kernfs_open_file___36 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___36 *, struct poll_table_struct___25 *);
};

struct perf_cpu_context___24;

struct pmu___24 {
	struct list_head entry;
	struct module___36 *module;
	struct device___34 *dev;
	const struct attribute_group___34 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___24 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___24 *);
	void (*pmu_disable)(struct pmu___24 *);
	int (*event_init)(struct perf_event___24 *);
	void (*event_mapped)(struct perf_event___24 *, struct mm_struct___2 *);
	void (*event_unmapped)(struct perf_event___24 *, struct mm_struct___2 *);
	int (*add)(struct perf_event___24 *, int);
	void (*del)(struct perf_event___24 *, int);
	void (*start)(struct perf_event___24 *, int);
	void (*stop)(struct perf_event___24 *, int);
	void (*read)(struct perf_event___24 *);
	void (*start_txn)(struct pmu___24 *, unsigned int);
	int (*commit_txn)(struct pmu___24 *);
	void (*cancel_txn)(struct pmu___24 *);
	int (*event_idx)(struct perf_event___24 *);
	void (*sched_task)(struct perf_event_context___24 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___24 *);
	int (*filter_match)(struct perf_event___24 *);
	int (*check_period)(struct perf_event___24 *, u64);
};

struct perf_cpu_context___24 {
	struct perf_event_context___24 ctx;
	struct perf_event_context___24 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___24 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___24 {
	struct cgroup_subsys_state___28 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___19 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___19 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___19 *);
	struct list_head * (*get_fields)(struct trace_event_call___19 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___19 *);
};

struct syscall_metadata___8 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___19 *enter_event;
	struct trace_event_call___19 *exit_event;
};

struct user_regset___2;

typedef int user_regset_active_fn___2(struct task_struct___40 *, const struct user_regset___2 *);

typedef int user_regset_get_fn___2(struct task_struct___40 *, const struct user_regset___2 *, unsigned int, unsigned int, void *, void *);

typedef int user_regset_set_fn___2(struct task_struct___40 *, const struct user_regset___2 *, unsigned int, unsigned int, const void *, const void *);

typedef int user_regset_writeback_fn___2(struct task_struct___40 *, const struct user_regset___2 *, int);

typedef unsigned int user_regset_get_size_fn___2(struct task_struct___40 *, const struct user_regset___2 *);

struct user_regset___2 {
	user_regset_get_fn___2 *get;
	user_regset_set_fn___2 *set;
	user_regset_active_fn___2 *active;
	user_regset_writeback_fn___2 *writeback;
	user_regset_get_size_fn___2 *get_size;
	unsigned int n;
	unsigned int size;
	unsigned int align;
	unsigned int bias;
	unsigned int core_note_type;
};

struct user_regset_view___2 {
	const char *name;
	const struct user_regset___2 *regsets;
	unsigned int n;
	u32 e_flags;
	u16 e_machine;
	u8 ei_osabi;
};

struct proc_ns_operations___3;

struct ns_common___3 {
	atomic_long_t stashed;
	const struct proc_ns_operations___3 *ops;
	unsigned int inum;
};

struct ucounts___30;

struct user_namespace___30 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___30 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___3 ns;
	long unsigned int flags;
	struct key___39 *persistent_keyring_register;
	struct rw_semaphore___39 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___30 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct proc_ns_operations___3 {
	const char *name;
	const char *real_ns_name;
	int type;
	struct ns_common___3 * (*get)(struct task_struct___40 *);
	void (*put)(struct ns_common___3 *);
	int (*install)(struct nsproxy___37 *, struct ns_common___3 *);
	struct user_namespace___30 * (*owner)(struct ns_common___3 *);
	struct ns_common___3 * (*get_parent)(struct ns_common___3 *);
};

struct ucounts___30 {
	struct hlist_node node;
	struct user_namespace___30 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct seq_file___37;

struct seq_operations___34 {
	void * (*start)(struct seq_file___37 *, loff_t *);
	void (*stop)(struct seq_file___37 *, void *);
	void * (*next)(struct seq_file___37 *, void *, loff_t *);
	int (*show)(struct seq_file___37 *, void *);
};

typedef int __kernel_mqd_t;

typedef __kernel_mqd_t mqd_t;

struct module___37;

struct file___40;

struct kiocb___40;

struct iov_iter___17;

struct poll_table_struct___26;

struct vm_area_struct___40;

struct inode___42;

struct file_lock___40;

struct page___40;

struct pipe_inode_info___8;

struct seq_file___38;

struct file_operations___40 {
	struct module___37 *owner;
	loff_t (*llseek)(struct file___40 *, loff_t, int);
	ssize_t (*read)(struct file___40 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___40 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___40 *, struct iov_iter___17 *);
	ssize_t (*write_iter)(struct kiocb___40 *, struct iov_iter___17 *);
	int (*iopoll)(struct kiocb___40 *, bool);
	int (*iterate)(struct file___40 *, struct dir_context *);
	int (*iterate_shared)(struct file___40 *, struct dir_context *);
	__poll_t (*poll)(struct file___40 *, struct poll_table_struct___26 *);
	long int (*unlocked_ioctl)(struct file___40 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___40 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___40 *, struct vm_area_struct___40 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___42 *, struct file___40 *);
	int (*flush)(struct file___40 *, fl_owner_t);
	int (*release)(struct inode___42 *, struct file___40 *);
	int (*fsync)(struct file___40 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___40 *, int);
	int (*lock)(struct file___40 *, int, struct file_lock___40 *);
	ssize_t (*sendpage)(struct file___40 *, struct page___40 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___40 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___40 *, int, struct file_lock___40 *);
	ssize_t (*splice_write)(struct pipe_inode_info___8 *, struct file___40 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___40 *, loff_t *, struct pipe_inode_info___8 *, size_t, unsigned int);
	int (*setlease)(struct file___40 *, long int, struct file_lock___40 **, void **);
	long int (*fallocate)(struct file___40 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___38 *, struct file___40 *);
	ssize_t (*copy_file_range)(struct file___40 *, loff_t, struct file___40 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___40 *, loff_t, struct file___40 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___40 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___39 {
	u64 seqnum;
	struct vm_area_struct___40 *vmas[4];
};

struct page_frag___39 {
	struct page___40 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___25;

struct debug_info___25 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___25 *hbp_break[16];
	struct perf_event___25 *hbp_watch[16];
};

struct thread_struct___25 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___25 debug;
	long: 64;
};

struct mm_struct___39;

struct mem_cgroup___14;

struct pid___35;

struct cred___39;

struct nsproxy___38;

struct signal_struct___37;

struct bio_list___15;

struct backing_dev_info___15;

struct io_context___9;

struct css_set___29;

struct perf_event_context___25;

struct request_queue___10;

struct vm_struct___31;

struct task_struct___41 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___41 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___39 *mm;
	struct mm_struct___39 *active_mm;
	struct vmacache___39 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___41 *real_parent;
	struct task_struct___41 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___41 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___14 *active_memcg;
	long int rh_reserved2;
	struct pid___35 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___35 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___35 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___39 *ptracer_cred;
	const struct cred___39 *real_cred;
	const struct cred___39 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___38 *nsproxy;
	struct signal_struct___37 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___41 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___15 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___15 *backing_dev_info;
	struct io_context___9 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___29 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___25 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___8 *splice_pipe;
	struct page_frag___39 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___14 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___10 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___41 *oom_reaper_list;
	struct vm_struct___31 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___25 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___25 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___41 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___25)(struct perf_event___25 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___25;

struct fasync_struct___39;

struct pid_namespace___35;

struct trace_event_call___20;

struct perf_cgroup___25;

struct perf_event___25 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___25 *group_leader;
	struct pmu___25 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___25 hw;
	struct perf_event_context___25 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___25 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___41 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___39 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___25 *);
	struct callback_head callback_head;
	struct pid_namespace___35 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___25 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___25 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___20 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___25 *cgrp;
	struct list_head sb_list;
};

typedef struct page___40 *pgtable_t___39;

struct address_space___39;

struct dev_pagemap___39;

struct page___40 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___39 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___40 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___39 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___39 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___39 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___14 *mem_cgroup;
};

struct pglist_data___39;

struct lruvec___39 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___39 *pgdat;
};

struct zone___39 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___39 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___39 {
	struct zone___39 *zone;
	int zone_idx;
};

struct zonelist___39 {
	struct zoneref___39 _zonerefs[25];
};

struct pglist_data___39 {
	struct zone___39 node_zones[3];
	struct zonelist___39 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___41 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___41 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___39 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___40 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___41 *owner;
};

struct secondary_data___40 {
	void *stack;
	struct task_struct___41 *task;
	long int status;
};

struct blocking_notifier_head___39 {
	struct rw_semaphore___40 rwsem;
	struct notifier_block *head;
};

struct cgroup___29;

struct cgroup_subsys___29;

struct cgroup_subsys_state___29 {
	struct cgroup___29 *cgroup;
	struct cgroup_subsys___29 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___29 *parent;
};

struct kernfs_node___37;

struct cgroup_file___29 {
	struct kernfs_node___37 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___14;

struct mem_cgroup___14 {
	struct cgroup_subsys_state___29 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___29 events_file;
	struct cgroup_file___29 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___41 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___14 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct upid___35 {
	int nr;
	struct pid_namespace___35 *ns;
};

struct dentry___41;

struct user_namespace___31;

struct ucounts___31;

struct pid_namespace___35 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___41 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___35 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___41 *proc_self;
	struct dentry___41 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___31 *user_ns;
	struct ucounts___31 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___3 ns;
};

struct pid___35 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___35 numbers[1];
};

struct key___40;

struct user_namespace___31 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___31 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___3 ns;
	long unsigned int flags;
	struct key___40 *persistent_keyring_register;
	struct rw_semaphore___40 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___31 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct user_struct___39;

struct sigqueue___2 {
	struct list_head list;
	int flags;
	kernel_siginfo_t info;
	struct user_struct___39 *user;
};

struct user_struct___39 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___40 *uid_keyring;
	struct key___40 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___39;

struct vm_area_struct___40 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___40 *vm_next;
	struct vm_area_struct___40 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___39 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___39 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___40 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct linux_binfmt___6;

struct core_state___39;

struct mm_struct___39 {
	struct {
		struct vm_area_struct___40 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___40 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___40 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___6 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___39 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___41 *owner;
		struct user_namespace___31 *user_ns;
		struct file___40 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___39 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___39 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___40 *session_keyring;
	struct key___40 *process_keyring;
	struct key___40 *thread_keyring;
	struct key___40 *request_key_auth;
	void *security;
	struct user_struct___39 *user;
	struct user_namespace___31 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___29;

struct nsproxy___38 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___35 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___29 *cgroup_ns;
};

struct tty_struct___5;

struct signal_struct___37 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___41 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___41 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___35 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___35 *tty_old_pgrp;
	int leader;
	struct tty_struct___5 *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___39 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___35 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

enum audit_state {
	AUDIT_DISABLED = 0,
	AUDIT_BUILD_CONTEXT = 1,
	AUDIT_RECORD_CONTEXT = 2,
};

struct audit_cap_data {
	kernel_cap_t permitted;
	kernel_cap_t inheritable;
	union {
		unsigned int fE;
		kernel_cap_t effective;
	};
	kernel_cap_t ambient;
};

struct filename;

struct audit_names {
	struct list_head list;
	struct filename *name;
	int name_len;
	bool hidden;
	long unsigned int ino;
	dev_t dev;
	umode_t mode;
	kuid_t uid;
	kgid_t gid;
	dev_t rdev;
	u32 osid;
	struct audit_cap_data fcap;
	unsigned int fcap_ver;
	unsigned char type;
	bool should_free;
};

struct path___39 {
	struct vfsmount *mnt;
	struct dentry___41 *dentry;
};

struct audit_aux_data;

struct audit_tree_refs;

struct mq_attr {
	__kernel_long_t mq_flags;
	__kernel_long_t mq_maxmsg;
	__kernel_long_t mq_msgsize;
	__kernel_long_t mq_curmsgs;
	__kernel_long_t __reserved[4];
};

struct audit_proctitle {
	int len;
	char *value;
};

struct audit_context {
	int dummy;
	int in_syscall;
	enum audit_state state;
	enum audit_state current_state;
	unsigned int serial;
	int major;
	struct timespec64 ctime;
	long unsigned int argv[4];
	long int return_code;
	u64 prio;
	int return_valid;
	struct audit_names preallocated_names[5];
	int name_count;
	struct list_head names_list;
	char *filterkey;
	struct path___39 pwd;
	struct audit_aux_data *aux;
	struct audit_aux_data *aux_pids;
	struct __kernel_sockaddr_storage *sockaddr;
	size_t sockaddr_len;
	pid_t pid;
	pid_t ppid;
	kuid_t uid;
	kuid_t euid;
	kuid_t suid;
	kuid_t fsuid;
	kgid_t gid;
	kgid_t egid;
	kgid_t sgid;
	kgid_t fsgid;
	long unsigned int personality;
	int arch;
	pid_t target_pid;
	kuid_t target_auid;
	kuid_t target_uid;
	unsigned int target_sessionid;
	u32 target_sid;
	char target_comm[16];
	struct audit_tree_refs *trees;
	struct audit_tree_refs *first_trees;
	struct list_head killed_trees;
	int tree_count;
	int type;
	union {
		struct {
			int nargs;
			long int args[6];
		} socketcall;
		struct {
			kuid_t uid;
			kgid_t gid;
			umode_t mode;
			u32 osid;
			int has_perm;
			uid_t perm_uid;
			gid_t perm_gid;
			umode_t perm_mode;
			long unsigned int qbytes;
		} ipc;
		struct {
			mqd_t mqdes;
			struct mq_attr mqstat;
		} mq_getsetattr;
		struct {
			mqd_t mqdes;
			int sigev_signo;
		} mq_notify;
		struct {
			mqd_t mqdes;
			size_t msg_len;
			unsigned int msg_prio;
			struct timespec64 abs_timeout;
		} mq_sendrecv;
		struct {
			int oflag;
			umode_t mode;
			struct mq_attr attr;
		} mq_open;
		struct {
			pid_t pid;
			struct audit_cap_data cap;
		} capset;
		struct {
			int fd;
			int flags;
		} mmap;
		struct {
			int argc;
		} execve;
		struct {
			char *name;
		} module;
	};
	int fds[2];
	struct audit_proctitle proctitle;
};

struct bio___15;

struct bio_list___15 {
	struct bio___15 *head;
	struct bio___15 *tail;
};

struct bdi_writeback_congested___15;

struct bdi_writeback___15 {
	struct backing_dev_info___15 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___15 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___29 *memcg_css;
	struct cgroup_subsys_state___29 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___35;

struct backing_dev_info___15 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___15 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___35 *dev;
	struct device___35 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___41 *debug_dir;
	struct dentry___41 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___9;

struct io_context___9 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___9 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___29 {
	struct cgroup_subsys_state___29 *subsys[13];
	refcount_t refcount;
	struct css_set___29 *dom_cset;
	struct cgroup___29 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___29 *mg_src_cgrp;
	struct cgroup___29 *mg_dst_cgrp;
	struct css_set___29 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___25 {
	struct pmu___25 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___41 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___25 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___8;

struct pipe_inode_info___8 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___40 *tmp_page;
	struct fasync_struct___39 *fasync_readers;
	struct fasync_struct___39 *fasync_writers;
	struct pipe_buffer___8 *bufs;
	struct user_struct___39 *user;
};

typedef blk_qc_t make_request_fn___9(struct request_queue___10 *, struct bio___15 *);

struct request___10;

typedef int dma_drain_needed_fn___9(struct request___10 *);

struct kset___37;

struct kobj_type___37;

struct kobject___38 {
	const char *name;
	struct list_head entry;
	struct kobject___38 *parent;
	struct kset___37 *kset;
	struct kobj_type___37 *ktype;
	struct kernfs_node___37 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___9;

struct bsg_class_device___9 {
	struct device___35 *class_dev;
	int minor;
	struct request_queue___10 *queue;
	const struct bsg_ops___9 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___15 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___15 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___9;

struct blkcg_gq___6;

struct request_queue___10 {
	struct list_head queue_head;
	struct request___10 *last_merge;
	struct elevator_queue___9 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___9 *make_request_fn;
	dma_drain_needed_fn___9 *dma_drain_needed;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___15 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___38 kobj;
	struct kobject___38 *mq_kobj;
	struct blk_integrity integrity;
	struct device___35 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___6 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide38;
		union {		};
	};
	struct bsg_class_device___9 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___15 bio_split;
	struct dentry___41 *debugfs_dir;
	struct dentry___41 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___31 {
	struct vm_struct___31 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___40 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___37 {
	struct task_struct___41 task;
	long unsigned int stack[8192];
};

struct address_space_operations___39;

struct address_space___39 {
	struct inode___42 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___40 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___39 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___39)(struct vm_area_struct___40 *, long unsigned int, const struct page___40 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___39)(struct page___40 *, void *);

struct dev_pagemap___39 {
	dev_page_fault_t___39 page_fault;
	dev_page_free_t___39 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___35 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct fown_struct___35 {
	rwlock_t lock;
	struct pid___35 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___40 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___39 f_path;
	struct inode___42 *f_inode;
	const struct file_operations___40 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___35 f_owner;
	const struct cred___39 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___39 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___39;

struct vm_operations_struct___39 {
	void (*open)(struct vm_area_struct___40 *);
	void (*close)(struct vm_area_struct___40 *);
	int (*split)(struct vm_area_struct___40 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___40 *);
	vm_fault_t (*fault)(struct vm_fault___39 *);
	vm_fault_t (*huge_fault)(struct vm_fault___39 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___39 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___40 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___39 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___39 *);
	int (*access)(struct vm_area_struct___40 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___40 *);
	int (*set_policy)(struct vm_area_struct___40 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___40 *, long unsigned int);
	struct page___40 * (*find_special_page)(struct vm_area_struct___40 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___39 {
	struct task_struct___41 *task;
	struct core_thread___39 *next;
};

struct core_state___39 {
	atomic_t nr_threads;
	struct core_thread___39 dumper;
	struct completion startup;
};

struct linux_binprm___6;

struct coredump_params___5;

struct linux_binfmt___6 {
	struct list_head lh;
	struct module___37 *module;
	int (*load_binary)(struct linux_binprm___6 *);
	int (*load_shlib)(struct file___40 *);
	int (*core_dump)(struct coredump_params___5 *);
	long unsigned int min_coredump;
};

struct vm_fault___39 {
	struct vm_area_struct___40 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___40 *cow_page;
	struct mem_cgroup___14 *memcg;
	struct page___40 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___39 prealloc_pte;
};

struct key_restriction___40;

struct key___40 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___40 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___40 *restrict_link;
};

typedef int (*key_restrict_link_func_t___39)(struct key___40 *, const struct key_type *, const union key_payload *, struct key___40 *);

struct key_restriction___40 {
	key_restrict_link_func_t___39 check;
	struct key___40 *key;
	struct key_type *keytype;
};

struct tty_driver___6;

struct tty_operations___5;

struct tty_ldisc___5;

struct tty_port___5;

struct tty_struct___5 {
	int magic;
	struct kref kref;
	struct device___35 *dev;
	struct tty_driver___6 *driver;
	const struct tty_operations___5 *ops;
	int index;
	struct ld_semaphore ldisc_sem;
	struct tty_ldisc___5 *ldisc;
	struct mutex atomic_write_lock;
	struct mutex legacy_mutex;
	struct mutex throttle_mutex;
	struct rw_semaphore___40 termios_rwsem;
	struct mutex winsize_mutex;
	spinlock_t ctrl_lock;
	spinlock_t flow_lock;
	struct ktermios termios;
	struct ktermios termios_locked;
	struct termiox *termiox;
	char name[64];
	struct pid___35 *pgrp;
	struct pid___35 *session;
	long unsigned int flags;
	int count;
	struct winsize winsize;
	long unsigned int stopped: 1;
	long unsigned int flow_stopped: 1;
	int: 30;
	long unsigned int unused: 62;
	int hw_stopped;
	long unsigned int ctrl_status: 8;
	long unsigned int packet: 1;
	int: 23;
	long unsigned int unused_ctrl: 55;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___5 *link;
	struct fasync_struct___39 *fasync;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	spinlock_t files_lock;
	struct list_head tty_files;
	int closing;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___5 *port;
};

struct dentry_operations___39;

struct super_block___40;

struct dentry___41 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___41 *d_parent;
	struct qstr d_name;
	struct inode___42 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___39 *d_op;
	struct super_block___40 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___39;

struct block_device___40;

struct cdev___12;

struct inode___42 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___39 *i_op;
	struct super_block___40 *i_sb;
	struct address_space___39 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___40 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___15 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___40 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___39 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___8 *i_pipe;
		struct block_device___40 *i_bdev;
		struct cdev___12 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___39 {
	int (*d_revalidate)(struct dentry___41 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___41 *, unsigned int);
	int (*d_hash)(const struct dentry___41 *, struct qstr *);
	int (*d_compare)(const struct dentry___41 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___41 *);
	int (*d_init)(struct dentry___41 *);
	void (*d_release)(struct dentry___41 *);
	void (*d_prune)(struct dentry___41 *);
	void (*d_iput)(struct dentry___41 *, struct inode___42 *);
	char * (*d_dname)(struct dentry___41 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___39 *);
	int (*d_manage)(const struct path___39 *, bool);
	struct dentry___41 * (*d_real)(struct dentry___41 *, const struct inode___42 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___39;

struct mem_dqinfo___39 {
	struct quota_format_type___39 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___39;

struct quota_info___39 {
	unsigned int flags;
	struct rw_semaphore___40 dqio_sem;
	struct inode___42 *files[3];
	struct mem_dqinfo___39 info[3];
	const struct quota_format_ops___39 *ops[3];
};

struct rcuwait___39 {
	struct task_struct___41 *task;
};

struct percpu_rw_semaphore___39 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___40 rw_sem;
	struct rcuwait___39 writer;
	int readers_block;
};

struct sb_writers___39 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___39 rw_sem[3];
};

struct shrink_control___14;

struct shrinker___14 {
	long unsigned int (*count_objects)(struct shrinker___14 *, struct shrink_control___14 *);
	long unsigned int (*scan_objects)(struct shrinker___14 *, struct shrink_control___14 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___39;

struct super_operations___39;

struct dquot_operations___39;

struct quotactl_ops___39;

struct super_block___40 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___39 *s_type;
	const struct super_operations___39 *s_op;
	const struct dquot_operations___39 *dq_op;
	const struct quotactl_ops___39 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___41 *s_root;
	struct rw_semaphore___40 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___40 *s_bdev;
	struct backing_dev_info___15 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___39 s_dquot;
	struct sb_writers___39 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___39 *s_d_op;
	int cleancache_poolid;
	struct shrinker___14 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___31 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___14 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___14 *memcg;
};

struct io_cq___9 {
	struct request_queue___10 *q;
	struct io_context___9 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___40 {
	struct file___40 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___40 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___40 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___40 *ia_file;
};

struct dquot___39 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___40 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___39 {
	int qf_fmt_id;
	const struct quota_format_ops___39 *qf_ops;
	struct module___37 *qf_owner;
	struct quota_format_type___39 *qf_next;
};

struct quota_format_ops___39 {
	int (*check_quota_file)(struct super_block___40 *, int);
	int (*read_file_info)(struct super_block___40 *, int);
	int (*write_file_info)(struct super_block___40 *, int);
	int (*free_file_info)(struct super_block___40 *, int);
	int (*read_dqblk)(struct dquot___39 *);
	int (*commit_dqblk)(struct dquot___39 *);
	int (*release_dqblk)(struct dquot___39 *);
	int (*get_next_id)(struct super_block___40 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___39 {
	int (*write_dquot)(struct dquot___39 *);
	struct dquot___39 * (*alloc_dquot)(struct super_block___40 *, int);
	void (*destroy_dquot)(struct dquot___39 *);
	int (*acquire_dquot)(struct dquot___39 *);
	int (*release_dquot)(struct dquot___39 *);
	int (*mark_dirty)(struct dquot___39 *);
	int (*write_info)(struct super_block___40 *, int);
	qsize_t * (*get_reserved_space)(struct inode___42 *);
	int (*get_projid)(struct inode___42 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___42 *, qsize_t *);
	int (*get_next_id)(struct super_block___40 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___39 {
	int (*quota_on)(struct super_block___40 *, int, int, const struct path___39 *);
	int (*quota_off)(struct super_block___40 *, int);
	int (*quota_enable)(struct super_block___40 *, unsigned int);
	int (*quota_disable)(struct super_block___40 *, unsigned int);
	int (*quota_sync)(struct super_block___40 *, int);
	int (*set_info)(struct super_block___40 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___40 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___40 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___40 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___40 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___40 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___34 {
	struct kobject___38 kobj;
	struct module___37 *mod;
	struct kobject___38 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___34 {
	struct module___37 *mod;
	struct latch_tree_node node;
};

struct module_layout___34 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___34 mtn;
};

struct module_attribute___34;

struct kernel_param___34;

struct module___37 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___34 mkobj;
	struct module_attribute___34 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___38 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___34 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___34 core_layout;
	struct module_layout___34 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___20 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___14;

struct address_space_operations___39 {
	int (*writepage)(struct page___40 *, struct writeback_control___14 *);
	int (*readpage)(struct file___40 *, struct page___40 *);
	int (*writepages)(struct address_space___39 *, struct writeback_control___14 *);
	int (*set_page_dirty)(struct page___40 *);
	int (*readpages)(struct file___40 *, struct address_space___39 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___40 *, struct address_space___39 *, loff_t, unsigned int, unsigned int, struct page___40 **, void **);
	int (*write_end)(struct file___40 *, struct address_space___39 *, loff_t, unsigned int, unsigned int, struct page___40 *, void *);
	sector_t (*bmap)(struct address_space___39 *, sector_t);
	void (*invalidatepage)(struct page___40 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___40 *, gfp_t);
	void (*freepage)(struct page___40 *);
	ssize_t (*direct_IO)(struct kiocb___40 *, struct iov_iter___17 *);
	int (*migratepage)(struct address_space___39 *, struct page___40 *, struct page___40 *, enum migrate_mode);
	bool (*isolate_page)(struct page___40 *, isolate_mode_t);
	void (*putback_page)(struct page___40 *);
	int (*launder_page)(struct page___40 *);
	int (*is_partially_uptodate)(struct page___40 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___40 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___39 *, struct page___40 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___40 *, sector_t *);
	void (*swap_deactivate)(struct file___40 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___14 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___15 *wb;
	struct inode___42 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___15;

struct iov_iter___17 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___15 *bvec;
		struct pipe_inode_info___8 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct hd_struct___9;

struct gendisk___9;

struct block_device___40 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___42 *bd_inode;
	struct super_block___40 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___40 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___9 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___9 *bd_disk;
	struct request_queue___10 *bd_queue;
	struct backing_dev_info___15 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___35 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___35 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___35;

struct bus_type___35;

struct device_driver___35;

struct dev_pm_domain___35;

struct dma_map_ops___10;

struct fwnode_handle___28;

struct class___35;

struct attribute_group___35;

struct device___35 {
	struct device___35 *parent;
	struct device_private *p;
	struct kobject___38 kobj;
	const char *init_name;
	const struct device_type___35 *type;
	struct mutex mutex;
	struct bus_type___35 *bus;
	struct device_driver___35 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___35 power;
	struct dev_pm_domain___35 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___10 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___28 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___35 *class;
	const struct attribute_group___35 **groups;
	void (*release)(struct device___35 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___9 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___35 __dev;
	struct kobject___38 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___9;

struct block_device_operations___9;

struct gendisk___9 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___9 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___9 *part_tbl;
	struct hd_struct___9 part0;
	const struct block_device_operations___9 *fops;
	struct request_queue___10 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___40 lookup_sem;
	struct kobject___38 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___38 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___12 {
	struct kobject___38 kobj;
	struct module___37 *owner;
	const struct file_operations___40 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___39 {
	struct dentry___41 * (*lookup)(struct inode___42 *, struct dentry___41 *, unsigned int);
	const char * (*get_link)(struct dentry___41 *, struct inode___42 *, struct delayed_call *);
	int (*permission)(struct inode___42 *, int);
	struct posix_acl * (*get_acl)(struct inode___42 *, int);
	int (*readlink)(struct dentry___41 *, char *, int);
	int (*create)(struct inode___42 *, struct dentry___41 *, umode_t, bool);
	int (*link)(struct dentry___41 *, struct inode___42 *, struct dentry___41 *);
	int (*unlink)(struct inode___42 *, struct dentry___41 *);
	int (*symlink)(struct inode___42 *, struct dentry___41 *, const char *);
	int (*mkdir)(struct inode___42 *, struct dentry___41 *, umode_t);
	int (*rmdir)(struct inode___42 *, struct dentry___41 *);
	int (*mknod)(struct inode___42 *, struct dentry___41 *, umode_t, dev_t);
	int (*rename)(struct inode___42 *, struct dentry___41 *, struct inode___42 *, struct dentry___41 *, unsigned int);
	int (*setattr)(struct dentry___41 *, struct iattr___40 *);
	int (*getattr)(const struct path___39 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___41 *, char *, size_t);
	int (*fiemap)(struct inode___42 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___42 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___42 *, struct dentry___41 *, struct file___40 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___42 *, struct dentry___41 *, umode_t);
	int (*set_acl)(struct inode___42 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___39 {
	void (*fl_copy_lock)(struct file_lock___40 *, struct file_lock___40 *);
	void (*fl_release_private)(struct file_lock___40 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___39;

struct file_lock___40 {
	struct file_lock___40 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___40 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___39 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___39 *fl_ops;
	const struct lock_manager_operations___39 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___39 {
	int (*lm_compare_owner)(struct file_lock___40 *, struct file_lock___40 *);
	long unsigned int (*lm_owner_key)(struct file_lock___40 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___40 *);
	int (*lm_grant)(struct file_lock___40 *, int);
	bool (*lm_break)(struct file_lock___40 *);
	int (*lm_change)(struct file_lock___40 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___40 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___39 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___39 *fa_next;
	struct file___40 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___39 {
	const char *name;
	int fs_flags;
	struct dentry___41 * (*mount)(struct file_system_type___39 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___40 *);
	struct module___37 *owner;
	struct file_system_type___39 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___39 {
	struct inode___42 * (*alloc_inode)(struct super_block___40 *);
	void (*destroy_inode)(struct inode___42 *);
	void (*dirty_inode)(struct inode___42 *, int);
	int (*write_inode)(struct inode___42 *, struct writeback_control___14 *);
	int (*drop_inode)(struct inode___42 *);
	void (*evict_inode)(struct inode___42 *);
	void (*put_super)(struct super_block___40 *);
	int (*sync_fs)(struct super_block___40 *, int);
	int (*freeze_super)(struct super_block___40 *);
	int (*freeze_fs)(struct super_block___40 *);
	int (*thaw_super)(struct super_block___40 *);
	int (*unfreeze_fs)(struct super_block___40 *);
	int (*statfs)(struct dentry___41 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___40 *, int *, char *);
	void (*umount_begin)(struct super_block___40 *);
	int (*show_options)(struct seq_file___38 *, struct dentry___41 *);
	int (*show_devname)(struct seq_file___38 *, struct dentry___41 *);
	int (*show_path)(struct seq_file___38 *, struct dentry___41 *);
	int (*show_stats)(struct seq_file___38 *, struct dentry___41 *);
	ssize_t (*quota_read)(struct super_block___40 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___40 *, int, const char *, size_t, loff_t);
	struct dquot___39 ** (*get_dquots)(struct inode___42 *);
	int (*bdev_try_to_free_page)(struct super_block___40 *, struct page___40 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___40 *, struct shrink_control___14 *);
	long int (*free_cached_objects)(struct super_block___40 *, struct shrink_control___14 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___25)(struct file___40 *, wait_queue_head_t *, struct poll_table_struct___26 *);

struct poll_table_struct___26 {
	poll_queue_proc___25 _qproc;
	__poll_t _key;
};

struct seq_operations___35;

struct seq_file___38 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___35 *op;
	int poll_event;
	const struct file___40 *file;
	void *private;
};

struct filename {
	const char *name;
	const char *uptr;
	int refcnt;
	struct audit_names *aname;
	const char iname[0];
};

typedef void bio_end_io_t___15(struct bio___15 *);

struct bio_vec___15 {
	struct page___40 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___15;

struct bio___15 {
	struct bio___15 *bi_next;
	struct gendisk___9 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___15 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___6 *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___15 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___15 *bi_io_vec;
	struct bio_set___15 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___15 bi_inline_vecs[0];
};

struct kernfs_root___37;

struct kernfs_elem_dir___37 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___37 *root;
};

struct kernfs_syscall_ops___37;

struct kernfs_root___37 {
	struct kernfs_node___37 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___37 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___37 {
	struct kernfs_node___37 *target_kn;
};

struct kernfs_ops___37;

struct kernfs_elem_attr___37 {
	const struct kernfs_ops___37 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___37 *notify_next;
};

struct kernfs_node___37 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___37 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___37 dir;
		struct kernfs_elem_symlink___37 symlink;
		struct kernfs_elem_attr___37 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___37;

struct kernfs_ops___37 {
	int (*open)(struct kernfs_open_file___37 *);
	void (*release)(struct kernfs_open_file___37 *);
	int (*seq_show)(struct seq_file___38 *, void *);
	void * (*seq_start)(struct seq_file___38 *, loff_t *);
	void * (*seq_next)(struct seq_file___38 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___38 *, void *);
	ssize_t (*read)(struct kernfs_open_file___37 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___37 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___37 *, struct vm_area_struct___40 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___37 *, struct poll_table_struct___26 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___37 {
	int (*remount_fs)(struct kernfs_root___37 *, int *, char *);
	int (*show_options)(struct seq_file___38 *, struct kernfs_root___37 *);
	int (*mkdir)(struct kernfs_node___37 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___37 *);
	int (*rename)(struct kernfs_node___37 *, struct kernfs_node___37 *, const char *);
	int (*show_path)(struct seq_file___38 *, struct kernfs_node___37 *, struct kernfs_root___37 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___37 {
	struct kernfs_node___37 *kn;
	struct file___40 *file;
	struct seq_file___38 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___39 *vm_ops;
};

struct bin_attribute___35;

struct attribute_group___35 {
	const char *name;
	umode_t (*is_visible)(struct kobject___38 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___38 *, struct bin_attribute___35 *, int);
	struct attribute **attrs;
	struct bin_attribute___35 **bin_attrs;
};

struct bin_attribute___35 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___40 *, struct kobject___38 *, struct bin_attribute___35 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___40 *, struct kobject___38 *, struct bin_attribute___35 *, char *, loff_t, size_t);
	int (*mmap)(struct file___40 *, struct kobject___38 *, struct bin_attribute___35 *, struct vm_area_struct___40 *);
};

struct sysfs_ops___37 {
	ssize_t (*show)(struct kobject___38 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___38 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___37;

struct kset___37 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___38 kobj;
	const struct kset_uevent_ops___37 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___37 {
	void (*release)(struct kobject___38 *);
	const struct sysfs_ops___37 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___2 * (*child_ns_type)(struct kobject___38 *);
	const void * (*namespace)(struct kobject___38 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___37 {
	int (* const filter)(struct kset___37 *, struct kobject___38 *);
	const char * (* const name)(struct kset___37 *, struct kobject___38 *);
	int (* const uevent)(struct kset___37 *, struct kobject___38 *, struct kobj_uevent_env *);
};

struct kobj_attribute___38 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___38 *, struct kobj_attribute___38 *, char *);
	ssize_t (*store)(struct kobject___38 *, struct kobj_attribute___38 *, const char *, size_t);
};

struct dev_pm_ops___35 {
	int (*prepare)(struct device___35 *);
	void (*complete)(struct device___35 *);
	int (*suspend)(struct device___35 *);
	int (*resume)(struct device___35 *);
	int (*freeze)(struct device___35 *);
	int (*thaw)(struct device___35 *);
	int (*poweroff)(struct device___35 *);
	int (*restore)(struct device___35 *);
	int (*suspend_late)(struct device___35 *);
	int (*resume_early)(struct device___35 *);
	int (*freeze_late)(struct device___35 *);
	int (*thaw_early)(struct device___35 *);
	int (*poweroff_late)(struct device___35 *);
	int (*restore_early)(struct device___35 *);
	int (*suspend_noirq)(struct device___35 *);
	int (*resume_noirq)(struct device___35 *);
	int (*freeze_noirq)(struct device___35 *);
	int (*thaw_noirq)(struct device___35 *);
	int (*poweroff_noirq)(struct device___35 *);
	int (*restore_noirq)(struct device___35 *);
	int (*runtime_suspend)(struct device___35 *);
	int (*runtime_resume)(struct device___35 *);
	int (*runtime_idle)(struct device___35 *);
};

struct dev_pm_domain___35 {
	struct dev_pm_ops___35 ops;
	void (*detach)(struct device___35 *, bool);
	int (*activate)(struct device___35 *);
	void (*sync)(struct device___35 *);
	void (*dismiss)(struct device___35 *);
};

struct bus_type___35 {
	const char *name;
	const char *dev_name;
	struct device___35 *dev_root;
	const struct attribute_group___35 **bus_groups;
	const struct attribute_group___35 **dev_groups;
	const struct attribute_group___35 **drv_groups;
	int (*match)(struct device___35 *, struct device_driver___35 *);
	int (*uevent)(struct device___35 *, struct kobj_uevent_env *);
	int (*probe)(struct device___35 *);
	int (*remove)(struct device___35 *);
	void (*shutdown)(struct device___35 *);
	int (*online)(struct device___35 *);
	int (*offline)(struct device___35 *);
	int (*suspend)(struct device___35 *, pm_message_t);
	int (*resume)(struct device___35 *);
	int (*num_vf)(struct device___35 *);
	int (*dma_configure)(struct device___35 *);
	const struct dev_pm_ops___35 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___35 {
	const char *name;
	struct bus_type___35 *bus;
	struct module___37 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___35 *);
	int (*remove)(struct device___35 *);
	void (*shutdown)(struct device___35 *);
	int (*suspend)(struct device___35 *, pm_message_t);
	int (*resume)(struct device___35 *);
	const struct attribute_group___35 **groups;
	const struct dev_pm_ops___35 *pm;
	void (*coredump)(struct device___35 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___35 {
	const char *name;
	const struct attribute_group___35 **groups;
	int (*uevent)(struct device___35 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___35 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___35 *);
	const struct dev_pm_ops___35 *pm;
};

struct class___35 {
	const char *name;
	struct module___37 *owner;
	const struct attribute_group___35 **class_groups;
	const struct attribute_group___35 **dev_groups;
	struct kobject___38 *dev_kobj;
	int (*dev_uevent)(struct device___35 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___35 *, umode_t *);
	void (*class_release)(struct class___35 *);
	void (*dev_release)(struct device___35 *);
	int (*shutdown_pre)(struct device___35 *);
	const struct kobj_ns_type_operations___2 *ns_type;
	const void * (*namespace)(struct device___35 *);
	const struct dev_pm_ops___35 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___10 {
	void * (*alloc)(struct device___35 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___35 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___35 *, struct vm_area_struct___40 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___35 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___35 *, struct page___40 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___35 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___35 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___35 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___35 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___35 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___35 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide49;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___35 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___35 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___35 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___35 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___35 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___35 *, u64);
	u64 (*get_required_mask)(struct device___35 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___28;

struct fwnode_handle___28 {
	struct fwnode_handle___28 *secondary;
	const struct fwnode_operations___28 *ops;
};

struct seq_operations___35 {
	void * (*start)(struct seq_file___38 *, loff_t *);
	void (*stop)(struct seq_file___38 *, void *);
	void * (*next)(struct seq_file___38 *, void *, loff_t *);
	int (*show)(struct seq_file___38 *, void *);
};

struct tty_operations___5 {
	struct tty_struct___5 * (*lookup)(struct tty_driver___6 *, struct file___40 *, int);
	int (*install)(struct tty_driver___6 *, struct tty_struct___5 *);
	void (*remove)(struct tty_driver___6 *, struct tty_struct___5 *);
	int (*open)(struct tty_struct___5 *, struct file___40 *);
	void (*close)(struct tty_struct___5 *, struct file___40 *);
	void (*shutdown)(struct tty_struct___5 *);
	void (*cleanup)(struct tty_struct___5 *);
	int (*write)(struct tty_struct___5 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___5 *, unsigned char);
	void (*flush_chars)(struct tty_struct___5 *);
	int (*write_room)(struct tty_struct___5 *);
	int (*chars_in_buffer)(struct tty_struct___5 *);
	int (*ioctl)(struct tty_struct___5 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___5 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___5 *, struct ktermios *);
	void (*throttle)(struct tty_struct___5 *);
	void (*unthrottle)(struct tty_struct___5 *);
	void (*stop)(struct tty_struct___5 *);
	void (*start)(struct tty_struct___5 *);
	void (*hangup)(struct tty_struct___5 *);
	int (*break_ctl)(struct tty_struct___5 *, int);
	void (*flush_buffer)(struct tty_struct___5 *);
	void (*set_ldisc)(struct tty_struct___5 *);
	void (*wait_until_sent)(struct tty_struct___5 *, int);
	void (*send_xchar)(struct tty_struct___5 *, char);
	int (*tiocmget)(struct tty_struct___5 *);
	int (*tiocmset)(struct tty_struct___5 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___5 *, struct winsize *);
	int (*set_termiox)(struct tty_struct___5 *, struct termiox *);
	int (*get_icount)(struct tty_struct___5 *, struct serial_icounter_struct *);
	void (*show_fdinfo)(struct tty_struct___5 *, struct seq_file___38 *);
	int (*poll_init)(struct tty_driver___6 *, int, char *);
	int (*poll_get_char)(struct tty_driver___6 *, int);
	void (*poll_put_char)(struct tty_driver___6 *, int, char);
	int (*proc_show)(struct seq_file___38 *, void *);
};

struct tty_driver___6 {
	int magic;
	struct kref kref;
	struct cdev___12 **cdevs;
	struct module___37 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___6 *other;
	struct tty_struct___5 **ttys;
	struct tty_port___5 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___5 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___5;

struct tty_port_client_operations___5;

struct tty_port___5 {
	struct tty_bufhead buf;
	struct tty_struct___5 *tty;
	struct tty_struct___5 *itty;
	const struct tty_port_operations___5 *ops;
	const struct tty_port_client_operations___5 *client_ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	unsigned char low_latency: 1;
	struct mutex mutex;
	struct mutex buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
	void *client_data;
};

struct tty_ldisc_ops___5 {
	int magic;
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___5 *);
	void (*close)(struct tty_struct___5 *);
	void (*flush_buffer)(struct tty_struct___5 *);
	ssize_t (*read)(struct tty_struct___5 *, struct file___40 *, unsigned char *, size_t);
	ssize_t (*write)(struct tty_struct___5 *, struct file___40 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___5 *, struct file___40 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___5 *, struct file___40 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___5 *, struct ktermios *);
	__poll_t (*poll)(struct tty_struct___5 *, struct file___40 *, struct poll_table_struct___26 *);
	int (*hangup)(struct tty_struct___5 *);
	void (*receive_buf)(struct tty_struct___5 *, const unsigned char *, char *, int);
	void (*write_wakeup)(struct tty_struct___5 *);
	void (*dcd_change)(struct tty_struct___5 *, unsigned int);
	int (*receive_buf2)(struct tty_struct___5 *, const unsigned char *, char *, int);
	struct module___37 *owner;
	int refcount;
};

struct tty_ldisc___5 {
	struct tty_ldisc_ops___5 *ops;
	struct tty_struct___5 *tty;
};

struct tty_port_operations___5 {
	int (*carrier_raised)(struct tty_port___5 *);
	void (*dtr_rts)(struct tty_port___5 *, int);
	void (*shutdown)(struct tty_port___5 *);
	int (*activate)(struct tty_port___5 *, struct tty_struct___5 *);
	void (*destruct)(struct tty_port___5 *);
};

struct tty_port_client_operations___5 {
	int (*receive_buf)(struct tty_port___5 *, const unsigned char *, const unsigned char *, size_t);
	void (*write_wakeup)(struct tty_port___5 *);
};

struct linux_binprm___6 {
	char buf[256];
	struct vm_area_struct___40 *vma;
	long unsigned int vma_pages;
	struct mm_struct___39 *mm;
	long unsigned int p;
	unsigned int called_set_creds: 1;
	unsigned int cap_elevated: 1;
	unsigned int secureexec: 1;
	unsigned int recursion_depth;
	struct file___40 *file;
	struct cred___39 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
};

struct coredump_params___5 {
	union {
		const kernel_siginfo_t *siginfo;
		struct {
			const siginfo_t *siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct pt_regs *regs;
	struct file___40 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
};

typedef void compound_page_dtor___39(struct page___40 *);

struct cgroup_namespace___29 {
	refcount_t count;
	struct ns_common___3 ns;
	struct user_namespace___31 *user_ns;
	struct ucounts___31 *ucounts;
	struct css_set___29 *root_cset;
};

struct ucounts___31 {
	struct hlist_node node;
	struct user_namespace___31 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct kernel_param_ops___34 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___34 *);
	int (*get)(char *, const struct kernel_param___34 *);
	void (*free)(void *);
};

struct kparam_array___34;

struct kernel_param___34 {
	const char *name;
	struct module___37 *mod;
	const struct kernel_param_ops___34 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___34 *arr;
	};
};

struct kparam_array___34 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___34 *ops;
	void *elem;
};

struct module_attribute___34 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___34 *, struct module_kobject___34 *, char *);
	ssize_t (*store)(struct module_attribute___34 *, struct module_kobject___34 *, const char *, size_t);
	void (*setup)(struct module___37 *, const char *);
	int (*test)(struct module___37 *);
	void (*free)(struct module___37 *);
};

struct trace_event_class___20;

struct trace_event_call___20 {
	struct list_head list;
	struct trace_event_class___20 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___3 *prog_array;
	int (*perf_perm)(struct trace_event_call___20 *, struct perf_event___25 *);
};

struct node___33 {
	struct device___35 dev;
};

struct bpf_map___29;

struct bpf_map_ops___29 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___29 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___29 *, struct file___40 *);
	void (*map_free)(struct bpf_map___29 *);
	int (*map_get_next_key)(struct bpf_map___29 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___29 *);
	void * (*map_lookup_elem)(struct bpf_map___29 *, void *);
	int (*map_update_elem)(struct bpf_map___29 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___29 *, void *);
	int (*map_push_elem)(struct bpf_map___29 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___29 *, void *);
	int (*map_peek_elem)(struct bpf_map___29 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___29 *, struct file___40 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___29 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___29 *, void *, struct seq_file___38 *);
	int (*map_check_btf)(const struct bpf_map___29 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___29 {
	const struct bpf_map_ops___29 *ops;
	struct bpf_map___29 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___39 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___29;

typedef void (*kthread_work_func_t___29)(struct kthread_work___29 *);

struct kthread_worker___29;

struct kthread_work___29 {
	struct list_head node;
	kthread_work_func_t___29 func;
	struct kthread_worker___29 *worker;
	int canceling;
};

struct kthread_worker___29 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___41 *task;
	struct kthread_work___29 *current_work;
};

struct kthread_delayed_work___29 {
	struct kthread_work___29 work;
	struct timer_list timer;
};

struct psi_group___29 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___29 *poll_kworker;
	struct kthread_delayed_work___29 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___29;

struct cgroup_rstat_cpu___29;

struct cgroup___29 {
	struct cgroup_subsys_state___29 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___37 *kn;
	struct cgroup_file___29 procs_file;
	struct cgroup_file___29 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___29 *subsys[13];
	struct cgroup_root___29 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___29 *dom_cgrp;
	struct cgroup_rstat_cpu___29 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___3 bpf;
	atomic_t congestion_count;
	struct cgroup___29 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___29 psi;
	int ancestor_ids[0];
};

struct cftype___29;

struct cgroup_subsys___29 {
	struct cgroup_subsys_state___29 * (*css_alloc)(struct cgroup_subsys_state___29 *);
	int (*css_online)(struct cgroup_subsys_state___29 *);
	void (*css_offline)(struct cgroup_subsys_state___29 *);
	void (*css_released)(struct cgroup_subsys_state___29 *);
	void (*css_free)(struct cgroup_subsys_state___29 *);
	void (*css_reset)(struct cgroup_subsys_state___29 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___29 *, int);
	int (*css_extra_stat_show)(struct seq_file___38 *, struct cgroup_subsys_state___29 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___41 *);
	void (*cancel_fork)(struct task_struct___41 *);
	void (*fork)(struct task_struct___41 *);
	void (*exit)(struct task_struct___41 *);
	void (*free)(struct task_struct___41 *);
	void (*bind)(struct cgroup_subsys_state___29 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___29 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___29 *dfl_cftypes;
	struct cftype___29 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___29 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___29 *updated_children;
	struct cgroup___29 *updated_next;
};

struct cgroup_root___29 {
	struct kernfs_root___37 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___29 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___29 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___29 *ss;
	struct list_head node;
	struct kernfs_ops___37 *kf_ops;
	int (*open)(struct kernfs_open_file___37 *);
	void (*release)(struct kernfs_open_file___37 *);
	u64 (*read_u64)(struct cgroup_subsys_state___29 *, struct cftype___29 *);
	s64 (*read_s64)(struct cgroup_subsys_state___29 *, struct cftype___29 *);
	int (*seq_show)(struct seq_file___38 *, void *);
	void * (*seq_start)(struct seq_file___38 *, loff_t *);
	void * (*seq_next)(struct seq_file___38 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___38 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___29 *, struct cftype___29 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___29 *, struct cftype___29 *, s64);
	ssize_t (*write)(struct kernfs_open_file___37 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___37 *, struct poll_table_struct___26 *);
};

struct perf_cpu_context___25;

struct pmu___25 {
	struct list_head entry;
	struct module___37 *module;
	struct device___35 *dev;
	const struct attribute_group___35 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___25 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___25 *);
	void (*pmu_disable)(struct pmu___25 *);
	int (*event_init)(struct perf_event___25 *);
	void (*event_mapped)(struct perf_event___25 *, struct mm_struct___39 *);
	void (*event_unmapped)(struct perf_event___25 *, struct mm_struct___39 *);
	int (*add)(struct perf_event___25 *, int);
	void (*del)(struct perf_event___25 *, int);
	void (*start)(struct perf_event___25 *, int);
	void (*stop)(struct perf_event___25 *, int);
	void (*read)(struct perf_event___25 *);
	void (*start_txn)(struct pmu___25 *, unsigned int);
	int (*commit_txn)(struct pmu___25 *);
	void (*cancel_txn)(struct pmu___25 *);
	int (*event_idx)(struct perf_event___25 *);
	void (*sched_task)(struct perf_event_context___25 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___25 *);
	int (*filter_match)(struct perf_event___25 *);
	int (*check_period)(struct perf_event___25 *, u64);
};

struct perf_cpu_context___25 {
	struct perf_event_context___25 ctx;
	struct perf_event_context___25 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___25 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___25 {
	struct cgroup_subsys_state___29 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___20 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___20 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___20 *);
	struct list_head * (*get_fields)(struct trace_event_call___20 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___20 *);
};

struct trace_event_file___8;

struct trace_event_buffer___8 {
	struct ring_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___8 *trace_file;
	void *entry;
	long unsigned int flags;
	int pc;
};

struct trace_event_file___8 {
	struct list_head list;
	struct trace_event_call___20 *event_call;
	struct event_filter *filter;
	struct dentry___41 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct syscall_metadata___9 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___20 *enter_event;
	struct trace_event_call___20 *exit_event;
};

struct bdi_writeback_congested___15 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___15 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___15 {
	struct bio___15 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___15 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___15 bip_inline_vecs[0];
};

struct blkcg___6;

struct blkg_policy_data___6;

struct blkcg_gq___6 {
	struct request_queue___10 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___6 *blkcg;
	struct bdi_writeback_congested___15 *wb_congested;
	struct blkcg_gq___6 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_rwstat stat_bytes;
	struct blkg_rwstat stat_ios;
	struct blkg_policy_data___6 *pd[5];
	struct callback_head callback_head;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
};

struct mem_cgroup_reclaim_iter___14 {
	struct mem_cgroup___14 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___14 {
	struct lruvec___39 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___14 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___14 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct disk_part_tbl___9 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___9 *last_lookup;
	struct hd_struct___9 *part[0];
};

struct block_device_operations___9 {
	int (*open)(struct block_device___40 *, fmode_t);
	void (*release)(struct gendisk___9 *, fmode_t);
	int (*rw_page)(struct block_device___40 *, sector_t, struct page___40 *, unsigned int);
	int (*ioctl)(struct block_device___40 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___40 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___9 *, unsigned int);
	int (*media_changed)(struct gendisk___9 *);
	void (*unlock_native_capacity)(struct gendisk___9 *);
	int (*revalidate_disk)(struct gendisk___9 *);
	int (*getgeo)(struct block_device___40 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___40 *, long unsigned int);
	int (*report_zones)(struct gendisk___9 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___37 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___9 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___10 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___10 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___10 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___9(struct request___10 *, blk_status_t);

struct request___10 {
	struct request_queue___10 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___15 *bio;
	struct bio___15 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___15 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___9 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___9 *saved_end_io;
		} flush;
	};
	struct gendisk___9 *rq_disk;
	struct hd_struct___9 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___9 *end_io;
	void *end_io_data;
	struct request___10 *next_rq;
};

struct fwnode_reference_args___28;

struct fwnode_endpoint___28;

struct fwnode_operations___28 {
	struct fwnode_handle___28 * (*get)(struct fwnode_handle___28 *);
	void (*put)(struct fwnode_handle___28 *);
	bool (*device_is_available)(const struct fwnode_handle___28 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___28 *, const struct device___35 *);
	bool (*property_present)(const struct fwnode_handle___28 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___28 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___28 *, const char *, const char **, size_t);
	struct fwnode_handle___28 * (*get_parent)(const struct fwnode_handle___28 *);
	struct fwnode_handle___28 * (*get_next_child_node)(const struct fwnode_handle___28 *, struct fwnode_handle___28 *);
	struct fwnode_handle___28 * (*get_named_child_node)(const struct fwnode_handle___28 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___28 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___28 *);
	struct fwnode_handle___28 * (*graph_get_next_endpoint)(const struct fwnode_handle___28 *, struct fwnode_handle___28 *);
	struct fwnode_handle___28 * (*graph_get_remote_endpoint)(const struct fwnode_handle___28 *);
	struct fwnode_handle___28 * (*graph_get_port_parent)(struct fwnode_handle___28 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___28 *, struct fwnode_endpoint___28 *);
};

struct fwnode_endpoint___28 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___28 *local_fwnode;
};

struct fwnode_reference_args___28 {
	struct fwnode_handle___28 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct elevator_type___9;

struct elevator_mq_ops___9 {
	int (*init_sched)(struct request_queue___10 *, struct elevator_type___9 *);
	void (*exit_sched)(struct elevator_queue___9 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	bool (*allow_merge)(struct request_queue___10 *, struct request___10 *, struct bio___15 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx *, struct bio___15 *);
	int (*request_merge)(struct request_queue___10 *, struct request___10 **, struct bio___15 *);
	void (*request_merged)(struct request_queue___10 *, struct request___10 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___10 *, struct request___10 *, struct request___10 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___10 *, struct bio___15 *);
	void (*finish_request)(struct request___10 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___10 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___10 *, u64);
	void (*started_request)(struct request___10 *);
	void (*requeue_request)(struct request___10 *);
	struct request___10 * (*former_request)(struct request_queue___10 *, struct request___10 *);
	struct request___10 * (*next_request)(struct request_queue___10 *, struct request___10 *);
	void (*init_icq)(struct io_cq___9 *);
	void (*exit_icq)(struct io_cq___9 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide37;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___9;

struct elevator_type___9 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___9 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___9 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___37 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___9 {
	struct elevator_type___9 *type;
	void *elevator_data;
	struct kobject___38 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___9 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___9 *, char *);
	ssize_t (*store)(struct elevator_queue___9 *, const char *, size_t);
};

struct blkcg_policy_data___6;

struct blkcg___6 {
	struct cgroup_subsys_state___29 css;
	spinlock_t lock;
	struct xarray blkg_tree;
	struct blkcg_gq___6 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___6 *cpd[5];
	struct list_head all_blkcgs_node;
	struct list_head cgwb_list;
	refcount_t cgwb_refcnt;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct blkcg_policy_data___6 {
	struct blkcg___6 *blkcg;
	int plid;
};

struct blkg_policy_data___6 {
	struct blkcg_gq___6 *blkg;
	int plid;
};

enum {
	TRACE_SIGNAL_DELIVERED = 0,
	TRACE_SIGNAL_IGNORED = 1,
	TRACE_SIGNAL_ALREADY_PENDING = 2,
	TRACE_SIGNAL_OVERFLOW_FAIL = 3,
	TRACE_SIGNAL_LOSE_INFO = 4,
};

struct trace_event_raw_signal_generate {
	struct trace_entry ent;
	int sig;
	int errno;
	int code;
	char comm[16];
	pid_t pid;
	int group;
	int result;
	char __data[0];
};

struct trace_event_raw_signal_deliver {
	struct trace_entry ent;
	int sig;
	int errno;
	int code;
	long unsigned int sa_handler;
	long unsigned int sa_flags;
	char __data[0];
};

struct trace_event_data_offsets_signal_generate {};

struct trace_event_data_offsets_signal_deliver {};

struct pipe_buf_operations___8;

struct pipe_buffer___8 {
	struct page___40 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___8 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___8 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___8 *, struct pipe_buffer___8 *);
	void (*release)(struct pipe_inode_info___8 *, struct pipe_buffer___8 *);
	int (*steal)(struct pipe_inode_info___8 *, struct pipe_buffer___8 *);
	union {
		bool (*get)(struct pipe_inode_info___8 *, struct pipe_buffer___8 *);
		struct {
			void (*get)(struct pipe_inode_info___8 *, struct pipe_buffer___8 *);
		} __UNIQUE_ID_rh_kabi_hide52;
		union {		};
	};
};

typedef int (*get_char_func)();

struct sysinfo {
	__kernel_long_t uptime;
	__kernel_ulong_t loads[3];
	__kernel_ulong_t totalram;
	__kernel_ulong_t freeram;
	__kernel_ulong_t sharedram;
	__kernel_ulong_t bufferram;
	__kernel_ulong_t totalswap;
	__kernel_ulong_t freeswap;
	__u16 procs;
	__u16 pad;
	__kernel_ulong_t totalhigh;
	__kernel_ulong_t freehigh;
	__u32 mem_unit;
	char _f[0];
};

struct module___38;

struct file___41;

struct kiocb___41;

struct iov_iter___18;

struct poll_table_struct___27;

struct vm_area_struct___41;

struct inode___43;

struct file_lock___41;

struct page___41;

struct seq_file___39;

struct file_operations___41 {
	struct module___38 *owner;
	loff_t (*llseek)(struct file___41 *, loff_t, int);
	ssize_t (*read)(struct file___41 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___41 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___41 *, struct iov_iter___18 *);
	ssize_t (*write_iter)(struct kiocb___41 *, struct iov_iter___18 *);
	int (*iopoll)(struct kiocb___41 *, bool);
	int (*iterate)(struct file___41 *, struct dir_context *);
	int (*iterate_shared)(struct file___41 *, struct dir_context *);
	__poll_t (*poll)(struct file___41 *, struct poll_table_struct___27 *);
	long int (*unlocked_ioctl)(struct file___41 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___41 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___41 *, struct vm_area_struct___41 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___43 *, struct file___41 *);
	int (*flush)(struct file___41 *, fl_owner_t);
	int (*release)(struct inode___43 *, struct file___41 *);
	int (*fsync)(struct file___41 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___41 *, int);
	int (*lock)(struct file___41 *, int, struct file_lock___41 *);
	ssize_t (*sendpage)(struct file___41 *, struct page___41 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___41 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___41 *, int, struct file_lock___41 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___41 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___41 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___41 *, long int, struct file_lock___41 **, void **);
	long int (*fallocate)(struct file___41 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___39 *, struct file___41 *);
	ssize_t (*copy_file_range)(struct file___41 *, loff_t, struct file___41 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___41 *, loff_t, struct file___41 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___41 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___40 {
	u64 seqnum;
	struct vm_area_struct___41 *vmas[4];
};

struct page_frag___40 {
	struct page___41 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___26;

struct debug_info___26 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___26 *hbp_break[16];
	struct perf_event___26 *hbp_watch[16];
};

struct thread_struct___26 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___26 debug;
	long: 64;
};

struct mm_struct___40;

struct mem_cgroup___15;

struct pid___36;

struct cred___40;

struct fs_struct___4;

struct nsproxy___39;

struct signal_struct___38;

struct bio_list___16;

struct backing_dev_info___16;

struct css_set___30;

struct perf_event_context___26;

struct vm_struct___32;

struct task_struct___42 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___42 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___40 *mm;
	struct mm_struct___40 *active_mm;
	struct vmacache___40 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___42 *real_parent;
	struct task_struct___42 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___42 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___15 *active_memcg;
	long int rh_reserved2;
	struct pid___36 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___36 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___36 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___40 *ptracer_cred;
	const struct cred___40 *real_cred;
	const struct cred___40 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct___4 *fs;
	struct files_struct *files;
	struct nsproxy___39 *nsproxy;
	struct signal_struct___38 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___42 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___16 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___16 *backing_dev_info;
	struct io_context___9 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___30 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___26 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___40 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___15 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___42 *oom_reaper_list;
	struct vm_struct___32 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___26 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct prctl_mm_map {
	__u64 start_code;
	__u64 end_code;
	__u64 start_data;
	__u64 end_data;
	__u64 start_brk;
	__u64 brk;
	__u64 start_stack;
	__u64 arg_start;
	__u64 arg_end;
	__u64 env_start;
	__u64 env_end;
	__u64 *auxv;
	__u32 auxv_size;
	__u32 exe_fd;
};

struct hw_perf_event___26 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___42 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___26)(struct perf_event___26 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___26;

struct fasync_struct___40;

struct pid_namespace___36;

struct trace_event_call___21;

struct perf_cgroup___26;

struct perf_event___26 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___26 *group_leader;
	struct pmu___26 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___26 hw;
	struct perf_event_context___26 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___26 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___42 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___40 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___26 *);
	struct callback_head callback_head;
	struct pid_namespace___36 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___26 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___26 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___21 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___26 *cgrp;
	struct list_head sb_list;
};

typedef struct page___41 *pgtable_t___40;

struct address_space___40;

struct dev_pagemap___40;

struct page___41 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___40 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___41 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___40 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___40 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___40 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___15 *mem_cgroup;
};

struct pglist_data___40;

struct lruvec___40 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___40 *pgdat;
};

struct zone___40 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___40 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___40 {
	struct zone___40 *zone;
	int zone_idx;
};

struct zonelist___40 {
	struct zoneref___40 _zonerefs[25];
};

struct pglist_data___40 {
	struct zone___40 node_zones[3];
	struct zonelist___40 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___42 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___42 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___40 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___41 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___42 *owner;
};

struct secondary_data___41 {
	void *stack;
	struct task_struct___42 *task;
	long int status;
};

struct blocking_notifier_head___40 {
	struct rw_semaphore___41 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___40;

struct vm_area_struct___41 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___41 *vm_next;
	struct vm_area_struct___41 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___40 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___40 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___41 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct linux_binfmt___7;

struct core_state___40;

struct user_namespace___32;

struct mm_struct___40 {
	struct {
		struct vm_area_struct___41 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___41 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___41 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___7 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___40 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___42 *owner;
		struct user_namespace___32 *user_ns;
		struct file___41 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___40 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___40;

struct address_space___40 {
	struct inode___43 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___41 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___40 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___40)(struct vm_area_struct___41 *, long unsigned int, const struct page___41 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___40)(struct page___41 *, void *);

struct device___36;

struct dev_pagemap___40 {
	dev_page_fault_t___40 page_fault;
	dev_page_free_t___40 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___36 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct cgroup___30;

struct cgroup_subsys___30;

struct cgroup_subsys_state___30 {
	struct cgroup___30 *cgroup;
	struct cgroup_subsys___30 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___30 *parent;
};

struct kernfs_node___38;

struct cgroup_file___30 {
	struct kernfs_node___38 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___15;

struct mem_cgroup___15 {
	struct cgroup_subsys_state___30 css;
	struct mem_cgroup_id___5 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___30 events_file;
	struct cgroup_file___30 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___42 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___15 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct vfsmount___7;

struct dentry___42;

struct path___40 {
	struct vfsmount___7 *mnt;
	struct dentry___42 *dentry;
};

struct fown_struct___36 {
	rwlock_t lock;
	struct pid___36 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___41 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___40 f_path;
	struct inode___43 *f_inode;
	const struct file_operations___41 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___36 f_owner;
	const struct cred___40 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___40 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___40;

struct vm_operations_struct___40 {
	void (*open)(struct vm_area_struct___41 *);
	void (*close)(struct vm_area_struct___41 *);
	int (*split)(struct vm_area_struct___41 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___41 *);
	vm_fault_t (*fault)(struct vm_fault___40 *);
	vm_fault_t (*huge_fault)(struct vm_fault___40 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___40 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___41 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___40 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___40 *);
	int (*access)(struct vm_area_struct___41 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___41 *);
	int (*set_policy)(struct vm_area_struct___41 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___41 *, long unsigned int);
	struct page___41 * (*find_special_page)(struct vm_area_struct___41 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___40 {
	struct task_struct___42 *task;
	struct core_thread___40 *next;
};

struct core_state___40 {
	atomic_t nr_threads;
	struct core_thread___40 dumper;
	struct completion startup;
};

struct linux_binprm___7;

struct coredump_params___6;

struct linux_binfmt___7 {
	struct list_head lh;
	struct module___38 *module;
	int (*load_binary)(struct linux_binprm___7 *);
	int (*load_shlib)(struct file___41 *);
	int (*core_dump)(struct coredump_params___6 *);
	long unsigned int min_coredump;
};

struct key___41;

struct ucounts___32;

struct user_namespace___32 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___32 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___3 ns;
	long unsigned int flags;
	struct key___41 *persistent_keyring_register;
	struct rw_semaphore___41 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___32 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___40 {
	struct vm_area_struct___41 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___41 *cow_page;
	struct mem_cgroup___15 *memcg;
	struct page___41 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___40 prealloc_pte;
};

struct shrink_control___15 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___15 *memcg;
};

struct shrinker___15 {
	long unsigned int (*count_objects)(struct shrinker___15 *, struct shrink_control___15 *);
	long unsigned int (*scan_objects)(struct shrinker___15 *, struct shrink_control___15 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct rlimit64 {
	__u64 rlim_cur;
	__u64 rlim_max;
};

struct upid___36 {
	int nr;
	struct pid_namespace___36 *ns;
};

struct pid_namespace___36 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___42 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___36 *parent;
	struct vfsmount___7 *proc_mnt;
	struct dentry___42 *proc_self;
	struct dentry___42 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___32 *user_ns;
	struct ucounts___32 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___3 ns;
};

struct pid___36 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___36 numbers[1];
};

struct user_struct___40 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___41 *uid_keyring;
	struct key___41 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___40 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___41 *session_keyring;
	struct key___41 *process_keyring;
	struct key___41 *thread_keyring;
	struct key___41 *request_key_auth;
	void *security;
	struct user_struct___40 *user;
	struct user_namespace___32 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct fs_struct___4 {
	int users;
	spinlock_t lock;
	seqcount_t seq;
	int umask;
	int in_exec;
	struct path___40 root;
	struct path___40 pwd;
};

struct uts_namespace___9;

struct cgroup_namespace___30;

struct nsproxy___39 {
	atomic_t count;
	struct uts_namespace___9 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___36 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___30 *cgroup_ns;
};

struct tty_struct___6;

struct signal_struct___38 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___42 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___42 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___36 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___36 *tty_old_pgrp;
	int leader;
	struct tty_struct___6 *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___40 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___36 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___16;

struct bio_list___16 {
	struct bio___16 *head;
	struct bio___16 *tail;
};

struct bdi_writeback_congested___16;

struct bdi_writeback___16 {
	struct backing_dev_info___16 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___16 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___30 *memcg_css;
	struct cgroup_subsys_state___30 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___16 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___16 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___36 *dev;
	struct device___36 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___42 *debug_dir;
	struct dentry___42 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___30 {
	struct cgroup_subsys_state___30 *subsys[13];
	refcount_t refcount;
	struct css_set___30 *dom_cset;
	struct cgroup___30 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___30 *mg_src_cgrp;
	struct cgroup___30 *mg_dst_cgrp;
	struct css_set___30 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___26 {
	struct pmu___26 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___42 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___26 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___32 {
	struct vm_struct___32 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___41 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___38 {
	struct task_struct___42 task;
	long unsigned int stack[8192];
};

struct kset___38;

struct kobj_type___38;

struct kobject___39 {
	const char *name;
	struct list_head entry;
	struct kobject___39 *parent;
	struct kset___38 *kset;
	struct kobj_type___38 *ktype;
	struct kernfs_node___38 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___36 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___36 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___36;

struct bus_type___36;

struct device_driver___36;

struct dev_pm_domain___36;

struct fwnode_handle___29;

struct class___36;

struct attribute_group___36;

struct device___36 {
	struct device___36 *parent;
	struct device_private *p;
	struct kobject___39 kobj;
	const char *init_name;
	const struct device_type___36 *type;
	struct mutex mutex;
	struct bus_type___36 *bus;
	struct device_driver___36 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___36 power;
	struct dev_pm_domain___36 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___29 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___36 *class;
	const struct attribute_group___36 **groups;
	void (*release)(struct device___36 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___40;

struct super_block___41;

struct dentry___42 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___42 *d_parent;
	struct qstr d_name;
	struct inode___43 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___40 *d_op;
	struct super_block___41 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___40;

struct block_device___41;

struct cdev___13;

struct inode___43 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___40 *i_op;
	struct super_block___41 *i_sb;
	struct address_space___40 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___41 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___16 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___41 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___40 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___41 *i_bdev;
		struct cdev___13 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___40 {
	int (*d_revalidate)(struct dentry___42 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___42 *, unsigned int);
	int (*d_hash)(const struct dentry___42 *, struct qstr *);
	int (*d_compare)(const struct dentry___42 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___42 *);
	int (*d_init)(struct dentry___42 *);
	void (*d_release)(struct dentry___42 *);
	void (*d_prune)(struct dentry___42 *);
	void (*d_iput)(struct dentry___42 *, struct inode___43 *);
	char * (*d_dname)(struct dentry___42 *, char *, int);
	struct vfsmount___7 * (*d_automount)(struct path___40 *);
	int (*d_manage)(const struct path___40 *, bool);
	struct dentry___42 * (*d_real)(struct dentry___42 *, const struct inode___43 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___40;

struct mem_dqinfo___40 {
	struct quota_format_type___40 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___40;

struct quota_info___40 {
	unsigned int flags;
	struct rw_semaphore___41 dqio_sem;
	struct inode___43 *files[3];
	struct mem_dqinfo___40 info[3];
	const struct quota_format_ops___40 *ops[3];
};

struct rcuwait___40 {
	struct task_struct___42 *task;
};

struct percpu_rw_semaphore___40 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___41 rw_sem;
	struct rcuwait___40 writer;
	int readers_block;
};

struct sb_writers___40 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___40 rw_sem[3];
};

struct file_system_type___40;

struct super_operations___40;

struct dquot_operations___40;

struct quotactl_ops___40;

struct super_block___41 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___40 *s_type;
	const struct super_operations___40 *s_op;
	const struct dquot_operations___40 *dq_op;
	const struct quotactl_ops___40 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___42 *s_root;
	struct rw_semaphore___41 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___41 *s_bdev;
	struct backing_dev_info___16 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___40 s_dquot;
	struct sb_writers___40 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___40 *s_d_op;
	int cleancache_poolid;
	struct shrinker___15 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___32 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___7 {
	struct dentry___42 *mnt_root;
	struct super_block___41 *mnt_sb;
	int mnt_flags;
};

struct kiocb___41 {
	struct file___41 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___41 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___41 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___41 *ia_file;
};

struct dquot___40 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___41 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___40 {
	int qf_fmt_id;
	const struct quota_format_ops___40 *qf_ops;
	struct module___38 *qf_owner;
	struct quota_format_type___40 *qf_next;
};

struct quota_format_ops___40 {
	int (*check_quota_file)(struct super_block___41 *, int);
	int (*read_file_info)(struct super_block___41 *, int);
	int (*write_file_info)(struct super_block___41 *, int);
	int (*free_file_info)(struct super_block___41 *, int);
	int (*read_dqblk)(struct dquot___40 *);
	int (*commit_dqblk)(struct dquot___40 *);
	int (*release_dqblk)(struct dquot___40 *);
	int (*get_next_id)(struct super_block___41 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___40 {
	int (*write_dquot)(struct dquot___40 *);
	struct dquot___40 * (*alloc_dquot)(struct super_block___41 *, int);
	void (*destroy_dquot)(struct dquot___40 *);
	int (*acquire_dquot)(struct dquot___40 *);
	int (*release_dquot)(struct dquot___40 *);
	int (*mark_dirty)(struct dquot___40 *);
	int (*write_info)(struct super_block___41 *, int);
	qsize_t * (*get_reserved_space)(struct inode___43 *);
	int (*get_projid)(struct inode___43 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___43 *, qsize_t *);
	int (*get_next_id)(struct super_block___41 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___40 {
	int (*quota_on)(struct super_block___41 *, int, int, const struct path___40 *);
	int (*quota_off)(struct super_block___41 *, int);
	int (*quota_enable)(struct super_block___41 *, unsigned int);
	int (*quota_disable)(struct super_block___41 *, unsigned int);
	int (*quota_sync)(struct super_block___41 *, int);
	int (*set_info)(struct super_block___41 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___41 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___41 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___41 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___41 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___41 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___35 {
	struct kobject___39 kobj;
	struct module___38 *mod;
	struct kobject___39 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___35 {
	struct module___38 *mod;
	struct latch_tree_node node;
};

struct module_layout___35 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___35 mtn;
};

struct module_attribute___35;

struct kernel_param___35;

struct module___38 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___35 mkobj;
	struct module_attribute___35 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___39 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___35 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___35 core_layout;
	struct module_layout___35 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___21 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___15;

struct swap_info_struct___11;

struct address_space_operations___40 {
	int (*writepage)(struct page___41 *, struct writeback_control___15 *);
	int (*readpage)(struct file___41 *, struct page___41 *);
	int (*writepages)(struct address_space___40 *, struct writeback_control___15 *);
	int (*set_page_dirty)(struct page___41 *);
	int (*readpages)(struct file___41 *, struct address_space___40 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___41 *, struct address_space___40 *, loff_t, unsigned int, unsigned int, struct page___41 **, void **);
	int (*write_end)(struct file___41 *, struct address_space___40 *, loff_t, unsigned int, unsigned int, struct page___41 *, void *);
	sector_t (*bmap)(struct address_space___40 *, sector_t);
	void (*invalidatepage)(struct page___41 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___41 *, gfp_t);
	void (*freepage)(struct page___41 *);
	ssize_t (*direct_IO)(struct kiocb___41 *, struct iov_iter___18 *);
	int (*migratepage)(struct address_space___40 *, struct page___41 *, struct page___41 *, enum migrate_mode);
	bool (*isolate_page)(struct page___41 *, isolate_mode_t);
	void (*putback_page)(struct page___41 *);
	int (*launder_page)(struct page___41 *);
	int (*is_partially_uptodate)(struct page___41 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___41 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___40 *, struct page___41 *);
	int (*swap_activate)(struct swap_info_struct___11 *, struct file___41 *, sector_t *);
	void (*swap_deactivate)(struct file___41 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___15 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___16 *wb;
	struct inode___43 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___16;

struct iov_iter___18 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___16 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct swap_info_struct___11 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___41 *bdev;
	struct file___41 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___41 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___43 *bd_inode;
	struct super_block___41 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___41 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___16 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___13 {
	struct kobject___39 kobj;
	struct module___38 *owner;
	const struct file_operations___41 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___40 {
	struct dentry___42 * (*lookup)(struct inode___43 *, struct dentry___42 *, unsigned int);
	const char * (*get_link)(struct dentry___42 *, struct inode___43 *, struct delayed_call *);
	int (*permission)(struct inode___43 *, int);
	struct posix_acl * (*get_acl)(struct inode___43 *, int);
	int (*readlink)(struct dentry___42 *, char *, int);
	int (*create)(struct inode___43 *, struct dentry___42 *, umode_t, bool);
	int (*link)(struct dentry___42 *, struct inode___43 *, struct dentry___42 *);
	int (*unlink)(struct inode___43 *, struct dentry___42 *);
	int (*symlink)(struct inode___43 *, struct dentry___42 *, const char *);
	int (*mkdir)(struct inode___43 *, struct dentry___42 *, umode_t);
	int (*rmdir)(struct inode___43 *, struct dentry___42 *);
	int (*mknod)(struct inode___43 *, struct dentry___42 *, umode_t, dev_t);
	int (*rename)(struct inode___43 *, struct dentry___42 *, struct inode___43 *, struct dentry___42 *, unsigned int);
	int (*setattr)(struct dentry___42 *, struct iattr___41 *);
	int (*getattr)(const struct path___40 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___42 *, char *, size_t);
	int (*fiemap)(struct inode___43 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___43 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___43 *, struct dentry___42 *, struct file___41 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___43 *, struct dentry___42 *, umode_t);
	int (*set_acl)(struct inode___43 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___40 {
	void (*fl_copy_lock)(struct file_lock___41 *, struct file_lock___41 *);
	void (*fl_release_private)(struct file_lock___41 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___40;

struct file_lock___41 {
	struct file_lock___41 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___41 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___40 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___40 *fl_ops;
	const struct lock_manager_operations___40 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___40 {
	int (*lm_compare_owner)(struct file_lock___41 *, struct file_lock___41 *);
	long unsigned int (*lm_owner_key)(struct file_lock___41 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___41 *);
	int (*lm_grant)(struct file_lock___41 *, int);
	bool (*lm_break)(struct file_lock___41 *);
	int (*lm_change)(struct file_lock___41 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___41 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___40 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___40 *fa_next;
	struct file___41 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___40 {
	const char *name;
	int fs_flags;
	struct dentry___42 * (*mount)(struct file_system_type___40 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___41 *);
	struct module___38 *owner;
	struct file_system_type___40 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___40 {
	struct inode___43 * (*alloc_inode)(struct super_block___41 *);
	void (*destroy_inode)(struct inode___43 *);
	void (*dirty_inode)(struct inode___43 *, int);
	int (*write_inode)(struct inode___43 *, struct writeback_control___15 *);
	int (*drop_inode)(struct inode___43 *);
	void (*evict_inode)(struct inode___43 *);
	void (*put_super)(struct super_block___41 *);
	int (*sync_fs)(struct super_block___41 *, int);
	int (*freeze_super)(struct super_block___41 *);
	int (*freeze_fs)(struct super_block___41 *);
	int (*thaw_super)(struct super_block___41 *);
	int (*unfreeze_fs)(struct super_block___41 *);
	int (*statfs)(struct dentry___42 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___41 *, int *, char *);
	void (*umount_begin)(struct super_block___41 *);
	int (*show_options)(struct seq_file___39 *, struct dentry___42 *);
	int (*show_devname)(struct seq_file___39 *, struct dentry___42 *);
	int (*show_path)(struct seq_file___39 *, struct dentry___42 *);
	int (*show_stats)(struct seq_file___39 *, struct dentry___42 *);
	ssize_t (*quota_read)(struct super_block___41 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___41 *, int, const char *, size_t, loff_t);
	struct dquot___40 ** (*get_dquots)(struct inode___43 *);
	int (*bdev_try_to_free_page)(struct super_block___41 *, struct page___41 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___41 *, struct shrink_control___15 *);
	long int (*free_cached_objects)(struct super_block___41 *, struct shrink_control___15 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___26)(struct file___41 *, wait_queue_head_t *, struct poll_table_struct___27 *);

struct poll_table_struct___27 {
	poll_queue_proc___26 _qproc;
	__poll_t _key;
};

struct seq_operations___36;

struct seq_file___39 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___36 *op;
	int poll_event;
	const struct file___41 *file;
	void *private;
};

typedef void bio_end_io_t___16(struct bio___16 *);

struct bio_vec___16 {
	struct page___41 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___16;

struct bio_set___16;

struct bio___16 {
	struct bio___16 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___16 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___16 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___16 *bi_io_vec;
	struct bio_set___16 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___16 bi_inline_vecs[0];
};

struct kobj_attribute___39 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___39 *, struct kobj_attribute___39 *, char *);
	ssize_t (*store)(struct kobject___39 *, struct kobj_attribute___39 *, const char *, size_t);
};

typedef void compound_page_dtor___40(struct page___41 *);

struct uts_namespace___9 {
	struct kref kref;
	struct new_utsname name;
	struct user_namespace___32 *user_ns;
	struct ucounts___32 *ucounts;
	struct ns_common___3 ns;
};

struct cgroup_namespace___30 {
	refcount_t count;
	struct ns_common___3 ns;
	struct user_namespace___32 *user_ns;
	struct ucounts___32 *ucounts;
	struct css_set___30 *root_cset;
};

enum uts_proc {
	UTS_PROC_OSTYPE = 0,
	UTS_PROC_OSRELEASE = 1,
	UTS_PROC_VERSION = 2,
	UTS_PROC_HOSTNAME = 3,
	UTS_PROC_DOMAINNAME = 4,
};

struct ucounts___32 {
	struct hlist_node node;
	struct user_namespace___32 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct kernfs_root___38;

struct kernfs_elem_dir___38 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___38 *root;
};

struct kernfs_syscall_ops___38;

struct kernfs_root___38 {
	struct kernfs_node___38 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___38 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___38 {
	struct kernfs_node___38 *target_kn;
};

struct kernfs_ops___38;

struct kernfs_elem_attr___38 {
	const struct kernfs_ops___38 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___38 *notify_next;
};

struct kernfs_node___38 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___38 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___38 dir;
		struct kernfs_elem_symlink___38 symlink;
		struct kernfs_elem_attr___38 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___38;

struct kernfs_ops___38 {
	int (*open)(struct kernfs_open_file___38 *);
	void (*release)(struct kernfs_open_file___38 *);
	int (*seq_show)(struct seq_file___39 *, void *);
	void * (*seq_start)(struct seq_file___39 *, loff_t *);
	void * (*seq_next)(struct seq_file___39 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___39 *, void *);
	ssize_t (*read)(struct kernfs_open_file___38 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___38 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___38 *, struct vm_area_struct___41 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___38 *, struct poll_table_struct___27 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___38 {
	int (*remount_fs)(struct kernfs_root___38 *, int *, char *);
	int (*show_options)(struct seq_file___39 *, struct kernfs_root___38 *);
	int (*mkdir)(struct kernfs_node___38 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___38 *);
	int (*rename)(struct kernfs_node___38 *, struct kernfs_node___38 *, const char *);
	int (*show_path)(struct seq_file___39 *, struct kernfs_node___38 *, struct kernfs_root___38 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___38 {
	struct kernfs_node___38 *kn;
	struct file___41 *file;
	struct seq_file___39 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___40 *vm_ops;
};

struct bin_attribute___36;

struct attribute_group___36 {
	const char *name;
	umode_t (*is_visible)(struct kobject___39 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___39 *, struct bin_attribute___36 *, int);
	struct attribute **attrs;
	struct bin_attribute___36 **bin_attrs;
};

struct bin_attribute___36 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___41 *, struct kobject___39 *, struct bin_attribute___36 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___41 *, struct kobject___39 *, struct bin_attribute___36 *, char *, loff_t, size_t);
	int (*mmap)(struct file___41 *, struct kobject___39 *, struct bin_attribute___36 *, struct vm_area_struct___41 *);
};

struct sysfs_ops___38 {
	ssize_t (*show)(struct kobject___39 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___39 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___38;

struct kset___38 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___39 kobj;
	const struct kset_uevent_ops___38 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___38 {
	void (*release)(struct kobject___39 *);
	const struct sysfs_ops___38 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___2 * (*child_ns_type)(struct kobject___39 *);
	const void * (*namespace)(struct kobject___39 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___38 {
	int (* const filter)(struct kset___38 *, struct kobject___39 *);
	const char * (* const name)(struct kset___38 *, struct kobject___39 *);
	int (* const uevent)(struct kset___38 *, struct kobject___39 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___35 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___35 *);
	int (*get)(char *, const struct kernel_param___35 *);
	void (*free)(void *);
};

struct kparam_array___35;

struct kernel_param___35 {
	const char *name;
	struct module___38 *mod;
	const struct kernel_param_ops___35 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___35 *arr;
	};
};

struct kparam_array___35 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___35 *ops;
	void *elem;
};

struct module_attribute___35 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___35 *, struct module_kobject___35 *, char *);
	ssize_t (*store)(struct module_attribute___35 *, struct module_kobject___35 *, const char *, size_t);
	void (*setup)(struct module___38 *, const char *);
	int (*test)(struct module___38 *);
	void (*free)(struct module___38 *);
};

struct trace_event_class___21;

struct trace_event_call___21 {
	struct list_head list;
	struct trace_event_class___21 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___3 *prog_array;
	int (*perf_perm)(struct trace_event_call___21 *, struct perf_event___26 *);
};

typedef int (*key_restrict_link_func_t___40)(struct key___41 *, const struct key_type *, const union key_payload *, struct key___41 *);

struct key_restriction___41;

struct key___41 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___41 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___41 *restrict_link;
};

struct key_restriction___41 {
	key_restrict_link_func_t___40 check;
	struct key___41 *key;
	struct key_type *keytype;
};

struct tty_driver___7;

struct tty_operations___6;

struct tty_ldisc___6;

struct tty_port___6;

struct tty_struct___6 {
	int magic;
	struct kref kref;
	struct device___36 *dev;
	struct tty_driver___7 *driver;
	const struct tty_operations___6 *ops;
	int index;
	struct ld_semaphore ldisc_sem;
	struct tty_ldisc___6 *ldisc;
	struct mutex atomic_write_lock;
	struct mutex legacy_mutex;
	struct mutex throttle_mutex;
	struct rw_semaphore___41 termios_rwsem;
	struct mutex winsize_mutex;
	spinlock_t ctrl_lock;
	spinlock_t flow_lock;
	struct ktermios termios;
	struct ktermios termios_locked;
	struct termiox *termiox;
	char name[64];
	struct pid___36 *pgrp;
	struct pid___36 *session;
	long unsigned int flags;
	int count;
	struct winsize winsize;
	long unsigned int stopped: 1;
	long unsigned int flow_stopped: 1;
	int: 30;
	long unsigned int unused: 62;
	int hw_stopped;
	long unsigned int ctrl_status: 8;
	long unsigned int packet: 1;
	int: 23;
	long unsigned int unused_ctrl: 55;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___6 *link;
	struct fasync_struct___40 *fasync;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	spinlock_t files_lock;
	struct list_head tty_files;
	int closing;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___6 *port;
};

struct dev_pm_ops___36 {
	int (*prepare)(struct device___36 *);
	void (*complete)(struct device___36 *);
	int (*suspend)(struct device___36 *);
	int (*resume)(struct device___36 *);
	int (*freeze)(struct device___36 *);
	int (*thaw)(struct device___36 *);
	int (*poweroff)(struct device___36 *);
	int (*restore)(struct device___36 *);
	int (*suspend_late)(struct device___36 *);
	int (*resume_early)(struct device___36 *);
	int (*freeze_late)(struct device___36 *);
	int (*thaw_early)(struct device___36 *);
	int (*poweroff_late)(struct device___36 *);
	int (*restore_early)(struct device___36 *);
	int (*suspend_noirq)(struct device___36 *);
	int (*resume_noirq)(struct device___36 *);
	int (*freeze_noirq)(struct device___36 *);
	int (*thaw_noirq)(struct device___36 *);
	int (*poweroff_noirq)(struct device___36 *);
	int (*restore_noirq)(struct device___36 *);
	int (*runtime_suspend)(struct device___36 *);
	int (*runtime_resume)(struct device___36 *);
	int (*runtime_idle)(struct device___36 *);
};

struct dev_pm_domain___36 {
	struct dev_pm_ops___36 ops;
	void (*detach)(struct device___36 *, bool);
	int (*activate)(struct device___36 *);
	void (*sync)(struct device___36 *);
	void (*dismiss)(struct device___36 *);
};

struct bus_type___36 {
	const char *name;
	const char *dev_name;
	struct device___36 *dev_root;
	const struct attribute_group___36 **bus_groups;
	const struct attribute_group___36 **dev_groups;
	const struct attribute_group___36 **drv_groups;
	int (*match)(struct device___36 *, struct device_driver___36 *);
	int (*uevent)(struct device___36 *, struct kobj_uevent_env *);
	int (*probe)(struct device___36 *);
	int (*remove)(struct device___36 *);
	void (*shutdown)(struct device___36 *);
	int (*online)(struct device___36 *);
	int (*offline)(struct device___36 *);
	int (*suspend)(struct device___36 *, pm_message_t);
	int (*resume)(struct device___36 *);
	int (*num_vf)(struct device___36 *);
	int (*dma_configure)(struct device___36 *);
	const struct dev_pm_ops___36 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___36 {
	const char *name;
	struct bus_type___36 *bus;
	struct module___38 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___36 *);
	int (*remove)(struct device___36 *);
	void (*shutdown)(struct device___36 *);
	int (*suspend)(struct device___36 *, pm_message_t);
	int (*resume)(struct device___36 *);
	const struct attribute_group___36 **groups;
	const struct dev_pm_ops___36 *pm;
	void (*coredump)(struct device___36 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___36 {
	const char *name;
	const struct attribute_group___36 **groups;
	int (*uevent)(struct device___36 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___36 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___36 *);
	const struct dev_pm_ops___36 *pm;
};

struct class___36 {
	const char *name;
	struct module___38 *owner;
	const struct attribute_group___36 **class_groups;
	const struct attribute_group___36 **dev_groups;
	struct kobject___39 *dev_kobj;
	int (*dev_uevent)(struct device___36 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___36 *, umode_t *);
	void (*class_release)(struct class___36 *);
	void (*dev_release)(struct device___36 *);
	int (*shutdown_pre)(struct device___36 *);
	const struct kobj_ns_type_operations___2 *ns_type;
	const void * (*namespace)(struct device___36 *);
	const struct dev_pm_ops___36 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct fwnode_operations___29;

struct fwnode_handle___29 {
	struct fwnode_handle___29 *secondary;
	const struct fwnode_operations___29 *ops;
};

struct node___34 {
	struct device___36 dev;
};

struct seq_operations___36 {
	void * (*start)(struct seq_file___39 *, loff_t *);
	void (*stop)(struct seq_file___39 *, void *);
	void * (*next)(struct seq_file___39 *, void *, loff_t *);
	int (*show)(struct seq_file___39 *, void *);
};

struct fd___3 {
	struct file___41 *file;
	unsigned int flags;
};

struct bpf_map___30;

struct bpf_map_ops___30 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___30 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___30 *, struct file___41 *);
	void (*map_free)(struct bpf_map___30 *);
	int (*map_get_next_key)(struct bpf_map___30 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___30 *);
	void * (*map_lookup_elem)(struct bpf_map___30 *, void *);
	int (*map_update_elem)(struct bpf_map___30 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___30 *, void *);
	int (*map_push_elem)(struct bpf_map___30 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___30 *, void *);
	int (*map_peek_elem)(struct bpf_map___30 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___30 *, struct file___41 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___30 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___30 *, void *, struct seq_file___39 *);
	int (*map_check_btf)(const struct bpf_map___30 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___30 {
	const struct bpf_map_ops___30 *ops;
	struct bpf_map___30 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___40 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___30;

typedef void (*kthread_work_func_t___30)(struct kthread_work___30 *);

struct kthread_worker___30;

struct kthread_work___30 {
	struct list_head node;
	kthread_work_func_t___30 func;
	struct kthread_worker___30 *worker;
	int canceling;
};

struct kthread_worker___30 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___42 *task;
	struct kthread_work___30 *current_work;
};

struct kthread_delayed_work___30 {
	struct kthread_work___30 work;
	struct timer_list timer;
};

struct psi_group___30 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___30 *poll_kworker;
	struct kthread_delayed_work___30 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___30;

struct cgroup_rstat_cpu___30;

struct cgroup___30 {
	struct cgroup_subsys_state___30 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___38 *kn;
	struct cgroup_file___30 procs_file;
	struct cgroup_file___30 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___30 *subsys[13];
	struct cgroup_root___30 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___30 *dom_cgrp;
	struct cgroup_rstat_cpu___30 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___3 bpf;
	atomic_t congestion_count;
	struct cgroup___30 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___30 psi;
	int ancestor_ids[0];
};

struct cftype___30;

struct cgroup_subsys___30 {
	struct cgroup_subsys_state___30 * (*css_alloc)(struct cgroup_subsys_state___30 *);
	int (*css_online)(struct cgroup_subsys_state___30 *);
	void (*css_offline)(struct cgroup_subsys_state___30 *);
	void (*css_released)(struct cgroup_subsys_state___30 *);
	void (*css_free)(struct cgroup_subsys_state___30 *);
	void (*css_reset)(struct cgroup_subsys_state___30 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___30 *, int);
	int (*css_extra_stat_show)(struct seq_file___39 *, struct cgroup_subsys_state___30 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___42 *);
	void (*cancel_fork)(struct task_struct___42 *);
	void (*fork)(struct task_struct___42 *);
	void (*exit)(struct task_struct___42 *);
	void (*free)(struct task_struct___42 *);
	void (*bind)(struct cgroup_subsys_state___30 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___30 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___30 *dfl_cftypes;
	struct cftype___30 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___30 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___30 *updated_children;
	struct cgroup___30 *updated_next;
};

struct cgroup_root___30 {
	struct kernfs_root___38 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___30 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___30 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___30 *ss;
	struct list_head node;
	struct kernfs_ops___38 *kf_ops;
	int (*open)(struct kernfs_open_file___38 *);
	void (*release)(struct kernfs_open_file___38 *);
	u64 (*read_u64)(struct cgroup_subsys_state___30 *, struct cftype___30 *);
	s64 (*read_s64)(struct cgroup_subsys_state___30 *, struct cftype___30 *);
	int (*seq_show)(struct seq_file___39 *, void *);
	void * (*seq_start)(struct seq_file___39 *, loff_t *);
	void * (*seq_next)(struct seq_file___39 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___39 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___30 *, struct cftype___30 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___30 *, struct cftype___30 *, s64);
	ssize_t (*write)(struct kernfs_open_file___38 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___38 *, struct poll_table_struct___27 *);
};

struct perf_cpu_context___26;

struct pmu___26 {
	struct list_head entry;
	struct module___38 *module;
	struct device___36 *dev;
	const struct attribute_group___36 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___26 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___26 *);
	void (*pmu_disable)(struct pmu___26 *);
	int (*event_init)(struct perf_event___26 *);
	void (*event_mapped)(struct perf_event___26 *, struct mm_struct___40 *);
	void (*event_unmapped)(struct perf_event___26 *, struct mm_struct___40 *);
	int (*add)(struct perf_event___26 *, int);
	void (*del)(struct perf_event___26 *, int);
	void (*start)(struct perf_event___26 *, int);
	void (*stop)(struct perf_event___26 *, int);
	void (*read)(struct perf_event___26 *);
	void (*start_txn)(struct pmu___26 *, unsigned int);
	int (*commit_txn)(struct pmu___26 *);
	void (*cancel_txn)(struct pmu___26 *);
	int (*event_idx)(struct perf_event___26 *);
	void (*sched_task)(struct perf_event_context___26 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___26 *);
	int (*filter_match)(struct perf_event___26 *);
	int (*check_period)(struct perf_event___26 *, u64);
};

struct perf_cpu_context___26 {
	struct perf_event_context___26 ctx;
	struct perf_event_context___26 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___26 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___26 {
	struct cgroup_subsys_state___30 css;
	struct perf_cgroup_info *info;
};

struct tms {
	__kernel_clock_t tms_utime;
	__kernel_clock_t tms_stime;
	__kernel_clock_t tms_cutime;
	__kernel_clock_t tms_cstime;
};

struct bdi_writeback_congested___16 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___16 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___16 {
	struct bio___16 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___16 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___16 bip_inline_vecs[0];
};

struct bio_set___16 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___16 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___15 {
	struct mem_cgroup___15 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___15 {
	struct lruvec___40 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___15 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___15 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct tty_operations___6 {
	struct tty_struct___6 * (*lookup)(struct tty_driver___7 *, struct file___41 *, int);
	int (*install)(struct tty_driver___7 *, struct tty_struct___6 *);
	void (*remove)(struct tty_driver___7 *, struct tty_struct___6 *);
	int (*open)(struct tty_struct___6 *, struct file___41 *);
	void (*close)(struct tty_struct___6 *, struct file___41 *);
	void (*shutdown)(struct tty_struct___6 *);
	void (*cleanup)(struct tty_struct___6 *);
	int (*write)(struct tty_struct___6 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___6 *, unsigned char);
	void (*flush_chars)(struct tty_struct___6 *);
	int (*write_room)(struct tty_struct___6 *);
	int (*chars_in_buffer)(struct tty_struct___6 *);
	int (*ioctl)(struct tty_struct___6 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___6 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___6 *, struct ktermios *);
	void (*throttle)(struct tty_struct___6 *);
	void (*unthrottle)(struct tty_struct___6 *);
	void (*stop)(struct tty_struct___6 *);
	void (*start)(struct tty_struct___6 *);
	void (*hangup)(struct tty_struct___6 *);
	int (*break_ctl)(struct tty_struct___6 *, int);
	void (*flush_buffer)(struct tty_struct___6 *);
	void (*set_ldisc)(struct tty_struct___6 *);
	void (*wait_until_sent)(struct tty_struct___6 *, int);
	void (*send_xchar)(struct tty_struct___6 *, char);
	int (*tiocmget)(struct tty_struct___6 *);
	int (*tiocmset)(struct tty_struct___6 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___6 *, struct winsize *);
	int (*set_termiox)(struct tty_struct___6 *, struct termiox *);
	int (*get_icount)(struct tty_struct___6 *, struct serial_icounter_struct *);
	void (*show_fdinfo)(struct tty_struct___6 *, struct seq_file___39 *);
	int (*poll_init)(struct tty_driver___7 *, int, char *);
	int (*poll_get_char)(struct tty_driver___7 *, int);
	void (*poll_put_char)(struct tty_driver___7 *, int, char);
	int (*proc_show)(struct seq_file___39 *, void *);
};

struct tty_driver___7 {
	int magic;
	struct kref kref;
	struct cdev___13 **cdevs;
	struct module___38 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___7 *other;
	struct tty_struct___6 **ttys;
	struct tty_port___6 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___6 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___6;

struct tty_port_client_operations___6;

struct tty_port___6 {
	struct tty_bufhead buf;
	struct tty_struct___6 *tty;
	struct tty_struct___6 *itty;
	const struct tty_port_operations___6 *ops;
	const struct tty_port_client_operations___6 *client_ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	unsigned char low_latency: 1;
	struct mutex mutex;
	struct mutex buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
	void *client_data;
};

struct tty_ldisc_ops___6 {
	int magic;
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___6 *);
	void (*close)(struct tty_struct___6 *);
	void (*flush_buffer)(struct tty_struct___6 *);
	ssize_t (*read)(struct tty_struct___6 *, struct file___41 *, unsigned char *, size_t);
	ssize_t (*write)(struct tty_struct___6 *, struct file___41 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___6 *, struct file___41 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___6 *, struct file___41 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___6 *, struct ktermios *);
	__poll_t (*poll)(struct tty_struct___6 *, struct file___41 *, struct poll_table_struct___27 *);
	int (*hangup)(struct tty_struct___6 *);
	void (*receive_buf)(struct tty_struct___6 *, const unsigned char *, char *, int);
	void (*write_wakeup)(struct tty_struct___6 *);
	void (*dcd_change)(struct tty_struct___6 *, unsigned int);
	int (*receive_buf2)(struct tty_struct___6 *, const unsigned char *, char *, int);
	struct module___38 *owner;
	int refcount;
};

struct tty_ldisc___6 {
	struct tty_ldisc_ops___6 *ops;
	struct tty_struct___6 *tty;
};

struct tty_port_operations___6 {
	int (*carrier_raised)(struct tty_port___6 *);
	void (*dtr_rts)(struct tty_port___6 *, int);
	void (*shutdown)(struct tty_port___6 *);
	int (*activate)(struct tty_port___6 *, struct tty_struct___6 *);
	void (*destruct)(struct tty_port___6 *);
};

struct tty_port_client_operations___6 {
	int (*receive_buf)(struct tty_port___6 *, const unsigned char *, const unsigned char *, size_t);
	void (*write_wakeup)(struct tty_port___6 *);
};

struct getcpu_cache {
	long unsigned int blob[16];
};

struct trace_event_class___21 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___21 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___21 *);
	struct list_head * (*get_fields)(struct trace_event_call___21 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___21 *);
};

struct syscall_metadata___10 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___21 *enter_event;
	struct trace_event_call___21 *exit_event;
};

struct linux_binprm___7 {
	char buf[256];
	struct vm_area_struct___41 *vma;
	long unsigned int vma_pages;
	struct mm_struct___40 *mm;
	long unsigned int p;
	unsigned int called_set_creds: 1;
	unsigned int cap_elevated: 1;
	unsigned int secureexec: 1;
	unsigned int recursion_depth;
	struct file___41 *file;
	struct cred___40 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
};

struct coredump_params___6 {
	union {
		const kernel_siginfo_t *siginfo;
		struct {
			const siginfo_t *siginfo;
		} __UNIQUE_ID_rh_kabi_hide36;
		union {		};
	};
	struct pt_regs *regs;
	struct file___41 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
};

struct fwnode_reference_args___29;

struct fwnode_endpoint___29;

struct fwnode_operations___29 {
	struct fwnode_handle___29 * (*get)(struct fwnode_handle___29 *);
	void (*put)(struct fwnode_handle___29 *);
	bool (*device_is_available)(const struct fwnode_handle___29 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___29 *, const struct device___36 *);
	bool (*property_present)(const struct fwnode_handle___29 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___29 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___29 *, const char *, const char **, size_t);
	struct fwnode_handle___29 * (*get_parent)(const struct fwnode_handle___29 *);
	struct fwnode_handle___29 * (*get_next_child_node)(const struct fwnode_handle___29 *, struct fwnode_handle___29 *);
	struct fwnode_handle___29 * (*get_named_child_node)(const struct fwnode_handle___29 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___29 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___29 *);
	struct fwnode_handle___29 * (*graph_get_next_endpoint)(const struct fwnode_handle___29 *, struct fwnode_handle___29 *);
	struct fwnode_handle___29 * (*graph_get_remote_endpoint)(const struct fwnode_handle___29 *);
	struct fwnode_handle___29 * (*graph_get_port_parent)(struct fwnode_handle___29 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___29 *, struct fwnode_endpoint___29 *);
};

struct fwnode_endpoint___29 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___29 *local_fwnode;
};

struct fwnode_reference_args___29 {
	struct fwnode_handle___29 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct module___39;

struct file___42;

struct kiocb___42;

struct iov_iter___19;

struct poll_table_struct___28;

struct vm_area_struct___42;

struct file_lock___42;

struct page___42;

struct pipe_inode_info___9;

struct seq_file___40;

struct file_operations___42 {
	struct module___39 *owner;
	loff_t (*llseek)(struct file___42 *, loff_t, int);
	ssize_t (*read)(struct file___42 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___42 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___42 *, struct iov_iter___19 *);
	ssize_t (*write_iter)(struct kiocb___42 *, struct iov_iter___19 *);
	int (*iopoll)(struct kiocb___42 *, bool);
	int (*iterate)(struct file___42 *, struct dir_context *);
	int (*iterate_shared)(struct file___42 *, struct dir_context *);
	__poll_t (*poll)(struct file___42 *, struct poll_table_struct___28 *);
	long int (*unlocked_ioctl)(struct file___42 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___42 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___42 *, struct vm_area_struct___42 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___6 *, struct file___42 *);
	int (*flush)(struct file___42 *, fl_owner_t);
	int (*release)(struct inode___6 *, struct file___42 *);
	int (*fsync)(struct file___42 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___42 *, int);
	int (*lock)(struct file___42 *, int, struct file_lock___42 *);
	ssize_t (*sendpage)(struct file___42 *, struct page___42 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___42 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___42 *, int, struct file_lock___42 *);
	ssize_t (*splice_write)(struct pipe_inode_info___9 *, struct file___42 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___42 *, loff_t *, struct pipe_inode_info___9 *, size_t, unsigned int);
	int (*setlease)(struct file___42 *, long int, struct file_lock___42 **, void **);
	long int (*fallocate)(struct file___42 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___40 *, struct file___42 *);
	ssize_t (*copy_file_range)(struct file___42 *, loff_t, struct file___42 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___42 *, loff_t, struct file___42 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___42 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___41 {
	u64 seqnum;
	struct vm_area_struct___42 *vmas[4];
};

struct page_frag___41 {
	struct page___42 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___27;

struct debug_info___27 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___27 *hbp_break[16];
	struct perf_event___27 *hbp_watch[16];
};

struct thread_struct___27 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___27 debug;
	long: 64;
};

struct mm_struct___41;

struct mem_cgroup___16;

struct pid___37;

struct cred___41;

struct nsproxy___40;

struct signal_struct___39;

struct bio_list___17;

struct backing_dev_info___17;

struct css_set___31;

struct perf_event_context___27;

struct task_struct___43 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___43 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___41 *mm;
	struct mm_struct___41 *active_mm;
	struct vmacache___41 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___43 *real_parent;
	struct task_struct___43 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___43 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___16 *active_memcg;
	long int rh_reserved2;
	struct pid___37 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___37 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___37 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___41 *ptracer_cred;
	const struct cred___41 *real_cred;
	const struct cred___41 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___40 *nsproxy;
	struct signal_struct___39 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___43 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___17 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___17 *backing_dev_info;
	struct io_context___9 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___31 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___27 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___9 *splice_pipe;
	struct page_frag___41 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___16 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___43 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___27 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___27 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___43 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___27)(struct perf_event___27 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___27;

struct fasync_struct___41;

struct pid_namespace___37;

struct trace_event_call___22;

struct perf_cgroup___27;

struct perf_event___27 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___27 *group_leader;
	struct pmu___27 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___27 hw;
	struct perf_event_context___27 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___27 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___43 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___41 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___27 *);
	struct callback_head callback_head;
	struct pid_namespace___37 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___27 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___27 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___22 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___27 *cgrp;
	struct list_head sb_list;
};

struct rw_semaphore___42 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___43 *owner;
};

struct key___42;

struct ucounts___33;

struct user_namespace___33 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___33 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___3 ns;
	long unsigned int flags;
	struct key___42 *persistent_keyring_register;
	struct rw_semaphore___42 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___33 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___42 *pgtable_t___41;

struct address_space___41;

struct dev_pagemap___41;

struct page___42 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___41 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___42 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___41 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___41 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___41 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___16 *mem_cgroup;
};

struct pglist_data___41;

struct lruvec___41 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___41 *pgdat;
};

struct zone___41 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___41 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___41 {
	struct zone___41 *zone;
	int zone_idx;
};

struct zonelist___41 {
	struct zoneref___41 _zonerefs[25];
};

struct pglist_data___41 {
	struct zone___41 node_zones[3];
	struct zonelist___41 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___43 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___43 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___41 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___42 {
	void *stack;
	struct task_struct___43 *task;
	long int status;
};

struct blocking_notifier_head___41 {
	struct rw_semaphore___42 rwsem;
	struct notifier_block *head;
};

struct subprocess_info___2 {
	struct work_struct work;
	struct completion *complete;
	const char *path;
	char **argv;
	char **envp;
	struct file___42 *file;
	int wait;
	int retval;
	pid_t pid;
	int (*init)(struct subprocess_info___2 *, struct cred___41 *);
	void (*cleanup)(struct subprocess_info___2 *);
	void *data;
};

struct vfsmount___8;

struct path___41 {
	struct vfsmount___8 *mnt;
	struct dentry___5 *dentry;
};

struct fown_struct___37 {
	rwlock_t lock;
	struct pid___37 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___42 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___41 f_path;
	struct inode___6 *f_inode;
	const struct file_operations___42 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___37 f_owner;
	const struct cred___41 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___41 *f_mapping;
	errseq_t f_wb_err;
};

struct user_struct___41;

struct cred___41 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___42 *session_keyring;
	struct key___42 *process_keyring;
	struct key___42 *thread_keyring;
	struct key___42 *request_key_auth;
	void *security;
	struct user_struct___41 *user;
	struct user_namespace___33 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct umh_info {
	const char *cmdline;
	struct file___42 *pipe_to_umh;
	struct file___42 *pipe_from_umh;
	struct list_head list;
	void (*cleanup)(struct umh_info *);
	pid_t pid;
};

struct kernfs_root___39;

struct kernfs_elem_dir___39 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___39 *root;
};

struct kernfs_node___39;

struct kernfs_syscall_ops___39;

struct kernfs_root___39 {
	struct kernfs_node___39 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___39 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___39 {
	struct kernfs_node___39 *target_kn;
};

struct kernfs_ops___39;

struct kernfs_elem_attr___39 {
	const struct kernfs_ops___39 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___39 *notify_next;
};

struct kernfs_node___39 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___39 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___39 dir;
		struct kernfs_elem_symlink___39 symlink;
		struct kernfs_elem_attr___39 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___39;

struct kernfs_ops___39 {
	int (*open)(struct kernfs_open_file___39 *);
	void (*release)(struct kernfs_open_file___39 *);
	int (*seq_show)(struct seq_file___40 *, void *);
	void * (*seq_start)(struct seq_file___40 *, loff_t *);
	void * (*seq_next)(struct seq_file___40 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___40 *, void *);
	ssize_t (*read)(struct kernfs_open_file___39 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___39 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___39 *, struct vm_area_struct___42 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___39 *, struct poll_table_struct___28 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___39 {
	int (*remount_fs)(struct kernfs_root___39 *, int *, char *);
	int (*show_options)(struct seq_file___40 *, struct kernfs_root___39 *);
	int (*mkdir)(struct kernfs_node___39 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___39 *);
	int (*rename)(struct kernfs_node___39 *, struct kernfs_node___39 *, const char *);
	int (*show_path)(struct seq_file___40 *, struct kernfs_node___39 *, struct kernfs_root___39 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___37;

struct seq_file___40 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___37 *op;
	int poll_event;
	const struct file___42 *file;
	void *private;
};

struct vm_operations_struct___41;

struct kernfs_open_file___39 {
	struct kernfs_node___39 *kn;
	struct file___42 *file;
	struct seq_file___40 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___41 *vm_ops;
};

struct vm_fault___41;

struct vm_operations_struct___41 {
	void (*open)(struct vm_area_struct___42 *);
	void (*close)(struct vm_area_struct___42 *);
	int (*split)(struct vm_area_struct___42 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___42 *);
	vm_fault_t (*fault)(struct vm_fault___41 *);
	vm_fault_t (*huge_fault)(struct vm_fault___41 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___41 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___42 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___41 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___41 *);
	int (*access)(struct vm_area_struct___42 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___42 *);
	int (*set_policy)(struct vm_area_struct___42 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___42 *, long unsigned int);
	struct page___42 * (*find_special_page)(struct vm_area_struct___42 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___27)(struct file___42 *, wait_queue_head_t *, struct poll_table_struct___28 *);

struct poll_table_struct___28 {
	poll_queue_proc___27 _qproc;
	__poll_t _key;
};

struct vm_area_struct___42 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___42 *vm_next;
	struct vm_area_struct___42 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___41 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___41 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___42 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___40;

struct bin_attribute___37;

struct attribute_group___37 {
	const char *name;
	umode_t (*is_visible)(struct kobject___40 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___40 *, struct bin_attribute___37 *, int);
	struct attribute **attrs;
	struct bin_attribute___37 **bin_attrs;
};

struct kset___39;

struct kobj_type___39;

struct kobject___40 {
	const char *name;
	struct list_head entry;
	struct kobject___40 *parent;
	struct kset___39 *kset;
	struct kobj_type___39 *ktype;
	struct kernfs_node___39 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___37 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___42 *, struct kobject___40 *, struct bin_attribute___37 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___42 *, struct kobject___40 *, struct bin_attribute___37 *, char *, loff_t, size_t);
	int (*mmap)(struct file___42 *, struct kobject___40 *, struct bin_attribute___37 *, struct vm_area_struct___42 *);
};

struct sysfs_ops___39 {
	ssize_t (*show)(struct kobject___40 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___40 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___39;

struct kset___39 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___40 kobj;
	const struct kset_uevent_ops___39 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___39 {
	void (*release)(struct kobject___40 *);
	const struct sysfs_ops___39 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___2 * (*child_ns_type)(struct kobject___40 *);
	const void * (*namespace)(struct kobject___40 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___39 {
	int (* const filter)(struct kset___39 *, struct kobject___40 *);
	const char * (* const name)(struct kset___39 *, struct kobject___40 *);
	int (* const uevent)(struct kset___39 *, struct kobject___40 *, struct kobj_uevent_env *);
};

struct kobj_attribute___40 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___40 *, struct kobj_attribute___40 *, char *);
	ssize_t (*store)(struct kobject___40 *, struct kobj_attribute___40 *, const char *, size_t);
};

struct kernel_param___36;

struct kernel_param_ops___36 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___36 *);
	int (*get)(char *, const struct kernel_param___36 *);
	void (*free)(void *);
};

struct kparam_array___36;

struct kernel_param___36 {
	const char *name;
	struct module___39 *mod;
	const struct kernel_param_ops___36 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___36 *arr;
	};
};

struct kparam_array___36 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___36 *ops;
	void *elem;
};

struct module_kobject___36 {
	struct kobject___40 kobj;
	struct module___39 *mod;
	struct kobject___40 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___36 {
	struct module___39 *mod;
	struct latch_tree_node node;
};

struct module_layout___36 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___36 mtn;
};

struct module_attribute___36;

struct module___39 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___36 mkobj;
	struct module_attribute___36 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___40 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___36 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___36 core_layout;
	struct module_layout___36 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___22 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___36 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___36 *, struct module_kobject___36 *, char *);
	ssize_t (*store)(struct module_attribute___36 *, struct module_kobject___36 *, const char *, size_t);
	void (*setup)(struct module___39 *, const char *);
	int (*test)(struct module___39 *);
	void (*free)(struct module___39 *);
};

struct trace_event_class___22;

struct trace_event_call___22 {
	struct list_head list;
	struct trace_event_class___22 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___3 *prog_array;
	int (*perf_perm)(struct trace_event_call___22 *, struct perf_event___27 *);
};

struct upid___37 {
	int nr;
	struct pid_namespace___37 *ns;
};

struct pid_namespace___37 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___43 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___37 *parent;
	struct vfsmount___8 *proc_mnt;
	struct dentry___5 *proc_self;
	struct dentry___5 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___33 *user_ns;
	struct ucounts___33 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___3 ns;
};

struct pid___37 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___37 numbers[1];
};

struct user_struct___41 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___42 *uid_keyring;
	struct key___42 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct linux_binfmt___8;

struct core_state___41;

struct mm_struct___41 {
	struct {
		struct vm_area_struct___42 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___42 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___42 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___8 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___41 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___43 *owner;
		struct user_namespace___33 *user_ns;
		struct file___42 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___41 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup___31;

struct cgroup_subsys___31;

struct cgroup_subsys_state___31 {
	struct cgroup___31 *cgroup;
	struct cgroup_subsys___31 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___31 *parent;
};

struct cgroup_file___31 {
	struct kernfs_node___39 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___16;

struct mem_cgroup___16 {
	struct cgroup_subsys_state___31 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___31 events_file;
	struct cgroup_file___31 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___43 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___16 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fdtable___3 {
	unsigned int max_fds;
	struct file___42 **fd;
	long unsigned int *close_on_exec;
	long unsigned int *open_fds;
	long unsigned int *full_fds_bits;
	struct callback_head rcu;
};

struct files_struct {
	atomic_t count;
	bool resize_in_progress;
	wait_queue_head_t resize_wait;
	struct fdtable___3 *fdt;
	struct fdtable___3 fdtab;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t file_lock;
	unsigned int next_fd;
	long unsigned int close_on_exec_init[1];
	long unsigned int open_fds_init[1];
	long unsigned int full_fds_bits_init[1];
	struct file___42 *fd_array[64];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cgroup_namespace___31;

struct nsproxy___40 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___37 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___31 *cgroup_ns;
};

struct signal_struct___39 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___43 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___43 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___37 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___37 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___41 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___37 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___17;

struct bio_list___17 {
	struct bio___17 *head;
	struct bio___17 *tail;
};

struct bdi_writeback_congested___17;

struct bdi_writeback___17 {
	struct backing_dev_info___17 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___17 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___31 *memcg_css;
	struct cgroup_subsys_state___31 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___37;

struct backing_dev_info___17 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___17 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___37 *dev;
	struct device___37 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___5 *debug_dir;
	struct dentry___5 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___31 {
	struct cgroup_subsys_state___31 *subsys[13];
	refcount_t refcount;
	struct css_set___31 *dom_cset;
	struct cgroup___31 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___31 *mg_src_cgrp;
	struct cgroup___31 *mg_dst_cgrp;
	struct css_set___31 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___27 {
	struct pmu___27 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___43 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___27 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___9;

struct pipe_inode_info___9 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___42 *tmp_page;
	struct fasync_struct___41 *fasync_readers;
	struct fasync_struct___41 *fasync_writers;
	struct pipe_buffer___9 *bufs;
	struct user_struct___41 *user;
};

union thread_union___39 {
	struct task_struct___43 task;
	long unsigned int stack[8192];
};

struct linux_binprm___8 {
	char buf[256];
	struct vm_area_struct___42 *vma;
	long unsigned int vma_pages;
	struct mm_struct___41 *mm;
	long unsigned int p;
	unsigned int called_set_creds: 1;
	unsigned int cap_elevated: 1;
	unsigned int secureexec: 1;
	unsigned int recursion_depth;
	struct file___42 *file;
	struct cred___41 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
};

struct coredump_params___7 {
	union {
		const kernel_siginfo_t *siginfo;
		struct {
			const siginfo_t *siginfo;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	struct pt_regs *regs;
	struct file___42 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
};

struct linux_binfmt___8 {
	struct list_head lh;
	struct module___39 *module;
	int (*load_binary)(struct linux_binprm___8 *);
	int (*load_shlib)(struct file___42 *);
	int (*core_dump)(struct coredump_params___7 *);
	long unsigned int min_coredump;
};

struct dentry_operations___41;

struct super_block___42;

struct dentry___5 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___5 *d_parent;
	struct qstr d_name;
	struct inode___6 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___41 *d_op;
	struct super_block___42 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___41;

struct address_space___41 {
	struct inode___6 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___42 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___41 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___41;

struct block_device___42;

struct inode___6 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___41 *i_op;
	struct super_block___42 *i_sb;
	struct address_space___41 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___42 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___17 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___42 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___41 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___9 *i_pipe;
		struct block_device___42 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___41 {
	int (*d_revalidate)(struct dentry___5 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___5 *, unsigned int);
	int (*d_hash)(const struct dentry___5 *, struct qstr *);
	int (*d_compare)(const struct dentry___5 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___5 *);
	int (*d_init)(struct dentry___5 *);
	void (*d_release)(struct dentry___5 *);
	void (*d_prune)(struct dentry___5 *);
	void (*d_iput)(struct dentry___5 *, struct inode___6 *);
	char * (*d_dname)(struct dentry___5 *, char *, int);
	struct vfsmount___8 * (*d_automount)(struct path___41 *);
	int (*d_manage)(const struct path___41 *, bool);
	struct dentry___5 * (*d_real)(struct dentry___5 *, const struct inode___6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___41;

struct mem_dqinfo___41 {
	struct quota_format_type___41 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___41;

struct quota_info___41 {
	unsigned int flags;
	struct rw_semaphore___42 dqio_sem;
	struct inode___6 *files[3];
	struct mem_dqinfo___41 info[3];
	const struct quota_format_ops___41 *ops[3];
};

struct rcuwait___41 {
	struct task_struct___43 *task;
};

struct percpu_rw_semaphore___41 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___42 rw_sem;
	struct rcuwait___41 writer;
	int readers_block;
};

struct sb_writers___41 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___41 rw_sem[3];
};

struct shrink_control___16;

struct shrinker___16 {
	long unsigned int (*count_objects)(struct shrinker___16 *, struct shrink_control___16 *);
	long unsigned int (*scan_objects)(struct shrinker___16 *, struct shrink_control___16 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___41;

struct super_operations___41;

struct dquot_operations___41;

struct quotactl_ops___41;

struct super_block___42 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___41 *s_type;
	const struct super_operations___41 *s_op;
	const struct dquot_operations___41 *dq_op;
	const struct quotactl_ops___41 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___5 *s_root;
	struct rw_semaphore___42 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___42 *s_bdev;
	struct backing_dev_info___17 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___41 s_dquot;
	struct sb_writers___41 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___41 *s_d_op;
	int cleancache_poolid;
	struct shrinker___16 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___33 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___8 {
	struct dentry___5 *mnt_root;
	struct super_block___42 *mnt_sb;
	int mnt_flags;
};

struct shrink_control___16 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___16 *memcg;
};

typedef int (*dev_page_fault_t___41)(struct vm_area_struct___42 *, long unsigned int, const struct page___42 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___41)(struct page___42 *, void *);

struct dev_pagemap___41 {
	dev_page_fault_t___41 page_fault;
	dev_page_free_t___41 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___37 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___41 {
	struct task_struct___43 *task;
	struct core_thread___41 *next;
};

struct core_state___41 {
	atomic_t nr_threads;
	struct core_thread___41 dumper;
	struct completion startup;
};

struct vm_fault___41 {
	struct vm_area_struct___42 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___42 *cow_page;
	struct mem_cgroup___16 *memcg;
	struct page___42 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___41 prealloc_pte;
};

struct kiocb___42 {
	struct file___42 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___42 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___42 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___42 *ia_file;
};

struct dquot___41 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___42 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___41 {
	int qf_fmt_id;
	const struct quota_format_ops___41 *qf_ops;
	struct module___39 *qf_owner;
	struct quota_format_type___41 *qf_next;
};

struct quota_format_ops___41 {
	int (*check_quota_file)(struct super_block___42 *, int);
	int (*read_file_info)(struct super_block___42 *, int);
	int (*write_file_info)(struct super_block___42 *, int);
	int (*free_file_info)(struct super_block___42 *, int);
	int (*read_dqblk)(struct dquot___41 *);
	int (*commit_dqblk)(struct dquot___41 *);
	int (*release_dqblk)(struct dquot___41 *);
	int (*get_next_id)(struct super_block___42 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___41 {
	int (*write_dquot)(struct dquot___41 *);
	struct dquot___41 * (*alloc_dquot)(struct super_block___42 *, int);
	void (*destroy_dquot)(struct dquot___41 *);
	int (*acquire_dquot)(struct dquot___41 *);
	int (*release_dquot)(struct dquot___41 *);
	int (*mark_dirty)(struct dquot___41 *);
	int (*write_info)(struct super_block___42 *, int);
	qsize_t * (*get_reserved_space)(struct inode___6 *);
	int (*get_projid)(struct inode___6 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___6 *, qsize_t *);
	int (*get_next_id)(struct super_block___42 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___41 {
	int (*quota_on)(struct super_block___42 *, int, int, const struct path___41 *);
	int (*quota_off)(struct super_block___42 *, int);
	int (*quota_enable)(struct super_block___42 *, unsigned int);
	int (*quota_disable)(struct super_block___42 *, unsigned int);
	int (*quota_sync)(struct super_block___42 *, int);
	int (*set_info)(struct super_block___42 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___42 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___42 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___42 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___42 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___42 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___16;

struct swap_info_struct___12;

struct address_space_operations___41 {
	int (*writepage)(struct page___42 *, struct writeback_control___16 *);
	int (*readpage)(struct file___42 *, struct page___42 *);
	int (*writepages)(struct address_space___41 *, struct writeback_control___16 *);
	int (*set_page_dirty)(struct page___42 *);
	int (*readpages)(struct file___42 *, struct address_space___41 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___42 *, struct address_space___41 *, loff_t, unsigned int, unsigned int, struct page___42 **, void **);
	int (*write_end)(struct file___42 *, struct address_space___41 *, loff_t, unsigned int, unsigned int, struct page___42 *, void *);
	sector_t (*bmap)(struct address_space___41 *, sector_t);
	void (*invalidatepage)(struct page___42 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___42 *, gfp_t);
	void (*freepage)(struct page___42 *);
	ssize_t (*direct_IO)(struct kiocb___42 *, struct iov_iter___19 *);
	int (*migratepage)(struct address_space___41 *, struct page___42 *, struct page___42 *, enum migrate_mode);
	bool (*isolate_page)(struct page___42 *, isolate_mode_t);
	void (*putback_page)(struct page___42 *);
	int (*launder_page)(struct page___42 *);
	int (*is_partially_uptodate)(struct page___42 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___42 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___41 *, struct page___42 *);
	int (*swap_activate)(struct swap_info_struct___12 *, struct file___42 *, sector_t *);
	void (*swap_deactivate)(struct file___42 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___16 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___17 *wb;
	struct inode___6 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___17;

struct iov_iter___19 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___17 *bvec;
		struct pipe_inode_info___9 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct swap_info_struct___12 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___42 *bdev;
	struct file___42 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___42 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___6 *bd_inode;
	struct super_block___42 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___42 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___17 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___41 {
	struct dentry___5 * (*lookup)(struct inode___6 *, struct dentry___5 *, unsigned int);
	const char * (*get_link)(struct dentry___5 *, struct inode___6 *, struct delayed_call *);
	int (*permission)(struct inode___6 *, int);
	struct posix_acl * (*get_acl)(struct inode___6 *, int);
	int (*readlink)(struct dentry___5 *, char *, int);
	int (*create)(struct inode___6 *, struct dentry___5 *, umode_t, bool);
	int (*link)(struct dentry___5 *, struct inode___6 *, struct dentry___5 *);
	int (*unlink)(struct inode___6 *, struct dentry___5 *);
	int (*symlink)(struct inode___6 *, struct dentry___5 *, const char *);
	int (*mkdir)(struct inode___6 *, struct dentry___5 *, umode_t);
	int (*rmdir)(struct inode___6 *, struct dentry___5 *);
	int (*mknod)(struct inode___6 *, struct dentry___5 *, umode_t, dev_t);
	int (*rename)(struct inode___6 *, struct dentry___5 *, struct inode___6 *, struct dentry___5 *, unsigned int);
	int (*setattr)(struct dentry___5 *, struct iattr___42 *);
	int (*getattr)(const struct path___41 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___5 *, char *, size_t);
	int (*fiemap)(struct inode___6 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___6 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___6 *, struct dentry___5 *, struct file___42 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___6 *, struct dentry___5 *, umode_t);
	int (*set_acl)(struct inode___6 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___41 {
	void (*fl_copy_lock)(struct file_lock___42 *, struct file_lock___42 *);
	void (*fl_release_private)(struct file_lock___42 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___41;

struct file_lock___42 {
	struct file_lock___42 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___42 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___41 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___41 *fl_ops;
	const struct lock_manager_operations___41 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___41 {
	int (*lm_compare_owner)(struct file_lock___42 *, struct file_lock___42 *);
	long unsigned int (*lm_owner_key)(struct file_lock___42 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___42 *);
	int (*lm_grant)(struct file_lock___42 *, int);
	bool (*lm_break)(struct file_lock___42 *);
	int (*lm_change)(struct file_lock___42 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___42 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___41 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___41 *fa_next;
	struct file___42 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___41 {
	const char *name;
	int fs_flags;
	struct dentry___5 * (*mount)(struct file_system_type___41 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___42 *);
	struct module___39 *owner;
	struct file_system_type___41 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___41 {
	struct inode___6 * (*alloc_inode)(struct super_block___42 *);
	void (*destroy_inode)(struct inode___6 *);
	void (*dirty_inode)(struct inode___6 *, int);
	int (*write_inode)(struct inode___6 *, struct writeback_control___16 *);
	int (*drop_inode)(struct inode___6 *);
	void (*evict_inode)(struct inode___6 *);
	void (*put_super)(struct super_block___42 *);
	int (*sync_fs)(struct super_block___42 *, int);
	int (*freeze_super)(struct super_block___42 *);
	int (*freeze_fs)(struct super_block___42 *);
	int (*thaw_super)(struct super_block___42 *);
	int (*unfreeze_fs)(struct super_block___42 *);
	int (*statfs)(struct dentry___5 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___42 *, int *, char *);
	void (*umount_begin)(struct super_block___42 *);
	int (*show_options)(struct seq_file___40 *, struct dentry___5 *);
	int (*show_devname)(struct seq_file___40 *, struct dentry___5 *);
	int (*show_path)(struct seq_file___40 *, struct dentry___5 *);
	int (*show_stats)(struct seq_file___40 *, struct dentry___5 *);
	ssize_t (*quota_read)(struct super_block___42 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___42 *, int, const char *, size_t, loff_t);
	struct dquot___41 ** (*get_dquots)(struct inode___6 *);
	int (*bdev_try_to_free_page)(struct super_block___42 *, struct page___42 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___42 *, struct shrink_control___16 *);
	long int (*free_cached_objects)(struct super_block___42 *, struct shrink_control___16 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___17(struct bio___17 *);

struct bio_vec___17 {
	struct page___42 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___17;

struct bio_set___17;

struct bio___17 {
	struct bio___17 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___17 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___17 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___17 *bi_io_vec;
	struct bio_set___17 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___17 bi_inline_vecs[0];
};

typedef int (*key_restrict_link_func_t___41)(struct key___42 *, const struct key_type *, const union key_payload *, struct key___42 *);

struct key_restriction___42;

struct key___42 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___42 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___42 *restrict_link;
};

struct key_restriction___42 {
	key_restrict_link_func_t___41 check;
	struct key___42 *key;
	struct key_type *keytype;
};

struct dev_pm_info___37 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___37 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___37;

struct bus_type___37;

struct device_driver___37;

struct dev_pm_domain___37;

struct class___37;

struct device___37 {
	struct device___37 *parent;
	struct device_private *p;
	struct kobject___40 kobj;
	const char *init_name;
	const struct device_type___37 *type;
	struct mutex mutex;
	struct bus_type___37 *bus;
	struct device_driver___37 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___37 power;
	struct dev_pm_domain___37 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___37 *class;
	const struct attribute_group___37 **groups;
	void (*release)(struct device___37 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

typedef void compound_page_dtor___41(struct page___42 *);

struct seq_operations___37 {
	void * (*start)(struct seq_file___40 *, loff_t *);
	void (*stop)(struct seq_file___40 *, void *);
	void * (*next)(struct seq_file___40 *, void *, loff_t *);
	int (*show)(struct seq_file___40 *, void *);
};

struct cgroup_namespace___31 {
	refcount_t count;
	struct ns_common___3 ns;
	struct user_namespace___33 *user_ns;
	struct ucounts___33 *ucounts;
	struct css_set___31 *root_cset;
};

struct ucounts___33 {
	struct hlist_node node;
	struct user_namespace___33 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct dev_pm_ops___37 {
	int (*prepare)(struct device___37 *);
	void (*complete)(struct device___37 *);
	int (*suspend)(struct device___37 *);
	int (*resume)(struct device___37 *);
	int (*freeze)(struct device___37 *);
	int (*thaw)(struct device___37 *);
	int (*poweroff)(struct device___37 *);
	int (*restore)(struct device___37 *);
	int (*suspend_late)(struct device___37 *);
	int (*resume_early)(struct device___37 *);
	int (*freeze_late)(struct device___37 *);
	int (*thaw_early)(struct device___37 *);
	int (*poweroff_late)(struct device___37 *);
	int (*restore_early)(struct device___37 *);
	int (*suspend_noirq)(struct device___37 *);
	int (*resume_noirq)(struct device___37 *);
	int (*freeze_noirq)(struct device___37 *);
	int (*thaw_noirq)(struct device___37 *);
	int (*poweroff_noirq)(struct device___37 *);
	int (*restore_noirq)(struct device___37 *);
	int (*runtime_suspend)(struct device___37 *);
	int (*runtime_resume)(struct device___37 *);
	int (*runtime_idle)(struct device___37 *);
};

struct dev_pm_domain___37 {
	struct dev_pm_ops___37 ops;
	void (*detach)(struct device___37 *, bool);
	int (*activate)(struct device___37 *);
	void (*sync)(struct device___37 *);
	void (*dismiss)(struct device___37 *);
};

struct bus_type___37 {
	const char *name;
	const char *dev_name;
	struct device___37 *dev_root;
	const struct attribute_group___37 **bus_groups;
	const struct attribute_group___37 **dev_groups;
	const struct attribute_group___37 **drv_groups;
	int (*match)(struct device___37 *, struct device_driver___37 *);
	int (*uevent)(struct device___37 *, struct kobj_uevent_env *);
	int (*probe)(struct device___37 *);
	int (*remove)(struct device___37 *);
	void (*shutdown)(struct device___37 *);
	int (*online)(struct device___37 *);
	int (*offline)(struct device___37 *);
	int (*suspend)(struct device___37 *, pm_message_t);
	int (*resume)(struct device___37 *);
	int (*num_vf)(struct device___37 *);
	int (*dma_configure)(struct device___37 *);
	const struct dev_pm_ops___37 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___37 {
	const char *name;
	struct bus_type___37 *bus;
	struct module___39 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___37 *);
	int (*remove)(struct device___37 *);
	void (*shutdown)(struct device___37 *);
	int (*suspend)(struct device___37 *, pm_message_t);
	int (*resume)(struct device___37 *);
	const struct attribute_group___37 **groups;
	const struct dev_pm_ops___37 *pm;
	void (*coredump)(struct device___37 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___37 {
	const char *name;
	const struct attribute_group___37 **groups;
	int (*uevent)(struct device___37 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___37 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___37 *);
	const struct dev_pm_ops___37 *pm;
};

struct class___37 {
	const char *name;
	struct module___39 *owner;
	const struct attribute_group___37 **class_groups;
	const struct attribute_group___37 **dev_groups;
	struct kobject___40 *dev_kobj;
	int (*dev_uevent)(struct device___37 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___37 *, umode_t *);
	void (*class_release)(struct class___37 *);
	void (*dev_release)(struct device___37 *);
	int (*shutdown_pre)(struct device___37 *);
	const struct kobj_ns_type_operations___2 *ns_type;
	const void * (*namespace)(struct device___37 *);
	const struct dev_pm_ops___37 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___35 {
	struct device___37 dev;
};

struct bpf_map___31;

struct bpf_map_ops___31 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___31 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___31 *, struct file___42 *);
	void (*map_free)(struct bpf_map___31 *);
	int (*map_get_next_key)(struct bpf_map___31 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___31 *);
	void * (*map_lookup_elem)(struct bpf_map___31 *, void *);
	int (*map_update_elem)(struct bpf_map___31 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___31 *, void *);
	int (*map_push_elem)(struct bpf_map___31 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___31 *, void *);
	int (*map_peek_elem)(struct bpf_map___31 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___31 *, struct file___42 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___31 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___31 *, void *, struct seq_file___40 *);
	int (*map_check_btf)(const struct bpf_map___31 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___31 {
	const struct bpf_map_ops___31 *ops;
	struct bpf_map___31 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___41 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___31;

typedef void (*kthread_work_func_t___31)(struct kthread_work___31 *);

struct kthread_worker___31;

struct kthread_work___31 {
	struct list_head node;
	kthread_work_func_t___31 func;
	struct kthread_worker___31 *worker;
	int canceling;
};

struct kthread_worker___31 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___43 *task;
	struct kthread_work___31 *current_work;
};

struct kthread_delayed_work___31 {
	struct kthread_work___31 work;
	struct timer_list timer;
};

struct psi_group___31 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___31 *poll_kworker;
	struct kthread_delayed_work___31 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___31;

struct cgroup_rstat_cpu___31;

struct cgroup___31 {
	struct cgroup_subsys_state___31 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___39 *kn;
	struct cgroup_file___31 procs_file;
	struct cgroup_file___31 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___31 *subsys[13];
	struct cgroup_root___31 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___31 *dom_cgrp;
	struct cgroup_rstat_cpu___31 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___3 bpf;
	atomic_t congestion_count;
	struct cgroup___31 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___31 psi;
	int ancestor_ids[0];
};

struct cftype___31;

struct cgroup_subsys___31 {
	struct cgroup_subsys_state___31 * (*css_alloc)(struct cgroup_subsys_state___31 *);
	int (*css_online)(struct cgroup_subsys_state___31 *);
	void (*css_offline)(struct cgroup_subsys_state___31 *);
	void (*css_released)(struct cgroup_subsys_state___31 *);
	void (*css_free)(struct cgroup_subsys_state___31 *);
	void (*css_reset)(struct cgroup_subsys_state___31 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___31 *, int);
	int (*css_extra_stat_show)(struct seq_file___40 *, struct cgroup_subsys_state___31 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___43 *);
	void (*cancel_fork)(struct task_struct___43 *);
	void (*fork)(struct task_struct___43 *);
	void (*exit)(struct task_struct___43 *);
	void (*free)(struct task_struct___43 *);
	void (*bind)(struct cgroup_subsys_state___31 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___31 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___31 *dfl_cftypes;
	struct cftype___31 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___31 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___31 *updated_children;
	struct cgroup___31 *updated_next;
};

struct cgroup_root___31 {
	struct kernfs_root___39 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___31 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___31 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___31 *ss;
	struct list_head node;
	struct kernfs_ops___39 *kf_ops;
	int (*open)(struct kernfs_open_file___39 *);
	void (*release)(struct kernfs_open_file___39 *);
	u64 (*read_u64)(struct cgroup_subsys_state___31 *, struct cftype___31 *);
	s64 (*read_s64)(struct cgroup_subsys_state___31 *, struct cftype___31 *);
	int (*seq_show)(struct seq_file___40 *, void *);
	void * (*seq_start)(struct seq_file___40 *, loff_t *);
	void * (*seq_next)(struct seq_file___40 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___40 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___31 *, struct cftype___31 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___31 *, struct cftype___31 *, s64);
	ssize_t (*write)(struct kernfs_open_file___39 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___39 *, struct poll_table_struct___28 *);
};

struct perf_cpu_context___27;

struct pmu___27 {
	struct list_head entry;
	struct module___39 *module;
	struct device___37 *dev;
	const struct attribute_group___37 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___27 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___27 *);
	void (*pmu_disable)(struct pmu___27 *);
	int (*event_init)(struct perf_event___27 *);
	void (*event_mapped)(struct perf_event___27 *, struct mm_struct___41 *);
	void (*event_unmapped)(struct perf_event___27 *, struct mm_struct___41 *);
	int (*add)(struct perf_event___27 *, int);
	void (*del)(struct perf_event___27 *, int);
	void (*start)(struct perf_event___27 *, int);
	void (*stop)(struct perf_event___27 *, int);
	void (*read)(struct perf_event___27 *);
	void (*start_txn)(struct pmu___27 *, unsigned int);
	int (*commit_txn)(struct pmu___27 *);
	void (*cancel_txn)(struct pmu___27 *);
	int (*event_idx)(struct perf_event___27 *);
	void (*sched_task)(struct perf_event_context___27 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___27 *);
	int (*filter_match)(struct perf_event___27 *);
	int (*check_period)(struct perf_event___27 *, u64);
};

struct perf_cpu_context___27 {
	struct perf_event_context___27 ctx;
	struct perf_event_context___27 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___27 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___27 {
	struct cgroup_subsys_state___31 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___22 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___22 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___22 *);
	struct list_head * (*get_fields)(struct trace_event_call___22 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___22 *);
};

struct bdi_writeback_congested___17 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___17 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___17 {
	struct bio___17 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___17 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___17 bip_inline_vecs[0];
};

struct bio_set___17 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___17 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___16 {
	struct mem_cgroup___16 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___16 {
	struct lruvec___41 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___16 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___16 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct pipe_buf_operations___9;

struct pipe_buffer___9 {
	struct page___42 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___9 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___9 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___9 *, struct pipe_buffer___9 *);
	void (*release)(struct pipe_inode_info___9 *, struct pipe_buffer___9 *);
	int (*steal)(struct pipe_inode_info___9 *, struct pipe_buffer___9 *);
	union {
		bool (*get)(struct pipe_inode_info___9 *, struct pipe_buffer___9 *);
		struct {
			void (*get)(struct pipe_inode_info___9 *, struct pipe_buffer___9 *);
		} __UNIQUE_ID_rh_kabi_hide37;
		union {		};
	};
};

typedef void (*rcu_callback_t)(struct callback_head *);

struct module___40;

struct file___43;

struct kiocb___43;

struct poll_table_struct___29;

struct vm_area_struct___43;

struct inode___44;

struct file_lock___43;

struct page___43;

struct seq_file___41;

struct file_operations___43 {
	struct module___40 *owner;
	loff_t (*llseek)(struct file___43 *, loff_t, int);
	ssize_t (*read)(struct file___43 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___43 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___43 *, struct iov_iter___19 *);
	ssize_t (*write_iter)(struct kiocb___43 *, struct iov_iter___19 *);
	int (*iopoll)(struct kiocb___43 *, bool);
	int (*iterate)(struct file___43 *, struct dir_context *);
	int (*iterate_shared)(struct file___43 *, struct dir_context *);
	__poll_t (*poll)(struct file___43 *, struct poll_table_struct___29 *);
	long int (*unlocked_ioctl)(struct file___43 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___43 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___43 *, struct vm_area_struct___43 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___44 *, struct file___43 *);
	int (*flush)(struct file___43 *, fl_owner_t);
	int (*release)(struct inode___44 *, struct file___43 *);
	int (*fsync)(struct file___43 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___43 *, int);
	int (*lock)(struct file___43 *, int, struct file_lock___43 *);
	ssize_t (*sendpage)(struct file___43 *, struct page___43 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___43 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___43 *, int, struct file_lock___43 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___43 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___43 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___43 *, long int, struct file_lock___43 **, void **);
	long int (*fallocate)(struct file___43 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___41 *, struct file___43 *);
	ssize_t (*copy_file_range)(struct file___43 *, loff_t, struct file___43 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___43 *, loff_t, struct file___43 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___43 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___42 {
	u64 seqnum;
	struct vm_area_struct___43 *vmas[4];
};

struct page_frag___42 {
	struct page___43 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___28;

struct debug_info___28 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___28 *hbp_break[16];
	struct perf_event___28 *hbp_watch[16];
};

struct thread_struct___28 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___28 debug;
	long: 64;
};

struct mm_struct___42;

struct pid___38;

struct cred___42;

struct nsproxy___41;

struct signal_struct___40;

struct css_set___32;

struct perf_event_context___28;

struct vm_struct___33;

struct task_struct___44 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___44 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___42 *mm;
	struct mm_struct___42 *active_mm;
	struct vmacache___42 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___44 *real_parent;
	struct task_struct___44 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___44 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___38 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___38 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___38 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___42 *ptracer_cred;
	const struct cred___42 *real_cred;
	const struct cred___42 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___41 *nsproxy;
	struct signal_struct___40 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___44 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___9 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___32 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___28 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___42 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___44 *oom_reaper_list;
	struct vm_struct___33 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___28 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___28 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___44 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___28)(struct perf_event___28 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___28;

struct fasync_struct___42;

struct pid_namespace___38;

struct trace_event_call___23;

struct perf_cgroup___28;

struct perf_event___28 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___28 *group_leader;
	struct pmu___28 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___28 hw;
	struct perf_event_context___28 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___28 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___44 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___42 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___28 *);
	struct callback_head callback_head;
	struct pid_namespace___38 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___28 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___28 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___23 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___28 *cgrp;
	struct list_head sb_list;
};

struct upid___38 {
	int nr;
	struct pid_namespace___38 *ns;
};

struct dentry___43;

struct user_namespace___34;

struct ucounts___34;

struct pid_namespace___38 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___44 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___38 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___43 *proc_self;
	struct dentry___43 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___34 *user_ns;
	struct ucounts___34 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___3 ns;
};

struct pid___38 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___38 numbers[1];
};

struct rw_semaphore___43 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___44 *owner;
};

struct key___43;

struct user_namespace___34 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___34 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___3 ns;
	long unsigned int flags;
	struct key___43 *persistent_keyring_register;
	struct rw_semaphore___43 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___34 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct secondary_data___43 {
	void *stack;
	struct task_struct___44 *task;
	long int status;
};

struct clock_event_device___7;

struct arch_timer_erratum_workaround___7 {
	enum arch_timer_erratum_match_type match_type;
	const void *id;
	const char *desc;
	u32 (*read_cntp_tval_el0)();
	u32 (*read_cntv_tval_el0)();
	u64 (*read_cntpct_el0)();
	u64 (*read_cntvct_el0)();
	int (*set_next_event_phys)(long unsigned int, struct clock_event_device___7 *);
	int (*set_next_event_virt)(long unsigned int, struct clock_event_device___7 *);
};

struct clock_event_device___7 {
	void (*event_handler)(struct clock_event_device___7 *);
	int (*set_next_event)(long unsigned int, struct clock_event_device___7 *);
	int (*set_next_ktime)(ktime_t, struct clock_event_device___7 *);
	ktime_t next_event;
	u64 max_delta_ns;
	u64 min_delta_ns;
	u32 mult;
	u32 shift;
	enum clock_event_state state_use_accessors;
	unsigned int features;
	long unsigned int retries;
	int (*set_state_periodic)(struct clock_event_device___7 *);
	int (*set_state_oneshot)(struct clock_event_device___7 *);
	int (*set_state_oneshot_stopped)(struct clock_event_device___7 *);
	int (*set_state_shutdown)(struct clock_event_device___7 *);
	int (*tick_resume)(struct clock_event_device___7 *);
	void (*broadcast)(const struct cpumask *);
	void (*suspend)(struct clock_event_device___7 *);
	void (*resume)(struct clock_event_device___7 *);
	long unsigned int min_delta_ticks;
	long unsigned int max_delta_ticks;
	const char *name;
	int rating;
	int irq;
	int bound_on;
	const struct cpumask *cpumask;
	struct list_head list;
	struct module___40 *owner;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct wq_flusher;

struct worker;

struct workqueue_attrs;

struct pool_workqueue;

struct wq_device;

struct workqueue_struct {
	struct list_head pwqs;
	struct list_head list;
	struct mutex mutex;
	int work_color;
	int flush_color;
	atomic_t nr_pwqs_to_flush;
	struct wq_flusher *first_flusher;
	struct list_head flusher_queue;
	struct list_head flusher_overflow;
	struct list_head maydays;
	struct worker *rescuer;
	int nr_drainers;
	int saved_max_active;
	struct workqueue_attrs *unbound_attrs;
	struct pool_workqueue *dfl_pwq;
	struct wq_device *wq_dev;
	char name[24];
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int flags;
	struct pool_workqueue *cpu_pwqs;
	struct pool_workqueue *numa_pwq_tbl[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct workqueue_attrs {
	int nice;
	cpumask_var_t cpumask;
	bool no_numa;
};

struct execute_work {
	struct work_struct work;
};

enum {
	WQ_UNBOUND = 2,
	WQ_FREEZABLE = 4,
	WQ_MEM_RECLAIM = 8,
	WQ_HIGHPRI = 16,
	WQ_CPU_INTENSIVE = 32,
	WQ_SYSFS = 64,
	WQ_POWER_EFFICIENT = 128,
	__WQ_DRAINING = 65536,
	__WQ_ORDERED = 131072,
	__WQ_LEGACY = 262144,
	__WQ_ORDERED_EXPLICIT = 524288,
	WQ_MAX_ACTIVE = 512,
	WQ_MAX_UNBOUND_PER_CPU = 4,
	WQ_DFL_ACTIVE = 256,
};

typedef struct page___43 *pgtable_t___42;

struct address_space___42;

struct dev_pagemap___42;

struct page___43 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___42 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___43 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___42 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___42 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___42 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct user_struct___42 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___43 *uid_keyring;
	struct key___43 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___42;

struct vm_area_struct___43 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___43 *vm_next;
	struct vm_area_struct___43 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___42 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___42 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___43 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___42;

struct mm_struct___42 {
	struct {
		struct vm_area_struct___43 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___43 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___43 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___42 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___44 *owner;
		struct user_namespace___34 *user_ns;
		struct file___43 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___42 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___42 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___43 *session_keyring;
	struct key___43 *process_keyring;
	struct key___43 *thread_keyring;
	struct key___43 *request_key_auth;
	void *security;
	struct user_struct___42 *user;
	struct user_namespace___34 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___32;

struct nsproxy___41 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___38 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___32 *cgroup_ns;
};

struct signal_struct___40 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___44 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___44 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___38 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___38 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___42 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___38 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide21;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___32;

struct cgroup___32;

struct css_set___32 {
	struct cgroup_subsys_state___32 *subsys[13];
	refcount_t refcount;
	struct css_set___32 *dom_cset;
	struct cgroup___32 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___32 *mg_src_cgrp;
	struct cgroup___32 *mg_dst_cgrp;
	struct css_set___32 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___28 {
	struct pmu___28 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___44 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___28 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___33 {
	struct vm_struct___33 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___43 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___40 {
	struct task_struct___44 task;
	long unsigned int stack[8192];
};

struct pglist_data___42;

struct lruvec___42 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___42 *pgdat;
};

struct zone___42 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___42 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___42 {
	struct zone___42 *zone;
	int zone_idx;
};

struct zonelist___42 {
	struct zoneref___42 _zonerefs[25];
};

struct pglist_data___42 {
	struct zone___42 node_zones[3];
	struct zonelist___42 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___44 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___44 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___42 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___42 {
	struct rw_semaphore___43 rwsem;
	struct notifier_block *head;
};

typedef unsigned int xa_mark_t;

enum xa_lock_type {
	XA_LOCK_IRQ = 1,
	XA_LOCK_BH = 2,
};

struct kernfs_root___40;

struct kernfs_elem_dir___40 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___40 *root;
};

struct kernfs_node___40;

struct kernfs_syscall_ops___40;

struct kernfs_root___40 {
	struct kernfs_node___40 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___40 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___40 {
	struct kernfs_node___40 *target_kn;
};

struct kernfs_ops___40;

struct kernfs_elem_attr___40 {
	const struct kernfs_ops___40 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___40 *notify_next;
};

struct kernfs_node___40 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___40 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___40 dir;
		struct kernfs_elem_symlink___40 symlink;
		struct kernfs_elem_attr___40 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___40;

struct kernfs_ops___40 {
	int (*open)(struct kernfs_open_file___40 *);
	void (*release)(struct kernfs_open_file___40 *);
	int (*seq_show)(struct seq_file___41 *, void *);
	void * (*seq_start)(struct seq_file___41 *, loff_t *);
	void * (*seq_next)(struct seq_file___41 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___41 *, void *);
	ssize_t (*read)(struct kernfs_open_file___40 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___40 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___40 *, struct vm_area_struct___43 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___40 *, struct poll_table_struct___29 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___40 {
	int (*remount_fs)(struct kernfs_root___40 *, int *, char *);
	int (*show_options)(struct seq_file___41 *, struct kernfs_root___40 *);
	int (*mkdir)(struct kernfs_node___40 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___40 *);
	int (*rename)(struct kernfs_node___40 *, struct kernfs_node___40 *, const char *);
	int (*show_path)(struct seq_file___41 *, struct kernfs_node___40 *, struct kernfs_root___40 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___38;

struct seq_file___41 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___38 *op;
	int poll_event;
	const struct file___43 *file;
	void *private;
};

struct kernfs_open_file___40 {
	struct kernfs_node___40 *kn;
	struct file___43 *file;
	struct seq_file___41 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___42 *vm_ops;
};

struct path___42 {
	struct vfsmount *mnt;
	struct dentry___43 *dentry;
};

struct fown_struct___38 {
	rwlock_t lock;
	struct pid___38 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___43 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___42 f_path;
	struct inode___44 *f_inode;
	const struct file_operations___43 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___38 f_owner;
	const struct cred___42 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___42 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___42;

struct vm_operations_struct___42 {
	void (*open)(struct vm_area_struct___43 *);
	void (*close)(struct vm_area_struct___43 *);
	int (*split)(struct vm_area_struct___43 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___43 *);
	vm_fault_t (*fault)(struct vm_fault___42 *);
	vm_fault_t (*huge_fault)(struct vm_fault___42 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___42 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___43 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___42 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___42 *);
	int (*access)(struct vm_area_struct___43 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___43 *);
	int (*set_policy)(struct vm_area_struct___43 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___43 *, long unsigned int);
	struct page___43 * (*find_special_page)(struct vm_area_struct___43 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___28)(struct file___43 *, wait_queue_head_t *, struct poll_table_struct___29 *);

struct poll_table_struct___29 {
	poll_queue_proc___28 _qproc;
	__poll_t _key;
};

struct kobject___41;

struct bin_attribute___38;

struct attribute_group___38 {
	const char *name;
	umode_t (*is_visible)(struct kobject___41 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___41 *, struct bin_attribute___38 *, int);
	struct attribute **attrs;
	struct bin_attribute___38 **bin_attrs;
};

struct kset___40;

struct kobj_type___40;

struct kobject___41 {
	const char *name;
	struct list_head entry;
	struct kobject___41 *parent;
	struct kset___40 *kset;
	struct kobj_type___40 *ktype;
	struct kernfs_node___40 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___38 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___43 *, struct kobject___41 *, struct bin_attribute___38 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___43 *, struct kobject___41 *, struct bin_attribute___38 *, char *, loff_t, size_t);
	int (*mmap)(struct file___43 *, struct kobject___41 *, struct bin_attribute___38 *, struct vm_area_struct___43 *);
};

struct sysfs_ops___40 {
	ssize_t (*show)(struct kobject___41 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___41 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___40;

struct kset___40 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___41 kobj;
	const struct kset_uevent_ops___40 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___40 {
	void (*release)(struct kobject___41 *);
	const struct sysfs_ops___40 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___2 * (*child_ns_type)(struct kobject___41 *);
	const void * (*namespace)(struct kobject___41 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___40 {
	int (* const filter)(struct kset___40 *, struct kobject___41 *);
	const char * (* const name)(struct kset___40 *, struct kobject___41 *);
	int (* const uevent)(struct kset___40 *, struct kobject___41 *, struct kobj_uevent_env *);
};

struct kobj_attribute___41 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___41 *, struct kobj_attribute___41 *, char *);
	ssize_t (*store)(struct kobject___41 *, struct kobj_attribute___41 *, const char *, size_t);
};

struct device___38;

struct dev_pm_ops___38 {
	int (*prepare)(struct device___38 *);
	void (*complete)(struct device___38 *);
	int (*suspend)(struct device___38 *);
	int (*resume)(struct device___38 *);
	int (*freeze)(struct device___38 *);
	int (*thaw)(struct device___38 *);
	int (*poweroff)(struct device___38 *);
	int (*restore)(struct device___38 *);
	int (*suspend_late)(struct device___38 *);
	int (*resume_early)(struct device___38 *);
	int (*freeze_late)(struct device___38 *);
	int (*thaw_early)(struct device___38 *);
	int (*poweroff_late)(struct device___38 *);
	int (*restore_early)(struct device___38 *);
	int (*suspend_noirq)(struct device___38 *);
	int (*resume_noirq)(struct device___38 *);
	int (*freeze_noirq)(struct device___38 *);
	int (*thaw_noirq)(struct device___38 *);
	int (*poweroff_noirq)(struct device___38 *);
	int (*restore_noirq)(struct device___38 *);
	int (*runtime_suspend)(struct device___38 *);
	int (*runtime_resume)(struct device___38 *);
	int (*runtime_idle)(struct device___38 *);
};

struct dev_pm_info___38 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___38 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___38;

struct bus_type___38;

struct device_driver___38;

struct dev_pm_domain___38;

struct device_node___14;

struct fwnode_handle___30;

struct class___38;

struct device___38 {
	struct device___38 *parent;
	struct device_private *p;
	struct kobject___41 kobj;
	const char *init_name;
	const struct device_type___38 *type;
	struct mutex mutex;
	struct bus_type___38 *bus;
	struct device_driver___38 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___38 power;
	struct dev_pm_domain___38 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___14 *of_node;
	struct fwnode_handle___30 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___38 *class;
	const struct attribute_group___38 **groups;
	void (*release)(struct device___38 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___38 {
	struct dev_pm_ops___38 ops;
	void (*detach)(struct device___38 *, bool);
	int (*activate)(struct device___38 *);
	void (*sync)(struct device___38 *);
	void (*dismiss)(struct device___38 *);
};

struct bus_type___38 {
	const char *name;
	const char *dev_name;
	struct device___38 *dev_root;
	const struct attribute_group___38 **bus_groups;
	const struct attribute_group___38 **dev_groups;
	const struct attribute_group___38 **drv_groups;
	int (*match)(struct device___38 *, struct device_driver___38 *);
	int (*uevent)(struct device___38 *, struct kobj_uevent_env *);
	int (*probe)(struct device___38 *);
	int (*remove)(struct device___38 *);
	void (*shutdown)(struct device___38 *);
	int (*online)(struct device___38 *);
	int (*offline)(struct device___38 *);
	int (*suspend)(struct device___38 *, pm_message_t);
	int (*resume)(struct device___38 *);
	int (*num_vf)(struct device___38 *);
	int (*dma_configure)(struct device___38 *);
	const struct dev_pm_ops___38 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___38 {
	const char *name;
	struct bus_type___38 *bus;
	struct module___40 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___38 *);
	int (*remove)(struct device___38 *);
	void (*shutdown)(struct device___38 *);
	int (*suspend)(struct device___38 *, pm_message_t);
	int (*resume)(struct device___38 *);
	const struct attribute_group___38 **groups;
	const struct dev_pm_ops___38 *pm;
	void (*coredump)(struct device___38 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___38 {
	const char *name;
	const struct attribute_group___38 **groups;
	int (*uevent)(struct device___38 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___38 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___38 *);
	const struct dev_pm_ops___38 *pm;
};

struct module_kobject___37 {
	struct kobject___41 kobj;
	struct module___40 *mod;
	struct kobject___41 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___37 {
	struct module___40 *mod;
	struct latch_tree_node node;
};

struct module_layout___37 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___37 mtn;
};

struct module_attribute___37;

struct kernel_param___37;

struct module___40 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___37 mkobj;
	struct module_attribute___37 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___41 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___37 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___37 core_layout;
	struct module_layout___37 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___23 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct class___38 {
	const char *name;
	struct module___40 *owner;
	const struct attribute_group___38 **class_groups;
	const struct attribute_group___38 **dev_groups;
	struct kobject___41 *dev_kobj;
	int (*dev_uevent)(struct device___38 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___38 *, umode_t *);
	void (*class_release)(struct class___38 *);
	void (*dev_release)(struct device___38 *);
	int (*shutdown_pre)(struct device___38 *);
	const struct kobj_ns_type_operations___2 *ns_type;
	const void * (*namespace)(struct device___38 *);
	const struct dev_pm_ops___38 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct device_attribute___5 {
	struct attribute attr;
	ssize_t (*show)(struct device___38 *, struct device_attribute___5 *, char *);
	ssize_t (*store)(struct device___38 *, struct device_attribute___5 *, const char *, size_t);
};

struct fwnode_operations___30;

struct fwnode_handle___30 {
	struct fwnode_handle___30 *secondary;
	const struct fwnode_operations___30 *ops;
};

struct property___14;

struct device_node___14 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___30 fwnode;
	struct property___14 *properties;
	struct property___14 *deadprops;
	struct device_node___14 *parent;
	struct device_node___14 *child;
	struct device_node___14 *sibling;
	struct kobject___41 kobj;
	long unsigned int _flags;
	void *data;
};

struct node___36 {
	struct device___38 dev;
};

struct kthread_work___32;

typedef void (*kthread_work_func_t___32)(struct kthread_work___32 *);

struct kthread_worker___32;

struct kthread_work___32 {
	struct list_head node;
	kthread_work_func_t___32 func;
	struct kthread_worker___32 *worker;
	int canceling;
};

struct kthread_worker___32 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___44 *task;
	struct kthread_work___32 *current_work;
};

struct kthread_delayed_work___32 {
	struct kthread_work___32 work;
	struct timer_list timer;
};

struct dentry_operations___42;

struct super_block___43;

struct dentry___43 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___43 *d_parent;
	struct qstr d_name;
	struct inode___44 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___42 *d_op;
	struct super_block___43 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___42;

struct address_space___42 {
	struct inode___44 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___43 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___42 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___42;

struct block_device___43;

struct inode___44 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___42 *i_op;
	struct super_block___43 *i_sb;
	struct address_space___42 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___43 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___43 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___42 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___43 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___42 {
	int (*d_revalidate)(struct dentry___43 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___43 *, unsigned int);
	int (*d_hash)(const struct dentry___43 *, struct qstr *);
	int (*d_compare)(const struct dentry___43 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___43 *);
	int (*d_init)(struct dentry___43 *);
	void (*d_release)(struct dentry___43 *);
	void (*d_prune)(struct dentry___43 *);
	void (*d_iput)(struct dentry___43 *, struct inode___44 *);
	char * (*d_dname)(struct dentry___43 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___42 *);
	int (*d_manage)(const struct path___42 *, bool);
	struct dentry___43 * (*d_real)(struct dentry___43 *, const struct inode___44 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___42;

struct mem_dqinfo___42 {
	struct quota_format_type___42 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___42;

struct quota_info___42 {
	unsigned int flags;
	struct rw_semaphore___43 dqio_sem;
	struct inode___44 *files[3];
	struct mem_dqinfo___42 info[3];
	const struct quota_format_ops___42 *ops[3];
};

struct rcuwait___42 {
	struct task_struct___44 *task;
};

struct percpu_rw_semaphore___42 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___43 rw_sem;
	struct rcuwait___42 writer;
	int readers_block;
};

struct sb_writers___42 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___42 rw_sem[3];
};

struct file_system_type___42;

struct super_operations___42;

struct dquot_operations___42;

struct quotactl_ops___42;

struct super_block___43 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___42 *s_type;
	const struct super_operations___42 *s_op;
	const struct dquot_operations___42 *dq_op;
	const struct quotactl_ops___42 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___43 *s_root;
	struct rw_semaphore___43 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___43 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___42 s_dquot;
	struct sb_writers___42 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___42 *s_d_op;
	int cleancache_poolid;
	struct shrinker___16 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___34 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

typedef int (*dev_page_fault_t___42)(struct vm_area_struct___43 *, long unsigned int, const struct page___43 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___42)(struct page___43 *, void *);

struct dev_pagemap___42 {
	dev_page_fault_t___42 page_fault;
	dev_page_free_t___42 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___38 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___42 {
	struct task_struct___44 *task;
	struct core_thread___42 *next;
};

struct core_state___42 {
	atomic_t nr_threads;
	struct core_thread___42 dumper;
	struct completion startup;
};

struct vm_fault___42 {
	struct vm_area_struct___43 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___43 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___43 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___42 prealloc_pte;
};

struct kiocb___43 {
	struct file___43 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___43 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___43 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___43 *ia_file;
};

struct dquot___42 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___43 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___42 {
	int qf_fmt_id;
	const struct quota_format_ops___42 *qf_ops;
	struct module___40 *qf_owner;
	struct quota_format_type___42 *qf_next;
};

struct quota_format_ops___42 {
	int (*check_quota_file)(struct super_block___43 *, int);
	int (*read_file_info)(struct super_block___43 *, int);
	int (*write_file_info)(struct super_block___43 *, int);
	int (*free_file_info)(struct super_block___43 *, int);
	int (*read_dqblk)(struct dquot___42 *);
	int (*commit_dqblk)(struct dquot___42 *);
	int (*release_dqblk)(struct dquot___42 *);
	int (*get_next_id)(struct super_block___43 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___42 {
	int (*write_dquot)(struct dquot___42 *);
	struct dquot___42 * (*alloc_dquot)(struct super_block___43 *, int);
	void (*destroy_dquot)(struct dquot___42 *);
	int (*acquire_dquot)(struct dquot___42 *);
	int (*release_dquot)(struct dquot___42 *);
	int (*mark_dirty)(struct dquot___42 *);
	int (*write_info)(struct super_block___43 *, int);
	qsize_t * (*get_reserved_space)(struct inode___44 *);
	int (*get_projid)(struct inode___44 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___44 *, qsize_t *);
	int (*get_next_id)(struct super_block___43 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___42 {
	int (*quota_on)(struct super_block___43 *, int, int, const struct path___42 *);
	int (*quota_off)(struct super_block___43 *, int);
	int (*quota_enable)(struct super_block___43 *, unsigned int);
	int (*quota_disable)(struct super_block___43 *, unsigned int);
	int (*quota_sync)(struct super_block___43 *, int);
	int (*set_info)(struct super_block___43 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___43 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___43 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___43 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___43 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___43 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___42 {
	int (*writepage)(struct page___43 *, struct writeback_control___3 *);
	int (*readpage)(struct file___43 *, struct page___43 *);
	int (*writepages)(struct address_space___42 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___43 *);
	int (*readpages)(struct file___43 *, struct address_space___42 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___43 *, struct address_space___42 *, loff_t, unsigned int, unsigned int, struct page___43 **, void **);
	int (*write_end)(struct file___43 *, struct address_space___42 *, loff_t, unsigned int, unsigned int, struct page___43 *, void *);
	sector_t (*bmap)(struct address_space___42 *, sector_t);
	void (*invalidatepage)(struct page___43 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___43 *, gfp_t);
	void (*freepage)(struct page___43 *);
	ssize_t (*direct_IO)(struct kiocb___43 *, struct iov_iter___19 *);
	int (*migratepage)(struct address_space___42 *, struct page___43 *, struct page___43 *, enum migrate_mode);
	bool (*isolate_page)(struct page___43 *, isolate_mode_t);
	void (*putback_page)(struct page___43 *);
	int (*launder_page)(struct page___43 *);
	int (*is_partially_uptodate)(struct page___43 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___43 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___42 *, struct page___43 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___43 *, sector_t *);
	void (*swap_deactivate)(struct file___43 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___43 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___44 *bd_inode;
	struct super_block___43 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___43 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___42 {
	struct dentry___43 * (*lookup)(struct inode___44 *, struct dentry___43 *, unsigned int);
	const char * (*get_link)(struct dentry___43 *, struct inode___44 *, struct delayed_call *);
	int (*permission)(struct inode___44 *, int);
	struct posix_acl * (*get_acl)(struct inode___44 *, int);
	int (*readlink)(struct dentry___43 *, char *, int);
	int (*create)(struct inode___44 *, struct dentry___43 *, umode_t, bool);
	int (*link)(struct dentry___43 *, struct inode___44 *, struct dentry___43 *);
	int (*unlink)(struct inode___44 *, struct dentry___43 *);
	int (*symlink)(struct inode___44 *, struct dentry___43 *, const char *);
	int (*mkdir)(struct inode___44 *, struct dentry___43 *, umode_t);
	int (*rmdir)(struct inode___44 *, struct dentry___43 *);
	int (*mknod)(struct inode___44 *, struct dentry___43 *, umode_t, dev_t);
	int (*rename)(struct inode___44 *, struct dentry___43 *, struct inode___44 *, struct dentry___43 *, unsigned int);
	int (*setattr)(struct dentry___43 *, struct iattr___43 *);
	int (*getattr)(const struct path___42 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___43 *, char *, size_t);
	int (*fiemap)(struct inode___44 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___44 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___44 *, struct dentry___43 *, struct file___43 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___44 *, struct dentry___43 *, umode_t);
	int (*set_acl)(struct inode___44 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___42 {
	void (*fl_copy_lock)(struct file_lock___43 *, struct file_lock___43 *);
	void (*fl_release_private)(struct file_lock___43 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___42;

struct file_lock___43 {
	struct file_lock___43 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___43 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___42 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___42 *fl_ops;
	const struct lock_manager_operations___42 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___42 {
	int (*lm_compare_owner)(struct file_lock___43 *, struct file_lock___43 *);
	long unsigned int (*lm_owner_key)(struct file_lock___43 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___43 *);
	int (*lm_grant)(struct file_lock___43 *, int);
	bool (*lm_break)(struct file_lock___43 *);
	int (*lm_change)(struct file_lock___43 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___43 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___42 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___42 *fa_next;
	struct file___43 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___42 {
	const char *name;
	int fs_flags;
	struct dentry___43 * (*mount)(struct file_system_type___42 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___43 *);
	struct module___40 *owner;
	struct file_system_type___42 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___42 {
	struct inode___44 * (*alloc_inode)(struct super_block___43 *);
	void (*destroy_inode)(struct inode___44 *);
	void (*dirty_inode)(struct inode___44 *, int);
	int (*write_inode)(struct inode___44 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___44 *);
	void (*evict_inode)(struct inode___44 *);
	void (*put_super)(struct super_block___43 *);
	int (*sync_fs)(struct super_block___43 *, int);
	int (*freeze_super)(struct super_block___43 *);
	int (*freeze_fs)(struct super_block___43 *);
	int (*thaw_super)(struct super_block___43 *);
	int (*unfreeze_fs)(struct super_block___43 *);
	int (*statfs)(struct dentry___43 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___43 *, int *, char *);
	void (*umount_begin)(struct super_block___43 *);
	int (*show_options)(struct seq_file___41 *, struct dentry___43 *);
	int (*show_devname)(struct seq_file___41 *, struct dentry___43 *);
	int (*show_path)(struct seq_file___41 *, struct dentry___43 *);
	int (*show_stats)(struct seq_file___41 *, struct dentry___43 *);
	ssize_t (*quota_read)(struct super_block___43 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___43 *, int, const char *, size_t, loff_t);
	struct dquot___42 ** (*get_dquots)(struct inode___44 *);
	int (*bdev_try_to_free_page)(struct super_block___43 *, struct page___43 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___43 *, struct shrink_control___16 *);
	long int (*free_cached_objects)(struct super_block___43 *, struct shrink_control___16 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___42(struct page___43 *);

struct __una_u32 {
	u32 x;
};

struct kernel_param_ops___37 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___37 *);
	int (*get)(char *, const struct kernel_param___37 *);
	void (*free)(void *);
};

struct kparam_array___37;

struct kernel_param___37 {
	const char *name;
	struct module___40 *mod;
	const struct kernel_param_ops___37 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___37 *arr;
	};
};

struct kparam_array___37 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___37 *ops;
	void *elem;
};

struct fwnode_reference_args___30;

struct fwnode_endpoint___30;

struct fwnode_operations___30 {
	struct fwnode_handle___30 * (*get)(struct fwnode_handle___30 *);
	void (*put)(struct fwnode_handle___30 *);
	bool (*device_is_available)(const struct fwnode_handle___30 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___30 *, const struct device___38 *);
	bool (*property_present)(const struct fwnode_handle___30 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___30 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___30 *, const char *, const char **, size_t);
	struct fwnode_handle___30 * (*get_parent)(const struct fwnode_handle___30 *);
	struct fwnode_handle___30 * (*get_next_child_node)(const struct fwnode_handle___30 *, struct fwnode_handle___30 *);
	struct fwnode_handle___30 * (*get_named_child_node)(const struct fwnode_handle___30 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___30 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___30 *);
	struct fwnode_handle___30 * (*graph_get_next_endpoint)(const struct fwnode_handle___30 *, struct fwnode_handle___30 *);
	struct fwnode_handle___30 * (*graph_get_remote_endpoint)(const struct fwnode_handle___30 *);
	struct fwnode_handle___30 * (*graph_get_port_parent)(struct fwnode_handle___30 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___30 *, struct fwnode_endpoint___30 *);
};

struct fwnode_endpoint___30 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___30 *local_fwnode;
};

struct fwnode_reference_args___30 {
	struct fwnode_handle___30 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct property___14 {
	char *name;
	int length;
	void *value;
	struct property___14 *next;
	long unsigned int _flags;
	struct bin_attribute___38 attr;
};

struct worker_pool;

struct worker {
	union {
		struct list_head entry;
		struct hlist_node hentry;
	};
	struct work_struct *current_work;
	work_func_t current_func;
	struct pool_workqueue *current_pwq;
	struct list_head scheduled;
	struct task_struct___44 *task;
	struct worker_pool *pool;
	struct list_head node;
	long unsigned int last_active;
	unsigned int flags;
	int id;
	char desc[24];
	struct workqueue_struct *rescue_wq;
	work_func_t last_func;
};

struct pool_workqueue {
	struct worker_pool *pool;
	struct workqueue_struct *wq;
	int work_color;
	int flush_color;
	int refcnt;
	int nr_in_flight[15];
	int nr_active;
	int max_active;
	struct list_head delayed_works;
	struct list_head pwqs_node;
	struct list_head mayday_node;
	struct work_struct unbound_release_work;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct worker_pool {
	spinlock_t lock;
	int cpu;
	int node;
	int id;
	unsigned int flags;
	long unsigned int watchdog_ts;
	struct list_head worklist;
	int nr_workers;
	int nr_idle;
	struct list_head idle_list;
	struct timer_list idle_timer;
	struct timer_list mayday_timer;
	struct hlist_head busy_hash[64];
	struct worker *manager;
	struct list_head workers;
	struct completion *detach_completion;
	struct ida worker_ida;
	struct workqueue_attrs *attrs;
	struct hlist_node hash_node;
	int refcnt;
	long: 32;
	long: 64;
	long: 64;
	atomic_t nr_running;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

enum {
	POOL_MANAGER_ACTIVE = 1,
	POOL_DISASSOCIATED = 4,
	WORKER_DIE = 2,
	WORKER_IDLE = 4,
	WORKER_PREP = 8,
	WORKER_CPU_INTENSIVE = 64,
	WORKER_UNBOUND = 128,
	WORKER_REBOUND = 256,
	WORKER_NOT_RUNNING = 456,
	NR_STD_WORKER_POOLS = 2,
	UNBOUND_POOL_HASH_ORDER = 6,
	BUSY_WORKER_HASH_ORDER = 6,
	MAX_IDLE_WORKERS_RATIO = 4,
	IDLE_WORKER_TIMEOUT = 30000,
	MAYDAY_INITIAL_TIMEOUT = 2,
	MAYDAY_INTERVAL = 10,
	CREATE_COOLDOWN = 100,
	RESCUER_NICE_LEVEL = 4294967276,
	HIGHPRI_NICE_LEVEL = 4294967276,
	WQ_NAME_LEN = 24,
};

struct wq_flusher {
	struct list_head list;
	int flush_color;
	struct completion done;
};

struct wq_device {
	struct workqueue_struct *wq;
	struct device___38 dev;
};

typedef int (*key_restrict_link_func_t___42)(struct key___43 *, const struct key_type *, const union key_payload *, struct key___43 *);

struct key_restriction___43;

struct key___43 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___43 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___43 *restrict_link;
};

struct key_restriction___43 {
	key_restrict_link_func_t___42 check;
	struct key___43 *key;
	struct key_type *keytype;
};

struct seq_operations___38 {
	void * (*start)(struct seq_file___41 *, loff_t *);
	void (*stop)(struct seq_file___41 *, void *);
	void * (*next)(struct seq_file___41 *, void *, loff_t *);
	int (*show)(struct seq_file___41 *, void *);
};

struct cgroup_namespace___32 {
	refcount_t count;
	struct ns_common___3 ns;
	struct user_namespace___34 *user_ns;
	struct ucounts___34 *ucounts;
	struct css_set___32 *root_cset;
};

struct ucounts___34 {
	struct hlist_node node;
	struct user_namespace___34 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct module_attribute___37 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___37 *, struct module_kobject___37 *, char *);
	ssize_t (*store)(struct module_attribute___37 *, struct module_kobject___37 *, const char *, size_t);
	void (*setup)(struct module___40 *, const char *);
	int (*test)(struct module___40 *);
	void (*free)(struct module___40 *);
};

struct trace_event_class___23;

struct trace_event_call___23 {
	struct list_head list;
	struct trace_event_class___23 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___3 *prog_array;
	int (*perf_perm)(struct trace_event_call___23 *, struct perf_event___28 *);
};

struct bpf_map___32;

struct bpf_map_ops___32 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___32 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___32 *, struct file___43 *);
	void (*map_free)(struct bpf_map___32 *);
	int (*map_get_next_key)(struct bpf_map___32 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___32 *);
	void * (*map_lookup_elem)(struct bpf_map___32 *, void *);
	int (*map_update_elem)(struct bpf_map___32 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___32 *, void *);
	int (*map_push_elem)(struct bpf_map___32 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___32 *, void *);
	int (*map_peek_elem)(struct bpf_map___32 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___32 *, struct file___43 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___32 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___32 *, void *, struct seq_file___41 *);
	int (*map_check_btf)(const struct bpf_map___32 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___32 {
	const struct bpf_map_ops___32 *ops;
	struct bpf_map___32 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___42 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct psi_group___32 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___32 *poll_kworker;
	struct kthread_delayed_work___32 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___32 {
	struct kernfs_node___40 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___32;

struct cgroup_subsys_state___32 {
	struct cgroup___32 *cgroup;
	struct cgroup_subsys___32 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___32 *parent;
};

struct cgroup_root___32;

struct cgroup_rstat_cpu___32;

struct cgroup___32 {
	struct cgroup_subsys_state___32 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___40 *kn;
	struct cgroup_file___32 procs_file;
	struct cgroup_file___32 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___32 *subsys[13];
	struct cgroup_root___32 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___32 *dom_cgrp;
	struct cgroup_rstat_cpu___32 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___3 bpf;
	atomic_t congestion_count;
	struct cgroup___32 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___32 psi;
	int ancestor_ids[0];
};

struct cftype___32;

struct cgroup_subsys___32 {
	struct cgroup_subsys_state___32 * (*css_alloc)(struct cgroup_subsys_state___32 *);
	int (*css_online)(struct cgroup_subsys_state___32 *);
	void (*css_offline)(struct cgroup_subsys_state___32 *);
	void (*css_released)(struct cgroup_subsys_state___32 *);
	void (*css_free)(struct cgroup_subsys_state___32 *);
	void (*css_reset)(struct cgroup_subsys_state___32 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___32 *, int);
	int (*css_extra_stat_show)(struct seq_file___41 *, struct cgroup_subsys_state___32 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___44 *);
	void (*cancel_fork)(struct task_struct___44 *);
	void (*fork)(struct task_struct___44 *);
	void (*exit)(struct task_struct___44 *);
	void (*free)(struct task_struct___44 *);
	void (*bind)(struct cgroup_subsys_state___32 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___32 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___32 *dfl_cftypes;
	struct cftype___32 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___32 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___32 *updated_children;
	struct cgroup___32 *updated_next;
};

struct cgroup_root___32 {
	struct kernfs_root___40 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___32 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___32 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___32 *ss;
	struct list_head node;
	struct kernfs_ops___40 *kf_ops;
	int (*open)(struct kernfs_open_file___40 *);
	void (*release)(struct kernfs_open_file___40 *);
	u64 (*read_u64)(struct cgroup_subsys_state___32 *, struct cftype___32 *);
	s64 (*read_s64)(struct cgroup_subsys_state___32 *, struct cftype___32 *);
	int (*seq_show)(struct seq_file___41 *, void *);
	void * (*seq_start)(struct seq_file___41 *, loff_t *);
	void * (*seq_next)(struct seq_file___41 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___41 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___32 *, struct cftype___32 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___32 *, struct cftype___32 *, s64);
	ssize_t (*write)(struct kernfs_open_file___40 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___40 *, struct poll_table_struct___29 *);
};

struct perf_cpu_context___28;

struct pmu___28 {
	struct list_head entry;
	struct module___40 *module;
	struct device___38 *dev;
	const struct attribute_group___38 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___28 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___28 *);
	void (*pmu_disable)(struct pmu___28 *);
	int (*event_init)(struct perf_event___28 *);
	void (*event_mapped)(struct perf_event___28 *, struct mm_struct___42 *);
	void (*event_unmapped)(struct perf_event___28 *, struct mm_struct___42 *);
	int (*add)(struct perf_event___28 *, int);
	void (*del)(struct perf_event___28 *, int);
	void (*start)(struct perf_event___28 *, int);
	void (*stop)(struct perf_event___28 *, int);
	void (*read)(struct perf_event___28 *);
	void (*start_txn)(struct pmu___28 *, unsigned int);
	int (*commit_txn)(struct pmu___28 *);
	void (*cancel_txn)(struct pmu___28 *);
	int (*event_idx)(struct perf_event___28 *);
	void (*sched_task)(struct perf_event_context___28 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___28 *);
	int (*filter_match)(struct perf_event___28 *);
	int (*check_period)(struct perf_event___28 *, u64);
};

struct perf_cpu_context___28 {
	struct perf_event_context___28 ctx;
	struct perf_event_context___28 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___28 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___28 {
	struct cgroup_subsys_state___32 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___23 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___23 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___23 *);
	struct list_head * (*get_fields)(struct trace_event_call___23 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___23 *);
};

struct trace_event_file___9;

struct trace_event_buffer___9 {
	struct ring_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___9 *trace_file;
	void *entry;
	long unsigned int flags;
	int pc;
};

struct trace_event_file___9 {
	struct list_head list;
	struct trace_event_call___23 *event_call;
	struct event_filter *filter;
	struct dentry___43 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_workqueue_work {
	struct trace_entry ent;
	void *work;
	char __data[0];
};

struct trace_event_raw_workqueue_queue_work {
	struct trace_entry ent;
	void *work;
	void *function;
	void *workqueue;
	unsigned int req_cpu;
	unsigned int cpu;
	char __data[0];
};

struct trace_event_raw_workqueue_execute_start {
	struct trace_entry ent;
	void *work;
	void *function;
	char __data[0];
};

struct trace_event_data_offsets_workqueue_work {};

struct trace_event_data_offsets_workqueue_queue_work {};

struct trace_event_data_offsets_workqueue_execute_start {};

struct wq_barrier {
	struct work_struct work;
	struct completion done;
	struct task_struct___44 *task;
};

struct cwt_wait {
	wait_queue_entry_t wait;
	struct work_struct *work;
};

struct apply_wqattrs_ctx {
	struct workqueue_struct *wq;
	struct workqueue_attrs *attrs;
	struct list_head list;
	struct pool_workqueue *dfl_pwq;
	struct pool_workqueue *pwq_tbl[0];
};

struct work_for_cpu {
	struct work_struct work;
	long int (*fn)(void *);
	void *arg;
	long int ret;
};

struct module___41;

struct file___44;

struct kiocb___44;

struct iov_iter___20;

struct poll_table_struct___30;

struct vm_area_struct___44;

struct inode___45;

struct file_lock___44;

struct page___44;

struct pipe_inode_info___10;

struct seq_file___42;

struct file_operations___44 {
	struct module___41 *owner;
	loff_t (*llseek)(struct file___44 *, loff_t, int);
	ssize_t (*read)(struct file___44 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___44 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___44 *, struct iov_iter___20 *);
	ssize_t (*write_iter)(struct kiocb___44 *, struct iov_iter___20 *);
	int (*iopoll)(struct kiocb___44 *, bool);
	int (*iterate)(struct file___44 *, struct dir_context *);
	int (*iterate_shared)(struct file___44 *, struct dir_context *);
	__poll_t (*poll)(struct file___44 *, struct poll_table_struct___30 *);
	long int (*unlocked_ioctl)(struct file___44 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___44 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___44 *, struct vm_area_struct___44 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___45 *, struct file___44 *);
	int (*flush)(struct file___44 *, fl_owner_t);
	int (*release)(struct inode___45 *, struct file___44 *);
	int (*fsync)(struct file___44 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___44 *, int);
	int (*lock)(struct file___44 *, int, struct file_lock___44 *);
	ssize_t (*sendpage)(struct file___44 *, struct page___44 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___44 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___44 *, int, struct file_lock___44 *);
	ssize_t (*splice_write)(struct pipe_inode_info___10 *, struct file___44 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___44 *, loff_t *, struct pipe_inode_info___10 *, size_t, unsigned int);
	int (*setlease)(struct file___44 *, long int, struct file_lock___44 **, void **);
	long int (*fallocate)(struct file___44 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___42 *, struct file___44 *);
	ssize_t (*copy_file_range)(struct file___44 *, loff_t, struct file___44 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___44 *, loff_t, struct file___44 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___44 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___43 {
	u64 seqnum;
	struct vm_area_struct___44 *vmas[4];
};

struct page_frag___43 {
	struct page___44 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___29;

struct debug_info___29 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___29 *hbp_break[16];
	struct perf_event___29 *hbp_watch[16];
};

struct thread_struct___29 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___29 debug;
	long: 64;
};

struct mm_struct___43;

struct pid___39;

struct cred___43;

struct nsproxy___42;

struct signal_struct___41;

struct css_set___33;

struct perf_event_context___29;

struct vm_struct___34;

struct task_struct___45 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___45 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___43 *mm;
	struct mm_struct___43 *active_mm;
	struct vmacache___43 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___45 *real_parent;
	struct task_struct___45 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___45 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___39 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___39 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___39 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___43 *ptracer_cred;
	const struct cred___43 *real_cred;
	const struct cred___43 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___42 *nsproxy;
	struct signal_struct___41 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___45 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___9 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___33 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___29 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___10 *splice_pipe;
	struct page_frag___43 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___45 *oom_reaper_list;
	struct vm_struct___34 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___29 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___29 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___45 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___29)(struct perf_event___29 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___29;

struct fasync_struct___43;

struct pid_namespace___39;

struct trace_event_call___24;

struct perf_cgroup___29;

struct perf_event___29 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___29 *group_leader;
	struct pmu___29 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___29 hw;
	struct perf_event_context___29 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___29 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___45 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___43 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___29 *);
	struct callback_head callback_head;
	struct pid_namespace___39 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___29 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___29 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___24 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___29 *cgrp;
	struct list_head sb_list;
};

typedef struct page___44 *pgtable_t___43;

struct address_space___43;

struct dev_pagemap___43;

struct page___44 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___43 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___44 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___43 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___43 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___43 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___43;

struct lruvec___43 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___43 *pgdat;
};

struct zone___43 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___43 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___43 {
	struct zone___43 *zone;
	int zone_idx;
};

struct zonelist___43 {
	struct zoneref___43 _zonerefs[25];
};

struct pglist_data___43 {
	struct zone___43 node_zones[3];
	struct zonelist___43 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___45 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___45 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___43 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___44 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___45 *owner;
};

struct secondary_data___44 {
	void *stack;
	struct task_struct___45 *task;
	long int status;
};

struct blocking_notifier_head___43 {
	struct rw_semaphore___44 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___43;

struct vm_area_struct___44 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___44 *vm_next;
	struct vm_area_struct___44 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___43 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___43 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___44 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___43;

struct user_namespace___35;

struct mm_struct___43 {
	struct {
		struct vm_area_struct___44 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___44 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___44 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___43 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___45 *owner;
		struct user_namespace___35 *user_ns;
		struct file___44 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___43 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___43;

struct address_space___43 {
	struct inode___45 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___44 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___43 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___43)(struct vm_area_struct___44 *, long unsigned int, const struct page___44 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___43)(struct page___44 *, void *);

struct device___39;

struct dev_pagemap___43 {
	dev_page_fault_t___43 page_fault;
	dev_page_free_t___43 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___39 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct dentry___44;

struct path___43 {
	struct vfsmount *mnt;
	struct dentry___44 *dentry;
};

struct fown_struct___39 {
	rwlock_t lock;
	struct pid___39 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___44 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___43 f_path;
	struct inode___45 *f_inode;
	const struct file_operations___44 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___39 f_owner;
	const struct cred___43 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___43 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___43;

struct vm_operations_struct___43 {
	void (*open)(struct vm_area_struct___44 *);
	void (*close)(struct vm_area_struct___44 *);
	int (*split)(struct vm_area_struct___44 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___44 *);
	vm_fault_t (*fault)(struct vm_fault___43 *);
	vm_fault_t (*huge_fault)(struct vm_fault___43 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___43 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___44 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___43 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___43 *);
	int (*access)(struct vm_area_struct___44 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___44 *);
	int (*set_policy)(struct vm_area_struct___44 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___44 *, long unsigned int);
	struct page___44 * (*find_special_page)(struct vm_area_struct___44 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___43 {
	struct task_struct___45 *task;
	struct core_thread___43 *next;
};

struct core_state___43 {
	atomic_t nr_threads;
	struct core_thread___43 dumper;
	struct completion startup;
};

struct proc_ns_operations___4;

struct ns_common___4 {
	atomic_long_t stashed;
	const struct proc_ns_operations___4 *ops;
	unsigned int inum;
};

struct key___44;

struct ucounts___35;

struct user_namespace___35 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___35 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___4 ns;
	long unsigned int flags;
	struct key___44 *persistent_keyring_register;
	struct rw_semaphore___44 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___35 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___43 {
	struct vm_area_struct___44 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___44 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___44 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___43 prealloc_pte;
};

struct upid___39 {
	int nr;
	struct pid_namespace___39 *ns;
};

struct pid_namespace___39 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___45 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___39 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___44 *proc_self;
	struct dentry___44 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___35 *user_ns;
	struct ucounts___35 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___4 ns;
};

struct pid___39 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___39 numbers[1];
};

struct user_struct___43 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___44 *uid_keyring;
	struct key___44 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___43 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___44 *session_keyring;
	struct key___44 *process_keyring;
	struct key___44 *thread_keyring;
	struct key___44 *request_key_auth;
	void *security;
	struct user_struct___43 *user;
	struct user_namespace___35 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct uts_namespace___10;

struct net___11;

struct cgroup_namespace___33;

struct nsproxy___42 {
	atomic_t count;
	struct uts_namespace___10 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___39 *pid_ns_for_children;
	struct net___11 *net_ns;
	struct cgroup_namespace___33 *cgroup_ns;
};

struct signal_struct___41 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___45 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___45 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___39 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___39 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___43 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___39 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___33;

struct cgroup___33;

struct css_set___33 {
	struct cgroup_subsys_state___33 *subsys[13];
	refcount_t refcount;
	struct css_set___33 *dom_cset;
	struct cgroup___33 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___33 *mg_src_cgrp;
	struct cgroup___33 *mg_dst_cgrp;
	struct css_set___33 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___29 {
	struct pmu___29 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___45 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___29 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___10;

struct pipe_inode_info___10 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___44 *tmp_page;
	struct fasync_struct___43 *fasync_readers;
	struct fasync_struct___43 *fasync_writers;
	struct pipe_buffer___10 *bufs;
	struct user_struct___43 *user;
};

struct vm_struct___34 {
	struct vm_struct___34 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___44 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___41 {
	struct task_struct___45 task;
	long unsigned int stack[8192];
};

struct kset___41;

struct kobj_type___41;

struct kernfs_node___41;

struct kobject___42 {
	const char *name;
	struct list_head entry;
	struct kobject___42 *parent;
	struct kset___41 *kset;
	struct kobj_type___41 *ktype;
	struct kernfs_node___41 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___39 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___39 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___39;

struct bus_type___39;

struct device_driver___39;

struct dev_pm_domain___39;

struct dma_map_ops___11;

struct fwnode_handle___31;

struct class___39;

struct attribute_group___39;

struct device___39 {
	struct device___39 *parent;
	struct device_private *p;
	struct kobject___42 kobj;
	const char *init_name;
	const struct device_type___39 *type;
	struct mutex mutex;
	struct bus_type___39 *bus;
	struct device_driver___39 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___39 power;
	struct dev_pm_domain___39 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___11 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___31 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___39 *class;
	const struct attribute_group___39 **groups;
	void (*release)(struct device___39 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___43;

struct super_block___44;

struct dentry___44 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___44 *d_parent;
	struct qstr d_name;
	struct inode___45 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___43 *d_op;
	struct super_block___44 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___43;

struct block_device___44;

struct inode___45 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___43 *i_op;
	struct super_block___44 *i_sb;
	struct address_space___43 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___44 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___44 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___43 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___10 *i_pipe;
		struct block_device___44 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___43 {
	int (*d_revalidate)(struct dentry___44 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___44 *, unsigned int);
	int (*d_hash)(const struct dentry___44 *, struct qstr *);
	int (*d_compare)(const struct dentry___44 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___44 *);
	int (*d_init)(struct dentry___44 *);
	void (*d_release)(struct dentry___44 *);
	void (*d_prune)(struct dentry___44 *);
	void (*d_iput)(struct dentry___44 *, struct inode___45 *);
	char * (*d_dname)(struct dentry___44 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___43 *);
	int (*d_manage)(const struct path___43 *, bool);
	struct dentry___44 * (*d_real)(struct dentry___44 *, const struct inode___45 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___43;

struct mem_dqinfo___43 {
	struct quota_format_type___43 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___43;

struct quota_info___43 {
	unsigned int flags;
	struct rw_semaphore___44 dqio_sem;
	struct inode___45 *files[3];
	struct mem_dqinfo___43 info[3];
	const struct quota_format_ops___43 *ops[3];
};

struct rcuwait___43 {
	struct task_struct___45 *task;
};

struct percpu_rw_semaphore___43 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___44 rw_sem;
	struct rcuwait___43 writer;
	int readers_block;
};

struct sb_writers___43 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___43 rw_sem[3];
};

struct file_system_type___43;

struct super_operations___43;

struct dquot_operations___43;

struct quotactl_ops___43;

struct super_block___44 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___43 *s_type;
	const struct super_operations___43 *s_op;
	const struct dquot_operations___43 *dq_op;
	const struct quotactl_ops___43 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___44 *s_root;
	struct rw_semaphore___44 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___44 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___43 s_dquot;
	struct sb_writers___43 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___43 *s_d_op;
	int cleancache_poolid;
	struct shrinker___16 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___35 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___44 {
	struct file___44 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___44 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___44 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___44 *ia_file;
};

struct dquot___43 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___44 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___43 {
	int qf_fmt_id;
	const struct quota_format_ops___43 *qf_ops;
	struct module___41 *qf_owner;
	struct quota_format_type___43 *qf_next;
};

struct quota_format_ops___43 {
	int (*check_quota_file)(struct super_block___44 *, int);
	int (*read_file_info)(struct super_block___44 *, int);
	int (*write_file_info)(struct super_block___44 *, int);
	int (*free_file_info)(struct super_block___44 *, int);
	int (*read_dqblk)(struct dquot___43 *);
	int (*commit_dqblk)(struct dquot___43 *);
	int (*release_dqblk)(struct dquot___43 *);
	int (*get_next_id)(struct super_block___44 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___43 {
	int (*write_dquot)(struct dquot___43 *);
	struct dquot___43 * (*alloc_dquot)(struct super_block___44 *, int);
	void (*destroy_dquot)(struct dquot___43 *);
	int (*acquire_dquot)(struct dquot___43 *);
	int (*release_dquot)(struct dquot___43 *);
	int (*mark_dirty)(struct dquot___43 *);
	int (*write_info)(struct super_block___44 *, int);
	qsize_t * (*get_reserved_space)(struct inode___45 *);
	int (*get_projid)(struct inode___45 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___45 *, qsize_t *);
	int (*get_next_id)(struct super_block___44 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___43 {
	int (*quota_on)(struct super_block___44 *, int, int, const struct path___43 *);
	int (*quota_off)(struct super_block___44 *, int);
	int (*quota_enable)(struct super_block___44 *, unsigned int);
	int (*quota_disable)(struct super_block___44 *, unsigned int);
	int (*quota_sync)(struct super_block___44 *, int);
	int (*set_info)(struct super_block___44 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___44 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___44 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___44 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___44 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___44 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___38 {
	struct kobject___42 kobj;
	struct module___41 *mod;
	struct kobject___42 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___38 {
	struct module___41 *mod;
	struct latch_tree_node node;
};

struct module_layout___38 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___38 mtn;
};

struct module_attribute___38;

struct kernel_param___38;

struct module___41 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___38 mkobj;
	struct module_attribute___38 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___42 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___38 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___38 core_layout;
	struct module_layout___38 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___24 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___43 {
	int (*writepage)(struct page___44 *, struct writeback_control___3 *);
	int (*readpage)(struct file___44 *, struct page___44 *);
	int (*writepages)(struct address_space___43 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___44 *);
	int (*readpages)(struct file___44 *, struct address_space___43 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___44 *, struct address_space___43 *, loff_t, unsigned int, unsigned int, struct page___44 **, void **);
	int (*write_end)(struct file___44 *, struct address_space___43 *, loff_t, unsigned int, unsigned int, struct page___44 *, void *);
	sector_t (*bmap)(struct address_space___43 *, sector_t);
	void (*invalidatepage)(struct page___44 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___44 *, gfp_t);
	void (*freepage)(struct page___44 *);
	ssize_t (*direct_IO)(struct kiocb___44 *, struct iov_iter___20 *);
	int (*migratepage)(struct address_space___43 *, struct page___44 *, struct page___44 *, enum migrate_mode);
	bool (*isolate_page)(struct page___44 *, isolate_mode_t);
	void (*putback_page)(struct page___44 *);
	int (*launder_page)(struct page___44 *);
	int (*is_partially_uptodate)(struct page___44 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___44 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___43 *, struct page___44 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___44 *, sector_t *);
	void (*swap_deactivate)(struct file___44 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct iov_iter___20 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___3 *bvec;
		struct pipe_inode_info___10 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___44 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___45 *bd_inode;
	struct super_block___44 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___44 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___43 {
	struct dentry___44 * (*lookup)(struct inode___45 *, struct dentry___44 *, unsigned int);
	const char * (*get_link)(struct dentry___44 *, struct inode___45 *, struct delayed_call *);
	int (*permission)(struct inode___45 *, int);
	struct posix_acl * (*get_acl)(struct inode___45 *, int);
	int (*readlink)(struct dentry___44 *, char *, int);
	int (*create)(struct inode___45 *, struct dentry___44 *, umode_t, bool);
	int (*link)(struct dentry___44 *, struct inode___45 *, struct dentry___44 *);
	int (*unlink)(struct inode___45 *, struct dentry___44 *);
	int (*symlink)(struct inode___45 *, struct dentry___44 *, const char *);
	int (*mkdir)(struct inode___45 *, struct dentry___44 *, umode_t);
	int (*rmdir)(struct inode___45 *, struct dentry___44 *);
	int (*mknod)(struct inode___45 *, struct dentry___44 *, umode_t, dev_t);
	int (*rename)(struct inode___45 *, struct dentry___44 *, struct inode___45 *, struct dentry___44 *, unsigned int);
	int (*setattr)(struct dentry___44 *, struct iattr___44 *);
	int (*getattr)(const struct path___43 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___44 *, char *, size_t);
	int (*fiemap)(struct inode___45 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___45 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___45 *, struct dentry___44 *, struct file___44 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___45 *, struct dentry___44 *, umode_t);
	int (*set_acl)(struct inode___45 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___43 {
	void (*fl_copy_lock)(struct file_lock___44 *, struct file_lock___44 *);
	void (*fl_release_private)(struct file_lock___44 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___43;

struct file_lock___44 {
	struct file_lock___44 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___44 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___43 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___43 *fl_ops;
	const struct lock_manager_operations___43 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___43 {
	int (*lm_compare_owner)(struct file_lock___44 *, struct file_lock___44 *);
	long unsigned int (*lm_owner_key)(struct file_lock___44 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___44 *);
	int (*lm_grant)(struct file_lock___44 *, int);
	bool (*lm_break)(struct file_lock___44 *);
	int (*lm_change)(struct file_lock___44 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___44 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___43 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___43 *fa_next;
	struct file___44 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___43 {
	const char *name;
	int fs_flags;
	struct dentry___44 * (*mount)(struct file_system_type___43 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___44 *);
	struct module___41 *owner;
	struct file_system_type___43 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___43 {
	struct inode___45 * (*alloc_inode)(struct super_block___44 *);
	void (*destroy_inode)(struct inode___45 *);
	void (*dirty_inode)(struct inode___45 *, int);
	int (*write_inode)(struct inode___45 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___45 *);
	void (*evict_inode)(struct inode___45 *);
	void (*put_super)(struct super_block___44 *);
	int (*sync_fs)(struct super_block___44 *, int);
	int (*freeze_super)(struct super_block___44 *);
	int (*freeze_fs)(struct super_block___44 *);
	int (*thaw_super)(struct super_block___44 *);
	int (*unfreeze_fs)(struct super_block___44 *);
	int (*statfs)(struct dentry___44 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___44 *, int *, char *);
	void (*umount_begin)(struct super_block___44 *);
	int (*show_options)(struct seq_file___42 *, struct dentry___44 *);
	int (*show_devname)(struct seq_file___42 *, struct dentry___44 *);
	int (*show_path)(struct seq_file___42 *, struct dentry___44 *);
	int (*show_stats)(struct seq_file___42 *, struct dentry___44 *);
	ssize_t (*quota_read)(struct super_block___44 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___44 *, int, const char *, size_t, loff_t);
	struct dquot___43 ** (*get_dquots)(struct inode___45 *);
	int (*bdev_try_to_free_page)(struct super_block___44 *, struct page___44 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___44 *, struct shrink_control___16 *);
	long int (*free_cached_objects)(struct super_block___44 *, struct shrink_control___16 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___29)(struct file___44 *, wait_queue_head_t *, struct poll_table_struct___30 *);

struct poll_table_struct___30 {
	poll_queue_proc___29 _qproc;
	__poll_t _key;
};

struct seq_operations___39;

struct seq_file___42 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___39 *op;
	int poll_event;
	const struct file___44 *file;
	void *private;
};

struct kobj_attribute___42 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___42 *, struct kobj_attribute___42 *, char *);
	ssize_t (*store)(struct kobject___42 *, struct kobj_attribute___42 *, const char *, size_t);
};

typedef void compound_page_dtor___43(struct page___44 *);

struct uts_namespace___10 {
	struct kref kref;
	struct new_utsname name;
	struct user_namespace___35 *user_ns;
	struct ucounts___35 *ucounts;
	struct ns_common___4 ns;
};

struct dst_ops___9 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___9 *);
	struct dst_entry___2 * (*check)(struct dst_entry___2 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___2 *);
	unsigned int (*mtu)(const struct dst_entry___2 *);
	u32 * (*cow_metrics)(struct dst_entry___2 *, long unsigned int);
	void (*destroy)(struct dst_entry___2 *);
	void (*ifdown)(struct dst_entry___2 *, struct net_device *, int);
	struct dst_entry___2 * (*negative_advice)(struct dst_entry___2 *);
	void (*link_failure)(struct sk_buff___8 *);
	void (*update_pmtu)(struct dst_entry___2 *, struct sock *, struct sk_buff___8 *, u32);
	void (*redirect)(struct dst_entry___2 *, struct sock *, struct sk_buff___8 *);
	int (*local_out)(struct net___11 *, struct sock *, struct sk_buff___8 *);
	struct neighbour___2 * (*neigh_lookup)(const struct dst_entry___2 *, struct sk_buff___8 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___2 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___8 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___4 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___9 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct sock *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops *notifier_ops;
	struct fib_notifier_ops *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_xfrm___8 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___9 xfrm4_dst_ops;
	struct dst_ops___9 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct net___11 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___35 *user_ns;
	struct ucounts___35 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___4 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___4 ipv4;
	struct netns_ipv6___8 ipv6;
	struct netns_sctp___2 sctp;
	struct netns_nf nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___4 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock *nfnl;
	struct sock *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___8 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cgroup_namespace___33 {
	refcount_t count;
	struct ns_common___4 ns;
	struct user_namespace___35 *user_ns;
	struct ucounts___35 *ucounts;
	struct css_set___33 *root_cset;
};

struct proc_ns_operations___4 {
	const char *name;
	const char *real_ns_name;
	int type;
	struct ns_common___4 * (*get)(struct task_struct___45 *);
	void (*put)(struct ns_common___4 *);
	int (*install)(struct nsproxy___42 *, struct ns_common___4 *);
	struct user_namespace___35 * (*owner)(struct ns_common___4 *);
	struct ns_common___4 * (*get_parent)(struct ns_common___4 *);
};

struct ucounts___35 {
	struct hlist_node node;
	struct user_namespace___35 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct kernfs_root___41;

struct kernfs_elem_dir___41 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___41 *root;
};

struct kernfs_syscall_ops___41;

struct kernfs_root___41 {
	struct kernfs_node___41 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___41 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___41 {
	struct kernfs_node___41 *target_kn;
};

struct kernfs_ops___41;

struct kernfs_elem_attr___41 {
	const struct kernfs_ops___41 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___41 *notify_next;
};

struct kernfs_node___41 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___41 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___41 dir;
		struct kernfs_elem_symlink___41 symlink;
		struct kernfs_elem_attr___41 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___41;

struct kernfs_ops___41 {
	int (*open)(struct kernfs_open_file___41 *);
	void (*release)(struct kernfs_open_file___41 *);
	int (*seq_show)(struct seq_file___42 *, void *);
	void * (*seq_start)(struct seq_file___42 *, loff_t *);
	void * (*seq_next)(struct seq_file___42 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___42 *, void *);
	ssize_t (*read)(struct kernfs_open_file___41 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___41 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___41 *, struct vm_area_struct___44 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___41 *, struct poll_table_struct___30 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___41 {
	int (*remount_fs)(struct kernfs_root___41 *, int *, char *);
	int (*show_options)(struct seq_file___42 *, struct kernfs_root___41 *);
	int (*mkdir)(struct kernfs_node___41 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___41 *);
	int (*rename)(struct kernfs_node___41 *, struct kernfs_node___41 *, const char *);
	int (*show_path)(struct seq_file___42 *, struct kernfs_node___41 *, struct kernfs_root___41 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___41 {
	struct kernfs_node___41 *kn;
	struct file___44 *file;
	struct seq_file___42 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___43 *vm_ops;
};

struct bin_attribute___39;

struct attribute_group___39 {
	const char *name;
	umode_t (*is_visible)(struct kobject___42 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___42 *, struct bin_attribute___39 *, int);
	struct attribute **attrs;
	struct bin_attribute___39 **bin_attrs;
};

struct bin_attribute___39 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___44 *, struct kobject___42 *, struct bin_attribute___39 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___44 *, struct kobject___42 *, struct bin_attribute___39 *, char *, loff_t, size_t);
	int (*mmap)(struct file___44 *, struct kobject___42 *, struct bin_attribute___39 *, struct vm_area_struct___44 *);
};

struct sysfs_ops___41 {
	ssize_t (*show)(struct kobject___42 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___42 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___41;

struct kset___41 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___42 kobj;
	const struct kset_uevent_ops___41 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___41 {
	void (*release)(struct kobject___42 *);
	const struct sysfs_ops___41 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___2 * (*child_ns_type)(struct kobject___42 *);
	const void * (*namespace)(struct kobject___42 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___41 {
	int (* const filter)(struct kset___41 *, struct kobject___42 *);
	const char * (* const name)(struct kset___41 *, struct kobject___42 *);
	int (* const uevent)(struct kset___41 *, struct kobject___42 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___38 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___38 *);
	int (*get)(char *, const struct kernel_param___38 *);
	void (*free)(void *);
};

struct kparam_array___38;

struct kernel_param___38 {
	const char *name;
	struct module___41 *mod;
	const struct kernel_param_ops___38 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___38 *arr;
	};
};

struct kparam_array___38 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___38 *ops;
	void *elem;
};

struct module_attribute___38 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___38 *, struct module_kobject___38 *, char *);
	ssize_t (*store)(struct module_attribute___38 *, struct module_kobject___38 *, const char *, size_t);
	void (*setup)(struct module___41 *, const char *);
	int (*test)(struct module___41 *);
	void (*free)(struct module___41 *);
};

struct trace_event_class___24;

struct trace_event_call___24 {
	struct list_head list;
	struct trace_event_class___24 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___3 *prog_array;
	int (*perf_perm)(struct trace_event_call___24 *, struct perf_event___29 *);
};

typedef int (*key_restrict_link_func_t___43)(struct key___44 *, const struct key_type *, const union key_payload *, struct key___44 *);

struct key_restriction___44;

struct key___44 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___44 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___44 *restrict_link;
};

struct key_restriction___44 {
	key_restrict_link_func_t___43 check;
	struct key___44 *key;
	struct key_type *keytype;
};

struct seq_operations___39 {
	void * (*start)(struct seq_file___42 *, loff_t *);
	void (*stop)(struct seq_file___42 *, void *);
	void * (*next)(struct seq_file___42 *, void *, loff_t *);
	int (*show)(struct seq_file___42 *, void *);
};

struct dev_pm_ops___39 {
	int (*prepare)(struct device___39 *);
	void (*complete)(struct device___39 *);
	int (*suspend)(struct device___39 *);
	int (*resume)(struct device___39 *);
	int (*freeze)(struct device___39 *);
	int (*thaw)(struct device___39 *);
	int (*poweroff)(struct device___39 *);
	int (*restore)(struct device___39 *);
	int (*suspend_late)(struct device___39 *);
	int (*resume_early)(struct device___39 *);
	int (*freeze_late)(struct device___39 *);
	int (*thaw_early)(struct device___39 *);
	int (*poweroff_late)(struct device___39 *);
	int (*restore_early)(struct device___39 *);
	int (*suspend_noirq)(struct device___39 *);
	int (*resume_noirq)(struct device___39 *);
	int (*freeze_noirq)(struct device___39 *);
	int (*thaw_noirq)(struct device___39 *);
	int (*poweroff_noirq)(struct device___39 *);
	int (*restore_noirq)(struct device___39 *);
	int (*runtime_suspend)(struct device___39 *);
	int (*runtime_resume)(struct device___39 *);
	int (*runtime_idle)(struct device___39 *);
};

struct dev_pm_domain___39 {
	struct dev_pm_ops___39 ops;
	void (*detach)(struct device___39 *, bool);
	int (*activate)(struct device___39 *);
	void (*sync)(struct device___39 *);
	void (*dismiss)(struct device___39 *);
};

struct bus_type___39 {
	const char *name;
	const char *dev_name;
	struct device___39 *dev_root;
	const struct attribute_group___39 **bus_groups;
	const struct attribute_group___39 **dev_groups;
	const struct attribute_group___39 **drv_groups;
	int (*match)(struct device___39 *, struct device_driver___39 *);
	int (*uevent)(struct device___39 *, struct kobj_uevent_env *);
	int (*probe)(struct device___39 *);
	int (*remove)(struct device___39 *);
	void (*shutdown)(struct device___39 *);
	int (*online)(struct device___39 *);
	int (*offline)(struct device___39 *);
	int (*suspend)(struct device___39 *, pm_message_t);
	int (*resume)(struct device___39 *);
	int (*num_vf)(struct device___39 *);
	int (*dma_configure)(struct device___39 *);
	const struct dev_pm_ops___39 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___39 {
	const char *name;
	struct bus_type___39 *bus;
	struct module___41 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___39 *);
	int (*remove)(struct device___39 *);
	void (*shutdown)(struct device___39 *);
	int (*suspend)(struct device___39 *, pm_message_t);
	int (*resume)(struct device___39 *);
	const struct attribute_group___39 **groups;
	const struct dev_pm_ops___39 *pm;
	void (*coredump)(struct device___39 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___39 {
	const char *name;
	const struct attribute_group___39 **groups;
	int (*uevent)(struct device___39 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___39 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___39 *);
	const struct dev_pm_ops___39 *pm;
};

struct class___39 {
	const char *name;
	struct module___41 *owner;
	const struct attribute_group___39 **class_groups;
	const struct attribute_group___39 **dev_groups;
	struct kobject___42 *dev_kobj;
	int (*dev_uevent)(struct device___39 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___39 *, umode_t *);
	void (*class_release)(struct class___39 *);
	void (*dev_release)(struct device___39 *);
	int (*shutdown_pre)(struct device___39 *);
	const struct kobj_ns_type_operations___2 *ns_type;
	const void * (*namespace)(struct device___39 *);
	const struct dev_pm_ops___39 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___11 {
	void * (*alloc)(struct device___39 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___39 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___39 *, struct vm_area_struct___44 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___39 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___39 *, struct page___44 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___39 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___39 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___39 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___39 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___39 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___39 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___39 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___39 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___39 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___39 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___39 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___39 *, u64);
	u64 (*get_required_mask)(struct device___39 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___31;

struct fwnode_handle___31 {
	struct fwnode_handle___31 *secondary;
	const struct fwnode_operations___31 *ops;
};

struct fwnode_reference_args___31;

struct fwnode_endpoint___31;

struct fwnode_operations___31 {
	struct fwnode_handle___31 * (*get)(struct fwnode_handle___31 *);
	void (*put)(struct fwnode_handle___31 *);
	bool (*device_is_available)(const struct fwnode_handle___31 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___31 *, const struct device___39 *);
	bool (*property_present)(const struct fwnode_handle___31 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___31 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___31 *, const char *, const char **, size_t);
	struct fwnode_handle___31 * (*get_parent)(const struct fwnode_handle___31 *);
	struct fwnode_handle___31 * (*get_next_child_node)(const struct fwnode_handle___31 *, struct fwnode_handle___31 *);
	struct fwnode_handle___31 * (*get_named_child_node)(const struct fwnode_handle___31 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___31 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___31 *);
	struct fwnode_handle___31 * (*graph_get_next_endpoint)(const struct fwnode_handle___31 *, struct fwnode_handle___31 *);
	struct fwnode_handle___31 * (*graph_get_remote_endpoint)(const struct fwnode_handle___31 *);
	struct fwnode_handle___31 * (*graph_get_port_parent)(struct fwnode_handle___31 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___31 *, struct fwnode_endpoint___31 *);
};

struct fwnode_endpoint___31 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___31 *local_fwnode;
};

struct fwnode_reference_args___31 {
	struct fwnode_handle___31 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___10;

struct pipe_buffer___10 {
	struct page___44 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___10 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___10 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___10 *, struct pipe_buffer___10 *);
	void (*release)(struct pipe_inode_info___10 *, struct pipe_buffer___10 *);
	int (*steal)(struct pipe_inode_info___10 *, struct pipe_buffer___10 *);
	union {
		bool (*get)(struct pipe_inode_info___10 *, struct pipe_buffer___10 *);
		struct {
			void (*get)(struct pipe_inode_info___10 *, struct pipe_buffer___10 *);
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
};

struct node___37 {
	struct device___39 dev;
};

struct bpf_map___33;

struct bpf_map_ops___33 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___33 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___33 *, struct file___44 *);
	void (*map_free)(struct bpf_map___33 *);
	int (*map_get_next_key)(struct bpf_map___33 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___33 *);
	void * (*map_lookup_elem)(struct bpf_map___33 *, void *);
	int (*map_update_elem)(struct bpf_map___33 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___33 *, void *);
	int (*map_push_elem)(struct bpf_map___33 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___33 *, void *);
	int (*map_peek_elem)(struct bpf_map___33 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___33 *, struct file___44 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___33 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___33 *, void *, struct seq_file___42 *);
	int (*map_check_btf)(const struct bpf_map___33 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___33 {
	const struct bpf_map_ops___33 *ops;
	struct bpf_map___33 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___43 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___33;

typedef void (*kthread_work_func_t___33)(struct kthread_work___33 *);

struct kthread_worker___33;

struct kthread_work___33 {
	struct list_head node;
	kthread_work_func_t___33 func;
	struct kthread_worker___33 *worker;
	int canceling;
};

struct kthread_worker___33 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___45 *task;
	struct kthread_work___33 *current_work;
};

struct kthread_delayed_work___33 {
	struct kthread_work___33 work;
	struct timer_list timer;
};

struct psi_group___33 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___33 *poll_kworker;
	struct kthread_delayed_work___33 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___33 {
	struct kernfs_node___41 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___33;

struct cgroup_subsys_state___33 {
	struct cgroup___33 *cgroup;
	struct cgroup_subsys___33 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___33 *parent;
};

struct cgroup_root___33;

struct cgroup_rstat_cpu___33;

struct cgroup___33 {
	struct cgroup_subsys_state___33 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___41 *kn;
	struct cgroup_file___33 procs_file;
	struct cgroup_file___33 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___33 *subsys[13];
	struct cgroup_root___33 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___33 *dom_cgrp;
	struct cgroup_rstat_cpu___33 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___3 bpf;
	atomic_t congestion_count;
	struct cgroup___33 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___33 psi;
	int ancestor_ids[0];
};

struct cftype___33;

struct cgroup_subsys___33 {
	struct cgroup_subsys_state___33 * (*css_alloc)(struct cgroup_subsys_state___33 *);
	int (*css_online)(struct cgroup_subsys_state___33 *);
	void (*css_offline)(struct cgroup_subsys_state___33 *);
	void (*css_released)(struct cgroup_subsys_state___33 *);
	void (*css_free)(struct cgroup_subsys_state___33 *);
	void (*css_reset)(struct cgroup_subsys_state___33 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___33 *, int);
	int (*css_extra_stat_show)(struct seq_file___42 *, struct cgroup_subsys_state___33 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___45 *);
	void (*cancel_fork)(struct task_struct___45 *);
	void (*fork)(struct task_struct___45 *);
	void (*exit)(struct task_struct___45 *);
	void (*free)(struct task_struct___45 *);
	void (*bind)(struct cgroup_subsys_state___33 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___33 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___33 *dfl_cftypes;
	struct cftype___33 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___33 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___33 *updated_children;
	struct cgroup___33 *updated_next;
};

struct cgroup_root___33 {
	struct kernfs_root___41 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___33 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___33 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___33 *ss;
	struct list_head node;
	struct kernfs_ops___41 *kf_ops;
	int (*open)(struct kernfs_open_file___41 *);
	void (*release)(struct kernfs_open_file___41 *);
	u64 (*read_u64)(struct cgroup_subsys_state___33 *, struct cftype___33 *);
	s64 (*read_s64)(struct cgroup_subsys_state___33 *, struct cftype___33 *);
	int (*seq_show)(struct seq_file___42 *, void *);
	void * (*seq_start)(struct seq_file___42 *, loff_t *);
	void * (*seq_next)(struct seq_file___42 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___42 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___33 *, struct cftype___33 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___33 *, struct cftype___33 *, s64);
	ssize_t (*write)(struct kernfs_open_file___41 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___41 *, struct poll_table_struct___30 *);
};

struct perf_cpu_context___29;

struct pmu___29 {
	struct list_head entry;
	struct module___41 *module;
	struct device___39 *dev;
	const struct attribute_group___39 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___29 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___29 *);
	void (*pmu_disable)(struct pmu___29 *);
	int (*event_init)(struct perf_event___29 *);
	void (*event_mapped)(struct perf_event___29 *, struct mm_struct___43 *);
	void (*event_unmapped)(struct perf_event___29 *, struct mm_struct___43 *);
	int (*add)(struct perf_event___29 *, int);
	void (*del)(struct perf_event___29 *, int);
	void (*start)(struct perf_event___29 *, int);
	void (*stop)(struct perf_event___29 *, int);
	void (*read)(struct perf_event___29 *);
	void (*start_txn)(struct pmu___29 *, unsigned int);
	int (*commit_txn)(struct pmu___29 *);
	void (*cancel_txn)(struct pmu___29 *);
	int (*event_idx)(struct perf_event___29 *);
	void (*sched_task)(struct perf_event_context___29 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___29 *);
	int (*filter_match)(struct perf_event___29 *);
	int (*check_period)(struct perf_event___29 *, u64);
};

struct perf_cpu_context___29 {
	struct perf_event_context___29 ctx;
	struct perf_event_context___29 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___29 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___29 {
	struct cgroup_subsys_state___33 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___24 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___24 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___24 *);
	struct list_head * (*get_fields)(struct trace_event_call___24 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___24 *);
};

struct file___45;

struct kiocb___45;

struct vm_area_struct___45;

struct inode___46;

struct file_lock___45;

struct page___45;

struct seq_file___43;

struct file_operations___45 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___45 *, loff_t, int);
	ssize_t (*read)(struct file___45 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___45 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___45 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___45 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___45 *, bool);
	int (*iterate)(struct file___45 *, struct dir_context *);
	int (*iterate_shared)(struct file___45 *, struct dir_context *);
	__poll_t (*poll)(struct file___45 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___45 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___45 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___45 *, struct vm_area_struct___45 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___46 *, struct file___45 *);
	int (*flush)(struct file___45 *, fl_owner_t);
	int (*release)(struct inode___46 *, struct file___45 *);
	int (*fsync)(struct file___45 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___45 *, int);
	int (*lock)(struct file___45 *, int, struct file_lock___45 *);
	ssize_t (*sendpage)(struct file___45 *, struct page___45 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___45 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___45 *, int, struct file_lock___45 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___45 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___45 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___45 *, long int, struct file_lock___45 **, void **);
	long int (*fallocate)(struct file___45 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___43 *, struct file___45 *);
	ssize_t (*copy_file_range)(struct file___45 *, loff_t, struct file___45 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___45 *, loff_t, struct file___45 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___45 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___44 {
	u64 seqnum;
	struct vm_area_struct___45 *vmas[4];
};

struct page_frag___44 {
	struct page___45 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___44;

struct mem_cgroup___17;

struct pid___40;

struct cred___44;

struct nsproxy___43;

struct signal_struct___42;

struct bio_list___18;

struct backing_dev_info___18;

struct io_context___10;

struct css_set___34;

struct request_queue___11;

struct vm_struct___35;

struct task_struct___46 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___46 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___44 *mm;
	struct mm_struct___44 *active_mm;
	struct vmacache___44 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___46 *real_parent;
	struct task_struct___46 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___46 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___17 *active_memcg;
	long int rh_reserved2;
	struct pid___40 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___40 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___40 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___44 *ptracer_cred;
	const struct cred___44 *real_cred;
	const struct cred___44 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___43 *nsproxy;
	struct signal_struct___42 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___46 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___18 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___18 *backing_dev_info;
	struct io_context___10 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___34 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___44 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___17 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___11 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___46 *oom_reaper_list;
	struct vm_struct___35 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___29 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___40;

struct upid___40 {
	int nr;
	struct pid_namespace___40 *ns;
};

struct dentry___45;

struct user_namespace___36;

struct ucounts___36;

struct pid_namespace___40 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___46 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___40 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___45 *proc_self;
	struct dentry___45 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___36 *user_ns;
	struct ucounts___36 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___4 ns;
};

struct pid___40 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___40 numbers[1];
};

struct rw_semaphore___45 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___46 *owner;
};

struct key___45;

struct user_namespace___36 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___36 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___4 ns;
	long unsigned int flags;
	struct key___45 *persistent_keyring_register;
	struct rw_semaphore___45 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___36 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct secondary_data___45 {
	void *stack;
	struct task_struct___46 *task;
	long int status;
};

typedef struct page___45 *pgtable_t___44;

struct address_space___44;

struct dev_pagemap___44;

struct page___45 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___44 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___45 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___44 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___44 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___44 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___17 *mem_cgroup;
};

struct user_struct___44 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___45 *uid_keyring;
	struct key___45 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___44;

struct vm_area_struct___45 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___45 *vm_next;
	struct vm_area_struct___45 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___44 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___44 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___45 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___44;

struct mm_struct___44 {
	struct {
		struct vm_area_struct___45 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___45 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___45 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___44 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___46 *owner;
		struct user_namespace___36 *user_ns;
		struct file___45 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___44 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup___34;

struct cgroup_subsys___34;

struct cgroup_subsys_state___34 {
	struct cgroup___34 *cgroup;
	struct cgroup_subsys___34 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___34 *parent;
};

struct kernfs_node___42;

struct cgroup_file___34 {
	struct kernfs_node___42 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___17;

struct mem_cgroup___17 {
	struct cgroup_subsys_state___34 css;
	struct mem_cgroup_id___8 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___34 events_file;
	struct cgroup_file___34 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___46 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___17 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cred___44 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___45 *session_keyring;
	struct key___45 *process_keyring;
	struct key___45 *thread_keyring;
	struct key___45 *request_key_auth;
	void *security;
	struct user_struct___44 *user;
	struct user_namespace___36 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___34;

struct nsproxy___43 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___40 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___34 *cgroup_ns;
};

struct signal_struct___42 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___46 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___46 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___40 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___40 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___44 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___40 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___18;

struct bio_list___18 {
	struct bio___18 *head;
	struct bio___18 *tail;
};

struct bdi_writeback_congested___18;

struct bdi_writeback___18 {
	struct backing_dev_info___18 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___18 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___34 *memcg_css;
	struct cgroup_subsys_state___34 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___40;

struct backing_dev_info___18 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___18 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___40 *dev;
	struct device___40 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___45 *debug_dir;
	struct dentry___45 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___10;

struct io_context___10 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___10 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___34 {
	struct cgroup_subsys_state___34 *subsys[13];
	refcount_t refcount;
	struct css_set___34 *dom_cset;
	struct cgroup___34 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___34 *mg_src_cgrp;
	struct cgroup___34 *mg_dst_cgrp;
	struct css_set___34 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

typedef blk_qc_t make_request_fn___10(struct request_queue___11 *, struct bio___18 *);

struct request___11;

typedef int dma_drain_needed_fn___10(struct request___11 *);

struct kset___42;

struct kobj_type___42;

struct kobject___43 {
	const char *name;
	struct list_head entry;
	struct kobject___43 *parent;
	struct kset___42 *kset;
	struct kobj_type___42 *ktype;
	struct kernfs_node___42 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___10;

struct bsg_class_device___10 {
	struct device___40 *class_dev;
	int minor;
	struct request_queue___11 *queue;
	const struct bsg_ops___10 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___18 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___18 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___10;

struct blkcg_gq___7;

struct request_queue___11 {
	struct list_head queue_head;
	struct request___11 *last_merge;
	struct elevator_queue___10 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___10 *make_request_fn;
	dma_drain_needed_fn___10 *dma_drain_needed;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___18 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___43 kobj;
	struct kobject___43 *mq_kobj;
	struct blk_integrity integrity;
	struct device___40 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___7 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	struct bsg_class_device___10 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___18 bio_split;
	struct dentry___45 *debugfs_dir;
	struct dentry___45 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___35 {
	struct vm_struct___35 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___45 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___42 {
	struct task_struct___46 task;
	long unsigned int stack[8192];
};

typedef void (*task_work_func_t)(struct callback_head *);

typedef int (*key_restrict_link_func_t___44)(struct key___45 *, const struct key_type *, const union key_payload *, struct key___45 *);

struct key_restriction___45;

struct key___45 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___45 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___45 *restrict_link;
};

struct key_restriction___45 {
	key_restrict_link_func_t___44 check;
	struct key___45 *key;
	struct key_type *keytype;
};

struct pglist_data___44;

struct lruvec___44 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___44 *pgdat;
};

struct zone___44 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___44 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___44 {
	struct zone___44 *zone;
	int zone_idx;
};

struct zonelist___44 {
	struct zoneref___44 _zonerefs[25];
};

struct pglist_data___44 {
	struct zone___44 node_zones[3];
	struct zonelist___44 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___46 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___46 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___44 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___44 {
	struct rw_semaphore___45 rwsem;
	struct notifier_block *head;
};

struct address_space_operations___44;

struct address_space___44 {
	struct inode___46 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___45 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___44 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___44)(struct vm_area_struct___45 *, long unsigned int, const struct page___45 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___44)(struct page___45 *, void *);

struct dev_pagemap___44 {
	dev_page_fault_t___44 page_fault;
	dev_page_free_t___44 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___40 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___44 {
	struct vfsmount *mnt;
	struct dentry___45 *dentry;
};

struct fown_struct___40 {
	rwlock_t lock;
	struct pid___40 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___45 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___44 f_path;
	struct inode___46 *f_inode;
	const struct file_operations___45 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___40 f_owner;
	const struct cred___44 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___44 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___44;

struct vm_operations_struct___44 {
	void (*open)(struct vm_area_struct___45 *);
	void (*close)(struct vm_area_struct___45 *);
	int (*split)(struct vm_area_struct___45 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___45 *);
	vm_fault_t (*fault)(struct vm_fault___44 *);
	vm_fault_t (*huge_fault)(struct vm_fault___44 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___44 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___45 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___44 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___44 *);
	int (*access)(struct vm_area_struct___45 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___45 *);
	int (*set_policy)(struct vm_area_struct___45 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___45 *, long unsigned int);
	struct page___45 * (*find_special_page)(struct vm_area_struct___45 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___44 {
	struct task_struct___46 *task;
	struct core_thread___44 *next;
};

struct core_state___44 {
	atomic_t nr_threads;
	struct core_thread___44 dumper;
	struct completion startup;
};

struct vm_fault___44 {
	struct vm_area_struct___45 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___45 *cow_page;
	struct mem_cgroup___17 *memcg;
	struct page___45 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___44 prealloc_pte;
};

struct shrink_control___17 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___17 *memcg;
};

struct shrinker___17 {
	long unsigned int (*count_objects)(struct shrinker___17 *, struct shrink_control___17 *);
	long unsigned int (*scan_objects)(struct shrinker___17 *, struct shrink_control___17 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct dev_pm_info___40 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___40 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___40;

struct bus_type___40;

struct device_driver___40;

struct dev_pm_domain___40;

struct fwnode_handle___32;

struct class___40;

struct attribute_group___40;

struct device___40 {
	struct device___40 *parent;
	struct device_private *p;
	struct kobject___43 kobj;
	const char *init_name;
	const struct device_type___40 *type;
	struct mutex mutex;
	struct bus_type___40 *bus;
	struct device_driver___40 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___40 power;
	struct dev_pm_domain___40 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___32 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___40 *class;
	const struct attribute_group___40 **groups;
	void (*release)(struct device___40 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___44;

struct super_block___45;

struct dentry___45 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___45 *d_parent;
	struct qstr d_name;
	struct inode___46 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___44 *d_op;
	struct super_block___45 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___44;

struct block_device___45;

struct inode___46 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___44 *i_op;
	struct super_block___45 *i_sb;
	struct address_space___44 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___45 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___18 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___45 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___44 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___45 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___44 {
	int (*d_revalidate)(struct dentry___45 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___45 *, unsigned int);
	int (*d_hash)(const struct dentry___45 *, struct qstr *);
	int (*d_compare)(const struct dentry___45 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___45 *);
	int (*d_init)(struct dentry___45 *);
	void (*d_release)(struct dentry___45 *);
	void (*d_prune)(struct dentry___45 *);
	void (*d_iput)(struct dentry___45 *, struct inode___46 *);
	char * (*d_dname)(struct dentry___45 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___44 *);
	int (*d_manage)(const struct path___44 *, bool);
	struct dentry___45 * (*d_real)(struct dentry___45 *, const struct inode___46 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___44;

struct mem_dqinfo___44 {
	struct quota_format_type___44 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___44;

struct quota_info___44 {
	unsigned int flags;
	struct rw_semaphore___45 dqio_sem;
	struct inode___46 *files[3];
	struct mem_dqinfo___44 info[3];
	const struct quota_format_ops___44 *ops[3];
};

struct rcuwait___44 {
	struct task_struct___46 *task;
};

struct percpu_rw_semaphore___44 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___45 rw_sem;
	struct rcuwait___44 writer;
	int readers_block;
};

struct sb_writers___44 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___44 rw_sem[3];
};

struct file_system_type___44;

struct super_operations___44;

struct dquot_operations___44;

struct quotactl_ops___44;

struct super_block___45 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___44 *s_type;
	const struct super_operations___44 *s_op;
	const struct dquot_operations___44 *dq_op;
	const struct quotactl_ops___44 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___45 *s_root;
	struct rw_semaphore___45 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___45 *s_bdev;
	struct backing_dev_info___18 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___44 s_dquot;
	struct sb_writers___44 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___44 *s_d_op;
	int cleancache_poolid;
	struct shrinker___17 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___36 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct io_cq___10 {
	struct request_queue___11 *q;
	struct io_context___10 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___45 {
	struct file___45 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___45 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___45 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___45 *ia_file;
};

struct dquot___44 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___45 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___44 {
	int qf_fmt_id;
	const struct quota_format_ops___44 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___44 *qf_next;
};

struct quota_format_ops___44 {
	int (*check_quota_file)(struct super_block___45 *, int);
	int (*read_file_info)(struct super_block___45 *, int);
	int (*write_file_info)(struct super_block___45 *, int);
	int (*free_file_info)(struct super_block___45 *, int);
	int (*read_dqblk)(struct dquot___44 *);
	int (*commit_dqblk)(struct dquot___44 *);
	int (*release_dqblk)(struct dquot___44 *);
	int (*get_next_id)(struct super_block___45 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___44 {
	int (*write_dquot)(struct dquot___44 *);
	struct dquot___44 * (*alloc_dquot)(struct super_block___45 *, int);
	void (*destroy_dquot)(struct dquot___44 *);
	int (*acquire_dquot)(struct dquot___44 *);
	int (*release_dquot)(struct dquot___44 *);
	int (*mark_dirty)(struct dquot___44 *);
	int (*write_info)(struct super_block___45 *, int);
	qsize_t * (*get_reserved_space)(struct inode___46 *);
	int (*get_projid)(struct inode___46 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___46 *, qsize_t *);
	int (*get_next_id)(struct super_block___45 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___44 {
	int (*quota_on)(struct super_block___45 *, int, int, const struct path___44 *);
	int (*quota_off)(struct super_block___45 *, int);
	int (*quota_enable)(struct super_block___45 *, unsigned int);
	int (*quota_disable)(struct super_block___45 *, unsigned int);
	int (*quota_sync)(struct super_block___45 *, int);
	int (*set_info)(struct super_block___45 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___45 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___45 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___45 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___45 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___45 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___17;

struct address_space_operations___44 {
	int (*writepage)(struct page___45 *, struct writeback_control___17 *);
	int (*readpage)(struct file___45 *, struct page___45 *);
	int (*writepages)(struct address_space___44 *, struct writeback_control___17 *);
	int (*set_page_dirty)(struct page___45 *);
	int (*readpages)(struct file___45 *, struct address_space___44 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___45 *, struct address_space___44 *, loff_t, unsigned int, unsigned int, struct page___45 **, void **);
	int (*write_end)(struct file___45 *, struct address_space___44 *, loff_t, unsigned int, unsigned int, struct page___45 *, void *);
	sector_t (*bmap)(struct address_space___44 *, sector_t);
	void (*invalidatepage)(struct page___45 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___45 *, gfp_t);
	void (*freepage)(struct page___45 *);
	ssize_t (*direct_IO)(struct kiocb___45 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___44 *, struct page___45 *, struct page___45 *, enum migrate_mode);
	bool (*isolate_page)(struct page___45 *, isolate_mode_t);
	void (*putback_page)(struct page___45 *);
	int (*launder_page)(struct page___45 *);
	int (*is_partially_uptodate)(struct page___45 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___45 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___44 *, struct page___45 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___45 *, sector_t *);
	void (*swap_deactivate)(struct file___45 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___17 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___18 *wb;
	struct inode___46 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct hd_struct___10;

struct gendisk___10;

struct block_device___45 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___46 *bd_inode;
	struct super_block___45 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___45 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___10 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___10 *bd_disk;
	struct request_queue___11 *bd_queue;
	struct backing_dev_info___18 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct hd_struct___10 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___40 __dev;
	struct kobject___43 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___10;

struct block_device_operations___10;

struct gendisk___10 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___10 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___10 *part_tbl;
	struct hd_struct___10 part0;
	const struct block_device_operations___10 *fops;
	struct request_queue___11 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___45 lookup_sem;
	struct kobject___43 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___43 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___44 {
	struct dentry___45 * (*lookup)(struct inode___46 *, struct dentry___45 *, unsigned int);
	const char * (*get_link)(struct dentry___45 *, struct inode___46 *, struct delayed_call *);
	int (*permission)(struct inode___46 *, int);
	struct posix_acl * (*get_acl)(struct inode___46 *, int);
	int (*readlink)(struct dentry___45 *, char *, int);
	int (*create)(struct inode___46 *, struct dentry___45 *, umode_t, bool);
	int (*link)(struct dentry___45 *, struct inode___46 *, struct dentry___45 *);
	int (*unlink)(struct inode___46 *, struct dentry___45 *);
	int (*symlink)(struct inode___46 *, struct dentry___45 *, const char *);
	int (*mkdir)(struct inode___46 *, struct dentry___45 *, umode_t);
	int (*rmdir)(struct inode___46 *, struct dentry___45 *);
	int (*mknod)(struct inode___46 *, struct dentry___45 *, umode_t, dev_t);
	int (*rename)(struct inode___46 *, struct dentry___45 *, struct inode___46 *, struct dentry___45 *, unsigned int);
	int (*setattr)(struct dentry___45 *, struct iattr___45 *);
	int (*getattr)(const struct path___44 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___45 *, char *, size_t);
	int (*fiemap)(struct inode___46 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___46 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___46 *, struct dentry___45 *, struct file___45 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___46 *, struct dentry___45 *, umode_t);
	int (*set_acl)(struct inode___46 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___44 {
	void (*fl_copy_lock)(struct file_lock___45 *, struct file_lock___45 *);
	void (*fl_release_private)(struct file_lock___45 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___44;

struct lock_manager_operations___44;

struct file_lock___45 {
	struct file_lock___45 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___45 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___44 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___44 *fl_ops;
	const struct lock_manager_operations___44 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___44 {
	int (*lm_compare_owner)(struct file_lock___45 *, struct file_lock___45 *);
	long unsigned int (*lm_owner_key)(struct file_lock___45 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___45 *);
	int (*lm_grant)(struct file_lock___45 *, int);
	bool (*lm_break)(struct file_lock___45 *);
	int (*lm_change)(struct file_lock___45 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___45 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___44 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___44 *fa_next;
	struct file___45 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___44 {
	const char *name;
	int fs_flags;
	struct dentry___45 * (*mount)(struct file_system_type___44 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___45 *);
	struct module___11 *owner;
	struct file_system_type___44 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___44 {
	struct inode___46 * (*alloc_inode)(struct super_block___45 *);
	void (*destroy_inode)(struct inode___46 *);
	void (*dirty_inode)(struct inode___46 *, int);
	int (*write_inode)(struct inode___46 *, struct writeback_control___17 *);
	int (*drop_inode)(struct inode___46 *);
	void (*evict_inode)(struct inode___46 *);
	void (*put_super)(struct super_block___45 *);
	int (*sync_fs)(struct super_block___45 *, int);
	int (*freeze_super)(struct super_block___45 *);
	int (*freeze_fs)(struct super_block___45 *);
	int (*thaw_super)(struct super_block___45 *);
	int (*unfreeze_fs)(struct super_block___45 *);
	int (*statfs)(struct dentry___45 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___45 *, int *, char *);
	void (*umount_begin)(struct super_block___45 *);
	int (*show_options)(struct seq_file___43 *, struct dentry___45 *);
	int (*show_devname)(struct seq_file___43 *, struct dentry___45 *);
	int (*show_path)(struct seq_file___43 *, struct dentry___45 *);
	int (*show_stats)(struct seq_file___43 *, struct dentry___45 *);
	ssize_t (*quota_read)(struct super_block___45 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___45 *, int, const char *, size_t, loff_t);
	struct dquot___44 ** (*get_dquots)(struct inode___46 *);
	int (*bdev_try_to_free_page)(struct super_block___45 *, struct page___45 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___45 *, struct shrink_control___17 *);
	long int (*free_cached_objects)(struct super_block___45 *, struct shrink_control___17 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___40;

struct seq_file___43 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___40 *op;
	int poll_event;
	const struct file___45 *file;
	void *private;
};

typedef void bio_end_io_t___18(struct bio___18 *);

struct bio_vec___18 {
	struct page___45 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___18;

struct bio___18 {
	struct bio___18 *bi_next;
	struct gendisk___10 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___18 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___7 *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___18 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___18 *bi_io_vec;
	struct bio_set___18 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___18 bi_inline_vecs[0];
};

struct kobj_attribute___43 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___43 *, struct kobj_attribute___43 *, char *);
	ssize_t (*store)(struct kobject___43 *, struct kobj_attribute___43 *, const char *, size_t);
};

typedef void compound_page_dtor___44(struct page___45 *);

struct cgroup_namespace___34 {
	refcount_t count;
	struct ns_common___4 ns;
	struct user_namespace___36 *user_ns;
	struct ucounts___36 *ucounts;
	struct css_set___34 *root_cset;
};

struct ucounts___36 {
	struct hlist_node node;
	struct user_namespace___36 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct seq_operations___40 {
	void * (*start)(struct seq_file___43 *, loff_t *);
	void (*stop)(struct seq_file___43 *, void *);
	void * (*next)(struct seq_file___43 *, void *, loff_t *);
	int (*show)(struct seq_file___43 *, void *);
};

struct kernfs_root___42;

struct kernfs_elem_dir___42 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___42 *root;
};

struct kernfs_syscall_ops___42;

struct kernfs_root___42 {
	struct kernfs_node___42 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___42 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___42 {
	struct kernfs_node___42 *target_kn;
};

struct kernfs_ops___42;

struct kernfs_elem_attr___42 {
	const struct kernfs_ops___42 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___42 *notify_next;
};

struct kernfs_node___42 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___42 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___42 dir;
		struct kernfs_elem_symlink___42 symlink;
		struct kernfs_elem_attr___42 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___42;

struct kernfs_ops___42 {
	int (*open)(struct kernfs_open_file___42 *);
	void (*release)(struct kernfs_open_file___42 *);
	int (*seq_show)(struct seq_file___43 *, void *);
	void * (*seq_start)(struct seq_file___43 *, loff_t *);
	void * (*seq_next)(struct seq_file___43 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___43 *, void *);
	ssize_t (*read)(struct kernfs_open_file___42 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___42 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___42 *, struct vm_area_struct___45 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___42 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___42 {
	int (*remount_fs)(struct kernfs_root___42 *, int *, char *);
	int (*show_options)(struct seq_file___43 *, struct kernfs_root___42 *);
	int (*mkdir)(struct kernfs_node___42 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___42 *);
	int (*rename)(struct kernfs_node___42 *, struct kernfs_node___42 *, const char *);
	int (*show_path)(struct seq_file___43 *, struct kernfs_node___42 *, struct kernfs_root___42 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___42 {
	struct kernfs_node___42 *kn;
	struct file___45 *file;
	struct seq_file___43 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___44 *vm_ops;
};

struct bpf_map___34;

struct bpf_map_ops___34 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___34 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___34 *, struct file___45 *);
	void (*map_free)(struct bpf_map___34 *);
	int (*map_get_next_key)(struct bpf_map___34 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___34 *);
	void * (*map_lookup_elem)(struct bpf_map___34 *, void *);
	int (*map_update_elem)(struct bpf_map___34 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___34 *, void *);
	int (*map_push_elem)(struct bpf_map___34 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___34 *, void *);
	int (*map_peek_elem)(struct bpf_map___34 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___34 *, struct file___45 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___34 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___34 *, void *, struct seq_file___43 *);
	int (*map_check_btf)(const struct bpf_map___34 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___34 {
	const struct bpf_map_ops___34 *ops;
	struct bpf_map___34 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___44 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___34;

typedef void (*kthread_work_func_t___34)(struct kthread_work___34 *);

struct kthread_worker___34;

struct kthread_work___34 {
	struct list_head node;
	kthread_work_func_t___34 func;
	struct kthread_worker___34 *worker;
	int canceling;
};

struct kthread_worker___34 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___46 *task;
	struct kthread_work___34 *current_work;
};

struct kthread_delayed_work___34 {
	struct kthread_work___34 work;
	struct timer_list timer;
};

struct psi_group___34 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___34 *poll_kworker;
	struct kthread_delayed_work___34 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___34;

struct cgroup_rstat_cpu___34;

struct cgroup___34 {
	struct cgroup_subsys_state___34 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___42 *kn;
	struct cgroup_file___34 procs_file;
	struct cgroup_file___34 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___34 *subsys[13];
	struct cgroup_root___34 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___34 *dom_cgrp;
	struct cgroup_rstat_cpu___34 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___3 bpf;
	atomic_t congestion_count;
	struct cgroup___34 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___34 psi;
	int ancestor_ids[0];
};

struct cftype___34;

struct cgroup_subsys___34 {
	struct cgroup_subsys_state___34 * (*css_alloc)(struct cgroup_subsys_state___34 *);
	int (*css_online)(struct cgroup_subsys_state___34 *);
	void (*css_offline)(struct cgroup_subsys_state___34 *);
	void (*css_released)(struct cgroup_subsys_state___34 *);
	void (*css_free)(struct cgroup_subsys_state___34 *);
	void (*css_reset)(struct cgroup_subsys_state___34 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___34 *, int);
	int (*css_extra_stat_show)(struct seq_file___43 *, struct cgroup_subsys_state___34 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___46 *);
	void (*cancel_fork)(struct task_struct___46 *);
	void (*fork)(struct task_struct___46 *);
	void (*exit)(struct task_struct___46 *);
	void (*free)(struct task_struct___46 *);
	void (*bind)(struct cgroup_subsys_state___34 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___34 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___34 *dfl_cftypes;
	struct cftype___34 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___34 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___34 *updated_children;
	struct cgroup___34 *updated_next;
};

struct cgroup_root___34 {
	struct kernfs_root___42 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___34 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___34 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___34 *ss;
	struct list_head node;
	struct kernfs_ops___42 *kf_ops;
	int (*open)(struct kernfs_open_file___42 *);
	void (*release)(struct kernfs_open_file___42 *);
	u64 (*read_u64)(struct cgroup_subsys_state___34 *, struct cftype___34 *);
	s64 (*read_s64)(struct cgroup_subsys_state___34 *, struct cftype___34 *);
	int (*seq_show)(struct seq_file___43 *, void *);
	void * (*seq_start)(struct seq_file___43 *, loff_t *);
	void * (*seq_next)(struct seq_file___43 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___43 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___34 *, struct cftype___34 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___34 *, struct cftype___34 *, s64);
	ssize_t (*write)(struct kernfs_open_file___42 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___42 *, struct poll_table_struct___6 *);
};

struct bdi_writeback_congested___18 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___18 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___18 {
	struct bio___18 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___18 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___18 bip_inline_vecs[0];
};

struct blkcg___7;

struct blkg_policy_data___7;

struct blkcg_gq___7 {
	struct request_queue___11 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___7 *blkcg;
	struct bdi_writeback_congested___18 *wb_congested;
	struct blkcg_gq___7 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_rwstat stat_bytes;
	struct blkg_rwstat stat_ios;
	struct blkg_policy_data___7 *pd[5];
	struct callback_head callback_head;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
};

struct mem_cgroup_reclaim_iter___17 {
	struct mem_cgroup___17 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___17 {
	struct lruvec___44 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___17 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___17 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct dev_pm_ops___40;

struct device_type___40 {
	const char *name;
	const struct attribute_group___40 **groups;
	int (*uevent)(struct device___40 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___40 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___40 *);
	const struct dev_pm_ops___40 *pm;
};

struct class___40 {
	const char *name;
	struct module___11 *owner;
	const struct attribute_group___40 **class_groups;
	const struct attribute_group___40 **dev_groups;
	struct kobject___43 *dev_kobj;
	int (*dev_uevent)(struct device___40 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___40 *, umode_t *);
	void (*class_release)(struct class___40 *);
	void (*dev_release)(struct device___40 *);
	int (*shutdown_pre)(struct device___40 *);
	const struct kobj_ns_type_operations___2 *ns_type;
	const void * (*namespace)(struct device___40 *);
	const struct dev_pm_ops___40 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct bin_attribute___40;

struct attribute_group___40 {
	const char *name;
	umode_t (*is_visible)(struct kobject___43 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___43 *, struct bin_attribute___40 *, int);
	struct attribute **attrs;
	struct bin_attribute___40 **bin_attrs;
};

struct bin_attribute___40 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___45 *, struct kobject___43 *, struct bin_attribute___40 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___45 *, struct kobject___43 *, struct bin_attribute___40 *, char *, loff_t, size_t);
	int (*mmap)(struct file___45 *, struct kobject___43 *, struct bin_attribute___40 *, struct vm_area_struct___45 *);
};

struct sysfs_ops___42 {
	ssize_t (*show)(struct kobject___43 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___43 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___42;

struct kset___42 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___43 kobj;
	const struct kset_uevent_ops___42 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___42 {
	void (*release)(struct kobject___43 *);
	const struct sysfs_ops___42 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___2 * (*child_ns_type)(struct kobject___43 *);
	const void * (*namespace)(struct kobject___43 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___42 {
	int (* const filter)(struct kset___42 *, struct kobject___43 *);
	const char * (* const name)(struct kset___42 *, struct kobject___43 *);
	int (* const uevent)(struct kset___42 *, struct kobject___43 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___40 {
	int (*prepare)(struct device___40 *);
	void (*complete)(struct device___40 *);
	int (*suspend)(struct device___40 *);
	int (*resume)(struct device___40 *);
	int (*freeze)(struct device___40 *);
	int (*thaw)(struct device___40 *);
	int (*poweroff)(struct device___40 *);
	int (*restore)(struct device___40 *);
	int (*suspend_late)(struct device___40 *);
	int (*resume_early)(struct device___40 *);
	int (*freeze_late)(struct device___40 *);
	int (*thaw_early)(struct device___40 *);
	int (*poweroff_late)(struct device___40 *);
	int (*restore_early)(struct device___40 *);
	int (*suspend_noirq)(struct device___40 *);
	int (*resume_noirq)(struct device___40 *);
	int (*freeze_noirq)(struct device___40 *);
	int (*thaw_noirq)(struct device___40 *);
	int (*poweroff_noirq)(struct device___40 *);
	int (*restore_noirq)(struct device___40 *);
	int (*runtime_suspend)(struct device___40 *);
	int (*runtime_resume)(struct device___40 *);
	int (*runtime_idle)(struct device___40 *);
};

struct dev_pm_domain___40 {
	struct dev_pm_ops___40 ops;
	void (*detach)(struct device___40 *, bool);
	int (*activate)(struct device___40 *);
	void (*sync)(struct device___40 *);
	void (*dismiss)(struct device___40 *);
};

struct bus_type___40 {
	const char *name;
	const char *dev_name;
	struct device___40 *dev_root;
	const struct attribute_group___40 **bus_groups;
	const struct attribute_group___40 **dev_groups;
	const struct attribute_group___40 **drv_groups;
	int (*match)(struct device___40 *, struct device_driver___40 *);
	int (*uevent)(struct device___40 *, struct kobj_uevent_env *);
	int (*probe)(struct device___40 *);
	int (*remove)(struct device___40 *);
	void (*shutdown)(struct device___40 *);
	int (*online)(struct device___40 *);
	int (*offline)(struct device___40 *);
	int (*suspend)(struct device___40 *, pm_message_t);
	int (*resume)(struct device___40 *);
	int (*num_vf)(struct device___40 *);
	int (*dma_configure)(struct device___40 *);
	const struct dev_pm_ops___40 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___40 {
	const char *name;
	struct bus_type___40 *bus;
	struct module___11 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___40 *);
	int (*remove)(struct device___40 *);
	void (*shutdown)(struct device___40 *);
	int (*suspend)(struct device___40 *, pm_message_t);
	int (*resume)(struct device___40 *);
	const struct attribute_group___40 **groups;
	const struct dev_pm_ops___40 *pm;
	void (*coredump)(struct device___40 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct fwnode_operations___32;

struct fwnode_handle___32 {
	struct fwnode_handle___32 *secondary;
	const struct fwnode_operations___32 *ops;
};

struct disk_part_tbl___10 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___10 *last_lookup;
	struct hd_struct___10 *part[0];
};

struct block_device_operations___10 {
	int (*open)(struct block_device___45 *, fmode_t);
	void (*release)(struct gendisk___10 *, fmode_t);
	int (*rw_page)(struct block_device___45 *, sector_t, struct page___45 *, unsigned int);
	int (*ioctl)(struct block_device___45 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___45 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___10 *, unsigned int);
	int (*media_changed)(struct gendisk___10 *);
	void (*unlock_native_capacity)(struct gendisk___10 *);
	int (*revalidate_disk)(struct gendisk___10 *);
	int (*getgeo)(struct block_device___45 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___45 *, long unsigned int);
	int (*report_zones)(struct gendisk___10 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___11 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___10 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___11 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___11 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___11 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___10(struct request___11 *, blk_status_t);

struct request___11 {
	struct request_queue___11 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___18 *bio;
	struct bio___18 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___18 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___10 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___10 *saved_end_io;
		} flush;
	};
	struct gendisk___10 *rq_disk;
	struct hd_struct___10 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___10 *end_io;
	void *end_io_data;
	struct request___11 *next_rq;
};

struct fwnode_reference_args___32;

struct fwnode_endpoint___32;

struct fwnode_operations___32 {
	struct fwnode_handle___32 * (*get)(struct fwnode_handle___32 *);
	void (*put)(struct fwnode_handle___32 *);
	bool (*device_is_available)(const struct fwnode_handle___32 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___32 *, const struct device___40 *);
	bool (*property_present)(const struct fwnode_handle___32 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___32 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___32 *, const char *, const char **, size_t);
	struct fwnode_handle___32 * (*get_parent)(const struct fwnode_handle___32 *);
	struct fwnode_handle___32 * (*get_next_child_node)(const struct fwnode_handle___32 *, struct fwnode_handle___32 *);
	struct fwnode_handle___32 * (*get_named_child_node)(const struct fwnode_handle___32 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___32 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___32 *);
	struct fwnode_handle___32 * (*graph_get_next_endpoint)(const struct fwnode_handle___32 *, struct fwnode_handle___32 *);
	struct fwnode_handle___32 * (*graph_get_remote_endpoint)(const struct fwnode_handle___32 *);
	struct fwnode_handle___32 * (*graph_get_port_parent)(struct fwnode_handle___32 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___32 *, struct fwnode_endpoint___32 *);
};

struct fwnode_endpoint___32 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___32 *local_fwnode;
};

struct fwnode_reference_args___32 {
	struct fwnode_handle___32 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct elevator_type___10;

struct elevator_mq_ops___10 {
	int (*init_sched)(struct request_queue___11 *, struct elevator_type___10 *);
	void (*exit_sched)(struct elevator_queue___10 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	bool (*allow_merge)(struct request_queue___11 *, struct request___11 *, struct bio___18 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx *, struct bio___18 *);
	int (*request_merge)(struct request_queue___11 *, struct request___11 **, struct bio___18 *);
	void (*request_merged)(struct request_queue___11 *, struct request___11 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___11 *, struct request___11 *, struct request___11 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___11 *, struct bio___18 *);
	void (*finish_request)(struct request___11 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___11 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___11 *, u64);
	void (*started_request)(struct request___11 *);
	void (*requeue_request)(struct request___11 *);
	struct request___11 * (*former_request)(struct request_queue___11 *, struct request___11 *);
	struct request___11 * (*next_request)(struct request_queue___11 *, struct request___11 *);
	void (*init_icq)(struct io_cq___10 *);
	void (*exit_icq)(struct io_cq___10 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___10;

struct elevator_type___10 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___10 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___10 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___11 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___10 {
	struct elevator_type___10 *type;
	void *elevator_data;
	struct kobject___43 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___10 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___10 *, char *);
	ssize_t (*store)(struct elevator_queue___10 *, const char *, size_t);
};

struct blkcg_policy_data___7;

struct blkcg___7 {
	struct cgroup_subsys_state___34 css;
	spinlock_t lock;
	struct xarray blkg_tree;
	struct blkcg_gq___7 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___7 *cpd[5];
	struct list_head all_blkcgs_node;
	struct list_head cgwb_list;
	refcount_t cgwb_refcnt;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct blkcg_policy_data___7 {
	struct blkcg___7 *blkcg;
	int plid;
};

struct blkg_policy_data___7 {
	struct blkcg_gq___7 *blkg;
	int plid;
};

struct module___42;

struct file___46;

struct kiocb___46;

struct iov_iter___21;

struct vm_area_struct___46;

struct inode___47;

struct file_lock___46;

struct page___46;

struct pipe_inode_info___11;

struct seq_file___44;

struct file_operations___46 {
	struct module___42 *owner;
	loff_t (*llseek)(struct file___46 *, loff_t, int);
	ssize_t (*read)(struct file___46 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___46 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___46 *, struct iov_iter___21 *);
	ssize_t (*write_iter)(struct kiocb___46 *, struct iov_iter___21 *);
	int (*iopoll)(struct kiocb___46 *, bool);
	int (*iterate)(struct file___46 *, struct dir_context *);
	int (*iterate_shared)(struct file___46 *, struct dir_context *);
	__poll_t (*poll)(struct file___46 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___46 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___46 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___46 *, struct vm_area_struct___46 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___47 *, struct file___46 *);
	int (*flush)(struct file___46 *, fl_owner_t);
	int (*release)(struct inode___47 *, struct file___46 *);
	int (*fsync)(struct file___46 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___46 *, int);
	int (*lock)(struct file___46 *, int, struct file_lock___46 *);
	ssize_t (*sendpage)(struct file___46 *, struct page___46 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___46 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___46 *, int, struct file_lock___46 *);
	ssize_t (*splice_write)(struct pipe_inode_info___11 *, struct file___46 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___46 *, loff_t *, struct pipe_inode_info___11 *, size_t, unsigned int);
	int (*setlease)(struct file___46 *, long int, struct file_lock___46 **, void **);
	long int (*fallocate)(struct file___46 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___44 *, struct file___46 *);
	ssize_t (*copy_file_range)(struct file___46 *, loff_t, struct file___46 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___46 *, loff_t, struct file___46 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___46 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___45 {
	u64 seqnum;
	struct vm_area_struct___46 *vmas[4];
};

struct page_frag___45 {
	struct page___46 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___45;

struct pid___41;

struct cred___45;

struct nsproxy___44;

struct signal_struct___43;

struct css_set___35;

struct vm_struct___36;

struct task_struct___47 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___47 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___45 *mm;
	struct mm_struct___45 *active_mm;
	struct vmacache___45 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___47 *real_parent;
	struct task_struct___47 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___47 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___41 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___41 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___41 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___45 *ptracer_cred;
	const struct cred___45 *real_cred;
	const struct cred___45 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___44 *nsproxy;
	struct signal_struct___43 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___47 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___10 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___35 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___11 *splice_pipe;
	struct page_frag___45 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___47 *oom_reaper_list;
	struct vm_struct___36 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___29 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___46 *pgtable_t___45;

struct address_space___45;

struct dev_pagemap___45;

struct page___46 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___45 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___46 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___45 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___45 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___45 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___45;

struct lruvec___45 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___45 *pgdat;
};

struct zone___45 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___45 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___45 {
	struct zone___45 *zone;
	int zone_idx;
};

struct zonelist___45 {
	struct zoneref___45 _zonerefs[25];
};

struct pglist_data___45 {
	struct zone___45 node_zones[3];
	struct zonelist___45 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___47 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___47 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___45 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___46 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___47 *owner;
};

struct secondary_data___46 {
	void *stack;
	struct task_struct___47 *task;
	long int status;
};

struct blocking_notifier_head___45 {
	struct rw_semaphore___46 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___45;

struct vm_area_struct___46 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___46 *vm_next;
	struct vm_area_struct___46 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___45 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___45 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___46 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___45;

struct user_namespace___37;

struct mm_struct___45 {
	struct {
		struct vm_area_struct___46 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___46 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___46 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___45 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___47 *owner;
		struct user_namespace___37 *user_ns;
		struct file___46 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___45 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___45;

struct address_space___45 {
	struct inode___47 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___46 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___45 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___45)(struct vm_area_struct___46 *, long unsigned int, const struct page___46 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___45)(struct page___46 *, void *);

struct device___41;

struct dev_pagemap___45 {
	dev_page_fault_t___45 page_fault;
	dev_page_free_t___45 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___41 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct dentry___46;

struct path___45 {
	struct vfsmount *mnt;
	struct dentry___46 *dentry;
};

struct fown_struct___41 {
	rwlock_t lock;
	struct pid___41 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___46 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___45 f_path;
	struct inode___47 *f_inode;
	const struct file_operations___46 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___41 f_owner;
	const struct cred___45 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___45 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___45;

struct vm_operations_struct___45 {
	void (*open)(struct vm_area_struct___46 *);
	void (*close)(struct vm_area_struct___46 *);
	int (*split)(struct vm_area_struct___46 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___46 *);
	vm_fault_t (*fault)(struct vm_fault___45 *);
	vm_fault_t (*huge_fault)(struct vm_fault___45 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___45 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___46 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___45 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___45 *);
	int (*access)(struct vm_area_struct___46 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___46 *);
	int (*set_policy)(struct vm_area_struct___46 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___46 *, long unsigned int);
	struct page___46 * (*find_special_page)(struct vm_area_struct___46 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___45 {
	struct task_struct___47 *task;
	struct core_thread___45 *next;
};

struct core_state___45 {
	atomic_t nr_threads;
	struct core_thread___45 dumper;
	struct completion startup;
};

struct key___46;

struct ucounts___37;

struct user_namespace___37 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___37 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___4 ns;
	long unsigned int flags;
	struct key___46 *persistent_keyring_register;
	struct rw_semaphore___46 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___37 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___45 {
	struct vm_area_struct___46 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___46 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___46 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___45 prealloc_pte;
};

struct pid_namespace___41;

struct upid___41 {
	int nr;
	struct pid_namespace___41 *ns;
};

struct pid_namespace___41 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___47 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___41 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___46 *proc_self;
	struct dentry___46 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___37 *user_ns;
	struct ucounts___37 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___4 ns;
};

struct pid___41 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___41 numbers[1];
};

struct user_struct___45 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___46 *uid_keyring;
	struct key___46 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___45 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___46 *session_keyring;
	struct key___46 *process_keyring;
	struct key___46 *thread_keyring;
	struct key___46 *request_key_auth;
	void *security;
	struct user_struct___45 *user;
	struct user_namespace___37 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___12;

struct cgroup_namespace___35;

struct nsproxy___44 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___41 *pid_ns_for_children;
	struct net___12 *net_ns;
	struct cgroup_namespace___35 *cgroup_ns;
};

struct signal_struct___43 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___47 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___47 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___41 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___41 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___45 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___41 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___35;

struct cgroup___35;

struct css_set___35 {
	struct cgroup_subsys_state___35 *subsys[13];
	refcount_t refcount;
	struct css_set___35 *dom_cset;
	struct cgroup___35 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___35 *mg_src_cgrp;
	struct cgroup___35 *mg_dst_cgrp;
	struct css_set___35 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___45;

struct pipe_buffer___11;

struct pipe_inode_info___11 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___46 *tmp_page;
	struct fasync_struct___45 *fasync_readers;
	struct fasync_struct___45 *fasync_writers;
	struct pipe_buffer___11 *bufs;
	struct user_struct___45 *user;
};

struct vm_struct___36 {
	struct vm_struct___36 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___46 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___43 {
	struct task_struct___47 task;
	long unsigned int stack[8192];
};

struct kset___43;

struct kobj_type___43;

struct kernfs_node___43;

struct kobject___44 {
	const char *name;
	struct list_head entry;
	struct kobject___44 *parent;
	struct kset___43 *kset;
	struct kobj_type___43 *ktype;
	struct kernfs_node___43 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___41 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___41 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___41;

struct bus_type___41;

struct device_driver___41;

struct dev_pm_domain___41;

struct dma_map_ops___12;

struct fwnode_handle___33;

struct class___41;

struct attribute_group___41;

struct device___41 {
	struct device___41 *parent;
	struct device_private *p;
	struct kobject___44 kobj;
	const char *init_name;
	const struct device_type___41 *type;
	struct mutex mutex;
	struct bus_type___41 *bus;
	struct device_driver___41 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___41 power;
	struct dev_pm_domain___41 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___12 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___33 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___41 *class;
	const struct attribute_group___41 **groups;
	void (*release)(struct device___41 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___45;

struct super_block___46;

struct dentry___46 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___46 *d_parent;
	struct qstr d_name;
	struct inode___47 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___45 *d_op;
	struct super_block___46 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___45;

struct block_device___46;

struct inode___47 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___45 *i_op;
	struct super_block___46 *i_sb;
	struct address_space___45 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___46 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___46 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___45 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___11 *i_pipe;
		struct block_device___46 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___45 {
	int (*d_revalidate)(struct dentry___46 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___46 *, unsigned int);
	int (*d_hash)(const struct dentry___46 *, struct qstr *);
	int (*d_compare)(const struct dentry___46 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___46 *);
	int (*d_init)(struct dentry___46 *);
	void (*d_release)(struct dentry___46 *);
	void (*d_prune)(struct dentry___46 *);
	void (*d_iput)(struct dentry___46 *, struct inode___47 *);
	char * (*d_dname)(struct dentry___46 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___45 *);
	int (*d_manage)(const struct path___45 *, bool);
	struct dentry___46 * (*d_real)(struct dentry___46 *, const struct inode___47 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___45;

struct mem_dqinfo___45 {
	struct quota_format_type___45 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___45;

struct quota_info___45 {
	unsigned int flags;
	struct rw_semaphore___46 dqio_sem;
	struct inode___47 *files[3];
	struct mem_dqinfo___45 info[3];
	const struct quota_format_ops___45 *ops[3];
};

struct rcuwait___45 {
	struct task_struct___47 *task;
};

struct percpu_rw_semaphore___45 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___46 rw_sem;
	struct rcuwait___45 writer;
	int readers_block;
};

struct sb_writers___45 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___45 rw_sem[3];
};

struct file_system_type___45;

struct super_operations___45;

struct dquot_operations___45;

struct quotactl_ops___45;

struct super_block___46 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___45 *s_type;
	const struct super_operations___45 *s_op;
	const struct dquot_operations___45 *dq_op;
	const struct quotactl_ops___45 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___46 *s_root;
	struct rw_semaphore___46 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___46 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___45 s_dquot;
	struct sb_writers___45 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___45 *s_d_op;
	int cleancache_poolid;
	struct shrinker___17 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___37 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___46 {
	struct file___46 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___46 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___46 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___46 *ia_file;
};

struct dquot___45 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___46 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___45 {
	int qf_fmt_id;
	const struct quota_format_ops___45 *qf_ops;
	struct module___42 *qf_owner;
	struct quota_format_type___45 *qf_next;
};

struct quota_format_ops___45 {
	int (*check_quota_file)(struct super_block___46 *, int);
	int (*read_file_info)(struct super_block___46 *, int);
	int (*write_file_info)(struct super_block___46 *, int);
	int (*free_file_info)(struct super_block___46 *, int);
	int (*read_dqblk)(struct dquot___45 *);
	int (*commit_dqblk)(struct dquot___45 *);
	int (*release_dqblk)(struct dquot___45 *);
	int (*get_next_id)(struct super_block___46 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___45 {
	int (*write_dquot)(struct dquot___45 *);
	struct dquot___45 * (*alloc_dquot)(struct super_block___46 *, int);
	void (*destroy_dquot)(struct dquot___45 *);
	int (*acquire_dquot)(struct dquot___45 *);
	int (*release_dquot)(struct dquot___45 *);
	int (*mark_dirty)(struct dquot___45 *);
	int (*write_info)(struct super_block___46 *, int);
	qsize_t * (*get_reserved_space)(struct inode___47 *);
	int (*get_projid)(struct inode___47 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___47 *, qsize_t *);
	int (*get_next_id)(struct super_block___46 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___45 {
	int (*quota_on)(struct super_block___46 *, int, int, const struct path___45 *);
	int (*quota_off)(struct super_block___46 *, int);
	int (*quota_enable)(struct super_block___46 *, unsigned int);
	int (*quota_disable)(struct super_block___46 *, unsigned int);
	int (*quota_sync)(struct super_block___46 *, int);
	int (*set_info)(struct super_block___46 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___46 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___46 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___46 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___46 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___46 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___39 {
	struct kobject___44 kobj;
	struct module___42 *mod;
	struct kobject___44 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___39 {
	struct module___42 *mod;
	struct latch_tree_node node;
};

struct module_layout___39 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___39 mtn;
};

struct module_attribute___39;

struct kernel_param___39;

struct module___42 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___39 mkobj;
	struct module_attribute___39 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___44 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___39 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___39 core_layout;
	struct module_layout___39 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___45 {
	int (*writepage)(struct page___46 *, struct writeback_control___3 *);
	int (*readpage)(struct file___46 *, struct page___46 *);
	int (*writepages)(struct address_space___45 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___46 *);
	int (*readpages)(struct file___46 *, struct address_space___45 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___46 *, struct address_space___45 *, loff_t, unsigned int, unsigned int, struct page___46 **, void **);
	int (*write_end)(struct file___46 *, struct address_space___45 *, loff_t, unsigned int, unsigned int, struct page___46 *, void *);
	sector_t (*bmap)(struct address_space___45 *, sector_t);
	void (*invalidatepage)(struct page___46 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___46 *, gfp_t);
	void (*freepage)(struct page___46 *);
	ssize_t (*direct_IO)(struct kiocb___46 *, struct iov_iter___21 *);
	int (*migratepage)(struct address_space___45 *, struct page___46 *, struct page___46 *, enum migrate_mode);
	bool (*isolate_page)(struct page___46 *, isolate_mode_t);
	void (*putback_page)(struct page___46 *);
	int (*launder_page)(struct page___46 *);
	int (*is_partially_uptodate)(struct page___46 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___46 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___45 *, struct page___46 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___46 *, sector_t *);
	void (*swap_deactivate)(struct file___46 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct iov_iter___21 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___3 *bvec;
		struct pipe_inode_info___11 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___46 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___47 *bd_inode;
	struct super_block___46 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___46 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___45 {
	struct dentry___46 * (*lookup)(struct inode___47 *, struct dentry___46 *, unsigned int);
	const char * (*get_link)(struct dentry___46 *, struct inode___47 *, struct delayed_call *);
	int (*permission)(struct inode___47 *, int);
	struct posix_acl * (*get_acl)(struct inode___47 *, int);
	int (*readlink)(struct dentry___46 *, char *, int);
	int (*create)(struct inode___47 *, struct dentry___46 *, umode_t, bool);
	int (*link)(struct dentry___46 *, struct inode___47 *, struct dentry___46 *);
	int (*unlink)(struct inode___47 *, struct dentry___46 *);
	int (*symlink)(struct inode___47 *, struct dentry___46 *, const char *);
	int (*mkdir)(struct inode___47 *, struct dentry___46 *, umode_t);
	int (*rmdir)(struct inode___47 *, struct dentry___46 *);
	int (*mknod)(struct inode___47 *, struct dentry___46 *, umode_t, dev_t);
	int (*rename)(struct inode___47 *, struct dentry___46 *, struct inode___47 *, struct dentry___46 *, unsigned int);
	int (*setattr)(struct dentry___46 *, struct iattr___46 *);
	int (*getattr)(const struct path___45 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___46 *, char *, size_t);
	int (*fiemap)(struct inode___47 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___47 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___47 *, struct dentry___46 *, struct file___46 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___47 *, struct dentry___46 *, umode_t);
	int (*set_acl)(struct inode___47 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___45 {
	void (*fl_copy_lock)(struct file_lock___46 *, struct file_lock___46 *);
	void (*fl_release_private)(struct file_lock___46 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___45;

struct file_lock___46 {
	struct file_lock___46 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___46 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___45 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___45 *fl_ops;
	const struct lock_manager_operations___45 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___45 {
	int (*lm_compare_owner)(struct file_lock___46 *, struct file_lock___46 *);
	long unsigned int (*lm_owner_key)(struct file_lock___46 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___46 *);
	int (*lm_grant)(struct file_lock___46 *, int);
	bool (*lm_break)(struct file_lock___46 *);
	int (*lm_change)(struct file_lock___46 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___46 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___45 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___45 *fa_next;
	struct file___46 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___45 {
	const char *name;
	int fs_flags;
	struct dentry___46 * (*mount)(struct file_system_type___45 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___46 *);
	struct module___42 *owner;
	struct file_system_type___45 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___45 {
	struct inode___47 * (*alloc_inode)(struct super_block___46 *);
	void (*destroy_inode)(struct inode___47 *);
	void (*dirty_inode)(struct inode___47 *, int);
	int (*write_inode)(struct inode___47 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___47 *);
	void (*evict_inode)(struct inode___47 *);
	void (*put_super)(struct super_block___46 *);
	int (*sync_fs)(struct super_block___46 *, int);
	int (*freeze_super)(struct super_block___46 *);
	int (*freeze_fs)(struct super_block___46 *);
	int (*thaw_super)(struct super_block___46 *);
	int (*unfreeze_fs)(struct super_block___46 *);
	int (*statfs)(struct dentry___46 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___46 *, int *, char *);
	void (*umount_begin)(struct super_block___46 *);
	int (*show_options)(struct seq_file___44 *, struct dentry___46 *);
	int (*show_devname)(struct seq_file___44 *, struct dentry___46 *);
	int (*show_path)(struct seq_file___44 *, struct dentry___46 *);
	int (*show_stats)(struct seq_file___44 *, struct dentry___46 *);
	ssize_t (*quota_read)(struct super_block___46 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___46 *, int, const char *, size_t, loff_t);
	struct dquot___45 ** (*get_dquots)(struct inode___47 *);
	int (*bdev_try_to_free_page)(struct super_block___46 *, struct page___46 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___46 *, struct shrink_control___17 *);
	long int (*free_cached_objects)(struct super_block___46 *, struct shrink_control___17 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___41;

struct seq_file___44 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___41 *op;
	int poll_event;
	const struct file___46 *file;
	void *private;
};

struct kobj_attribute___44 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___44 *, struct kobj_attribute___44 *, char *);
	ssize_t (*store)(struct kobject___44 *, struct kobj_attribute___44 *, const char *, size_t);
};

typedef void compound_page_dtor___45(struct page___46 *);

struct kernfs_root___43;

struct kernfs_elem_dir___43 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___43 *root;
};

struct kernfs_syscall_ops___43;

struct kernfs_root___43 {
	struct kernfs_node___43 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___43 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___43 {
	struct kernfs_node___43 *target_kn;
};

struct kernfs_ops___43;

struct kernfs_elem_attr___43 {
	const struct kernfs_ops___43 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___43 *notify_next;
};

struct kernfs_node___43 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___43 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___43 dir;
		struct kernfs_elem_symlink___43 symlink;
		struct kernfs_elem_attr___43 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___43;

struct kernfs_ops___43 {
	int (*open)(struct kernfs_open_file___43 *);
	void (*release)(struct kernfs_open_file___43 *);
	int (*seq_show)(struct seq_file___44 *, void *);
	void * (*seq_start)(struct seq_file___44 *, loff_t *);
	void * (*seq_next)(struct seq_file___44 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___44 *, void *);
	ssize_t (*read)(struct kernfs_open_file___43 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___43 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___43 *, struct vm_area_struct___46 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___43 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___43 {
	int (*remount_fs)(struct kernfs_root___43 *, int *, char *);
	int (*show_options)(struct seq_file___44 *, struct kernfs_root___43 *);
	int (*mkdir)(struct kernfs_node___43 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___43 *);
	int (*rename)(struct kernfs_node___43 *, struct kernfs_node___43 *, const char *);
	int (*show_path)(struct seq_file___44 *, struct kernfs_node___43 *, struct kernfs_root___43 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___43 {
	struct kernfs_node___43 *kn;
	struct file___46 *file;
	struct seq_file___44 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___45 *vm_ops;
};

struct bin_attribute___41;

struct attribute_group___41 {
	const char *name;
	umode_t (*is_visible)(struct kobject___44 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___44 *, struct bin_attribute___41 *, int);
	struct attribute **attrs;
	struct bin_attribute___41 **bin_attrs;
};

struct bin_attribute___41 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___46 *, struct kobject___44 *, struct bin_attribute___41 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___46 *, struct kobject___44 *, struct bin_attribute___41 *, char *, loff_t, size_t);
	int (*mmap)(struct file___46 *, struct kobject___44 *, struct bin_attribute___41 *, struct vm_area_struct___46 *);
};

struct sysfs_ops___43 {
	ssize_t (*show)(struct kobject___44 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___44 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___43;

struct kset___43 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___44 kobj;
	const struct kset_uevent_ops___43 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___43 {
	void (*release)(struct kobject___44 *);
	const struct sysfs_ops___43 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___2 * (*child_ns_type)(struct kobject___44 *);
	const void * (*namespace)(struct kobject___44 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___43 {
	int (* const filter)(struct kset___43 *, struct kobject___44 *);
	const char * (* const name)(struct kset___43 *, struct kobject___44 *);
	int (* const uevent)(struct kset___43 *, struct kobject___44 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___39 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___39 *);
	int (*get)(char *, const struct kernel_param___39 *);
	void (*free)(void *);
};

struct kparam_array___39;

struct kernel_param___39 {
	const char *name;
	struct module___42 *mod;
	const struct kernel_param_ops___39 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___39 *arr;
	};
};

struct kparam_array___39 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___39 *ops;
	void *elem;
};

struct module_attribute___39 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___39 *, struct module_kobject___39 *, char *);
	ssize_t (*store)(struct module_attribute___39 *, struct module_kobject___39 *, const char *, size_t);
	void (*setup)(struct module___42 *, const char *);
	int (*test)(struct module___42 *);
	void (*free)(struct module___42 *);
};

typedef int (*key_restrict_link_func_t___45)(struct key___46 *, const struct key_type *, const union key_payload *, struct key___46 *);

struct key_restriction___46;

struct key___46 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___46 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___46 *restrict_link;
};

struct key_restriction___46 {
	key_restrict_link_func_t___45 check;
	struct key___46 *key;
	struct key_type *keytype;
};

struct inet_frags___5;

struct netns_frags___5 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___5 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv4___5 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct sock *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock **tcp_sk;
	struct netns_frags___5 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct net_device___10;

struct sk_buff___9;

struct dst_ops___10 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___10 *);
	struct dst_entry___2 * (*check)(struct dst_entry___2 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___2 *);
	unsigned int (*mtu)(const struct dst_entry___2 *);
	u32 * (*cow_metrics)(struct dst_entry___2 *, long unsigned int);
	void (*destroy)(struct dst_entry___2 *);
	void (*ifdown)(struct dst_entry___2 *, struct net_device___10 *, int);
	struct dst_entry___2 * (*negative_advice)(struct dst_entry___2 *);
	void (*link_failure)(struct sk_buff___9 *);
	void (*update_pmtu)(struct dst_entry___2 *, struct sock *, struct sk_buff___9 *, u32);
	void (*redirect)(struct dst_entry___2 *, struct sock *, struct sk_buff___9 *);
	int (*local_out)(struct net___12 *, struct sock *, struct sk_buff___9 *);
	struct neighbour___2 * (*neigh_lookup)(const struct dst_entry___2 *, struct sk_buff___9 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___2 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___9 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___5 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___10 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct sock *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops *notifier_ops;
	struct fib_notifier_ops *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_nf_frag___5 {
	struct netns_frags___5 frags;
};

struct netns_xfrm___9 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___10 xfrm4_dst_ops;
	struct dst_ops___10 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___4;

struct net___12 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___37 *user_ns;
	struct ucounts___37 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___4 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___10 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___5 ipv4;
	struct netns_ipv6___9 ipv6;
	struct netns_sctp___2 sctp;
	struct netns_nf nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___5 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock *nfnl;
	struct sock *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___9 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___4 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cgroup_namespace___35 {
	refcount_t count;
	struct ns_common___4 ns;
	struct user_namespace___37 *user_ns;
	struct ucounts___37 *ucounts;
	struct css_set___35 *root_cset;
};

struct ucounts___37 {
	struct hlist_node node;
	struct user_namespace___37 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct dev_pm_ops___41 {
	int (*prepare)(struct device___41 *);
	void (*complete)(struct device___41 *);
	int (*suspend)(struct device___41 *);
	int (*resume)(struct device___41 *);
	int (*freeze)(struct device___41 *);
	int (*thaw)(struct device___41 *);
	int (*poweroff)(struct device___41 *);
	int (*restore)(struct device___41 *);
	int (*suspend_late)(struct device___41 *);
	int (*resume_early)(struct device___41 *);
	int (*freeze_late)(struct device___41 *);
	int (*thaw_early)(struct device___41 *);
	int (*poweroff_late)(struct device___41 *);
	int (*restore_early)(struct device___41 *);
	int (*suspend_noirq)(struct device___41 *);
	int (*resume_noirq)(struct device___41 *);
	int (*freeze_noirq)(struct device___41 *);
	int (*thaw_noirq)(struct device___41 *);
	int (*poweroff_noirq)(struct device___41 *);
	int (*restore_noirq)(struct device___41 *);
	int (*runtime_suspend)(struct device___41 *);
	int (*runtime_resume)(struct device___41 *);
	int (*runtime_idle)(struct device___41 *);
};

struct dev_pm_domain___41 {
	struct dev_pm_ops___41 ops;
	void (*detach)(struct device___41 *, bool);
	int (*activate)(struct device___41 *);
	void (*sync)(struct device___41 *);
	void (*dismiss)(struct device___41 *);
};

struct bus_type___41 {
	const char *name;
	const char *dev_name;
	struct device___41 *dev_root;
	const struct attribute_group___41 **bus_groups;
	const struct attribute_group___41 **dev_groups;
	const struct attribute_group___41 **drv_groups;
	int (*match)(struct device___41 *, struct device_driver___41 *);
	int (*uevent)(struct device___41 *, struct kobj_uevent_env *);
	int (*probe)(struct device___41 *);
	int (*remove)(struct device___41 *);
	void (*shutdown)(struct device___41 *);
	int (*online)(struct device___41 *);
	int (*offline)(struct device___41 *);
	int (*suspend)(struct device___41 *, pm_message_t);
	int (*resume)(struct device___41 *);
	int (*num_vf)(struct device___41 *);
	int (*dma_configure)(struct device___41 *);
	const struct dev_pm_ops___41 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___41 {
	const char *name;
	struct bus_type___41 *bus;
	struct module___42 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___41 *);
	int (*remove)(struct device___41 *);
	void (*shutdown)(struct device___41 *);
	int (*suspend)(struct device___41 *, pm_message_t);
	int (*resume)(struct device___41 *);
	const struct attribute_group___41 **groups;
	const struct dev_pm_ops___41 *pm;
	void (*coredump)(struct device___41 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___41 {
	const char *name;
	const struct attribute_group___41 **groups;
	int (*uevent)(struct device___41 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___41 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___41 *);
	const struct dev_pm_ops___41 *pm;
};

struct class___41 {
	const char *name;
	struct module___42 *owner;
	const struct attribute_group___41 **class_groups;
	const struct attribute_group___41 **dev_groups;
	struct kobject___44 *dev_kobj;
	int (*dev_uevent)(struct device___41 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___41 *, umode_t *);
	void (*class_release)(struct class___41 *);
	void (*dev_release)(struct device___41 *);
	int (*shutdown_pre)(struct device___41 *);
	const struct kobj_ns_type_operations___2 *ns_type;
	const void * (*namespace)(struct device___41 *);
	const struct dev_pm_ops___41 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___12 {
	void * (*alloc)(struct device___41 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___41 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___41 *, struct vm_area_struct___46 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___41 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___41 *, struct page___46 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___41 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___41 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___41 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___41 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___41 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___41 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___41 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___41 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___41 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___41 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___41 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___41 *, u64);
	u64 (*get_required_mask)(struct device___41 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___33;

struct fwnode_handle___33 {
	struct fwnode_handle___33 *secondary;
	const struct fwnode_operations___33 *ops;
};

struct node___38 {
	struct device___41 dev;
};

struct nf_bridge_info___5;

struct sk_buff___9 {
	union {
		struct {
			struct sk_buff___9 *next;
			struct sk_buff___9 *prev;
			union {
				struct net_device___10 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___5 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___9 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___5 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct fwnode_reference_args___33;

struct fwnode_endpoint___33;

struct fwnode_operations___33 {
	struct fwnode_handle___33 * (*get)(struct fwnode_handle___33 *);
	void (*put)(struct fwnode_handle___33 *);
	bool (*device_is_available)(const struct fwnode_handle___33 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___33 *, const struct device___41 *);
	bool (*property_present)(const struct fwnode_handle___33 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___33 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___33 *, const char *, const char **, size_t);
	struct fwnode_handle___33 * (*get_parent)(const struct fwnode_handle___33 *);
	struct fwnode_handle___33 * (*get_next_child_node)(const struct fwnode_handle___33 *, struct fwnode_handle___33 *);
	struct fwnode_handle___33 * (*get_named_child_node)(const struct fwnode_handle___33 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___33 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___33 *);
	struct fwnode_handle___33 * (*graph_get_next_endpoint)(const struct fwnode_handle___33 *, struct fwnode_handle___33 *);
	struct fwnode_handle___33 * (*graph_get_remote_endpoint)(const struct fwnode_handle___33 *);
	struct fwnode_handle___33 * (*graph_get_port_parent)(struct fwnode_handle___33 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___33 *, struct fwnode_endpoint___33 *);
};

struct fwnode_endpoint___33 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___33 *local_fwnode;
};

struct fwnode_reference_args___33 {
	struct fwnode_handle___33 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___11;

struct pipe_buffer___11 {
	struct page___46 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___11 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___11 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___11 *, struct pipe_buffer___11 *);
	void (*release)(struct pipe_inode_info___11 *, struct pipe_buffer___11 *);
	int (*steal)(struct pipe_inode_info___11 *, struct pipe_buffer___11 *);
	union {
		bool (*get)(struct pipe_inode_info___11 *, struct pipe_buffer___11 *);
		struct {
			void (*get)(struct pipe_inode_info___11 *, struct pipe_buffer___11 *);
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
};

struct nf_bridge_info___5 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___5 = 0,
		BRNF_PROTO_8021Q___5 = 1,
		BRNF_PROTO_PPPOE___5 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___10 *physindev;
	struct net_device___10 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___5(struct sk_buff___9 **);

typedef struct {
	struct net___12 *net;
} possible_net_t___5;

struct net_device_ops___5;

struct ethtool_ops___5;

struct xfrmdev_ops___5;

struct tlsdev_ops___5;

struct header_ops___5;

struct netdev_rx_queue___5;

struct mini_Qdisc___4;

struct netdev_queue___5;

struct Qdisc___4;

struct rtnl_link_ops___4;

struct dcbnl_rtnl_ops___5;

struct net_device___10 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___5 *netdev_ops;
	const struct ethtool_ops___5 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___2 *l3mdev_ops;
	const struct ndisc_ops___2 *ndisc_ops;
	const struct xfrmdev_ops___5 *xfrmdev_ops;
	const struct tlsdev_ops___5 *tlsdev_ops;
	const struct header_ops___5 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___43 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___2 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___5 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___4 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___5 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___4 *miniq_ingress;
	struct netdev_queue___5 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___5 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___4 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___4 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___5 = 0,
		NETREG_REGISTERED___5 = 1,
		NETREG_UNREGISTERING___5 = 2,
		NETREG_UNREGISTERED___5 = 3,
		NETREG_RELEASED___5 = 4,
		NETREG_DUMMY___5 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___5 = 0,
		RTNL_LINK_INITIALIZING___5 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___10 *);
	struct netpoll_info *npinfo;
	possible_net_t___5 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___41 dev;
	const struct attribute_group___41 *sysfs_groups[4];
	const struct attribute_group___41 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___4 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___5 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide35;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct sk_buff_head___6 {
	struct sk_buff___9 *next;
	struct sk_buff___9 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct ethtool_ops___5 {
	int (*get_settings)(struct net_device___10 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___10 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___10 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___10 *);
	void (*get_regs)(struct net_device___10 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___10 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___10 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___10 *);
	void (*set_msglevel)(struct net_device___10 *, u32);
	int (*nway_reset)(struct net_device___10 *);
	u32 (*get_link)(struct net_device___10 *);
	int (*get_eeprom_len)(struct net_device___10 *);
	int (*get_eeprom)(struct net_device___10 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___10 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___10 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___10 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___10 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___10 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___10 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___10 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___10 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___10 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___10 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___10 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___10 *);
	void (*complete)(struct net_device___10 *);
	u32 (*get_priv_flags)(struct net_device___10 *);
	int (*set_priv_flags)(struct net_device___10 *, u32);
	int (*get_sset_count)(struct net_device___10 *, int);
	int (*get_rxnfc)(struct net_device___10 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___10 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___10 *, struct ethtool_flash *);
	int (*reset)(struct net_device___10 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___10 *);
	u32 (*get_rxfh_indir_size)(struct net_device___10 *);
	int (*get_rxfh)(struct net_device___10 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___10 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___10 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___10 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___10 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___10 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___10 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___10 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___10 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___10 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___10 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___10 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___10 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___10 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___10 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___10 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___10 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___10 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___10 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___10 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___10 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___10 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	int (*get_fecparam)(struct net_device___10 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___10 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___10 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___10 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___10 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___5;

struct inet_frags___5 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___5 *, const void *);
	void (*destructor)(struct inet_frag_queue___5 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___5 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___9 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___9 *fragments_tail;
	struct sk_buff___9 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___5 *net;
	struct callback_head rcu;
};

struct bpf_prog_aux___4;

struct bpf_prog___4 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___4 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

struct seq_operations___41 {
	void * (*start)(struct seq_file___44 *, loff_t *);
	void (*stop)(struct seq_file___44 *, void *);
	void * (*next)(struct seq_file___44 *, void *, loff_t *);
	int (*show)(struct seq_file___44 *, void *);
};

struct pernet_operations___5 {
	struct list_head list;
	int (*init)(struct net___12 *);
	void (*exit)(struct net___12 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___5 {
	int (*ieee_getets)(struct net_device___10 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___10 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___10 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___10 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___10 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___10 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___10 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___10 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___10 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___10 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___10 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___10 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___10 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___10 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___10 *);
	u8 (*setstate)(struct net_device___10 *, u8);
	void (*getpermhwaddr)(struct net_device___10 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___10 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___10 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___10 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___10 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___10 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___10 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___10 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___10 *, int, u8 *);
	void (*setpfccfg)(struct net_device___10 *, int, u8);
	void (*getpfccfg)(struct net_device___10 *, int, u8 *);
	u8 (*setall)(struct net_device___10 *);
	u8 (*getcap)(struct net_device___10 *, int, u8 *);
	int (*getnumtcs)(struct net_device___10 *, int, u8 *);
	int (*setnumtcs)(struct net_device___10 *, int, u8);
	u8 (*getpfcstate)(struct net_device___10 *);
	void (*setpfcstate)(struct net_device___10 *, u8);
	void (*getbcncfg)(struct net_device___10 *, int, u32 *);
	void (*setbcncfg)(struct net_device___10 *, int, u32);
	void (*getbcnrp)(struct net_device___10 *, int, u8 *);
	void (*setbcnrp)(struct net_device___10 *, int, u8);
	int (*setapp)(struct net_device___10 *, u8, u16, u8);
	int (*getapp)(struct net_device___10 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___10 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___10 *, int, u8);
	u8 (*getdcbx)(struct net_device___10 *);
	u8 (*setdcbx)(struct net_device___10 *, u8);
	int (*peer_getappinfo)(struct net_device___10 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___10 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___10 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___10 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___10 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___10 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct bpf_map___35;

struct bpf_map_ops___35 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___35 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___35 *, struct file___46 *);
	void (*map_free)(struct bpf_map___35 *);
	int (*map_get_next_key)(struct bpf_map___35 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___35 *);
	void * (*map_lookup_elem)(struct bpf_map___35 *, void *);
	int (*map_update_elem)(struct bpf_map___35 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___35 *, void *);
	int (*map_push_elem)(struct bpf_map___35 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___35 *, void *);
	int (*map_peek_elem)(struct bpf_map___35 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___35 *, struct file___46 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___35 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___35 *, void *, struct seq_file___44 *);
	int (*map_check_btf)(const struct bpf_map___35 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___35 {
	const struct bpf_map_ops___35 *ops;
	struct bpf_map___35 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___45 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___5;

struct bpf_map_dev_ops___5 {
	int (*map_get_next_key)(struct bpf_offloaded_map___5 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___5 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___5 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___5 *, void *);
};

struct bpf_offloaded_map___5 {
	struct bpf_map___35 map;
	struct net_device___10 *netdev;
	const struct bpf_map_dev_ops___5 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___4 {
	int (*test_run)(struct bpf_prog___4 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___4 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___4 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___4 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___4 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___4 *, u32 *);
};

struct bpf_prog_offload_ops___4 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___4 *);
	int (*translate)(struct bpf_prog___4 *);
	void (*destroy)(struct bpf_prog___4 *);
};

struct bpf_prog_offload___4 {
	struct bpf_prog___4 *prog;
	struct net_device___10 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___4 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___4 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___4 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___4 *ops;
	struct bpf_map___35 **used_maps;
	struct bpf_prog___4 *prog;
	struct user_struct___45 *user;
	u64 load_time;
	struct bpf_map___35 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___4 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___4 {
	struct bpf_prog___4 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___4 {
	struct callback_head rcu;
	struct bpf_prog_array_item___4 items[0];
};

struct cgroup_bpf___4 {
	struct bpf_prog_array___4 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___4 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___35;

typedef void (*kthread_work_func_t___35)(struct kthread_work___35 *);

struct kthread_worker___35;

struct kthread_work___35 {
	struct list_head node;
	kthread_work_func_t___35 func;
	struct kthread_worker___35 *worker;
	int canceling;
};

struct kthread_worker___35 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___47 *task;
	struct kthread_work___35 *current_work;
};

struct kthread_delayed_work___35 {
	struct kthread_work___35 work;
	struct timer_list timer;
};

struct psi_group___35 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___35 *poll_kworker;
	struct kthread_delayed_work___35 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___35 {
	struct kernfs_node___43 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___35;

struct cgroup_subsys_state___35 {
	struct cgroup___35 *cgroup;
	struct cgroup_subsys___35 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___35 *parent;
};

struct cgroup_root___35;

struct cgroup_rstat_cpu___35;

struct cgroup___35 {
	struct cgroup_subsys_state___35 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___43 *kn;
	struct cgroup_file___35 procs_file;
	struct cgroup_file___35 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___35 *subsys[13];
	struct cgroup_root___35 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___35 *dom_cgrp;
	struct cgroup_rstat_cpu___35 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___4 bpf;
	atomic_t congestion_count;
	struct cgroup___35 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___35 psi;
	int ancestor_ids[0];
};

struct cftype___35;

struct cgroup_subsys___35 {
	struct cgroup_subsys_state___35 * (*css_alloc)(struct cgroup_subsys_state___35 *);
	int (*css_online)(struct cgroup_subsys_state___35 *);
	void (*css_offline)(struct cgroup_subsys_state___35 *);
	void (*css_released)(struct cgroup_subsys_state___35 *);
	void (*css_free)(struct cgroup_subsys_state___35 *);
	void (*css_reset)(struct cgroup_subsys_state___35 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___35 *, int);
	int (*css_extra_stat_show)(struct seq_file___44 *, struct cgroup_subsys_state___35 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___47 *);
	void (*cancel_fork)(struct task_struct___47 *);
	void (*fork)(struct task_struct___47 *);
	void (*exit)(struct task_struct___47 *);
	void (*free)(struct task_struct___47 *);
	void (*bind)(struct cgroup_subsys_state___35 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___35 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___35 *dfl_cftypes;
	struct cftype___35 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___35 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___35 *updated_children;
	struct cgroup___35 *updated_next;
};

struct cgroup_root___35 {
	struct kernfs_root___43 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___35 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___35 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___35 *ss;
	struct list_head node;
	struct kernfs_ops___43 *kf_ops;
	int (*open)(struct kernfs_open_file___43 *);
	void (*release)(struct kernfs_open_file___43 *);
	u64 (*read_u64)(struct cgroup_subsys_state___35 *, struct cftype___35 *);
	s64 (*read_s64)(struct cgroup_subsys_state___35 *, struct cftype___35 *);
	int (*seq_show)(struct seq_file___44 *, void *);
	void * (*seq_start)(struct seq_file___44 *, loff_t *);
	void * (*seq_next)(struct seq_file___44 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___44 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___35 *, struct cftype___35 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___35 *, struct cftype___35 *, s64);
	ssize_t (*write)(struct kernfs_open_file___43 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___43 *, struct poll_table_struct___6 *);
};

struct xdp_rxq_info___5 {
	struct net_device___10 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___5 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___10 *dev_rx;
};

struct netlink_callback___5 {
	struct sk_buff___9 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___5 *);
	int (*dump)(struct sk_buff___9 *, struct netlink_callback___5 *);
	int (*done)(struct netlink_callback___5 *);
	void *data;
	struct module___42 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___5 {
	int (*create)(struct sk_buff___9 *, struct net_device___10 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___9 *, unsigned char *);
	int (*cache)(const struct neighbour___2 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___10 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___5 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___5 *, int);
	int poll_owner;
	struct net_device___10 *dev;
	struct sk_buff___9 *gro_list;
	struct sk_buff___9 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___5 {
	struct net_device___10 *dev;
	struct Qdisc___4 *qdisc;
	struct Qdisc___4 *qdisc_sleeping;
	struct kobject___44 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___10 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___4 {
	struct sk_buff___9 *head;
	struct sk_buff___9 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___4;

struct Qdisc___4 {
	int (*enqueue)(struct sk_buff___9 *, struct Qdisc___4 *, struct sk_buff___9 **);
	struct sk_buff___9 * (*dequeue)(struct Qdisc___4 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___4 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___5 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___6 gso_skb;
	struct qdisc_skb_head___4 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___4 *next_sched;
	struct sk_buff_head___6 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___5 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___44 kobj;
	struct net_device___10 *dev;
	long: 64;
	struct xdp_rxq_info___5 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___5)(struct net_device___10 *, struct sk_buff___9 *, struct net_device___10 *);

struct netdev_bpf___5 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___4 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___4 *prog;
			const struct bpf_prog_offload_ops___4 *ops;
		} verifier;
		struct {
			struct bpf_prog___4 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___5 *offmap;
		};
		struct {
			struct xdp_umem *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___5 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___9 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___5 {
	int (*tls_dev_add)(struct net_device___10 *, struct sock *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___10 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___10 *, struct sock *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___5 {
	int (*ndo_init)(struct net_device___10 *);
	void (*ndo_uninit)(struct net_device___10 *);
	int (*ndo_open)(struct net_device___10 *);
	int (*ndo_stop)(struct net_device___10 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___9 *, struct net_device___10 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___9 *, struct net_device___10 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___10 *, struct sk_buff___9 *, struct net_device___10 *, select_queue_fallback_t___5);
	void (*ndo_change_rx_flags)(struct net_device___10 *, int);
	void (*ndo_set_rx_mode)(struct net_device___10 *);
	int (*ndo_set_mac_address)(struct net_device___10 *, void *);
	int (*ndo_validate_addr)(struct net_device___10 *);
	int (*ndo_do_ioctl)(struct net_device___10 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___10 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___10 *, int);
	int (*ndo_neigh_setup)(struct net_device___10 *, struct neigh_parms___3 *);
	void (*ndo_tx_timeout)(struct net_device___10 *);
	void (*ndo_get_stats64)(struct net_device___10 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___10 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___10 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___10 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___10 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___10 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___10 *);
	int (*ndo_netpoll_setup)(struct net_device___10 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___10 *);
	int (*ndo_set_vf_mac)(struct net_device___10 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___10 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___10 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___10 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___10 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___10 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___10 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___10 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___10 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___10 *, int, struct sk_buff___9 *);
	int (*ndo_set_vf_guid)(struct net_device___10 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___10 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___10 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___10 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___10 *, const struct sk_buff___9 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___10 *, struct net_device___10 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___10 *, struct net_device___10 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___10 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___10 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___10 *, struct neighbour___2 *);
	void (*ndo_neigh_destroy)(struct net_device___10 *, struct neighbour___2 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___10 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___10 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___10 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___9 *, struct netlink_callback___5 *, struct net_device___10 *, struct net_device___10 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___10 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___10 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___9 *, u32, u32, struct net_device___10 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___10 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___10 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___10 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___10 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___10 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___10 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___10 *, struct net_device___10 *);
	void (*ndo_dfwd_del_station)(struct net_device___10 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___10 *);
	int (*ndo_set_tx_maxrate)(struct net_device___10 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___10 *);
	int (*ndo_change_proto_down)(struct net_device___10 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___10 *, struct sk_buff___9 *);
	void (*ndo_set_rx_headroom)(struct net_device___10 *, int);
	int (*ndo_bpf)(struct net_device___10 *, struct netdev_bpf___5 *);
	int (*ndo_xdp_xmit)(struct net_device___10 *, int, struct xdp_frame___5 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___10 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___10 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct tcf_proto___4;

struct mini_Qdisc___4 {
	struct tcf_proto___4 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___4 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___10 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___12 *, struct net_device___10 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___10 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___10 *, struct list_head *);
	size_t (*get_size)(const struct net_device___10 *);
	int (*fill_info)(struct sk_buff___9 *, const struct net_device___10 *);
	size_t (*get_xstats_size)(const struct net_device___10 *);
	int (*fill_xstats)(struct sk_buff___9 *, const struct net_device___10 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___10 *, struct net_device___10 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___10 *, const struct net_device___10 *);
	int (*fill_slave_info)(struct sk_buff___9 *, const struct net_device___10 *, const struct net_device___10 *);
	struct net___12 * (*get_link_net)(const struct net_device___10 *);
	size_t (*get_linkxstats_size)(const struct net_device___10 *, int);
	int (*fill_linkxstats)(struct sk_buff___9 *, const struct net_device___10 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___5 {
	struct list_head poll_list;
	struct sk_buff_head___6 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___5 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___4 *output_queue;
	struct Qdisc___4 **output_queue_tailp;
	struct sk_buff___9 *completion_queue;
	struct sk_buff_head___6 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___5 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___6 input_pkt_queue;
	struct napi_struct___5 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct gnet_dump___4 {
	spinlock_t *lock;
	struct sk_buff___9 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___4;

struct Qdisc_ops___4 {
	struct Qdisc_ops___4 *next;
	const struct Qdisc_class_ops___4 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___9 *, struct Qdisc___4 *, struct sk_buff___9 **);
	struct sk_buff___9 * (*dequeue)(struct Qdisc___4 *);
	struct sk_buff___9 * (*peek)(struct Qdisc___4 *);
	int (*init)(struct Qdisc___4 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___4 *);
	void (*destroy)(struct Qdisc___4 *);
	int (*change)(struct Qdisc___4 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___4 *);
	int (*change_tx_queue_len)(struct Qdisc___4 *, unsigned int);
	int (*dump)(struct Qdisc___4 *, struct sk_buff___9 *);
	int (*dump_stats)(struct Qdisc___4 *, struct gnet_dump___4 *);
	void (*ingress_block_set)(struct Qdisc___4 *, u32);
	void (*egress_block_set)(struct Qdisc___4 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___4 *);
	u32 (*egress_block_get)(struct Qdisc___4 *);
	struct module___42 *owner;
};

struct tcf_block___4;

struct Qdisc_class_ops___4 {
	unsigned int flags;
	struct netdev_queue___5 * (*select_queue)(struct Qdisc___4 *, struct tcmsg *);
	int (*graft)(struct Qdisc___4 *, long unsigned int, struct Qdisc___4 *, struct Qdisc___4 **, struct netlink_ext_ack *);
	struct Qdisc___4 * (*leaf)(struct Qdisc___4 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___4 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___4 *, u32);
	int (*change)(struct Qdisc___4 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___4 *, long unsigned int);
	void (*walk)(struct Qdisc___4 *, struct qdisc_walker *);
	struct tcf_block___4 * (*tcf_block)(struct Qdisc___4 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___4 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___4 *, long unsigned int);
	int (*dump)(struct Qdisc___4 *, long unsigned int, struct sk_buff___9 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___4 *, long unsigned int, struct gnet_dump___4 *);
};

struct tcf_chain___4;

struct tcf_block___4 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___12 *net;
	struct Qdisc___4 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___4 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___4;

struct tcf_proto_ops___4;

struct tcf_proto___4 {
	struct tcf_proto___4 *next;
	void *root;
	int (*classify)(struct sk_buff___9 *, const struct tcf_proto___4 *, struct tcf_result___4 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___4 *ops;
	struct tcf_chain___4 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___4 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___4 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___4 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___9 *, const struct tcf_proto___4 *, struct tcf_result___4 *);
	int (*init)(struct tcf_proto___4 *);
	void (*destroy)(struct tcf_proto___4 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___4 *, u32);
	void (*put)(struct tcf_proto___4 *, void *);
	int (*change)(struct net___12 *, struct sk_buff___9 *, struct tcf_proto___4 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___4 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___4 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___4 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___12 *, struct tcf_chain___4 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___12 *, struct tcf_proto___4 *, void *, struct sk_buff___9 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___9 *, struct net___12 *, void *);
	struct module___42 *owner;
	int flags;
};

struct tcf_chain___4 {
	struct mutex filter_chain_lock;
	struct tcf_proto___4 *filter_chain;
	struct list_head list;
	struct tcf_block___4 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___4 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct bpf_redirect_info___4 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___35 *map;
	struct bpf_map___35 *map_to_flush;
	u32 kern_flags;
};

enum {
	KERNEL_PARAM_OPS_FL_NOARG = 1,
};

enum {
	KERNEL_PARAM_FL_UNSAFE = 1,
	KERNEL_PARAM_FL_HWPARAM = 2,
};

struct param_attribute {
	struct module_attribute___36 mattr;
	const struct kernel_param___36 *param;
};

struct module_param_attrs {
	unsigned int num;
	struct attribute_group___37 grp;
	struct param_attribute attrs[0];
};

struct module_version_attribute {
	struct module_attribute___36 mattr;
	const char *module_name;
	const char *version;
};

struct kmalloced_param {
	struct list_head list;
	char val[0];
};

struct sched_param {
	int sched_priority;
};

struct file___47;

struct kiocb___47;

struct vm_area_struct___47;

struct inode___48;

struct file_lock___47;

struct page___47;

struct seq_file___45;

struct file_operations___47 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___47 *, loff_t, int);
	ssize_t (*read)(struct file___47 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___47 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___47 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___47 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___47 *, bool);
	int (*iterate)(struct file___47 *, struct dir_context *);
	int (*iterate_shared)(struct file___47 *, struct dir_context *);
	__poll_t (*poll)(struct file___47 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___47 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___47 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___47 *, struct vm_area_struct___47 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___48 *, struct file___47 *);
	int (*flush)(struct file___47 *, fl_owner_t);
	int (*release)(struct inode___48 *, struct file___47 *);
	int (*fsync)(struct file___47 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___47 *, int);
	int (*lock)(struct file___47 *, int, struct file_lock___47 *);
	ssize_t (*sendpage)(struct file___47 *, struct page___47 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___47 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___47 *, int, struct file_lock___47 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___47 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___47 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___47 *, long int, struct file_lock___47 **, void **);
	long int (*fallocate)(struct file___47 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___45 *, struct file___47 *);
	ssize_t (*copy_file_range)(struct file___47 *, loff_t, struct file___47 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___47 *, loff_t, struct file___47 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___47 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___46 {
	u64 seqnum;
	struct vm_area_struct___47 *vmas[4];
};

struct page_frag___46 {
	struct page___47 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___46;

struct pid___42;

struct cred___46;

struct nsproxy___45;

struct signal_struct___44;

struct css_set___36;

struct task_struct___48 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___48 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___46 *mm;
	struct mm_struct___46 *active_mm;
	struct vmacache___46 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___48 *real_parent;
	struct task_struct___48 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___48 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___42 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___42 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___42 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___46 *ptracer_cred;
	const struct cred___46 *real_cred;
	const struct cred___46 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___45 *nsproxy;
	struct signal_struct___44 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___48 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___10 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___36 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___46 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___48 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___29 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___42;

struct upid___42 {
	int nr;
	struct pid_namespace___42 *ns;
};

struct dentry___47;

struct user_namespace___38;

struct ucounts___38;

struct pid_namespace___42 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___48 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___42 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___47 *proc_self;
	struct dentry___47 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___38 *user_ns;
	struct ucounts___38 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___4 ns;
};

struct pid___42 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___42 numbers[1];
};

struct rw_semaphore___47 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___48 *owner;
};

struct key___47;

struct user_namespace___38 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___38 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___4 ns;
	long unsigned int flags;
	struct key___47 *persistent_keyring_register;
	struct rw_semaphore___47 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___38 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct secondary_data___47 {
	void *stack;
	struct task_struct___48 *task;
	long int status;
};

typedef struct page___47 *pgtable_t___46;

struct address_space___46;

struct dev_pagemap___46;

struct page___47 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___46 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___47 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___46 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___46 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___46 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct user_struct___46 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___47 *uid_keyring;
	struct key___47 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___46;

struct vm_area_struct___47 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___47 *vm_next;
	struct vm_area_struct___47 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___46 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___46 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___47 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct linux_binfmt___9;

struct core_state___46;

struct mm_struct___46 {
	struct {
		struct vm_area_struct___47 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___47 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___47 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___9 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___46 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___48 *owner;
		struct user_namespace___38 *user_ns;
		struct file___47 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___46 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___46 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___47 *session_keyring;
	struct key___47 *process_keyring;
	struct key___47 *thread_keyring;
	struct key___47 *request_key_auth;
	void *security;
	struct user_struct___46 *user;
	struct user_namespace___38 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___36;

struct nsproxy___45 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___42 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___36 *cgroup_ns;
};

struct signal_struct___44 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___48 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___48 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___42 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___42 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___46 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___42 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___36;

struct cgroup___36;

struct css_set___36 {
	struct cgroup_subsys_state___36 *subsys[13];
	refcount_t refcount;
	struct css_set___36 *dom_cset;
	struct cgroup___36 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___36 *mg_src_cgrp;
	struct cgroup___36 *mg_dst_cgrp;
	struct css_set___36 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

union thread_union___44 {
	struct task_struct___48 task;
	long unsigned int stack[8192];
};

struct kthread_work___36;

typedef void (*kthread_work_func_t___36)(struct kthread_work___36 *);

struct kthread_worker___36;

struct kthread_work___36 {
	struct list_head node;
	kthread_work_func_t___36 func;
	struct kthread_worker___36 *worker;
	int canceling;
};

enum {
	KTW_FREEZABLE = 1,
};

struct kthread_worker___36 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___48 *task;
	struct kthread_work___36 *current_work;
};

struct kthread_delayed_work___36 {
	struct kthread_work___36 work;
	struct timer_list timer;
};

struct dentry_operations___46;

struct super_block___47;

struct dentry___47 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___47 *d_parent;
	struct qstr d_name;
	struct inode___48 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___46 *d_op;
	struct super_block___47 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___46;

struct address_space___46 {
	struct inode___48 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___47 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___46 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___46;

struct block_device___47;

struct inode___48 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___46 *i_op;
	struct super_block___47 *i_sb;
	struct address_space___46 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___47 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___47 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___46 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___47 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___46;

struct dentry_operations___46 {
	int (*d_revalidate)(struct dentry___47 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___47 *, unsigned int);
	int (*d_hash)(const struct dentry___47 *, struct qstr *);
	int (*d_compare)(const struct dentry___47 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___47 *);
	int (*d_init)(struct dentry___47 *);
	void (*d_release)(struct dentry___47 *);
	void (*d_prune)(struct dentry___47 *);
	void (*d_iput)(struct dentry___47 *, struct inode___48 *);
	char * (*d_dname)(struct dentry___47 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___46 *);
	int (*d_manage)(const struct path___46 *, bool);
	struct dentry___47 * (*d_real)(struct dentry___47 *, const struct inode___48 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___46;

struct mem_dqinfo___46 {
	struct quota_format_type___46 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___46;

struct quota_info___46 {
	unsigned int flags;
	struct rw_semaphore___47 dqio_sem;
	struct inode___48 *files[3];
	struct mem_dqinfo___46 info[3];
	const struct quota_format_ops___46 *ops[3];
};

struct rcuwait___46 {
	struct task_struct___48 *task;
};

struct percpu_rw_semaphore___46 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___47 rw_sem;
	struct rcuwait___46 writer;
	int readers_block;
};

struct sb_writers___46 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___46 rw_sem[3];
};

struct file_system_type___46;

struct super_operations___46;

struct dquot_operations___46;

struct quotactl_ops___46;

struct super_block___47 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___46 *s_type;
	const struct super_operations___46 *s_op;
	const struct dquot_operations___46 *dq_op;
	const struct quotactl_ops___46 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___47 *s_root;
	struct rw_semaphore___47 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___47 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___46 s_dquot;
	struct sb_writers___46 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___46 *s_d_op;
	int cleancache_poolid;
	struct shrinker___17 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___38 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct path___46 {
	struct vfsmount *mnt;
	struct dentry___47 *dentry;
};

struct pglist_data___46;

struct lruvec___46 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___46 *pgdat;
};

struct zone___46 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___46 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___46 {
	struct zone___46 *zone;
	int zone_idx;
};

struct zonelist___46 {
	struct zoneref___46 _zonerefs[25];
};

struct pglist_data___46 {
	struct zone___46 node_zones[3];
	struct zonelist___46 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___48 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___48 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___46 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___46 {
	struct rw_semaphore___47 rwsem;
	struct notifier_block *head;
};

typedef int (*dev_page_fault_t___46)(struct vm_area_struct___47 *, long unsigned int, const struct page___47 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___46)(struct page___47 *, void *);

struct dev_pagemap___46 {
	dev_page_fault_t___46 page_fault;
	dev_page_free_t___46 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___6 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct fown_struct___42 {
	rwlock_t lock;
	struct pid___42 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___47 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___46 f_path;
	struct inode___48 *f_inode;
	const struct file_operations___47 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___42 f_owner;
	const struct cred___46 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___46 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___46;

struct vm_operations_struct___46 {
	void (*open)(struct vm_area_struct___47 *);
	void (*close)(struct vm_area_struct___47 *);
	int (*split)(struct vm_area_struct___47 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___47 *);
	vm_fault_t (*fault)(struct vm_fault___46 *);
	vm_fault_t (*huge_fault)(struct vm_fault___46 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___46 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___47 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___46 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___46 *);
	int (*access)(struct vm_area_struct___47 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___47 *);
	int (*set_policy)(struct vm_area_struct___47 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___47 *, long unsigned int);
	struct page___47 * (*find_special_page)(struct vm_area_struct___47 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___46 {
	struct task_struct___48 *task;
	struct core_thread___46 *next;
};

struct core_state___46 {
	atomic_t nr_threads;
	struct core_thread___46 dumper;
	struct completion startup;
};

struct linux_binprm___9;

struct coredump_params___8;

struct linux_binfmt___9 {
	struct list_head lh;
	struct module___11 *module;
	int (*load_binary)(struct linux_binprm___9 *);
	int (*load_shlib)(struct file___47 *);
	int (*core_dump)(struct coredump_params___8 *);
	long unsigned int min_coredump;
};

struct vm_fault___46 {
	struct vm_area_struct___47 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___47 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___47 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___46 prealloc_pte;
};

struct kiocb___47 {
	struct file___47 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___47 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___47 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___47 *ia_file;
};

struct dquot___46 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___47 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___46 {
	int qf_fmt_id;
	const struct quota_format_ops___46 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___46 *qf_next;
};

struct quota_format_ops___46 {
	int (*check_quota_file)(struct super_block___47 *, int);
	int (*read_file_info)(struct super_block___47 *, int);
	int (*write_file_info)(struct super_block___47 *, int);
	int (*free_file_info)(struct super_block___47 *, int);
	int (*read_dqblk)(struct dquot___46 *);
	int (*commit_dqblk)(struct dquot___46 *);
	int (*release_dqblk)(struct dquot___46 *);
	int (*get_next_id)(struct super_block___47 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___46 {
	int (*write_dquot)(struct dquot___46 *);
	struct dquot___46 * (*alloc_dquot)(struct super_block___47 *, int);
	void (*destroy_dquot)(struct dquot___46 *);
	int (*acquire_dquot)(struct dquot___46 *);
	int (*release_dquot)(struct dquot___46 *);
	int (*mark_dirty)(struct dquot___46 *);
	int (*write_info)(struct super_block___47 *, int);
	qsize_t * (*get_reserved_space)(struct inode___48 *);
	int (*get_projid)(struct inode___48 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___48 *, qsize_t *);
	int (*get_next_id)(struct super_block___47 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___46 {
	int (*quota_on)(struct super_block___47 *, int, int, const struct path___46 *);
	int (*quota_off)(struct super_block___47 *, int);
	int (*quota_enable)(struct super_block___47 *, unsigned int);
	int (*quota_disable)(struct super_block___47 *, unsigned int);
	int (*quota_sync)(struct super_block___47 *, int);
	int (*set_info)(struct super_block___47 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___47 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___47 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___47 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___47 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___47 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___46 {
	int (*writepage)(struct page___47 *, struct writeback_control___3 *);
	int (*readpage)(struct file___47 *, struct page___47 *);
	int (*writepages)(struct address_space___46 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___47 *);
	int (*readpages)(struct file___47 *, struct address_space___46 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___47 *, struct address_space___46 *, loff_t, unsigned int, unsigned int, struct page___47 **, void **);
	int (*write_end)(struct file___47 *, struct address_space___46 *, loff_t, unsigned int, unsigned int, struct page___47 *, void *);
	sector_t (*bmap)(struct address_space___46 *, sector_t);
	void (*invalidatepage)(struct page___47 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___47 *, gfp_t);
	void (*freepage)(struct page___47 *);
	ssize_t (*direct_IO)(struct kiocb___47 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___46 *, struct page___47 *, struct page___47 *, enum migrate_mode);
	bool (*isolate_page)(struct page___47 *, isolate_mode_t);
	void (*putback_page)(struct page___47 *);
	int (*launder_page)(struct page___47 *);
	int (*is_partially_uptodate)(struct page___47 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___47 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___46 *, struct page___47 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___47 *, sector_t *);
	void (*swap_deactivate)(struct file___47 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___47 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___48 *bd_inode;
	struct super_block___47 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___47 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___46 {
	struct dentry___47 * (*lookup)(struct inode___48 *, struct dentry___47 *, unsigned int);
	const char * (*get_link)(struct dentry___47 *, struct inode___48 *, struct delayed_call *);
	int (*permission)(struct inode___48 *, int);
	struct posix_acl * (*get_acl)(struct inode___48 *, int);
	int (*readlink)(struct dentry___47 *, char *, int);
	int (*create)(struct inode___48 *, struct dentry___47 *, umode_t, bool);
	int (*link)(struct dentry___47 *, struct inode___48 *, struct dentry___47 *);
	int (*unlink)(struct inode___48 *, struct dentry___47 *);
	int (*symlink)(struct inode___48 *, struct dentry___47 *, const char *);
	int (*mkdir)(struct inode___48 *, struct dentry___47 *, umode_t);
	int (*rmdir)(struct inode___48 *, struct dentry___47 *);
	int (*mknod)(struct inode___48 *, struct dentry___47 *, umode_t, dev_t);
	int (*rename)(struct inode___48 *, struct dentry___47 *, struct inode___48 *, struct dentry___47 *, unsigned int);
	int (*setattr)(struct dentry___47 *, struct iattr___47 *);
	int (*getattr)(const struct path___46 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___47 *, char *, size_t);
	int (*fiemap)(struct inode___48 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___48 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___48 *, struct dentry___47 *, struct file___47 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___48 *, struct dentry___47 *, umode_t);
	int (*set_acl)(struct inode___48 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___46 {
	void (*fl_copy_lock)(struct file_lock___47 *, struct file_lock___47 *);
	void (*fl_release_private)(struct file_lock___47 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___46;

struct lock_manager_operations___46;

struct file_lock___47 {
	struct file_lock___47 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___47 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___46 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___46 *fl_ops;
	const struct lock_manager_operations___46 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___46 {
	int (*lm_compare_owner)(struct file_lock___47 *, struct file_lock___47 *);
	long unsigned int (*lm_owner_key)(struct file_lock___47 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___47 *);
	int (*lm_grant)(struct file_lock___47 *, int);
	bool (*lm_break)(struct file_lock___47 *);
	int (*lm_change)(struct file_lock___47 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___47 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___46 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___46 *fa_next;
	struct file___47 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___46 {
	const char *name;
	int fs_flags;
	struct dentry___47 * (*mount)(struct file_system_type___46 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___47 *);
	struct module___11 *owner;
	struct file_system_type___46 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___46 {
	struct inode___48 * (*alloc_inode)(struct super_block___47 *);
	void (*destroy_inode)(struct inode___48 *);
	void (*dirty_inode)(struct inode___48 *, int);
	int (*write_inode)(struct inode___48 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___48 *);
	void (*evict_inode)(struct inode___48 *);
	void (*put_super)(struct super_block___47 *);
	int (*sync_fs)(struct super_block___47 *, int);
	int (*freeze_super)(struct super_block___47 *);
	int (*freeze_fs)(struct super_block___47 *);
	int (*thaw_super)(struct super_block___47 *);
	int (*unfreeze_fs)(struct super_block___47 *);
	int (*statfs)(struct dentry___47 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___47 *, int *, char *);
	void (*umount_begin)(struct super_block___47 *);
	int (*show_options)(struct seq_file___45 *, struct dentry___47 *);
	int (*show_devname)(struct seq_file___45 *, struct dentry___47 *);
	int (*show_path)(struct seq_file___45 *, struct dentry___47 *);
	int (*show_stats)(struct seq_file___45 *, struct dentry___47 *);
	ssize_t (*quota_read)(struct super_block___47 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___47 *, int, const char *, size_t, loff_t);
	struct dquot___46 ** (*get_dquots)(struct inode___48 *);
	int (*bdev_try_to_free_page)(struct super_block___47 *, struct page___47 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___47 *, struct shrink_control___17 *);
	long int (*free_cached_objects)(struct super_block___47 *, struct shrink_control___17 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___42;

struct seq_file___45 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___42 *op;
	int poll_event;
	const struct file___47 *file;
	void *private;
};

typedef int (*key_restrict_link_func_t___46)(struct key___47 *, const struct key_type *, const union key_payload *, struct key___47 *);

struct key_restriction___47;

struct key___47 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___47 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___47 *restrict_link;
};

struct key_restriction___47 {
	key_restrict_link_func_t___46 check;
	struct key___47 *key;
	struct key_type *keytype;
};

struct seq_operations___42 {
	void * (*start)(struct seq_file___45 *, loff_t *);
	void (*stop)(struct seq_file___45 *, void *);
	void * (*next)(struct seq_file___45 *, void *, loff_t *);
	int (*show)(struct seq_file___45 *, void *);
};

struct kernfs_root___44;

struct kernfs_elem_dir___44 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___44 *root;
};

struct kernfs_node___44;

struct kernfs_syscall_ops___44;

struct kernfs_root___44 {
	struct kernfs_node___44 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___44 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___44 {
	struct kernfs_node___44 *target_kn;
};

struct kernfs_ops___44;

struct kernfs_elem_attr___44 {
	const struct kernfs_ops___44 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___44 *notify_next;
};

struct kernfs_node___44 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___44 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___44 dir;
		struct kernfs_elem_symlink___44 symlink;
		struct kernfs_elem_attr___44 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___44;

struct kernfs_ops___44 {
	int (*open)(struct kernfs_open_file___44 *);
	void (*release)(struct kernfs_open_file___44 *);
	int (*seq_show)(struct seq_file___45 *, void *);
	void * (*seq_start)(struct seq_file___45 *, loff_t *);
	void * (*seq_next)(struct seq_file___45 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___45 *, void *);
	ssize_t (*read)(struct kernfs_open_file___44 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___44 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___44 *, struct vm_area_struct___47 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___44 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___44 {
	int (*remount_fs)(struct kernfs_root___44 *, int *, char *);
	int (*show_options)(struct seq_file___45 *, struct kernfs_root___44 *);
	int (*mkdir)(struct kernfs_node___44 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___44 *);
	int (*rename)(struct kernfs_node___44 *, struct kernfs_node___44 *, const char *);
	int (*show_path)(struct seq_file___45 *, struct kernfs_node___44 *, struct kernfs_root___44 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___44 {
	struct kernfs_node___44 *kn;
	struct file___47 *file;
	struct seq_file___45 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___46 *vm_ops;
};

struct cgroup_namespace___36 {
	refcount_t count;
	struct ns_common___4 ns;
	struct user_namespace___38 *user_ns;
	struct ucounts___38 *ucounts;
	struct css_set___36 *root_cset;
};

struct ucounts___38 {
	struct hlist_node node;
	struct user_namespace___38 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

enum {
	__PERCPU_REF_ATOMIC = 1,
	__PERCPU_REF_DEAD = 2,
	__PERCPU_REF_ATOMIC_DEAD = 3,
	__PERCPU_REF_FLAG_BITS = 2,
};

struct bpf_map___36;

struct bpf_map_ops___36 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___36 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___36 *, struct file___47 *);
	void (*map_free)(struct bpf_map___36 *);
	int (*map_get_next_key)(struct bpf_map___36 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___36 *);
	void * (*map_lookup_elem)(struct bpf_map___36 *, void *);
	int (*map_update_elem)(struct bpf_map___36 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___36 *, void *);
	int (*map_push_elem)(struct bpf_map___36 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___36 *, void *);
	int (*map_peek_elem)(struct bpf_map___36 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___36 *, struct file___47 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___36 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___36 *, void *, struct seq_file___45 *);
	int (*map_check_btf)(const struct bpf_map___36 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___36 {
	const struct bpf_map_ops___36 *ops;
	struct bpf_map___36 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___46 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct psi_group___36 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___36 *poll_kworker;
	struct kthread_delayed_work___36 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

enum {
	CSS_NO_REF = 1,
	CSS_ONLINE = 2,
	CSS_RELEASED = 4,
	CSS_VISIBLE = 8,
	CSS_DYING = 16,
};

struct cgroup_file___36 {
	struct kernfs_node___44 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___36;

struct cgroup_subsys_state___36 {
	struct cgroup___36 *cgroup;
	struct cgroup_subsys___36 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___36 *parent;
};

struct cgroup_root___36;

struct cgroup_rstat_cpu___36;

struct cgroup___36 {
	struct cgroup_subsys_state___36 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___44 *kn;
	struct cgroup_file___36 procs_file;
	struct cgroup_file___36 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___36 *subsys[13];
	struct cgroup_root___36 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___36 *dom_cgrp;
	struct cgroup_rstat_cpu___36 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___4 bpf;
	atomic_t congestion_count;
	struct cgroup___36 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___36 psi;
	int ancestor_ids[0];
};

struct cftype___36;

struct cgroup_subsys___36 {
	struct cgroup_subsys_state___36 * (*css_alloc)(struct cgroup_subsys_state___36 *);
	int (*css_online)(struct cgroup_subsys_state___36 *);
	void (*css_offline)(struct cgroup_subsys_state___36 *);
	void (*css_released)(struct cgroup_subsys_state___36 *);
	void (*css_free)(struct cgroup_subsys_state___36 *);
	void (*css_reset)(struct cgroup_subsys_state___36 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___36 *, int);
	int (*css_extra_stat_show)(struct seq_file___45 *, struct cgroup_subsys_state___36 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___48 *);
	void (*cancel_fork)(struct task_struct___48 *);
	void (*fork)(struct task_struct___48 *);
	void (*exit)(struct task_struct___48 *);
	void (*free)(struct task_struct___48 *);
	void (*bind)(struct cgroup_subsys_state___36 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___36 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___36 *dfl_cftypes;
	struct cftype___36 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___36 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___36 *updated_children;
	struct cgroup___36 *updated_next;
};

struct cgroup_root___36 {
	struct kernfs_root___44 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___36 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___36 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___36 *ss;
	struct list_head node;
	struct kernfs_ops___44 *kf_ops;
	int (*open)(struct kernfs_open_file___44 *);
	void (*release)(struct kernfs_open_file___44 *);
	u64 (*read_u64)(struct cgroup_subsys_state___36 *, struct cftype___36 *);
	s64 (*read_s64)(struct cgroup_subsys_state___36 *, struct cftype___36 *);
	int (*seq_show)(struct seq_file___45 *, void *);
	void * (*seq_start)(struct seq_file___45 *, loff_t *);
	void * (*seq_next)(struct seq_file___45 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___45 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___36 *, struct cftype___36 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___36 *, struct cftype___36 *, s64);
	ssize_t (*write)(struct kernfs_open_file___44 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___44 *, struct poll_table_struct___6 *);
};

typedef void compound_page_dtor___46(struct page___47 *);

struct linux_binprm___9 {
	char buf[256];
	struct vm_area_struct___47 *vma;
	long unsigned int vma_pages;
	struct mm_struct___46 *mm;
	long unsigned int p;
	unsigned int called_set_creds: 1;
	unsigned int cap_elevated: 1;
	unsigned int secureexec: 1;
	unsigned int recursion_depth;
	struct file___47 *file;
	struct cred___46 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
};

struct coredump_params___8 {
	union {
		const kernel_siginfo_t *siginfo;
		struct {
			const siginfo_t *siginfo;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	struct pt_regs *regs;
	struct file___47 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
};

struct kthread_create_info {
	int (*threadfn)(void *);
	void *data;
	int node;
	struct task_struct___48 *result;
	struct completion *done;
	struct list_head list;
};

struct kthread {
	long unsigned int flags;
	unsigned int cpu;
	void *data;
	struct completion parked;
	struct completion exited;
	struct cgroup_subsys_state___36 *blkcg_css;
};

enum KTHREAD_BITS {
	KTHREAD_IS_PER_CPU = 0,
	KTHREAD_SHOULD_STOP = 1,
	KTHREAD_SHOULD_PARK = 2,
};

struct kthread_flush_work {
	struct kthread_work___36 work;
	struct completion done;
};

struct ipc_ids {
	int in_use;
	short unsigned int seq;
	struct rw_semaphore___44 rwsem;
	struct idr ipcs_idr;
	int max_idx;
	int last_idx;
	int next_id;
	struct rhashtable key_ht;
};

struct ipc_namespace {
	refcount_t count;
	struct ipc_ids ids[3];
	int sem_ctls[4];
	int used_sems;
	unsigned int msg_ctlmax;
	unsigned int msg_ctlmnb;
	unsigned int msg_ctlmni;
	atomic_t msg_bytes;
	atomic_t msg_hdrs;
	size_t shm_ctlmax;
	size_t shm_ctlall;
	long unsigned int shm_tot;
	int shm_ctlmni;
	int shm_rmid_forced;
	struct notifier_block ipcns_nb;
	struct vfsmount *mq_mnt;
	unsigned int mq_queues_count;
	unsigned int mq_queues_max;
	unsigned int mq_msg_max;
	unsigned int mq_msgsize_max;
	unsigned int mq_msg_default;
	unsigned int mq_msgsize_default;
	struct user_namespace___35 *user_ns;
	struct ucounts___35 *ucounts;
	struct ns_common___4 ns;
};

struct syscall_metadata___11 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___24 *enter_event;
	struct trace_event_call___24 *exit_event;
};

struct raw_notifier_head {
	struct notifier_block *head;
};

struct srcu_notifier_head {
	struct mutex mutex;
	struct srcu_struct srcu;
	struct notifier_block *head;
};

struct module___43;

struct file___48;

struct kiocb___48;

struct vm_area_struct___48;

struct inode___49;

struct file_lock___48;

struct page___48;

struct file_operations___48 {
	struct module___43 *owner;
	loff_t (*llseek)(struct file___48 *, loff_t, int);
	ssize_t (*read)(struct file___48 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___48 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___48 *, struct iov_iter___21 *);
	ssize_t (*write_iter)(struct kiocb___48 *, struct iov_iter___21 *);
	int (*iopoll)(struct kiocb___48 *, bool);
	int (*iterate)(struct file___48 *, struct dir_context *);
	int (*iterate_shared)(struct file___48 *, struct dir_context *);
	__poll_t (*poll)(struct file___48 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___48 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___48 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___48 *, struct vm_area_struct___48 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___49 *, struct file___48 *);
	int (*flush)(struct file___48 *, fl_owner_t);
	int (*release)(struct inode___49 *, struct file___48 *);
	int (*fsync)(struct file___48 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___48 *, int);
	int (*lock)(struct file___48 *, int, struct file_lock___48 *);
	ssize_t (*sendpage)(struct file___48 *, struct page___48 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___48 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___48 *, int, struct file_lock___48 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___48 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___48 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___48 *, long int, struct file_lock___48 **, void **);
	long int (*fallocate)(struct file___48 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___48 *);
	ssize_t (*copy_file_range)(struct file___48 *, loff_t, struct file___48 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___48 *, loff_t, struct file___48 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___48 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___47 {
	u64 seqnum;
	struct vm_area_struct___48 *vmas[4];
};

struct page_frag___47 {
	struct page___48 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___47;

struct pid___43;

struct cred___47;

struct nsproxy___46;

struct signal_struct___45;

struct vm_struct___37;

struct task_struct___49 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___49 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___47 *mm;
	struct mm_struct___47 *active_mm;
	struct vmacache___47 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___49 *real_parent;
	struct task_struct___49 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___49 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___43 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___43 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___43 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___47 *ptracer_cred;
	const struct cred___47 *real_cred;
	const struct cred___47 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___46 *nsproxy;
	struct signal_struct___45 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___49 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___10 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___47 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___49 *oom_reaper_list;
	struct vm_struct___37 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___29 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___48 *pgtable_t___47;

struct address_space___47;

struct dev_pagemap___47;

struct page___48 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___47 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___48 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___47 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___47 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___47 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___47;

struct lruvec___47 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___47 *pgdat;
};

struct zone___47 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___47 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___47 {
	struct zone___47 *zone;
	int zone_idx;
};

struct zonelist___47 {
	struct zoneref___47 _zonerefs[25];
};

struct pglist_data___47 {
	struct zone___47 node_zones[3];
	struct zonelist___47 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___49 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___49 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___47 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___48 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___49 *owner;
};

struct secondary_data___48 {
	void *stack;
	struct task_struct___49 *task;
	long int status;
};

struct blocking_notifier_head___47 {
	struct rw_semaphore___48 rwsem;
	struct notifier_block *head;
};

struct kernfs_root___45;

struct kernfs_elem_dir___45 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___45 *root;
};

struct kernfs_node___45;

struct kernfs_syscall_ops___45;

struct kernfs_root___45 {
	struct kernfs_node___45 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___45 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___45 {
	struct kernfs_node___45 *target_kn;
};

struct kernfs_ops___45;

struct kernfs_elem_attr___45 {
	const struct kernfs_ops___45 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___45 *notify_next;
};

struct kernfs_node___45 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___45 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___45 dir;
		struct kernfs_elem_symlink___45 symlink;
		struct kernfs_elem_attr___45 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___45;

struct kernfs_ops___45 {
	int (*open)(struct kernfs_open_file___45 *);
	void (*release)(struct kernfs_open_file___45 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___45 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___45 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___45 *, struct vm_area_struct___48 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___45 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___45 {
	int (*remount_fs)(struct kernfs_root___45 *, int *, char *);
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___45 *);
	int (*mkdir)(struct kernfs_node___45 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___45 *);
	int (*rename)(struct kernfs_node___45 *, struct kernfs_node___45 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___45 *, struct kernfs_root___45 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_operations_struct___47;

struct kernfs_open_file___45 {
	struct kernfs_node___45 *kn;
	struct file___48 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___47 *vm_ops;
};

struct dentry___48;

struct path___47 {
	struct vfsmount *mnt;
	struct dentry___48 *dentry;
};

struct fown_struct___43 {
	rwlock_t lock;
	struct pid___43 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___48 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___47 f_path;
	struct inode___49 *f_inode;
	const struct file_operations___48 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___43 f_owner;
	const struct cred___47 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___47 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___47;

struct vm_operations_struct___47 {
	void (*open)(struct vm_area_struct___48 *);
	void (*close)(struct vm_area_struct___48 *);
	int (*split)(struct vm_area_struct___48 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___48 *);
	vm_fault_t (*fault)(struct vm_fault___47 *);
	vm_fault_t (*huge_fault)(struct vm_fault___47 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___47 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___48 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___47 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___47 *);
	int (*access)(struct vm_area_struct___48 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___48 *);
	int (*set_policy)(struct vm_area_struct___48 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___48 *, long unsigned int);
	struct page___48 * (*find_special_page)(struct vm_area_struct___48 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_area_struct___48 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___48 *vm_next;
	struct vm_area_struct___48 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___47 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___47 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___48 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___45;

struct bin_attribute___42;

struct attribute_group___42 {
	const char *name;
	umode_t (*is_visible)(struct kobject___45 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___45 *, struct bin_attribute___42 *, int);
	struct attribute **attrs;
	struct bin_attribute___42 **bin_attrs;
};

struct kset___44;

struct kobj_type___44;

struct kobject___45 {
	const char *name;
	struct list_head entry;
	struct kobject___45 *parent;
	struct kset___44 *kset;
	struct kobj_type___44 *ktype;
	struct kernfs_node___45 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___42 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___48 *, struct kobject___45 *, struct bin_attribute___42 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___48 *, struct kobject___45 *, struct bin_attribute___42 *, char *, loff_t, size_t);
	int (*mmap)(struct file___48 *, struct kobject___45 *, struct bin_attribute___42 *, struct vm_area_struct___48 *);
};

struct sysfs_ops___44 {
	ssize_t (*show)(struct kobject___45 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___45 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___44;

struct kset___44 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___45 kobj;
	const struct kset_uevent_ops___44 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___44 {
	void (*release)(struct kobject___45 *);
	const struct sysfs_ops___44 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___2 * (*child_ns_type)(struct kobject___45 *);
	const void * (*namespace)(struct kobject___45 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___44 {
	int (* const filter)(struct kset___44 *, struct kobject___45 *);
	const char * (* const name)(struct kset___44 *, struct kobject___45 *);
	int (* const uevent)(struct kset___44 *, struct kobject___45 *, struct kobj_uevent_env *);
};

struct kobj_attribute___45 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___45 *, struct kobj_attribute___45 *, char *);
	ssize_t (*store)(struct kobject___45 *, struct kobj_attribute___45 *, const char *, size_t);
};

struct pid_namespace___43;

struct upid___43 {
	int nr;
	struct pid_namespace___43 *ns;
};

struct pid_namespace___43 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___49 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___43 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___48 *proc_self;
	struct dentry___48 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___3 *user_ns;
	struct ucounts___2 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___4 ns;
};

struct pid___43 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___43 numbers[1];
};

struct key___48;

struct user_struct___47 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___48 *uid_keyring;
	struct key___48 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___47;

struct mm_struct___47 {
	struct {
		struct vm_area_struct___48 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___48 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___48 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___47 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___49 *owner;
		struct user_namespace___3 *user_ns;
		struct file___48 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___47 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___47 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___48 *session_keyring;
	struct key___48 *process_keyring;
	struct key___48 *thread_keyring;
	struct key___48 *request_key_auth;
	void *security;
	struct user_struct___47 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct nsproxy___46 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___43 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct signal_struct___45 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___49 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___49 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___43 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___43 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___47 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___43 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_struct___37 {
	struct vm_struct___37 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___48 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___45 {
	struct task_struct___49 task;
	long unsigned int stack[8192];
};

typedef int (*key_restrict_link_func_t___47)(struct key___48 *, const struct key_type *, const union key_payload *, struct key___48 *);

struct key_restriction___48;

struct key___48 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___48 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___48 *restrict_link;
};

struct key_restriction___48 {
	key_restrict_link_func_t___47 check;
	struct key___48 *key;
	struct key_type *keytype;
};

struct address_space_operations___47;

struct address_space___47 {
	struct inode___49 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___48 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___47 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___47)(struct vm_area_struct___48 *, long unsigned int, const struct page___48 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___47)(struct page___48 *, void *);

struct dev_pagemap___47 {
	dev_page_fault_t___47 page_fault;
	dev_page_free_t___47 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___6 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___47 {
	struct task_struct___49 *task;
	struct core_thread___47 *next;
};

struct core_state___47 {
	atomic_t nr_threads;
	struct core_thread___47 dumper;
	struct completion startup;
};

struct vm_fault___47 {
	struct vm_area_struct___48 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___48 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___48 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___47 prealloc_pte;
};

struct dentry_operations___47;

struct super_block___48;

struct dentry___48 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___48 *d_parent;
	struct qstr d_name;
	struct inode___49 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___47 *d_op;
	struct super_block___48 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___47;

struct block_device___48;

struct inode___49 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___47 *i_op;
	struct super_block___48 *i_sb;
	struct address_space___47 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___48 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___48 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___47 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___48 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___47 {
	int (*d_revalidate)(struct dentry___48 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___48 *, unsigned int);
	int (*d_hash)(const struct dentry___48 *, struct qstr *);
	int (*d_compare)(const struct dentry___48 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___48 *);
	int (*d_init)(struct dentry___48 *);
	void (*d_release)(struct dentry___48 *);
	void (*d_prune)(struct dentry___48 *);
	void (*d_iput)(struct dentry___48 *, struct inode___49 *);
	char * (*d_dname)(struct dentry___48 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___47 *);
	int (*d_manage)(const struct path___47 *, bool);
	struct dentry___48 * (*d_real)(struct dentry___48 *, const struct inode___49 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___47;

struct mem_dqinfo___47 {
	struct quota_format_type___47 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___47;

struct quota_info___47 {
	unsigned int flags;
	struct rw_semaphore___48 dqio_sem;
	struct inode___49 *files[3];
	struct mem_dqinfo___47 info[3];
	const struct quota_format_ops___47 *ops[3];
};

struct rcuwait___47 {
	struct task_struct___49 *task;
};

struct percpu_rw_semaphore___47 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___48 rw_sem;
	struct rcuwait___47 writer;
	int readers_block;
};

struct sb_writers___47 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___47 rw_sem[3];
};

struct file_system_type___47;

struct super_operations___47;

struct dquot_operations___47;

struct quotactl_ops___47;

struct super_block___48 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___47 *s_type;
	const struct super_operations___47 *s_op;
	const struct dquot_operations___47 *dq_op;
	const struct quotactl_ops___47 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___48 *s_root;
	struct rw_semaphore___48 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___48 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___47 s_dquot;
	struct sb_writers___47 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___47 *s_d_op;
	int cleancache_poolid;
	struct shrinker___17 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___48 {
	struct file___48 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___48 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___48 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___48 *ia_file;
};

struct dquot___47 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___48 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___47 {
	int qf_fmt_id;
	const struct quota_format_ops___47 *qf_ops;
	struct module___43 *qf_owner;
	struct quota_format_type___47 *qf_next;
};

struct quota_format_ops___47 {
	int (*check_quota_file)(struct super_block___48 *, int);
	int (*read_file_info)(struct super_block___48 *, int);
	int (*write_file_info)(struct super_block___48 *, int);
	int (*free_file_info)(struct super_block___48 *, int);
	int (*read_dqblk)(struct dquot___47 *);
	int (*commit_dqblk)(struct dquot___47 *);
	int (*release_dqblk)(struct dquot___47 *);
	int (*get_next_id)(struct super_block___48 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___47 {
	int (*write_dquot)(struct dquot___47 *);
	struct dquot___47 * (*alloc_dquot)(struct super_block___48 *, int);
	void (*destroy_dquot)(struct dquot___47 *);
	int (*acquire_dquot)(struct dquot___47 *);
	int (*release_dquot)(struct dquot___47 *);
	int (*mark_dirty)(struct dquot___47 *);
	int (*write_info)(struct super_block___48 *, int);
	qsize_t * (*get_reserved_space)(struct inode___49 *);
	int (*get_projid)(struct inode___49 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___49 *, qsize_t *);
	int (*get_next_id)(struct super_block___48 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___47 {
	int (*quota_on)(struct super_block___48 *, int, int, const struct path___47 *);
	int (*quota_off)(struct super_block___48 *, int);
	int (*quota_enable)(struct super_block___48 *, unsigned int);
	int (*quota_disable)(struct super_block___48 *, unsigned int);
	int (*quota_sync)(struct super_block___48 *, int);
	int (*set_info)(struct super_block___48 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___48 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___48 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___48 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___48 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___48 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___40 {
	struct kobject___45 kobj;
	struct module___43 *mod;
	struct kobject___45 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___40 {
	struct module___43 *mod;
	struct latch_tree_node node;
};

struct module_layout___40 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___40 mtn;
};

struct module_attribute___40;

struct kernel_param___40;

struct module___43 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___40 mkobj;
	struct module_attribute___40 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___45 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___40 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___40 core_layout;
	struct module_layout___40 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___47 {
	int (*writepage)(struct page___48 *, struct writeback_control___3 *);
	int (*readpage)(struct file___48 *, struct page___48 *);
	int (*writepages)(struct address_space___47 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___48 *);
	int (*readpages)(struct file___48 *, struct address_space___47 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___48 *, struct address_space___47 *, loff_t, unsigned int, unsigned int, struct page___48 **, void **);
	int (*write_end)(struct file___48 *, struct address_space___47 *, loff_t, unsigned int, unsigned int, struct page___48 *, void *);
	sector_t (*bmap)(struct address_space___47 *, sector_t);
	void (*invalidatepage)(struct page___48 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___48 *, gfp_t);
	void (*freepage)(struct page___48 *);
	ssize_t (*direct_IO)(struct kiocb___48 *, struct iov_iter___21 *);
	int (*migratepage)(struct address_space___47 *, struct page___48 *, struct page___48 *, enum migrate_mode);
	bool (*isolate_page)(struct page___48 *, isolate_mode_t);
	void (*putback_page)(struct page___48 *);
	int (*launder_page)(struct page___48 *);
	int (*is_partially_uptodate)(struct page___48 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___48 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___47 *, struct page___48 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___48 *, sector_t *);
	void (*swap_deactivate)(struct file___48 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___48 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___49 *bd_inode;
	struct super_block___48 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___48 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___47 {
	struct dentry___48 * (*lookup)(struct inode___49 *, struct dentry___48 *, unsigned int);
	const char * (*get_link)(struct dentry___48 *, struct inode___49 *, struct delayed_call *);
	int (*permission)(struct inode___49 *, int);
	struct posix_acl * (*get_acl)(struct inode___49 *, int);
	int (*readlink)(struct dentry___48 *, char *, int);
	int (*create)(struct inode___49 *, struct dentry___48 *, umode_t, bool);
	int (*link)(struct dentry___48 *, struct inode___49 *, struct dentry___48 *);
	int (*unlink)(struct inode___49 *, struct dentry___48 *);
	int (*symlink)(struct inode___49 *, struct dentry___48 *, const char *);
	int (*mkdir)(struct inode___49 *, struct dentry___48 *, umode_t);
	int (*rmdir)(struct inode___49 *, struct dentry___48 *);
	int (*mknod)(struct inode___49 *, struct dentry___48 *, umode_t, dev_t);
	int (*rename)(struct inode___49 *, struct dentry___48 *, struct inode___49 *, struct dentry___48 *, unsigned int);
	int (*setattr)(struct dentry___48 *, struct iattr___48 *);
	int (*getattr)(const struct path___47 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___48 *, char *, size_t);
	int (*fiemap)(struct inode___49 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___49 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___49 *, struct dentry___48 *, struct file___48 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___49 *, struct dentry___48 *, umode_t);
	int (*set_acl)(struct inode___49 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___47 {
	void (*fl_copy_lock)(struct file_lock___48 *, struct file_lock___48 *);
	void (*fl_release_private)(struct file_lock___48 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___47;

struct lock_manager_operations___47;

struct file_lock___48 {
	struct file_lock___48 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___48 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___47 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___47 *fl_ops;
	const struct lock_manager_operations___47 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___47 {
	int (*lm_compare_owner)(struct file_lock___48 *, struct file_lock___48 *);
	long unsigned int (*lm_owner_key)(struct file_lock___48 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___48 *);
	int (*lm_grant)(struct file_lock___48 *, int);
	bool (*lm_break)(struct file_lock___48 *);
	int (*lm_change)(struct file_lock___48 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___48 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___47 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___47 *fa_next;
	struct file___48 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___47 {
	const char *name;
	int fs_flags;
	struct dentry___48 * (*mount)(struct file_system_type___47 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___48 *);
	struct module___43 *owner;
	struct file_system_type___47 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___47 {
	struct inode___49 * (*alloc_inode)(struct super_block___48 *);
	void (*destroy_inode)(struct inode___49 *);
	void (*dirty_inode)(struct inode___49 *, int);
	int (*write_inode)(struct inode___49 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___49 *);
	void (*evict_inode)(struct inode___49 *);
	void (*put_super)(struct super_block___48 *);
	int (*sync_fs)(struct super_block___48 *, int);
	int (*freeze_super)(struct super_block___48 *);
	int (*freeze_fs)(struct super_block___48 *);
	int (*thaw_super)(struct super_block___48 *);
	int (*unfreeze_fs)(struct super_block___48 *);
	int (*statfs)(struct dentry___48 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___48 *, int *, char *);
	void (*umount_begin)(struct super_block___48 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___48 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___48 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___48 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___48 *);
	ssize_t (*quota_read)(struct super_block___48 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___48 *, int, const char *, size_t, loff_t);
	struct dquot___47 ** (*get_dquots)(struct inode___49 *);
	int (*bdev_try_to_free_page)(struct super_block___48 *, struct page___48 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___48 *, struct shrink_control___17 *);
	long int (*free_cached_objects)(struct super_block___48 *, struct shrink_control___17 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___47(struct page___48 *);

struct kernel_param_ops___40 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___40 *);
	int (*get)(char *, const struct kernel_param___40 *);
	void (*free)(void *);
};

struct kparam_array___40;

struct kernel_param___40 {
	const char *name;
	struct module___43 *mod;
	const struct kernel_param_ops___40 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___40 *arr;
	};
};

struct kparam_array___40 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___40 *ops;
	void *elem;
};

struct module_attribute___40 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___40 *, struct module_kobject___40 *, char *);
	ssize_t (*store)(struct module_attribute___40 *, struct module_kobject___40 *, const char *, size_t);
	void (*setup)(struct module___43 *, const char *);
	int (*test)(struct module___43 *);
	void (*free)(struct module___43 *);
};

struct kimage___10;

typedef void *kexec_load_t___10(struct kimage___10 *, char *, long unsigned int, char *, long unsigned int, char *, long unsigned int);

struct kexec_file_ops___11 {
	kexec_probe_t *probe;
	kexec_load_t___10 *load;
	kexec_cleanup_t *cleanup;
};

struct kimage___10 {
	kimage_entry_t head;
	kimage_entry_t *entry;
	kimage_entry_t *last_entry;
	long unsigned int start;
	struct page___48 *control_code_page;
	struct page___48 *swap_page;
	void *vmcoreinfo_data_copy;
	long unsigned int nr_segments;
	struct kexec_segment segment[16];
	struct list_head control_pages;
	struct list_head dest_pages;
	struct list_head unusable_pages;
	long unsigned int control_page;
	unsigned int type: 1;
	unsigned int preserve_context: 1;
	unsigned int file_mode: 1;
	struct kimage_arch arch;
	void *kernel_buf;
	long unsigned int kernel_buf_len;
	void *initrd_buf;
	long unsigned int initrd_buf_len;
	char *cmdline_buf;
	long unsigned int cmdline_buf_len;
	const struct kexec_file_ops___11 *fops;
	void *image_loader_data;
	struct purgatory_info purgatory_info;
};

struct linux_binprm___10;

struct coredump_params___9;

struct linux_binfmt___2 {
	struct list_head lh;
	struct module___42 *module;
	int (*load_binary)(struct linux_binprm___10 *);
	int (*load_shlib)(struct file___46 *);
	int (*core_dump)(struct coredump_params___9 *);
	long unsigned int min_coredump;
};

struct linux_binprm___10 {
	char buf[256];
	struct vm_area_struct___46 *vma;
	long unsigned int vma_pages;
	struct mm_struct___45 *mm;
	long unsigned int p;
	unsigned int called_set_creds: 1;
	unsigned int cap_elevated: 1;
	unsigned int secureexec: 1;
	unsigned int recursion_depth;
	struct file___46 *file;
	struct cred___45 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
};

struct coredump_params___9 {
	union {
		const kernel_siginfo_t *siginfo;
		struct {
			const siginfo_t *siginfo;
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	struct pt_regs *regs;
	struct file___46 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
};

enum what {
	PROC_EVENT_NONE = 0,
	PROC_EVENT_FORK = 1,
	PROC_EVENT_EXEC = 2,
	PROC_EVENT_UID = 4,
	PROC_EVENT_GID = 64,
	PROC_EVENT_SID = 128,
	PROC_EVENT_PTRACE = 256,
	PROC_EVENT_COMM = 512,
	PROC_EVENT_COREDUMP = 1073741824,
	PROC_EVENT_EXIT = 2147483648,
};

struct module___44;

struct file___49;

struct kiocb___49;

struct iov_iter___22;

struct poll_table_struct___31;

struct vm_area_struct___49;

struct inode___50;

struct file_lock___49;

struct page___49;

struct seq_file___46;

struct file_operations___49 {
	struct module___44 *owner;
	loff_t (*llseek)(struct file___49 *, loff_t, int);
	ssize_t (*read)(struct file___49 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___49 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___49 *, struct iov_iter___22 *);
	ssize_t (*write_iter)(struct kiocb___49 *, struct iov_iter___22 *);
	int (*iopoll)(struct kiocb___49 *, bool);
	int (*iterate)(struct file___49 *, struct dir_context *);
	int (*iterate_shared)(struct file___49 *, struct dir_context *);
	__poll_t (*poll)(struct file___49 *, struct poll_table_struct___31 *);
	long int (*unlocked_ioctl)(struct file___49 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___49 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___49 *, struct vm_area_struct___49 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___50 *, struct file___49 *);
	int (*flush)(struct file___49 *, fl_owner_t);
	int (*release)(struct inode___50 *, struct file___49 *);
	int (*fsync)(struct file___49 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___49 *, int);
	int (*lock)(struct file___49 *, int, struct file_lock___49 *);
	ssize_t (*sendpage)(struct file___49 *, struct page___49 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___49 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___49 *, int, struct file_lock___49 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___49 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___49 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___49 *, long int, struct file_lock___49 **, void **);
	long int (*fallocate)(struct file___49 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___46 *, struct file___49 *);
	ssize_t (*copy_file_range)(struct file___49 *, loff_t, struct file___49 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___49 *, loff_t, struct file___49 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___49 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___48 {
	u64 seqnum;
	struct vm_area_struct___49 *vmas[4];
};

struct page_frag___48 {
	struct page___49 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___30;

struct debug_info___30 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___30 *hbp_break[16];
	struct perf_event___30 *hbp_watch[16];
};

struct thread_struct___30 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___30 debug;
	long: 64;
};

struct mm_struct___48;

struct mem_cgroup___18;

struct pid___44;

struct cred___48;

struct nsproxy___47;

struct signal_struct___46;

struct bio_list___19;

struct backing_dev_info___19;

struct css_set___37;

struct perf_event_context___30;

struct vm_struct___38;

struct task_struct___50 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___50 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___48 *mm;
	struct mm_struct___48 *active_mm;
	struct vmacache___48 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___50 *real_parent;
	struct task_struct___50 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___50 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___18 *active_memcg;
	long int rh_reserved2;
	struct pid___44 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___44 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___44 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___48 *ptracer_cred;
	const struct cred___48 *real_cred;
	const struct cred___48 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___47 *nsproxy;
	struct signal_struct___46 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___50 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___19 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___19 *backing_dev_info;
	struct io_context___10 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___37 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___30 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___48 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___18 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___50 *oom_reaper_list;
	struct vm_struct___38 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___30 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___30 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___50 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___30)(struct perf_event___30 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___30;

struct fasync_struct___48;

struct pid_namespace___44;

struct trace_event_call___25;

struct perf_cgroup___30;

struct perf_event___30 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___30 *group_leader;
	struct pmu___30 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___30 hw;
	struct perf_event_context___30 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___30 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___50 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___48 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___30 *);
	struct callback_head callback_head;
	struct pid_namespace___44 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___30 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___30 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___25 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___30 *cgrp;
	struct list_head sb_list;
};

struct upid___44 {
	int nr;
	struct pid_namespace___44 *ns;
};

struct dentry___49;

struct user_namespace___39;

struct ucounts___39;

struct pid_namespace___44 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___50 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___44 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___49 *proc_self;
	struct dentry___49 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___39 *user_ns;
	struct ucounts___39 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___4 ns;
};

struct pid___44 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___44 numbers[1];
};

struct rw_semaphore___49 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___50 *owner;
};

struct key___49;

struct user_namespace___39 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___39 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___4 ns;
	long unsigned int flags;
	struct key___49 *persistent_keyring_register;
	struct rw_semaphore___49 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___39 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct secondary_data___49 {
	void *stack;
	struct task_struct___50 *task;
	long int status;
};

typedef struct page___49 *pgtable_t___48;

struct address_space___48;

struct dev_pagemap___48;

struct page___49 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___48 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___49 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___48 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___48 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___48 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___18 *mem_cgroup;
};

struct user_struct___48 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___49 *uid_keyring;
	struct key___49 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___48;

struct vm_area_struct___49 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___49 *vm_next;
	struct vm_area_struct___49 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___48 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___48 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___49 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___48;

struct mm_struct___48 {
	struct {
		struct vm_area_struct___49 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___49 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___49 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___48 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___50 *owner;
		struct user_namespace___39 *user_ns;
		struct file___49 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___48 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup___37;

struct cgroup_subsys___37;

struct cgroup_subsys_state___37 {
	struct cgroup___37 *cgroup;
	struct cgroup_subsys___37 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___37 *parent;
};

struct kernfs_node___46;

struct cgroup_file___37 {
	struct kernfs_node___46 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___18;

struct mem_cgroup___18 {
	struct cgroup_subsys_state___37 css;
	struct mem_cgroup_id___5 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___37 events_file;
	struct cgroup_file___37 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___50 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___18 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cred___48 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___49 *session_keyring;
	struct key___49 *process_keyring;
	struct key___49 *thread_keyring;
	struct key___49 *request_key_auth;
	void *security;
	struct user_struct___48 *user;
	struct user_namespace___39 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___37;

struct nsproxy___47 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___44 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___37 *cgroup_ns;
};

struct signal_struct___46 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___50 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___50 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___44 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___44 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___48 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___44 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___19;

struct bio_list___19 {
	struct bio___19 *head;
	struct bio___19 *tail;
};

struct bdi_writeback_congested___19;

struct bdi_writeback___19 {
	struct backing_dev_info___19 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___19 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___37 *memcg_css;
	struct cgroup_subsys_state___37 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___42;

struct backing_dev_info___19 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___19 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___42 *dev;
	struct device___42 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___49 *debug_dir;
	struct dentry___49 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___37 {
	struct cgroup_subsys_state___37 *subsys[13];
	refcount_t refcount;
	struct css_set___37 *dom_cset;
	struct cgroup___37 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___37 *mg_src_cgrp;
	struct cgroup___37 *mg_dst_cgrp;
	struct css_set___37 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___30 {
	struct pmu___30 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___50 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___30 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___38 {
	struct vm_struct___38 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___49 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___46 {
	struct task_struct___50 task;
	long unsigned int stack[8192];
};

typedef int (*key_restrict_link_func_t___48)(struct key___49 *, const struct key_type *, const union key_payload *, struct key___49 *);

struct key_restriction___49;

struct key___49 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___49 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___49 *restrict_link;
};

struct key_restriction___49 {
	key_restrict_link_func_t___48 check;
	struct key___49 *key;
	struct key_type *keytype;
};

struct pglist_data___48;

struct lruvec___48 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___48 *pgdat;
};

struct zone___48 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___48 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___48 {
	struct zone___48 *zone;
	int zone_idx;
};

struct zonelist___48 {
	struct zoneref___48 _zonerefs[25];
};

struct pglist_data___48 {
	struct zone___48 node_zones[3];
	struct zonelist___48 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___50 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___50 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___48 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___48 {
	struct rw_semaphore___49 rwsem;
	struct notifier_block *head;
};

struct address_space_operations___48;

struct address_space___48 {
	struct inode___50 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___49 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___48 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___48)(struct vm_area_struct___49 *, long unsigned int, const struct page___49 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___48)(struct page___49 *, void *);

struct dev_pagemap___48 {
	dev_page_fault_t___48 page_fault;
	dev_page_free_t___48 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___42 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___48 {
	struct vfsmount *mnt;
	struct dentry___49 *dentry;
};

struct fown_struct___44 {
	rwlock_t lock;
	struct pid___44 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___49 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___48 f_path;
	struct inode___50 *f_inode;
	const struct file_operations___49 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___44 f_owner;
	const struct cred___48 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___48 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___48;

struct vm_operations_struct___48 {
	void (*open)(struct vm_area_struct___49 *);
	void (*close)(struct vm_area_struct___49 *);
	int (*split)(struct vm_area_struct___49 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___49 *);
	vm_fault_t (*fault)(struct vm_fault___48 *);
	vm_fault_t (*huge_fault)(struct vm_fault___48 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___48 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___49 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___48 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___48 *);
	int (*access)(struct vm_area_struct___49 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___49 *);
	int (*set_policy)(struct vm_area_struct___49 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___49 *, long unsigned int);
	struct page___49 * (*find_special_page)(struct vm_area_struct___49 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___48 {
	struct task_struct___50 *task;
	struct core_thread___48 *next;
};

struct core_state___48 {
	atomic_t nr_threads;
	struct core_thread___48 dumper;
	struct completion startup;
};

struct vm_fault___48 {
	struct vm_area_struct___49 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___49 *cow_page;
	struct mem_cgroup___18 *memcg;
	struct page___49 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___48 prealloc_pte;
};

struct shrink_control___18 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___18 *memcg;
};

struct shrinker___18 {
	long unsigned int (*count_objects)(struct shrinker___18 *, struct shrink_control___18 *);
	long unsigned int (*scan_objects)(struct shrinker___18 *, struct shrink_control___18 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct kset___45;

struct kobj_type___45;

struct kobject___46 {
	const char *name;
	struct list_head entry;
	struct kobject___46 *parent;
	struct kset___45 *kset;
	struct kobj_type___45 *ktype;
	struct kernfs_node___46 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___42 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___42 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___42;

struct bus_type___42;

struct device_driver___42;

struct dev_pm_domain___42;

struct fwnode_handle___34;

struct class___42;

struct attribute_group___43;

struct device___42 {
	struct device___42 *parent;
	struct device_private *p;
	struct kobject___46 kobj;
	const char *init_name;
	const struct device_type___42 *type;
	struct mutex mutex;
	struct bus_type___42 *bus;
	struct device_driver___42 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___42 power;
	struct dev_pm_domain___42 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___34 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___42 *class;
	const struct attribute_group___43 **groups;
	void (*release)(struct device___42 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___48;

struct super_block___49;

struct dentry___49 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___49 *d_parent;
	struct qstr d_name;
	struct inode___50 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___48 *d_op;
	struct super_block___49 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___48;

struct block_device___49;

struct inode___50 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___48 *i_op;
	struct super_block___49 *i_sb;
	struct address_space___48 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___49 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___19 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___49 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___48 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___49 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___48 {
	int (*d_revalidate)(struct dentry___49 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___49 *, unsigned int);
	int (*d_hash)(const struct dentry___49 *, struct qstr *);
	int (*d_compare)(const struct dentry___49 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___49 *);
	int (*d_init)(struct dentry___49 *);
	void (*d_release)(struct dentry___49 *);
	void (*d_prune)(struct dentry___49 *);
	void (*d_iput)(struct dentry___49 *, struct inode___50 *);
	char * (*d_dname)(struct dentry___49 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___48 *);
	int (*d_manage)(const struct path___48 *, bool);
	struct dentry___49 * (*d_real)(struct dentry___49 *, const struct inode___50 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___48;

struct mem_dqinfo___48 {
	struct quota_format_type___48 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___48;

struct quota_info___48 {
	unsigned int flags;
	struct rw_semaphore___49 dqio_sem;
	struct inode___50 *files[3];
	struct mem_dqinfo___48 info[3];
	const struct quota_format_ops___48 *ops[3];
};

struct rcuwait___48 {
	struct task_struct___50 *task;
};

struct percpu_rw_semaphore___48 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___49 rw_sem;
	struct rcuwait___48 writer;
	int readers_block;
};

struct sb_writers___48 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___48 rw_sem[3];
};

struct file_system_type___48;

struct super_operations___48;

struct dquot_operations___48;

struct quotactl_ops___48;

struct super_block___49 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___48 *s_type;
	const struct super_operations___48 *s_op;
	const struct dquot_operations___48 *dq_op;
	const struct quotactl_ops___48 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___49 *s_root;
	struct rw_semaphore___49 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___49 *s_bdev;
	struct backing_dev_info___19 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___48 s_dquot;
	struct sb_writers___48 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___48 *s_d_op;
	int cleancache_poolid;
	struct shrinker___18 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___39 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___49 {
	struct file___49 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___49 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___49 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___49 *ia_file;
};

struct dquot___48 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___49 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___48 {
	int qf_fmt_id;
	const struct quota_format_ops___48 *qf_ops;
	struct module___44 *qf_owner;
	struct quota_format_type___48 *qf_next;
};

struct quota_format_ops___48 {
	int (*check_quota_file)(struct super_block___49 *, int);
	int (*read_file_info)(struct super_block___49 *, int);
	int (*write_file_info)(struct super_block___49 *, int);
	int (*free_file_info)(struct super_block___49 *, int);
	int (*read_dqblk)(struct dquot___48 *);
	int (*commit_dqblk)(struct dquot___48 *);
	int (*release_dqblk)(struct dquot___48 *);
	int (*get_next_id)(struct super_block___49 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___48 {
	int (*write_dquot)(struct dquot___48 *);
	struct dquot___48 * (*alloc_dquot)(struct super_block___49 *, int);
	void (*destroy_dquot)(struct dquot___48 *);
	int (*acquire_dquot)(struct dquot___48 *);
	int (*release_dquot)(struct dquot___48 *);
	int (*mark_dirty)(struct dquot___48 *);
	int (*write_info)(struct super_block___49 *, int);
	qsize_t * (*get_reserved_space)(struct inode___50 *);
	int (*get_projid)(struct inode___50 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___50 *, qsize_t *);
	int (*get_next_id)(struct super_block___49 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___48 {
	int (*quota_on)(struct super_block___49 *, int, int, const struct path___48 *);
	int (*quota_off)(struct super_block___49 *, int);
	int (*quota_enable)(struct super_block___49 *, unsigned int);
	int (*quota_disable)(struct super_block___49 *, unsigned int);
	int (*quota_sync)(struct super_block___49 *, int);
	int (*set_info)(struct super_block___49 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___49 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___49 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___49 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___49 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___49 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___41 {
	struct kobject___46 kobj;
	struct module___44 *mod;
	struct kobject___46 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___41 {
	struct module___44 *mod;
	struct latch_tree_node node;
};

struct module_layout___41 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___41 mtn;
};

struct module_attribute___41;

struct kernel_param___41;

struct module___44 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___41 mkobj;
	struct module_attribute___41 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___46 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___41 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___41 core_layout;
	struct module_layout___41 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___25 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___18;

struct swap_info_struct___13;

struct address_space_operations___48 {
	int (*writepage)(struct page___49 *, struct writeback_control___18 *);
	int (*readpage)(struct file___49 *, struct page___49 *);
	int (*writepages)(struct address_space___48 *, struct writeback_control___18 *);
	int (*set_page_dirty)(struct page___49 *);
	int (*readpages)(struct file___49 *, struct address_space___48 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___49 *, struct address_space___48 *, loff_t, unsigned int, unsigned int, struct page___49 **, void **);
	int (*write_end)(struct file___49 *, struct address_space___48 *, loff_t, unsigned int, unsigned int, struct page___49 *, void *);
	sector_t (*bmap)(struct address_space___48 *, sector_t);
	void (*invalidatepage)(struct page___49 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___49 *, gfp_t);
	void (*freepage)(struct page___49 *);
	ssize_t (*direct_IO)(struct kiocb___49 *, struct iov_iter___22 *);
	int (*migratepage)(struct address_space___48 *, struct page___49 *, struct page___49 *, enum migrate_mode);
	bool (*isolate_page)(struct page___49 *, isolate_mode_t);
	void (*putback_page)(struct page___49 *);
	int (*launder_page)(struct page___49 *);
	int (*is_partially_uptodate)(struct page___49 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___49 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___48 *, struct page___49 *);
	int (*swap_activate)(struct swap_info_struct___13 *, struct file___49 *, sector_t *);
	void (*swap_deactivate)(struct file___49 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___18 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___19 *wb;
	struct inode___50 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___19;

struct iov_iter___22 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___19 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct swap_info_struct___13 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___49 *bdev;
	struct file___49 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___49 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___50 *bd_inode;
	struct super_block___49 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___49 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___19 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___48 {
	struct dentry___49 * (*lookup)(struct inode___50 *, struct dentry___49 *, unsigned int);
	const char * (*get_link)(struct dentry___49 *, struct inode___50 *, struct delayed_call *);
	int (*permission)(struct inode___50 *, int);
	struct posix_acl * (*get_acl)(struct inode___50 *, int);
	int (*readlink)(struct dentry___49 *, char *, int);
	int (*create)(struct inode___50 *, struct dentry___49 *, umode_t, bool);
	int (*link)(struct dentry___49 *, struct inode___50 *, struct dentry___49 *);
	int (*unlink)(struct inode___50 *, struct dentry___49 *);
	int (*symlink)(struct inode___50 *, struct dentry___49 *, const char *);
	int (*mkdir)(struct inode___50 *, struct dentry___49 *, umode_t);
	int (*rmdir)(struct inode___50 *, struct dentry___49 *);
	int (*mknod)(struct inode___50 *, struct dentry___49 *, umode_t, dev_t);
	int (*rename)(struct inode___50 *, struct dentry___49 *, struct inode___50 *, struct dentry___49 *, unsigned int);
	int (*setattr)(struct dentry___49 *, struct iattr___49 *);
	int (*getattr)(const struct path___48 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___49 *, char *, size_t);
	int (*fiemap)(struct inode___50 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___50 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___50 *, struct dentry___49 *, struct file___49 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___50 *, struct dentry___49 *, umode_t);
	int (*set_acl)(struct inode___50 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___48 {
	void (*fl_copy_lock)(struct file_lock___49 *, struct file_lock___49 *);
	void (*fl_release_private)(struct file_lock___49 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___48;

struct file_lock___49 {
	struct file_lock___49 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___49 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___48 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___48 *fl_ops;
	const struct lock_manager_operations___48 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___48 {
	int (*lm_compare_owner)(struct file_lock___49 *, struct file_lock___49 *);
	long unsigned int (*lm_owner_key)(struct file_lock___49 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___49 *);
	int (*lm_grant)(struct file_lock___49 *, int);
	bool (*lm_break)(struct file_lock___49 *);
	int (*lm_change)(struct file_lock___49 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___49 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___48 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___48 *fa_next;
	struct file___49 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___48 {
	const char *name;
	int fs_flags;
	struct dentry___49 * (*mount)(struct file_system_type___48 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___49 *);
	struct module___44 *owner;
	struct file_system_type___48 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___48 {
	struct inode___50 * (*alloc_inode)(struct super_block___49 *);
	void (*destroy_inode)(struct inode___50 *);
	void (*dirty_inode)(struct inode___50 *, int);
	int (*write_inode)(struct inode___50 *, struct writeback_control___18 *);
	int (*drop_inode)(struct inode___50 *);
	void (*evict_inode)(struct inode___50 *);
	void (*put_super)(struct super_block___49 *);
	int (*sync_fs)(struct super_block___49 *, int);
	int (*freeze_super)(struct super_block___49 *);
	int (*freeze_fs)(struct super_block___49 *);
	int (*thaw_super)(struct super_block___49 *);
	int (*unfreeze_fs)(struct super_block___49 *);
	int (*statfs)(struct dentry___49 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___49 *, int *, char *);
	void (*umount_begin)(struct super_block___49 *);
	int (*show_options)(struct seq_file___46 *, struct dentry___49 *);
	int (*show_devname)(struct seq_file___46 *, struct dentry___49 *);
	int (*show_path)(struct seq_file___46 *, struct dentry___49 *);
	int (*show_stats)(struct seq_file___46 *, struct dentry___49 *);
	ssize_t (*quota_read)(struct super_block___49 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___49 *, int, const char *, size_t, loff_t);
	struct dquot___48 ** (*get_dquots)(struct inode___50 *);
	int (*bdev_try_to_free_page)(struct super_block___49 *, struct page___49 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___49 *, struct shrink_control___18 *);
	long int (*free_cached_objects)(struct super_block___49 *, struct shrink_control___18 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___30)(struct file___49 *, wait_queue_head_t *, struct poll_table_struct___31 *);

struct poll_table_struct___31 {
	poll_queue_proc___30 _qproc;
	__poll_t _key;
};

struct seq_operations___43;

struct seq_file___46 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___43 *op;
	int poll_event;
	const struct file___49 *file;
	void *private;
};

typedef void bio_end_io_t___19(struct bio___19 *);

struct bio_vec___19 {
	struct page___49 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___19;

struct bio_set___19;

struct bio___19 {
	struct bio___19 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___19 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___19 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___19 *bi_io_vec;
	struct bio_set___19 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___19 bi_inline_vecs[0];
};

struct kobj_attribute___46 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___46 *, struct kobj_attribute___46 *, char *);
	ssize_t (*store)(struct kobject___46 *, struct kobj_attribute___46 *, const char *, size_t);
};

typedef void compound_page_dtor___48(struct page___49 *);

struct cgroup_namespace___37 {
	refcount_t count;
	struct ns_common___4 ns;
	struct user_namespace___39 *user_ns;
	struct ucounts___39 *ucounts;
	struct css_set___37 *root_cset;
};

struct ucounts___39 {
	struct hlist_node node;
	struct user_namespace___39 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct fwnode_operations___34;

struct fwnode_handle___34 {
	struct fwnode_handle___34 *secondary;
	const struct fwnode_operations___34 *ops;
};

struct fwnode_reference_args___34;

struct fwnode_endpoint___34;

struct fwnode_operations___34 {
	struct fwnode_handle___34 * (*get)(struct fwnode_handle___34 *);
	void (*put)(struct fwnode_handle___34 *);
	bool (*device_is_available)(const struct fwnode_handle___34 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___34 *, const struct device___42 *);
	bool (*property_present)(const struct fwnode_handle___34 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___34 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___34 *, const char *, const char **, size_t);
	struct fwnode_handle___34 * (*get_parent)(const struct fwnode_handle___34 *);
	struct fwnode_handle___34 * (*get_next_child_node)(const struct fwnode_handle___34 *, struct fwnode_handle___34 *);
	struct fwnode_handle___34 * (*get_named_child_node)(const struct fwnode_handle___34 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___34 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___34 *);
	struct fwnode_handle___34 * (*graph_get_next_endpoint)(const struct fwnode_handle___34 *, struct fwnode_handle___34 *);
	struct fwnode_handle___34 * (*graph_get_remote_endpoint)(const struct fwnode_handle___34 *);
	struct fwnode_handle___34 * (*graph_get_port_parent)(struct fwnode_handle___34 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___34 *, struct fwnode_endpoint___34 *);
};

struct fwnode_endpoint___34 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___34 *local_fwnode;
};

struct fwnode_reference_args___34 {
	struct fwnode_handle___34 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct kernfs_root___46;

struct kernfs_elem_dir___46 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___46 *root;
};

struct kernfs_syscall_ops___46;

struct kernfs_root___46 {
	struct kernfs_node___46 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___46 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___46 {
	struct kernfs_node___46 *target_kn;
};

struct kernfs_ops___46;

struct kernfs_elem_attr___46 {
	const struct kernfs_ops___46 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___46 *notify_next;
};

struct kernfs_node___46 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___46 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___46 dir;
		struct kernfs_elem_symlink___46 symlink;
		struct kernfs_elem_attr___46 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___46;

struct kernfs_ops___46 {
	int (*open)(struct kernfs_open_file___46 *);
	void (*release)(struct kernfs_open_file___46 *);
	int (*seq_show)(struct seq_file___46 *, void *);
	void * (*seq_start)(struct seq_file___46 *, loff_t *);
	void * (*seq_next)(struct seq_file___46 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___46 *, void *);
	ssize_t (*read)(struct kernfs_open_file___46 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___46 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___46 *, struct vm_area_struct___49 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___46 *, struct poll_table_struct___31 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___46 {
	int (*remount_fs)(struct kernfs_root___46 *, int *, char *);
	int (*show_options)(struct seq_file___46 *, struct kernfs_root___46 *);
	int (*mkdir)(struct kernfs_node___46 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___46 *);
	int (*rename)(struct kernfs_node___46 *, struct kernfs_node___46 *, const char *);
	int (*show_path)(struct seq_file___46 *, struct kernfs_node___46 *, struct kernfs_root___46 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___46 {
	struct kernfs_node___46 *kn;
	struct file___49 *file;
	struct seq_file___46 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___48 *vm_ops;
};

struct bin_attribute___43;

struct attribute_group___43 {
	const char *name;
	umode_t (*is_visible)(struct kobject___46 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___46 *, struct bin_attribute___43 *, int);
	struct attribute **attrs;
	struct bin_attribute___43 **bin_attrs;
};

struct bin_attribute___43 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___49 *, struct kobject___46 *, struct bin_attribute___43 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___49 *, struct kobject___46 *, struct bin_attribute___43 *, char *, loff_t, size_t);
	int (*mmap)(struct file___49 *, struct kobject___46 *, struct bin_attribute___43 *, struct vm_area_struct___49 *);
};

struct sysfs_ops___45 {
	ssize_t (*show)(struct kobject___46 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___46 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___45;

struct kset___45 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___46 kobj;
	const struct kset_uevent_ops___45 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___45 {
	void (*release)(struct kobject___46 *);
	const struct sysfs_ops___45 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___2 * (*child_ns_type)(struct kobject___46 *);
	const void * (*namespace)(struct kobject___46 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___45 {
	int (* const filter)(struct kset___45 *, struct kobject___46 *);
	const char * (* const name)(struct kset___45 *, struct kobject___46 *);
	int (* const uevent)(struct kset___45 *, struct kobject___46 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___41 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___41 *);
	int (*get)(char *, const struct kernel_param___41 *);
	void (*free)(void *);
};

struct kparam_array___41;

struct kernel_param___41 {
	const char *name;
	struct module___44 *mod;
	const struct kernel_param_ops___41 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___41 *arr;
	};
};

struct kparam_array___41 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___41 *ops;
	void *elem;
};

struct module_attribute___41 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___41 *, struct module_kobject___41 *, char *);
	ssize_t (*store)(struct module_attribute___41 *, struct module_kobject___41 *, const char *, size_t);
	void (*setup)(struct module___44 *, const char *);
	int (*test)(struct module___44 *);
	void (*free)(struct module___44 *);
};

struct trace_event_class___25;

struct trace_event_call___25 {
	struct list_head list;
	struct trace_event_class___25 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___4 *prog_array;
	int (*perf_perm)(struct trace_event_call___25 *, struct perf_event___30 *);
};

struct kimage___11;

typedef void *kexec_load_t___11(struct kimage___11 *, char *, long unsigned int, char *, long unsigned int, char *, long unsigned int);

struct kexec_file_ops___12 {
	kexec_probe_t *probe;
	kexec_load_t___11 *load;
	kexec_cleanup_t *cleanup;
};

struct kimage___11 {
	kimage_entry_t head;
	kimage_entry_t *entry;
	kimage_entry_t *last_entry;
	long unsigned int start;
	struct page___49 *control_code_page;
	struct page___49 *swap_page;
	void *vmcoreinfo_data_copy;
	long unsigned int nr_segments;
	struct kexec_segment segment[16];
	struct list_head control_pages;
	struct list_head dest_pages;
	struct list_head unusable_pages;
	long unsigned int control_page;
	unsigned int type: 1;
	unsigned int preserve_context: 1;
	unsigned int file_mode: 1;
	struct kimage_arch arch;
	void *kernel_buf;
	long unsigned int kernel_buf_len;
	void *initrd_buf;
	long unsigned int initrd_buf_len;
	char *cmdline_buf;
	long unsigned int cmdline_buf_len;
	const struct kexec_file_ops___12 *fops;
	void *image_loader_data;
	struct purgatory_info purgatory_info;
};

struct seq_operations___43 {
	void * (*start)(struct seq_file___46 *, loff_t *);
	void (*stop)(struct seq_file___46 *, void *);
	void * (*next)(struct seq_file___46 *, void *, loff_t *);
	int (*show)(struct seq_file___46 *, void *);
};

struct bpf_map___37;

struct bpf_map_ops___37 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___37 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___37 *, struct file___49 *);
	void (*map_free)(struct bpf_map___37 *);
	int (*map_get_next_key)(struct bpf_map___37 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___37 *);
	void * (*map_lookup_elem)(struct bpf_map___37 *, void *);
	int (*map_update_elem)(struct bpf_map___37 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___37 *, void *);
	int (*map_push_elem)(struct bpf_map___37 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___37 *, void *);
	int (*map_peek_elem)(struct bpf_map___37 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___37 *, struct file___49 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___37 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___37 *, void *, struct seq_file___46 *);
	int (*map_check_btf)(const struct bpf_map___37 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___37 {
	const struct bpf_map_ops___37 *ops;
	struct bpf_map___37 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___48 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___37;

typedef void (*kthread_work_func_t___37)(struct kthread_work___37 *);

struct kthread_worker___37;

struct kthread_work___37 {
	struct list_head node;
	kthread_work_func_t___37 func;
	struct kthread_worker___37 *worker;
	int canceling;
};

struct kthread_worker___37 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___50 *task;
	struct kthread_work___37 *current_work;
};

struct kthread_delayed_work___37 {
	struct kthread_work___37 work;
	struct timer_list timer;
};

struct psi_group___37 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___37 *poll_kworker;
	struct kthread_delayed_work___37 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___37;

struct cgroup_rstat_cpu___37;

struct cgroup___37 {
	struct cgroup_subsys_state___37 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___46 *kn;
	struct cgroup_file___37 procs_file;
	struct cgroup_file___37 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___37 *subsys[13];
	struct cgroup_root___37 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___37 *dom_cgrp;
	struct cgroup_rstat_cpu___37 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___4 bpf;
	atomic_t congestion_count;
	struct cgroup___37 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___37 psi;
	int ancestor_ids[0];
};

struct cftype___37;

struct cgroup_subsys___37 {
	struct cgroup_subsys_state___37 * (*css_alloc)(struct cgroup_subsys_state___37 *);
	int (*css_online)(struct cgroup_subsys_state___37 *);
	void (*css_offline)(struct cgroup_subsys_state___37 *);
	void (*css_released)(struct cgroup_subsys_state___37 *);
	void (*css_free)(struct cgroup_subsys_state___37 *);
	void (*css_reset)(struct cgroup_subsys_state___37 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___37 *, int);
	int (*css_extra_stat_show)(struct seq_file___46 *, struct cgroup_subsys_state___37 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___50 *);
	void (*cancel_fork)(struct task_struct___50 *);
	void (*fork)(struct task_struct___50 *);
	void (*exit)(struct task_struct___50 *);
	void (*free)(struct task_struct___50 *);
	void (*bind)(struct cgroup_subsys_state___37 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___37 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___37 *dfl_cftypes;
	struct cftype___37 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___37 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___37 *updated_children;
	struct cgroup___37 *updated_next;
};

struct cgroup_root___37 {
	struct kernfs_root___46 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___37 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___37 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___37 *ss;
	struct list_head node;
	struct kernfs_ops___46 *kf_ops;
	int (*open)(struct kernfs_open_file___46 *);
	void (*release)(struct kernfs_open_file___46 *);
	u64 (*read_u64)(struct cgroup_subsys_state___37 *, struct cftype___37 *);
	s64 (*read_s64)(struct cgroup_subsys_state___37 *, struct cftype___37 *);
	int (*seq_show)(struct seq_file___46 *, void *);
	void * (*seq_start)(struct seq_file___46 *, loff_t *);
	void * (*seq_next)(struct seq_file___46 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___46 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___37 *, struct cftype___37 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___37 *, struct cftype___37 *, s64);
	ssize_t (*write)(struct kernfs_open_file___46 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___46 *, struct poll_table_struct___31 *);
};

struct bdi_writeback_congested___19 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___19 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___19 {
	struct bio___19 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___19 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___19 bip_inline_vecs[0];
};

struct bio_set___19 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___19 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___18 {
	struct mem_cgroup___18 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___18 {
	struct lruvec___48 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___18 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___18 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct dev_pm_ops___42 {
	int (*prepare)(struct device___42 *);
	void (*complete)(struct device___42 *);
	int (*suspend)(struct device___42 *);
	int (*resume)(struct device___42 *);
	int (*freeze)(struct device___42 *);
	int (*thaw)(struct device___42 *);
	int (*poweroff)(struct device___42 *);
	int (*restore)(struct device___42 *);
	int (*suspend_late)(struct device___42 *);
	int (*resume_early)(struct device___42 *);
	int (*freeze_late)(struct device___42 *);
	int (*thaw_early)(struct device___42 *);
	int (*poweroff_late)(struct device___42 *);
	int (*restore_early)(struct device___42 *);
	int (*suspend_noirq)(struct device___42 *);
	int (*resume_noirq)(struct device___42 *);
	int (*freeze_noirq)(struct device___42 *);
	int (*thaw_noirq)(struct device___42 *);
	int (*poweroff_noirq)(struct device___42 *);
	int (*restore_noirq)(struct device___42 *);
	int (*runtime_suspend)(struct device___42 *);
	int (*runtime_resume)(struct device___42 *);
	int (*runtime_idle)(struct device___42 *);
};

struct dev_pm_domain___42 {
	struct dev_pm_ops___42 ops;
	void (*detach)(struct device___42 *, bool);
	int (*activate)(struct device___42 *);
	void (*sync)(struct device___42 *);
	void (*dismiss)(struct device___42 *);
};

struct bus_type___42 {
	const char *name;
	const char *dev_name;
	struct device___42 *dev_root;
	const struct attribute_group___43 **bus_groups;
	const struct attribute_group___43 **dev_groups;
	const struct attribute_group___43 **drv_groups;
	int (*match)(struct device___42 *, struct device_driver___42 *);
	int (*uevent)(struct device___42 *, struct kobj_uevent_env *);
	int (*probe)(struct device___42 *);
	int (*remove)(struct device___42 *);
	void (*shutdown)(struct device___42 *);
	int (*online)(struct device___42 *);
	int (*offline)(struct device___42 *);
	int (*suspend)(struct device___42 *, pm_message_t);
	int (*resume)(struct device___42 *);
	int (*num_vf)(struct device___42 *);
	int (*dma_configure)(struct device___42 *);
	const struct dev_pm_ops___42 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___42 {
	const char *name;
	struct bus_type___42 *bus;
	struct module___44 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___42 *);
	int (*remove)(struct device___42 *);
	void (*shutdown)(struct device___42 *);
	int (*suspend)(struct device___42 *, pm_message_t);
	int (*resume)(struct device___42 *);
	const struct attribute_group___43 **groups;
	const struct dev_pm_ops___42 *pm;
	void (*coredump)(struct device___42 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___42 {
	const char *name;
	const struct attribute_group___43 **groups;
	int (*uevent)(struct device___42 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___42 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___42 *);
	const struct dev_pm_ops___42 *pm;
};

struct class___42 {
	const char *name;
	struct module___44 *owner;
	const struct attribute_group___43 **class_groups;
	const struct attribute_group___43 **dev_groups;
	struct kobject___46 *dev_kobj;
	int (*dev_uevent)(struct device___42 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___42 *, umode_t *);
	void (*class_release)(struct class___42 *);
	void (*dev_release)(struct device___42 *);
	int (*shutdown_pre)(struct device___42 *);
	const struct kobj_ns_type_operations___2 *ns_type;
	const void * (*namespace)(struct device___42 *);
	const struct dev_pm_ops___42 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

typedef void (*dr_release_t___2)(struct device___42 *, void *);

struct node___39 {
	struct device___42 dev;
};

struct perf_cpu_context___30;

struct pmu___30 {
	struct list_head entry;
	struct module___44 *module;
	struct device___42 *dev;
	const struct attribute_group___43 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___30 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___30 *);
	void (*pmu_disable)(struct pmu___30 *);
	int (*event_init)(struct perf_event___30 *);
	void (*event_mapped)(struct perf_event___30 *, struct mm_struct___48 *);
	void (*event_unmapped)(struct perf_event___30 *, struct mm_struct___48 *);
	int (*add)(struct perf_event___30 *, int);
	void (*del)(struct perf_event___30 *, int);
	void (*start)(struct perf_event___30 *, int);
	void (*stop)(struct perf_event___30 *, int);
	void (*read)(struct perf_event___30 *);
	void (*start_txn)(struct pmu___30 *, unsigned int);
	int (*commit_txn)(struct pmu___30 *);
	void (*cancel_txn)(struct pmu___30 *);
	int (*event_idx)(struct perf_event___30 *);
	void (*sched_task)(struct perf_event_context___30 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___30 *);
	int (*filter_match)(struct perf_event___30 *);
	int (*check_period)(struct perf_event___30 *, u64);
};

struct perf_cpu_context___30 {
	struct perf_event_context___30 ctx;
	struct perf_event_context___30 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___30 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___30 {
	struct cgroup_subsys_state___37 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___25 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___25 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___25 *);
	struct list_head * (*get_fields)(struct trace_event_call___25 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___25 *);
};

struct syscall_metadata___12 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___25 *enter_event;
	struct trace_event_call___25 *exit_event;
};

typedef u64 async_cookie_t;

typedef void (*async_func_t)(void *, async_cookie_t);

struct async_domain {
	struct list_head pending;
	unsigned int registered: 1;
};

struct async_entry {
	struct list_head domain_list;
	struct list_head global_list;
	struct work_struct work;
	async_cookie_t cookie;
	async_func_t func;
	void *data;
	struct async_domain *domain;
};

struct range {
	u64 start;
	u64 end;
};

struct smp_hotplug_thread___3 {
	struct task_struct___49 **store;
	struct list_head list;
	int (*thread_should_run)(unsigned int);
	void (*thread_fn)(unsigned int);
	void (*create)(unsigned int);
	void (*setup)(unsigned int);
	void (*cleanup)(unsigned int, bool);
	void (*park)(unsigned int);
	void (*unpark)(unsigned int);
	cpumask_var_t cpumask;
	bool selfparking;
	const char *thread_comm;
};

struct smpboot_thread_data {
	unsigned int cpu;
	unsigned int status;
	struct smp_hotplug_thread___3 *ht;
};

enum {
	HP_THREAD_NONE = 0,
	HP_THREAD_ACTIVE = 1,
	HP_THREAD_PARKED = 2,
};

struct rh_feature {
	struct list_head list;
	char name[32];
};

typedef void (*call_rcu_func_t)(struct callback_head *, rcu_callback_t);

struct module___45;

struct file___50;

struct kiocb___50;

struct iov_iter___23;

struct poll_table_struct___32;

struct vm_area_struct___50;

struct inode___51;

struct file_lock___50;

struct page___50;

struct pipe_inode_info___12;

struct seq_file___47;

struct file_operations___50 {
	struct module___45 *owner;
	loff_t (*llseek)(struct file___50 *, loff_t, int);
	ssize_t (*read)(struct file___50 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___50 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___50 *, struct iov_iter___23 *);
	ssize_t (*write_iter)(struct kiocb___50 *, struct iov_iter___23 *);
	int (*iopoll)(struct kiocb___50 *, bool);
	int (*iterate)(struct file___50 *, struct dir_context *);
	int (*iterate_shared)(struct file___50 *, struct dir_context *);
	__poll_t (*poll)(struct file___50 *, struct poll_table_struct___32 *);
	long int (*unlocked_ioctl)(struct file___50 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___50 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___50 *, struct vm_area_struct___50 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___51 *, struct file___50 *);
	int (*flush)(struct file___50 *, fl_owner_t);
	int (*release)(struct inode___51 *, struct file___50 *);
	int (*fsync)(struct file___50 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___50 *, int);
	int (*lock)(struct file___50 *, int, struct file_lock___50 *);
	ssize_t (*sendpage)(struct file___50 *, struct page___50 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___50 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___50 *, int, struct file_lock___50 *);
	ssize_t (*splice_write)(struct pipe_inode_info___12 *, struct file___50 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___50 *, loff_t *, struct pipe_inode_info___12 *, size_t, unsigned int);
	int (*setlease)(struct file___50 *, long int, struct file_lock___50 **, void **);
	long int (*fallocate)(struct file___50 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___47 *, struct file___50 *);
	ssize_t (*copy_file_range)(struct file___50 *, loff_t, struct file___50 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___50 *, loff_t, struct file___50 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___50 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct preempt_notifier___7;

struct preempt_ops___7 {
	void (*sched_in)(struct preempt_notifier___7 *, int);
	void (*sched_out)(struct preempt_notifier___7 *, struct task_struct___2 *);
};

struct preempt_notifier___7 {
	struct hlist_node link;
	struct preempt_ops___7 *ops;
};

struct vmacache___49 {
	u64 seqnum;
	struct vm_area_struct___50 *vmas[4];
};

struct page_frag___49 {
	struct page___50 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___31;

struct debug_info___31 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___31 *hbp_break[16];
	struct perf_event___31 *hbp_watch[16];
};

struct thread_struct___31 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___31 debug;
	long: 64;
};

struct mm_struct___49;

struct mem_cgroup___19;

struct pid___45;

struct cred___49;

struct nsproxy___48;

struct signal_struct___47;

struct bio_list___20;

struct backing_dev_info___20;

struct io_context___11;

struct css_set___38;

struct perf_event_context___31;

struct request_queue___12;

struct vm_struct___39;

struct task_struct___2 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___2 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___49 *mm;
	struct mm_struct___49 *active_mm;
	struct vmacache___49 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___2 *real_parent;
	struct task_struct___2 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___2 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___19 *active_memcg;
	long int rh_reserved2;
	struct pid___45 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___45 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___45 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___49 *ptracer_cred;
	const struct cred___49 *real_cred;
	const struct cred___49 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___48 *nsproxy;
	struct signal_struct___47 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___2 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___20 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___20 *backing_dev_info;
	struct io_context___11 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___38 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___31 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___12 *splice_pipe;
	struct page_frag___49 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___19 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___12 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___2 *oom_reaper_list;
	struct vm_struct___39 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___31 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pin_cookie {};

struct hw_perf_event___31 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___2 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___31)(struct perf_event___31 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___31;

struct fasync_struct___49;

struct pid_namespace___45;

struct trace_event_call___26;

struct perf_cgroup___31;

struct perf_event___31 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___31 *group_leader;
	struct pmu___31 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___31 hw;
	struct perf_event_context___31 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___31 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___2 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___49 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___31 *);
	struct callback_head callback_head;
	struct pid_namespace___45 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___31 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___31 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___26 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___31 *cgrp;
	struct list_head sb_list;
};

struct upid___45 {
	int nr;
	struct pid_namespace___45 *ns;
};

struct dentry___50;

struct user_namespace___40;

struct ucounts___40;

struct pid_namespace___45 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___2 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___45 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___50 *proc_self;
	struct dentry___50 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___40 *user_ns;
	struct ucounts___40 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___4 ns;
};

struct pid___45 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___45 numbers[1];
};

struct rw_semaphore___50 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___2 *owner;
};

struct key___50;

struct user_namespace___40 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___40 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___4 ns;
	long unsigned int flags;
	struct key___50 *persistent_keyring_register;
	struct rw_semaphore___50 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___40 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct secondary_data___50 {
	void *stack;
	struct task_struct___2 *task;
	long int status;
};

struct clock_event_device___8;

struct arch_timer_erratum_workaround___8 {
	enum arch_timer_erratum_match_type match_type;
	const void *id;
	const char *desc;
	u32 (*read_cntp_tval_el0)();
	u32 (*read_cntv_tval_el0)();
	u64 (*read_cntpct_el0)();
	u64 (*read_cntvct_el0)();
	int (*set_next_event_phys)(long unsigned int, struct clock_event_device___8 *);
	int (*set_next_event_virt)(long unsigned int, struct clock_event_device___8 *);
};

struct clock_event_device___8 {
	void (*event_handler)(struct clock_event_device___8 *);
	int (*set_next_event)(long unsigned int, struct clock_event_device___8 *);
	int (*set_next_ktime)(ktime_t, struct clock_event_device___8 *);
	ktime_t next_event;
	u64 max_delta_ns;
	u64 min_delta_ns;
	u32 mult;
	u32 shift;
	enum clock_event_state state_use_accessors;
	unsigned int features;
	long unsigned int retries;
	int (*set_state_periodic)(struct clock_event_device___8 *);
	int (*set_state_oneshot)(struct clock_event_device___8 *);
	int (*set_state_oneshot_stopped)(struct clock_event_device___8 *);
	int (*set_state_shutdown)(struct clock_event_device___8 *);
	int (*tick_resume)(struct clock_event_device___8 *);
	void (*broadcast)(const struct cpumask *);
	void (*suspend)(struct clock_event_device___8 *);
	void (*resume)(struct clock_event_device___8 *);
	long unsigned int min_delta_ticks;
	long unsigned int max_delta_ticks;
	const char *name;
	int rating;
	int irq;
	int bound_on;
	const struct cpumask *cpumask;
	struct list_head list;
	struct module___45 *owner;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___50 *pgtable_t___49;

struct address_space___49;

struct dev_pagemap___49;

struct page___50 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___49 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___50 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___49 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___49 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___49 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___19 *mem_cgroup;
};

struct user_struct___49 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___50 *uid_keyring;
	struct key___50 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___49;

struct vm_area_struct___50 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___50 *vm_next;
	struct vm_area_struct___50 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___49 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___49 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___50 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cfs_rq {
	struct load_weight load;
	long unsigned int runnable_weight;
	unsigned int nr_running;
	unsigned int h_nr_running;
	u64 exec_clock;
	u64 min_vruntime;
	struct rb_root_cached tasks_timeline;
	struct sched_entity *curr;
	struct sched_entity *next;
	struct sched_entity *last;
	struct sched_entity *skip;
	unsigned int nr_spread_over;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	struct sched_avg avg;
	struct {
		raw_spinlock_t lock;
		int nr;
		long unsigned int load_avg;
		long unsigned int util_avg;
		long unsigned int runnable_sum;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	} removed;
	long unsigned int tg_load_avg_contrib;
	long int propagate;
	long int prop_runnable_sum;
	long unsigned int h_load;
	u64 last_h_load_update;
	struct sched_entity *h_load_next;
	struct rq *rq;
	int on_list;
	struct list_head leaf_cfs_rq_list;
	struct task_group *tg;
	int runtime_enabled;
	int rh_reserved_expires_seq;
	u64 rh_reserved_runtime_expires;
	s64 runtime_remaining;
	u64 throttled_clock;
	u64 throttled_clock_task;
	u64 throttled_clock_task_time;
	int throttled;
	int throttle_count;
	struct list_head throttled_list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long: 64;
	long: 64;
};

struct rt_prio_array {
	long unsigned int bitmap[2];
	struct list_head queue[100];
};

struct rt_rq {
	struct rt_prio_array active;
	unsigned int rt_nr_running;
	unsigned int rr_nr_running;
	struct {
		int curr;
		int next;
	} highest_prio;
	long unsigned int rt_nr_migratory;
	long unsigned int rt_nr_total;
	int overloaded;
	struct plist_head pushable_tasks;
	int rt_queued;
	int rt_throttled;
	u64 rt_time;
	u64 rt_runtime;
	raw_spinlock_t rt_runtime_lock;
	long unsigned int rt_nr_boosted;
	struct rq *rq;
	struct task_group *tg;
};

struct cgroup___38;

struct cgroup_subsys___38;

struct cgroup_subsys_state___38 {
	struct cgroup___38 *cgroup;
	struct cgroup_subsys___38 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___38 *parent;
};

struct rt_bandwidth {
	raw_spinlock_t rt_runtime_lock;
	ktime_t rt_period;
	u64 rt_runtime;
	struct hrtimer rt_period_timer;
	unsigned int rt_period_active;
};

struct cfs_bandwidth {
	raw_spinlock_t lock;
	ktime_t period;
	u64 quota;
	u64 runtime;
	s64 hierarchical_quota;
	u64 rh_reserved_runtime_expires;
	int rh_reserved_expires_seq;
	short int idle;
	short int period_active;
	struct hrtimer period_timer;
	struct hrtimer slack_timer;
	struct list_head throttled_cfs_rq;
	int nr_periods;
	int nr_throttled;
	u64 throttled_time;
	bool distribute_running;
};

struct task_group {
	struct cgroup_subsys_state___38 css;
	struct sched_entity **se;
	struct cfs_rq **cfs_rq;
	long unsigned int shares;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t load_avg;
	struct sched_rt_entity **rt_se;
	struct rt_rq **rt_rq;
	struct rt_bandwidth rt_bandwidth;
	struct callback_head rcu;
	struct list_head list;
	struct task_group *parent;
	struct list_head siblings;
	struct list_head children;
	struct autogroup *autogroup;
	struct cfs_bandwidth cfs_bandwidth;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long: 64;
	long: 64;
	long: 64;
};

struct linux_binfmt___10;

struct core_state___49;

struct mm_struct___49 {
	struct {
		struct vm_area_struct___50 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___50 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___50 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___10 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___49 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___2 *owner;
		struct user_namespace___40 *user_ns;
		struct file___50 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___49 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct mem_cgroup_id___10 {
	int id;
	union {
		refcount_t ref;
		struct {
			atomic_t ref;
		} __UNIQUE_ID_rh_kabi_hide64;
		union {		};
	};
};

struct kernfs_node___47;

struct cgroup_file___38 {
	struct kernfs_node___47 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___19;

struct mem_cgroup___19 {
	struct cgroup_subsys_state___38 css;
	struct mem_cgroup_id___10 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___38 events_file;
	struct cgroup_file___38 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___2 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___19 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cred___49 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___50 *session_keyring;
	struct key___50 *process_keyring;
	struct key___50 *thread_keyring;
	struct key___50 *request_key_auth;
	void *security;
	struct user_struct___49 *user;
	struct user_namespace___40 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct uts_namespace___11;

struct net___13;

struct cgroup_namespace___38;

struct nsproxy___48 {
	atomic_t count;
	struct uts_namespace___11 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___45 *pid_ns_for_children;
	struct net___13 *net_ns;
	struct cgroup_namespace___38 *cgroup_ns;
};

struct signal_struct___47 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___2 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___2 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___45 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___45 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___49 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___45 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___20;

struct bio_list___20 {
	struct bio___20 *head;
	struct bio___20 *tail;
};

struct bdi_writeback_congested___20;

struct bdi_writeback___20 {
	struct backing_dev_info___20 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___20 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___38 *memcg_css;
	struct cgroup_subsys_state___38 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___43;

struct backing_dev_info___20 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___20 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___43 *dev;
	struct device___43 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___50 *debug_dir;
	struct dentry___50 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___11;

struct io_context___11 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___11 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___38 {
	struct cgroup_subsys_state___38 *subsys[13];
	refcount_t refcount;
	struct css_set___38 *dom_cset;
	struct cgroup___38 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___38 *mg_src_cgrp;
	struct cgroup___38 *mg_dst_cgrp;
	struct css_set___38 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___31 {
	struct pmu___31 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___2 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___31 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___12;

struct pipe_inode_info___12 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___50 *tmp_page;
	struct fasync_struct___49 *fasync_readers;
	struct fasync_struct___49 *fasync_writers;
	struct pipe_buffer___12 *bufs;
	struct user_struct___49 *user;
};

typedef blk_qc_t make_request_fn___11(struct request_queue___12 *, struct bio___20 *);

struct request___12;

typedef int dma_drain_needed_fn___11(struct request___12 *);

struct kset___46;

struct kobj_type___46;

struct kobject___47 {
	const char *name;
	struct list_head entry;
	struct kobject___47 *parent;
	struct kset___46 *kset;
	struct kobj_type___46 *ktype;
	struct kernfs_node___47 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___11;

struct bsg_class_device___11 {
	struct device___43 *class_dev;
	int minor;
	struct request_queue___12 *queue;
	const struct bsg_ops___11 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___20 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___20 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___11;

struct request_queue___12 {
	struct list_head queue_head;
	struct request___12 *last_merge;
	struct elevator_queue___11 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___11 *make_request_fn;
	dma_drain_needed_fn___11 *dma_drain_needed;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___20 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___47 kobj;
	struct kobject___47 *mq_kobj;
	struct blk_integrity integrity;
	struct device___43 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	struct bsg_class_device___11 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___20 bio_split;
	struct dentry___50 *debugfs_dir;
	struct dentry___50 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___39 {
	struct vm_struct___39 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___50 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___47 {
	struct task_struct___2 task;
	long unsigned int stack[8192];
};

struct address_space_operations___49;

struct address_space___49 {
	struct inode___51 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___50 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___49 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___49)(struct vm_area_struct___50 *, long unsigned int, const struct page___50 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___49)(struct page___50 *, void *);

struct dev_pagemap___49 {
	dev_page_fault_t___49 page_fault;
	dev_page_free_t___49 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___43 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___49 {
	struct vfsmount *mnt;
	struct dentry___50 *dentry;
};

struct fown_struct___45 {
	rwlock_t lock;
	struct pid___45 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___50 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___49 f_path;
	struct inode___51 *f_inode;
	const struct file_operations___50 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___45 f_owner;
	const struct cred___49 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___49 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___49;

struct vm_operations_struct___49 {
	void (*open)(struct vm_area_struct___50 *);
	void (*close)(struct vm_area_struct___50 *);
	int (*split)(struct vm_area_struct___50 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___50 *);
	vm_fault_t (*fault)(struct vm_fault___49 *);
	vm_fault_t (*huge_fault)(struct vm_fault___49 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___49 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___50 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___49 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___49 *);
	int (*access)(struct vm_area_struct___50 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___50 *);
	int (*set_policy)(struct vm_area_struct___50 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___50 *, long unsigned int);
	struct page___50 * (*find_special_page)(struct vm_area_struct___50 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___49 {
	struct task_struct___2 *task;
	struct core_thread___49 *next;
};

struct core_state___49 {
	atomic_t nr_threads;
	struct core_thread___49 dumper;
	struct completion startup;
};

struct linux_binprm___11;

struct coredump_params___10;

struct linux_binfmt___10 {
	struct list_head lh;
	struct module___45 *module;
	int (*load_binary)(struct linux_binprm___11 *);
	int (*load_shlib)(struct file___50 *);
	int (*core_dump)(struct coredump_params___10 *);
	long unsigned int min_coredump;
};

struct vm_fault___49 {
	struct vm_area_struct___50 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___50 *cow_page;
	struct mem_cgroup___19 *memcg;
	struct page___50 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___49 prealloc_pte;
};

struct update_util_data {
	void (*func)(struct update_util_data *, u64, unsigned int);
};

typedef int (*key_restrict_link_func_t___49)(struct key___50 *, const struct key_type *, const union key_payload *, struct key___50 *);

struct key_restriction___50;

struct key___50 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___50 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___50 *restrict_link;
};

struct key_restriction___50 {
	key_restrict_link_func_t___49 check;
	struct key___50 *key;
	struct key_type *keytype;
};

struct autogroup {
	struct kref kref;
	struct task_group *tg;
	struct rw_semaphore___50 lock;
	long unsigned int id;
	int nice;
};

struct pglist_data___49;

struct lruvec___49 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___49 *pgdat;
};

struct zone___49 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___49 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___49 {
	struct zone___49 *zone;
	int zone_idx;
};

struct zonelist___49 {
	struct zoneref___49 _zonerefs[25];
};

struct pglist_data___49 {
	struct zone___49 node_zones[3];
	struct zonelist___49 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___2 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___2 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___49 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___49 {
	struct rw_semaphore___50 rwsem;
	struct notifier_block *head;
};

struct kernfs_root___47;

struct kernfs_elem_dir___47 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___47 *root;
};

struct kernfs_syscall_ops___47;

struct kernfs_root___47 {
	struct kernfs_node___47 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___47 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___47 {
	struct kernfs_node___47 *target_kn;
};

struct kernfs_ops___47;

struct kernfs_elem_attr___47 {
	const struct kernfs_ops___47 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___47 *notify_next;
};

struct kernfs_node___47 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___47 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___47 dir;
		struct kernfs_elem_symlink___47 symlink;
		struct kernfs_elem_attr___47 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___47;

struct kernfs_ops___47 {
	int (*open)(struct kernfs_open_file___47 *);
	void (*release)(struct kernfs_open_file___47 *);
	int (*seq_show)(struct seq_file___47 *, void *);
	void * (*seq_start)(struct seq_file___47 *, loff_t *);
	void * (*seq_next)(struct seq_file___47 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___47 *, void *);
	ssize_t (*read)(struct kernfs_open_file___47 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___47 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___47 *, struct vm_area_struct___50 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___47 *, struct poll_table_struct___32 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___47 {
	int (*remount_fs)(struct kernfs_root___47 *, int *, char *);
	int (*show_options)(struct seq_file___47 *, struct kernfs_root___47 *);
	int (*mkdir)(struct kernfs_node___47 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___47 *);
	int (*rename)(struct kernfs_node___47 *, struct kernfs_node___47 *, const char *);
	int (*show_path)(struct seq_file___47 *, struct kernfs_node___47 *, struct kernfs_root___47 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___44;

struct seq_file___47 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___44 *op;
	int poll_event;
	const struct file___50 *file;
	void *private;
};

struct kernfs_open_file___47 {
	struct kernfs_node___47 *kn;
	struct file___50 *file;
	struct seq_file___47 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___49 *vm_ops;
};

typedef void (*poll_queue_proc___31)(struct file___50 *, wait_queue_head_t *, struct poll_table_struct___32 *);

struct poll_table_struct___32 {
	poll_queue_proc___31 _qproc;
	__poll_t _key;
};

struct bin_attribute___44;

struct attribute_group___44 {
	const char *name;
	umode_t (*is_visible)(struct kobject___47 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___47 *, struct bin_attribute___44 *, int);
	struct attribute **attrs;
	struct bin_attribute___44 **bin_attrs;
};

struct bin_attribute___44 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___50 *, struct kobject___47 *, struct bin_attribute___44 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___50 *, struct kobject___47 *, struct bin_attribute___44 *, char *, loff_t, size_t);
	int (*mmap)(struct file___50 *, struct kobject___47 *, struct bin_attribute___44 *, struct vm_area_struct___50 *);
};

struct sysfs_ops___46 {
	ssize_t (*show)(struct kobject___47 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___47 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___46;

struct kset___46 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___47 kobj;
	const struct kset_uevent_ops___46 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___46 {
	void (*release)(struct kobject___47 *);
	const struct sysfs_ops___46 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___2 * (*child_ns_type)(struct kobject___47 *);
	const void * (*namespace)(struct kobject___47 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___46 {
	int (* const filter)(struct kset___46 *, struct kobject___47 *);
	const char * (* const name)(struct kset___46 *, struct kobject___47 *);
	int (* const uevent)(struct kset___46 *, struct kobject___47 *, struct kobj_uevent_env *);
};

struct kobj_attribute___47 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___47 *, struct kobj_attribute___47 *, char *);
	ssize_t (*store)(struct kobject___47 *, struct kobj_attribute___47 *, const char *, size_t);
};

struct fwnode_operations___35;

struct fwnode_handle___35 {
	struct fwnode_handle___35 *secondary;
	const struct fwnode_operations___35 *ops;
};

struct fwnode_reference_args___35;

struct fwnode_endpoint___35;

struct fwnode_operations___35 {
	struct fwnode_handle___35 * (*get)(struct fwnode_handle___35 *);
	void (*put)(struct fwnode_handle___35 *);
	bool (*device_is_available)(const struct fwnode_handle___35 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___35 *, const struct device___43 *);
	bool (*property_present)(const struct fwnode_handle___35 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___35 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___35 *, const char *, const char **, size_t);
	struct fwnode_handle___35 * (*get_parent)(const struct fwnode_handle___35 *);
	struct fwnode_handle___35 * (*get_next_child_node)(const struct fwnode_handle___35 *, struct fwnode_handle___35 *);
	struct fwnode_handle___35 * (*get_named_child_node)(const struct fwnode_handle___35 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___35 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___35 *);
	struct fwnode_handle___35 * (*graph_get_next_endpoint)(const struct fwnode_handle___35 *, struct fwnode_handle___35 *);
	struct fwnode_handle___35 * (*graph_get_remote_endpoint)(const struct fwnode_handle___35 *);
	struct fwnode_handle___35 * (*graph_get_port_parent)(struct fwnode_handle___35 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___35 *, struct fwnode_endpoint___35 *);
};

struct fwnode_endpoint___35 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___35 *local_fwnode;
};

struct fwnode_reference_args___35 {
	struct fwnode_handle___35 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct dev_pm_info___43 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___43 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___43;

struct bus_type___43;

struct device_driver___43;

struct dev_pm_domain___43;

struct dma_map_ops___13;

struct device_node___15;

struct class___43;

struct device___43 {
	struct device___43 *parent;
	struct device_private *p;
	struct kobject___47 kobj;
	const char *init_name;
	const struct device_type___43 *type;
	struct mutex mutex;
	struct bus_type___43 *bus;
	struct device_driver___43 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___43 power;
	struct dev_pm_domain___43 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___13 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___15 *of_node;
	struct fwnode_handle___35 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___43 *class;
	const struct attribute_group___44 **groups;
	void (*release)(struct device___43 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct property___15 {
	char *name;
	int length;
	void *value;
	struct property___15 *next;
	long unsigned int _flags;
	struct bin_attribute___44 attr;
};

struct device_node___15 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___35 fwnode;
	struct property___15 *properties;
	struct property___15 *deadprops;
	struct device_node___15 *parent;
	struct device_node___15 *child;
	struct device_node___15 *sibling;
	struct kobject___47 kobj;
	long unsigned int _flags;
	void *data;
};

struct module_kobject___42 {
	struct kobject___47 kobj;
	struct module___45 *mod;
	struct kobject___47 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___42 {
	struct module___45 *mod;
	struct latch_tree_node node;
};

struct module_layout___42 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___42 mtn;
};

struct module_attribute___42;

struct kernel_param___42;

struct module___45 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___42 mkobj;
	struct module_attribute___42 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___47 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___42 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___42 core_layout;
	struct module_layout___42 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___26 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide56;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide57;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

enum {
	MEMBARRIER_STATE_PRIVATE_EXPEDITED_READY = 1,
	MEMBARRIER_STATE_PRIVATE_EXPEDITED = 2,
	MEMBARRIER_STATE_GLOBAL_EXPEDITED_READY = 4,
	MEMBARRIER_STATE_GLOBAL_EXPEDITED = 8,
	MEMBARRIER_STATE_PRIVATE_EXPEDITED_SYNC_CORE_READY = 16,
	MEMBARRIER_STATE_PRIVATE_EXPEDITED_SYNC_CORE = 32,
};

struct sched_domain_shared {
	atomic_t ref;
	atomic_t nr_busy_cpus;
	int has_idle_cores;
};

struct sched_group;

struct sched_domain {
	struct sched_domain *parent;
	struct sched_domain *child;
	struct sched_group *groups;
	long unsigned int min_interval;
	long unsigned int max_interval;
	unsigned int busy_factor;
	unsigned int imbalance_pct;
	unsigned int cache_nice_tries;
	unsigned int busy_idx;
	unsigned int idle_idx;
	unsigned int newidle_idx;
	unsigned int wake_idx;
	unsigned int forkexec_idx;
	unsigned int rh_reserved_smt_gain;
	int nohz_idle;
	int flags;
	int level;
	long unsigned int last_balance;
	unsigned int balance_interval;
	unsigned int nr_balance_failed;
	u64 max_newidle_lb_cost;
	long unsigned int next_decay_max_lb_cost;
	u64 avg_scan_cost;
	unsigned int lb_count[3];
	unsigned int lb_failed[3];
	unsigned int lb_balanced[3];
	unsigned int lb_imbalance[3];
	unsigned int lb_gained[3];
	unsigned int lb_hot_gained[3];
	unsigned int lb_nobusyg[3];
	unsigned int lb_nobusyq[3];
	unsigned int alb_count;
	unsigned int alb_failed;
	unsigned int alb_pushed;
	unsigned int sbe_count;
	unsigned int sbe_balanced;
	unsigned int sbe_pushed;
	unsigned int sbf_count;
	unsigned int sbf_balanced;
	unsigned int sbf_pushed;
	unsigned int ttwu_wake_remote;
	unsigned int ttwu_move_affine;
	unsigned int ttwu_move_balance;
	char *name;
	union {
		void *private;
		struct callback_head rcu;
	};
	struct sched_domain_shared *shared;
	unsigned int span_weight;
	long unsigned int span[0];
};

struct sched_group_capacity;

struct sched_group {
	struct sched_group *next;
	atomic_t ref;
	unsigned int group_weight;
	struct sched_group_capacity *sgc;
	int asym_prefer_cpu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int cpumask[0];
};

struct sched_group_capacity {
	atomic_t ref;
	long unsigned int capacity;
	long unsigned int min_capacity;
	long unsigned int next_update;
	int imbalance;
	int id;
	long unsigned int cpumask[0];
};

struct wake_q_head {
	struct wake_q_node *first;
	struct wake_q_node **lastp;
};

struct sched_attr {
	__u32 size;
	__u32 sched_policy;
	__u64 sched_flags;
	__s32 sched_nice;
	__u32 sched_priority;
	__u64 sched_runtime;
	__u64 sched_deadline;
	__u64 sched_period;
};

struct linux_binprm___11 {
	char buf[256];
	struct vm_area_struct___50 *vma;
	long unsigned int vma_pages;
	struct mm_struct___49 *mm;
	long unsigned int p;
	unsigned int called_set_creds: 1;
	unsigned int cap_elevated: 1;
	unsigned int secureexec: 1;
	unsigned int recursion_depth;
	struct file___50 *file;
	struct cred___49 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
};

struct coredump_params___10 {
	union {
		const kernel_siginfo_t *siginfo;
		struct {
			const siginfo_t *siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct pt_regs *regs;
	struct file___50 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
};

struct bio_vec___20 {
	struct page___50 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

typedef void bio_end_io_t___20(struct bio___20 *);

struct gendisk___11;

struct bio_integrity_payload___20;

struct bio___20 {
	struct bio___20 *bi_next;
	struct gendisk___11 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___20 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___20 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___20 *bi_io_vec;
	struct bio_set___20 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___20 bi_inline_vecs[0];
};

struct bio_integrity_payload___20 {
	struct bio___20 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___20 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___20 bip_inline_vecs[0];
};

struct hd_struct___11 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___43 __dev;
	struct kobject___47 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___11;

struct block_device_operations___11;

struct gendisk___11 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___11 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___11 *part_tbl;
	struct hd_struct___11 part0;
	const struct block_device_operations___11 *fops;
	struct request_queue___12 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___50 lookup_sem;
	struct kobject___47 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___47 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_ops___43;

struct device_type___43 {
	const char *name;
	const struct attribute_group___44 **groups;
	int (*uevent)(struct device___43 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___43 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___43 *);
	const struct dev_pm_ops___43 *pm;
};

struct class___43 {
	const char *name;
	struct module___45 *owner;
	const struct attribute_group___44 **class_groups;
	const struct attribute_group___44 **dev_groups;
	struct kobject___47 *dev_kobj;
	int (*dev_uevent)(struct device___43 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___43 *, umode_t *);
	void (*class_release)(struct class___43 *);
	void (*dev_release)(struct device___43 *);
	int (*shutdown_pre)(struct device___43 *);
	const struct kobj_ns_type_operations___2 *ns_type;
	const void * (*namespace)(struct device___43 *);
	const struct dev_pm_ops___43 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dev_pm_ops___43 {
	int (*prepare)(struct device___43 *);
	void (*complete)(struct device___43 *);
	int (*suspend)(struct device___43 *);
	int (*resume)(struct device___43 *);
	int (*freeze)(struct device___43 *);
	int (*thaw)(struct device___43 *);
	int (*poweroff)(struct device___43 *);
	int (*restore)(struct device___43 *);
	int (*suspend_late)(struct device___43 *);
	int (*resume_early)(struct device___43 *);
	int (*freeze_late)(struct device___43 *);
	int (*thaw_early)(struct device___43 *);
	int (*poweroff_late)(struct device___43 *);
	int (*restore_early)(struct device___43 *);
	int (*suspend_noirq)(struct device___43 *);
	int (*resume_noirq)(struct device___43 *);
	int (*freeze_noirq)(struct device___43 *);
	int (*thaw_noirq)(struct device___43 *);
	int (*poweroff_noirq)(struct device___43 *);
	int (*restore_noirq)(struct device___43 *);
	int (*runtime_suspend)(struct device___43 *);
	int (*runtime_resume)(struct device___43 *);
	int (*runtime_idle)(struct device___43 *);
};

struct dev_pm_domain___43 {
	struct dev_pm_ops___43 ops;
	void (*detach)(struct device___43 *, bool);
	int (*activate)(struct device___43 *);
	void (*sync)(struct device___43 *);
	void (*dismiss)(struct device___43 *);
};

struct bus_type___43 {
	const char *name;
	const char *dev_name;
	struct device___43 *dev_root;
	const struct attribute_group___44 **bus_groups;
	const struct attribute_group___44 **dev_groups;
	const struct attribute_group___44 **drv_groups;
	int (*match)(struct device___43 *, struct device_driver___43 *);
	int (*uevent)(struct device___43 *, struct kobj_uevent_env *);
	int (*probe)(struct device___43 *);
	int (*remove)(struct device___43 *);
	void (*shutdown)(struct device___43 *);
	int (*online)(struct device___43 *);
	int (*offline)(struct device___43 *);
	int (*suspend)(struct device___43 *, pm_message_t);
	int (*resume)(struct device___43 *);
	int (*num_vf)(struct device___43 *);
	int (*dma_configure)(struct device___43 *);
	const struct dev_pm_ops___43 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___43 {
	const char *name;
	struct bus_type___43 *bus;
	struct module___45 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___43 *);
	int (*remove)(struct device___43 *);
	void (*shutdown)(struct device___43 *);
	int (*suspend)(struct device___43 *, pm_message_t);
	int (*resume)(struct device___43 *);
	const struct attribute_group___44 **groups;
	const struct dev_pm_ops___43 *pm;
	void (*coredump)(struct device___43 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct dma_map_ops___13 {
	void * (*alloc)(struct device___43 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___43 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___43 *, struct vm_area_struct___50 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___43 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___43 *, struct page___50 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___43 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___43 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___43 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___43 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___43 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___43 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide58;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___43 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___43 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___43 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___43 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___43 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___43 *, u64);
	u64 (*get_required_mask)(struct device___43 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct dentry_operations___49;

struct super_block___50;

struct dentry___50 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___50 *d_parent;
	struct qstr d_name;
	struct inode___51 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___49 *d_op;
	struct super_block___50 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___49;

struct block_device___50;

struct inode___51 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___49 *i_op;
	struct super_block___50 *i_sb;
	struct address_space___49 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___50 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___20 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___50 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___49 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___12 *i_pipe;
		struct block_device___50 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___49 {
	int (*d_revalidate)(struct dentry___50 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___50 *, unsigned int);
	int (*d_hash)(const struct dentry___50 *, struct qstr *);
	int (*d_compare)(const struct dentry___50 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___50 *);
	int (*d_init)(struct dentry___50 *);
	void (*d_release)(struct dentry___50 *);
	void (*d_prune)(struct dentry___50 *);
	void (*d_iput)(struct dentry___50 *, struct inode___51 *);
	char * (*d_dname)(struct dentry___50 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___49 *);
	int (*d_manage)(const struct path___49 *, bool);
	struct dentry___50 * (*d_real)(struct dentry___50 *, const struct inode___51 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___49;

struct mem_dqinfo___49 {
	struct quota_format_type___49 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___49;

struct quota_info___49 {
	unsigned int flags;
	struct rw_semaphore___50 dqio_sem;
	struct inode___51 *files[3];
	struct mem_dqinfo___49 info[3];
	const struct quota_format_ops___49 *ops[3];
};

struct rcuwait___49 {
	struct task_struct___2 *task;
};

struct percpu_rw_semaphore___49 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___50 rw_sem;
	struct rcuwait___49 writer;
	int readers_block;
};

struct sb_writers___49 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___49 rw_sem[3];
};

struct shrink_control___19;

struct shrinker___19 {
	long unsigned int (*count_objects)(struct shrinker___19 *, struct shrink_control___19 *);
	long unsigned int (*scan_objects)(struct shrinker___19 *, struct shrink_control___19 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___49;

struct super_operations___49;

struct dquot_operations___49;

struct quotactl_ops___49;

struct super_block___50 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___49 *s_type;
	const struct super_operations___49 *s_op;
	const struct dquot_operations___49 *dq_op;
	const struct quotactl_ops___49 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___50 *s_root;
	struct rw_semaphore___50 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___50 *s_bdev;
	struct backing_dev_info___20 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___49 s_dquot;
	struct sb_writers___49 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___49 *s_d_op;
	int cleancache_poolid;
	struct shrinker___19 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___40 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___19 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___19 *memcg;
};

struct io_cq___11 {
	struct request_queue___12 *q;
	struct io_context___11 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___50 {
	struct file___50 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___50 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___50 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___50 *ia_file;
};

struct dquot___49 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___50 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___49 {
	int qf_fmt_id;
	const struct quota_format_ops___49 *qf_ops;
	struct module___45 *qf_owner;
	struct quota_format_type___49 *qf_next;
};

struct quota_format_ops___49 {
	int (*check_quota_file)(struct super_block___50 *, int);
	int (*read_file_info)(struct super_block___50 *, int);
	int (*write_file_info)(struct super_block___50 *, int);
	int (*free_file_info)(struct super_block___50 *, int);
	int (*read_dqblk)(struct dquot___49 *);
	int (*commit_dqblk)(struct dquot___49 *);
	int (*release_dqblk)(struct dquot___49 *);
	int (*get_next_id)(struct super_block___50 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___49 {
	int (*write_dquot)(struct dquot___49 *);
	struct dquot___49 * (*alloc_dquot)(struct super_block___50 *, int);
	void (*destroy_dquot)(struct dquot___49 *);
	int (*acquire_dquot)(struct dquot___49 *);
	int (*release_dquot)(struct dquot___49 *);
	int (*mark_dirty)(struct dquot___49 *);
	int (*write_info)(struct super_block___50 *, int);
	qsize_t * (*get_reserved_space)(struct inode___51 *);
	int (*get_projid)(struct inode___51 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___51 *, qsize_t *);
	int (*get_next_id)(struct super_block___50 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___49 {
	int (*quota_on)(struct super_block___50 *, int, int, const struct path___49 *);
	int (*quota_off)(struct super_block___50 *, int);
	int (*quota_enable)(struct super_block___50 *, unsigned int);
	int (*quota_disable)(struct super_block___50 *, unsigned int);
	int (*quota_sync)(struct super_block___50 *, int);
	int (*set_info)(struct super_block___50 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___50 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___50 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___50 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___50 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___50 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___19;

struct swap_info_struct___14;

struct address_space_operations___49 {
	int (*writepage)(struct page___50 *, struct writeback_control___19 *);
	int (*readpage)(struct file___50 *, struct page___50 *);
	int (*writepages)(struct address_space___49 *, struct writeback_control___19 *);
	int (*set_page_dirty)(struct page___50 *);
	int (*readpages)(struct file___50 *, struct address_space___49 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___50 *, struct address_space___49 *, loff_t, unsigned int, unsigned int, struct page___50 **, void **);
	int (*write_end)(struct file___50 *, struct address_space___49 *, loff_t, unsigned int, unsigned int, struct page___50 *, void *);
	sector_t (*bmap)(struct address_space___49 *, sector_t);
	void (*invalidatepage)(struct page___50 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___50 *, gfp_t);
	void (*freepage)(struct page___50 *);
	ssize_t (*direct_IO)(struct kiocb___50 *, struct iov_iter___23 *);
	int (*migratepage)(struct address_space___49 *, struct page___50 *, struct page___50 *, enum migrate_mode);
	bool (*isolate_page)(struct page___50 *, isolate_mode_t);
	void (*putback_page)(struct page___50 *);
	int (*launder_page)(struct page___50 *);
	int (*is_partially_uptodate)(struct page___50 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___50 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___49 *, struct page___50 *);
	int (*swap_activate)(struct swap_info_struct___14 *, struct file___50 *, sector_t *);
	void (*swap_deactivate)(struct file___50 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___19 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___20 *wb;
	struct inode___51 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct iov_iter___23 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___20 *bvec;
		struct pipe_inode_info___12 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct swap_info_struct___14 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___50 *bdev;
	struct file___50 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___50 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___51 *bd_inode;
	struct super_block___50 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___50 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___11 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___11 *bd_disk;
	struct request_queue___12 *bd_queue;
	struct backing_dev_info___20 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___49 {
	struct dentry___50 * (*lookup)(struct inode___51 *, struct dentry___50 *, unsigned int);
	const char * (*get_link)(struct dentry___50 *, struct inode___51 *, struct delayed_call *);
	int (*permission)(struct inode___51 *, int);
	struct posix_acl * (*get_acl)(struct inode___51 *, int);
	int (*readlink)(struct dentry___50 *, char *, int);
	int (*create)(struct inode___51 *, struct dentry___50 *, umode_t, bool);
	int (*link)(struct dentry___50 *, struct inode___51 *, struct dentry___50 *);
	int (*unlink)(struct inode___51 *, struct dentry___50 *);
	int (*symlink)(struct inode___51 *, struct dentry___50 *, const char *);
	int (*mkdir)(struct inode___51 *, struct dentry___50 *, umode_t);
	int (*rmdir)(struct inode___51 *, struct dentry___50 *);
	int (*mknod)(struct inode___51 *, struct dentry___50 *, umode_t, dev_t);
	int (*rename)(struct inode___51 *, struct dentry___50 *, struct inode___51 *, struct dentry___50 *, unsigned int);
	int (*setattr)(struct dentry___50 *, struct iattr___50 *);
	int (*getattr)(const struct path___49 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___50 *, char *, size_t);
	int (*fiemap)(struct inode___51 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___51 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___51 *, struct dentry___50 *, struct file___50 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___51 *, struct dentry___50 *, umode_t);
	int (*set_acl)(struct inode___51 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___49 {
	void (*fl_copy_lock)(struct file_lock___50 *, struct file_lock___50 *);
	void (*fl_release_private)(struct file_lock___50 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___49;

struct file_lock___50 {
	struct file_lock___50 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___50 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___49 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___49 *fl_ops;
	const struct lock_manager_operations___49 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___49 {
	int (*lm_compare_owner)(struct file_lock___50 *, struct file_lock___50 *);
	long unsigned int (*lm_owner_key)(struct file_lock___50 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___50 *);
	int (*lm_grant)(struct file_lock___50 *, int);
	bool (*lm_break)(struct file_lock___50 *);
	int (*lm_change)(struct file_lock___50 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___50 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___49 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___49 *fa_next;
	struct file___50 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___49 {
	const char *name;
	int fs_flags;
	struct dentry___50 * (*mount)(struct file_system_type___49 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___50 *);
	struct module___45 *owner;
	struct file_system_type___49 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___49 {
	struct inode___51 * (*alloc_inode)(struct super_block___50 *);
	void (*destroy_inode)(struct inode___51 *);
	void (*dirty_inode)(struct inode___51 *, int);
	int (*write_inode)(struct inode___51 *, struct writeback_control___19 *);
	int (*drop_inode)(struct inode___51 *);
	void (*evict_inode)(struct inode___51 *);
	void (*put_super)(struct super_block___50 *);
	int (*sync_fs)(struct super_block___50 *, int);
	int (*freeze_super)(struct super_block___50 *);
	int (*freeze_fs)(struct super_block___50 *);
	int (*thaw_super)(struct super_block___50 *);
	int (*unfreeze_fs)(struct super_block___50 *);
	int (*statfs)(struct dentry___50 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___50 *, int *, char *);
	void (*umount_begin)(struct super_block___50 *);
	int (*show_options)(struct seq_file___47 *, struct dentry___50 *);
	int (*show_devname)(struct seq_file___47 *, struct dentry___50 *);
	int (*show_path)(struct seq_file___47 *, struct dentry___50 *);
	int (*show_stats)(struct seq_file___47 *, struct dentry___50 *);
	ssize_t (*quota_read)(struct super_block___50 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___50 *, int, const char *, size_t, loff_t);
	struct dquot___49 ** (*get_dquots)(struct inode___51 *);
	int (*bdev_try_to_free_page)(struct super_block___50 *, struct page___50 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___50 *, struct shrink_control___19 *);
	long int (*free_cached_objects)(struct super_block___50 *, struct shrink_control___19 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___11 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___11 *last_lookup;
	struct hd_struct___11 *part[0];
};

struct block_device_operations___11 {
	int (*open)(struct block_device___50 *, fmode_t);
	void (*release)(struct gendisk___11 *, fmode_t);
	int (*rw_page)(struct block_device___50 *, sector_t, struct page___50 *, unsigned int);
	int (*ioctl)(struct block_device___50 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___50 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___11 *, unsigned int);
	int (*media_changed)(struct gendisk___11 *);
	void (*unlock_native_capacity)(struct gendisk___11 *);
	int (*revalidate_disk)(struct gendisk___11 *);
	int (*getgeo)(struct block_device___50 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___50 *, long unsigned int);
	int (*report_zones)(struct gendisk___11 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___45 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___49(struct page___50 *);

struct bdi_writeback_congested___20 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___20 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bsg_ops___11 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___12 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___12 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___12 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___11(struct request___12 *, blk_status_t);

struct request___12 {
	struct request_queue___12 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___20 *bio;
	struct bio___20 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___20 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___11 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___11 *saved_end_io;
		} flush;
	};
	struct gendisk___11 *rq_disk;
	struct hd_struct___11 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___11 *end_io;
	void *end_io_data;
	struct request___12 *next_rq;
};

struct elevator_type___11;

struct elevator_mq_ops___11 {
	int (*init_sched)(struct request_queue___12 *, struct elevator_type___11 *);
	void (*exit_sched)(struct elevator_queue___11 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	bool (*allow_merge)(struct request_queue___12 *, struct request___12 *, struct bio___20 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx *, struct bio___20 *);
	int (*request_merge)(struct request_queue___12 *, struct request___12 **, struct bio___20 *);
	void (*request_merged)(struct request_queue___12 *, struct request___12 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___12 *, struct request___12 *, struct request___12 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___12 *, struct bio___20 *);
	void (*finish_request)(struct request___12 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___12 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___12 *, u64);
	void (*started_request)(struct request___12 *);
	void (*requeue_request)(struct request___12 *);
	struct request___12 * (*former_request)(struct request_queue___12 *, struct request___12 *);
	struct request___12 * (*next_request)(struct request_queue___12 *, struct request___12 *);
	void (*init_icq)(struct io_cq___11 *);
	void (*exit_icq)(struct io_cq___11 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___11;

struct elevator_type___11 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___11 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___11 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___45 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___11 {
	struct elevator_type___11 *type;
	void *elevator_data;
	struct kobject___47 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___11 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___11 *, char *);
	ssize_t (*store)(struct elevator_queue___11 *, const char *, size_t);
};

enum cpufreq_table_sorting {
	CPUFREQ_TABLE_UNSORTED = 0,
	CPUFREQ_TABLE_SORTED_ASCENDING = 1,
	CPUFREQ_TABLE_SORTED_DESCENDING = 2,
};

struct cpufreq_cpuinfo {
	unsigned int max_freq;
	unsigned int min_freq;
	unsigned int transition_latency;
};

struct cpufreq_user_policy {
	unsigned int min;
	unsigned int max;
};

struct cpufreq_governor;

struct cpufreq_frequency_table;

struct cpufreq_stats;

struct cpufreq_policy {
	cpumask_var_t cpus;
	cpumask_var_t related_cpus;
	cpumask_var_t real_cpus;
	unsigned int shared_type;
	unsigned int cpu;
	struct clk *clk;
	struct cpufreq_cpuinfo cpuinfo;
	unsigned int min;
	unsigned int max;
	unsigned int cur;
	unsigned int restore_freq;
	unsigned int suspend_freq;
	unsigned int policy;
	unsigned int last_policy;
	struct cpufreq_governor *governor;
	void *governor_data;
	char last_governor[16];
	struct work_struct update;
	struct cpufreq_user_policy user_policy;
	struct cpufreq_frequency_table *freq_table;
	enum cpufreq_table_sorting freq_table_sorted;
	struct list_head policy_list;
	struct kobject___47 kobj;
	struct completion kobj_unregister;
	struct rw_semaphore___50 rwsem;
	bool fast_switch_possible;
	bool fast_switch_enabled;
	unsigned int transition_delay_us;
	bool dvfs_possible_from_any_cpu;
	unsigned int cached_target_freq;
	int cached_resolved_idx;
	bool transition_ongoing;
	spinlock_t transition_lock;
	wait_queue_head_t transition_wait;
	struct task_struct___2 *transition_task;
	struct cpufreq_stats *stats;
	void *driver_data;
};

struct cpufreq_governor {
	char name[16];
	int (*init)(struct cpufreq_policy *);
	void (*exit)(struct cpufreq_policy *);
	int (*start)(struct cpufreq_policy *);
	void (*stop)(struct cpufreq_policy *);
	void (*limits)(struct cpufreq_policy *);
	ssize_t (*show_setspeed)(struct cpufreq_policy *, char *);
	int (*store_setspeed)(struct cpufreq_policy *, unsigned int);
	bool dynamic_switching;
	struct list_head governor_list;
	struct module___45 *owner;
};

struct cpufreq_frequency_table {
	unsigned int flags;
	unsigned int driver_data;
	unsigned int frequency;
};

struct freq_attr {
	struct attribute attr;
	ssize_t (*show)(struct cpufreq_policy *, char *);
	ssize_t (*store)(struct cpufreq_policy *, const char *, size_t);
};

struct cpuidle_driver___3;

struct cpuidle_state___2 {
	char name[16];
	char desc[32];
	unsigned int flags;
	unsigned int exit_latency;
	int power_usage;
	unsigned int target_residency;
	bool disabled;
	int (*enter)(struct cpuidle_device *, struct cpuidle_driver___3 *, int);
	int (*enter_dead)(struct cpuidle_device *, int);
	void (*enter_s2idle)(struct cpuidle_device *, struct cpuidle_driver___3 *, int);
};

struct cpuidle_driver___3 {
	const char *name;
	struct module___45 *owner;
	int refcnt;
	unsigned int bctimer: 1;
	struct cpuidle_state___2 states[10];
	int state_count;
	int safe_state_index;
	struct cpumask *cpumask;
};

struct seq_operations___44 {
	void * (*start)(struct seq_file___47 *, loff_t *);
	void (*stop)(struct seq_file___47 *, void *);
	void * (*next)(struct seq_file___47 *, void *, loff_t *);
	int (*show)(struct seq_file___47 *, void *);
};

struct uts_namespace___11 {
	struct kref kref;
	struct new_utsname name;
	struct user_namespace___40 *user_ns;
	struct ucounts___40 *ucounts;
	struct ns_common___4 ns;
};

struct dst_ops___11 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___11 *);
	struct dst_entry___2 * (*check)(struct dst_entry___2 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___2 *);
	unsigned int (*mtu)(const struct dst_entry___2 *);
	u32 * (*cow_metrics)(struct dst_entry___2 *, long unsigned int);
	void (*destroy)(struct dst_entry___2 *);
	void (*ifdown)(struct dst_entry___2 *, struct net_device *, int);
	struct dst_entry___2 * (*negative_advice)(struct dst_entry___2 *);
	void (*link_failure)(struct sk_buff___9 *);
	void (*update_pmtu)(struct dst_entry___2 *, struct sock *, struct sk_buff___9 *, u32);
	void (*redirect)(struct dst_entry___2 *, struct sock *, struct sk_buff___9 *);
	int (*local_out)(struct net___13 *, struct sock *, struct sk_buff___9 *);
	struct neighbour___2 * (*neigh_lookup)(const struct dst_entry___2 *, struct sk_buff___9 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___2 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___10 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___5 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___11 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct sock *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops *notifier_ops;
	struct fib_notifier_ops *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_xfrm___10 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___11 xfrm4_dst_ops;
	struct dst_ops___11 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct net___13 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___40 *user_ns;
	struct ucounts___40 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___4 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___5 ipv4;
	struct netns_ipv6___10 ipv6;
	struct netns_sctp___2 sctp;
	struct netns_nf nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___5 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock *nfnl;
	struct sock *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___10 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cgroup_namespace___38 {
	refcount_t count;
	struct ns_common___4 ns;
	struct user_namespace___40 *user_ns;
	struct ucounts___40 *ucounts;
	struct css_set___38 *root_cset;
};

struct ucounts___40 {
	struct hlist_node node;
	struct user_namespace___40 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct kernel_param_ops___42 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___42 *);
	int (*get)(char *, const struct kernel_param___42 *);
	void (*free)(void *);
};

struct kparam_array___42;

struct kernel_param___42 {
	const char *name;
	struct module___45 *mod;
	const struct kernel_param_ops___42 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___42 *arr;
	};
};

struct kparam_array___42 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___42 *ops;
	void *elem;
};

struct module_attribute___42 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___42 *, struct module_kobject___42 *, char *);
	ssize_t (*store)(struct module_attribute___42 *, struct module_kobject___42 *, const char *, size_t);
	void (*setup)(struct module___45 *, const char *);
	int (*test)(struct module___45 *);
	void (*free)(struct module___45 *);
};

struct trace_event_class___26;

struct trace_event_call___26 {
	struct list_head list;
	struct trace_event_class___26 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___4 *prog_array;
	int (*perf_perm)(struct trace_event_call___26 *, struct perf_event___31 *);
};

struct pipe_buf_operations___12;

struct pipe_buffer___12 {
	struct page___50 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___12 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___12 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___12 *, struct pipe_buffer___12 *);
	void (*release)(struct pipe_inode_info___12 *, struct pipe_buffer___12 *);
	int (*steal)(struct pipe_inode_info___12 *, struct pipe_buffer___12 *);
	union {
		bool (*get)(struct pipe_inode_info___12 *, struct pipe_buffer___12 *);
		struct {
			void (*get)(struct pipe_inode_info___12 *, struct pipe_buffer___12 *);
		} __UNIQUE_ID_rh_kabi_hide61;
		union {		};
	};
};

struct kthread_work___38;

typedef void (*kthread_work_func_t___38)(struct kthread_work___38 *);

struct kthread_worker___38;

struct kthread_work___38 {
	struct list_head node;
	kthread_work_func_t___38 func;
	struct kthread_worker___38 *worker;
	int canceling;
};

struct kthread_worker___38 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___2 *task;
	struct kthread_work___38 *current_work;
};

struct kthread_delayed_work___38 {
	struct kthread_work___38 work;
	struct timer_list timer;
};

struct bpf_map___38;

struct bpf_map_ops___38 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___38 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___38 *, struct file___50 *);
	void (*map_free)(struct bpf_map___38 *);
	int (*map_get_next_key)(struct bpf_map___38 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___38 *);
	void * (*map_lookup_elem)(struct bpf_map___38 *, void *);
	int (*map_update_elem)(struct bpf_map___38 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___38 *, void *);
	int (*map_push_elem)(struct bpf_map___38 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___38 *, void *);
	int (*map_peek_elem)(struct bpf_map___38 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___38 *, struct file___50 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___38 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___38 *, void *, struct seq_file___47 *);
	int (*map_check_btf)(const struct bpf_map___38 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___38 {
	const struct bpf_map_ops___38 *ops;
	struct bpf_map___38 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___49 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct psi_group___38 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___38 *poll_kworker;
	struct kthread_delayed_work___38 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

enum {
	CFTYPE_ONLY_ON_ROOT = 1,
	CFTYPE_NOT_ON_ROOT = 2,
	CFTYPE_NS_DELEGATABLE = 4,
	CFTYPE_NO_PREFIX = 8,
	CFTYPE_WORLD_WRITABLE = 16,
	CFTYPE_DEBUG = 32,
	__CFTYPE_ONLY_ON_DFL = 65536,
	__CFTYPE_NOT_ON_DFL = 131072,
};

struct cgroup_root___38;

struct cgroup_rstat_cpu___38;

struct cgroup___38 {
	struct cgroup_subsys_state___38 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___47 *kn;
	struct cgroup_file___38 procs_file;
	struct cgroup_file___38 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___38 *subsys[13];
	struct cgroup_root___38 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___38 *dom_cgrp;
	struct cgroup_rstat_cpu___38 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___4 bpf;
	atomic_t congestion_count;
	struct cgroup___38 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___38 psi;
	int ancestor_ids[0];
};

struct cftype___38;

struct cgroup_subsys___38 {
	struct cgroup_subsys_state___38 * (*css_alloc)(struct cgroup_subsys_state___38 *);
	int (*css_online)(struct cgroup_subsys_state___38 *);
	void (*css_offline)(struct cgroup_subsys_state___38 *);
	void (*css_released)(struct cgroup_subsys_state___38 *);
	void (*css_free)(struct cgroup_subsys_state___38 *);
	void (*css_reset)(struct cgroup_subsys_state___38 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___38 *, int);
	int (*css_extra_stat_show)(struct seq_file___47 *, struct cgroup_subsys_state___38 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___2 *);
	void (*cancel_fork)(struct task_struct___2 *);
	void (*fork)(struct task_struct___2 *);
	void (*exit)(struct task_struct___2 *);
	void (*free)(struct task_struct___2 *);
	void (*bind)(struct cgroup_subsys_state___38 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___38 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___38 *dfl_cftypes;
	struct cftype___38 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___38 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___38 *updated_children;
	struct cgroup___38 *updated_next;
};

struct cgroup_root___38 {
	struct kernfs_root___47 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___38 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___38 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___38 *ss;
	struct list_head node;
	struct kernfs_ops___47 *kf_ops;
	int (*open)(struct kernfs_open_file___47 *);
	void (*release)(struct kernfs_open_file___47 *);
	u64 (*read_u64)(struct cgroup_subsys_state___38 *, struct cftype___38 *);
	s64 (*read_s64)(struct cgroup_subsys_state___38 *, struct cftype___38 *);
	int (*seq_show)(struct seq_file___47 *, void *);
	void * (*seq_start)(struct seq_file___47 *, loff_t *);
	void * (*seq_next)(struct seq_file___47 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___47 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___38 *, struct cftype___38 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___38 *, struct cftype___38 *, s64);
	ssize_t (*write)(struct kernfs_open_file___47 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___47 *, struct poll_table_struct___32 *);
};

struct hstate___8 {
	int next_nid_to_alloc;
	int next_nid_to_free;
	unsigned int order;
	long unsigned int mask;
	long unsigned int max_huge_pages;
	long unsigned int nr_huge_pages;
	long unsigned int free_huge_pages;
	long unsigned int resv_huge_pages;
	long unsigned int surplus_huge_pages;
	long unsigned int nr_overcommit_huge_pages;
	struct list_head hugepage_activelist;
	struct list_head hugepage_freelists[8];
	unsigned int nr_huge_pages_node[8];
	unsigned int free_huge_pages_node[8];
	unsigned int surplus_huge_pages_node[8];
	struct cftype___38 cgroup_files[5];
	char name[32];
};

enum migrate_reason {
	MR_COMPACTION = 0,
	MR_MEMORY_FAILURE = 1,
	MR_MEMORY_HOTPLUG = 2,
	MR_SYSCALL = 3,
	MR_MEMPOLICY_MBIND = 4,
	MR_NUMA_MISPLACED = 5,
	MR_CONTIG_RANGE = 6,
	MR_TYPES = 7,
};

struct rcu_synchronize {
	struct callback_head head;
	struct completion completion;
};

struct node___40 {
	struct device___43 dev;
};

typedef int (*cpu_stop_fn_t)(void *);

struct cpu_stop_done;

struct cpu_stop_work {
	struct list_head list;
	cpu_stop_fn_t fn;
	void *arg;
	struct cpu_stop_done *done;
};

struct mem_cgroup_reclaim_iter___19 {
	struct mem_cgroup___19 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___19 {
	struct lruvec___49 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___19 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___19 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct perf_cpu_context___31;

struct pmu___31 {
	struct list_head entry;
	struct module___45 *module;
	struct device___43 *dev;
	const struct attribute_group___44 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___31 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___31 *);
	void (*pmu_disable)(struct pmu___31 *);
	int (*event_init)(struct perf_event___31 *);
	void (*event_mapped)(struct perf_event___31 *, struct mm_struct___49 *);
	void (*event_unmapped)(struct perf_event___31 *, struct mm_struct___49 *);
	int (*add)(struct perf_event___31 *, int);
	void (*del)(struct perf_event___31 *, int);
	void (*start)(struct perf_event___31 *, int);
	void (*stop)(struct perf_event___31 *, int);
	void (*read)(struct perf_event___31 *);
	void (*start_txn)(struct pmu___31 *, unsigned int);
	int (*commit_txn)(struct pmu___31 *);
	void (*cancel_txn)(struct pmu___31 *);
	int (*event_idx)(struct perf_event___31 *);
	void (*sched_task)(struct perf_event_context___31 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___31 *);
	int (*filter_match)(struct perf_event___31 *);
	int (*check_period)(struct perf_event___31 *, u64);
};

struct perf_cpu_context___31 {
	struct perf_event_context___31 ctx;
	struct perf_event_context___31 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___31 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___31 {
	struct cgroup_subsys_state___38 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___26 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___26 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___26 *);
	struct list_head * (*get_fields)(struct trace_event_call___26 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___26 *);
};

struct trace_event_file___10;

struct trace_event_buffer___10 {
	struct ring_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___10 *trace_file;
	void *entry;
	long unsigned int flags;
	int pc;
};

struct trace_event_file___10 {
	struct list_head list;
	struct trace_event_call___26 *event_call;
	struct event_filter *filter;
	struct dentry___50 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct syscall_metadata___13 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___26 *enter_event;
	struct trace_event_call___26 *exit_event;
};

struct cpupri_vec {
	atomic_t count;
	cpumask_var_t mask;
};

struct cpupri {
	struct cpupri_vec pri_to_cpu[102];
	int *cpu_to_pri;
};

struct cpudl_item {
	u64 dl;
	int cpu;
	int idx;
};

struct cpudl {
	raw_spinlock_t lock;
	int size;
	cpumask_var_t free_cpus;
	struct cpudl_item *elements;
};

struct dl_bandwidth {
	raw_spinlock_t dl_runtime_lock;
	u64 dl_runtime;
	u64 dl_period;
};

struct dl_bw {
	raw_spinlock_t lock;
	u64 bw;
	u64 total_bw;
};

typedef int (*tg_visitor)(struct task_group *, void *);

struct dl_rq {
	struct rb_root_cached root;
	long unsigned int dl_nr_running;
	struct {
		u64 curr;
		u64 next;
	} earliest_dl;
	long unsigned int dl_nr_migratory;
	int overloaded;
	struct rb_root_cached pushable_dl_tasks_root;
	u64 running_bw;
	u64 this_bw;
	u64 extra_bw;
	u64 bw_ratio;
};

struct root_domain;

struct rq {
	raw_spinlock_t lock;
	unsigned int nr_running;
	unsigned int nr_numa_running;
	unsigned int nr_preferred_running;
	long unsigned int cpu_load[5];
	long unsigned int last_load_update_tick;
	long unsigned int last_blocked_load_update_tick;
	unsigned int has_blocked_load;
	unsigned int nohz_tick_stopped;
	atomic_t nohz_flags;
	struct load_weight load;
	long unsigned int nr_load_updates;
	u64 nr_switches;
	long: 64;
	struct cfs_rq cfs;
	struct rt_rq rt;
	struct dl_rq dl;
	struct list_head leaf_cfs_rq_list;
	struct list_head *tmp_alone_branch;
	long unsigned int nr_uninterruptible;
	struct task_struct___2 *curr;
	struct task_struct___2 *idle;
	struct task_struct___2 *stop;
	long unsigned int next_balance;
	struct mm_struct___49 *prev_mm;
	unsigned int clock_update_flags;
	u64 clock;
	u64 clock_task;
	atomic_t nr_iowait;
	struct root_domain *rd;
	struct sched_domain *sd;
	long unsigned int cpu_capacity;
	long unsigned int cpu_capacity_orig;
	struct callback_head *balance_callback;
	unsigned char idle_balance;
	int active_balance;
	int push_cpu;
	struct cpu_stop_work active_balance_work;
	int cpu;
	int online;
	struct list_head cfs_tasks;
	u64 rh_reserved_rt_avg;
	u64 rh_reserved_age_stamp;
	u64 idle_stamp;
	u64 avg_idle;
	u64 max_idle_balance_cost;
	u64 prev_steal_time;
	u64 prev_steal_time_rq;
	long unsigned int calc_load_update;
	long int calc_load_active;
	int hrtick_csd_pending;
	long: 32;
	long: 64;
	call_single_data_t hrtick_csd;
	struct hrtimer hrtick_timer;
	struct sched_info rq_sched_info;
	long long unsigned int rq_cpu_time;
	unsigned int yld_count;
	unsigned int sched_count;
	unsigned int sched_goidle;
	unsigned int ttwu_count;
	unsigned int ttwu_local;
	struct llist_head wake_list;
	struct cpuidle_state___2 *idle_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	unsigned int numa_migrate_on;
	long: 32;
	long: 64;
	struct sched_avg avg_rt;
	struct sched_avg avg_dl;
	struct sched_avg avg_irq;
};

struct root_domain {
	atomic_t refcount;
	atomic_t rto_count;
	struct callback_head rcu;
	cpumask_var_t span;
	cpumask_var_t online;
	bool overload;
	cpumask_var_t dlo_mask;
	atomic_t dlo_count;
	struct dl_bw dl_bw;
	struct cpudl cpudl;
	struct irq_work rto_push_work;
	raw_spinlock_t rto_lock;
	int rto_loop;
	int rto_cpu;
	atomic_t rto_loop_next;
	atomic_t rto_loop_start;
	cpumask_var_t rto_mask;
	struct cpupri cpupri;
	long unsigned int max_cpu_capacity;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct rq_flags {
	long unsigned int flags;
	struct pin_cookie cookie;
	unsigned int clock_update_flags;
};

enum numa_topology_type {
	NUMA_DIRECT = 0,
	NUMA_GLUELESS_MESH = 1,
	NUMA_BACKPLANE = 2,
};

enum {
	__SCHED_FEAT_GENTLE_FAIR_SLEEPERS = 0,
	__SCHED_FEAT_START_DEBIT = 1,
	__SCHED_FEAT_NEXT_BUDDY = 2,
	__SCHED_FEAT_LAST_BUDDY = 3,
	__SCHED_FEAT_CACHE_HOT_BUDDY = 4,
	__SCHED_FEAT_WAKEUP_PREEMPTION = 5,
	__SCHED_FEAT_HRTICK = 6,
	__SCHED_FEAT_DOUBLE_TICK = 7,
	__SCHED_FEAT_LB_BIAS = 8,
	__SCHED_FEAT_NONTASK_CAPACITY = 9,
	__SCHED_FEAT_TTWU_QUEUE = 10,
	__SCHED_FEAT_SIS_AVG_CPU = 11,
	__SCHED_FEAT_SIS_PROP = 12,
	__SCHED_FEAT_WARN_DOUBLE_CLOCK = 13,
	__SCHED_FEAT_RT_PUSH_IPI = 14,
	__SCHED_FEAT_RT_RUNTIME_SHARE = 15,
	__SCHED_FEAT_LB_MIN = 16,
	__SCHED_FEAT_ATTACH_AGE_LOAD = 17,
	__SCHED_FEAT_WA_IDLE = 18,
	__SCHED_FEAT_WA_WEIGHT = 19,
	__SCHED_FEAT_WA_BIAS = 20,
	__SCHED_FEAT_UTIL_EST = 21,
	__SCHED_FEAT_NR = 22,
};

struct trace_event_raw_sched_kthread_stop {
	struct trace_entry ent;
	char comm[16];
	pid_t pid;
	char __data[0];
};

struct trace_event_raw_sched_kthread_stop_ret {
	struct trace_entry ent;
	int ret;
	char __data[0];
};

struct trace_event_raw_sched_wakeup_template {
	struct trace_entry ent;
	char comm[16];
	pid_t pid;
	int prio;
	int success;
	int target_cpu;
	char __data[0];
};

struct trace_event_raw_sched_switch {
	struct trace_entry ent;
	char prev_comm[16];
	pid_t prev_pid;
	int prev_prio;
	long int prev_state;
	char next_comm[16];
	pid_t next_pid;
	int next_prio;
	char __data[0];
};

struct trace_event_raw_sched_migrate_task {
	struct trace_entry ent;
	char comm[16];
	pid_t pid;
	int prio;
	int orig_cpu;
	int dest_cpu;
	char __data[0];
};

struct trace_event_raw_sched_process_template {
	struct trace_entry ent;
	char comm[16];
	pid_t pid;
	int prio;
	char __data[0];
};

struct trace_event_raw_sched_process_wait {
	struct trace_entry ent;
	char comm[16];
	pid_t pid;
	int prio;
	char __data[0];
};

struct trace_event_raw_sched_process_fork {
	struct trace_entry ent;
	char parent_comm[16];
	pid_t parent_pid;
	char child_comm[16];
	pid_t child_pid;
	char __data[0];
};

struct trace_event_raw_sched_process_exec {
	struct trace_entry ent;
	u32 __data_loc_filename;
	pid_t pid;
	pid_t old_pid;
	char __data[0];
};

struct trace_event_raw_sched_stat_template {
	struct trace_entry ent;
	char comm[16];
	pid_t pid;
	u64 delay;
	char __data[0];
};

struct trace_event_raw_sched_stat_runtime {
	struct trace_entry ent;
	char comm[16];
	pid_t pid;
	u64 runtime;
	u64 vruntime;
	char __data[0];
};

struct trace_event_raw_sched_pi_setprio {
	struct trace_entry ent;
	char comm[16];
	pid_t pid;
	int oldprio;
	int newprio;
	char __data[0];
};

struct trace_event_raw_sched_process_hang {
	struct trace_entry ent;
	char comm[16];
	pid_t pid;
	char __data[0];
};

struct trace_event_raw_sched_move_task_template {
	struct trace_entry ent;
	pid_t pid;
	pid_t tgid;
	pid_t ngid;
	int src_cpu;
	int src_nid;
	int dst_cpu;
	int dst_nid;
	char __data[0];
};

struct trace_event_raw_sched_swap_numa {
	struct trace_entry ent;
	pid_t src_pid;
	pid_t src_tgid;
	pid_t src_ngid;
	int src_cpu;
	int src_nid;
	pid_t dst_pid;
	pid_t dst_tgid;
	pid_t dst_ngid;
	int dst_cpu;
	int dst_nid;
	char __data[0];
};

struct trace_event_raw_sched_wake_idle_without_ipi {
	struct trace_entry ent;
	int cpu;
	char __data[0];
};

struct trace_event_data_offsets_sched_kthread_stop {};

struct trace_event_data_offsets_sched_kthread_stop_ret {};

struct trace_event_data_offsets_sched_wakeup_template {};

struct trace_event_data_offsets_sched_switch {};

struct trace_event_data_offsets_sched_migrate_task {};

struct trace_event_data_offsets_sched_process_template {};

struct trace_event_data_offsets_sched_process_wait {};

struct trace_event_data_offsets_sched_process_fork {};

struct trace_event_data_offsets_sched_process_exec {
	u32 filename;
};

struct trace_event_data_offsets_sched_stat_template {};

struct trace_event_data_offsets_sched_stat_runtime {};

struct trace_event_data_offsets_sched_pi_setprio {};

struct trace_event_data_offsets_sched_process_hang {};

struct trace_event_data_offsets_sched_move_task_template {};

struct trace_event_data_offsets_sched_swap_numa {};

struct trace_event_data_offsets_sched_wake_idle_without_ipi {};

struct migration_arg {
	struct task_struct___2 *task;
	int dest_cpu;
};

struct migration_swap_arg {
	struct task_struct___2 *src_task;
	struct task_struct___2 *dst_task;
	int src_cpu;
	int dst_cpu;
};

struct tick_work {
	int cpu;
	struct delayed_work work;
};

struct cfs_schedulable_data {
	struct task_group *tg;
	u64 period;
	u64 quota;
};

enum {
	cpuset = 0,
	possible = 1,
	fail = 2,
};

struct pm_qos_constraints___3 {
	struct plist_head list;
	s32 target_value;
	s32 default_value;
	s32 no_constraint_value;
	enum pm_qos_type type;
	struct blocking_notifier_head___49 *notifiers;
};

struct dev_pm_qos_request___3;

struct dev_pm_qos {
	struct pm_qos_constraints___3 resume_latency;
	struct pm_qos_constraints___3 latency_tolerance;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___3 *resume_latency_req;
	struct dev_pm_qos_request___3 *latency_tolerance_req;
	struct dev_pm_qos_request___3 *flags_req;
};

struct dev_pm_qos_request___3 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___43 *dev;
};

struct idle_timer {
	struct hrtimer timer;
	int done;
};

struct numa_group {
	atomic_t refcount;
	spinlock_t lock;
	int nr_tasks;
	pid_t gid;
	int active_nodes;
	struct callback_head rcu;
	long unsigned int total_faults;
	long unsigned int max_faults_cpu;
	long unsigned int *faults_cpu;
	long unsigned int faults[0];
};

enum tick_dep_bits {
	TICK_DEP_BIT_POSIX_TIMER = 0,
	TICK_DEP_BIT_PERF_EVENTS = 1,
	TICK_DEP_BIT_SCHED = 2,
	TICK_DEP_BIT_CLOCK_UNSTABLE = 3,
};

enum numa_faults_stats {
	NUMA_MEM = 0,
	NUMA_CPU = 1,
	NUMA_MEMBUF = 2,
	NUMA_CPUBUF = 3,
};

struct numa_stats {
	long unsigned int load;
	long unsigned int compute_capacity;
	unsigned int nr_running;
};

struct task_numa_env {
	struct task_struct___2 *p;
	int src_cpu;
	int src_nid;
	int dst_cpu;
	int dst_nid;
	struct numa_stats src_stats;
	struct numa_stats dst_stats;
	int imbalance_pct;
	int dist;
	struct task_struct___2 *best_task;
	long int best_imp;
	int best_cpu;
};

enum fbq_type {
	regular = 0,
	remote = 1,
	all = 2,
};

struct lb_env {
	struct sched_domain *sd;
	struct rq *src_rq;
	int src_cpu;
	int dst_cpu;
	struct rq *dst_rq;
	struct cpumask *dst_grpmask;
	int new_dst_cpu;
	enum cpu_idle_type idle;
	long int imbalance;
	struct cpumask *cpus;
	unsigned int flags;
	unsigned int loop;
	unsigned int loop_break;
	unsigned int loop_max;
	enum fbq_type fbq_type;
	struct list_head tasks;
};

enum group_type {
	group_other = 0,
	group_imbalanced = 1,
	group_overloaded = 2,
};

struct sg_lb_stats {
	long unsigned int avg_load;
	long unsigned int group_load;
	long unsigned int sum_weighted_load;
	long unsigned int load_per_task;
	long unsigned int group_capacity;
	long unsigned int group_util;
	unsigned int sum_nr_running;
	unsigned int idle_cpus;
	unsigned int group_weight;
	enum group_type group_type;
	int group_no_capacity;
	unsigned int nr_numa_running;
	unsigned int nr_preferred_running;
};

struct sd_lb_stats {
	struct sched_group *busiest;
	struct sched_group *local;
	long unsigned int total_running;
	long unsigned int total_load;
	long unsigned int total_capacity;
	long unsigned int avg_load;
	struct sg_lb_stats busiest_stat;
	struct sg_lb_stats local_stat;
};

typedef struct task_group *rt_rq_iter_t;

struct rt_schedulable_data {
	struct task_group *tg;
	u64 rt_period;
	u64 rt_runtime;
};

struct wait_bit_key {
	void *flags;
	int bit_nr;
	long unsigned int timeout;
};

struct wait_bit_queue_entry {
	struct wait_bit_key key;
	struct wait_queue_entry wq_entry;
};

typedef int wait_bit_action_f(struct wait_bit_key *, int);

struct swait_queue___2 {
	struct task_struct___2 *task;
	struct list_head task_list;
};

struct sched_domain_attr {
	int relax_domain_level;
};

typedef const struct cpumask * (*sched_domain_mask_f)(int);

typedef int (*sched_domain_flags_f)();

struct sd_data {
	struct sched_domain **sd;
	struct sched_domain_shared **sds;
	struct sched_group **sg;
	struct sched_group_capacity **sgc;
};

struct sched_domain_topology_level {
	sched_domain_mask_f mask;
	sched_domain_flags_f sd_flags;
	int flags;
	int numa_level;
	struct sd_data data;
	char *name;
};

struct s_data {
	struct sched_domain **sd;
	struct root_domain *rd;
};

enum s_alloc {
	sa_rootdomain = 0,
	sa_sd = 1,
	sa_sd_storage = 2,
	sa_none = 3,
};

enum cpuacct_stat_index {
	CPUACCT_STAT_USER = 0,
	CPUACCT_STAT_SYSTEM = 1,
	CPUACCT_STAT_NSTATS = 2,
};

struct cpuacct_usage {
	u64 usages[2];
};

struct cpuacct {
	struct cgroup_subsys_state___38 css;
	struct cpuacct_usage *cpuusage;
	struct kernel_cpustat *cpustat;
};

enum {
	MEMBARRIER_FLAG_SYNC_CORE = 1,
};

enum membarrier_cmd {
	MEMBARRIER_CMD_QUERY = 0,
	MEMBARRIER_CMD_GLOBAL = 1,
	MEMBARRIER_CMD_GLOBAL_EXPEDITED = 2,
	MEMBARRIER_CMD_REGISTER_GLOBAL_EXPEDITED = 4,
	MEMBARRIER_CMD_PRIVATE_EXPEDITED = 8,
	MEMBARRIER_CMD_REGISTER_PRIVATE_EXPEDITED = 16,
	MEMBARRIER_CMD_PRIVATE_EXPEDITED_SYNC_CORE = 32,
	MEMBARRIER_CMD_REGISTER_PRIVATE_EXPEDITED_SYNC_CORE = 64,
	MEMBARRIER_CMD_SHARED = 1,
};

struct module___46;

struct file___51;

struct kiocb___51;

struct iov_iter___24;

struct poll_table_struct___33;

struct vm_area_struct___51;

struct inode___52;

struct file_lock___51;

struct page___51;

struct pipe_inode_info___13;

struct seq_file___48;

struct file_operations___51 {
	struct module___46 *owner;
	loff_t (*llseek)(struct file___51 *, loff_t, int);
	ssize_t (*read)(struct file___51 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___51 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___51 *, struct iov_iter___24 *);
	ssize_t (*write_iter)(struct kiocb___51 *, struct iov_iter___24 *);
	int (*iopoll)(struct kiocb___51 *, bool);
	int (*iterate)(struct file___51 *, struct dir_context *);
	int (*iterate_shared)(struct file___51 *, struct dir_context *);
	__poll_t (*poll)(struct file___51 *, struct poll_table_struct___33 *);
	long int (*unlocked_ioctl)(struct file___51 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___51 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___51 *, struct vm_area_struct___51 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___52 *, struct file___51 *);
	int (*flush)(struct file___51 *, fl_owner_t);
	int (*release)(struct inode___52 *, struct file___51 *);
	int (*fsync)(struct file___51 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___51 *, int);
	int (*lock)(struct file___51 *, int, struct file_lock___51 *);
	ssize_t (*sendpage)(struct file___51 *, struct page___51 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___51 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___51 *, int, struct file_lock___51 *);
	ssize_t (*splice_write)(struct pipe_inode_info___13 *, struct file___51 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___51 *, loff_t *, struct pipe_inode_info___13 *, size_t, unsigned int);
	int (*setlease)(struct file___51 *, long int, struct file_lock___51 **, void **);
	long int (*fallocate)(struct file___51 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___48 *, struct file___51 *);
	ssize_t (*copy_file_range)(struct file___51 *, loff_t, struct file___51 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___51 *, loff_t, struct file___51 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___51 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cfs_rq___2;

struct sched_entity___2 {
	struct load_weight load;
	long unsigned int runnable_weight;
	struct rb_node run_node;
	struct list_head group_node;
	unsigned int on_rq;
	u64 exec_start;
	u64 sum_exec_runtime;
	u64 vruntime;
	u64 prev_sum_exec_runtime;
	u64 nr_migrations;
	struct sched_statistics statistics;
	int depth;
	struct sched_entity___2 *parent;
	struct cfs_rq___2 *cfs_rq;
	struct cfs_rq___2 *my_q;
	long: 64;
	long: 64;
	long: 64;
	struct sched_avg avg;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rt_rq___2;

struct sched_rt_entity___2 {
	struct list_head run_list;
	long unsigned int timeout;
	long unsigned int watchdog_stamp;
	unsigned int time_slice;
	short unsigned int on_rq;
	short unsigned int on_list;
	struct sched_rt_entity___2 *back;
	struct sched_rt_entity___2 *parent;
	struct rt_rq___2 *rt_rq;
	struct rt_rq___2 *my_q;
};

struct vmacache___50 {
	u64 seqnum;
	struct vm_area_struct___51 *vmas[4];
};

struct page_frag___50 {
	struct page___51 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___32;

struct debug_info___32 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___32 *hbp_break[16];
	struct perf_event___32 *hbp_watch[16];
};

struct thread_struct___32 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___32 debug;
	long: 64;
};

struct sched_class___2;

struct task_group___2;

struct mm_struct___50;

struct mem_cgroup___20;

struct pid___46;

struct cred___50;

struct nsproxy___49;

struct signal_struct___48;

struct bio_list___21;

struct backing_dev_info___21;

struct io_context___12;

struct css_set___39;

struct perf_event_context___32;

struct request_queue___13;

struct vm_struct___40;

struct task_struct___51 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___51 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class___2 *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group___2 *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___50 *mm;
	struct mm_struct___50 *active_mm;
	struct vmacache___50 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___51 *real_parent;
	struct task_struct___51 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___51 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___20 *active_memcg;
	long int rh_reserved2;
	struct pid___46 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___46 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___46 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___50 *ptracer_cred;
	const struct cred___50 *real_cred;
	const struct cred___50 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___49 *nsproxy;
	struct signal_struct___48 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___51 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___21 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___21 *backing_dev_info;
	struct io_context___12 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___39 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___32 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___13 *splice_pipe;
	struct page_frag___50 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___20 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___13 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___51 *oom_reaper_list;
	struct vm_struct___40 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___32 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___32 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___51 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___32)(struct perf_event___32 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___32;

struct fasync_struct___50;

struct pid_namespace___46;

struct trace_event_call___27;

struct perf_cgroup___32;

struct perf_event___32 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___32 *group_leader;
	struct pmu___32 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___32 hw;
	struct perf_event_context___32 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___32 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___51 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___50 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___32 *);
	struct callback_head callback_head;
	struct pid_namespace___46 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___32 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___32 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___27 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___32 *cgrp;
	struct list_head sb_list;
};

struct secondary_data___51 {
	void *stack;
	struct task_struct___51 *task;
	long int status;
};

struct clock_event_device___9;

struct arch_timer_erratum_workaround___9 {
	enum arch_timer_erratum_match_type match_type;
	const void *id;
	const char *desc;
	u32 (*read_cntp_tval_el0)();
	u32 (*read_cntv_tval_el0)();
	u64 (*read_cntpct_el0)();
	u64 (*read_cntvct_el0)();
	int (*set_next_event_phys)(long unsigned int, struct clock_event_device___9 *);
	int (*set_next_event_virt)(long unsigned int, struct clock_event_device___9 *);
};

struct clock_event_device___9 {
	void (*event_handler)(struct clock_event_device___9 *);
	int (*set_next_event)(long unsigned int, struct clock_event_device___9 *);
	int (*set_next_ktime)(ktime_t, struct clock_event_device___9 *);
	ktime_t next_event;
	u64 max_delta_ns;
	u64 min_delta_ns;
	u32 mult;
	u32 shift;
	enum clock_event_state state_use_accessors;
	unsigned int features;
	long unsigned int retries;
	int (*set_state_periodic)(struct clock_event_device___9 *);
	int (*set_state_oneshot)(struct clock_event_device___9 *);
	int (*set_state_oneshot_stopped)(struct clock_event_device___9 *);
	int (*set_state_shutdown)(struct clock_event_device___9 *);
	int (*tick_resume)(struct clock_event_device___9 *);
	void (*broadcast)(const struct cpumask *);
	void (*suspend)(struct clock_event_device___9 *);
	void (*resume)(struct clock_event_device___9 *);
	long unsigned int min_delta_ticks;
	long unsigned int max_delta_ticks;
	const char *name;
	int rating;
	int irq;
	int bound_on;
	const struct cpumask *cpumask;
	struct list_head list;
	struct module___46 *owner;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct upid___46 {
	int nr;
	struct pid_namespace___46 *ns;
};

struct dentry___51;

struct user_namespace___41;

struct ucounts___41;

struct pid_namespace___46 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___51 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___46 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___51 *proc_self;
	struct dentry___51 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___41 *user_ns;
	struct ucounts___41 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___4 ns;
};

struct pid___46 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___46 numbers[1];
};

struct rw_semaphore___51 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___51 *owner;
};

struct key___51;

struct user_namespace___41 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___41 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___4 ns;
	long unsigned int flags;
	struct key___51 *persistent_keyring_register;
	struct rw_semaphore___51 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___41 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___51 *pgtable_t___50;

struct address_space___50;

struct dev_pagemap___50;

struct page___51 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___50 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___51 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___50 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___50 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___50 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___20 *mem_cgroup;
};

struct user_struct___50 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___51 *uid_keyring;
	struct key___51 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___50;

struct vm_area_struct___51 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___51 *vm_next;
	struct vm_area_struct___51 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___50 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___50 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___51 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct rq___2;

struct cfs_rq___2 {
	struct load_weight load;
	long unsigned int runnable_weight;
	unsigned int nr_running;
	unsigned int h_nr_running;
	u64 exec_clock;
	u64 min_vruntime;
	struct rb_root_cached tasks_timeline;
	struct sched_entity___2 *curr;
	struct sched_entity___2 *next;
	struct sched_entity___2 *last;
	struct sched_entity___2 *skip;
	unsigned int nr_spread_over;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	struct sched_avg avg;
	struct {
		raw_spinlock_t lock;
		int nr;
		long unsigned int load_avg;
		long unsigned int util_avg;
		long unsigned int runnable_sum;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	} removed;
	long unsigned int tg_load_avg_contrib;
	long int propagate;
	long int prop_runnable_sum;
	long unsigned int h_load;
	u64 last_h_load_update;
	struct sched_entity___2 *h_load_next;
	struct rq___2 *rq;
	int on_list;
	struct list_head leaf_cfs_rq_list;
	struct task_group___2 *tg;
	int runtime_enabled;
	int rh_reserved_expires_seq;
	u64 rh_reserved_runtime_expires;
	s64 runtime_remaining;
	u64 throttled_clock;
	u64 throttled_clock_task;
	u64 throttled_clock_task_time;
	int throttled;
	int throttle_count;
	struct list_head throttled_list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long: 64;
	long: 64;
};

struct rt_rq___2 {
	struct rt_prio_array active;
	unsigned int rt_nr_running;
	unsigned int rr_nr_running;
	struct {
		int curr;
		int next;
	} highest_prio;
	long unsigned int rt_nr_migratory;
	long unsigned int rt_nr_total;
	int overloaded;
	struct plist_head pushable_tasks;
	int rt_queued;
	int rt_throttled;
	u64 rt_time;
	u64 rt_runtime;
	raw_spinlock_t rt_runtime_lock;
	long unsigned int rt_nr_boosted;
	struct rq___2 *rq;
	struct task_group___2 *tg;
};

struct sched_class___2 {
	const struct sched_class___2 *next;
	void (*enqueue_task)(struct rq___2 *, struct task_struct___51 *, int);
	void (*dequeue_task)(struct rq___2 *, struct task_struct___51 *, int);
	void (*yield_task)(struct rq___2 *);
	bool (*yield_to_task)(struct rq___2 *, struct task_struct___51 *, bool);
	void (*check_preempt_curr)(struct rq___2 *, struct task_struct___51 *, int);
	struct task_struct___51 * (*pick_next_task)(struct rq___2 *, struct task_struct___51 *, struct rq_flags *);
	void (*put_prev_task)(struct rq___2 *, struct task_struct___51 *);
	int (*select_task_rq)(struct task_struct___51 *, int, int, int);
	union {
		void (*migrate_task_rq)(struct task_struct___51 *, int);
		struct {
			void (*migrate_task_rq)(struct task_struct___51 *);
		} __UNIQUE_ID_rh_kabi_hide71;
		union {		};
	};
	void (*task_woken)(struct rq___2 *, struct task_struct___51 *);
	void (*set_cpus_allowed)(struct task_struct___51 *, const struct cpumask *);
	void (*rq_online)(struct rq___2 *);
	void (*rq_offline)(struct rq___2 *);
	void (*set_curr_task)(struct rq___2 *);
	void (*task_tick)(struct rq___2 *, struct task_struct___51 *, int);
	void (*task_fork)(struct task_struct___51 *);
	void (*task_dead)(struct task_struct___51 *);
	void (*switched_from)(struct rq___2 *, struct task_struct___51 *);
	void (*switched_to)(struct rq___2 *, struct task_struct___51 *);
	void (*prio_changed)(struct rq___2 *, struct task_struct___51 *, int);
	unsigned int (*get_rr_interval)(struct rq___2 *, struct task_struct___51 *);
	void (*update_curr)(struct rq___2 *);
	void (*task_change_group)(struct task_struct___51 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cgroup___39;

struct cgroup_subsys___39;

struct cgroup_subsys_state___39 {
	struct cgroup___39 *cgroup;
	struct cgroup_subsys___39 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___39 *parent;
};

struct autogroup___2;

struct task_group___2 {
	struct cgroup_subsys_state___39 css;
	struct sched_entity___2 **se;
	struct cfs_rq___2 **cfs_rq;
	long unsigned int shares;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t load_avg;
	struct sched_rt_entity___2 **rt_se;
	struct rt_rq___2 **rt_rq;
	struct rt_bandwidth rt_bandwidth;
	struct callback_head rcu;
	struct list_head list;
	struct task_group___2 *parent;
	struct list_head siblings;
	struct list_head children;
	struct autogroup___2 *autogroup;
	struct cfs_bandwidth cfs_bandwidth;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long: 64;
	long: 64;
	long: 64;
};

struct linux_binfmt___11;

struct core_state___50;

struct mm_struct___50 {
	struct {
		struct vm_area_struct___51 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___51 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___51 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___11 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___50 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___51 *owner;
		struct user_namespace___41 *user_ns;
		struct file___51 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___50 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct kernfs_node___48;

struct cgroup_file___39 {
	struct kernfs_node___48 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___20;

struct mem_cgroup___20 {
	struct cgroup_subsys_state___39 css;
	struct mem_cgroup_id___10 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___39 events_file;
	struct cgroup_file___39 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___51 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___20 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cred___50 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___51 *session_keyring;
	struct key___51 *process_keyring;
	struct key___51 *thread_keyring;
	struct key___51 *request_key_auth;
	void *security;
	struct user_struct___50 *user;
	struct user_namespace___41 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct uts_namespace___12;

struct net___14;

struct cgroup_namespace___39;

struct nsproxy___49 {
	atomic_t count;
	struct uts_namespace___12 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___46 *pid_ns_for_children;
	struct net___14 *net_ns;
	struct cgroup_namespace___39 *cgroup_ns;
};

struct signal_struct___48 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___51 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___51 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___46 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___46 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup___2 *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___50 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___46 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___21;

struct bio_list___21 {
	struct bio___21 *head;
	struct bio___21 *tail;
};

struct bdi_writeback_congested___21;

struct bdi_writeback___21 {
	struct backing_dev_info___21 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___21 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___39 *memcg_css;
	struct cgroup_subsys_state___39 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___44;

struct backing_dev_info___21 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___21 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___44 *dev;
	struct device___44 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___51 *debug_dir;
	struct dentry___51 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___12;

struct io_context___12 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___12 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___39 {
	struct cgroup_subsys_state___39 *subsys[13];
	refcount_t refcount;
	struct css_set___39 *dom_cset;
	struct cgroup___39 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___39 *mg_src_cgrp;
	struct cgroup___39 *mg_dst_cgrp;
	struct css_set___39 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___32 {
	struct pmu___32 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___51 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___32 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___13;

struct pipe_inode_info___13 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___51 *tmp_page;
	struct fasync_struct___50 *fasync_readers;
	struct fasync_struct___50 *fasync_writers;
	struct pipe_buffer___13 *bufs;
	struct user_struct___50 *user;
};

typedef blk_qc_t make_request_fn___12(struct request_queue___13 *, struct bio___21 *);

struct request___13;

typedef int dma_drain_needed_fn___12(struct request___13 *);

struct kset___47;

struct kobj_type___47;

struct kobject___48 {
	const char *name;
	struct list_head entry;
	struct kobject___48 *parent;
	struct kset___47 *kset;
	struct kobj_type___47 *ktype;
	struct kernfs_node___48 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___12;

struct bsg_class_device___12 {
	struct device___44 *class_dev;
	int minor;
	struct request_queue___13 *queue;
	const struct bsg_ops___12 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___21 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___21 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___12;

struct request_queue___13 {
	struct list_head queue_head;
	struct request___13 *last_merge;
	struct elevator_queue___12 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___12 *make_request_fn;
	dma_drain_needed_fn___12 *dma_drain_needed;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___21 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___48 kobj;
	struct kobject___48 *mq_kobj;
	struct blk_integrity integrity;
	struct device___44 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	struct bsg_class_device___12 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___21 bio_split;
	struct dentry___51 *debugfs_dir;
	struct dentry___51 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___40 {
	struct vm_struct___40 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___51 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___48 {
	struct task_struct___51 task;
	long unsigned int stack[8192];
};

struct kthread_work___39;

typedef void (*kthread_work_func_t___39)(struct kthread_work___39 *);

struct kthread_worker___39;

struct kthread_work___39 {
	struct list_head node;
	kthread_work_func_t___39 func;
	struct kthread_worker___39 *worker;
	int canceling;
};

struct kthread_worker___39 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___51 *task;
	struct kthread_work___39 *current_work;
};

struct kthread_delayed_work___39 {
	struct kthread_work___39 work;
	struct timer_list timer;
};

struct dentry_operations___50;

struct super_block___51;

struct dentry___51 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___51 *d_parent;
	struct qstr d_name;
	struct inode___52 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___50 *d_op;
	struct super_block___51 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___50;

struct address_space___50 {
	struct inode___52 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___51 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___50 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___50;

struct block_device___51;

struct inode___52 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___50 *i_op;
	struct super_block___51 *i_sb;
	struct address_space___50 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___51 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___21 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___51 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___50 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___13 *i_pipe;
		struct block_device___51 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___50;

struct dentry_operations___50 {
	int (*d_revalidate)(struct dentry___51 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___51 *, unsigned int);
	int (*d_hash)(const struct dentry___51 *, struct qstr *);
	int (*d_compare)(const struct dentry___51 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___51 *);
	int (*d_init)(struct dentry___51 *);
	void (*d_release)(struct dentry___51 *);
	void (*d_prune)(struct dentry___51 *);
	void (*d_iput)(struct dentry___51 *, struct inode___52 *);
	char * (*d_dname)(struct dentry___51 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___50 *);
	int (*d_manage)(const struct path___50 *, bool);
	struct dentry___51 * (*d_real)(struct dentry___51 *, const struct inode___52 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___50;

struct mem_dqinfo___50 {
	struct quota_format_type___50 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___50;

struct quota_info___50 {
	unsigned int flags;
	struct rw_semaphore___51 dqio_sem;
	struct inode___52 *files[3];
	struct mem_dqinfo___50 info[3];
	const struct quota_format_ops___50 *ops[3];
};

struct rcuwait___50 {
	struct task_struct___51 *task;
};

struct percpu_rw_semaphore___50 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___51 rw_sem;
	struct rcuwait___50 writer;
	int readers_block;
};

struct sb_writers___50 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___50 rw_sem[3];
};

struct shrink_control___20;

struct shrinker___20 {
	long unsigned int (*count_objects)(struct shrinker___20 *, struct shrink_control___20 *);
	long unsigned int (*scan_objects)(struct shrinker___20 *, struct shrink_control___20 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___50;

struct super_operations___50;

struct dquot_operations___50;

struct quotactl_ops___50;

struct super_block___51 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___50 *s_type;
	const struct super_operations___50 *s_op;
	const struct dquot_operations___50 *dq_op;
	const struct quotactl_ops___50 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___51 *s_root;
	struct rw_semaphore___51 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___51 *s_bdev;
	struct backing_dev_info___21 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___50 s_dquot;
	struct sb_writers___50 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___50 *s_d_op;
	int cleancache_poolid;
	struct shrinker___20 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___41 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct path___50 {
	struct vfsmount *mnt;
	struct dentry___51 *dentry;
};

struct shrink_control___20 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___20 *memcg;
};

struct pglist_data___50;

struct lruvec___50 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___50 *pgdat;
};

struct zone___50 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___50 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___50 {
	struct zone___50 *zone;
	int zone_idx;
};

struct zonelist___50 {
	struct zoneref___50 _zonerefs[25];
};

struct pglist_data___50 {
	struct zone___50 node_zones[3];
	struct zonelist___50 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___51 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___51 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___50 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___50 {
	struct rw_semaphore___51 rwsem;
	struct notifier_block *head;
};

typedef int (*dev_page_fault_t___50)(struct vm_area_struct___51 *, long unsigned int, const struct page___51 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___50)(struct page___51 *, void *);

struct dev_pagemap___50 {
	dev_page_fault_t___50 page_fault;
	dev_page_free_t___50 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___44 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct fown_struct___46 {
	rwlock_t lock;
	struct pid___46 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___51 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___50 f_path;
	struct inode___52 *f_inode;
	const struct file_operations___51 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___46 f_owner;
	const struct cred___50 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___50 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___50;

struct vm_operations_struct___50 {
	void (*open)(struct vm_area_struct___51 *);
	void (*close)(struct vm_area_struct___51 *);
	int (*split)(struct vm_area_struct___51 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___51 *);
	vm_fault_t (*fault)(struct vm_fault___50 *);
	vm_fault_t (*huge_fault)(struct vm_fault___50 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___50 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___51 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___50 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___50 *);
	int (*access)(struct vm_area_struct___51 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___51 *);
	int (*set_policy)(struct vm_area_struct___51 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___51 *, long unsigned int);
	struct page___51 * (*find_special_page)(struct vm_area_struct___51 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___50 {
	struct task_struct___51 *task;
	struct core_thread___50 *next;
};

struct core_state___50 {
	atomic_t nr_threads;
	struct core_thread___50 dumper;
	struct completion startup;
};

struct linux_binprm___12;

struct coredump_params___11;

struct linux_binfmt___11 {
	struct list_head lh;
	struct module___46 *module;
	int (*load_binary)(struct linux_binprm___12 *);
	int (*load_shlib)(struct file___51 *);
	int (*core_dump)(struct coredump_params___11 *);
	long unsigned int min_coredump;
};

struct vm_fault___50 {
	struct vm_area_struct___51 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___51 *cow_page;
	struct mem_cgroup___20 *memcg;
	struct page___51 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___50 prealloc_pte;
};

struct io_cq___12 {
	struct request_queue___13 *q;
	struct io_context___12 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___51 {
	struct file___51 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___51 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___51 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___51 *ia_file;
};

struct dquot___50 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___51 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___50 {
	int qf_fmt_id;
	const struct quota_format_ops___50 *qf_ops;
	struct module___46 *qf_owner;
	struct quota_format_type___50 *qf_next;
};

struct quota_format_ops___50 {
	int (*check_quota_file)(struct super_block___51 *, int);
	int (*read_file_info)(struct super_block___51 *, int);
	int (*write_file_info)(struct super_block___51 *, int);
	int (*free_file_info)(struct super_block___51 *, int);
	int (*read_dqblk)(struct dquot___50 *);
	int (*commit_dqblk)(struct dquot___50 *);
	int (*release_dqblk)(struct dquot___50 *);
	int (*get_next_id)(struct super_block___51 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___50 {
	int (*write_dquot)(struct dquot___50 *);
	struct dquot___50 * (*alloc_dquot)(struct super_block___51 *, int);
	void (*destroy_dquot)(struct dquot___50 *);
	int (*acquire_dquot)(struct dquot___50 *);
	int (*release_dquot)(struct dquot___50 *);
	int (*mark_dirty)(struct dquot___50 *);
	int (*write_info)(struct super_block___51 *, int);
	qsize_t * (*get_reserved_space)(struct inode___52 *);
	int (*get_projid)(struct inode___52 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___52 *, qsize_t *);
	int (*get_next_id)(struct super_block___51 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___50 {
	int (*quota_on)(struct super_block___51 *, int, int, const struct path___50 *);
	int (*quota_off)(struct super_block___51 *, int);
	int (*quota_enable)(struct super_block___51 *, unsigned int);
	int (*quota_disable)(struct super_block___51 *, unsigned int);
	int (*quota_sync)(struct super_block___51 *, int);
	int (*set_info)(struct super_block___51 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___51 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___51 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___51 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___51 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___51 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___43 {
	struct kobject___48 kobj;
	struct module___46 *mod;
	struct kobject___48 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___43 {
	struct module___46 *mod;
	struct latch_tree_node node;
};

struct module_layout___43 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___43 mtn;
};

struct module_attribute___43;

struct kernel_param___43;

struct module___46 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___43 mkobj;
	struct module_attribute___43 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___48 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___43 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___43 core_layout;
	struct module_layout___43 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___27 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___20;

struct swap_info_struct___15;

struct address_space_operations___50 {
	int (*writepage)(struct page___51 *, struct writeback_control___20 *);
	int (*readpage)(struct file___51 *, struct page___51 *);
	int (*writepages)(struct address_space___50 *, struct writeback_control___20 *);
	int (*set_page_dirty)(struct page___51 *);
	int (*readpages)(struct file___51 *, struct address_space___50 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___51 *, struct address_space___50 *, loff_t, unsigned int, unsigned int, struct page___51 **, void **);
	int (*write_end)(struct file___51 *, struct address_space___50 *, loff_t, unsigned int, unsigned int, struct page___51 *, void *);
	sector_t (*bmap)(struct address_space___50 *, sector_t);
	void (*invalidatepage)(struct page___51 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___51 *, gfp_t);
	void (*freepage)(struct page___51 *);
	ssize_t (*direct_IO)(struct kiocb___51 *, struct iov_iter___24 *);
	int (*migratepage)(struct address_space___50 *, struct page___51 *, struct page___51 *, enum migrate_mode);
	bool (*isolate_page)(struct page___51 *, isolate_mode_t);
	void (*putback_page)(struct page___51 *);
	int (*launder_page)(struct page___51 *);
	int (*is_partially_uptodate)(struct page___51 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___51 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___50 *, struct page___51 *);
	int (*swap_activate)(struct swap_info_struct___15 *, struct file___51 *, sector_t *);
	void (*swap_deactivate)(struct file___51 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___20 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___21 *wb;
	struct inode___52 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___21;

struct iov_iter___24 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___21 *bvec;
		struct pipe_inode_info___13 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct swap_info_struct___15 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___51 *bdev;
	struct file___51 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct hd_struct___12;

struct gendisk___12;

struct block_device___51 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___52 *bd_inode;
	struct super_block___51 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___51 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___12 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___12 *bd_disk;
	struct request_queue___13 *bd_queue;
	struct backing_dev_info___21 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___44 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___44 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___44;

struct bus_type___44;

struct device_driver___44;

struct dev_pm_domain___44;

struct dma_map_ops___14;

struct device_node___16;

struct fwnode_handle___36;

struct class___44;

struct attribute_group___45;

struct device___44 {
	struct device___44 *parent;
	struct device_private *p;
	struct kobject___48 kobj;
	const char *init_name;
	const struct device_type___44 *type;
	struct mutex mutex;
	struct bus_type___44 *bus;
	struct device_driver___44 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___44 power;
	struct dev_pm_domain___44 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___14 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___16 *of_node;
	struct fwnode_handle___36 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___44 *class;
	const struct attribute_group___45 **groups;
	void (*release)(struct device___44 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___12 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___44 __dev;
	struct kobject___48 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___12;

struct block_device_operations___12;

struct gendisk___12 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___12 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___12 *part_tbl;
	struct hd_struct___12 part0;
	const struct block_device_operations___12 *fops;
	struct request_queue___13 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___51 lookup_sem;
	struct kobject___48 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___48 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___50 {
	struct dentry___51 * (*lookup)(struct inode___52 *, struct dentry___51 *, unsigned int);
	const char * (*get_link)(struct dentry___51 *, struct inode___52 *, struct delayed_call *);
	int (*permission)(struct inode___52 *, int);
	struct posix_acl * (*get_acl)(struct inode___52 *, int);
	int (*readlink)(struct dentry___51 *, char *, int);
	int (*create)(struct inode___52 *, struct dentry___51 *, umode_t, bool);
	int (*link)(struct dentry___51 *, struct inode___52 *, struct dentry___51 *);
	int (*unlink)(struct inode___52 *, struct dentry___51 *);
	int (*symlink)(struct inode___52 *, struct dentry___51 *, const char *);
	int (*mkdir)(struct inode___52 *, struct dentry___51 *, umode_t);
	int (*rmdir)(struct inode___52 *, struct dentry___51 *);
	int (*mknod)(struct inode___52 *, struct dentry___51 *, umode_t, dev_t);
	int (*rename)(struct inode___52 *, struct dentry___51 *, struct inode___52 *, struct dentry___51 *, unsigned int);
	int (*setattr)(struct dentry___51 *, struct iattr___51 *);
	int (*getattr)(const struct path___50 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___51 *, char *, size_t);
	int (*fiemap)(struct inode___52 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___52 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___52 *, struct dentry___51 *, struct file___51 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___52 *, struct dentry___51 *, umode_t);
	int (*set_acl)(struct inode___52 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___50 {
	void (*fl_copy_lock)(struct file_lock___51 *, struct file_lock___51 *);
	void (*fl_release_private)(struct file_lock___51 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___50;

struct file_lock___51 {
	struct file_lock___51 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___51 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___50 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___50 *fl_ops;
	const struct lock_manager_operations___50 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___50 {
	int (*lm_compare_owner)(struct file_lock___51 *, struct file_lock___51 *);
	long unsigned int (*lm_owner_key)(struct file_lock___51 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___51 *);
	int (*lm_grant)(struct file_lock___51 *, int);
	bool (*lm_break)(struct file_lock___51 *);
	int (*lm_change)(struct file_lock___51 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___51 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___50 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___50 *fa_next;
	struct file___51 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___50 {
	const char *name;
	int fs_flags;
	struct dentry___51 * (*mount)(struct file_system_type___50 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___51 *);
	struct module___46 *owner;
	struct file_system_type___50 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___50 {
	struct inode___52 * (*alloc_inode)(struct super_block___51 *);
	void (*destroy_inode)(struct inode___52 *);
	void (*dirty_inode)(struct inode___52 *, int);
	int (*write_inode)(struct inode___52 *, struct writeback_control___20 *);
	int (*drop_inode)(struct inode___52 *);
	void (*evict_inode)(struct inode___52 *);
	void (*put_super)(struct super_block___51 *);
	int (*sync_fs)(struct super_block___51 *, int);
	int (*freeze_super)(struct super_block___51 *);
	int (*freeze_fs)(struct super_block___51 *);
	int (*thaw_super)(struct super_block___51 *);
	int (*unfreeze_fs)(struct super_block___51 *);
	int (*statfs)(struct dentry___51 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___51 *, int *, char *);
	void (*umount_begin)(struct super_block___51 *);
	int (*show_options)(struct seq_file___48 *, struct dentry___51 *);
	int (*show_devname)(struct seq_file___48 *, struct dentry___51 *);
	int (*show_path)(struct seq_file___48 *, struct dentry___51 *);
	int (*show_stats)(struct seq_file___48 *, struct dentry___51 *);
	ssize_t (*quota_read)(struct super_block___51 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___51 *, int, const char *, size_t, loff_t);
	struct dquot___50 ** (*get_dquots)(struct inode___52 *);
	int (*bdev_try_to_free_page)(struct super_block___51 *, struct page___51 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___51 *, struct shrink_control___20 *);
	long int (*free_cached_objects)(struct super_block___51 *, struct shrink_control___20 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___32)(struct file___51 *, wait_queue_head_t *, struct poll_table_struct___33 *);

struct poll_table_struct___33 {
	poll_queue_proc___32 _qproc;
	__poll_t _key;
};

struct seq_operations___45;

struct seq_file___48 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___45 *op;
	int poll_event;
	const struct file___51 *file;
	void *private;
};

typedef void bio_end_io_t___21(struct bio___21 *);

struct bio_vec___21 {
	struct page___51 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___21;

struct bio___21 {
	struct bio___21 *bi_next;
	struct gendisk___12 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___21 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___21 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___21 *bi_io_vec;
	struct bio_set___21 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___21 bi_inline_vecs[0];
};

typedef int (*key_restrict_link_func_t___50)(struct key___51 *, const struct key_type *, const union key_payload *, struct key___51 *);

struct key_restriction___51;

struct key___51 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___51 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___51 *restrict_link;
};

struct key_restriction___51 {
	key_restrict_link_func_t___50 check;
	struct key___51 *key;
	struct key_type *keytype;
};

struct seq_operations___45 {
	void * (*start)(struct seq_file___48 *, loff_t *);
	void (*stop)(struct seq_file___48 *, void *);
	void * (*next)(struct seq_file___48 *, void *, loff_t *);
	int (*show)(struct seq_file___48 *, void *);
};

struct kernfs_root___48;

struct kernfs_elem_dir___48 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___48 *root;
};

struct kernfs_syscall_ops___48;

struct kernfs_root___48 {
	struct kernfs_node___48 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___48 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___48 {
	struct kernfs_node___48 *target_kn;
};

struct kernfs_ops___48;

struct kernfs_elem_attr___48 {
	const struct kernfs_ops___48 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___48 *notify_next;
};

struct kernfs_node___48 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___48 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___48 dir;
		struct kernfs_elem_symlink___48 symlink;
		struct kernfs_elem_attr___48 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___48;

struct kernfs_ops___48 {
	int (*open)(struct kernfs_open_file___48 *);
	void (*release)(struct kernfs_open_file___48 *);
	int (*seq_show)(struct seq_file___48 *, void *);
	void * (*seq_start)(struct seq_file___48 *, loff_t *);
	void * (*seq_next)(struct seq_file___48 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___48 *, void *);
	ssize_t (*read)(struct kernfs_open_file___48 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___48 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___48 *, struct vm_area_struct___51 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___48 *, struct poll_table_struct___33 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___48 {
	int (*remount_fs)(struct kernfs_root___48 *, int *, char *);
	int (*show_options)(struct seq_file___48 *, struct kernfs_root___48 *);
	int (*mkdir)(struct kernfs_node___48 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___48 *);
	int (*rename)(struct kernfs_node___48 *, struct kernfs_node___48 *, const char *);
	int (*show_path)(struct seq_file___48 *, struct kernfs_node___48 *, struct kernfs_root___48 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___48 {
	struct kernfs_node___48 *kn;
	struct file___51 *file;
	struct seq_file___48 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___50 *vm_ops;
};

struct uts_namespace___12 {
	struct kref kref;
	struct new_utsname name;
	struct user_namespace___41 *user_ns;
	struct ucounts___41 *ucounts;
	struct ns_common___4 ns;
};

struct dst_ops___12 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___12 *);
	struct dst_entry___2 * (*check)(struct dst_entry___2 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___2 *);
	unsigned int (*mtu)(const struct dst_entry___2 *);
	u32 * (*cow_metrics)(struct dst_entry___2 *, long unsigned int);
	void (*destroy)(struct dst_entry___2 *);
	void (*ifdown)(struct dst_entry___2 *, struct net_device *, int);
	struct dst_entry___2 * (*negative_advice)(struct dst_entry___2 *);
	void (*link_failure)(struct sk_buff___9 *);
	void (*update_pmtu)(struct dst_entry___2 *, struct sock *, struct sk_buff___9 *, u32);
	void (*redirect)(struct dst_entry___2 *, struct sock *, struct sk_buff___9 *);
	int (*local_out)(struct net___14 *, struct sock *, struct sk_buff___9 *);
	struct neighbour___2 * (*neigh_lookup)(const struct dst_entry___2 *, struct sk_buff___9 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___2 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___11 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___5 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___12 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct sock *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops *notifier_ops;
	struct fib_notifier_ops *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_xfrm___11 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___12 xfrm4_dst_ops;
	struct dst_ops___12 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct net___14 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___41 *user_ns;
	struct ucounts___41 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___4 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___5 ipv4;
	struct netns_ipv6___11 ipv6;
	struct netns_sctp___2 sctp;
	struct netns_nf nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___5 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock *nfnl;
	struct sock *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___11 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cgroup_namespace___39 {
	refcount_t count;
	struct ns_common___4 ns;
	struct user_namespace___41 *user_ns;
	struct ucounts___41 *ucounts;
	struct css_set___39 *root_cset;
};

struct ucounts___41 {
	struct hlist_node node;
	struct user_namespace___41 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___39;

struct bpf_map_ops___39 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___39 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___39 *, struct file___51 *);
	void (*map_free)(struct bpf_map___39 *);
	int (*map_get_next_key)(struct bpf_map___39 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___39 *);
	void * (*map_lookup_elem)(struct bpf_map___39 *, void *);
	int (*map_update_elem)(struct bpf_map___39 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___39 *, void *);
	int (*map_push_elem)(struct bpf_map___39 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___39 *, void *);
	int (*map_peek_elem)(struct bpf_map___39 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___39 *, struct file___51 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___39 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___39 *, void *, struct seq_file___48 *);
	int (*map_check_btf)(const struct bpf_map___39 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___39 {
	const struct bpf_map_ops___39 *ops;
	struct bpf_map___39 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___50 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

enum psi_res {
	PSI_IO = 0,
	PSI_MEM = 1,
	PSI_CPU = 2,
	NR_PSI_RESOURCES = 3,
};

struct psi_window {
	u64 size;
	u64 start_time;
	u64 start_value;
	u64 prev_growth;
};

struct psi_group___39;

struct psi_trigger {
	enum psi_states state;
	u64 threshold;
	struct list_head node;
	struct psi_group___39 *group;
	wait_queue_head_t event_wait;
	int event;
	struct psi_window win;
	u64 last_event_time;
	struct kref refcount;
};

struct psi_group___39 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___39 *poll_kworker;
	struct kthread_delayed_work___39 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___39;

struct cgroup_rstat_cpu___39;

struct cgroup___39 {
	struct cgroup_subsys_state___39 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___48 *kn;
	struct cgroup_file___39 procs_file;
	struct cgroup_file___39 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___39 *subsys[13];
	struct cgroup_root___39 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___39 *dom_cgrp;
	struct cgroup_rstat_cpu___39 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___4 bpf;
	atomic_t congestion_count;
	struct cgroup___39 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___39 psi;
	int ancestor_ids[0];
};

struct cftype___39;

struct cgroup_subsys___39 {
	struct cgroup_subsys_state___39 * (*css_alloc)(struct cgroup_subsys_state___39 *);
	int (*css_online)(struct cgroup_subsys_state___39 *);
	void (*css_offline)(struct cgroup_subsys_state___39 *);
	void (*css_released)(struct cgroup_subsys_state___39 *);
	void (*css_free)(struct cgroup_subsys_state___39 *);
	void (*css_reset)(struct cgroup_subsys_state___39 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___39 *, int);
	int (*css_extra_stat_show)(struct seq_file___48 *, struct cgroup_subsys_state___39 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___51 *);
	void (*cancel_fork)(struct task_struct___51 *);
	void (*fork)(struct task_struct___51 *);
	void (*exit)(struct task_struct___51 *);
	void (*free)(struct task_struct___51 *);
	void (*bind)(struct cgroup_subsys_state___39 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___39 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___39 *dfl_cftypes;
	struct cftype___39 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___39 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___39 *updated_children;
	struct cgroup___39 *updated_next;
};

struct cgroup_root___39 {
	struct kernfs_root___48 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___39 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___39 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___39 *ss;
	struct list_head node;
	struct kernfs_ops___48 *kf_ops;
	int (*open)(struct kernfs_open_file___48 *);
	void (*release)(struct kernfs_open_file___48 *);
	u64 (*read_u64)(struct cgroup_subsys_state___39 *, struct cftype___39 *);
	s64 (*read_s64)(struct cgroup_subsys_state___39 *, struct cftype___39 *);
	int (*seq_show)(struct seq_file___48 *, void *);
	void * (*seq_start)(struct seq_file___48 *, loff_t *);
	void * (*seq_next)(struct seq_file___48 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___48 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___39 *, struct cftype___39 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___39 *, struct cftype___39 *, s64);
	ssize_t (*write)(struct kernfs_open_file___48 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___48 *, struct poll_table_struct___33 *);
};

struct bin_attribute___45;

struct attribute_group___45 {
	const char *name;
	umode_t (*is_visible)(struct kobject___48 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___48 *, struct bin_attribute___45 *, int);
	struct attribute **attrs;
	struct bin_attribute___45 **bin_attrs;
};

struct bin_attribute___45 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___51 *, struct kobject___48 *, struct bin_attribute___45 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___51 *, struct kobject___48 *, struct bin_attribute___45 *, char *, loff_t, size_t);
	int (*mmap)(struct file___51 *, struct kobject___48 *, struct bin_attribute___45 *, struct vm_area_struct___51 *);
};

struct sysfs_ops___47 {
	ssize_t (*show)(struct kobject___48 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___48 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___47;

struct kset___47 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___48 kobj;
	const struct kset_uevent_ops___47 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___47 {
	void (*release)(struct kobject___48 *);
	const struct sysfs_ops___47 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___2 * (*child_ns_type)(struct kobject___48 *);
	const void * (*namespace)(struct kobject___48 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___47 {
	int (* const filter)(struct kset___47 *, struct kobject___48 *);
	const char * (* const name)(struct kset___47 *, struct kobject___48 *);
	int (* const uevent)(struct kset___47 *, struct kobject___48 *, struct kobj_uevent_env *);
};

struct kobj_attribute___48 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___48 *, struct kobj_attribute___48 *, char *);
	ssize_t (*store)(struct kobject___48 *, struct kobj_attribute___48 *, const char *, size_t);
};

struct kernel_param_ops___43 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___43 *);
	int (*get)(char *, const struct kernel_param___43 *);
	void (*free)(void *);
};

struct kparam_array___43;

struct kernel_param___43 {
	const char *name;
	struct module___46 *mod;
	const struct kernel_param_ops___43 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___43 *arr;
	};
};

struct kparam_array___43 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___43 *ops;
	void *elem;
};

struct module_attribute___43 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___43 *, struct module_kobject___43 *, char *);
	ssize_t (*store)(struct module_attribute___43 *, struct module_kobject___43 *, const char *, size_t);
	void (*setup)(struct module___46 *, const char *);
	int (*test)(struct module___46 *);
	void (*free)(struct module___46 *);
};

struct trace_event_class___27;

struct trace_event_call___27 {
	struct list_head list;
	struct trace_event_class___27 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___4 *prog_array;
	int (*perf_perm)(struct trace_event_call___27 *, struct perf_event___32 *);
};

typedef struct poll_table_struct___33 poll_table___2;

struct autogroup___2 {
	struct kref kref;
	struct task_group___2 *tg;
	struct rw_semaphore___51 lock;
	long unsigned int id;
	int nice;
};

struct fwnode_operations___36;

struct fwnode_handle___36 {
	struct fwnode_handle___36 *secondary;
	const struct fwnode_operations___36 *ops;
};

struct fwnode_reference_args___36;

struct fwnode_endpoint___36;

struct fwnode_operations___36 {
	struct fwnode_handle___36 * (*get)(struct fwnode_handle___36 *);
	void (*put)(struct fwnode_handle___36 *);
	bool (*device_is_available)(const struct fwnode_handle___36 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___36 *, const struct device___44 *);
	bool (*property_present)(const struct fwnode_handle___36 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___36 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___36 *, const char *, const char **, size_t);
	struct fwnode_handle___36 * (*get_parent)(const struct fwnode_handle___36 *);
	struct fwnode_handle___36 * (*get_next_child_node)(const struct fwnode_handle___36 *, struct fwnode_handle___36 *);
	struct fwnode_handle___36 * (*get_named_child_node)(const struct fwnode_handle___36 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___36 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___36 *);
	struct fwnode_handle___36 * (*graph_get_next_endpoint)(const struct fwnode_handle___36 *, struct fwnode_handle___36 *);
	struct fwnode_handle___36 * (*graph_get_remote_endpoint)(const struct fwnode_handle___36 *);
	struct fwnode_handle___36 * (*graph_get_port_parent)(struct fwnode_handle___36 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___36 *, struct fwnode_endpoint___36 *);
};

struct fwnode_endpoint___36 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___36 *local_fwnode;
};

struct fwnode_reference_args___36 {
	struct fwnode_handle___36 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct property___16 {
	char *name;
	int length;
	void *value;
	struct property___16 *next;
	long unsigned int _flags;
	struct bin_attribute___45 attr;
};

struct device_node___16 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___36 fwnode;
	struct property___16 *properties;
	struct property___16 *deadprops;
	struct device_node___16 *parent;
	struct device_node___16 *child;
	struct device_node___16 *sibling;
	struct kobject___48 kobj;
	long unsigned int _flags;
	void *data;
};

struct linux_binprm___12 {
	char buf[256];
	struct vm_area_struct___51 *vma;
	long unsigned int vma_pages;
	struct mm_struct___50 *mm;
	long unsigned int p;
	unsigned int called_set_creds: 1;
	unsigned int cap_elevated: 1;
	unsigned int secureexec: 1;
	unsigned int recursion_depth;
	struct file___51 *file;
	struct cred___50 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
};

struct coredump_params___11 {
	union {
		const kernel_siginfo_t *siginfo;
		struct {
			const siginfo_t *siginfo;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	struct pt_regs *regs;
	struct file___51 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
};

struct bio_integrity_payload___21 {
	struct bio___21 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___21 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___21 bip_inline_vecs[0];
};

struct dev_pm_ops___44;

struct device_type___44 {
	const char *name;
	const struct attribute_group___45 **groups;
	int (*uevent)(struct device___44 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___44 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___44 *);
	const struct dev_pm_ops___44 *pm;
};

struct class___44 {
	const char *name;
	struct module___46 *owner;
	const struct attribute_group___45 **class_groups;
	const struct attribute_group___45 **dev_groups;
	struct kobject___48 *dev_kobj;
	int (*dev_uevent)(struct device___44 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___44 *, umode_t *);
	void (*class_release)(struct class___44 *);
	void (*dev_release)(struct device___44 *);
	int (*shutdown_pre)(struct device___44 *);
	const struct kobj_ns_type_operations___2 *ns_type;
	const void * (*namespace)(struct device___44 *);
	const struct dev_pm_ops___44 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dev_pm_ops___44 {
	int (*prepare)(struct device___44 *);
	void (*complete)(struct device___44 *);
	int (*suspend)(struct device___44 *);
	int (*resume)(struct device___44 *);
	int (*freeze)(struct device___44 *);
	int (*thaw)(struct device___44 *);
	int (*poweroff)(struct device___44 *);
	int (*restore)(struct device___44 *);
	int (*suspend_late)(struct device___44 *);
	int (*resume_early)(struct device___44 *);
	int (*freeze_late)(struct device___44 *);
	int (*thaw_early)(struct device___44 *);
	int (*poweroff_late)(struct device___44 *);
	int (*restore_early)(struct device___44 *);
	int (*suspend_noirq)(struct device___44 *);
	int (*resume_noirq)(struct device___44 *);
	int (*freeze_noirq)(struct device___44 *);
	int (*thaw_noirq)(struct device___44 *);
	int (*poweroff_noirq)(struct device___44 *);
	int (*restore_noirq)(struct device___44 *);
	int (*runtime_suspend)(struct device___44 *);
	int (*runtime_resume)(struct device___44 *);
	int (*runtime_idle)(struct device___44 *);
};

struct dev_pm_domain___44 {
	struct dev_pm_ops___44 ops;
	void (*detach)(struct device___44 *, bool);
	int (*activate)(struct device___44 *);
	void (*sync)(struct device___44 *);
	void (*dismiss)(struct device___44 *);
};

struct bus_type___44 {
	const char *name;
	const char *dev_name;
	struct device___44 *dev_root;
	const struct attribute_group___45 **bus_groups;
	const struct attribute_group___45 **dev_groups;
	const struct attribute_group___45 **drv_groups;
	int (*match)(struct device___44 *, struct device_driver___44 *);
	int (*uevent)(struct device___44 *, struct kobj_uevent_env *);
	int (*probe)(struct device___44 *);
	int (*remove)(struct device___44 *);
	void (*shutdown)(struct device___44 *);
	int (*online)(struct device___44 *);
	int (*offline)(struct device___44 *);
	int (*suspend)(struct device___44 *, pm_message_t);
	int (*resume)(struct device___44 *);
	int (*num_vf)(struct device___44 *);
	int (*dma_configure)(struct device___44 *);
	const struct dev_pm_ops___44 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___44 {
	const char *name;
	struct bus_type___44 *bus;
	struct module___46 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___44 *);
	int (*remove)(struct device___44 *);
	void (*shutdown)(struct device___44 *);
	int (*suspend)(struct device___44 *, pm_message_t);
	int (*resume)(struct device___44 *);
	const struct attribute_group___45 **groups;
	const struct dev_pm_ops___44 *pm;
	void (*coredump)(struct device___44 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct dma_map_ops___14 {
	void * (*alloc)(struct device___44 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___44 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___44 *, struct vm_area_struct___51 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___44 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___44 *, struct page___51 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___44 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___44 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___44 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___44 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___44 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___44 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide58;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___44 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___44 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___44 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___44 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___44 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___44 *, u64);
	u64 (*get_required_mask)(struct device___44 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct disk_part_tbl___12 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___12 *last_lookup;
	struct hd_struct___12 *part[0];
};

struct block_device_operations___12 {
	int (*open)(struct block_device___51 *, fmode_t);
	void (*release)(struct gendisk___12 *, fmode_t);
	int (*rw_page)(struct block_device___51 *, sector_t, struct page___51 *, unsigned int);
	int (*ioctl)(struct block_device___51 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___51 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___12 *, unsigned int);
	int (*media_changed)(struct gendisk___12 *);
	void (*unlock_native_capacity)(struct gendisk___12 *);
	int (*revalidate_disk)(struct gendisk___12 *);
	int (*getgeo)(struct block_device___51 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___51 *, long unsigned int);
	int (*report_zones)(struct gendisk___12 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___46 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___50(struct page___51 *);

struct bdi_writeback_congested___21 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___21 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bsg_ops___12 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___13 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___13 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___13 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___12(struct request___13 *, blk_status_t);

struct request___13 {
	struct request_queue___13 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___21 *bio;
	struct bio___21 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___21 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___12 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___12 *saved_end_io;
		} flush;
	};
	struct gendisk___12 *rq_disk;
	struct hd_struct___12 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___12 *end_io;
	void *end_io_data;
	struct request___13 *next_rq;
};

struct elevator_type___12;

struct elevator_mq_ops___12 {
	int (*init_sched)(struct request_queue___13 *, struct elevator_type___12 *);
	void (*exit_sched)(struct elevator_queue___12 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	bool (*allow_merge)(struct request_queue___13 *, struct request___13 *, struct bio___21 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx *, struct bio___21 *);
	int (*request_merge)(struct request_queue___13 *, struct request___13 **, struct bio___21 *);
	void (*request_merged)(struct request_queue___13 *, struct request___13 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___13 *, struct request___13 *, struct request___13 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___13 *, struct bio___21 *);
	void (*finish_request)(struct request___13 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___13 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___13 *, u64);
	void (*started_request)(struct request___13 *);
	void (*requeue_request)(struct request___13 *);
	struct request___13 * (*former_request)(struct request_queue___13 *, struct request___13 *);
	struct request___13 * (*next_request)(struct request_queue___13 *, struct request___13 *);
	void (*init_icq)(struct io_cq___12 *);
	void (*exit_icq)(struct io_cq___12 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___12;

struct elevator_type___12 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___12 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___12 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___46 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___12 {
	struct elevator_type___12 *type;
	void *elevator_data;
	struct kobject___48 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___12 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___12 *, char *);
	ssize_t (*store)(struct elevator_queue___12 *, const char *, size_t);
};

struct cpufreq_governor___2;

struct cpufreq_policy___2 {
	cpumask_var_t cpus;
	cpumask_var_t related_cpus;
	cpumask_var_t real_cpus;
	unsigned int shared_type;
	unsigned int cpu;
	struct clk *clk;
	struct cpufreq_cpuinfo cpuinfo;
	unsigned int min;
	unsigned int max;
	unsigned int cur;
	unsigned int restore_freq;
	unsigned int suspend_freq;
	unsigned int policy;
	unsigned int last_policy;
	struct cpufreq_governor___2 *governor;
	void *governor_data;
	char last_governor[16];
	struct work_struct update;
	struct cpufreq_user_policy user_policy;
	struct cpufreq_frequency_table *freq_table;
	enum cpufreq_table_sorting freq_table_sorted;
	struct list_head policy_list;
	struct kobject___48 kobj;
	struct completion kobj_unregister;
	struct rw_semaphore___51 rwsem;
	bool fast_switch_possible;
	bool fast_switch_enabled;
	unsigned int transition_delay_us;
	bool dvfs_possible_from_any_cpu;
	unsigned int cached_target_freq;
	int cached_resolved_idx;
	bool transition_ongoing;
	spinlock_t transition_lock;
	wait_queue_head_t transition_wait;
	struct task_struct___51 *transition_task;
	struct cpufreq_stats *stats;
	void *driver_data;
};

struct cpufreq_governor___2 {
	char name[16];
	int (*init)(struct cpufreq_policy___2 *);
	void (*exit)(struct cpufreq_policy___2 *);
	int (*start)(struct cpufreq_policy___2 *);
	void (*stop)(struct cpufreq_policy___2 *);
	void (*limits)(struct cpufreq_policy___2 *);
	ssize_t (*show_setspeed)(struct cpufreq_policy___2 *, char *);
	int (*store_setspeed)(struct cpufreq_policy___2 *, unsigned int);
	bool dynamic_switching;
	struct list_head governor_list;
	struct module___46 *owner;
};

struct freq_attr___2 {
	struct attribute attr;
	ssize_t (*show)(struct cpufreq_policy___2 *, char *);
	ssize_t (*store)(struct cpufreq_policy___2 *, const char *, size_t);
};

struct cpuidle_driver___4;

struct cpuidle_state___3 {
	char name[16];
	char desc[32];
	unsigned int flags;
	unsigned int exit_latency;
	int power_usage;
	unsigned int target_residency;
	bool disabled;
	int (*enter)(struct cpuidle_device *, struct cpuidle_driver___4 *, int);
	int (*enter_dead)(struct cpuidle_device *, int);
	void (*enter_s2idle)(struct cpuidle_device *, struct cpuidle_driver___4 *, int);
};

struct cpuidle_driver___4 {
	const char *name;
	struct module___46 *owner;
	int refcnt;
	unsigned int bctimer: 1;
	struct cpuidle_state___3 states[10];
	int state_count;
	int safe_state_index;
	struct cpumask *cpumask;
};

struct pipe_buf_operations___13;

struct pipe_buffer___13 {
	struct page___51 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___13 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___13 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___13 *, struct pipe_buffer___13 *);
	void (*release)(struct pipe_inode_info___13 *, struct pipe_buffer___13 *);
	int (*steal)(struct pipe_inode_info___13 *, struct pipe_buffer___13 *);
	union {
		bool (*get)(struct pipe_inode_info___13 *, struct pipe_buffer___13 *);
		struct {
			void (*get)(struct pipe_inode_info___13 *, struct pipe_buffer___13 *);
		} __UNIQUE_ID_rh_kabi_hide61;
		union {		};
	};
};

struct hstate___9 {
	int next_nid_to_alloc;
	int next_nid_to_free;
	unsigned int order;
	long unsigned int mask;
	long unsigned int max_huge_pages;
	long unsigned int nr_huge_pages;
	long unsigned int free_huge_pages;
	long unsigned int resv_huge_pages;
	long unsigned int surplus_huge_pages;
	long unsigned int nr_overcommit_huge_pages;
	struct list_head hugepage_activelist;
	struct list_head hugepage_freelists[8];
	unsigned int nr_huge_pages_node[8];
	unsigned int free_huge_pages_node[8];
	unsigned int surplus_huge_pages_node[8];
	struct cftype___39 cgroup_files[5];
	char name[32];
};

struct node___41 {
	struct device___44 dev;
};

struct mem_cgroup_reclaim_iter___20 {
	struct mem_cgroup___20 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___20 {
	struct lruvec___50 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___20 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___20 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct perf_cpu_context___32;

struct pmu___32 {
	struct list_head entry;
	struct module___46 *module;
	struct device___44 *dev;
	const struct attribute_group___45 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___32 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___32 *);
	void (*pmu_disable)(struct pmu___32 *);
	int (*event_init)(struct perf_event___32 *);
	void (*event_mapped)(struct perf_event___32 *, struct mm_struct___50 *);
	void (*event_unmapped)(struct perf_event___32 *, struct mm_struct___50 *);
	int (*add)(struct perf_event___32 *, int);
	void (*del)(struct perf_event___32 *, int);
	void (*start)(struct perf_event___32 *, int);
	void (*stop)(struct perf_event___32 *, int);
	void (*read)(struct perf_event___32 *);
	void (*start_txn)(struct pmu___32 *, unsigned int);
	int (*commit_txn)(struct pmu___32 *);
	void (*cancel_txn)(struct pmu___32 *);
	int (*event_idx)(struct perf_event___32 *);
	void (*sched_task)(struct perf_event_context___32 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___32 *);
	int (*filter_match)(struct perf_event___32 *);
	int (*check_period)(struct perf_event___32 *, u64);
};

struct perf_cpu_context___32 {
	struct perf_event_context___32 ctx;
	struct perf_event_context___32 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___32 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___32 {
	struct cgroup_subsys_state___39 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___27 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___27 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___27 *);
	struct list_head * (*get_fields)(struct trace_event_call___27 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___27 *);
};

struct rq___2 {
	raw_spinlock_t lock;
	unsigned int nr_running;
	unsigned int nr_numa_running;
	unsigned int nr_preferred_running;
	long unsigned int cpu_load[5];
	long unsigned int last_load_update_tick;
	long unsigned int last_blocked_load_update_tick;
	unsigned int has_blocked_load;
	unsigned int nohz_tick_stopped;
	atomic_t nohz_flags;
	struct load_weight load;
	long unsigned int nr_load_updates;
	u64 nr_switches;
	long: 64;
	struct cfs_rq___2 cfs;
	struct rt_rq___2 rt;
	struct dl_rq dl;
	struct list_head leaf_cfs_rq_list;
	struct list_head *tmp_alone_branch;
	long unsigned int nr_uninterruptible;
	struct task_struct___51 *curr;
	struct task_struct___51 *idle;
	struct task_struct___51 *stop;
	long unsigned int next_balance;
	struct mm_struct___50 *prev_mm;
	unsigned int clock_update_flags;
	u64 clock;
	u64 clock_task;
	atomic_t nr_iowait;
	struct root_domain *rd;
	struct sched_domain *sd;
	long unsigned int cpu_capacity;
	long unsigned int cpu_capacity_orig;
	struct callback_head *balance_callback;
	unsigned char idle_balance;
	int active_balance;
	int push_cpu;
	struct cpu_stop_work active_balance_work;
	int cpu;
	int online;
	struct list_head cfs_tasks;
	u64 rh_reserved_rt_avg;
	u64 rh_reserved_age_stamp;
	u64 idle_stamp;
	u64 avg_idle;
	u64 max_idle_balance_cost;
	u64 prev_steal_time;
	u64 prev_steal_time_rq;
	long unsigned int calc_load_update;
	long int calc_load_active;
	int hrtick_csd_pending;
	long: 32;
	long: 64;
	call_single_data_t hrtick_csd;
	struct hrtimer hrtick_timer;
	struct sched_info rq_sched_info;
	long long unsigned int rq_cpu_time;
	unsigned int yld_count;
	unsigned int sched_count;
	unsigned int sched_goidle;
	unsigned int ttwu_count;
	unsigned int ttwu_local;
	struct llist_head wake_list;
	struct cpuidle_state___3 *idle_state;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	unsigned int numa_migrate_on;
	long: 32;
	long: 64;
	struct sched_avg avg_rt;
	struct sched_avg avg_dl;
	struct sched_avg avg_irq;
};

struct ww_acquire_ctx;

struct mutex_waiter {
	struct list_head list;
	struct task_struct___2 *task;
	struct ww_acquire_ctx *ww_ctx;
};

struct ww_acquire_ctx {
	struct task_struct___2 *task;
	long unsigned int stamp;
	unsigned int acquired;
	short unsigned int wounded;
	short unsigned int is_wait_die;
};

struct ww_mutex {
	struct mutex base;
	struct ww_acquire_ctx *ctx;
};

struct semaphore {
	raw_spinlock_t lock;
	unsigned int count;
	struct list_head wait_list;
};

struct semaphore_waiter {
	struct list_head list;
	struct task_struct___47 *task;
	bool up;
};

enum rwsem_waiter_type {
	RWSEM_WAITING_FOR_WRITE = 0,
	RWSEM_WAITING_FOR_READ = 1,
};

struct rwsem_waiter {
	struct list_head list;
	struct task_struct___2 *task;
	enum rwsem_waiter_type type;
};

enum rwsem_wake_type {
	RWSEM_WAKE_ANY = 0,
	RWSEM_WAKE_READERS = 1,
	RWSEM_WAKE_READ_OWNED = 2,
};

struct optimistic_spin_node {
	struct optimistic_spin_node *next;
	struct optimistic_spin_node *prev;
	int locked;
	int cpu;
};

struct mcs_spinlock {
	struct mcs_spinlock *next;
	int locked;
	int count;
};

struct qnode {
	struct mcs_spinlock mcs;
};

struct hrtimer_sleeper {
	struct hrtimer timer;
	struct task_struct___2 *task;
};

struct rt_mutex;

struct rt_mutex_waiter {
	struct rb_node tree_entry;
	struct rb_node pi_tree_entry;
	struct task_struct___2 *task;
	struct rt_mutex *lock;
	int prio;
	u64 deadline;
};

struct rt_mutex {
	raw_spinlock_t wait_lock;
	struct rb_root_cached waiters;
	struct task_struct___2 *owner;
};

enum rtmutex_chainwalk {
	RT_MUTEX_MIN_CHAINWALK = 0,
	RT_MUTEX_FULL_CHAINWALK = 1,
};

struct module___47;

struct file___52;

struct kiocb___52;

struct poll_table_struct___34;

struct vm_area_struct___52;

struct inode___53;

struct file_lock___52;

struct page___52;

struct seq_file___49;

struct file_operations___52 {
	struct module___47 *owner;
	loff_t (*llseek)(struct file___52 *, loff_t, int);
	ssize_t (*read)(struct file___52 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___52 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___52 *, struct iov_iter___24 *);
	ssize_t (*write_iter)(struct kiocb___52 *, struct iov_iter___24 *);
	int (*iopoll)(struct kiocb___52 *, bool);
	int (*iterate)(struct file___52 *, struct dir_context *);
	int (*iterate_shared)(struct file___52 *, struct dir_context *);
	__poll_t (*poll)(struct file___52 *, struct poll_table_struct___34 *);
	long int (*unlocked_ioctl)(struct file___52 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___52 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___52 *, struct vm_area_struct___52 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___53 *, struct file___52 *);
	int (*flush)(struct file___52 *, fl_owner_t);
	int (*release)(struct inode___53 *, struct file___52 *);
	int (*fsync)(struct file___52 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___52 *, int);
	int (*lock)(struct file___52 *, int, struct file_lock___52 *);
	ssize_t (*sendpage)(struct file___52 *, struct page___52 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___52 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___52 *, int, struct file_lock___52 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___52 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___52 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___52 *, long int, struct file_lock___52 **, void **);
	long int (*fallocate)(struct file___52 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___49 *, struct file___52 *);
	ssize_t (*copy_file_range)(struct file___52 *, loff_t, struct file___52 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___52 *, loff_t, struct file___52 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___52 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct perf_event___33;

struct debug_info___33 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___33 *hbp_break[16];
	struct perf_event___33 *hbp_watch[16];
};

struct task_struct___52;

struct hw_perf_event___33 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___52 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___33)(struct perf_event___33 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___33;

struct perf_event_context___33;

struct fasync_struct___51;

struct pid_namespace___47;

struct trace_event_call___28;

struct perf_cgroup___33;

struct perf_event___33 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___33 *group_leader;
	struct pmu___33 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___33 hw;
	struct perf_event_context___33 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___33 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___52 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___51 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___33 *);
	struct callback_head callback_head;
	struct pid_namespace___47 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___33 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___33 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___28 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___33 *cgrp;
	struct list_head sb_list;
};

struct thread_struct___33 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___33 debug;
	long: 64;
};

struct vmacache___51 {
	u64 seqnum;
	struct vm_area_struct___52 *vmas[4];
};

struct page_frag___51 {
	struct page___52 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___51;

struct pid___47;

struct cred___51;

struct nsproxy___50;

struct signal_struct___49;

struct css_set___40;

struct task_struct___52 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___52 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___51 *mm;
	struct mm_struct___51 *active_mm;
	struct vmacache___51 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___52 *real_parent;
	struct task_struct___52 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___52 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___47 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___47 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___47 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___51 *ptracer_cred;
	const struct cred___51 *real_cred;
	const struct cred___51 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___50 *nsproxy;
	struct signal_struct___49 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___52 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___12 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___40 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___33 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___51 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___52 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___33 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rw_semaphore___52 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___52 *owner;
};

struct secondary_data___52 {
	void *stack;
	struct task_struct___52 *task;
	long int status;
};

struct blocking_notifier_head___51 {
	struct rw_semaphore___52 rwsem;
	struct notifier_block *head;
};

typedef struct page___52 *pgtable_t___51;

struct address_space___51;

struct dev_pagemap___51;

struct page___52 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___51 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___52 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___51 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___51 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___51 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___51;

struct lruvec___51 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___51 *pgdat;
};

struct zone___51 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___51 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___51 {
	struct zone___51 *zone;
	int zone_idx;
};

struct zonelist___51 {
	struct zoneref___51 _zonerefs[25];
};

struct pglist_data___51 {
	struct zone___51 node_zones[3];
	struct zonelist___51 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___52 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___52 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___51 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct key___52;

struct ucounts___42;

struct user_namespace___42 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___42 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___4 ns;
	long unsigned int flags;
	struct key___52 *persistent_keyring_register;
	struct rw_semaphore___52 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___42 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_root___49;

struct kernfs_elem_dir___49 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___49 *root;
};

struct kernfs_node___49;

struct kernfs_syscall_ops___49;

struct kernfs_root___49 {
	struct kernfs_node___49 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___49 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___49 {
	struct kernfs_node___49 *target_kn;
};

struct kernfs_ops___49;

struct kernfs_elem_attr___49 {
	const struct kernfs_ops___49 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___49 *notify_next;
};

struct kernfs_node___49 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___49 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___49 dir;
		struct kernfs_elem_symlink___49 symlink;
		struct kernfs_elem_attr___49 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___49;

struct kernfs_ops___49 {
	int (*open)(struct kernfs_open_file___49 *);
	void (*release)(struct kernfs_open_file___49 *);
	int (*seq_show)(struct seq_file___49 *, void *);
	void * (*seq_start)(struct seq_file___49 *, loff_t *);
	void * (*seq_next)(struct seq_file___49 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___49 *, void *);
	ssize_t (*read)(struct kernfs_open_file___49 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___49 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___49 *, struct vm_area_struct___52 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___49 *, struct poll_table_struct___34 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___49 {
	int (*remount_fs)(struct kernfs_root___49 *, int *, char *);
	int (*show_options)(struct seq_file___49 *, struct kernfs_root___49 *);
	int (*mkdir)(struct kernfs_node___49 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___49 *);
	int (*rename)(struct kernfs_node___49 *, struct kernfs_node___49 *, const char *);
	int (*show_path)(struct seq_file___49 *, struct kernfs_node___49 *, struct kernfs_root___49 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___46;

struct seq_file___49 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___46 *op;
	int poll_event;
	const struct file___52 *file;
	void *private;
};

struct vm_operations_struct___51;

struct kernfs_open_file___49 {
	struct kernfs_node___49 *kn;
	struct file___52 *file;
	struct seq_file___49 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___51 *vm_ops;
};

struct dentry___52;

struct path___51 {
	struct vfsmount *mnt;
	struct dentry___52 *dentry;
};

struct fown_struct___47 {
	rwlock_t lock;
	struct pid___47 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___52 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___51 f_path;
	struct inode___53 *f_inode;
	const struct file_operations___52 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___47 f_owner;
	const struct cred___51 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___51 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___51;

struct vm_operations_struct___51 {
	void (*open)(struct vm_area_struct___52 *);
	void (*close)(struct vm_area_struct___52 *);
	int (*split)(struct vm_area_struct___52 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___52 *);
	vm_fault_t (*fault)(struct vm_fault___51 *);
	vm_fault_t (*huge_fault)(struct vm_fault___51 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___51 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___52 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___51 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___51 *);
	int (*access)(struct vm_area_struct___52 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___52 *);
	int (*set_policy)(struct vm_area_struct___52 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___52 *, long unsigned int);
	struct page___52 * (*find_special_page)(struct vm_area_struct___52 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___33)(struct file___52 *, wait_queue_head_t *, struct poll_table_struct___34 *);

struct poll_table_struct___34 {
	poll_queue_proc___33 _qproc;
	__poll_t _key;
};

struct vm_area_struct___52 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___52 *vm_next;
	struct vm_area_struct___52 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___51 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___51 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___52 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___49;

struct bin_attribute___46;

struct attribute_group___46 {
	const char *name;
	umode_t (*is_visible)(struct kobject___49 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___49 *, struct bin_attribute___46 *, int);
	struct attribute **attrs;
	struct bin_attribute___46 **bin_attrs;
};

struct kset___48;

struct kobj_type___48;

struct kobject___49 {
	const char *name;
	struct list_head entry;
	struct kobject___49 *parent;
	struct kset___48 *kset;
	struct kobj_type___48 *ktype;
	struct kernfs_node___49 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___46 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___52 *, struct kobject___49 *, struct bin_attribute___46 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___52 *, struct kobject___49 *, struct bin_attribute___46 *, char *, loff_t, size_t);
	int (*mmap)(struct file___52 *, struct kobject___49 *, struct bin_attribute___46 *, struct vm_area_struct___52 *);
};

struct sysfs_ops___48 {
	ssize_t (*show)(struct kobject___49 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___49 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___48;

struct kset___48 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___49 kobj;
	const struct kset_uevent_ops___48 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___48 {
	void (*release)(struct kobject___49 *);
	const struct sysfs_ops___48 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___2 * (*child_ns_type)(struct kobject___49 *);
	const void * (*namespace)(struct kobject___49 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___48 {
	int (* const filter)(struct kset___48 *, struct kobject___49 *);
	const char * (* const name)(struct kset___48 *, struct kobject___49 *);
	int (* const uevent)(struct kset___48 *, struct kobject___49 *, struct kobj_uevent_env *);
};

struct kobj_attribute___49 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___49 *, struct kobj_attribute___49 *, char *);
	ssize_t (*store)(struct kobject___49 *, struct kobj_attribute___49 *, const char *, size_t);
};

struct device___45;

struct dev_pm_ops___45 {
	int (*prepare)(struct device___45 *);
	void (*complete)(struct device___45 *);
	int (*suspend)(struct device___45 *);
	int (*resume)(struct device___45 *);
	int (*freeze)(struct device___45 *);
	int (*thaw)(struct device___45 *);
	int (*poweroff)(struct device___45 *);
	int (*restore)(struct device___45 *);
	int (*suspend_late)(struct device___45 *);
	int (*resume_early)(struct device___45 *);
	int (*freeze_late)(struct device___45 *);
	int (*thaw_early)(struct device___45 *);
	int (*poweroff_late)(struct device___45 *);
	int (*restore_early)(struct device___45 *);
	int (*suspend_noirq)(struct device___45 *);
	int (*resume_noirq)(struct device___45 *);
	int (*freeze_noirq)(struct device___45 *);
	int (*thaw_noirq)(struct device___45 *);
	int (*poweroff_noirq)(struct device___45 *);
	int (*restore_noirq)(struct device___45 *);
	int (*runtime_suspend)(struct device___45 *);
	int (*runtime_resume)(struct device___45 *);
	int (*runtime_idle)(struct device___45 *);
};

struct dev_pm_qos___4;

struct dev_pm_info___45 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___45 *, s32);
	struct dev_pm_qos___4 *qos;
};

struct device_type___45;

struct bus_type___45;

struct device_driver___45;

struct dev_pm_domain___45;

struct class___45;

struct device___45 {
	struct device___45 *parent;
	struct device_private *p;
	struct kobject___49 kobj;
	const char *init_name;
	const struct device_type___45 *type;
	struct mutex mutex;
	struct bus_type___45 *bus;
	struct device_driver___45 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___45 power;
	struct dev_pm_domain___45 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___45 *class;
	const struct attribute_group___46 **groups;
	void (*release)(struct device___45 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct pm_qos_constraints___4 {
	struct plist_head list;
	s32 target_value;
	s32 default_value;
	s32 no_constraint_value;
	enum pm_qos_type type;
	struct blocking_notifier_head___51 *notifiers;
};

struct dev_pm_qos_request___4;

struct dev_pm_qos___4 {
	struct pm_qos_constraints___4 resume_latency;
	struct pm_qos_constraints___4 latency_tolerance;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___4 *resume_latency_req;
	struct dev_pm_qos_request___4 *latency_tolerance_req;
	struct dev_pm_qos_request___4 *flags_req;
};

struct dev_pm_domain___45 {
	struct dev_pm_ops___45 ops;
	void (*detach)(struct device___45 *, bool);
	int (*activate)(struct device___45 *);
	void (*sync)(struct device___45 *);
	void (*dismiss)(struct device___45 *);
};

struct upid___47 {
	int nr;
	struct pid_namespace___47 *ns;
};

struct pid_namespace___47 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___52 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___47 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___52 *proc_self;
	struct dentry___52 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___42 *user_ns;
	struct ucounts___42 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___4 ns;
};

struct pid___47 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___47 numbers[1];
};

struct user_struct___51 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___52 *uid_keyring;
	struct key___52 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___51;

struct mm_struct___51 {
	struct {
		struct vm_area_struct___52 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___52 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___52 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___51 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___52 *owner;
		struct user_namespace___42 *user_ns;
		struct file___52 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___51 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___51 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___52 *session_keyring;
	struct key___52 *process_keyring;
	struct key___52 *thread_keyring;
	struct key___52 *request_key_auth;
	void *security;
	struct user_struct___51 *user;
	struct user_namespace___42 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___40;

struct nsproxy___50 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___47 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___40 *cgroup_ns;
};

struct signal_struct___49 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___52 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___52 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___47 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___47 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___51 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___47 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___40;

struct cgroup___40;

struct css_set___40 {
	struct cgroup_subsys_state___40 *subsys[13];
	refcount_t refcount;
	struct css_set___40 *dom_cset;
	struct cgroup___40 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___40 *mg_src_cgrp;
	struct cgroup___40 *mg_dst_cgrp;
	struct css_set___40 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___33 {
	struct pmu___33 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___52 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___33 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

union thread_union___49 {
	struct task_struct___52 task;
	long unsigned int stack[8192];
};

struct bus_type___45 {
	const char *name;
	const char *dev_name;
	struct device___45 *dev_root;
	const struct attribute_group___46 **bus_groups;
	const struct attribute_group___46 **dev_groups;
	const struct attribute_group___46 **drv_groups;
	int (*match)(struct device___45 *, struct device_driver___45 *);
	int (*uevent)(struct device___45 *, struct kobj_uevent_env *);
	int (*probe)(struct device___45 *);
	int (*remove)(struct device___45 *);
	void (*shutdown)(struct device___45 *);
	int (*online)(struct device___45 *);
	int (*offline)(struct device___45 *);
	int (*suspend)(struct device___45 *, pm_message_t);
	int (*resume)(struct device___45 *);
	int (*num_vf)(struct device___45 *);
	int (*dma_configure)(struct device___45 *);
	const struct dev_pm_ops___45 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___45 {
	const char *name;
	struct bus_type___45 *bus;
	struct module___47 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___45 *);
	int (*remove)(struct device___45 *);
	void (*shutdown)(struct device___45 *);
	int (*suspend)(struct device___45 *, pm_message_t);
	int (*resume)(struct device___45 *);
	const struct attribute_group___46 **groups;
	const struct dev_pm_ops___45 *pm;
	void (*coredump)(struct device___45 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___45 {
	const char *name;
	const struct attribute_group___46 **groups;
	int (*uevent)(struct device___45 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___45 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___45 *);
	const struct dev_pm_ops___45 *pm;
};

struct module_kobject___44 {
	struct kobject___49 kobj;
	struct module___47 *mod;
	struct kobject___49 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___44 {
	struct module___47 *mod;
	struct latch_tree_node node;
};

struct module_layout___44 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___44 mtn;
};

struct module_attribute___44;

struct kernel_param___44;

struct module___47 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___44 mkobj;
	struct module_attribute___44 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___49 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___44 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___44 core_layout;
	struct module_layout___44 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___28 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct class___45 {
	const char *name;
	struct module___47 *owner;
	const struct attribute_group___46 **class_groups;
	const struct attribute_group___46 **dev_groups;
	struct kobject___49 *dev_kobj;
	int (*dev_uevent)(struct device___45 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___45 *, umode_t *);
	void (*class_release)(struct class___45 *);
	void (*dev_release)(struct device___45 *);
	int (*shutdown_pre)(struct device___45 *);
	const struct kobj_ns_type_operations___2 *ns_type;
	const void * (*namespace)(struct device___45 *);
	const struct dev_pm_ops___45 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

enum {
	PM_QOS_RESERVED = 0,
	PM_QOS_CPU_DMA_LATENCY = 1,
	PM_QOS_NETWORK_LATENCY = 2,
	PM_QOS_NETWORK_THROUGHPUT = 3,
	PM_QOS_MEMORY_BANDWIDTH = 4,
	PM_QOS_NUM_CLASSES = 5,
};

struct pm_qos_request {
	struct plist_node node;
	int pm_qos_class;
	struct delayed_work work;
};

struct dev_pm_qos_request___4 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___45 *dev;
};

enum pm_qos_req_action {
	PM_QOS_ADD_REQ = 0,
	PM_QOS_UPDATE_REQ = 1,
	PM_QOS_REMOVE_REQ = 2,
};

struct dentry_operations___51;

struct super_block___52;

struct dentry___52 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___52 *d_parent;
	struct qstr d_name;
	struct inode___53 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___51 *d_op;
	struct super_block___52 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___51;

struct address_space___51 {
	struct inode___53 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___52 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___51 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___51;

struct block_device___52;

struct inode___53 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___51 *i_op;
	struct super_block___52 *i_sb;
	struct address_space___51 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___52 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___52 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___51 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___52 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___51 {
	int (*d_revalidate)(struct dentry___52 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___52 *, unsigned int);
	int (*d_hash)(const struct dentry___52 *, struct qstr *);
	int (*d_compare)(const struct dentry___52 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___52 *);
	int (*d_init)(struct dentry___52 *);
	void (*d_release)(struct dentry___52 *);
	void (*d_prune)(struct dentry___52 *);
	void (*d_iput)(struct dentry___52 *, struct inode___53 *);
	char * (*d_dname)(struct dentry___52 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___51 *);
	int (*d_manage)(const struct path___51 *, bool);
	struct dentry___52 * (*d_real)(struct dentry___52 *, const struct inode___53 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___51;

struct mem_dqinfo___51 {
	struct quota_format_type___51 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___51;

struct quota_info___51 {
	unsigned int flags;
	struct rw_semaphore___52 dqio_sem;
	struct inode___53 *files[3];
	struct mem_dqinfo___51 info[3];
	const struct quota_format_ops___51 *ops[3];
};

struct rcuwait___51 {
	struct task_struct___52 *task;
};

struct percpu_rw_semaphore___51 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___52 rw_sem;
	struct rcuwait___51 writer;
	int readers_block;
};

struct sb_writers___51 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___51 rw_sem[3];
};

struct file_system_type___51;

struct super_operations___51;

struct dquot_operations___51;

struct quotactl_ops___51;

struct super_block___52 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___51 *s_type;
	const struct super_operations___51 *s_op;
	const struct dquot_operations___51 *dq_op;
	const struct quotactl_ops___51 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___52 *s_root;
	struct rw_semaphore___52 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___52 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___51 s_dquot;
	struct sb_writers___51 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___51 *s_d_op;
	int cleancache_poolid;
	struct shrinker___20 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___42 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

typedef int (*dev_page_fault_t___51)(struct vm_area_struct___52 *, long unsigned int, const struct page___52 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___51)(struct page___52 *, void *);

struct dev_pagemap___51 {
	dev_page_fault_t___51 page_fault;
	dev_page_free_t___51 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___45 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___51 {
	struct task_struct___52 *task;
	struct core_thread___51 *next;
};

struct core_state___51 {
	atomic_t nr_threads;
	struct core_thread___51 dumper;
	struct completion startup;
};

struct vm_fault___51 {
	struct vm_area_struct___52 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___52 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___52 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___51 prealloc_pte;
};

struct kiocb___52 {
	struct file___52 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___52 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___52 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___52 *ia_file;
};

struct dquot___51 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___52 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___51 {
	int qf_fmt_id;
	const struct quota_format_ops___51 *qf_ops;
	struct module___47 *qf_owner;
	struct quota_format_type___51 *qf_next;
};

struct quota_format_ops___51 {
	int (*check_quota_file)(struct super_block___52 *, int);
	int (*read_file_info)(struct super_block___52 *, int);
	int (*write_file_info)(struct super_block___52 *, int);
	int (*free_file_info)(struct super_block___52 *, int);
	int (*read_dqblk)(struct dquot___51 *);
	int (*commit_dqblk)(struct dquot___51 *);
	int (*release_dqblk)(struct dquot___51 *);
	int (*get_next_id)(struct super_block___52 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___51 {
	int (*write_dquot)(struct dquot___51 *);
	struct dquot___51 * (*alloc_dquot)(struct super_block___52 *, int);
	void (*destroy_dquot)(struct dquot___51 *);
	int (*acquire_dquot)(struct dquot___51 *);
	int (*release_dquot)(struct dquot___51 *);
	int (*mark_dirty)(struct dquot___51 *);
	int (*write_info)(struct super_block___52 *, int);
	qsize_t * (*get_reserved_space)(struct inode___53 *);
	int (*get_projid)(struct inode___53 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___53 *, qsize_t *);
	int (*get_next_id)(struct super_block___52 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___51 {
	int (*quota_on)(struct super_block___52 *, int, int, const struct path___51 *);
	int (*quota_off)(struct super_block___52 *, int);
	int (*quota_enable)(struct super_block___52 *, unsigned int);
	int (*quota_disable)(struct super_block___52 *, unsigned int);
	int (*quota_sync)(struct super_block___52 *, int);
	int (*set_info)(struct super_block___52 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___52 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___52 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___52 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___52 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___52 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___51 {
	int (*writepage)(struct page___52 *, struct writeback_control___3 *);
	int (*readpage)(struct file___52 *, struct page___52 *);
	int (*writepages)(struct address_space___51 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___52 *);
	int (*readpages)(struct file___52 *, struct address_space___51 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___52 *, struct address_space___51 *, loff_t, unsigned int, unsigned int, struct page___52 **, void **);
	int (*write_end)(struct file___52 *, struct address_space___51 *, loff_t, unsigned int, unsigned int, struct page___52 *, void *);
	sector_t (*bmap)(struct address_space___51 *, sector_t);
	void (*invalidatepage)(struct page___52 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___52 *, gfp_t);
	void (*freepage)(struct page___52 *);
	ssize_t (*direct_IO)(struct kiocb___52 *, struct iov_iter___24 *);
	int (*migratepage)(struct address_space___51 *, struct page___52 *, struct page___52 *, enum migrate_mode);
	bool (*isolate_page)(struct page___52 *, isolate_mode_t);
	void (*putback_page)(struct page___52 *);
	int (*launder_page)(struct page___52 *);
	int (*is_partially_uptodate)(struct page___52 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___52 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___51 *, struct page___52 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___52 *, sector_t *);
	void (*swap_deactivate)(struct file___52 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___52 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___53 *bd_inode;
	struct super_block___52 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___52 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___51 {
	struct dentry___52 * (*lookup)(struct inode___53 *, struct dentry___52 *, unsigned int);
	const char * (*get_link)(struct dentry___52 *, struct inode___53 *, struct delayed_call *);
	int (*permission)(struct inode___53 *, int);
	struct posix_acl * (*get_acl)(struct inode___53 *, int);
	int (*readlink)(struct dentry___52 *, char *, int);
	int (*create)(struct inode___53 *, struct dentry___52 *, umode_t, bool);
	int (*link)(struct dentry___52 *, struct inode___53 *, struct dentry___52 *);
	int (*unlink)(struct inode___53 *, struct dentry___52 *);
	int (*symlink)(struct inode___53 *, struct dentry___52 *, const char *);
	int (*mkdir)(struct inode___53 *, struct dentry___52 *, umode_t);
	int (*rmdir)(struct inode___53 *, struct dentry___52 *);
	int (*mknod)(struct inode___53 *, struct dentry___52 *, umode_t, dev_t);
	int (*rename)(struct inode___53 *, struct dentry___52 *, struct inode___53 *, struct dentry___52 *, unsigned int);
	int (*setattr)(struct dentry___52 *, struct iattr___52 *);
	int (*getattr)(const struct path___51 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___52 *, char *, size_t);
	int (*fiemap)(struct inode___53 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___53 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___53 *, struct dentry___52 *, struct file___52 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___53 *, struct dentry___52 *, umode_t);
	int (*set_acl)(struct inode___53 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___51 {
	void (*fl_copy_lock)(struct file_lock___52 *, struct file_lock___52 *);
	void (*fl_release_private)(struct file_lock___52 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___51;

struct file_lock___52 {
	struct file_lock___52 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___52 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___51 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___51 *fl_ops;
	const struct lock_manager_operations___51 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___51 {
	int (*lm_compare_owner)(struct file_lock___52 *, struct file_lock___52 *);
	long unsigned int (*lm_owner_key)(struct file_lock___52 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___52 *);
	int (*lm_grant)(struct file_lock___52 *, int);
	bool (*lm_break)(struct file_lock___52 *);
	int (*lm_change)(struct file_lock___52 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___52 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___51 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___51 *fa_next;
	struct file___52 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___51 {
	const char *name;
	int fs_flags;
	struct dentry___52 * (*mount)(struct file_system_type___51 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___52 *);
	struct module___47 *owner;
	struct file_system_type___51 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___51 {
	struct inode___53 * (*alloc_inode)(struct super_block___52 *);
	void (*destroy_inode)(struct inode___53 *);
	void (*dirty_inode)(struct inode___53 *, int);
	int (*write_inode)(struct inode___53 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___53 *);
	void (*evict_inode)(struct inode___53 *);
	void (*put_super)(struct super_block___52 *);
	int (*sync_fs)(struct super_block___52 *, int);
	int (*freeze_super)(struct super_block___52 *);
	int (*freeze_fs)(struct super_block___52 *);
	int (*thaw_super)(struct super_block___52 *);
	int (*unfreeze_fs)(struct super_block___52 *);
	int (*statfs)(struct dentry___52 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___52 *, int *, char *);
	void (*umount_begin)(struct super_block___52 *);
	int (*show_options)(struct seq_file___49 *, struct dentry___52 *);
	int (*show_devname)(struct seq_file___49 *, struct dentry___52 *);
	int (*show_path)(struct seq_file___49 *, struct dentry___52 *);
	int (*show_stats)(struct seq_file___49 *, struct dentry___52 *);
	ssize_t (*quota_read)(struct super_block___52 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___52 *, int, const char *, size_t, loff_t);
	struct dquot___51 ** (*get_dquots)(struct inode___53 *);
	int (*bdev_try_to_free_page)(struct super_block___52 *, struct page___52 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___52 *, struct shrink_control___20 *);
	long int (*free_cached_objects)(struct super_block___52 *, struct shrink_control___20 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct miscdevice___2 {
	int minor;
	const char *name;
	const struct file_operations___52 *fops;
	struct list_head list;
	struct device___45 *parent;
	struct device___45 *this_device;
	const struct attribute_group___46 **groups;
	const char *nodename;
	umode_t mode;
};

typedef int (*key_restrict_link_func_t___51)(struct key___52 *, const struct key_type *, const union key_payload *, struct key___52 *);

struct key_restriction___52;

struct key___52 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___52 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___52 *restrict_link;
};

struct key_restriction___52 {
	key_restrict_link_func_t___51 check;
	struct key___52 *key;
	struct key_type *keytype;
};

struct seq_operations___46 {
	void * (*start)(struct seq_file___49 *, loff_t *);
	void (*stop)(struct seq_file___49 *, void *);
	void * (*next)(struct seq_file___49 *, void *, loff_t *);
	int (*show)(struct seq_file___49 *, void *);
};

typedef void compound_page_dtor___51(struct page___52 *);

struct cgroup_namespace___40 {
	refcount_t count;
	struct ns_common___4 ns;
	struct user_namespace___42 *user_ns;
	struct ucounts___42 *ucounts;
	struct css_set___40 *root_cset;
};

struct ucounts___42 {
	struct hlist_node node;
	struct user_namespace___42 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct kernel_param_ops___44 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___44 *);
	int (*get)(char *, const struct kernel_param___44 *);
	void (*free)(void *);
};

struct kparam_array___44;

struct kernel_param___44 {
	const char *name;
	struct module___47 *mod;
	const struct kernel_param_ops___44 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___44 *arr;
	};
};

struct kparam_array___44 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___44 *ops;
	void *elem;
};

struct module_attribute___44 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___44 *, struct module_kobject___44 *, char *);
	ssize_t (*store)(struct module_attribute___44 *, struct module_kobject___44 *, const char *, size_t);
	void (*setup)(struct module___47 *, const char *);
	int (*test)(struct module___47 *);
	void (*free)(struct module___47 *);
};

struct trace_event_class___28;

struct trace_event_call___28 {
	struct list_head list;
	struct trace_event_class___28 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___4 *prog_array;
	int (*perf_perm)(struct trace_event_call___28 *, struct perf_event___33 *);
};

struct node___42 {
	struct device___45 dev;
};

struct bpf_map___40;

struct bpf_map_ops___40 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___40 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___40 *, struct file___52 *);
	void (*map_free)(struct bpf_map___40 *);
	int (*map_get_next_key)(struct bpf_map___40 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___40 *);
	void * (*map_lookup_elem)(struct bpf_map___40 *, void *);
	int (*map_update_elem)(struct bpf_map___40 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___40 *, void *);
	int (*map_push_elem)(struct bpf_map___40 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___40 *, void *);
	int (*map_peek_elem)(struct bpf_map___40 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___40 *, struct file___52 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___40 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___40 *, void *, struct seq_file___49 *);
	int (*map_check_btf)(const struct bpf_map___40 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___40 {
	const struct bpf_map_ops___40 *ops;
	struct bpf_map___40 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___51 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___40;

typedef void (*kthread_work_func_t___40)(struct kthread_work___40 *);

struct kthread_worker___40;

struct kthread_work___40 {
	struct list_head node;
	kthread_work_func_t___40 func;
	struct kthread_worker___40 *worker;
	int canceling;
};

struct kthread_worker___40 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___52 *task;
	struct kthread_work___40 *current_work;
};

struct kthread_delayed_work___40 {
	struct kthread_work___40 work;
	struct timer_list timer;
};

struct psi_group___40 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___40 *poll_kworker;
	struct kthread_delayed_work___40 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___40 {
	struct kernfs_node___49 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___40;

struct cgroup_subsys_state___40 {
	struct cgroup___40 *cgroup;
	struct cgroup_subsys___40 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___40 *parent;
};

struct cgroup_root___40;

struct cgroup_rstat_cpu___40;

struct cgroup___40 {
	struct cgroup_subsys_state___40 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___49 *kn;
	struct cgroup_file___40 procs_file;
	struct cgroup_file___40 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___40 *subsys[13];
	struct cgroup_root___40 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___40 *dom_cgrp;
	struct cgroup_rstat_cpu___40 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___4 bpf;
	atomic_t congestion_count;
	struct cgroup___40 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___40 psi;
	int ancestor_ids[0];
};

struct cftype___40;

struct cgroup_subsys___40 {
	struct cgroup_subsys_state___40 * (*css_alloc)(struct cgroup_subsys_state___40 *);
	int (*css_online)(struct cgroup_subsys_state___40 *);
	void (*css_offline)(struct cgroup_subsys_state___40 *);
	void (*css_released)(struct cgroup_subsys_state___40 *);
	void (*css_free)(struct cgroup_subsys_state___40 *);
	void (*css_reset)(struct cgroup_subsys_state___40 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___40 *, int);
	int (*css_extra_stat_show)(struct seq_file___49 *, struct cgroup_subsys_state___40 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___52 *);
	void (*cancel_fork)(struct task_struct___52 *);
	void (*fork)(struct task_struct___52 *);
	void (*exit)(struct task_struct___52 *);
	void (*free)(struct task_struct___52 *);
	void (*bind)(struct cgroup_subsys_state___40 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___40 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___40 *dfl_cftypes;
	struct cftype___40 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___40 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___40 *updated_children;
	struct cgroup___40 *updated_next;
};

struct cgroup_root___40 {
	struct kernfs_root___49 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___40 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___40 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___40 *ss;
	struct list_head node;
	struct kernfs_ops___49 *kf_ops;
	int (*open)(struct kernfs_open_file___49 *);
	void (*release)(struct kernfs_open_file___49 *);
	u64 (*read_u64)(struct cgroup_subsys_state___40 *, struct cftype___40 *);
	s64 (*read_s64)(struct cgroup_subsys_state___40 *, struct cftype___40 *);
	int (*seq_show)(struct seq_file___49 *, void *);
	void * (*seq_start)(struct seq_file___49 *, loff_t *);
	void * (*seq_next)(struct seq_file___49 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___49 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___40 *, struct cftype___40 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___40 *, struct cftype___40 *, s64);
	ssize_t (*write)(struct kernfs_open_file___49 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___49 *, struct poll_table_struct___34 *);
};

struct perf_cpu_context___33;

struct pmu___33 {
	struct list_head entry;
	struct module___47 *module;
	struct device___45 *dev;
	const struct attribute_group___46 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___33 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___33 *);
	void (*pmu_disable)(struct pmu___33 *);
	int (*event_init)(struct perf_event___33 *);
	void (*event_mapped)(struct perf_event___33 *, struct mm_struct___51 *);
	void (*event_unmapped)(struct perf_event___33 *, struct mm_struct___51 *);
	int (*add)(struct perf_event___33 *, int);
	void (*del)(struct perf_event___33 *, int);
	void (*start)(struct perf_event___33 *, int);
	void (*stop)(struct perf_event___33 *, int);
	void (*read)(struct perf_event___33 *);
	void (*start_txn)(struct pmu___33 *, unsigned int);
	int (*commit_txn)(struct pmu___33 *);
	void (*cancel_txn)(struct pmu___33 *);
	int (*event_idx)(struct perf_event___33 *);
	void (*sched_task)(struct perf_event_context___33 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___33 *);
	int (*filter_match)(struct perf_event___33 *);
	int (*check_period)(struct perf_event___33 *, u64);
};

struct perf_cpu_context___33 {
	struct perf_event_context___33 ctx;
	struct perf_event_context___33 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___33 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___33 {
	struct cgroup_subsys_state___40 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___28 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___28 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___28 *);
	struct list_head * (*get_fields)(struct trace_event_call___28 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___28 *);
};

struct pm_qos_object {
	struct pm_qos_constraints___4 *constraints;
	struct miscdevice___2 pm_qos_power_miscdev;
	char *name;
};

struct va_format {
	const char *fmt;
	va_list *va;
};

struct file___53;

struct kiocb___53;

struct vm_area_struct___53;

struct inode___54;

struct file_lock___53;

struct page___53;

struct seq_file___50;

struct file_operations___53 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___53 *, loff_t, int);
	ssize_t (*read)(struct file___53 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___53 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___53 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___53 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___53 *, bool);
	int (*iterate)(struct file___53 *, struct dir_context *);
	int (*iterate_shared)(struct file___53 *, struct dir_context *);
	__poll_t (*poll)(struct file___53 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___53 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___53 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___53 *, struct vm_area_struct___53 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___54 *, struct file___53 *);
	int (*flush)(struct file___53 *, fl_owner_t);
	int (*release)(struct inode___54 *, struct file___53 *);
	int (*fsync)(struct file___53 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___53 *, int);
	int (*lock)(struct file___53 *, int, struct file_lock___53 *);
	ssize_t (*sendpage)(struct file___53 *, struct page___53 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___53 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___53 *, int, struct file_lock___53 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___53 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___53 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___53 *, long int, struct file_lock___53 **, void **);
	long int (*fallocate)(struct file___53 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___50 *, struct file___53 *);
	ssize_t (*copy_file_range)(struct file___53 *, loff_t, struct file___53 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___53 *, loff_t, struct file___53 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___53 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___52 {
	u64 seqnum;
	struct vm_area_struct___53 *vmas[4];
};

struct page_frag___52 {
	struct page___53 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___52;

struct mem_cgroup___21;

struct cred___52;

struct nsproxy___51;

struct bio_list___22;

struct backing_dev_info___22;

struct css_set___41;

struct task_struct___53 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___53 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___52 *mm;
	struct mm_struct___52 *active_mm;
	struct vmacache___52 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___53 *real_parent;
	struct task_struct___53 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___53 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___21 *active_memcg;
	long int rh_reserved2;
	struct pid___47 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___47 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___47 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___52 *ptracer_cred;
	const struct cred___52 *real_cred;
	const struct cred___52 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___51 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___53 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___22 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___22 *backing_dev_info;
	struct io_context___12 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___41 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___52 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___21 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___53 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___33 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___53 *pgtable_t___52;

struct address_space___52;

struct dev_pagemap___52;

struct page___53 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___52 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___53 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___52 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___52 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___52 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___21 *mem_cgroup;
};

struct pglist_data___52;

struct lruvec___52 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___52 *pgdat;
};

struct zone___52 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___52 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___52 {
	struct zone___52 *zone;
	int zone_idx;
};

struct zonelist___52 {
	struct zoneref___52 _zonerefs[25];
};

struct pglist_data___52 {
	struct zone___52 node_zones[3];
	struct zonelist___52 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___53 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___53 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___52 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___53 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___53 *owner;
};

struct secondary_data___53 {
	void *stack;
	struct task_struct___53 *task;
	long int status;
};

struct blocking_notifier_head___52 {
	struct rw_semaphore___53 rwsem;
	struct notifier_block *head;
};

struct key___53;

struct ucounts___43;

struct user_namespace___43 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___43 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___4 ns;
	long unsigned int flags;
	struct key___53 *persistent_keyring_register;
	struct rw_semaphore___53 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___43 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_root___50;

struct kernfs_elem_dir___50 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___50 *root;
};

struct kernfs_node___50;

struct kernfs_syscall_ops___50;

struct kernfs_root___50 {
	struct kernfs_node___50 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___50 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___50 {
	struct kernfs_node___50 *target_kn;
};

struct kernfs_ops___50;

struct kernfs_elem_attr___50 {
	const struct kernfs_ops___50 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___50 *notify_next;
};

struct kernfs_node___50 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___50 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___50 dir;
		struct kernfs_elem_symlink___50 symlink;
		struct kernfs_elem_attr___50 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___50;

struct kernfs_ops___50 {
	int (*open)(struct kernfs_open_file___50 *);
	void (*release)(struct kernfs_open_file___50 *);
	int (*seq_show)(struct seq_file___50 *, void *);
	void * (*seq_start)(struct seq_file___50 *, loff_t *);
	void * (*seq_next)(struct seq_file___50 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___50 *, void *);
	ssize_t (*read)(struct kernfs_open_file___50 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___50 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___50 *, struct vm_area_struct___53 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___50 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___50 {
	int (*remount_fs)(struct kernfs_root___50 *, int *, char *);
	int (*show_options)(struct seq_file___50 *, struct kernfs_root___50 *);
	int (*mkdir)(struct kernfs_node___50 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___50 *);
	int (*rename)(struct kernfs_node___50 *, struct kernfs_node___50 *, const char *);
	int (*show_path)(struct seq_file___50 *, struct kernfs_node___50 *, struct kernfs_root___50 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___47;

struct seq_file___50 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___47 *op;
	int poll_event;
	const struct file___53 *file;
	void *private;
};

struct vm_operations_struct___52;

struct kernfs_open_file___50 {
	struct kernfs_node___50 *kn;
	struct file___53 *file;
	struct seq_file___50 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___52 *vm_ops;
};

struct dentry___53;

struct path___52 {
	struct vfsmount *mnt;
	struct dentry___53 *dentry;
};

struct file___53 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___52 f_path;
	struct inode___54 *f_inode;
	const struct file_operations___53 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___47 f_owner;
	const struct cred___52 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___52 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___52;

struct vm_operations_struct___52 {
	void (*open)(struct vm_area_struct___53 *);
	void (*close)(struct vm_area_struct___53 *);
	int (*split)(struct vm_area_struct___53 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___53 *);
	vm_fault_t (*fault)(struct vm_fault___52 *);
	vm_fault_t (*huge_fault)(struct vm_fault___52 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___52 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___53 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___52 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___52 *);
	int (*access)(struct vm_area_struct___53 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___53 *);
	int (*set_policy)(struct vm_area_struct___53 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___53 *, long unsigned int);
	struct page___53 * (*find_special_page)(struct vm_area_struct___53 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_area_struct___53 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___53 *vm_next;
	struct vm_area_struct___53 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___52 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___52 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___53 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___50;

struct bin_attribute___47;

struct attribute_group___47 {
	const char *name;
	umode_t (*is_visible)(struct kobject___50 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___50 *, struct bin_attribute___47 *, int);
	struct attribute **attrs;
	struct bin_attribute___47 **bin_attrs;
};

struct kset___49;

struct kobj_type___49;

struct kobject___50 {
	const char *name;
	struct list_head entry;
	struct kobject___50 *parent;
	struct kset___49 *kset;
	struct kobj_type___49 *ktype;
	struct kernfs_node___50 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___47 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___53 *, struct kobject___50 *, struct bin_attribute___47 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___53 *, struct kobject___50 *, struct bin_attribute___47 *, char *, loff_t, size_t);
	int (*mmap)(struct file___53 *, struct kobject___50 *, struct bin_attribute___47 *, struct vm_area_struct___53 *);
};

struct sysfs_ops___49 {
	ssize_t (*show)(struct kobject___50 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___50 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___49;

struct kset___49 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___50 kobj;
	const struct kset_uevent_ops___49 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___49 {
	void (*release)(struct kobject___50 *);
	const struct sysfs_ops___49 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___2 * (*child_ns_type)(struct kobject___50 *);
	const void * (*namespace)(struct kobject___50 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___49 {
	int (* const filter)(struct kset___49 *, struct kobject___50 *);
	const char * (* const name)(struct kset___49 *, struct kobject___50 *);
	int (* const uevent)(struct kset___49 *, struct kobject___50 *, struct kobj_uevent_env *);
};

struct kobj_attribute___50 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___50 *, struct kobj_attribute___50 *, char *);
	ssize_t (*store)(struct kobject___50 *, struct kobj_attribute___50 *, const char *, size_t);
};

struct dentry_operations___52;

struct super_block___53;

struct dentry___53 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___53 *d_parent;
	struct qstr d_name;
	struct inode___54 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___52 *d_op;
	struct super_block___53 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___52;

struct address_space___52 {
	struct inode___54 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___53 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___52 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___52;

struct bdi_writeback___22;

struct block_device___53;

struct inode___54 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___52 *i_op;
	struct super_block___53 *i_sb;
	struct address_space___52 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___53 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___22 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___53 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___52 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___53 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___52 {
	int (*d_revalidate)(struct dentry___53 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___53 *, unsigned int);
	int (*d_hash)(const struct dentry___53 *, struct qstr *);
	int (*d_compare)(const struct dentry___53 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___53 *);
	int (*d_init)(struct dentry___53 *);
	void (*d_release)(struct dentry___53 *);
	void (*d_prune)(struct dentry___53 *);
	void (*d_iput)(struct dentry___53 *, struct inode___54 *);
	char * (*d_dname)(struct dentry___53 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___52 *);
	int (*d_manage)(const struct path___52 *, bool);
	struct dentry___53 * (*d_real)(struct dentry___53 *, const struct inode___54 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___52;

struct mem_dqinfo___52 {
	struct quota_format_type___52 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___52;

struct quota_info___52 {
	unsigned int flags;
	struct rw_semaphore___53 dqio_sem;
	struct inode___54 *files[3];
	struct mem_dqinfo___52 info[3];
	const struct quota_format_ops___52 *ops[3];
};

struct rcuwait___52 {
	struct task_struct___53 *task;
};

struct percpu_rw_semaphore___52 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___53 rw_sem;
	struct rcuwait___52 writer;
	int readers_block;
};

struct sb_writers___52 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___52 rw_sem[3];
};

struct shrink_control___21;

struct shrinker___21 {
	long unsigned int (*count_objects)(struct shrinker___21 *, struct shrink_control___21 *);
	long unsigned int (*scan_objects)(struct shrinker___21 *, struct shrink_control___21 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___52;

struct super_operations___52;

struct dquot_operations___52;

struct quotactl_ops___52;

struct super_block___53 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___52 *s_type;
	const struct super_operations___52 *s_op;
	const struct dquot_operations___52 *dq_op;
	const struct quotactl_ops___52 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___53 *s_root;
	struct rw_semaphore___53 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___53 *s_bdev;
	struct backing_dev_info___22 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___52 s_dquot;
	struct sb_writers___52 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___52 *s_d_op;
	int cleancache_poolid;
	struct shrinker___21 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___43 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___21 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___21 *memcg;
};

struct cgroup___41;

struct cgroup_subsys___41;

struct cgroup_subsys_state___41 {
	struct cgroup___41 *cgroup;
	struct cgroup_subsys___41 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___41 *parent;
};

struct cgroup_file___41 {
	struct kernfs_node___50 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___21;

struct mem_cgroup___21 {
	struct cgroup_subsys_state___41 css;
	struct mem_cgroup_id___6 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___41 events_file;
	struct cgroup_file___41 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___53 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___21 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct core_state___52;

struct mm_struct___52 {
	struct {
		struct vm_area_struct___53 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___53 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___53 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___52 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___53 *owner;
		struct user_namespace___43 *user_ns;
		struct file___53 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___52 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___52)(struct vm_area_struct___53 *, long unsigned int, const struct page___53 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___52)(struct page___53 *, void *);

struct device___46;

struct dev_pagemap___52 {
	dev_page_fault_t___52 page_fault;
	dev_page_free_t___52 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___46 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___52 {
	struct task_struct___53 *task;
	struct core_thread___52 *next;
};

struct core_state___52 {
	atomic_t nr_threads;
	struct core_thread___52 dumper;
	struct completion startup;
};

struct vm_fault___52 {
	struct vm_area_struct___53 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___53 *cow_page;
	struct mem_cgroup___21 *memcg;
	struct page___53 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___52 prealloc_pte;
};

struct user_struct___52 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___53 *uid_keyring;
	struct key___53 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___52 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___53 *session_keyring;
	struct key___53 *process_keyring;
	struct key___53 *thread_keyring;
	struct key___53 *request_key_auth;
	void *security;
	struct user_struct___52 *user;
	struct user_namespace___43 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct uts_namespace___13;

struct cgroup_namespace___41;

struct nsproxy___51 {
	atomic_t count;
	struct uts_namespace___13 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___41 *cgroup_ns;
};

struct bio___22;

struct bio_list___22 {
	struct bio___22 *head;
	struct bio___22 *tail;
};

struct bdi_writeback_congested___22;

struct bdi_writeback___22 {
	struct backing_dev_info___22 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___22 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___41 *memcg_css;
	struct cgroup_subsys_state___41 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___22 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___22 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___46 *dev;
	struct device___46 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___53 *debug_dir;
	struct dentry___53 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___41 {
	struct cgroup_subsys_state___41 *subsys[13];
	refcount_t refcount;
	struct css_set___41 *dom_cset;
	struct cgroup___41 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___41 *mg_src_cgrp;
	struct cgroup___41 *mg_dst_cgrp;
	struct css_set___41 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct kiocb___53 {
	struct file___53 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___53 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___53 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___53 *ia_file;
};

struct dquot___52 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___53 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___52 {
	int qf_fmt_id;
	const struct quota_format_ops___52 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___52 *qf_next;
};

struct quota_format_ops___52 {
	int (*check_quota_file)(struct super_block___53 *, int);
	int (*read_file_info)(struct super_block___53 *, int);
	int (*write_file_info)(struct super_block___53 *, int);
	int (*free_file_info)(struct super_block___53 *, int);
	int (*read_dqblk)(struct dquot___52 *);
	int (*commit_dqblk)(struct dquot___52 *);
	int (*release_dqblk)(struct dquot___52 *);
	int (*get_next_id)(struct super_block___53 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___52 {
	int (*write_dquot)(struct dquot___52 *);
	struct dquot___52 * (*alloc_dquot)(struct super_block___53 *, int);
	void (*destroy_dquot)(struct dquot___52 *);
	int (*acquire_dquot)(struct dquot___52 *);
	int (*release_dquot)(struct dquot___52 *);
	int (*mark_dirty)(struct dquot___52 *);
	int (*write_info)(struct super_block___53 *, int);
	qsize_t * (*get_reserved_space)(struct inode___54 *);
	int (*get_projid)(struct inode___54 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___54 *, qsize_t *);
	int (*get_next_id)(struct super_block___53 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___52 {
	int (*quota_on)(struct super_block___53 *, int, int, const struct path___52 *);
	int (*quota_off)(struct super_block___53 *, int);
	int (*quota_enable)(struct super_block___53 *, unsigned int);
	int (*quota_disable)(struct super_block___53 *, unsigned int);
	int (*quota_sync)(struct super_block___53 *, int);
	int (*set_info)(struct super_block___53 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___53 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___53 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___53 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___53 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___53 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___21;

struct swap_info_struct___16;

struct address_space_operations___52 {
	int (*writepage)(struct page___53 *, struct writeback_control___21 *);
	int (*readpage)(struct file___53 *, struct page___53 *);
	int (*writepages)(struct address_space___52 *, struct writeback_control___21 *);
	int (*set_page_dirty)(struct page___53 *);
	int (*readpages)(struct file___53 *, struct address_space___52 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___53 *, struct address_space___52 *, loff_t, unsigned int, unsigned int, struct page___53 **, void **);
	int (*write_end)(struct file___53 *, struct address_space___52 *, loff_t, unsigned int, unsigned int, struct page___53 *, void *);
	sector_t (*bmap)(struct address_space___52 *, sector_t);
	void (*invalidatepage)(struct page___53 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___53 *, gfp_t);
	void (*freepage)(struct page___53 *);
	ssize_t (*direct_IO)(struct kiocb___53 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___52 *, struct page___53 *, struct page___53 *, enum migrate_mode);
	bool (*isolate_page)(struct page___53 *, isolate_mode_t);
	void (*putback_page)(struct page___53 *);
	int (*launder_page)(struct page___53 *);
	int (*is_partially_uptodate)(struct page___53 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___53 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___52 *, struct page___53 *);
	int (*swap_activate)(struct swap_info_struct___16 *, struct file___53 *, sector_t *);
	void (*swap_deactivate)(struct file___53 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___21 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___22 *wb;
	struct inode___54 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct swap_info_struct___16 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___53 *bdev;
	struct file___53 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___53 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___54 *bd_inode;
	struct super_block___53 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___53 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___22 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___52 {
	struct dentry___53 * (*lookup)(struct inode___54 *, struct dentry___53 *, unsigned int);
	const char * (*get_link)(struct dentry___53 *, struct inode___54 *, struct delayed_call *);
	int (*permission)(struct inode___54 *, int);
	struct posix_acl * (*get_acl)(struct inode___54 *, int);
	int (*readlink)(struct dentry___53 *, char *, int);
	int (*create)(struct inode___54 *, struct dentry___53 *, umode_t, bool);
	int (*link)(struct dentry___53 *, struct inode___54 *, struct dentry___53 *);
	int (*unlink)(struct inode___54 *, struct dentry___53 *);
	int (*symlink)(struct inode___54 *, struct dentry___53 *, const char *);
	int (*mkdir)(struct inode___54 *, struct dentry___53 *, umode_t);
	int (*rmdir)(struct inode___54 *, struct dentry___53 *);
	int (*mknod)(struct inode___54 *, struct dentry___53 *, umode_t, dev_t);
	int (*rename)(struct inode___54 *, struct dentry___53 *, struct inode___54 *, struct dentry___53 *, unsigned int);
	int (*setattr)(struct dentry___53 *, struct iattr___53 *);
	int (*getattr)(const struct path___52 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___53 *, char *, size_t);
	int (*fiemap)(struct inode___54 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___54 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___54 *, struct dentry___53 *, struct file___53 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___54 *, struct dentry___53 *, umode_t);
	int (*set_acl)(struct inode___54 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___52 {
	void (*fl_copy_lock)(struct file_lock___53 *, struct file_lock___53 *);
	void (*fl_release_private)(struct file_lock___53 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___52;

struct lock_manager_operations___52;

struct file_lock___53 {
	struct file_lock___53 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___53 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___52 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___52 *fl_ops;
	const struct lock_manager_operations___52 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___52 {
	int (*lm_compare_owner)(struct file_lock___53 *, struct file_lock___53 *);
	long unsigned int (*lm_owner_key)(struct file_lock___53 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___53 *);
	int (*lm_grant)(struct file_lock___53 *, int);
	bool (*lm_break)(struct file_lock___53 *);
	int (*lm_change)(struct file_lock___53 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___53 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___52 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___52 *fa_next;
	struct file___53 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___52 {
	const char *name;
	int fs_flags;
	struct dentry___53 * (*mount)(struct file_system_type___52 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___53 *);
	struct module___11 *owner;
	struct file_system_type___52 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___52 {
	struct inode___54 * (*alloc_inode)(struct super_block___53 *);
	void (*destroy_inode)(struct inode___54 *);
	void (*dirty_inode)(struct inode___54 *, int);
	int (*write_inode)(struct inode___54 *, struct writeback_control___21 *);
	int (*drop_inode)(struct inode___54 *);
	void (*evict_inode)(struct inode___54 *);
	void (*put_super)(struct super_block___53 *);
	int (*sync_fs)(struct super_block___53 *, int);
	int (*freeze_super)(struct super_block___53 *);
	int (*freeze_fs)(struct super_block___53 *);
	int (*thaw_super)(struct super_block___53 *);
	int (*unfreeze_fs)(struct super_block___53 *);
	int (*statfs)(struct dentry___53 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___53 *, int *, char *);
	void (*umount_begin)(struct super_block___53 *);
	int (*show_options)(struct seq_file___50 *, struct dentry___53 *);
	int (*show_devname)(struct seq_file___50 *, struct dentry___53 *);
	int (*show_path)(struct seq_file___50 *, struct dentry___53 *);
	int (*show_stats)(struct seq_file___50 *, struct dentry___53 *);
	ssize_t (*quota_read)(struct super_block___53 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___53 *, int, const char *, size_t, loff_t);
	struct dquot___52 ** (*get_dquots)(struct inode___54 *);
	int (*bdev_try_to_free_page)(struct super_block___53 *, struct page___53 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___53 *, struct shrink_control___21 *);
	long int (*free_cached_objects)(struct super_block___53 *, struct shrink_control___21 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___22(struct bio___22 *);

struct bio_vec___22 {
	struct page___53 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___22;

struct bio_set___22;

struct bio___22 {
	struct bio___22 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___22 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___22 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___22 *bi_io_vec;
	struct bio_set___22 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___22 bi_inline_vecs[0];
};

typedef int (*key_restrict_link_func_t___52)(struct key___53 *, const struct key_type *, const union key_payload *, struct key___53 *);

struct key_restriction___53;

struct key___53 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___53 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___53 *restrict_link;
};

struct key_restriction___53 {
	key_restrict_link_func_t___52 check;
	struct key___53 *key;
	struct key_type *keytype;
};

struct seq_operations___47 {
	void * (*start)(struct seq_file___50 *, loff_t *);
	void (*stop)(struct seq_file___50 *, void *);
	void * (*next)(struct seq_file___50 *, void *, loff_t *);
	int (*show)(struct seq_file___50 *, void *);
};

struct uts_namespace___13 {
	struct kref kref;
	struct new_utsname name;
	struct user_namespace___43 *user_ns;
	struct ucounts___43 *ucounts;
	struct ns_common___4 ns;
};

struct cgroup_namespace___41 {
	refcount_t count;
	struct ns_common___4 ns;
	struct user_namespace___43 *user_ns;
	struct ucounts___43 *ucounts;
	struct css_set___41 *root_cset;
};

struct ucounts___43 {
	struct hlist_node node;
	struct user_namespace___43 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___41;

struct bpf_map_ops___41 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___41 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___41 *, struct file___53 *);
	void (*map_free)(struct bpf_map___41 *);
	int (*map_get_next_key)(struct bpf_map___41 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___41 *);
	void * (*map_lookup_elem)(struct bpf_map___41 *, void *);
	int (*map_update_elem)(struct bpf_map___41 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___41 *, void *);
	int (*map_push_elem)(struct bpf_map___41 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___41 *, void *);
	int (*map_peek_elem)(struct bpf_map___41 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___41 *, struct file___53 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___41 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___41 *, void *, struct seq_file___50 *);
	int (*map_check_btf)(const struct bpf_map___41 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___41 {
	const struct bpf_map_ops___41 *ops;
	struct bpf_map___41 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___52 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___41;

typedef void (*kthread_work_func_t___41)(struct kthread_work___41 *);

struct kthread_worker___41;

struct kthread_work___41 {
	struct list_head node;
	kthread_work_func_t___41 func;
	struct kthread_worker___41 *worker;
	int canceling;
};

struct kthread_worker___41 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___53 *task;
	struct kthread_work___41 *current_work;
};

struct kthread_delayed_work___41 {
	struct kthread_work___41 work;
	struct timer_list timer;
};

struct psi_group___41 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___41 *poll_kworker;
	struct kthread_delayed_work___41 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___41;

struct cgroup_rstat_cpu___41;

struct cgroup___41 {
	struct cgroup_subsys_state___41 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___50 *kn;
	struct cgroup_file___41 procs_file;
	struct cgroup_file___41 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___41 *subsys[13];
	struct cgroup_root___41 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___41 *dom_cgrp;
	struct cgroup_rstat_cpu___41 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___4 bpf;
	atomic_t congestion_count;
	struct cgroup___41 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___41 psi;
	int ancestor_ids[0];
};

struct cftype___41;

struct cgroup_subsys___41 {
	struct cgroup_subsys_state___41 * (*css_alloc)(struct cgroup_subsys_state___41 *);
	int (*css_online)(struct cgroup_subsys_state___41 *);
	void (*css_offline)(struct cgroup_subsys_state___41 *);
	void (*css_released)(struct cgroup_subsys_state___41 *);
	void (*css_free)(struct cgroup_subsys_state___41 *);
	void (*css_reset)(struct cgroup_subsys_state___41 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___41 *, int);
	int (*css_extra_stat_show)(struct seq_file___50 *, struct cgroup_subsys_state___41 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___53 *);
	void (*cancel_fork)(struct task_struct___53 *);
	void (*fork)(struct task_struct___53 *);
	void (*exit)(struct task_struct___53 *);
	void (*free)(struct task_struct___53 *);
	void (*bind)(struct cgroup_subsys_state___41 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___41 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___41 *dfl_cftypes;
	struct cftype___41 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___41 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___41 *updated_children;
	struct cgroup___41 *updated_next;
};

struct cgroup_root___41 {
	struct kernfs_root___50 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___41 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___41 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___41 *ss;
	struct list_head node;
	struct kernfs_ops___50 *kf_ops;
	int (*open)(struct kernfs_open_file___50 *);
	void (*release)(struct kernfs_open_file___50 *);
	u64 (*read_u64)(struct cgroup_subsys_state___41 *, struct cftype___41 *);
	s64 (*read_s64)(struct cgroup_subsys_state___41 *, struct cftype___41 *);
	int (*seq_show)(struct seq_file___50 *, void *);
	void * (*seq_start)(struct seq_file___50 *, loff_t *);
	void * (*seq_next)(struct seq_file___50 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___50 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___41 *, struct cftype___41 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___41 *, struct cftype___41 *, s64);
	ssize_t (*write)(struct kernfs_open_file___50 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___50 *, struct poll_table_struct___6 *);
};

struct dev_pm_info___46 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___46 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___46;

struct bus_type___46;

struct device_driver___46;

struct dev_pm_domain___46;

struct class___46;

struct device___46 {
	struct device___46 *parent;
	struct device_private *p;
	struct kobject___50 kobj;
	const char *init_name;
	const struct device_type___46 *type;
	struct mutex mutex;
	struct bus_type___46 *bus;
	struct device_driver___46 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___46 power;
	struct dev_pm_domain___46 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___46 *class;
	const struct attribute_group___47 **groups;
	void (*release)(struct device___46 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

typedef void compound_page_dtor___52(struct page___53 *);

struct bdi_writeback_congested___22 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___22 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___22 {
	struct bio___22 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___22 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___22 bip_inline_vecs[0];
};

struct bio_set___22 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___22 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___21 {
	struct mem_cgroup___21 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___21 {
	struct lruvec___52 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___21 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___21 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct dev_pm_ops___46 {
	int (*prepare)(struct device___46 *);
	void (*complete)(struct device___46 *);
	int (*suspend)(struct device___46 *);
	int (*resume)(struct device___46 *);
	int (*freeze)(struct device___46 *);
	int (*thaw)(struct device___46 *);
	int (*poweroff)(struct device___46 *);
	int (*restore)(struct device___46 *);
	int (*suspend_late)(struct device___46 *);
	int (*resume_early)(struct device___46 *);
	int (*freeze_late)(struct device___46 *);
	int (*thaw_early)(struct device___46 *);
	int (*poweroff_late)(struct device___46 *);
	int (*restore_early)(struct device___46 *);
	int (*suspend_noirq)(struct device___46 *);
	int (*resume_noirq)(struct device___46 *);
	int (*freeze_noirq)(struct device___46 *);
	int (*thaw_noirq)(struct device___46 *);
	int (*poweroff_noirq)(struct device___46 *);
	int (*restore_noirq)(struct device___46 *);
	int (*runtime_suspend)(struct device___46 *);
	int (*runtime_resume)(struct device___46 *);
	int (*runtime_idle)(struct device___46 *);
};

struct dev_pm_domain___46 {
	struct dev_pm_ops___46 ops;
	void (*detach)(struct device___46 *, bool);
	int (*activate)(struct device___46 *);
	void (*sync)(struct device___46 *);
	void (*dismiss)(struct device___46 *);
};

struct bus_type___46 {
	const char *name;
	const char *dev_name;
	struct device___46 *dev_root;
	const struct attribute_group___47 **bus_groups;
	const struct attribute_group___47 **dev_groups;
	const struct attribute_group___47 **drv_groups;
	int (*match)(struct device___46 *, struct device_driver___46 *);
	int (*uevent)(struct device___46 *, struct kobj_uevent_env *);
	int (*probe)(struct device___46 *);
	int (*remove)(struct device___46 *);
	void (*shutdown)(struct device___46 *);
	int (*online)(struct device___46 *);
	int (*offline)(struct device___46 *);
	int (*suspend)(struct device___46 *, pm_message_t);
	int (*resume)(struct device___46 *);
	int (*num_vf)(struct device___46 *);
	int (*dma_configure)(struct device___46 *);
	const struct dev_pm_ops___46 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___46 {
	const char *name;
	struct bus_type___46 *bus;
	struct module___11 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___46 *);
	int (*remove)(struct device___46 *);
	void (*shutdown)(struct device___46 *);
	int (*suspend)(struct device___46 *, pm_message_t);
	int (*resume)(struct device___46 *);
	const struct attribute_group___47 **groups;
	const struct dev_pm_ops___46 *pm;
	void (*coredump)(struct device___46 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___46 {
	const char *name;
	const struct attribute_group___47 **groups;
	int (*uevent)(struct device___46 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___46 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___46 *);
	const struct dev_pm_ops___46 *pm;
};

struct class___46 {
	const char *name;
	struct module___11 *owner;
	const struct attribute_group___47 **class_groups;
	const struct attribute_group___47 **dev_groups;
	struct kobject___50 *dev_kobj;
	int (*dev_uevent)(struct device___46 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___46 *, umode_t *);
	void (*class_release)(struct class___46 *);
	void (*dev_release)(struct device___46 *);
	int (*shutdown_pre)(struct device___46 *);
	const struct kobj_ns_type_operations___2 *ns_type;
	const void * (*namespace)(struct device___46 *);
	const struct dev_pm_ops___46 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___43 {
	struct device___46 dev;
};

enum {
	TEST_NONE = 0,
	TEST_CORE = 1,
	TEST_CPUS = 2,
	TEST_PLATFORM = 3,
	TEST_DEVICES = 4,
	TEST_FREEZER = 5,
	__TEST_AFTER_LAST = 6,
};

struct module___48;

struct vc_data___2;

struct consw___4 {
	struct module___48 *owner;
	const char * (*con_startup)();
	void (*con_init)(struct vc_data___2 *, int);
	void (*con_deinit)(struct vc_data___2 *);
	void (*con_clear)(struct vc_data___2 *, int, int, int, int);
	void (*con_putc)(struct vc_data___2 *, int, int, int);
	void (*con_putcs)(struct vc_data___2 *, const short unsigned int *, int, int, int);
	void (*con_cursor)(struct vc_data___2 *, int);
	bool (*con_scroll)(struct vc_data___2 *, unsigned int, unsigned int, enum con_scroll, unsigned int);
	int (*con_switch)(struct vc_data___2 *);
	int (*con_blank)(struct vc_data___2 *, int, int);
	int (*con_font_set)(struct vc_data___2 *, struct console_font *, unsigned int);
	int (*con_font_get)(struct vc_data___2 *, struct console_font *);
	int (*con_font_default)(struct vc_data___2 *, struct console_font *, char *);
	int (*con_font_copy)(struct vc_data___2 *, int);
	int (*con_resize)(struct vc_data___2 *, unsigned int, unsigned int, unsigned int);
	void (*con_set_palette)(struct vc_data___2 *, const unsigned char *);
	void (*con_scrolldelta)(struct vc_data___2 *, int);
	int (*con_set_origin)(struct vc_data___2 *);
	void (*con_save_screen)(struct vc_data___2 *);
	u8 (*con_build_attr)(struct vc_data___2 *, u8, u8, u8, u8, u8, u8);
	void (*con_invert_region)(struct vc_data___2 *, u16 *, int);
	u16 * (*con_screen_pos)(struct vc_data___2 *, int);
	long unsigned int (*con_getxy)(struct vc_data___2 *, long unsigned int, int *, int *);
	void (*con_flush_scrollback)(struct vc_data___2 *);
	int (*con_debug_enter)(struct vc_data___2 *);
	int (*con_debug_leave)(struct vc_data___2 *);
};

struct kset___50;

struct kobj_type___50;

struct kernfs_node___51;

struct kobject___51 {
	const char *name;
	struct list_head entry;
	struct kobject___51 *parent;
	struct kset___50 *kset;
	struct kobj_type___50 *ktype;
	struct kernfs_node___51 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___45 {
	struct kobject___51 kobj;
	struct module___48 *mod;
	struct kobject___51 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___45 {
	struct module___48 *mod;
	struct latch_tree_node node;
};

struct module_layout___45 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___45 mtn;
};

struct module_attribute___45;

struct kernel_param___45;

struct module___48 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___45 mkobj;
	struct module_attribute___45 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___51 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___45 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___45 core_layout;
	struct module_layout___45 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct tty_struct___7;

struct tty_port_operations___7;

struct tty_port_client_operations___7;

struct tty_port___7 {
	struct tty_bufhead buf;
	struct tty_struct___7 *tty;
	struct tty_struct___7 *itty;
	const struct tty_port_operations___7 *ops;
	const struct tty_port_client_operations___7 *client_ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	unsigned char low_latency: 1;
	struct mutex mutex;
	struct mutex buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
	void *client_data;
};

struct console_font {
	unsigned int width;
	unsigned int height;
	unsigned int charcount;
	unsigned char *data;
};

struct vt_mode {
	char mode;
	char waitv;
	short int relsig;
	short int acqsig;
	short int frsig;
};

struct uni_pagedir;

struct vc_data___2 {
	struct tty_port___7 port;
	short unsigned int vc_num;
	unsigned int vc_cols;
	unsigned int vc_rows;
	unsigned int vc_size_row;
	unsigned int vc_scan_lines;
	long unsigned int vc_origin;
	long unsigned int vc_scr_end;
	long unsigned int vc_visible_origin;
	unsigned int vc_top;
	unsigned int vc_bottom;
	const struct consw___4 *vc_sw;
	short unsigned int *vc_screenbuf;
	unsigned int vc_screenbuf_size;
	unsigned char vc_mode;
	unsigned char vc_attr;
	unsigned char vc_def_color;
	unsigned char vc_color;
	unsigned char vc_s_color;
	unsigned char vc_ulcolor;
	unsigned char vc_itcolor;
	unsigned char vc_halfcolor;
	unsigned int vc_cursor_type;
	short unsigned int vc_complement_mask;
	short unsigned int vc_s_complement_mask;
	unsigned int vc_x;
	unsigned int vc_y;
	unsigned int vc_saved_x;
	unsigned int vc_saved_y;
	long unsigned int vc_pos;
	short unsigned int vc_hi_font_mask;
	struct console_font vc_font;
	short unsigned int vc_video_erase_char;
	unsigned int vc_state;
	unsigned int vc_npar;
	unsigned int vc_par[16];
	struct vt_mode vt_mode;
	struct pid___47 *vt_pid;
	int vt_newvt;
	wait_queue_head_t paste_wait;
	unsigned int vc_charset: 1;
	unsigned int vc_s_charset: 1;
	unsigned int vc_disp_ctrl: 1;
	unsigned int vc_toggle_meta: 1;
	unsigned int vc_decscnm: 1;
	unsigned int vc_decom: 1;
	unsigned int vc_decawm: 1;
	unsigned int vc_deccm: 1;
	unsigned int vc_decim: 1;
	unsigned int vc_intensity: 2;
	unsigned int vc_italic: 1;
	unsigned int vc_underline: 1;
	unsigned int vc_blink: 1;
	unsigned int vc_reverse: 1;
	unsigned int vc_s_intensity: 2;
	unsigned int vc_s_italic: 1;
	unsigned int vc_s_underline: 1;
	unsigned int vc_s_blink: 1;
	unsigned int vc_s_reverse: 1;
	unsigned int vc_ques: 1;
	unsigned int vc_need_wrap: 1;
	unsigned int vc_can_do_color: 1;
	unsigned int vc_report_mouse: 2;
	unsigned char vc_utf: 1;
	unsigned char vc_utf_count;
	int vc_utf_char;
	unsigned int vc_tab_stop[8];
	unsigned char vc_palette[48];
	short unsigned int *vc_translate;
	unsigned char vc_G0_charset;
	unsigned char vc_G1_charset;
	unsigned char vc_saved_G0;
	unsigned char vc_saved_G1;
	unsigned int vc_resize_user;
	unsigned int vc_bell_pitch;
	unsigned int vc_bell_duration;
	short unsigned int vc_cur_blink_ms;
	struct vc_data___2 **vc_display_fg;
	struct uni_pagedir *vc_uni_pagedir;
	struct uni_pagedir **vc_uni_pagedir_loc;
};

struct cdev___14;

struct tty_operations___7;

struct tty_driver {
	int magic;
	struct kref kref;
	struct cdev___14 **cdevs;
	struct module___48 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver *other;
	struct tty_struct___7 **ttys;
	struct tty_port___7 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___7 *ops;
	struct list_head tty_drivers;
};

struct file___54;

struct kiocb___54;

struct vm_area_struct___54;

struct inode___55;

struct file_lock___54;

struct page___54;

struct seq_file___51;

struct file_operations___54 {
	struct module___48 *owner;
	loff_t (*llseek)(struct file___54 *, loff_t, int);
	ssize_t (*read)(struct file___54 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___54 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___54 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___54 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___54 *, bool);
	int (*iterate)(struct file___54 *, struct dir_context *);
	int (*iterate_shared)(struct file___54 *, struct dir_context *);
	__poll_t (*poll)(struct file___54 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___54 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___54 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___54 *, struct vm_area_struct___54 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___55 *, struct file___54 *);
	int (*flush)(struct file___54 *, fl_owner_t);
	int (*release)(struct inode___55 *, struct file___54 *);
	int (*fsync)(struct file___54 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___54 *, int);
	int (*lock)(struct file___54 *, int, struct file_lock___54 *);
	ssize_t (*sendpage)(struct file___54 *, struct page___54 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___54 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___54 *, int, struct file_lock___54 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___54 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___54 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___54 *, long int, struct file_lock___54 **, void **);
	long int (*fallocate)(struct file___54 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___51 *, struct file___54 *);
	ssize_t (*copy_file_range)(struct file___54 *, loff_t, struct file___54 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___54 *, loff_t, struct file___54 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___54 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___53 {
	u64 seqnum;
	struct vm_area_struct___54 *vmas[4];
};

struct page_frag___53 {
	struct page___54 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___53;

struct mem_cgroup___22;

struct cred___53;

struct nsproxy___52;

struct bio_list___23;

struct backing_dev_info___23;

struct css_set___42;

struct task_struct___54 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___54 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___53 *mm;
	struct mm_struct___53 *active_mm;
	struct vmacache___53 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___54 *real_parent;
	struct task_struct___54 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___54 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___22 *active_memcg;
	long int rh_reserved2;
	struct pid___47 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___47 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___47 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___53 *ptracer_cred;
	const struct cred___53 *real_cred;
	const struct cred___53 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___52 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___54 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___23 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___23 *backing_dev_info;
	struct io_context___12 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___42 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___53 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___22 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___54 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___33 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___53;

struct super_block___54;

struct dentry___54 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___54 *d_parent;
	struct qstr d_name;
	struct inode___55 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___53 *d_op;
	struct super_block___54 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct rw_semaphore___54 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___54 *owner;
};

struct address_space_operations___53;

struct address_space___53 {
	struct inode___55 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___54 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___53 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___53;

struct bdi_writeback___23;

struct block_device___54;

struct inode___55 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___53 *i_op;
	struct super_block___54 *i_sb;
	struct address_space___53 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___54 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___23 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___54 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___53 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___54 *i_bdev;
		struct cdev___14 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___53;

struct dentry_operations___53 {
	int (*d_revalidate)(struct dentry___54 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___54 *, unsigned int);
	int (*d_hash)(const struct dentry___54 *, struct qstr *);
	int (*d_compare)(const struct dentry___54 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___54 *);
	int (*d_init)(struct dentry___54 *);
	void (*d_release)(struct dentry___54 *);
	void (*d_prune)(struct dentry___54 *);
	void (*d_iput)(struct dentry___54 *, struct inode___55 *);
	char * (*d_dname)(struct dentry___54 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___53 *);
	int (*d_manage)(const struct path___53 *, bool);
	struct dentry___54 * (*d_real)(struct dentry___54 *, const struct inode___55 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___53;

struct mem_dqinfo___53 {
	struct quota_format_type___53 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___53;

struct quota_info___53 {
	unsigned int flags;
	struct rw_semaphore___54 dqio_sem;
	struct inode___55 *files[3];
	struct mem_dqinfo___53 info[3];
	const struct quota_format_ops___53 *ops[3];
};

struct rcuwait___53 {
	struct task_struct___54 *task;
};

struct percpu_rw_semaphore___53 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___54 rw_sem;
	struct rcuwait___53 writer;
	int readers_block;
};

struct sb_writers___53 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___53 rw_sem[3];
};

struct shrink_control___22;

struct shrinker___22 {
	long unsigned int (*count_objects)(struct shrinker___22 *, struct shrink_control___22 *);
	long unsigned int (*scan_objects)(struct shrinker___22 *, struct shrink_control___22 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___53;

struct super_operations___53;

struct dquot_operations___53;

struct quotactl_ops___53;

struct user_namespace___44;

struct super_block___54 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___53 *s_type;
	const struct super_operations___53 *s_op;
	const struct dquot_operations___53 *dq_op;
	const struct quotactl_ops___53 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___54 *s_root;
	struct rw_semaphore___54 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___54 *s_bdev;
	struct backing_dev_info___23 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___53 s_dquot;
	struct sb_writers___53 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___53 *s_d_op;
	int cleancache_poolid;
	struct shrinker___22 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___44 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct path___53 {
	struct vfsmount *mnt;
	struct dentry___54 *dentry;
};

struct key___54;

struct ucounts___44;

struct user_namespace___44 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___44 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___4 ns;
	long unsigned int flags;
	struct key___54 *persistent_keyring_register;
	struct rw_semaphore___54 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___44 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct shrink_control___22 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___22 *memcg;
};

struct cgroup___42;

struct cgroup_subsys___42;

struct cgroup_subsys_state___42 {
	struct cgroup___42 *cgroup;
	struct cgroup_subsys___42 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___42 *parent;
};

struct cgroup_file___42 {
	struct kernfs_node___51 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___22;

struct mem_cgroup___22 {
	struct cgroup_subsys_state___42 css;
	struct mem_cgroup_id___2 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___42 events_file;
	struct cgroup_file___42 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___54 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___22 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___54 *pgtable_t___53;

struct dev_pagemap___53;

struct page___54 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___53 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___54 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___53 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___53 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___53 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___22 *mem_cgroup;
};

struct pglist_data___53;

struct lruvec___53 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___53 *pgdat;
};

struct zone___53 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___53 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___53 {
	struct zone___53 *zone;
	int zone_idx;
};

struct zonelist___53 {
	struct zoneref___53 _zonerefs[25];
};

struct pglist_data___53 {
	struct zone___53 node_zones[3];
	struct zonelist___53 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___54 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___54 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___53 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___54 {
	void *stack;
	struct task_struct___54 *task;
	long int status;
};

struct blocking_notifier_head___53 {
	struct rw_semaphore___54 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___53;

struct vm_area_struct___54 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___54 *vm_next;
	struct vm_area_struct___54 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___53 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___53 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___54 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___53;

struct mm_struct___53 {
	struct {
		struct vm_area_struct___54 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___54 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___54 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___53 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___54 *owner;
		struct user_namespace___44 *user_ns;
		struct file___54 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___53 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___53)(struct vm_area_struct___54 *, long unsigned int, const struct page___54 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___53)(struct page___54 *, void *);

struct device___47;

struct dev_pagemap___53 {
	dev_page_fault_t___53 page_fault;
	dev_page_free_t___53 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___47 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct file___54 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___53 f_path;
	struct inode___55 *f_inode;
	const struct file_operations___54 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___47 f_owner;
	const struct cred___53 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___53 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___53;

struct vm_operations_struct___53 {
	void (*open)(struct vm_area_struct___54 *);
	void (*close)(struct vm_area_struct___54 *);
	int (*split)(struct vm_area_struct___54 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___54 *);
	vm_fault_t (*fault)(struct vm_fault___53 *);
	vm_fault_t (*huge_fault)(struct vm_fault___53 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___53 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___54 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___53 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___53 *);
	int (*access)(struct vm_area_struct___54 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___54 *);
	int (*set_policy)(struct vm_area_struct___54 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___54 *, long unsigned int);
	struct page___54 * (*find_special_page)(struct vm_area_struct___54 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___53 {
	struct task_struct___54 *task;
	struct core_thread___53 *next;
};

struct core_state___53 {
	atomic_t nr_threads;
	struct core_thread___53 dumper;
	struct completion startup;
};

struct vm_fault___53 {
	struct vm_area_struct___54 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___54 *cow_page;
	struct mem_cgroup___22 *memcg;
	struct page___54 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___53 prealloc_pte;
};

struct user_struct___53 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___54 *uid_keyring;
	struct key___54 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___53 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___54 *session_keyring;
	struct key___54 *process_keyring;
	struct key___54 *thread_keyring;
	struct key___54 *request_key_auth;
	void *security;
	struct user_struct___53 *user;
	struct user_namespace___44 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct uts_namespace___14;

struct cgroup_namespace___42;

struct nsproxy___52 {
	atomic_t count;
	struct uts_namespace___14 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___42 *cgroup_ns;
};

struct bio___23;

struct bio_list___23 {
	struct bio___23 *head;
	struct bio___23 *tail;
};

struct bdi_writeback_congested___23;

struct bdi_writeback___23 {
	struct backing_dev_info___23 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___23 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___42 *memcg_css;
	struct cgroup_subsys_state___42 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___23 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___23 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___47 *dev;
	struct device___47 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___54 *debug_dir;
	struct dentry___54 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___42 {
	struct cgroup_subsys_state___42 *subsys[13];
	refcount_t refcount;
	struct css_set___42 *dom_cset;
	struct cgroup___42 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___42 *mg_src_cgrp;
	struct cgroup___42 *mg_dst_cgrp;
	struct css_set___42 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct kiocb___54 {
	struct file___54 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___54 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___54 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___54 *ia_file;
};

struct dquot___53 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___54 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___53 {
	int qf_fmt_id;
	const struct quota_format_ops___53 *qf_ops;
	struct module___48 *qf_owner;
	struct quota_format_type___53 *qf_next;
};

struct quota_format_ops___53 {
	int (*check_quota_file)(struct super_block___54 *, int);
	int (*read_file_info)(struct super_block___54 *, int);
	int (*write_file_info)(struct super_block___54 *, int);
	int (*free_file_info)(struct super_block___54 *, int);
	int (*read_dqblk)(struct dquot___53 *);
	int (*commit_dqblk)(struct dquot___53 *);
	int (*release_dqblk)(struct dquot___53 *);
	int (*get_next_id)(struct super_block___54 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___53 {
	int (*write_dquot)(struct dquot___53 *);
	struct dquot___53 * (*alloc_dquot)(struct super_block___54 *, int);
	void (*destroy_dquot)(struct dquot___53 *);
	int (*acquire_dquot)(struct dquot___53 *);
	int (*release_dquot)(struct dquot___53 *);
	int (*mark_dirty)(struct dquot___53 *);
	int (*write_info)(struct super_block___54 *, int);
	qsize_t * (*get_reserved_space)(struct inode___55 *);
	int (*get_projid)(struct inode___55 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___55 *, qsize_t *);
	int (*get_next_id)(struct super_block___54 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___53 {
	int (*quota_on)(struct super_block___54 *, int, int, const struct path___53 *);
	int (*quota_off)(struct super_block___54 *, int);
	int (*quota_enable)(struct super_block___54 *, unsigned int);
	int (*quota_disable)(struct super_block___54 *, unsigned int);
	int (*quota_sync)(struct super_block___54 *, int);
	int (*set_info)(struct super_block___54 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___54 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___54 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___54 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___54 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___54 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___22;

struct swap_info_struct___17;

struct address_space_operations___53 {
	int (*writepage)(struct page___54 *, struct writeback_control___22 *);
	int (*readpage)(struct file___54 *, struct page___54 *);
	int (*writepages)(struct address_space___53 *, struct writeback_control___22 *);
	int (*set_page_dirty)(struct page___54 *);
	int (*readpages)(struct file___54 *, struct address_space___53 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___54 *, struct address_space___53 *, loff_t, unsigned int, unsigned int, struct page___54 **, void **);
	int (*write_end)(struct file___54 *, struct address_space___53 *, loff_t, unsigned int, unsigned int, struct page___54 *, void *);
	sector_t (*bmap)(struct address_space___53 *, sector_t);
	void (*invalidatepage)(struct page___54 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___54 *, gfp_t);
	void (*freepage)(struct page___54 *);
	ssize_t (*direct_IO)(struct kiocb___54 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___53 *, struct page___54 *, struct page___54 *, enum migrate_mode);
	bool (*isolate_page)(struct page___54 *, isolate_mode_t);
	void (*putback_page)(struct page___54 *);
	int (*launder_page)(struct page___54 *);
	int (*is_partially_uptodate)(struct page___54 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___54 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___53 *, struct page___54 *);
	int (*swap_activate)(struct swap_info_struct___17 *, struct file___54 *, sector_t *);
	void (*swap_deactivate)(struct file___54 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___22 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___23 *wb;
	struct inode___55 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct swap_info_struct___17 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___54 *bdev;
	struct file___54 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___54 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___55 *bd_inode;
	struct super_block___54 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___54 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___23 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___14 {
	struct kobject___51 kobj;
	struct module___48 *owner;
	const struct file_operations___54 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___53 {
	struct dentry___54 * (*lookup)(struct inode___55 *, struct dentry___54 *, unsigned int);
	const char * (*get_link)(struct dentry___54 *, struct inode___55 *, struct delayed_call *);
	int (*permission)(struct inode___55 *, int);
	struct posix_acl * (*get_acl)(struct inode___55 *, int);
	int (*readlink)(struct dentry___54 *, char *, int);
	int (*create)(struct inode___55 *, struct dentry___54 *, umode_t, bool);
	int (*link)(struct dentry___54 *, struct inode___55 *, struct dentry___54 *);
	int (*unlink)(struct inode___55 *, struct dentry___54 *);
	int (*symlink)(struct inode___55 *, struct dentry___54 *, const char *);
	int (*mkdir)(struct inode___55 *, struct dentry___54 *, umode_t);
	int (*rmdir)(struct inode___55 *, struct dentry___54 *);
	int (*mknod)(struct inode___55 *, struct dentry___54 *, umode_t, dev_t);
	int (*rename)(struct inode___55 *, struct dentry___54 *, struct inode___55 *, struct dentry___54 *, unsigned int);
	int (*setattr)(struct dentry___54 *, struct iattr___54 *);
	int (*getattr)(const struct path___53 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___54 *, char *, size_t);
	int (*fiemap)(struct inode___55 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___55 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___55 *, struct dentry___54 *, struct file___54 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___55 *, struct dentry___54 *, umode_t);
	int (*set_acl)(struct inode___55 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___53 {
	void (*fl_copy_lock)(struct file_lock___54 *, struct file_lock___54 *);
	void (*fl_release_private)(struct file_lock___54 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___53;

struct lock_manager_operations___53;

struct file_lock___54 {
	struct file_lock___54 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___54 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___53 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___53 *fl_ops;
	const struct lock_manager_operations___53 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___53 {
	int (*lm_compare_owner)(struct file_lock___54 *, struct file_lock___54 *);
	long unsigned int (*lm_owner_key)(struct file_lock___54 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___54 *);
	int (*lm_grant)(struct file_lock___54 *, int);
	bool (*lm_break)(struct file_lock___54 *);
	int (*lm_change)(struct file_lock___54 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___54 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___53 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___53 *fa_next;
	struct file___54 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___53 {
	const char *name;
	int fs_flags;
	struct dentry___54 * (*mount)(struct file_system_type___53 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___54 *);
	struct module___48 *owner;
	struct file_system_type___53 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___53 {
	struct inode___55 * (*alloc_inode)(struct super_block___54 *);
	void (*destroy_inode)(struct inode___55 *);
	void (*dirty_inode)(struct inode___55 *, int);
	int (*write_inode)(struct inode___55 *, struct writeback_control___22 *);
	int (*drop_inode)(struct inode___55 *);
	void (*evict_inode)(struct inode___55 *);
	void (*put_super)(struct super_block___54 *);
	int (*sync_fs)(struct super_block___54 *, int);
	int (*freeze_super)(struct super_block___54 *);
	int (*freeze_fs)(struct super_block___54 *);
	int (*thaw_super)(struct super_block___54 *);
	int (*unfreeze_fs)(struct super_block___54 *);
	int (*statfs)(struct dentry___54 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___54 *, int *, char *);
	void (*umount_begin)(struct super_block___54 *);
	int (*show_options)(struct seq_file___51 *, struct dentry___54 *);
	int (*show_devname)(struct seq_file___51 *, struct dentry___54 *);
	int (*show_path)(struct seq_file___51 *, struct dentry___54 *);
	int (*show_stats)(struct seq_file___51 *, struct dentry___54 *);
	ssize_t (*quota_read)(struct super_block___54 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___54 *, int, const char *, size_t, loff_t);
	struct dquot___53 ** (*get_dquots)(struct inode___55 *);
	int (*bdev_try_to_free_page)(struct super_block___54 *, struct page___54 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___54 *, struct shrink_control___22 *);
	long int (*free_cached_objects)(struct super_block___54 *, struct shrink_control___22 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___48;

struct seq_file___51 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___48 *op;
	int poll_event;
	const struct file___54 *file;
	void *private;
};

typedef void bio_end_io_t___23(struct bio___23 *);

struct bio_vec___23 {
	struct page___54 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___23;

struct bio_set___23;

struct bio___23 {
	struct bio___23 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___23 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___23 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___23 *bi_io_vec;
	struct bio_set___23 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___23 bi_inline_vecs[0];
};

struct kernfs_root___51;

struct kernfs_elem_dir___51 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___51 *root;
};

struct kernfs_syscall_ops___51;

struct kernfs_root___51 {
	struct kernfs_node___51 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___51 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___51 {
	struct kernfs_node___51 *target_kn;
};

struct kernfs_ops___51;

struct kernfs_elem_attr___51 {
	const struct kernfs_ops___51 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___51 *notify_next;
};

struct kernfs_node___51 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___51 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___51 dir;
		struct kernfs_elem_symlink___51 symlink;
		struct kernfs_elem_attr___51 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___51;

struct kernfs_ops___51 {
	int (*open)(struct kernfs_open_file___51 *);
	void (*release)(struct kernfs_open_file___51 *);
	int (*seq_show)(struct seq_file___51 *, void *);
	void * (*seq_start)(struct seq_file___51 *, loff_t *);
	void * (*seq_next)(struct seq_file___51 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___51 *, void *);
	ssize_t (*read)(struct kernfs_open_file___51 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___51 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___51 *, struct vm_area_struct___54 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___51 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___51 {
	int (*remount_fs)(struct kernfs_root___51 *, int *, char *);
	int (*show_options)(struct seq_file___51 *, struct kernfs_root___51 *);
	int (*mkdir)(struct kernfs_node___51 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___51 *);
	int (*rename)(struct kernfs_node___51 *, struct kernfs_node___51 *, const char *);
	int (*show_path)(struct seq_file___51 *, struct kernfs_node___51 *, struct kernfs_root___51 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___51 {
	struct kernfs_node___51 *kn;
	struct file___54 *file;
	struct seq_file___51 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___53 *vm_ops;
};

struct bin_attribute___48;

struct attribute_group___48 {
	const char *name;
	umode_t (*is_visible)(struct kobject___51 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___51 *, struct bin_attribute___48 *, int);
	struct attribute **attrs;
	struct bin_attribute___48 **bin_attrs;
};

struct bin_attribute___48 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___54 *, struct kobject___51 *, struct bin_attribute___48 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___54 *, struct kobject___51 *, struct bin_attribute___48 *, char *, loff_t, size_t);
	int (*mmap)(struct file___54 *, struct kobject___51 *, struct bin_attribute___48 *, struct vm_area_struct___54 *);
};

struct sysfs_ops___50 {
	ssize_t (*show)(struct kobject___51 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___51 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___50;

struct kset___50 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___51 kobj;
	const struct kset_uevent_ops___50 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___50 {
	void (*release)(struct kobject___51 *);
	const struct sysfs_ops___50 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___2 * (*child_ns_type)(struct kobject___51 *);
	const void * (*namespace)(struct kobject___51 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___50 {
	int (* const filter)(struct kset___50 *, struct kobject___51 *);
	const char * (* const name)(struct kset___50 *, struct kobject___51 *);
	int (* const uevent)(struct kset___50 *, struct kobject___51 *, struct kobj_uevent_env *);
};

struct kobj_attribute___51 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___51 *, struct kobj_attribute___51 *, char *);
	ssize_t (*store)(struct kobject___51 *, struct kobj_attribute___51 *, const char *, size_t);
};

struct dev_pm_ops___47 {
	int (*prepare)(struct device___47 *);
	void (*complete)(struct device___47 *);
	int (*suspend)(struct device___47 *);
	int (*resume)(struct device___47 *);
	int (*freeze)(struct device___47 *);
	int (*thaw)(struct device___47 *);
	int (*poweroff)(struct device___47 *);
	int (*restore)(struct device___47 *);
	int (*suspend_late)(struct device___47 *);
	int (*resume_early)(struct device___47 *);
	int (*freeze_late)(struct device___47 *);
	int (*thaw_early)(struct device___47 *);
	int (*poweroff_late)(struct device___47 *);
	int (*restore_early)(struct device___47 *);
	int (*suspend_noirq)(struct device___47 *);
	int (*resume_noirq)(struct device___47 *);
	int (*freeze_noirq)(struct device___47 *);
	int (*thaw_noirq)(struct device___47 *);
	int (*poweroff_noirq)(struct device___47 *);
	int (*restore_noirq)(struct device___47 *);
	int (*runtime_suspend)(struct device___47 *);
	int (*runtime_resume)(struct device___47 *);
	int (*runtime_idle)(struct device___47 *);
};

struct dev_pm_info___47 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___47 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___47;

struct bus_type___47;

struct device_driver___47;

struct dev_pm_domain___47;

struct class___47;

struct device___47 {
	struct device___47 *parent;
	struct device_private *p;
	struct kobject___51 kobj;
	const char *init_name;
	const struct device_type___47 *type;
	struct mutex mutex;
	struct bus_type___47 *bus;
	struct device_driver___47 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___47 power;
	struct dev_pm_domain___47 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___47 *class;
	const struct attribute_group___48 **groups;
	void (*release)(struct device___47 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___47 {
	struct dev_pm_ops___47 ops;
	void (*detach)(struct device___47 *, bool);
	int (*activate)(struct device___47 *);
	void (*sync)(struct device___47 *);
	void (*dismiss)(struct device___47 *);
};

struct bus_type___47 {
	const char *name;
	const char *dev_name;
	struct device___47 *dev_root;
	const struct attribute_group___48 **bus_groups;
	const struct attribute_group___48 **dev_groups;
	const struct attribute_group___48 **drv_groups;
	int (*match)(struct device___47 *, struct device_driver___47 *);
	int (*uevent)(struct device___47 *, struct kobj_uevent_env *);
	int (*probe)(struct device___47 *);
	int (*remove)(struct device___47 *);
	void (*shutdown)(struct device___47 *);
	int (*online)(struct device___47 *);
	int (*offline)(struct device___47 *);
	int (*suspend)(struct device___47 *, pm_message_t);
	int (*resume)(struct device___47 *);
	int (*num_vf)(struct device___47 *);
	int (*dma_configure)(struct device___47 *);
	const struct dev_pm_ops___47 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___47 {
	const char *name;
	struct bus_type___47 *bus;
	struct module___48 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___47 *);
	int (*remove)(struct device___47 *);
	void (*shutdown)(struct device___47 *);
	int (*suspend)(struct device___47 *, pm_message_t);
	int (*resume)(struct device___47 *);
	const struct attribute_group___48 **groups;
	const struct dev_pm_ops___47 *pm;
	void (*coredump)(struct device___47 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___47 {
	const char *name;
	const struct attribute_group___48 **groups;
	int (*uevent)(struct device___47 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___47 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___47 *);
	const struct dev_pm_ops___47 *pm;
};

struct class___47 {
	const char *name;
	struct module___48 *owner;
	const struct attribute_group___48 **class_groups;
	const struct attribute_group___48 **dev_groups;
	struct kobject___51 *dev_kobj;
	int (*dev_uevent)(struct device___47 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___47 *, umode_t *);
	void (*class_release)(struct class___47 *);
	void (*dev_release)(struct device___47 *);
	int (*shutdown_pre)(struct device___47 *);
	const struct kobj_ns_type_operations___2 *ns_type;
	const void * (*namespace)(struct device___47 *);
	const struct dev_pm_ops___47 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

typedef int (*key_restrict_link_func_t___53)(struct key___54 *, const struct key_type *, const union key_payload *, struct key___54 *);

struct key_restriction___54;

struct key___54 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___54 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___54 *restrict_link;
};

struct key_restriction___54 {
	key_restrict_link_func_t___53 check;
	struct key___54 *key;
	struct key_type *keytype;
};

struct seq_operations___48 {
	void * (*start)(struct seq_file___51 *, loff_t *);
	void (*stop)(struct seq_file___51 *, void *);
	void * (*next)(struct seq_file___51 *, void *, loff_t *);
	int (*show)(struct seq_file___51 *, void *);
};

struct tty_operations___7 {
	struct tty_struct___7 * (*lookup)(struct tty_driver *, struct file___54 *, int);
	int (*install)(struct tty_driver *, struct tty_struct___7 *);
	void (*remove)(struct tty_driver *, struct tty_struct___7 *);
	int (*open)(struct tty_struct___7 *, struct file___54 *);
	void (*close)(struct tty_struct___7 *, struct file___54 *);
	void (*shutdown)(struct tty_struct___7 *);
	void (*cleanup)(struct tty_struct___7 *);
	int (*write)(struct tty_struct___7 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___7 *, unsigned char);
	void (*flush_chars)(struct tty_struct___7 *);
	int (*write_room)(struct tty_struct___7 *);
	int (*chars_in_buffer)(struct tty_struct___7 *);
	int (*ioctl)(struct tty_struct___7 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___7 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___7 *, struct ktermios *);
	void (*throttle)(struct tty_struct___7 *);
	void (*unthrottle)(struct tty_struct___7 *);
	void (*stop)(struct tty_struct___7 *);
	void (*start)(struct tty_struct___7 *);
	void (*hangup)(struct tty_struct___7 *);
	int (*break_ctl)(struct tty_struct___7 *, int);
	void (*flush_buffer)(struct tty_struct___7 *);
	void (*set_ldisc)(struct tty_struct___7 *);
	void (*wait_until_sent)(struct tty_struct___7 *, int);
	void (*send_xchar)(struct tty_struct___7 *, char);
	int (*tiocmget)(struct tty_struct___7 *);
	int (*tiocmset)(struct tty_struct___7 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___7 *, struct winsize *);
	int (*set_termiox)(struct tty_struct___7 *, struct termiox *);
	int (*get_icount)(struct tty_struct___7 *, struct serial_icounter_struct *);
	void (*show_fdinfo)(struct tty_struct___7 *, struct seq_file___51 *);
	int (*poll_init)(struct tty_driver *, int, char *);
	int (*poll_get_char)(struct tty_driver *, int);
	void (*poll_put_char)(struct tty_driver *, int, char);
	int (*proc_show)(struct seq_file___51 *, void *);
};

struct tty_ldisc___7;

struct tty_struct___7 {
	int magic;
	struct kref kref;
	struct device___47 *dev;
	struct tty_driver *driver;
	const struct tty_operations___7 *ops;
	int index;
	struct ld_semaphore ldisc_sem;
	struct tty_ldisc___7 *ldisc;
	struct mutex atomic_write_lock;
	struct mutex legacy_mutex;
	struct mutex throttle_mutex;
	struct rw_semaphore___54 termios_rwsem;
	struct mutex winsize_mutex;
	spinlock_t ctrl_lock;
	spinlock_t flow_lock;
	struct ktermios termios;
	struct ktermios termios_locked;
	struct termiox *termiox;
	char name[64];
	struct pid___47 *pgrp;
	struct pid___47 *session;
	long unsigned int flags;
	int count;
	struct winsize winsize;
	long unsigned int stopped: 1;
	long unsigned int flow_stopped: 1;
	int: 30;
	long unsigned int unused: 62;
	int hw_stopped;
	long unsigned int ctrl_status: 8;
	long unsigned int packet: 1;
	int: 23;
	long unsigned int unused_ctrl: 55;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___7 *link;
	struct fasync_struct___53 *fasync;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	spinlock_t files_lock;
	struct list_head tty_files;
	int closing;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___7 *port;
};

struct tty_ldisc_ops___7 {
	int magic;
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___7 *);
	void (*close)(struct tty_struct___7 *);
	void (*flush_buffer)(struct tty_struct___7 *);
	ssize_t (*read)(struct tty_struct___7 *, struct file___54 *, unsigned char *, size_t);
	ssize_t (*write)(struct tty_struct___7 *, struct file___54 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___7 *, struct file___54 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___7 *, struct file___54 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___7 *, struct ktermios *);
	__poll_t (*poll)(struct tty_struct___7 *, struct file___54 *, struct poll_table_struct___6 *);
	int (*hangup)(struct tty_struct___7 *);
	void (*receive_buf)(struct tty_struct___7 *, const unsigned char *, char *, int);
	void (*write_wakeup)(struct tty_struct___7 *);
	void (*dcd_change)(struct tty_struct___7 *, unsigned int);
	int (*receive_buf2)(struct tty_struct___7 *, const unsigned char *, char *, int);
	struct module___48 *owner;
	int refcount;
};

struct tty_ldisc___7 {
	struct tty_ldisc_ops___7 *ops;
	struct tty_struct___7 *tty;
};

struct tty_port_operations___7 {
	int (*carrier_raised)(struct tty_port___7 *);
	void (*dtr_rts)(struct tty_port___7 *, int);
	void (*shutdown)(struct tty_port___7 *);
	int (*activate)(struct tty_port___7 *, struct tty_struct___7 *);
	void (*destruct)(struct tty_port___7 *);
};

struct tty_port_client_operations___7 {
	int (*receive_buf)(struct tty_port___7 *, const unsigned char *, const unsigned char *, size_t);
	void (*write_wakeup)(struct tty_port___7 *);
};

struct vc {
	struct vc_data___2 *d;
	struct work_struct SAK_work;
};

typedef void compound_page_dtor___53(struct page___54 *);

struct vt_spawn_console {
	spinlock_t lock;
	struct pid___47 *pid;
	int sig;
};

struct kernel_param_ops___45 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___45 *);
	int (*get)(char *, const struct kernel_param___45 *);
	void (*free)(void *);
};

struct kparam_array___45;

struct kernel_param___45 {
	const char *name;
	struct module___48 *mod;
	const struct kernel_param_ops___45 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___45 *arr;
	};
};

struct kparam_array___45 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___45 *ops;
	void *elem;
};

struct module_attribute___45 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___45 *, struct module_kobject___45 *, char *);
	ssize_t (*store)(struct module_attribute___45 *, struct module_kobject___45 *, const char *, size_t);
	void (*setup)(struct module___48 *, const char *);
	int (*test)(struct module___48 *);
	void (*free)(struct module___48 *);
};

struct uts_namespace___14 {
	struct kref kref;
	struct new_utsname name;
	struct user_namespace___44 *user_ns;
	struct ucounts___44 *ucounts;
	struct ns_common___4 ns;
};

struct cgroup_namespace___42 {
	refcount_t count;
	struct ns_common___4 ns;
	struct user_namespace___44 *user_ns;
	struct ucounts___44 *ucounts;
	struct css_set___42 *root_cset;
};

struct ucounts___44 {
	struct hlist_node node;
	struct user_namespace___44 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___42;

struct bpf_map_ops___42 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___42 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___42 *, struct file___54 *);
	void (*map_free)(struct bpf_map___42 *);
	int (*map_get_next_key)(struct bpf_map___42 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___42 *);
	void * (*map_lookup_elem)(struct bpf_map___42 *, void *);
	int (*map_update_elem)(struct bpf_map___42 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___42 *, void *);
	int (*map_push_elem)(struct bpf_map___42 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___42 *, void *);
	int (*map_peek_elem)(struct bpf_map___42 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___42 *, struct file___54 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___42 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___42 *, void *, struct seq_file___51 *);
	int (*map_check_btf)(const struct bpf_map___42 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___42 {
	const struct bpf_map_ops___42 *ops;
	struct bpf_map___42 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___53 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___42;

typedef void (*kthread_work_func_t___42)(struct kthread_work___42 *);

struct kthread_worker___42;

struct kthread_work___42 {
	struct list_head node;
	kthread_work_func_t___42 func;
	struct kthread_worker___42 *worker;
	int canceling;
};

struct kthread_worker___42 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___54 *task;
	struct kthread_work___42 *current_work;
};

struct kthread_delayed_work___42 {
	struct kthread_work___42 work;
	struct timer_list timer;
};

struct psi_group___42 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___42 *poll_kworker;
	struct kthread_delayed_work___42 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___42;

struct cgroup_rstat_cpu___42;

struct cgroup___42 {
	struct cgroup_subsys_state___42 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___51 *kn;
	struct cgroup_file___42 procs_file;
	struct cgroup_file___42 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___42 *subsys[13];
	struct cgroup_root___42 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___42 *dom_cgrp;
	struct cgroup_rstat_cpu___42 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___4 bpf;
	atomic_t congestion_count;
	struct cgroup___42 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___42 psi;
	int ancestor_ids[0];
};

struct cftype___42;

struct cgroup_subsys___42 {
	struct cgroup_subsys_state___42 * (*css_alloc)(struct cgroup_subsys_state___42 *);
	int (*css_online)(struct cgroup_subsys_state___42 *);
	void (*css_offline)(struct cgroup_subsys_state___42 *);
	void (*css_released)(struct cgroup_subsys_state___42 *);
	void (*css_free)(struct cgroup_subsys_state___42 *);
	void (*css_reset)(struct cgroup_subsys_state___42 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___42 *, int);
	int (*css_extra_stat_show)(struct seq_file___51 *, struct cgroup_subsys_state___42 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___54 *);
	void (*cancel_fork)(struct task_struct___54 *);
	void (*fork)(struct task_struct___54 *);
	void (*exit)(struct task_struct___54 *);
	void (*free)(struct task_struct___54 *);
	void (*bind)(struct cgroup_subsys_state___42 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___42 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___42 *dfl_cftypes;
	struct cftype___42 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___42 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___42 *updated_children;
	struct cgroup___42 *updated_next;
};

struct cgroup_root___42 {
	struct kernfs_root___51 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___42 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___42 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___42 *ss;
	struct list_head node;
	struct kernfs_ops___51 *kf_ops;
	int (*open)(struct kernfs_open_file___51 *);
	void (*release)(struct kernfs_open_file___51 *);
	u64 (*read_u64)(struct cgroup_subsys_state___42 *, struct cftype___42 *);
	s64 (*read_s64)(struct cgroup_subsys_state___42 *, struct cftype___42 *);
	int (*seq_show)(struct seq_file___51 *, void *);
	void * (*seq_start)(struct seq_file___51 *, loff_t *);
	void * (*seq_next)(struct seq_file___51 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___51 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___42 *, struct cftype___42 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___42 *, struct cftype___42 *, s64);
	ssize_t (*write)(struct kernfs_open_file___51 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___51 *, struct poll_table_struct___6 *);
};

struct bdi_writeback_congested___23 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___23 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___23 {
	struct bio___23 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___23 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___23 bip_inline_vecs[0];
};

struct bio_set___23 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___23 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___22 {
	struct mem_cgroup___22 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___22 {
	struct lruvec___53 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___22 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___22 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct node___44 {
	struct device___47 dev;
};

struct pm_vt_switch {
	struct list_head head;
	struct device___47 *dev;
	bool required;
};

struct module___49;

struct file___55;

struct kiocb___55;

struct iov_iter___25;

struct poll_table_struct___35;

struct vm_area_struct___55;

struct inode___56;

struct file_lock___55;

struct page___55;

struct seq_file___52;

struct file_operations___55 {
	struct module___49 *owner;
	loff_t (*llseek)(struct file___55 *, loff_t, int);
	ssize_t (*read)(struct file___55 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___55 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___55 *, struct iov_iter___25 *);
	ssize_t (*write_iter)(struct kiocb___55 *, struct iov_iter___25 *);
	int (*iopoll)(struct kiocb___55 *, bool);
	int (*iterate)(struct file___55 *, struct dir_context *);
	int (*iterate_shared)(struct file___55 *, struct dir_context *);
	__poll_t (*poll)(struct file___55 *, struct poll_table_struct___35 *);
	long int (*unlocked_ioctl)(struct file___55 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___55 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___55 *, struct vm_area_struct___55 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___56 *, struct file___55 *);
	int (*flush)(struct file___55 *, fl_owner_t);
	int (*release)(struct inode___56 *, struct file___55 *);
	int (*fsync)(struct file___55 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___55 *, int);
	int (*lock)(struct file___55 *, int, struct file_lock___55 *);
	ssize_t (*sendpage)(struct file___55 *, struct page___55 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___55 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___55 *, int, struct file_lock___55 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___55 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___55 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___55 *, long int, struct file_lock___55 **, void **);
	long int (*fallocate)(struct file___55 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___52 *, struct file___55 *);
	ssize_t (*copy_file_range)(struct file___55 *, loff_t, struct file___55 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___55 *, loff_t, struct file___55 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___55 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___54 {
	u64 seqnum;
	struct vm_area_struct___55 *vmas[4];
};

struct page_frag___54 {
	struct page___55 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___34;

struct debug_info___34 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___34 *hbp_break[16];
	struct perf_event___34 *hbp_watch[16];
};

struct thread_struct___34 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___34 debug;
	long: 64;
};

struct mm_struct___54;

struct mem_cgroup___23;

struct pid___48;

struct cred___54;

struct nsproxy___53;

struct signal_struct___50;

struct bio_list___24;

struct backing_dev_info___24;

struct css_set___43;

struct perf_event_context___34;

struct task_struct___55 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___55 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___54 *mm;
	struct mm_struct___54 *active_mm;
	struct vmacache___54 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___55 *real_parent;
	struct task_struct___55 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___55 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___23 *active_memcg;
	long int rh_reserved2;
	struct pid___48 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___48 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___48 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___54 *ptracer_cred;
	const struct cred___54 *real_cred;
	const struct cred___54 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___53 *nsproxy;
	struct signal_struct___50 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___55 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___24 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___24 *backing_dev_info;
	struct io_context___12 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___43 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___34 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___54 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___23 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___55 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___34 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct secondary_data___55 {
	void *stack;
	struct task_struct___55 *task;
	long int status;
};

struct hw_perf_event___34 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___55 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___34)(struct perf_event___34 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___34;

struct fasync_struct___54;

struct pid_namespace___48;

struct trace_event_call___29;

struct perf_cgroup___34;

struct perf_event___34 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___34 *group_leader;
	struct pmu___34 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___34 hw;
	struct perf_event_context___34 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___34 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___55 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___54 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___34 *);
	struct callback_head callback_head;
	struct pid_namespace___48 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___34 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___34 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___29 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___34 *cgrp;
	struct list_head sb_list;
};

struct key___55;

struct user_struct___54 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___55 *uid_keyring;
	struct key___55 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct upid___48 {
	int nr;
	struct pid_namespace___48 *ns;
};

struct dentry___55;

struct user_namespace___45;

struct ucounts___45;

struct pid_namespace___48 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___55 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___48 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___55 *proc_self;
	struct dentry___55 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___45 *user_ns;
	struct ucounts___45 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___4 ns;
};

struct pid___48 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___48 numbers[1];
};

struct rw_semaphore___55 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___55 *owner;
};

struct user_namespace___45 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___45 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___4 ns;
	long unsigned int flags;
	struct key___55 *persistent_keyring_register;
	struct rw_semaphore___55 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___45 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___55 *pgtable_t___54;

struct address_space___54;

struct dev_pagemap___54;

struct page___55 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___54 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___55 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___54 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___54 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___54 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___23 *mem_cgroup;
};

struct vm_operations_struct___54;

struct vm_area_struct___55 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___55 *vm_next;
	struct vm_area_struct___55 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___54 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___54 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___55 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___54;

struct mm_struct___54 {
	struct {
		struct vm_area_struct___55 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___55 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___55 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___54 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___55 *owner;
		struct user_namespace___45 *user_ns;
		struct file___55 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___54 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup___43;

struct cgroup_subsys___43;

struct cgroup_subsys_state___43 {
	struct cgroup___43 *cgroup;
	struct cgroup_subsys___43 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___43 *parent;
};

struct kernfs_node___52;

struct cgroup_file___43 {
	struct kernfs_node___52 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___23;

struct mem_cgroup___23 {
	struct cgroup_subsys_state___43 css;
	struct mem_cgroup_id___8 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___43 events_file;
	struct cgroup_file___43 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___55 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___23 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cred___54 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___55 *session_keyring;
	struct key___55 *process_keyring;
	struct key___55 *thread_keyring;
	struct key___55 *request_key_auth;
	void *security;
	struct user_struct___54 *user;
	struct user_namespace___45 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___43;

struct nsproxy___53 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___48 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___43 *cgroup_ns;
};

struct signal_struct___50 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___55 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___55 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___48 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___48 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___54 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___48 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___24;

struct bio_list___24 {
	struct bio___24 *head;
	struct bio___24 *tail;
};

struct bdi_writeback_congested___24;

struct bdi_writeback___24 {
	struct backing_dev_info___24 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___24 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___43 *memcg_css;
	struct cgroup_subsys_state___43 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___48;

struct backing_dev_info___24 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___24 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___48 *dev;
	struct device___48 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___55 *debug_dir;
	struct dentry___55 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___43 {
	struct cgroup_subsys_state___43 *subsys[13];
	refcount_t refcount;
	struct css_set___43 *dom_cset;
	struct cgroup___43 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___43 *mg_src_cgrp;
	struct cgroup___43 *mg_dst_cgrp;
	struct css_set___43 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___34 {
	struct pmu___34 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___55 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___34 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

union thread_union___50 {
	struct task_struct___55 task;
	long unsigned int stack[8192];
};

typedef int (*key_restrict_link_func_t___54)(struct key___55 *, const struct key_type *, const union key_payload *, struct key___55 *);

struct key_restriction___55;

struct key___55 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___55 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___55 *restrict_link;
};

struct key_restriction___55 {
	key_restrict_link_func_t___54 check;
	struct key___55 *key;
	struct key_type *keytype;
};

struct address_space_operations___54;

struct address_space___54 {
	struct inode___56 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___55 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___54 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___54)(struct vm_area_struct___55 *, long unsigned int, const struct page___55 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___54)(struct page___55 *, void *);

struct dev_pagemap___54 {
	dev_page_fault_t___54 page_fault;
	dev_page_free_t___54 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___48 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___54 {
	struct vfsmount *mnt;
	struct dentry___55 *dentry;
};

struct fown_struct___48 {
	rwlock_t lock;
	struct pid___48 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___55 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___54 f_path;
	struct inode___56 *f_inode;
	const struct file_operations___55 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___48 f_owner;
	const struct cred___54 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___54 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___54;

struct vm_operations_struct___54 {
	void (*open)(struct vm_area_struct___55 *);
	void (*close)(struct vm_area_struct___55 *);
	int (*split)(struct vm_area_struct___55 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___55 *);
	vm_fault_t (*fault)(struct vm_fault___54 *);
	vm_fault_t (*huge_fault)(struct vm_fault___54 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___54 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___55 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___54 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___54 *);
	int (*access)(struct vm_area_struct___55 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___55 *);
	int (*set_policy)(struct vm_area_struct___55 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___55 *, long unsigned int);
	struct page___55 * (*find_special_page)(struct vm_area_struct___55 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___54 {
	struct task_struct___55 *task;
	struct core_thread___54 *next;
};

struct core_state___54 {
	atomic_t nr_threads;
	struct core_thread___54 dumper;
	struct completion startup;
};

struct vm_fault___54 {
	struct vm_area_struct___55 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___55 *cow_page;
	struct mem_cgroup___23 *memcg;
	struct page___55 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___54 prealloc_pte;
};

struct pglist_data___54;

struct lruvec___54 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___54 *pgdat;
};

struct zone___54 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___54 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___54 {
	struct zone___54 *zone;
	int zone_idx;
};

struct zonelist___54 {
	struct zoneref___54 _zonerefs[25];
};

struct pglist_data___54 {
	struct zone___54 node_zones[3];
	struct zonelist___54 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___55 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___55 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___54 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___54 {
	struct rw_semaphore___55 rwsem;
	struct notifier_block *head;
};

struct shrink_control___23 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___23 *memcg;
};

struct shrinker___23 {
	long unsigned int (*count_objects)(struct shrinker___23 *, struct shrink_control___23 *);
	long unsigned int (*scan_objects)(struct shrinker___23 *, struct shrink_control___23 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct kset___51;

struct kobj_type___51;

struct kobject___52 {
	const char *name;
	struct list_head entry;
	struct kobject___52 *parent;
	struct kset___51 *kset;
	struct kobj_type___51 *ktype;
	struct kernfs_node___52 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_qos___5;

struct dev_pm_info___48 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___48 *, s32);
	struct dev_pm_qos___5 *qos;
};

struct device_type___48;

struct bus_type___48;

struct device_driver___48;

struct dev_pm_domain___48;

struct class___48;

struct attribute_group___49;

struct device___48 {
	struct device___48 *parent;
	struct device_private *p;
	struct kobject___52 kobj;
	const char *init_name;
	const struct device_type___48 *type;
	struct mutex mutex;
	struct bus_type___48 *bus;
	struct device_driver___48 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___48 power;
	struct dev_pm_domain___48 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___48 *class;
	const struct attribute_group___49 **groups;
	void (*release)(struct device___48 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___54;

struct super_block___55;

struct dentry___55 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___55 *d_parent;
	struct qstr d_name;
	struct inode___56 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___54 *d_op;
	struct super_block___55 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___54;

struct block_device___55;

struct inode___56 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___54 *i_op;
	struct super_block___55 *i_sb;
	struct address_space___54 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___55 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___24 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___55 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___54 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___55 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___54 {
	int (*d_revalidate)(struct dentry___55 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___55 *, unsigned int);
	int (*d_hash)(const struct dentry___55 *, struct qstr *);
	int (*d_compare)(const struct dentry___55 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___55 *);
	int (*d_init)(struct dentry___55 *);
	void (*d_release)(struct dentry___55 *);
	void (*d_prune)(struct dentry___55 *);
	void (*d_iput)(struct dentry___55 *, struct inode___56 *);
	char * (*d_dname)(struct dentry___55 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___54 *);
	int (*d_manage)(const struct path___54 *, bool);
	struct dentry___55 * (*d_real)(struct dentry___55 *, const struct inode___56 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___54;

struct mem_dqinfo___54 {
	struct quota_format_type___54 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___54;

struct quota_info___54 {
	unsigned int flags;
	struct rw_semaphore___55 dqio_sem;
	struct inode___56 *files[3];
	struct mem_dqinfo___54 info[3];
	const struct quota_format_ops___54 *ops[3];
};

struct rcuwait___54 {
	struct task_struct___55 *task;
};

struct percpu_rw_semaphore___54 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___55 rw_sem;
	struct rcuwait___54 writer;
	int readers_block;
};

struct sb_writers___54 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___54 rw_sem[3];
};

struct file_system_type___54;

struct super_operations___54;

struct dquot_operations___54;

struct quotactl_ops___54;

struct super_block___55 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___54 *s_type;
	const struct super_operations___54 *s_op;
	const struct dquot_operations___54 *dq_op;
	const struct quotactl_ops___54 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___55 *s_root;
	struct rw_semaphore___55 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___55 *s_bdev;
	struct backing_dev_info___24 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___54 s_dquot;
	struct sb_writers___54 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___54 *s_d_op;
	int cleancache_poolid;
	struct shrinker___23 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___45 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___55 {
	struct file___55 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___55 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___55 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___55 *ia_file;
};

struct dquot___54 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___55 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___54 {
	int qf_fmt_id;
	const struct quota_format_ops___54 *qf_ops;
	struct module___49 *qf_owner;
	struct quota_format_type___54 *qf_next;
};

struct quota_format_ops___54 {
	int (*check_quota_file)(struct super_block___55 *, int);
	int (*read_file_info)(struct super_block___55 *, int);
	int (*write_file_info)(struct super_block___55 *, int);
	int (*free_file_info)(struct super_block___55 *, int);
	int (*read_dqblk)(struct dquot___54 *);
	int (*commit_dqblk)(struct dquot___54 *);
	int (*release_dqblk)(struct dquot___54 *);
	int (*get_next_id)(struct super_block___55 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___54 {
	int (*write_dquot)(struct dquot___54 *);
	struct dquot___54 * (*alloc_dquot)(struct super_block___55 *, int);
	void (*destroy_dquot)(struct dquot___54 *);
	int (*acquire_dquot)(struct dquot___54 *);
	int (*release_dquot)(struct dquot___54 *);
	int (*mark_dirty)(struct dquot___54 *);
	int (*write_info)(struct super_block___55 *, int);
	qsize_t * (*get_reserved_space)(struct inode___56 *);
	int (*get_projid)(struct inode___56 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___56 *, qsize_t *);
	int (*get_next_id)(struct super_block___55 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___54 {
	int (*quota_on)(struct super_block___55 *, int, int, const struct path___54 *);
	int (*quota_off)(struct super_block___55 *, int);
	int (*quota_enable)(struct super_block___55 *, unsigned int);
	int (*quota_disable)(struct super_block___55 *, unsigned int);
	int (*quota_sync)(struct super_block___55 *, int);
	int (*set_info)(struct super_block___55 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___55 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___55 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___55 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___55 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___55 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___46 {
	struct kobject___52 kobj;
	struct module___49 *mod;
	struct kobject___52 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___46 {
	struct module___49 *mod;
	struct latch_tree_node node;
};

struct module_layout___46 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___46 mtn;
};

struct module_attribute___46;

struct kernel_param___46;

struct module___49 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___46 mkobj;
	struct module_attribute___46 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___52 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___46 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___46 core_layout;
	struct module_layout___46 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___29 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___23;

struct swap_info_struct___18;

struct address_space_operations___54 {
	int (*writepage)(struct page___55 *, struct writeback_control___23 *);
	int (*readpage)(struct file___55 *, struct page___55 *);
	int (*writepages)(struct address_space___54 *, struct writeback_control___23 *);
	int (*set_page_dirty)(struct page___55 *);
	int (*readpages)(struct file___55 *, struct address_space___54 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___55 *, struct address_space___54 *, loff_t, unsigned int, unsigned int, struct page___55 **, void **);
	int (*write_end)(struct file___55 *, struct address_space___54 *, loff_t, unsigned int, unsigned int, struct page___55 *, void *);
	sector_t (*bmap)(struct address_space___54 *, sector_t);
	void (*invalidatepage)(struct page___55 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___55 *, gfp_t);
	void (*freepage)(struct page___55 *);
	ssize_t (*direct_IO)(struct kiocb___55 *, struct iov_iter___25 *);
	int (*migratepage)(struct address_space___54 *, struct page___55 *, struct page___55 *, enum migrate_mode);
	bool (*isolate_page)(struct page___55 *, isolate_mode_t);
	void (*putback_page)(struct page___55 *);
	int (*launder_page)(struct page___55 *);
	int (*is_partially_uptodate)(struct page___55 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___55 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___54 *, struct page___55 *);
	int (*swap_activate)(struct swap_info_struct___18 *, struct file___55 *, sector_t *);
	void (*swap_deactivate)(struct file___55 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___23 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___24 *wb;
	struct inode___56 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___24;

struct iov_iter___25 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___24 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct swap_info_struct___18 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___55 *bdev;
	struct file___55 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___55 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___56 *bd_inode;
	struct super_block___55 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___55 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___24 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___54 {
	struct dentry___55 * (*lookup)(struct inode___56 *, struct dentry___55 *, unsigned int);
	const char * (*get_link)(struct dentry___55 *, struct inode___56 *, struct delayed_call *);
	int (*permission)(struct inode___56 *, int);
	struct posix_acl * (*get_acl)(struct inode___56 *, int);
	int (*readlink)(struct dentry___55 *, char *, int);
	int (*create)(struct inode___56 *, struct dentry___55 *, umode_t, bool);
	int (*link)(struct dentry___55 *, struct inode___56 *, struct dentry___55 *);
	int (*unlink)(struct inode___56 *, struct dentry___55 *);
	int (*symlink)(struct inode___56 *, struct dentry___55 *, const char *);
	int (*mkdir)(struct inode___56 *, struct dentry___55 *, umode_t);
	int (*rmdir)(struct inode___56 *, struct dentry___55 *);
	int (*mknod)(struct inode___56 *, struct dentry___55 *, umode_t, dev_t);
	int (*rename)(struct inode___56 *, struct dentry___55 *, struct inode___56 *, struct dentry___55 *, unsigned int);
	int (*setattr)(struct dentry___55 *, struct iattr___55 *);
	int (*getattr)(const struct path___54 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___55 *, char *, size_t);
	int (*fiemap)(struct inode___56 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___56 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___56 *, struct dentry___55 *, struct file___55 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___56 *, struct dentry___55 *, umode_t);
	int (*set_acl)(struct inode___56 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___54 {
	void (*fl_copy_lock)(struct file_lock___55 *, struct file_lock___55 *);
	void (*fl_release_private)(struct file_lock___55 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___54;

struct file_lock___55 {
	struct file_lock___55 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___55 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___54 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___54 *fl_ops;
	const struct lock_manager_operations___54 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___54 {
	int (*lm_compare_owner)(struct file_lock___55 *, struct file_lock___55 *);
	long unsigned int (*lm_owner_key)(struct file_lock___55 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___55 *);
	int (*lm_grant)(struct file_lock___55 *, int);
	bool (*lm_break)(struct file_lock___55 *);
	int (*lm_change)(struct file_lock___55 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___55 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___54 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___54 *fa_next;
	struct file___55 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___54 {
	const char *name;
	int fs_flags;
	struct dentry___55 * (*mount)(struct file_system_type___54 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___55 *);
	struct module___49 *owner;
	struct file_system_type___54 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___54 {
	struct inode___56 * (*alloc_inode)(struct super_block___55 *);
	void (*destroy_inode)(struct inode___56 *);
	void (*dirty_inode)(struct inode___56 *, int);
	int (*write_inode)(struct inode___56 *, struct writeback_control___23 *);
	int (*drop_inode)(struct inode___56 *);
	void (*evict_inode)(struct inode___56 *);
	void (*put_super)(struct super_block___55 *);
	int (*sync_fs)(struct super_block___55 *, int);
	int (*freeze_super)(struct super_block___55 *);
	int (*freeze_fs)(struct super_block___55 *);
	int (*thaw_super)(struct super_block___55 *);
	int (*unfreeze_fs)(struct super_block___55 *);
	int (*statfs)(struct dentry___55 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___55 *, int *, char *);
	void (*umount_begin)(struct super_block___55 *);
	int (*show_options)(struct seq_file___52 *, struct dentry___55 *);
	int (*show_devname)(struct seq_file___52 *, struct dentry___55 *);
	int (*show_path)(struct seq_file___52 *, struct dentry___55 *);
	int (*show_stats)(struct seq_file___52 *, struct dentry___55 *);
	ssize_t (*quota_read)(struct super_block___55 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___55 *, int, const char *, size_t, loff_t);
	struct dquot___54 ** (*get_dquots)(struct inode___56 *);
	int (*bdev_try_to_free_page)(struct super_block___55 *, struct page___55 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___55 *, struct shrink_control___23 *);
	long int (*free_cached_objects)(struct super_block___55 *, struct shrink_control___23 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___34)(struct file___55 *, wait_queue_head_t *, struct poll_table_struct___35 *);

struct poll_table_struct___35 {
	poll_queue_proc___34 _qproc;
	__poll_t _key;
};

struct seq_operations___49;

struct seq_file___52 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___49 *op;
	int poll_event;
	const struct file___55 *file;
	void *private;
};

typedef void bio_end_io_t___24(struct bio___24 *);

struct bio_vec___24 {
	struct page___55 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___24;

struct bio_set___24;

struct bio___24 {
	struct bio___24 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___24 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___24 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___24 *bi_io_vec;
	struct bio_set___24 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___24 bi_inline_vecs[0];
};

struct kobj_attribute___52 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___52 *, struct kobj_attribute___52 *, char *);
	ssize_t (*store)(struct kobject___52 *, struct kobj_attribute___52 *, const char *, size_t);
};

typedef void compound_page_dtor___54(struct page___55 *);

struct seq_operations___49 {
	void * (*start)(struct seq_file___52 *, loff_t *);
	void (*stop)(struct seq_file___52 *, void *);
	void * (*next)(struct seq_file___52 *, void *, loff_t *);
	int (*show)(struct seq_file___52 *, void *);
};

struct kernfs_root___52;

struct kernfs_elem_dir___52 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___52 *root;
};

struct kernfs_syscall_ops___52;

struct kernfs_root___52 {
	struct kernfs_node___52 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___52 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___52 {
	struct kernfs_node___52 *target_kn;
};

struct kernfs_ops___52;

struct kernfs_elem_attr___52 {
	const struct kernfs_ops___52 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___52 *notify_next;
};

struct kernfs_node___52 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___52 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___52 dir;
		struct kernfs_elem_symlink___52 symlink;
		struct kernfs_elem_attr___52 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___52;

struct kernfs_ops___52 {
	int (*open)(struct kernfs_open_file___52 *);
	void (*release)(struct kernfs_open_file___52 *);
	int (*seq_show)(struct seq_file___52 *, void *);
	void * (*seq_start)(struct seq_file___52 *, loff_t *);
	void * (*seq_next)(struct seq_file___52 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___52 *, void *);
	ssize_t (*read)(struct kernfs_open_file___52 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___52 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___52 *, struct vm_area_struct___55 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___52 *, struct poll_table_struct___35 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___52 {
	int (*remount_fs)(struct kernfs_root___52 *, int *, char *);
	int (*show_options)(struct seq_file___52 *, struct kernfs_root___52 *);
	int (*mkdir)(struct kernfs_node___52 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___52 *);
	int (*rename)(struct kernfs_node___52 *, struct kernfs_node___52 *, const char *);
	int (*show_path)(struct seq_file___52 *, struct kernfs_node___52 *, struct kernfs_root___52 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___52 {
	struct kernfs_node___52 *kn;
	struct file___55 *file;
	struct seq_file___52 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___54 *vm_ops;
};

struct cgroup_namespace___43 {
	refcount_t count;
	struct ns_common___4 ns;
	struct user_namespace___45 *user_ns;
	struct ucounts___45 *ucounts;
	struct css_set___43 *root_cset;
};

struct ucounts___45 {
	struct hlist_node node;
	struct user_namespace___45 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___43;

struct bpf_map_ops___43 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___43 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___43 *, struct file___55 *);
	void (*map_free)(struct bpf_map___43 *);
	int (*map_get_next_key)(struct bpf_map___43 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___43 *);
	void * (*map_lookup_elem)(struct bpf_map___43 *, void *);
	int (*map_update_elem)(struct bpf_map___43 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___43 *, void *);
	int (*map_push_elem)(struct bpf_map___43 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___43 *, void *);
	int (*map_peek_elem)(struct bpf_map___43 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___43 *, struct file___55 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___43 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___43 *, void *, struct seq_file___52 *);
	int (*map_check_btf)(const struct bpf_map___43 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___43 {
	const struct bpf_map_ops___43 *ops;
	struct bpf_map___43 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___54 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___43;

typedef void (*kthread_work_func_t___43)(struct kthread_work___43 *);

struct kthread_worker___43;

struct kthread_work___43 {
	struct list_head node;
	kthread_work_func_t___43 func;
	struct kthread_worker___43 *worker;
	int canceling;
};

struct kthread_worker___43 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___55 *task;
	struct kthread_work___43 *current_work;
};

struct kthread_delayed_work___43 {
	struct kthread_work___43 work;
	struct timer_list timer;
};

struct psi_group___43 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___43 *poll_kworker;
	struct kthread_delayed_work___43 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___43;

struct cgroup_rstat_cpu___43;

struct cgroup___43 {
	struct cgroup_subsys_state___43 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___52 *kn;
	struct cgroup_file___43 procs_file;
	struct cgroup_file___43 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___43 *subsys[13];
	struct cgroup_root___43 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___43 *dom_cgrp;
	struct cgroup_rstat_cpu___43 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___4 bpf;
	atomic_t congestion_count;
	struct cgroup___43 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___43 psi;
	int ancestor_ids[0];
};

struct cftype___43;

struct cgroup_subsys___43 {
	struct cgroup_subsys_state___43 * (*css_alloc)(struct cgroup_subsys_state___43 *);
	int (*css_online)(struct cgroup_subsys_state___43 *);
	void (*css_offline)(struct cgroup_subsys_state___43 *);
	void (*css_released)(struct cgroup_subsys_state___43 *);
	void (*css_free)(struct cgroup_subsys_state___43 *);
	void (*css_reset)(struct cgroup_subsys_state___43 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___43 *, int);
	int (*css_extra_stat_show)(struct seq_file___52 *, struct cgroup_subsys_state___43 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___55 *);
	void (*cancel_fork)(struct task_struct___55 *);
	void (*fork)(struct task_struct___55 *);
	void (*exit)(struct task_struct___55 *);
	void (*free)(struct task_struct___55 *);
	void (*bind)(struct cgroup_subsys_state___43 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___43 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___43 *dfl_cftypes;
	struct cftype___43 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___43 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___43 *updated_children;
	struct cgroup___43 *updated_next;
};

struct cgroup_root___43 {
	struct kernfs_root___52 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___43 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___43 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___43 *ss;
	struct list_head node;
	struct kernfs_ops___52 *kf_ops;
	int (*open)(struct kernfs_open_file___52 *);
	void (*release)(struct kernfs_open_file___52 *);
	u64 (*read_u64)(struct cgroup_subsys_state___43 *, struct cftype___43 *);
	s64 (*read_s64)(struct cgroup_subsys_state___43 *, struct cftype___43 *);
	int (*seq_show)(struct seq_file___52 *, void *);
	void * (*seq_start)(struct seq_file___52 *, loff_t *);
	void * (*seq_next)(struct seq_file___52 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___52 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___43 *, struct cftype___43 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___43 *, struct cftype___43 *, s64);
	ssize_t (*write)(struct kernfs_open_file___52 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___52 *, struct poll_table_struct___35 *);
};

struct bdi_writeback_congested___24 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___24 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___24 {
	struct bio___24 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___24 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___24 bip_inline_vecs[0];
};

struct bio_set___24 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___24 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___23 {
	struct mem_cgroup___23 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___23 {
	struct lruvec___54 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___23 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___23 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct bin_attribute___49;

struct attribute_group___49 {
	const char *name;
	umode_t (*is_visible)(struct kobject___52 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___52 *, struct bin_attribute___49 *, int);
	struct attribute **attrs;
	struct bin_attribute___49 **bin_attrs;
};

struct bin_attribute___49 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___55 *, struct kobject___52 *, struct bin_attribute___49 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___55 *, struct kobject___52 *, struct bin_attribute___49 *, char *, loff_t, size_t);
	int (*mmap)(struct file___55 *, struct kobject___52 *, struct bin_attribute___49 *, struct vm_area_struct___55 *);
};

struct sysfs_ops___51 {
	ssize_t (*show)(struct kobject___52 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___52 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___51;

struct kset___51 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___52 kobj;
	const struct kset_uevent_ops___51 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___51 {
	void (*release)(struct kobject___52 *);
	const struct sysfs_ops___51 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___2 * (*child_ns_type)(struct kobject___52 *);
	const void * (*namespace)(struct kobject___52 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___51 {
	int (* const filter)(struct kset___51 *, struct kobject___52 *);
	const char * (* const name)(struct kset___51 *, struct kobject___52 *);
	int (* const uevent)(struct kset___51 *, struct kobject___52 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___48 {
	int (*prepare)(struct device___48 *);
	void (*complete)(struct device___48 *);
	int (*suspend)(struct device___48 *);
	int (*resume)(struct device___48 *);
	int (*freeze)(struct device___48 *);
	int (*thaw)(struct device___48 *);
	int (*poweroff)(struct device___48 *);
	int (*restore)(struct device___48 *);
	int (*suspend_late)(struct device___48 *);
	int (*resume_early)(struct device___48 *);
	int (*freeze_late)(struct device___48 *);
	int (*thaw_early)(struct device___48 *);
	int (*poweroff_late)(struct device___48 *);
	int (*restore_early)(struct device___48 *);
	int (*suspend_noirq)(struct device___48 *);
	int (*resume_noirq)(struct device___48 *);
	int (*freeze_noirq)(struct device___48 *);
	int (*thaw_noirq)(struct device___48 *);
	int (*poweroff_noirq)(struct device___48 *);
	int (*restore_noirq)(struct device___48 *);
	int (*runtime_suspend)(struct device___48 *);
	int (*runtime_resume)(struct device___48 *);
	int (*runtime_idle)(struct device___48 *);
};

struct pm_qos_constraints___5 {
	struct plist_head list;
	s32 target_value;
	s32 default_value;
	s32 no_constraint_value;
	enum pm_qos_type type;
	struct blocking_notifier_head___54 *notifiers;
};

struct dev_pm_qos_request___5;

struct dev_pm_qos___5 {
	struct pm_qos_constraints___5 resume_latency;
	struct pm_qos_constraints___5 latency_tolerance;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___5 *resume_latency_req;
	struct dev_pm_qos_request___5 *latency_tolerance_req;
	struct dev_pm_qos_request___5 *flags_req;
};

struct dev_pm_domain___48 {
	struct dev_pm_ops___48 ops;
	void (*detach)(struct device___48 *, bool);
	int (*activate)(struct device___48 *);
	void (*sync)(struct device___48 *);
	void (*dismiss)(struct device___48 *);
};

struct bus_type___48 {
	const char *name;
	const char *dev_name;
	struct device___48 *dev_root;
	const struct attribute_group___49 **bus_groups;
	const struct attribute_group___49 **dev_groups;
	const struct attribute_group___49 **drv_groups;
	int (*match)(struct device___48 *, struct device_driver___48 *);
	int (*uevent)(struct device___48 *, struct kobj_uevent_env *);
	int (*probe)(struct device___48 *);
	int (*remove)(struct device___48 *);
	void (*shutdown)(struct device___48 *);
	int (*online)(struct device___48 *);
	int (*offline)(struct device___48 *);
	int (*suspend)(struct device___48 *, pm_message_t);
	int (*resume)(struct device___48 *);
	int (*num_vf)(struct device___48 *);
	int (*dma_configure)(struct device___48 *);
	const struct dev_pm_ops___48 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___48 {
	const char *name;
	struct bus_type___48 *bus;
	struct module___49 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___48 *);
	int (*remove)(struct device___48 *);
	void (*shutdown)(struct device___48 *);
	int (*suspend)(struct device___48 *, pm_message_t);
	int (*resume)(struct device___48 *);
	const struct attribute_group___49 **groups;
	const struct dev_pm_ops___48 *pm;
	void (*coredump)(struct device___48 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___48 {
	const char *name;
	const struct attribute_group___49 **groups;
	int (*uevent)(struct device___48 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___48 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___48 *);
	const struct dev_pm_ops___48 *pm;
};

struct class___48 {
	const char *name;
	struct module___49 *owner;
	const struct attribute_group___49 **class_groups;
	const struct attribute_group___49 **dev_groups;
	struct kobject___52 *dev_kobj;
	int (*dev_uevent)(struct device___48 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___48 *, umode_t *);
	void (*class_release)(struct class___48 *);
	void (*dev_release)(struct device___48 *);
	int (*shutdown_pre)(struct device___48 *);
	const struct kobj_ns_type_operations___2 *ns_type;
	const void * (*namespace)(struct device___48 *);
	const struct dev_pm_ops___48 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___45 {
	struct device___48 dev;
};

struct kernel_param_ops___46 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___46 *);
	int (*get)(char *, const struct kernel_param___46 *);
	void (*free)(void *);
};

struct kparam_array___46;

struct kernel_param___46 {
	const char *name;
	struct module___49 *mod;
	const struct kernel_param_ops___46 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___46 *arr;
	};
};

struct kparam_array___46 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___46 *ops;
	void *elem;
};

struct module_attribute___46 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___46 *, struct module_kobject___46 *, char *);
	ssize_t (*store)(struct module_attribute___46 *, struct module_kobject___46 *, const char *, size_t);
	void (*setup)(struct module___49 *, const char *);
	int (*test)(struct module___49 *);
	void (*free)(struct module___49 *);
};

struct trace_event_class___29;

struct trace_event_call___29 {
	struct list_head list;
	struct trace_event_class___29 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___4 *prog_array;
	int (*perf_perm)(struct trace_event_call___29 *, struct perf_event___34 *);
};

struct perf_cpu_context___34;

struct pmu___34 {
	struct list_head entry;
	struct module___49 *module;
	struct device___48 *dev;
	const struct attribute_group___49 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___34 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___34 *);
	void (*pmu_disable)(struct pmu___34 *);
	int (*event_init)(struct perf_event___34 *);
	void (*event_mapped)(struct perf_event___34 *, struct mm_struct___54 *);
	void (*event_unmapped)(struct perf_event___34 *, struct mm_struct___54 *);
	int (*add)(struct perf_event___34 *, int);
	void (*del)(struct perf_event___34 *, int);
	void (*start)(struct perf_event___34 *, int);
	void (*stop)(struct perf_event___34 *, int);
	void (*read)(struct perf_event___34 *);
	void (*start_txn)(struct pmu___34 *, unsigned int);
	int (*commit_txn)(struct pmu___34 *);
	void (*cancel_txn)(struct pmu___34 *);
	int (*event_idx)(struct perf_event___34 *);
	void (*sched_task)(struct perf_event_context___34 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___34 *);
	int (*filter_match)(struct perf_event___34 *);
	int (*check_period)(struct perf_event___34 *, u64);
};

struct perf_cpu_context___34 {
	struct perf_event_context___34 ctx;
	struct perf_event_context___34 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___34 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___34 {
	struct cgroup_subsys_state___43 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___29 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___29 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___29 *);
	struct list_head * (*get_fields)(struct trace_event_call___29 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___29 *);
};

struct dev_pm_qos_request___5 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___48 *dev;
};

struct module___50;

struct file___56;

struct kiocb___56;

struct iov_iter___26;

struct poll_table_struct___36;

struct vm_area_struct___56;

struct inode___57;

struct file_lock___56;

struct page___56;

struct seq_file___53;

struct file_operations___56 {
	struct module___50 *owner;
	loff_t (*llseek)(struct file___56 *, loff_t, int);
	ssize_t (*read)(struct file___56 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___56 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___56 *, struct iov_iter___26 *);
	ssize_t (*write_iter)(struct kiocb___56 *, struct iov_iter___26 *);
	int (*iopoll)(struct kiocb___56 *, bool);
	int (*iterate)(struct file___56 *, struct dir_context *);
	int (*iterate_shared)(struct file___56 *, struct dir_context *);
	__poll_t (*poll)(struct file___56 *, struct poll_table_struct___36 *);
	long int (*unlocked_ioctl)(struct file___56 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___56 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___56 *, struct vm_area_struct___56 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___57 *, struct file___56 *);
	int (*flush)(struct file___56 *, fl_owner_t);
	int (*release)(struct inode___57 *, struct file___56 *);
	int (*fsync)(struct file___56 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___56 *, int);
	int (*lock)(struct file___56 *, int, struct file_lock___56 *);
	ssize_t (*sendpage)(struct file___56 *, struct page___56 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___56 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___56 *, int, struct file_lock___56 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___56 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___56 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___56 *, long int, struct file_lock___56 **, void **);
	long int (*fallocate)(struct file___56 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___53 *, struct file___56 *);
	ssize_t (*copy_file_range)(struct file___56 *, loff_t, struct file___56 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___56 *, loff_t, struct file___56 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___56 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct consw___5 {
	struct module___50 *owner;
	const char * (*con_startup)();
	void (*con_init)(struct vc_data *, int);
	void (*con_deinit)(struct vc_data *);
	void (*con_clear)(struct vc_data *, int, int, int, int);
	void (*con_putc)(struct vc_data *, int, int, int);
	void (*con_putcs)(struct vc_data *, const short unsigned int *, int, int, int);
	void (*con_cursor)(struct vc_data *, int);
	bool (*con_scroll)(struct vc_data *, unsigned int, unsigned int, enum con_scroll, unsigned int);
	int (*con_switch)(struct vc_data *);
	int (*con_blank)(struct vc_data *, int, int);
	int (*con_font_set)(struct vc_data *, struct console_font *, unsigned int);
	int (*con_font_get)(struct vc_data *, struct console_font *);
	int (*con_font_default)(struct vc_data *, struct console_font *, char *);
	int (*con_font_copy)(struct vc_data *, int);
	int (*con_resize)(struct vc_data *, unsigned int, unsigned int, unsigned int);
	void (*con_set_palette)(struct vc_data *, const unsigned char *);
	void (*con_scrolldelta)(struct vc_data *, int);
	int (*con_set_origin)(struct vc_data *);
	void (*con_save_screen)(struct vc_data *);
	u8 (*con_build_attr)(struct vc_data *, u8, u8, u8, u8, u8, u8);
	void (*con_invert_region)(struct vc_data *, u16 *, int);
	u16 * (*con_screen_pos)(struct vc_data *, int);
	long unsigned int (*con_getxy)(struct vc_data *, long unsigned int, int *, int *);
	void (*con_flush_scrollback)(struct vc_data *);
	int (*con_debug_enter)(struct vc_data *);
	int (*con_debug_leave)(struct vc_data *);
};

struct kset___52;

struct kobj_type___52;

struct kernfs_node___53;

struct kobject___53 {
	const char *name;
	struct list_head entry;
	struct kobject___53 *parent;
	struct kset___52 *kset;
	struct kobj_type___52 *ktype;
	struct kernfs_node___53 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___47 {
	struct kobject___53 kobj;
	struct module___50 *mod;
	struct kobject___53 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___47 {
	struct module___50 *mod;
	struct latch_tree_node node;
};

struct module_layout___47 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___47 mtn;
};

struct module_attribute___47;

struct kernel_param___47;

struct trace_event_call___30;

struct module___50 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___47 mkobj;
	struct module_attribute___47 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___53 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___47 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___47 core_layout;
	struct module_layout___47 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___30 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct perf_event___35;

struct debug_info___35 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___35 *hbp_break[16];
	struct perf_event___35 *hbp_watch[16];
};

struct task_struct___56;

struct hw_perf_event___35 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___56 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___35)(struct perf_event___35 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___35;

struct perf_event_context___35;

struct fasync_struct___55;

struct pid_namespace___49;

struct perf_cgroup___35;

struct perf_event___35 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___35 *group_leader;
	struct pmu___35 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___35 hw;
	struct perf_event_context___35 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___35 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___56 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___55 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___35 *);
	struct callback_head callback_head;
	struct pid_namespace___49 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___35 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___35 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___30 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___35 *cgrp;
	struct list_head sb_list;
};

struct thread_struct___35 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___35 debug;
	long: 64;
};

struct vmacache___55 {
	u64 seqnum;
	struct vm_area_struct___56 *vmas[4];
};

struct page_frag___55 {
	struct page___56 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___55;

struct mem_cgroup___24;

struct pid___49;

struct cred___55;

struct nsproxy___54;

struct signal_struct___51;

struct bio_list___25;

struct backing_dev_info___25;

struct css_set___44;

struct vm_struct___41;

struct task_struct___56 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___56 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___55 *mm;
	struct mm_struct___55 *active_mm;
	struct vmacache___55 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___56 *real_parent;
	struct task_struct___56 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___56 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___24 *active_memcg;
	long int rh_reserved2;
	struct pid___49 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___49 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___49 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___55 *ptracer_cred;
	const struct cred___55 *real_cred;
	const struct cred___55 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___54 *nsproxy;
	struct signal_struct___51 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___56 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___25 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___25 *backing_dev_info;
	struct io_context___12 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___44 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___35 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___55 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___24 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___56 *oom_reaper_list;
	struct vm_struct___41 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___35 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___56 *pgtable_t___55;

struct address_space___55;

struct dev_pagemap___55;

struct page___56 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___55 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___56 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___55 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___55 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___55 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___24 *mem_cgroup;
};

struct pglist_data___55;

struct lruvec___55 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___55 *pgdat;
};

struct zone___55 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___55 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___55 {
	struct zone___55 *zone;
	int zone_idx;
};

struct zonelist___55 {
	struct zoneref___55 _zonerefs[25];
};

struct pglist_data___55 {
	struct zone___55 node_zones[3];
	struct zonelist___55 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___56 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___56 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___55 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___56 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___56 *owner;
};

struct secondary_data___56 {
	void *stack;
	struct task_struct___56 *task;
	long int status;
};

struct blocking_notifier_head___55 {
	struct rw_semaphore___56 rwsem;
	struct notifier_block *head;
};

struct key___56;

struct ucounts___46;

struct user_namespace___46 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___46 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___4 ns;
	long unsigned int flags;
	struct key___56 *persistent_keyring_register;
	struct rw_semaphore___56 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___46 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_root___53;

struct kernfs_elem_dir___53 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___53 *root;
};

struct kernfs_syscall_ops___53;

struct kernfs_root___53 {
	struct kernfs_node___53 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___53 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___53 {
	struct kernfs_node___53 *target_kn;
};

struct kernfs_ops___53;

struct kernfs_elem_attr___53 {
	const struct kernfs_ops___53 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___53 *notify_next;
};

struct kernfs_node___53 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___53 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___53 dir;
		struct kernfs_elem_symlink___53 symlink;
		struct kernfs_elem_attr___53 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___53;

struct kernfs_ops___53 {
	int (*open)(struct kernfs_open_file___53 *);
	void (*release)(struct kernfs_open_file___53 *);
	int (*seq_show)(struct seq_file___53 *, void *);
	void * (*seq_start)(struct seq_file___53 *, loff_t *);
	void * (*seq_next)(struct seq_file___53 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___53 *, void *);
	ssize_t (*read)(struct kernfs_open_file___53 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___53 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___53 *, struct vm_area_struct___56 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___53 *, struct poll_table_struct___36 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___53 {
	int (*remount_fs)(struct kernfs_root___53 *, int *, char *);
	int (*show_options)(struct seq_file___53 *, struct kernfs_root___53 *);
	int (*mkdir)(struct kernfs_node___53 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___53 *);
	int (*rename)(struct kernfs_node___53 *, struct kernfs_node___53 *, const char *);
	int (*show_path)(struct seq_file___53 *, struct kernfs_node___53 *, struct kernfs_root___53 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___50;

struct seq_file___53 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___50 *op;
	int poll_event;
	const struct file___56 *file;
	void *private;
};

struct vm_operations_struct___55;

struct kernfs_open_file___53 {
	struct kernfs_node___53 *kn;
	struct file___56 *file;
	struct seq_file___53 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___55 *vm_ops;
};

struct dentry___56;

struct path___55 {
	struct vfsmount *mnt;
	struct dentry___56 *dentry;
};

struct fown_struct___49 {
	rwlock_t lock;
	struct pid___49 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___56 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___55 f_path;
	struct inode___57 *f_inode;
	const struct file_operations___56 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___49 f_owner;
	const struct cred___55 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___55 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___55;

struct vm_operations_struct___55 {
	void (*open)(struct vm_area_struct___56 *);
	void (*close)(struct vm_area_struct___56 *);
	int (*split)(struct vm_area_struct___56 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___56 *);
	vm_fault_t (*fault)(struct vm_fault___55 *);
	vm_fault_t (*huge_fault)(struct vm_fault___55 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___55 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___56 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___55 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___55 *);
	int (*access)(struct vm_area_struct___56 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___56 *);
	int (*set_policy)(struct vm_area_struct___56 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___56 *, long unsigned int);
	struct page___56 * (*find_special_page)(struct vm_area_struct___56 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___35)(struct file___56 *, wait_queue_head_t *, struct poll_table_struct___36 *);

struct poll_table_struct___36 {
	poll_queue_proc___35 _qproc;
	__poll_t _key;
};

struct vm_area_struct___56 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___56 *vm_next;
	struct vm_area_struct___56 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___55 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___55 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___56 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___50;

struct attribute_group___50 {
	const char *name;
	umode_t (*is_visible)(struct kobject___53 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___53 *, struct bin_attribute___50 *, int);
	struct attribute **attrs;
	struct bin_attribute___50 **bin_attrs;
};

struct bin_attribute___50 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___56 *, struct kobject___53 *, struct bin_attribute___50 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___56 *, struct kobject___53 *, struct bin_attribute___50 *, char *, loff_t, size_t);
	int (*mmap)(struct file___56 *, struct kobject___53 *, struct bin_attribute___50 *, struct vm_area_struct___56 *);
};

struct sysfs_ops___52 {
	ssize_t (*show)(struct kobject___53 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___53 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___52;

struct kset___52 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___53 kobj;
	const struct kset_uevent_ops___52 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___52 {
	void (*release)(struct kobject___53 *);
	const struct sysfs_ops___52 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___2 * (*child_ns_type)(struct kobject___53 *);
	const void * (*namespace)(struct kobject___53 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___52 {
	int (* const filter)(struct kset___52 *, struct kobject___53 *);
	const char * (* const name)(struct kset___52 *, struct kobject___53 *);
	int (* const uevent)(struct kset___52 *, struct kobject___53 *, struct kobj_uevent_env *);
};

struct kobj_attribute___53 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___53 *, struct kobj_attribute___53 *, char *);
	ssize_t (*store)(struct kobject___53 *, struct kobj_attribute___53 *, const char *, size_t);
};

struct device___49;

struct dev_pm_ops___49 {
	int (*prepare)(struct device___49 *);
	void (*complete)(struct device___49 *);
	int (*suspend)(struct device___49 *);
	int (*resume)(struct device___49 *);
	int (*freeze)(struct device___49 *);
	int (*thaw)(struct device___49 *);
	int (*poweroff)(struct device___49 *);
	int (*restore)(struct device___49 *);
	int (*suspend_late)(struct device___49 *);
	int (*resume_early)(struct device___49 *);
	int (*freeze_late)(struct device___49 *);
	int (*thaw_early)(struct device___49 *);
	int (*poweroff_late)(struct device___49 *);
	int (*restore_early)(struct device___49 *);
	int (*suspend_noirq)(struct device___49 *);
	int (*resume_noirq)(struct device___49 *);
	int (*freeze_noirq)(struct device___49 *);
	int (*thaw_noirq)(struct device___49 *);
	int (*poweroff_noirq)(struct device___49 *);
	int (*restore_noirq)(struct device___49 *);
	int (*runtime_suspend)(struct device___49 *);
	int (*runtime_resume)(struct device___49 *);
	int (*runtime_idle)(struct device___49 *);
};

struct dev_pm_qos___6;

struct dev_pm_info___49 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___49 *, s32);
	struct dev_pm_qos___6 *qos;
};

struct device_type___49;

struct bus_type___49;

struct device_driver___49;

struct dev_pm_domain___49;

struct fwnode_handle___37;

struct class___49;

struct device___49 {
	struct device___49 *parent;
	struct device_private *p;
	struct kobject___53 kobj;
	const char *init_name;
	const struct device_type___49 *type;
	struct mutex mutex;
	struct bus_type___49 *bus;
	struct device_driver___49 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___49 power;
	struct dev_pm_domain___49 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___37 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___49 *class;
	const struct attribute_group___50 **groups;
	void (*release)(struct device___49 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct pm_qos_constraints___6 {
	struct plist_head list;
	s32 target_value;
	s32 default_value;
	s32 no_constraint_value;
	enum pm_qos_type type;
	struct blocking_notifier_head___55 *notifiers;
};

struct dev_pm_qos_request___6;

struct dev_pm_qos___6 {
	struct pm_qos_constraints___6 resume_latency;
	struct pm_qos_constraints___6 latency_tolerance;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___6 *resume_latency_req;
	struct dev_pm_qos_request___6 *latency_tolerance_req;
	struct dev_pm_qos_request___6 *flags_req;
};

struct dev_pm_domain___49 {
	struct dev_pm_ops___49 ops;
	void (*detach)(struct device___49 *, bool);
	int (*activate)(struct device___49 *);
	void (*sync)(struct device___49 *);
	void (*dismiss)(struct device___49 *);
};

struct upid___49 {
	int nr;
	struct pid_namespace___49 *ns;
};

struct pid_namespace___49 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___56 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___49 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___56 *proc_self;
	struct dentry___56 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___46 *user_ns;
	struct ucounts___46 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___4 ns;
};

struct pid___49 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___49 numbers[1];
};

struct user_struct___55 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___56 *uid_keyring;
	struct key___56 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___55;

struct mm_struct___55 {
	struct {
		struct vm_area_struct___56 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___56 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___56 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___55 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___56 *owner;
		struct user_namespace___46 *user_ns;
		struct file___56 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___55 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup___44;

struct cgroup_subsys___44;

struct cgroup_subsys_state___44 {
	struct cgroup___44 *cgroup;
	struct cgroup_subsys___44 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___44 *parent;
};

struct mem_cgroup_id___11 {
	int id;
	union {
		refcount_t ref;
		struct {
			atomic_t ref;
		} __UNIQUE_ID_rh_kabi_hide35;
		union {		};
	};
};

struct cgroup_file___44 {
	struct kernfs_node___53 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___24;

struct mem_cgroup___24 {
	struct cgroup_subsys_state___44 css;
	struct mem_cgroup_id___11 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___44 events_file;
	struct cgroup_file___44 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___56 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___24 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cred___55 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___56 *session_keyring;
	struct key___56 *process_keyring;
	struct key___56 *thread_keyring;
	struct key___56 *request_key_auth;
	void *security;
	struct user_struct___55 *user;
	struct user_namespace___46 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct uts_namespace___15;

struct cgroup_namespace___44;

struct nsproxy___54 {
	atomic_t count;
	struct uts_namespace___15 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___49 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___44 *cgroup_ns;
};

struct signal_struct___51 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___56 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___56 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___49 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___49 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___55 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___49 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___25;

struct bio_list___25 {
	struct bio___25 *head;
	struct bio___25 *tail;
};

struct bdi_writeback_congested___25;

struct bdi_writeback___25 {
	struct backing_dev_info___25 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___25 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___44 *memcg_css;
	struct cgroup_subsys_state___44 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___25 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___25 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___49 *dev;
	struct device___49 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___56 *debug_dir;
	struct dentry___56 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___44 {
	struct cgroup_subsys_state___44 *subsys[13];
	refcount_t refcount;
	struct css_set___44 *dom_cset;
	struct cgroup___44 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___44 *mg_src_cgrp;
	struct cgroup___44 *mg_dst_cgrp;
	struct css_set___44 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___35 {
	struct pmu___35 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___56 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___35 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___41 {
	struct vm_struct___41 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___56 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___51 {
	struct task_struct___56 task;
	long unsigned int stack[8192];
};

struct bus_type___49 {
	const char *name;
	const char *dev_name;
	struct device___49 *dev_root;
	const struct attribute_group___50 **bus_groups;
	const struct attribute_group___50 **dev_groups;
	const struct attribute_group___50 **drv_groups;
	int (*match)(struct device___49 *, struct device_driver___49 *);
	int (*uevent)(struct device___49 *, struct kobj_uevent_env *);
	int (*probe)(struct device___49 *);
	int (*remove)(struct device___49 *);
	void (*shutdown)(struct device___49 *);
	int (*online)(struct device___49 *);
	int (*offline)(struct device___49 *);
	int (*suspend)(struct device___49 *, pm_message_t);
	int (*resume)(struct device___49 *);
	int (*num_vf)(struct device___49 *);
	int (*dma_configure)(struct device___49 *);
	const struct dev_pm_ops___49 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___49 {
	const char *name;
	struct bus_type___49 *bus;
	struct module___50 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___49 *);
	int (*remove)(struct device___49 *);
	void (*shutdown)(struct device___49 *);
	int (*suspend)(struct device___49 *, pm_message_t);
	int (*resume)(struct device___49 *);
	const struct attribute_group___50 **groups;
	const struct dev_pm_ops___49 *pm;
	void (*coredump)(struct device___49 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___49 {
	const char *name;
	const struct attribute_group___50 **groups;
	int (*uevent)(struct device___49 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___49 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___49 *);
	const struct dev_pm_ops___49 *pm;
};

struct class___49 {
	const char *name;
	struct module___50 *owner;
	const struct attribute_group___50 **class_groups;
	const struct attribute_group___50 **dev_groups;
	struct kobject___53 *dev_kobj;
	int (*dev_uevent)(struct device___49 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___49 *, umode_t *);
	void (*class_release)(struct class___49 *);
	void (*dev_release)(struct device___49 *);
	int (*shutdown_pre)(struct device___49 *);
	const struct kobj_ns_type_operations___2 *ns_type;
	const void * (*namespace)(struct device___49 *);
	const struct dev_pm_ops___49 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct fwnode_operations___37;

struct fwnode_handle___37 {
	struct fwnode_handle___37 *secondary;
	const struct fwnode_operations___37 *ops;
};

struct node___46 {
	struct device___49 dev;
};

struct dentry_operations___55;

struct super_block___56;

struct dentry___56 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___56 *d_parent;
	struct qstr d_name;
	struct inode___57 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___55 *d_op;
	struct super_block___56 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___55;

struct address_space___55 {
	struct inode___57 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___56 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___55 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___55;

struct block_device___56;

struct inode___57 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___55 *i_op;
	struct super_block___56 *i_sb;
	struct address_space___55 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___56 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___25 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___56 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___55 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___56 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___55 {
	int (*d_revalidate)(struct dentry___56 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___56 *, unsigned int);
	int (*d_hash)(const struct dentry___56 *, struct qstr *);
	int (*d_compare)(const struct dentry___56 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___56 *);
	int (*d_init)(struct dentry___56 *);
	void (*d_release)(struct dentry___56 *);
	void (*d_prune)(struct dentry___56 *);
	void (*d_iput)(struct dentry___56 *, struct inode___57 *);
	char * (*d_dname)(struct dentry___56 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___55 *);
	int (*d_manage)(const struct path___55 *, bool);
	struct dentry___56 * (*d_real)(struct dentry___56 *, const struct inode___57 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___55;

struct mem_dqinfo___55 {
	struct quota_format_type___55 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___55;

struct quota_info___55 {
	unsigned int flags;
	struct rw_semaphore___56 dqio_sem;
	struct inode___57 *files[3];
	struct mem_dqinfo___55 info[3];
	const struct quota_format_ops___55 *ops[3];
};

struct rcuwait___55 {
	struct task_struct___56 *task;
};

struct percpu_rw_semaphore___55 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___56 rw_sem;
	struct rcuwait___55 writer;
	int readers_block;
};

struct sb_writers___55 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___55 rw_sem[3];
};

struct shrink_control___24;

struct shrinker___24 {
	long unsigned int (*count_objects)(struct shrinker___24 *, struct shrink_control___24 *);
	long unsigned int (*scan_objects)(struct shrinker___24 *, struct shrink_control___24 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___55;

struct super_operations___55;

struct dquot_operations___55;

struct quotactl_ops___55;

struct super_block___56 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___55 *s_type;
	const struct super_operations___55 *s_op;
	const struct dquot_operations___55 *dq_op;
	const struct quotactl_ops___55 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___56 *s_root;
	struct rw_semaphore___56 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___56 *s_bdev;
	struct backing_dev_info___25 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___55 s_dquot;
	struct sb_writers___55 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___55 *s_d_op;
	int cleancache_poolid;
	struct shrinker___24 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___46 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___24 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___24 *memcg;
};

typedef int (*dev_page_fault_t___55)(struct vm_area_struct___56 *, long unsigned int, const struct page___56 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___55)(struct page___56 *, void *);

struct dev_pagemap___55 {
	dev_page_fault_t___55 page_fault;
	dev_page_free_t___55 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___49 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___55 {
	struct task_struct___56 *task;
	struct core_thread___55 *next;
};

struct core_state___55 {
	atomic_t nr_threads;
	struct core_thread___55 dumper;
	struct completion startup;
};

struct vm_fault___55 {
	struct vm_area_struct___56 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___56 *cow_page;
	struct mem_cgroup___24 *memcg;
	struct page___56 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___55 prealloc_pte;
};

struct kiocb___56 {
	struct file___56 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___56 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___56 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___56 *ia_file;
};

struct dquot___55 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___56 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___55 {
	int qf_fmt_id;
	const struct quota_format_ops___55 *qf_ops;
	struct module___50 *qf_owner;
	struct quota_format_type___55 *qf_next;
};

struct quota_format_ops___55 {
	int (*check_quota_file)(struct super_block___56 *, int);
	int (*read_file_info)(struct super_block___56 *, int);
	int (*write_file_info)(struct super_block___56 *, int);
	int (*free_file_info)(struct super_block___56 *, int);
	int (*read_dqblk)(struct dquot___55 *);
	int (*commit_dqblk)(struct dquot___55 *);
	int (*release_dqblk)(struct dquot___55 *);
	int (*get_next_id)(struct super_block___56 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___55 {
	int (*write_dquot)(struct dquot___55 *);
	struct dquot___55 * (*alloc_dquot)(struct super_block___56 *, int);
	void (*destroy_dquot)(struct dquot___55 *);
	int (*acquire_dquot)(struct dquot___55 *);
	int (*release_dquot)(struct dquot___55 *);
	int (*mark_dirty)(struct dquot___55 *);
	int (*write_info)(struct super_block___56 *, int);
	qsize_t * (*get_reserved_space)(struct inode___57 *);
	int (*get_projid)(struct inode___57 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___57 *, qsize_t *);
	int (*get_next_id)(struct super_block___56 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___55 {
	int (*quota_on)(struct super_block___56 *, int, int, const struct path___55 *);
	int (*quota_off)(struct super_block___56 *, int);
	int (*quota_enable)(struct super_block___56 *, unsigned int);
	int (*quota_disable)(struct super_block___56 *, unsigned int);
	int (*quota_sync)(struct super_block___56 *, int);
	int (*set_info)(struct super_block___56 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___56 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___56 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___56 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___56 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___56 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___24;

struct swap_info_struct___19;

struct address_space_operations___55 {
	int (*writepage)(struct page___56 *, struct writeback_control___24 *);
	int (*readpage)(struct file___56 *, struct page___56 *);
	int (*writepages)(struct address_space___55 *, struct writeback_control___24 *);
	int (*set_page_dirty)(struct page___56 *);
	int (*readpages)(struct file___56 *, struct address_space___55 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___56 *, struct address_space___55 *, loff_t, unsigned int, unsigned int, struct page___56 **, void **);
	int (*write_end)(struct file___56 *, struct address_space___55 *, loff_t, unsigned int, unsigned int, struct page___56 *, void *);
	sector_t (*bmap)(struct address_space___55 *, sector_t);
	void (*invalidatepage)(struct page___56 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___56 *, gfp_t);
	void (*freepage)(struct page___56 *);
	ssize_t (*direct_IO)(struct kiocb___56 *, struct iov_iter___26 *);
	int (*migratepage)(struct address_space___55 *, struct page___56 *, struct page___56 *, enum migrate_mode);
	bool (*isolate_page)(struct page___56 *, isolate_mode_t);
	void (*putback_page)(struct page___56 *);
	int (*launder_page)(struct page___56 *);
	int (*is_partially_uptodate)(struct page___56 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___56 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___55 *, struct page___56 *);
	int (*swap_activate)(struct swap_info_struct___19 *, struct file___56 *, sector_t *);
	void (*swap_deactivate)(struct file___56 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___24 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___25 *wb;
	struct inode___57 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___25;

struct iov_iter___26 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___25 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct swap_info_struct___19 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___56 *bdev;
	struct file___56 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___56 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___57 *bd_inode;
	struct super_block___56 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___56 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___25 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___55 {
	struct dentry___56 * (*lookup)(struct inode___57 *, struct dentry___56 *, unsigned int);
	const char * (*get_link)(struct dentry___56 *, struct inode___57 *, struct delayed_call *);
	int (*permission)(struct inode___57 *, int);
	struct posix_acl * (*get_acl)(struct inode___57 *, int);
	int (*readlink)(struct dentry___56 *, char *, int);
	int (*create)(struct inode___57 *, struct dentry___56 *, umode_t, bool);
	int (*link)(struct dentry___56 *, struct inode___57 *, struct dentry___56 *);
	int (*unlink)(struct inode___57 *, struct dentry___56 *);
	int (*symlink)(struct inode___57 *, struct dentry___56 *, const char *);
	int (*mkdir)(struct inode___57 *, struct dentry___56 *, umode_t);
	int (*rmdir)(struct inode___57 *, struct dentry___56 *);
	int (*mknod)(struct inode___57 *, struct dentry___56 *, umode_t, dev_t);
	int (*rename)(struct inode___57 *, struct dentry___56 *, struct inode___57 *, struct dentry___56 *, unsigned int);
	int (*setattr)(struct dentry___56 *, struct iattr___56 *);
	int (*getattr)(const struct path___55 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___56 *, char *, size_t);
	int (*fiemap)(struct inode___57 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___57 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___57 *, struct dentry___56 *, struct file___56 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___57 *, struct dentry___56 *, umode_t);
	int (*set_acl)(struct inode___57 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___55 {
	void (*fl_copy_lock)(struct file_lock___56 *, struct file_lock___56 *);
	void (*fl_release_private)(struct file_lock___56 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___55;

struct file_lock___56 {
	struct file_lock___56 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___56 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___55 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___55 *fl_ops;
	const struct lock_manager_operations___55 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___55 {
	int (*lm_compare_owner)(struct file_lock___56 *, struct file_lock___56 *);
	long unsigned int (*lm_owner_key)(struct file_lock___56 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___56 *);
	int (*lm_grant)(struct file_lock___56 *, int);
	bool (*lm_break)(struct file_lock___56 *);
	int (*lm_change)(struct file_lock___56 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___56 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___55 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___55 *fa_next;
	struct file___56 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___55 {
	const char *name;
	int fs_flags;
	struct dentry___56 * (*mount)(struct file_system_type___55 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___56 *);
	struct module___50 *owner;
	struct file_system_type___55 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___55 {
	struct inode___57 * (*alloc_inode)(struct super_block___56 *);
	void (*destroy_inode)(struct inode___57 *);
	void (*dirty_inode)(struct inode___57 *, int);
	int (*write_inode)(struct inode___57 *, struct writeback_control___24 *);
	int (*drop_inode)(struct inode___57 *);
	void (*evict_inode)(struct inode___57 *);
	void (*put_super)(struct super_block___56 *);
	int (*sync_fs)(struct super_block___56 *, int);
	int (*freeze_super)(struct super_block___56 *);
	int (*freeze_fs)(struct super_block___56 *);
	int (*thaw_super)(struct super_block___56 *);
	int (*unfreeze_fs)(struct super_block___56 *);
	int (*statfs)(struct dentry___56 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___56 *, int *, char *);
	void (*umount_begin)(struct super_block___56 *);
	int (*show_options)(struct seq_file___53 *, struct dentry___56 *);
	int (*show_devname)(struct seq_file___53 *, struct dentry___56 *);
	int (*show_path)(struct seq_file___53 *, struct dentry___56 *);
	int (*show_stats)(struct seq_file___53 *, struct dentry___56 *);
	ssize_t (*quota_read)(struct super_block___56 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___56 *, int, const char *, size_t, loff_t);
	struct dquot___55 ** (*get_dquots)(struct inode___57 *);
	int (*bdev_try_to_free_page)(struct super_block___56 *, struct page___56 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___56 *, struct shrink_control___24 *);
	long int (*free_cached_objects)(struct super_block___56 *, struct shrink_control___24 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___25(struct bio___25 *);

struct bio_vec___25 {
	struct page___56 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___25;

struct bio_set___25;

struct bio___25 {
	struct bio___25 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___25 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___25 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___25 *bi_io_vec;
	struct bio_set___25 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___25 bi_inline_vecs[0];
};

typedef int (*key_restrict_link_func_t___55)(struct key___56 *, const struct key_type *, const union key_payload *, struct key___56 *);

struct key_restriction___56;

struct key___56 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___56 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___56 *restrict_link;
};

struct key_restriction___56 {
	key_restrict_link_func_t___55 check;
	struct key___56 *key;
	struct key_type *keytype;
};

typedef void compound_page_dtor___55(struct page___56 *);

struct seq_operations___50 {
	void * (*start)(struct seq_file___53 *, loff_t *);
	void (*stop)(struct seq_file___53 *, void *);
	void * (*next)(struct seq_file___53 *, void *, loff_t *);
	int (*show)(struct seq_file___53 *, void *);
};

struct uts_namespace___15 {
	struct kref kref;
	struct new_utsname name;
	struct user_namespace___46 *user_ns;
	struct ucounts___46 *ucounts;
	struct ns_common___4 ns;
};

struct cgroup_namespace___44 {
	refcount_t count;
	struct ns_common___4 ns;
	struct user_namespace___46 *user_ns;
	struct ucounts___46 *ucounts;
	struct css_set___44 *root_cset;
};

struct ucounts___46 {
	struct hlist_node node;
	struct user_namespace___46 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct kernel_param_ops___47 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___47 *);
	int (*get)(char *, const struct kernel_param___47 *);
	void (*free)(void *);
};

struct kparam_array___47;

struct kernel_param___47 {
	const char *name;
	struct module___50 *mod;
	const struct kernel_param_ops___47 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___47 *arr;
	};
};

struct kparam_array___47 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___47 *ops;
	void *elem;
};

struct module_attribute___47 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___47 *, struct module_kobject___47 *, char *);
	ssize_t (*store)(struct module_attribute___47 *, struct module_kobject___47 *, const char *, size_t);
	void (*setup)(struct module___50 *, const char *);
	int (*test)(struct module___50 *);
	void (*free)(struct module___50 *);
};

struct trace_event_class___30;

struct trace_event_call___30 {
	struct list_head list;
	struct trace_event_class___30 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___4 *prog_array;
	int (*perf_perm)(struct trace_event_call___30 *, struct perf_event___35 *);
};

struct bpf_map___44;

struct bpf_map_ops___44 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___44 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___44 *, struct file___56 *);
	void (*map_free)(struct bpf_map___44 *);
	int (*map_get_next_key)(struct bpf_map___44 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___44 *);
	void * (*map_lookup_elem)(struct bpf_map___44 *, void *);
	int (*map_update_elem)(struct bpf_map___44 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___44 *, void *);
	int (*map_push_elem)(struct bpf_map___44 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___44 *, void *);
	int (*map_peek_elem)(struct bpf_map___44 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___44 *, struct file___56 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___44 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___44 *, void *, struct seq_file___53 *);
	int (*map_check_btf)(const struct bpf_map___44 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___44 {
	const struct bpf_map_ops___44 *ops;
	struct bpf_map___44 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___55 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___44;

typedef void (*kthread_work_func_t___44)(struct kthread_work___44 *);

struct kthread_worker___44;

struct kthread_work___44 {
	struct list_head node;
	kthread_work_func_t___44 func;
	struct kthread_worker___44 *worker;
	int canceling;
};

struct kthread_worker___44 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___56 *task;
	struct kthread_work___44 *current_work;
};

struct kthread_delayed_work___44 {
	struct kthread_work___44 work;
	struct timer_list timer;
};

struct psi_group___44 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___44 *poll_kworker;
	struct kthread_delayed_work___44 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___44;

struct cgroup_rstat_cpu___44;

struct cgroup___44 {
	struct cgroup_subsys_state___44 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___53 *kn;
	struct cgroup_file___44 procs_file;
	struct cgroup_file___44 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___44 *subsys[13];
	struct cgroup_root___44 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___44 *dom_cgrp;
	struct cgroup_rstat_cpu___44 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___4 bpf;
	atomic_t congestion_count;
	struct cgroup___44 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___44 psi;
	int ancestor_ids[0];
};

struct cftype___44;

struct cgroup_subsys___44 {
	struct cgroup_subsys_state___44 * (*css_alloc)(struct cgroup_subsys_state___44 *);
	int (*css_online)(struct cgroup_subsys_state___44 *);
	void (*css_offline)(struct cgroup_subsys_state___44 *);
	void (*css_released)(struct cgroup_subsys_state___44 *);
	void (*css_free)(struct cgroup_subsys_state___44 *);
	void (*css_reset)(struct cgroup_subsys_state___44 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___44 *, int);
	int (*css_extra_stat_show)(struct seq_file___53 *, struct cgroup_subsys_state___44 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___56 *);
	void (*cancel_fork)(struct task_struct___56 *);
	void (*fork)(struct task_struct___56 *);
	void (*exit)(struct task_struct___56 *);
	void (*free)(struct task_struct___56 *);
	void (*bind)(struct cgroup_subsys_state___44 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___44 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___44 *dfl_cftypes;
	struct cftype___44 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___44 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___44 *updated_children;
	struct cgroup___44 *updated_next;
};

struct cgroup_root___44 {
	struct kernfs_root___53 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___44 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___44 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___44 *ss;
	struct list_head node;
	struct kernfs_ops___53 *kf_ops;
	int (*open)(struct kernfs_open_file___53 *);
	void (*release)(struct kernfs_open_file___53 *);
	u64 (*read_u64)(struct cgroup_subsys_state___44 *, struct cftype___44 *);
	s64 (*read_s64)(struct cgroup_subsys_state___44 *, struct cftype___44 *);
	int (*seq_show)(struct seq_file___53 *, void *);
	void * (*seq_start)(struct seq_file___53 *, loff_t *);
	void * (*seq_next)(struct seq_file___53 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___53 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___44 *, struct cftype___44 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___44 *, struct cftype___44 *, s64);
	ssize_t (*write)(struct kernfs_open_file___53 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___53 *, struct poll_table_struct___36 *);
};

struct perf_cpu_context___35;

struct pmu___35 {
	struct list_head entry;
	struct module___50 *module;
	struct device___49 *dev;
	const struct attribute_group___50 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___35 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___35 *);
	void (*pmu_disable)(struct pmu___35 *);
	int (*event_init)(struct perf_event___35 *);
	void (*event_mapped)(struct perf_event___35 *, struct mm_struct___55 *);
	void (*event_unmapped)(struct perf_event___35 *, struct mm_struct___55 *);
	int (*add)(struct perf_event___35 *, int);
	void (*del)(struct perf_event___35 *, int);
	void (*start)(struct perf_event___35 *, int);
	void (*stop)(struct perf_event___35 *, int);
	void (*read)(struct perf_event___35 *);
	void (*start_txn)(struct pmu___35 *, unsigned int);
	int (*commit_txn)(struct pmu___35 *);
	void (*cancel_txn)(struct pmu___35 *);
	int (*event_idx)(struct perf_event___35 *);
	void (*sched_task)(struct perf_event_context___35 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___35 *);
	int (*filter_match)(struct perf_event___35 *);
	int (*check_period)(struct perf_event___35 *, u64);
};

struct perf_cpu_context___35 {
	struct perf_event_context___35 ctx;
	struct perf_event_context___35 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___35 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___35 {
	struct cgroup_subsys_state___44 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___30 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___30 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___30 *);
	struct list_head * (*get_fields)(struct trace_event_call___30 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___30 *);
};

struct fwnode_reference_args___37;

struct fwnode_endpoint___37;

struct fwnode_operations___37 {
	struct fwnode_handle___37 * (*get)(struct fwnode_handle___37 *);
	void (*put)(struct fwnode_handle___37 *);
	bool (*device_is_available)(const struct fwnode_handle___37 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___37 *, const struct device___49 *);
	bool (*property_present)(const struct fwnode_handle___37 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___37 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___37 *, const char *, const char **, size_t);
	struct fwnode_handle___37 * (*get_parent)(const struct fwnode_handle___37 *);
	struct fwnode_handle___37 * (*get_next_child_node)(const struct fwnode_handle___37 *, struct fwnode_handle___37 *);
	struct fwnode_handle___37 * (*get_named_child_node)(const struct fwnode_handle___37 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___37 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___37 *);
	struct fwnode_handle___37 * (*graph_get_next_endpoint)(const struct fwnode_handle___37 *, struct fwnode_handle___37 *);
	struct fwnode_handle___37 * (*graph_get_remote_endpoint)(const struct fwnode_handle___37 *);
	struct fwnode_handle___37 * (*graph_get_port_parent)(struct fwnode_handle___37 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___37 *, struct fwnode_endpoint___37 *);
};

struct fwnode_endpoint___37 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___37 *local_fwnode;
};

struct fwnode_reference_args___37 {
	struct fwnode_handle___37 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct bdi_writeback_congested___25 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___25 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___25 {
	struct bio___25 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___25 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___25 bip_inline_vecs[0];
};

struct bio_set___25 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___25 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___24 {
	struct mem_cgroup___24 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___24 {
	struct lruvec___55 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___24 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___24 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct platform_suspend_ops {
	int (*valid)(suspend_state_t);
	int (*begin)(suspend_state_t);
	int (*prepare)();
	int (*prepare_late)();
	int (*enter)(suspend_state_t);
	void (*wake)();
	void (*finish)();
	bool (*suspend_again)();
	void (*end)();
	void (*recover)();
};

struct platform_s2idle_ops {
	int (*begin)();
	int (*prepare)();
	void (*wake)();
	void (*sync)();
	void (*restore)();
	void (*end)();
};

struct swait_queue___3 {
	struct task_struct___56 *task;
	struct list_head task_list;
};

struct dev_pm_qos_request___6 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___49 *dev;
};

struct module___51;

struct file___57;

struct kiocb___57;

struct iov_iter___27;

struct poll_table_struct___37;

struct vm_area_struct___57;

struct inode___58;

struct file_lock___57;

struct page___57;

struct seq_file___54;

struct file_operations___57 {
	struct module___51 *owner;
	loff_t (*llseek)(struct file___57 *, loff_t, int);
	ssize_t (*read)(struct file___57 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___57 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___57 *, struct iov_iter___27 *);
	ssize_t (*write_iter)(struct kiocb___57 *, struct iov_iter___27 *);
	int (*iopoll)(struct kiocb___57 *, bool);
	int (*iterate)(struct file___57 *, struct dir_context *);
	int (*iterate_shared)(struct file___57 *, struct dir_context *);
	__poll_t (*poll)(struct file___57 *, struct poll_table_struct___37 *);
	long int (*unlocked_ioctl)(struct file___57 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___57 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___57 *, struct vm_area_struct___57 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___58 *, struct file___57 *);
	int (*flush)(struct file___57 *, fl_owner_t);
	int (*release)(struct inode___58 *, struct file___57 *);
	int (*fsync)(struct file___57 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___57 *, int);
	int (*lock)(struct file___57 *, int, struct file_lock___57 *);
	ssize_t (*sendpage)(struct file___57 *, struct page___57 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___57 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___57 *, int, struct file_lock___57 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___57 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___57 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___57 *, long int, struct file_lock___57 **, void **);
	long int (*fallocate)(struct file___57 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___54 *, struct file___57 *);
	ssize_t (*copy_file_range)(struct file___57 *, loff_t, struct file___57 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___57 *, loff_t, struct file___57 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___57 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___56 {
	u64 seqnum;
	struct vm_area_struct___57 *vmas[4];
};

struct page_frag___56 {
	struct page___57 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___36;

struct debug_info___36 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___36 *hbp_break[16];
	struct perf_event___36 *hbp_watch[16];
};

struct thread_struct___36 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___36 debug;
	long: 64;
};

struct mm_struct___56;

struct mem_cgroup___25;

struct pid___50;

struct cred___56;

struct nsproxy___55;

struct signal_struct___52;

struct bio_list___26;

struct backing_dev_info___26;

struct css_set___45;

struct perf_event_context___36;

struct task_struct___57 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___57 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___56 *mm;
	struct mm_struct___56 *active_mm;
	struct vmacache___56 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___57 *real_parent;
	struct task_struct___57 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___57 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___25 *active_memcg;
	long int rh_reserved2;
	struct pid___50 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___50 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___50 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___56 *ptracer_cred;
	const struct cred___56 *real_cred;
	const struct cred___56 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___55 *nsproxy;
	struct signal_struct___52 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___57 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___26 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___26 *backing_dev_info;
	struct io_context___12 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___45 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___36 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___56 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___25 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___57 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___36 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___36 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___57 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___36)(struct perf_event___36 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___36;

struct fasync_struct___56;

struct pid_namespace___50;

struct trace_event_call___31;

struct perf_cgroup___36;

struct perf_event___36 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___36 *group_leader;
	struct pmu___36 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___36 hw;
	struct perf_event_context___36 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___36 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___57 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___56 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___36 *);
	struct callback_head callback_head;
	struct pid_namespace___50 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___36 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___36 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___31 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___36 *cgrp;
	struct list_head sb_list;
};

typedef struct page___57 *pgtable_t___56;

struct address_space___56;

struct dev_pagemap___56;

struct page___57 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___56 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___57 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___56 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___56 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___56 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___25 *mem_cgroup;
};

struct pglist_data___56;

struct lruvec___56 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___56 *pgdat;
};

struct zone___56 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___56 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___56 {
	struct zone___56 *zone;
	int zone_idx;
};

struct zonelist___56 {
	struct zoneref___56 _zonerefs[25];
};

struct pglist_data___56 {
	struct zone___56 node_zones[3];
	struct zonelist___56 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___57 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___57 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___56 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___57 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___57 *owner;
};

struct secondary_data___57 {
	void *stack;
	struct task_struct___57 *task;
	long int status;
};

struct blocking_notifier_head___56 {
	struct rw_semaphore___57 rwsem;
	struct notifier_block *head;
};

struct upid___50 {
	int nr;
	struct pid_namespace___50 *ns;
};

struct vfsmount___9;

struct dentry___57;

struct user_namespace___47;

struct ucounts___47;

struct pid_namespace___50 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___57 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___50 *parent;
	struct vfsmount___9 *proc_mnt;
	struct dentry___57 *proc_self;
	struct dentry___57 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___47 *user_ns;
	struct ucounts___47 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common ns;
};

struct pid___50 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___50 numbers[1];
};

struct key___57;

struct user_namespace___47 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___47 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common ns;
	long unsigned int flags;
	struct key___57 *persistent_keyring_register;
	struct rw_semaphore___57 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___47 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct user_struct___56 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___57 *uid_keyring;
	struct key___57 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___56;

struct vm_area_struct___57 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___57 *vm_next;
	struct vm_area_struct___57 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___56 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___56 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___57 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___56;

struct mm_struct___56 {
	struct {
		struct vm_area_struct___57 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___57 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___57 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___56 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___57 *owner;
		struct user_namespace___47 *user_ns;
		struct file___57 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___56 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup___45;

struct cgroup_subsys___45;

struct cgroup_subsys_state___45 {
	struct cgroup___45 *cgroup;
	struct cgroup_subsys___45 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___45 *parent;
};

struct kernfs_node___54;

struct cgroup_file___45 {
	struct kernfs_node___54 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___25;

struct mem_cgroup___25 {
	struct cgroup_subsys_state___45 css;
	struct mem_cgroup_id___6 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___45 events_file;
	struct cgroup_file___45 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___57 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___25 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cred___56 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___57 *session_keyring;
	struct key___57 *process_keyring;
	struct key___57 *thread_keyring;
	struct key___57 *request_key_auth;
	void *security;
	struct user_struct___56 *user;
	struct user_namespace___47 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct uts_namespace___16;

struct cgroup_namespace___45;

struct nsproxy___55 {
	atomic_t count;
	struct uts_namespace___16 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___50 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___45 *cgroup_ns;
};

struct signal_struct___52 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___57 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___57 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___50 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___50 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___56 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___50 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___26;

struct bio_list___26 {
	struct bio___26 *head;
	struct bio___26 *tail;
};

struct bdi_writeback_congested___26;

struct bdi_writeback___26 {
	struct backing_dev_info___26 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___26 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___45 *memcg_css;
	struct cgroup_subsys_state___45 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___50;

struct backing_dev_info___26 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___26 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___50 *dev;
	struct device___50 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___57 *debug_dir;
	struct dentry___57 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___45 {
	struct cgroup_subsys_state___45 *subsys[13];
	refcount_t refcount;
	struct css_set___45 *dom_cset;
	struct cgroup___45 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___45 *mg_src_cgrp;
	struct cgroup___45 *mg_dst_cgrp;
	struct css_set___45 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___36 {
	struct pmu___36 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___57 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___36 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

union thread_union___52 {
	struct task_struct___57 task;
	long unsigned int stack[8192];
};

struct dentry_operations___56;

struct super_block___57;

struct dentry___57 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___57 *d_parent;
	struct qstr d_name;
	struct inode___58 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___56 *d_op;
	struct super_block___57 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___56;

struct address_space___56 {
	struct inode___58 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___57 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___56 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___56;

struct block_device___57;

struct inode___58 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___56 *i_op;
	struct super_block___57 *i_sb;
	struct address_space___56 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___57 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___26 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___57 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___56 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___57 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___56;

struct dentry_operations___56 {
	int (*d_revalidate)(struct dentry___57 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___57 *, unsigned int);
	int (*d_hash)(const struct dentry___57 *, struct qstr *);
	int (*d_compare)(const struct dentry___57 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___57 *);
	int (*d_init)(struct dentry___57 *);
	void (*d_release)(struct dentry___57 *);
	void (*d_prune)(struct dentry___57 *);
	void (*d_iput)(struct dentry___57 *, struct inode___58 *);
	char * (*d_dname)(struct dentry___57 *, char *, int);
	struct vfsmount___9 * (*d_automount)(struct path___56 *);
	int (*d_manage)(const struct path___56 *, bool);
	struct dentry___57 * (*d_real)(struct dentry___57 *, const struct inode___58 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___56;

struct mem_dqinfo___56 {
	struct quota_format_type___56 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___56;

struct quota_info___56 {
	unsigned int flags;
	struct rw_semaphore___57 dqio_sem;
	struct inode___58 *files[3];
	struct mem_dqinfo___56 info[3];
	const struct quota_format_ops___56 *ops[3];
};

struct rcuwait___56 {
	struct task_struct___57 *task;
};

struct percpu_rw_semaphore___56 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___57 rw_sem;
	struct rcuwait___56 writer;
	int readers_block;
};

struct sb_writers___56 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___56 rw_sem[3];
};

struct shrink_control___25;

struct shrinker___25 {
	long unsigned int (*count_objects)(struct shrinker___25 *, struct shrink_control___25 *);
	long unsigned int (*scan_objects)(struct shrinker___25 *, struct shrink_control___25 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___56;

struct super_operations___56;

struct dquot_operations___56;

struct quotactl_ops___56;

struct super_block___57 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___56 *s_type;
	const struct super_operations___56 *s_op;
	const struct dquot_operations___56 *dq_op;
	const struct quotactl_ops___56 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___57 *s_root;
	struct rw_semaphore___57 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___57 *s_bdev;
	struct backing_dev_info___26 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___56 s_dquot;
	struct sb_writers___56 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___56 *s_d_op;
	int cleancache_poolid;
	struct shrinker___25 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___47 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___9 {
	struct dentry___57 *mnt_root;
	struct super_block___57 *mnt_sb;
	int mnt_flags;
};

struct path___56 {
	struct vfsmount___9 *mnt;
	struct dentry___57 *dentry;
};

struct shrink_control___25 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___25 *memcg;
};

typedef int (*dev_page_fault_t___56)(struct vm_area_struct___57 *, long unsigned int, const struct page___57 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___56)(struct page___57 *, void *);

struct dev_pagemap___56 {
	dev_page_fault_t___56 page_fault;
	dev_page_free_t___56 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___50 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct fown_struct___50 {
	rwlock_t lock;
	struct pid___50 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___57 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___56 f_path;
	struct inode___58 *f_inode;
	const struct file_operations___57 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___50 f_owner;
	const struct cred___56 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___56 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___56;

struct vm_operations_struct___56 {
	void (*open)(struct vm_area_struct___57 *);
	void (*close)(struct vm_area_struct___57 *);
	int (*split)(struct vm_area_struct___57 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___57 *);
	vm_fault_t (*fault)(struct vm_fault___56 *);
	vm_fault_t (*huge_fault)(struct vm_fault___56 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___56 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___57 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___56 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___56 *);
	int (*access)(struct vm_area_struct___57 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___57 *);
	int (*set_policy)(struct vm_area_struct___57 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___57 *, long unsigned int);
	struct page___57 * (*find_special_page)(struct vm_area_struct___57 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___56 {
	struct task_struct___57 *task;
	struct core_thread___56 *next;
};

struct core_state___56 {
	atomic_t nr_threads;
	struct core_thread___56 dumper;
	struct completion startup;
};

struct vm_fault___56 {
	struct vm_area_struct___57 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___57 *cow_page;
	struct mem_cgroup___25 *memcg;
	struct page___57 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___56 prealloc_pte;
};

struct kiocb___57 {
	struct file___57 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___57 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___57 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___57 *ia_file;
};

struct dquot___56 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___57 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___56 {
	int qf_fmt_id;
	const struct quota_format_ops___56 *qf_ops;
	struct module___51 *qf_owner;
	struct quota_format_type___56 *qf_next;
};

struct quota_format_ops___56 {
	int (*check_quota_file)(struct super_block___57 *, int);
	int (*read_file_info)(struct super_block___57 *, int);
	int (*write_file_info)(struct super_block___57 *, int);
	int (*free_file_info)(struct super_block___57 *, int);
	int (*read_dqblk)(struct dquot___56 *);
	int (*commit_dqblk)(struct dquot___56 *);
	int (*release_dqblk)(struct dquot___56 *);
	int (*get_next_id)(struct super_block___57 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___56 {
	int (*write_dquot)(struct dquot___56 *);
	struct dquot___56 * (*alloc_dquot)(struct super_block___57 *, int);
	void (*destroy_dquot)(struct dquot___56 *);
	int (*acquire_dquot)(struct dquot___56 *);
	int (*release_dquot)(struct dquot___56 *);
	int (*mark_dirty)(struct dquot___56 *);
	int (*write_info)(struct super_block___57 *, int);
	qsize_t * (*get_reserved_space)(struct inode___58 *);
	int (*get_projid)(struct inode___58 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___58 *, qsize_t *);
	int (*get_next_id)(struct super_block___57 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___56 {
	int (*quota_on)(struct super_block___57 *, int, int, const struct path___56 *);
	int (*quota_off)(struct super_block___57 *, int);
	int (*quota_enable)(struct super_block___57 *, unsigned int);
	int (*quota_disable)(struct super_block___57 *, unsigned int);
	int (*quota_sync)(struct super_block___57 *, int);
	int (*set_info)(struct super_block___57 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___57 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___57 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___57 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___57 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___57 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___53;

struct kobj_type___53;

struct kobject___54 {
	const char *name;
	struct list_head entry;
	struct kobject___54 *parent;
	struct kset___53 *kset;
	struct kobj_type___53 *ktype;
	struct kernfs_node___54 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___48 {
	struct kobject___54 kobj;
	struct module___51 *mod;
	struct kobject___54 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___48 {
	struct module___51 *mod;
	struct latch_tree_node node;
};

struct module_layout___48 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___48 mtn;
};

struct module_attribute___48;

struct kernel_param___48;

struct module___51 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___48 mkobj;
	struct module_attribute___48 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___54 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___48 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___48 core_layout;
	struct module_layout___48 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___31 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___25;

struct swap_info_struct___20;

struct address_space_operations___56 {
	int (*writepage)(struct page___57 *, struct writeback_control___25 *);
	int (*readpage)(struct file___57 *, struct page___57 *);
	int (*writepages)(struct address_space___56 *, struct writeback_control___25 *);
	int (*set_page_dirty)(struct page___57 *);
	int (*readpages)(struct file___57 *, struct address_space___56 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___57 *, struct address_space___56 *, loff_t, unsigned int, unsigned int, struct page___57 **, void **);
	int (*write_end)(struct file___57 *, struct address_space___56 *, loff_t, unsigned int, unsigned int, struct page___57 *, void *);
	sector_t (*bmap)(struct address_space___56 *, sector_t);
	void (*invalidatepage)(struct page___57 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___57 *, gfp_t);
	void (*freepage)(struct page___57 *);
	ssize_t (*direct_IO)(struct kiocb___57 *, struct iov_iter___27 *);
	int (*migratepage)(struct address_space___56 *, struct page___57 *, struct page___57 *, enum migrate_mode);
	bool (*isolate_page)(struct page___57 *, isolate_mode_t);
	void (*putback_page)(struct page___57 *);
	int (*launder_page)(struct page___57 *);
	int (*is_partially_uptodate)(struct page___57 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___57 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___56 *, struct page___57 *);
	int (*swap_activate)(struct swap_info_struct___20 *, struct file___57 *, sector_t *);
	void (*swap_deactivate)(struct file___57 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___25 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___26 *wb;
	struct inode___58 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___26;

struct iov_iter___27 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___26 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct swap_info_struct___20 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___57 *bdev;
	struct file___57 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct hd_struct___13;

struct gendisk___13;

struct block_device___57 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___58 *bd_inode;
	struct super_block___57 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___57 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___13 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___13 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___26 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_qos___7;

struct dev_pm_info___50 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___50 *, s32);
	struct dev_pm_qos___7 *qos;
};

struct device_type___50;

struct bus_type___50;

struct device_driver___50;

struct dev_pm_domain___50;

struct class___50;

struct attribute_group___51;

struct device___50 {
	struct device___50 *parent;
	struct device_private *p;
	struct kobject___54 kobj;
	const char *init_name;
	const struct device_type___50 *type;
	struct mutex mutex;
	struct bus_type___50 *bus;
	struct device_driver___50 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___50 power;
	struct dev_pm_domain___50 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___50 *class;
	const struct attribute_group___51 **groups;
	void (*release)(struct device___50 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___13 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___50 __dev;
	struct kobject___54 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device_operations___13;

struct disk_part_tbl___13;

struct gendisk___13 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___13 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___13 *part_tbl;
	struct hd_struct___13 part0;
	const struct block_device_operations___13 *fops;
	struct request_queue___3 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___57 lookup_sem;
	struct kobject___54 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___54 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___56 {
	struct dentry___57 * (*lookup)(struct inode___58 *, struct dentry___57 *, unsigned int);
	const char * (*get_link)(struct dentry___57 *, struct inode___58 *, struct delayed_call *);
	int (*permission)(struct inode___58 *, int);
	struct posix_acl * (*get_acl)(struct inode___58 *, int);
	int (*readlink)(struct dentry___57 *, char *, int);
	int (*create)(struct inode___58 *, struct dentry___57 *, umode_t, bool);
	int (*link)(struct dentry___57 *, struct inode___58 *, struct dentry___57 *);
	int (*unlink)(struct inode___58 *, struct dentry___57 *);
	int (*symlink)(struct inode___58 *, struct dentry___57 *, const char *);
	int (*mkdir)(struct inode___58 *, struct dentry___57 *, umode_t);
	int (*rmdir)(struct inode___58 *, struct dentry___57 *);
	int (*mknod)(struct inode___58 *, struct dentry___57 *, umode_t, dev_t);
	int (*rename)(struct inode___58 *, struct dentry___57 *, struct inode___58 *, struct dentry___57 *, unsigned int);
	int (*setattr)(struct dentry___57 *, struct iattr___57 *);
	int (*getattr)(const struct path___56 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___57 *, char *, size_t);
	int (*fiemap)(struct inode___58 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___58 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___58 *, struct dentry___57 *, struct file___57 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___58 *, struct dentry___57 *, umode_t);
	int (*set_acl)(struct inode___58 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___56 {
	void (*fl_copy_lock)(struct file_lock___57 *, struct file_lock___57 *);
	void (*fl_release_private)(struct file_lock___57 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___56;

struct file_lock___57 {
	struct file_lock___57 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___57 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___56 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___56 *fl_ops;
	const struct lock_manager_operations___56 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___56 {
	int (*lm_compare_owner)(struct file_lock___57 *, struct file_lock___57 *);
	long unsigned int (*lm_owner_key)(struct file_lock___57 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___57 *);
	int (*lm_grant)(struct file_lock___57 *, int);
	bool (*lm_break)(struct file_lock___57 *);
	int (*lm_change)(struct file_lock___57 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___57 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___56 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___56 *fa_next;
	struct file___57 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___56 {
	const char *name;
	int fs_flags;
	struct dentry___57 * (*mount)(struct file_system_type___56 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___57 *);
	struct module___51 *owner;
	struct file_system_type___56 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___56 {
	struct inode___58 * (*alloc_inode)(struct super_block___57 *);
	void (*destroy_inode)(struct inode___58 *);
	void (*dirty_inode)(struct inode___58 *, int);
	int (*write_inode)(struct inode___58 *, struct writeback_control___25 *);
	int (*drop_inode)(struct inode___58 *);
	void (*evict_inode)(struct inode___58 *);
	void (*put_super)(struct super_block___57 *);
	int (*sync_fs)(struct super_block___57 *, int);
	int (*freeze_super)(struct super_block___57 *);
	int (*freeze_fs)(struct super_block___57 *);
	int (*thaw_super)(struct super_block___57 *);
	int (*unfreeze_fs)(struct super_block___57 *);
	int (*statfs)(struct dentry___57 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___57 *, int *, char *);
	void (*umount_begin)(struct super_block___57 *);
	int (*show_options)(struct seq_file___54 *, struct dentry___57 *);
	int (*show_devname)(struct seq_file___54 *, struct dentry___57 *);
	int (*show_path)(struct seq_file___54 *, struct dentry___57 *);
	int (*show_stats)(struct seq_file___54 *, struct dentry___57 *);
	ssize_t (*quota_read)(struct super_block___57 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___57 *, int, const char *, size_t, loff_t);
	struct dquot___56 ** (*get_dquots)(struct inode___58 *);
	int (*bdev_try_to_free_page)(struct super_block___57 *, struct page___57 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___57 *, struct shrink_control___25 *);
	long int (*free_cached_objects)(struct super_block___57 *, struct shrink_control___25 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___36)(struct file___57 *, wait_queue_head_t *, struct poll_table_struct___37 *);

struct poll_table_struct___37 {
	poll_queue_proc___36 _qproc;
	__poll_t _key;
};

struct seq_operations___51;

struct seq_file___54 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___51 *op;
	int poll_event;
	const struct file___57 *file;
	void *private;
};

typedef void bio_end_io_t___26(struct bio___26 *);

struct bio_vec___26 {
	struct page___57 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___26;

struct bio_set___26;

struct bio___26 {
	struct bio___26 *bi_next;
	struct gendisk___13 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___26 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___26 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___26 *bi_io_vec;
	struct bio_set___26 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___26 bi_inline_vecs[0];
};

typedef int (*key_restrict_link_func_t___56)(struct key___57 *, const struct key_type *, const union key_payload *, struct key___57 *);

struct key_restriction___57;

struct key___57 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___57 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___57 *restrict_link;
};

struct key_restriction___57 {
	key_restrict_link_func_t___56 check;
	struct key___57 *key;
	struct key_type *keytype;
};

struct seq_operations___51 {
	void * (*start)(struct seq_file___54 *, loff_t *);
	void (*stop)(struct seq_file___54 *, void *);
	void * (*next)(struct seq_file___54 *, void *, loff_t *);
	int (*show)(struct seq_file___54 *, void *);
};

struct kernfs_root___54;

struct kernfs_elem_dir___54 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___54 *root;
};

struct kernfs_syscall_ops___54;

struct kernfs_root___54 {
	struct kernfs_node___54 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___54 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___54 {
	struct kernfs_node___54 *target_kn;
};

struct kernfs_ops___54;

struct kernfs_elem_attr___54 {
	const struct kernfs_ops___54 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___54 *notify_next;
};

struct kernfs_node___54 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___54 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___54 dir;
		struct kernfs_elem_symlink___54 symlink;
		struct kernfs_elem_attr___54 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___54;

struct kernfs_ops___54 {
	int (*open)(struct kernfs_open_file___54 *);
	void (*release)(struct kernfs_open_file___54 *);
	int (*seq_show)(struct seq_file___54 *, void *);
	void * (*seq_start)(struct seq_file___54 *, loff_t *);
	void * (*seq_next)(struct seq_file___54 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___54 *, void *);
	ssize_t (*read)(struct kernfs_open_file___54 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___54 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___54 *, struct vm_area_struct___57 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___54 *, struct poll_table_struct___37 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___54 {
	int (*remount_fs)(struct kernfs_root___54 *, int *, char *);
	int (*show_options)(struct seq_file___54 *, struct kernfs_root___54 *);
	int (*mkdir)(struct kernfs_node___54 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___54 *);
	int (*rename)(struct kernfs_node___54 *, struct kernfs_node___54 *, const char *);
	int (*show_path)(struct seq_file___54 *, struct kernfs_node___54 *, struct kernfs_root___54 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___54 {
	struct kernfs_node___54 *kn;
	struct file___57 *file;
	struct seq_file___54 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___56 *vm_ops;
};

struct uts_namespace___16 {
	struct kref kref;
	struct new_utsname name;
	struct user_namespace___47 *user_ns;
	struct ucounts___47 *ucounts;
	struct ns_common ns;
};

struct cgroup_namespace___45 {
	refcount_t count;
	struct ns_common ns;
	struct user_namespace___47 *user_ns;
	struct ucounts___47 *ucounts;
	struct css_set___45 *root_cset;
};

struct ucounts___47 {
	struct hlist_node node;
	struct user_namespace___47 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___45;

struct bpf_map_ops___45 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___45 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___45 *, struct file___57 *);
	void (*map_free)(struct bpf_map___45 *);
	int (*map_get_next_key)(struct bpf_map___45 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___45 *);
	void * (*map_lookup_elem)(struct bpf_map___45 *, void *);
	int (*map_update_elem)(struct bpf_map___45 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___45 *, void *);
	int (*map_push_elem)(struct bpf_map___45 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___45 *, void *);
	int (*map_peek_elem)(struct bpf_map___45 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___45 *, struct file___57 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___45 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___45 *, void *, struct seq_file___54 *);
	int (*map_check_btf)(const struct bpf_map___45 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___45 {
	const struct bpf_map_ops___45 *ops;
	struct bpf_map___45 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___56 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___45;

typedef void (*kthread_work_func_t___45)(struct kthread_work___45 *);

struct kthread_worker___45;

struct kthread_work___45 {
	struct list_head node;
	kthread_work_func_t___45 func;
	struct kthread_worker___45 *worker;
	int canceling;
};

struct kthread_worker___45 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___57 *task;
	struct kthread_work___45 *current_work;
};

struct kthread_delayed_work___45 {
	struct kthread_work___45 work;
	struct timer_list timer;
};

struct psi_group___45 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___45 *poll_kworker;
	struct kthread_delayed_work___45 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___45;

struct cgroup_rstat_cpu___45;

struct cgroup___45 {
	struct cgroup_subsys_state___45 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___54 *kn;
	struct cgroup_file___45 procs_file;
	struct cgroup_file___45 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___45 *subsys[13];
	struct cgroup_root___45 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___45 *dom_cgrp;
	struct cgroup_rstat_cpu___45 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf bpf;
	atomic_t congestion_count;
	struct cgroup___45 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___45 psi;
	int ancestor_ids[0];
};

struct cftype___45;

struct cgroup_subsys___45 {
	struct cgroup_subsys_state___45 * (*css_alloc)(struct cgroup_subsys_state___45 *);
	int (*css_online)(struct cgroup_subsys_state___45 *);
	void (*css_offline)(struct cgroup_subsys_state___45 *);
	void (*css_released)(struct cgroup_subsys_state___45 *);
	void (*css_free)(struct cgroup_subsys_state___45 *);
	void (*css_reset)(struct cgroup_subsys_state___45 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___45 *, int);
	int (*css_extra_stat_show)(struct seq_file___54 *, struct cgroup_subsys_state___45 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___57 *);
	void (*cancel_fork)(struct task_struct___57 *);
	void (*fork)(struct task_struct___57 *);
	void (*exit)(struct task_struct___57 *);
	void (*free)(struct task_struct___57 *);
	void (*bind)(struct cgroup_subsys_state___45 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___45 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___45 *dfl_cftypes;
	struct cftype___45 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___45 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___45 *updated_children;
	struct cgroup___45 *updated_next;
};

struct cgroup_root___45 {
	struct kernfs_root___54 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___45 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___45 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___45 *ss;
	struct list_head node;
	struct kernfs_ops___54 *kf_ops;
	int (*open)(struct kernfs_open_file___54 *);
	void (*release)(struct kernfs_open_file___54 *);
	u64 (*read_u64)(struct cgroup_subsys_state___45 *, struct cftype___45 *);
	s64 (*read_s64)(struct cgroup_subsys_state___45 *, struct cftype___45 *);
	int (*seq_show)(struct seq_file___54 *, void *);
	void * (*seq_start)(struct seq_file___54 *, loff_t *);
	void * (*seq_next)(struct seq_file___54 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___54 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___45 *, struct cftype___45 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___45 *, struct cftype___45 *, s64);
	ssize_t (*write)(struct kernfs_open_file___54 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___54 *, struct poll_table_struct___37 *);
};

struct kobj_attribute___54 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___54 *, struct kobj_attribute___54 *, char *);
	ssize_t (*store)(struct kobject___54 *, struct kobj_attribute___54 *, const char *, size_t);
};

typedef void compound_page_dtor___56(struct page___57 *);

struct bdi_writeback_congested___26 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___26 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___26 {
	struct bio___26 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___26 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___26 bip_inline_vecs[0];
};

struct bio_set___26 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___26 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___25 {
	struct mem_cgroup___25 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___25 {
	struct lruvec___56 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___25 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___25 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct bin_attribute___51;

struct attribute_group___51 {
	const char *name;
	umode_t (*is_visible)(struct kobject___54 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___54 *, struct bin_attribute___51 *, int);
	struct attribute **attrs;
	struct bin_attribute___51 **bin_attrs;
};

struct bin_attribute___51 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___57 *, struct kobject___54 *, struct bin_attribute___51 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___57 *, struct kobject___54 *, struct bin_attribute___51 *, char *, loff_t, size_t);
	int (*mmap)(struct file___57 *, struct kobject___54 *, struct bin_attribute___51 *, struct vm_area_struct___57 *);
};

struct sysfs_ops___53 {
	ssize_t (*show)(struct kobject___54 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___54 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___53;

struct kset___53 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___54 kobj;
	const struct kset_uevent_ops___53 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___53 {
	void (*release)(struct kobject___54 *);
	const struct sysfs_ops___53 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___54 *);
	const void * (*namespace)(struct kobject___54 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___53 {
	int (* const filter)(struct kset___53 *, struct kobject___54 *);
	const char * (* const name)(struct kset___53 *, struct kobject___54 *);
	int (* const uevent)(struct kset___53 *, struct kobject___54 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___50 {
	int (*prepare)(struct device___50 *);
	void (*complete)(struct device___50 *);
	int (*suspend)(struct device___50 *);
	int (*resume)(struct device___50 *);
	int (*freeze)(struct device___50 *);
	int (*thaw)(struct device___50 *);
	int (*poweroff)(struct device___50 *);
	int (*restore)(struct device___50 *);
	int (*suspend_late)(struct device___50 *);
	int (*resume_early)(struct device___50 *);
	int (*freeze_late)(struct device___50 *);
	int (*thaw_early)(struct device___50 *);
	int (*poweroff_late)(struct device___50 *);
	int (*restore_early)(struct device___50 *);
	int (*suspend_noirq)(struct device___50 *);
	int (*resume_noirq)(struct device___50 *);
	int (*freeze_noirq)(struct device___50 *);
	int (*thaw_noirq)(struct device___50 *);
	int (*poweroff_noirq)(struct device___50 *);
	int (*restore_noirq)(struct device___50 *);
	int (*runtime_suspend)(struct device___50 *);
	int (*runtime_resume)(struct device___50 *);
	int (*runtime_idle)(struct device___50 *);
};

struct pm_qos_constraints___7 {
	struct plist_head list;
	s32 target_value;
	s32 default_value;
	s32 no_constraint_value;
	enum pm_qos_type type;
	struct blocking_notifier_head___56 *notifiers;
};

struct dev_pm_qos_request___7;

struct dev_pm_qos___7 {
	struct pm_qos_constraints___7 resume_latency;
	struct pm_qos_constraints___7 latency_tolerance;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___7 *resume_latency_req;
	struct dev_pm_qos_request___7 *latency_tolerance_req;
	struct dev_pm_qos_request___7 *flags_req;
};

struct dev_pm_domain___50 {
	struct dev_pm_ops___50 ops;
	void (*detach)(struct device___50 *, bool);
	int (*activate)(struct device___50 *);
	void (*sync)(struct device___50 *);
	void (*dismiss)(struct device___50 *);
};

struct bus_type___50 {
	const char *name;
	const char *dev_name;
	struct device___50 *dev_root;
	const struct attribute_group___51 **bus_groups;
	const struct attribute_group___51 **dev_groups;
	const struct attribute_group___51 **drv_groups;
	int (*match)(struct device___50 *, struct device_driver___50 *);
	int (*uevent)(struct device___50 *, struct kobj_uevent_env *);
	int (*probe)(struct device___50 *);
	int (*remove)(struct device___50 *);
	void (*shutdown)(struct device___50 *);
	int (*online)(struct device___50 *);
	int (*offline)(struct device___50 *);
	int (*suspend)(struct device___50 *, pm_message_t);
	int (*resume)(struct device___50 *);
	int (*num_vf)(struct device___50 *);
	int (*dma_configure)(struct device___50 *);
	const struct dev_pm_ops___50 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___50 {
	const char *name;
	struct bus_type___50 *bus;
	struct module___51 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___50 *);
	int (*remove)(struct device___50 *);
	void (*shutdown)(struct device___50 *);
	int (*suspend)(struct device___50 *, pm_message_t);
	int (*resume)(struct device___50 *);
	const struct attribute_group___51 **groups;
	const struct dev_pm_ops___50 *pm;
	void (*coredump)(struct device___50 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___50 {
	const char *name;
	const struct attribute_group___51 **groups;
	int (*uevent)(struct device___50 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___50 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___50 *);
	const struct dev_pm_ops___50 *pm;
};

struct class___50 {
	const char *name;
	struct module___51 *owner;
	const struct attribute_group___51 **class_groups;
	const struct attribute_group___51 **dev_groups;
	struct kobject___54 *dev_kobj;
	int (*dev_uevent)(struct device___50 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___50 *, umode_t *);
	void (*class_release)(struct class___50 *);
	void (*dev_release)(struct device___50 *);
	int (*shutdown_pre)(struct device___50 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___50 *);
	const struct dev_pm_ops___50 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___47 {
	struct device___50 dev;
};

struct platform_hibernation_ops {
	int (*begin)();
	void (*end)();
	int (*pre_snapshot)();
	void (*finish)();
	int (*prepare)();
	int (*enter)();
	void (*leave)();
	int (*pre_restore)();
	void (*restore_cleanup)();
	void (*recover)();
};

struct kernel_param_ops___48 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___48 *);
	int (*get)(char *, const struct kernel_param___48 *);
	void (*free)(void *);
};

struct kparam_array___48;

struct kernel_param___48 {
	const char *name;
	struct module___51 *mod;
	const struct kernel_param_ops___48 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___48 *arr;
	};
};

struct kparam_array___48 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___48 *ops;
	void *elem;
};

struct module_attribute___48 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___48 *, struct module_kobject___48 *, char *);
	ssize_t (*store)(struct module_attribute___48 *, struct module_kobject___48 *, const char *, size_t);
	void (*setup)(struct module___51 *, const char *);
	int (*test)(struct module___51 *);
	void (*free)(struct module___51 *);
};

struct trace_event_class___31;

struct trace_event_call___31 {
	struct list_head list;
	struct trace_event_class___31 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array *prog_array;
	int (*perf_perm)(struct trace_event_call___31 *, struct perf_event___36 *);
};

struct perf_cpu_context___36;

struct pmu___36 {
	struct list_head entry;
	struct module___51 *module;
	struct device___50 *dev;
	const struct attribute_group___51 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___36 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___36 *);
	void (*pmu_disable)(struct pmu___36 *);
	int (*event_init)(struct perf_event___36 *);
	void (*event_mapped)(struct perf_event___36 *, struct mm_struct___56 *);
	void (*event_unmapped)(struct perf_event___36 *, struct mm_struct___56 *);
	int (*add)(struct perf_event___36 *, int);
	void (*del)(struct perf_event___36 *, int);
	void (*start)(struct perf_event___36 *, int);
	void (*stop)(struct perf_event___36 *, int);
	void (*read)(struct perf_event___36 *);
	void (*start_txn)(struct pmu___36 *, unsigned int);
	int (*commit_txn)(struct pmu___36 *);
	void (*cancel_txn)(struct pmu___36 *);
	int (*event_idx)(struct perf_event___36 *);
	void (*sched_task)(struct perf_event_context___36 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___36 *);
	int (*filter_match)(struct perf_event___36 *);
	int (*check_period)(struct perf_event___36 *, u64);
};

struct perf_cpu_context___36 {
	struct perf_event_context___36 ctx;
	struct perf_event_context___36 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___36 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___36 {
	struct cgroup_subsys_state___45 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___31 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___31 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___31 *);
	struct list_head * (*get_fields)(struct trace_event_call___31 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___31 *);
};

struct consw___6 {
	struct module___51 *owner;
	const char * (*con_startup)();
	void (*con_init)(struct vc_data *, int);
	void (*con_deinit)(struct vc_data *);
	void (*con_clear)(struct vc_data *, int, int, int, int);
	void (*con_putc)(struct vc_data *, int, int, int);
	void (*con_putcs)(struct vc_data *, const short unsigned int *, int, int, int);
	void (*con_cursor)(struct vc_data *, int);
	bool (*con_scroll)(struct vc_data *, unsigned int, unsigned int, enum con_scroll, unsigned int);
	int (*con_switch)(struct vc_data *);
	int (*con_blank)(struct vc_data *, int, int);
	int (*con_font_set)(struct vc_data *, struct console_font *, unsigned int);
	int (*con_font_get)(struct vc_data *, struct console_font *);
	int (*con_font_default)(struct vc_data *, struct console_font *, char *);
	int (*con_font_copy)(struct vc_data *, int);
	int (*con_resize)(struct vc_data *, unsigned int, unsigned int, unsigned int);
	void (*con_set_palette)(struct vc_data *, const unsigned char *);
	void (*con_scrolldelta)(struct vc_data *, int);
	int (*con_set_origin)(struct vc_data *);
	void (*con_save_screen)(struct vc_data *);
	u8 (*con_build_attr)(struct vc_data *, u8, u8, u8, u8, u8, u8);
	void (*con_invert_region)(struct vc_data *, u16 *, int);
	u16 * (*con_screen_pos)(struct vc_data *, int);
	long unsigned int (*con_getxy)(struct vc_data *, long unsigned int, int *, int *);
	void (*con_flush_scrollback)(struct vc_data *);
	int (*con_debug_enter)(struct vc_data *);
	int (*con_debug_leave)(struct vc_data *);
};

struct disk_part_tbl___13 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___13 *last_lookup;
	struct hd_struct___13 *part[0];
};

struct dev_pm_qos_request___7 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___50 *dev;
};

enum {
	HIBERNATION_INVALID = 0,
	HIBERNATION_PLATFORM = 1,
	HIBERNATION_SHUTDOWN = 2,
	HIBERNATION_REBOOT = 3,
	HIBERNATION_SUSPEND = 4,
	HIBERNATION_TEST_RESUME = 5,
	__HIBERNATION_AFTER_LAST = 6,
};

struct consw___7 {
	struct module___3 *owner;
	const char * (*con_startup)();
	void (*con_init)(struct vc_data *, int);
	void (*con_deinit)(struct vc_data *);
	void (*con_clear)(struct vc_data *, int, int, int, int);
	void (*con_putc)(struct vc_data *, int, int, int);
	void (*con_putcs)(struct vc_data *, const short unsigned int *, int, int, int);
	void (*con_cursor)(struct vc_data *, int);
	bool (*con_scroll)(struct vc_data *, unsigned int, unsigned int, enum con_scroll, unsigned int);
	int (*con_switch)(struct vc_data *);
	int (*con_blank)(struct vc_data *, int, int);
	int (*con_font_set)(struct vc_data *, struct console_font *, unsigned int);
	int (*con_font_get)(struct vc_data *, struct console_font *);
	int (*con_font_default)(struct vc_data *, struct console_font *, char *);
	int (*con_font_copy)(struct vc_data *, int);
	int (*con_resize)(struct vc_data *, unsigned int, unsigned int, unsigned int);
	void (*con_set_palette)(struct vc_data *, const unsigned char *);
	void (*con_scrolldelta)(struct vc_data *, int);
	int (*con_set_origin)(struct vc_data *);
	void (*con_save_screen)(struct vc_data *);
	u8 (*con_build_attr)(struct vc_data *, u8, u8, u8, u8, u8, u8);
	void (*con_invert_region)(struct vc_data *, u16 *, int);
	u16 * (*con_screen_pos)(struct vc_data *, int);
	long unsigned int (*con_getxy)(struct vc_data *, long unsigned int, int *, int *);
	void (*con_flush_scrollback)(struct vc_data *);
	int (*con_debug_enter)(struct vc_data *);
	int (*con_debug_leave)(struct vc_data *);
};

struct swsusp_info {
	struct new_utsname uts;
	u32 version_code;
	long unsigned int num_physpages;
	int cpus;
	long unsigned int image_pages;
	long unsigned int pages;
	long unsigned int size;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct snapshot_handle {
	unsigned int cur;
	void *buffer;
	int sync_read;
};

struct linked_page {
	struct linked_page *next;
	char data[65528];
};

struct chain_allocator {
	struct linked_page *chain;
	unsigned int used_space;
	gfp_t gfp_mask;
	int safe_needed;
};

struct rtree_node {
	struct list_head list;
	long unsigned int *data;
};

struct mem_zone_bm_rtree {
	struct list_head list;
	struct list_head nodes;
	struct list_head leaves;
	long unsigned int start_pfn;
	long unsigned int end_pfn;
	struct rtree_node *rtree;
	int levels;
	unsigned int blocks;
};

struct bm_position {
	struct mem_zone_bm_rtree *zone;
	struct rtree_node *node;
	long unsigned int node_pfn;
	int node_bit;
};

struct memory_bitmap {
	struct list_head zones;
	struct linked_page *p_list;
	struct bm_position cur;
};

struct mem_extent {
	struct list_head hook;
	long unsigned int start;
	long unsigned int end;
};

struct nosave_region {
	struct list_head list;
	long unsigned int start_pfn;
	long unsigned int end_pfn;
};

struct module___52;

struct file___58;

struct kiocb___58;

struct vm_area_struct___58;

struct inode___59;

struct file_lock___58;

struct page___58;

struct seq_file___55;

struct file_operations___58 {
	struct module___52 *owner;
	loff_t (*llseek)(struct file___58 *, loff_t, int);
	ssize_t (*read)(struct file___58 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___58 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___58 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___58 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___58 *, bool);
	int (*iterate)(struct file___58 *, struct dir_context *);
	int (*iterate_shared)(struct file___58 *, struct dir_context *);
	__poll_t (*poll)(struct file___58 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___58 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___58 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___58 *, struct vm_area_struct___58 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___59 *, struct file___58 *);
	int (*flush)(struct file___58 *, fl_owner_t);
	int (*release)(struct inode___59 *, struct file___58 *);
	int (*fsync)(struct file___58 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___58 *, int);
	int (*lock)(struct file___58 *, int, struct file_lock___58 *);
	ssize_t (*sendpage)(struct file___58 *, struct page___58 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___58 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___58 *, int, struct file_lock___58 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___58 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___58 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___58 *, long int, struct file_lock___58 **, void **);
	long int (*fallocate)(struct file___58 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___55 *, struct file___58 *);
	ssize_t (*copy_file_range)(struct file___58 *, loff_t, struct file___58 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___58 *, loff_t, struct file___58 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___58 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___57 {
	u64 seqnum;
	struct vm_area_struct___58 *vmas[4];
};

struct page_frag___57 {
	struct page___58 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___57;

struct mem_cgroup___26;

struct cred___57;

struct nsproxy___56;

struct bio_list___27;

struct backing_dev_info___27;

struct io_context___13;

struct css_set___46;

struct request_queue___14;

struct vm_struct___42;

struct task_struct___58 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___58 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___57 *mm;
	struct mm_struct___57 *active_mm;
	struct vmacache___57 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___58 *real_parent;
	struct task_struct___58 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___58 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___26 *active_memcg;
	long int rh_reserved2;
	struct pid___21 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___21 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___21 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___57 *ptracer_cred;
	const struct cred___57 *real_cred;
	const struct cred___57 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___56 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___58 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___27 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___27 *backing_dev_info;
	struct io_context___13 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___46 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___57 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___26 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___14 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___58 *oom_reaper_list;
	struct vm_struct___42 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___11 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rw_semaphore___58 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___58 *owner;
};

struct key___58;

struct ucounts___48;

struct user_namespace___48 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___48 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common ns;
	long unsigned int flags;
	struct key___58 *persistent_keyring_register;
	struct rw_semaphore___58 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___48 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___58 *pgtable_t___57;

struct address_space___57;

struct dev_pagemap___57;

struct page___58 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___57 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___58 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___57 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___57 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___57 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___26 *mem_cgroup;
};

struct pglist_data___57;

struct lruvec___57 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___57 *pgdat;
};

struct zone___57 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___57 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___57 {
	struct zone___57 *zone;
	int zone_idx;
};

struct zonelist___57 {
	struct zoneref___57 _zonerefs[25];
};

struct pglist_data___57 {
	struct zone___57 node_zones[3];
	struct zonelist___57 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___58 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___58 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___57 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___58 {
	void *stack;
	struct task_struct___58 *task;
	long int status;
};

struct blocking_notifier_head___57 {
	struct rw_semaphore___58 rwsem;
	struct notifier_block *head;
};

struct dentry___58;

struct path___57 {
	struct vfsmount *mnt;
	struct dentry___58 *dentry;
};

struct file___58 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___57 f_path;
	struct inode___59 *f_inode;
	const struct file_operations___58 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___50 f_owner;
	const struct cred___57 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___57 *f_mapping;
	errseq_t f_wb_err;
};

struct user_struct___57;

struct cred___57 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___58 *session_keyring;
	struct key___58 *process_keyring;
	struct key___58 *thread_keyring;
	struct key___58 *request_key_auth;
	void *security;
	struct user_struct___57 *user;
	struct user_namespace___48 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___55;

struct kernfs_elem_dir___55 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___55 *root;
};

struct kernfs_node___55;

struct kernfs_syscall_ops___55;

struct kernfs_root___55 {
	struct kernfs_node___55 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___55 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___55 {
	struct kernfs_node___55 *target_kn;
};

struct kernfs_ops___55;

struct kernfs_elem_attr___55 {
	const struct kernfs_ops___55 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___55 *notify_next;
};

struct kernfs_node___55 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___55 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___55 dir;
		struct kernfs_elem_symlink___55 symlink;
		struct kernfs_elem_attr___55 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___55;

struct kernfs_ops___55 {
	int (*open)(struct kernfs_open_file___55 *);
	void (*release)(struct kernfs_open_file___55 *);
	int (*seq_show)(struct seq_file___55 *, void *);
	void * (*seq_start)(struct seq_file___55 *, loff_t *);
	void * (*seq_next)(struct seq_file___55 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___55 *, void *);
	ssize_t (*read)(struct kernfs_open_file___55 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___55 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___55 *, struct vm_area_struct___58 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___55 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___55 {
	int (*remount_fs)(struct kernfs_root___55 *, int *, char *);
	int (*show_options)(struct seq_file___55 *, struct kernfs_root___55 *);
	int (*mkdir)(struct kernfs_node___55 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___55 *);
	int (*rename)(struct kernfs_node___55 *, struct kernfs_node___55 *, const char *);
	int (*show_path)(struct seq_file___55 *, struct kernfs_node___55 *, struct kernfs_root___55 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___52;

struct seq_file___55 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___52 *op;
	int poll_event;
	const struct file___58 *file;
	void *private;
};

struct vm_operations_struct___57;

struct kernfs_open_file___55 {
	struct kernfs_node___55 *kn;
	struct file___58 *file;
	struct seq_file___55 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___57 *vm_ops;
};

struct vm_fault___57;

struct vm_operations_struct___57 {
	void (*open)(struct vm_area_struct___58 *);
	void (*close)(struct vm_area_struct___58 *);
	int (*split)(struct vm_area_struct___58 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___58 *);
	vm_fault_t (*fault)(struct vm_fault___57 *);
	vm_fault_t (*huge_fault)(struct vm_fault___57 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___57 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___58 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___57 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___57 *);
	int (*access)(struct vm_area_struct___58 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___58 *);
	int (*set_policy)(struct vm_area_struct___58 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___58 *, long unsigned int);
	struct page___58 * (*find_special_page)(struct vm_area_struct___58 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_area_struct___58 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___58 *vm_next;
	struct vm_area_struct___58 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___57 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___57 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___58 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___55;

struct bin_attribute___52;

struct attribute_group___52 {
	const char *name;
	umode_t (*is_visible)(struct kobject___55 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___55 *, struct bin_attribute___52 *, int);
	struct attribute **attrs;
	struct bin_attribute___52 **bin_attrs;
};

struct kset___54;

struct kobj_type___54;

struct kobject___55 {
	const char *name;
	struct list_head entry;
	struct kobject___55 *parent;
	struct kset___54 *kset;
	struct kobj_type___54 *ktype;
	struct kernfs_node___55 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___52 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___58 *, struct kobject___55 *, struct bin_attribute___52 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___58 *, struct kobject___55 *, struct bin_attribute___52 *, char *, loff_t, size_t);
	int (*mmap)(struct file___58 *, struct kobject___55 *, struct bin_attribute___52 *, struct vm_area_struct___58 *);
};

struct sysfs_ops___54 {
	ssize_t (*show)(struct kobject___55 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___55 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___54;

struct kset___54 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___55 kobj;
	const struct kset_uevent_ops___54 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___54 {
	void (*release)(struct kobject___55 *);
	const struct sysfs_ops___54 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___55 *);
	const void * (*namespace)(struct kobject___55 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___54 {
	int (* const filter)(struct kset___54 *, struct kobject___55 *);
	const char * (* const name)(struct kset___54 *, struct kobject___55 *);
	int (* const uevent)(struct kset___54 *, struct kobject___55 *, struct kobj_uevent_env *);
};

struct kobj_attribute___55 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___55 *, struct kobj_attribute___55 *, char *);
	ssize_t (*store)(struct kobject___55 *, struct kobj_attribute___55 *, const char *, size_t);
};

struct kernel_param___49;

struct kernel_param_ops___49 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___49 *);
	int (*get)(char *, const struct kernel_param___49 *);
	void (*free)(void *);
};

struct kparam_array___49;

struct kernel_param___49 {
	const char *name;
	struct module___52 *mod;
	const struct kernel_param_ops___49 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___49 *arr;
	};
};

struct kparam_array___49 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___49 *ops;
	void *elem;
};

struct module_kobject___49 {
	struct kobject___55 kobj;
	struct module___52 *mod;
	struct kobject___55 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___49 {
	struct module___52 *mod;
	struct latch_tree_node node;
};

struct module_layout___49 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___49 mtn;
};

struct module_attribute___49;

struct module___52 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___49 mkobj;
	struct module_attribute___49 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___55 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___49 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___49 core_layout;
	struct module_layout___49 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___49 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___49 *, struct module_kobject___49 *, char *);
	ssize_t (*store)(struct module_attribute___49 *, struct module_kobject___49 *, const char *, size_t);
	void (*setup)(struct module___52 *, const char *);
	int (*test)(struct module___52 *);
	void (*free)(struct module___52 *);
};

struct cgroup___46;

struct cgroup_subsys___46;

struct cgroup_subsys_state___46 {
	struct cgroup___46 *cgroup;
	struct cgroup_subsys___46 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___46 *parent;
};

struct mem_cgroup_id___12 {
	int id;
	union {
		refcount_t ref;
		struct {
			atomic_t ref;
		} __UNIQUE_ID_rh_kabi_hide42;
		union {		};
	};
};

struct cgroup_file___46 {
	struct kernfs_node___55 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___26;

struct mem_cgroup___26 {
	struct cgroup_subsys_state___46 css;
	struct mem_cgroup_id___12 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___46 events_file;
	struct cgroup_file___46 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___58 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___26 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bio_vec___27 {
	struct page___58 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio___27;

typedef void bio_end_io_t___27(struct bio___27 *);

struct gendisk___14;

struct bio_integrity_payload___27;

struct bio_set___27;

struct bio___27 {
	struct bio___27 *bi_next;
	struct gendisk___14 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___27 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___27 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___27 *bi_io_vec;
	struct bio_set___27 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___27 bi_inline_vecs[0];
};

struct bio_integrity_payload___27 {
	struct bio___27 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___27 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___27 bip_inline_vecs[0];
};

struct device___51;

struct dev_pm_info___51 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___51 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___51;

struct bus_type___51;

struct device_driver___51;

struct dev_pm_domain___51;

struct fwnode_handle___38;

struct class___51;

struct device___51 {
	struct device___51 *parent;
	struct device_private *p;
	struct kobject___55 kobj;
	const char *init_name;
	const struct device_type___51 *type;
	struct mutex mutex;
	struct bus_type___51 *bus;
	struct device_driver___51 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___51 power;
	struct dev_pm_domain___51 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___38 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___51 *class;
	const struct attribute_group___52 **groups;
	void (*release)(struct device___51 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___14 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___51 __dev;
	struct kobject___55 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___14;

struct block_device_operations___14;

struct gendisk___14 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___14 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___14 *part_tbl;
	struct hd_struct___14 part0;
	const struct block_device_operations___14 *fops;
	struct request_queue___14 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___58 lookup_sem;
	struct kobject___55 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___55 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio_list___27 {
	struct bio___27 *head;
	struct bio___27 *tail;
};

struct bio_set___27 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___27 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

enum req_opf {
	REQ_OP_READ = 0,
	REQ_OP_WRITE = 1,
	REQ_OP_FLUSH = 2,
	REQ_OP_DISCARD = 3,
	REQ_OP_SECURE_ERASE = 5,
	REQ_OP_ZONE_RESET = 6,
	REQ_OP_WRITE_SAME = 7,
	REQ_OP_WRITE_ZEROES = 9,
	REQ_OP_SCSI_IN = 32,
	REQ_OP_SCSI_OUT = 33,
	REQ_OP_DRV_IN = 34,
	REQ_OP_DRV_OUT = 35,
	REQ_OP_LAST = 36,
};

enum req_flag_bits {
	__REQ_FAILFAST_DEV = 8,
	__REQ_FAILFAST_TRANSPORT = 9,
	__REQ_FAILFAST_DRIVER = 10,
	__REQ_SYNC = 11,
	__REQ_META = 12,
	__REQ_PRIO = 13,
	__REQ_NOMERGE = 14,
	__REQ_IDLE = 15,
	__REQ_INTEGRITY = 16,
	__REQ_FUA = 17,
	__REQ_PREFLUSH = 18,
	__REQ_RAHEAD = 19,
	__REQ_BACKGROUND = 20,
	__REQ_NOWAIT = 21,
	__REQ_NOUNMAP = 22,
	__REQ_HIPRI = 23,
	__REQ_DRV = 24,
	__REQ_SWAP = 25,
	__REQ_NR_BITS = 26,
};

struct dev_pm_ops___51;

struct device_type___51 {
	const char *name;
	const struct attribute_group___52 **groups;
	int (*uevent)(struct device___51 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___51 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___51 *);
	const struct dev_pm_ops___51 *pm;
};

struct class___51 {
	const char *name;
	struct module___52 *owner;
	const struct attribute_group___52 **class_groups;
	const struct attribute_group___52 **dev_groups;
	struct kobject___55 *dev_kobj;
	int (*dev_uevent)(struct device___51 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___51 *, umode_t *);
	void (*class_release)(struct class___51 *);
	void (*dev_release)(struct device___51 *);
	int (*shutdown_pre)(struct device___51 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___51 *);
	const struct dev_pm_ops___51 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dev_pm_ops___51 {
	int (*prepare)(struct device___51 *);
	void (*complete)(struct device___51 *);
	int (*suspend)(struct device___51 *);
	int (*resume)(struct device___51 *);
	int (*freeze)(struct device___51 *);
	int (*thaw)(struct device___51 *);
	int (*poweroff)(struct device___51 *);
	int (*restore)(struct device___51 *);
	int (*suspend_late)(struct device___51 *);
	int (*resume_early)(struct device___51 *);
	int (*freeze_late)(struct device___51 *);
	int (*thaw_early)(struct device___51 *);
	int (*poweroff_late)(struct device___51 *);
	int (*restore_early)(struct device___51 *);
	int (*suspend_noirq)(struct device___51 *);
	int (*resume_noirq)(struct device___51 *);
	int (*freeze_noirq)(struct device___51 *);
	int (*thaw_noirq)(struct device___51 *);
	int (*poweroff_noirq)(struct device___51 *);
	int (*restore_noirq)(struct device___51 *);
	int (*runtime_suspend)(struct device___51 *);
	int (*runtime_resume)(struct device___51 *);
	int (*runtime_idle)(struct device___51 *);
};

struct dev_pm_domain___51 {
	struct dev_pm_ops___51 ops;
	void (*detach)(struct device___51 *, bool);
	int (*activate)(struct device___51 *);
	void (*sync)(struct device___51 *);
	void (*dismiss)(struct device___51 *);
};

struct user_struct___57 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___58 *uid_keyring;
	struct key___58 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___57;

struct mm_struct___57 {
	struct {
		struct vm_area_struct___58 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___58 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___58 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___57 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___58 *owner;
		struct user_namespace___48 *user_ns;
		struct file___58 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___57 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct uts_namespace___17;

struct cgroup_namespace___46;

struct nsproxy___56 {
	atomic_t count;
	struct uts_namespace___17 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___46 *cgroup_ns;
};

struct bdi_writeback_congested___27;

struct bdi_writeback___27 {
	struct backing_dev_info___27 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___27 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___46 *memcg_css;
	struct cgroup_subsys_state___46 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___27 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___27 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___51 *dev;
	struct device___51 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___58 *debug_dir;
	struct dentry___58 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___13;

struct io_context___13 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___13 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___46 {
	struct cgroup_subsys_state___46 *subsys[13];
	refcount_t refcount;
	struct css_set___46 *dom_cset;
	struct cgroup___46 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___46 *mg_src_cgrp;
	struct cgroup___46 *mg_dst_cgrp;
	struct css_set___46 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

typedef blk_qc_t make_request_fn___13(struct request_queue___14 *, struct bio___27 *);

struct request___14;

typedef int dma_drain_needed_fn___13(struct request___14 *);

struct bsg_ops___13;

struct bsg_class_device___13 {
	struct device___51 *class_dev;
	int minor;
	struct request_queue___14 *queue;
	const struct bsg_ops___13 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct elevator_queue___13;

struct request_queue___14 {
	struct list_head queue_head;
	struct request___14 *last_merge;
	struct elevator_queue___13 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___13 *make_request_fn;
	dma_drain_needed_fn___13 *dma_drain_needed;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___27 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___55 kobj;
	struct kobject___55 *mq_kobj;
	struct blk_integrity integrity;
	struct device___51 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	struct bsg_class_device___13 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___27 bio_split;
	struct dentry___58 *debugfs_dir;
	struct dentry___58 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___42 {
	struct vm_struct___42 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___58 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bus_type___51 {
	const char *name;
	const char *dev_name;
	struct device___51 *dev_root;
	const struct attribute_group___52 **bus_groups;
	const struct attribute_group___52 **dev_groups;
	const struct attribute_group___52 **drv_groups;
	int (*match)(struct device___51 *, struct device_driver___51 *);
	int (*uevent)(struct device___51 *, struct kobj_uevent_env *);
	int (*probe)(struct device___51 *);
	int (*remove)(struct device___51 *);
	void (*shutdown)(struct device___51 *);
	int (*online)(struct device___51 *);
	int (*offline)(struct device___51 *);
	int (*suspend)(struct device___51 *, pm_message_t);
	int (*resume)(struct device___51 *);
	int (*num_vf)(struct device___51 *);
	int (*dma_configure)(struct device___51 *);
	const struct dev_pm_ops___51 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___51 {
	const char *name;
	struct bus_type___51 *bus;
	struct module___52 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___51 *);
	int (*remove)(struct device___51 *);
	void (*shutdown)(struct device___51 *);
	int (*suspend)(struct device___51 *, pm_message_t);
	int (*resume)(struct device___51 *);
	const struct attribute_group___52 **groups;
	const struct dev_pm_ops___51 *pm;
	void (*coredump)(struct device___51 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct fwnode_operations___38;

struct fwnode_handle___38 {
	struct fwnode_handle___38 *secondary;
	const struct fwnode_operations___38 *ops;
};

struct dentry_operations___57;

struct super_block___58;

struct dentry___58 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___58 *d_parent;
	struct qstr d_name;
	struct inode___59 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___57 *d_op;
	struct super_block___58 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___57;

struct address_space___57 {
	struct inode___59 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___58 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___57 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___57;

struct block_device___58;

struct inode___59 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___57 *i_op;
	struct super_block___58 *i_sb;
	struct address_space___57 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___58 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___27 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___58 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___57 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___58 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___57 {
	int (*d_revalidate)(struct dentry___58 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___58 *, unsigned int);
	int (*d_hash)(const struct dentry___58 *, struct qstr *);
	int (*d_compare)(const struct dentry___58 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___58 *);
	int (*d_init)(struct dentry___58 *);
	void (*d_release)(struct dentry___58 *);
	void (*d_prune)(struct dentry___58 *);
	void (*d_iput)(struct dentry___58 *, struct inode___59 *);
	char * (*d_dname)(struct dentry___58 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___57 *);
	int (*d_manage)(const struct path___57 *, bool);
	struct dentry___58 * (*d_real)(struct dentry___58 *, const struct inode___59 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___57;

struct mem_dqinfo___57 {
	struct quota_format_type___57 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___57;

struct quota_info___57 {
	unsigned int flags;
	struct rw_semaphore___58 dqio_sem;
	struct inode___59 *files[3];
	struct mem_dqinfo___57 info[3];
	const struct quota_format_ops___57 *ops[3];
};

struct rcuwait___57 {
	struct task_struct___58 *task;
};

struct percpu_rw_semaphore___57 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___58 rw_sem;
	struct rcuwait___57 writer;
	int readers_block;
};

struct sb_writers___57 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___57 rw_sem[3];
};

struct shrink_control___26;

struct shrinker___26 {
	long unsigned int (*count_objects)(struct shrinker___26 *, struct shrink_control___26 *);
	long unsigned int (*scan_objects)(struct shrinker___26 *, struct shrink_control___26 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___57;

struct super_operations___57;

struct dquot_operations___57;

struct quotactl_ops___57;

struct super_block___58 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___57 *s_type;
	const struct super_operations___57 *s_op;
	const struct dquot_operations___57 *dq_op;
	const struct quotactl_ops___57 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___58 *s_root;
	struct rw_semaphore___58 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___58 *s_bdev;
	struct backing_dev_info___27 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___57 s_dquot;
	struct sb_writers___57 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___57 *s_d_op;
	int cleancache_poolid;
	struct shrinker___26 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___48 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___26 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___26 *memcg;
};

typedef int (*dev_page_fault_t___57)(struct vm_area_struct___58 *, long unsigned int, const struct page___58 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___57)(struct page___58 *, void *);

struct dev_pagemap___57 {
	dev_page_fault_t___57 page_fault;
	dev_page_free_t___57 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___51 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___57 {
	struct task_struct___58 *task;
	struct core_thread___57 *next;
};

struct core_state___57 {
	atomic_t nr_threads;
	struct core_thread___57 dumper;
	struct completion startup;
};

struct vm_fault___57 {
	struct vm_area_struct___58 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___58 *cow_page;
	struct mem_cgroup___26 *memcg;
	struct page___58 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___57 prealloc_pte;
};

typedef struct {
	long unsigned int val;
} swp_entry_t;

struct io_cq___13 {
	struct request_queue___14 *q;
	struct io_context___13 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___58 {
	struct file___58 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___58 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___58 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___58 *ia_file;
};

struct dquot___57 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___58 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___57 {
	int qf_fmt_id;
	const struct quota_format_ops___57 *qf_ops;
	struct module___52 *qf_owner;
	struct quota_format_type___57 *qf_next;
};

struct quota_format_ops___57 {
	int (*check_quota_file)(struct super_block___58 *, int);
	int (*read_file_info)(struct super_block___58 *, int);
	int (*write_file_info)(struct super_block___58 *, int);
	int (*free_file_info)(struct super_block___58 *, int);
	int (*read_dqblk)(struct dquot___57 *);
	int (*commit_dqblk)(struct dquot___57 *);
	int (*release_dqblk)(struct dquot___57 *);
	int (*get_next_id)(struct super_block___58 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___57 {
	int (*write_dquot)(struct dquot___57 *);
	struct dquot___57 * (*alloc_dquot)(struct super_block___58 *, int);
	void (*destroy_dquot)(struct dquot___57 *);
	int (*acquire_dquot)(struct dquot___57 *);
	int (*release_dquot)(struct dquot___57 *);
	int (*mark_dirty)(struct dquot___57 *);
	int (*write_info)(struct super_block___58 *, int);
	qsize_t * (*get_reserved_space)(struct inode___59 *);
	int (*get_projid)(struct inode___59 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___59 *, qsize_t *);
	int (*get_next_id)(struct super_block___58 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___57 {
	int (*quota_on)(struct super_block___58 *, int, int, const struct path___57 *);
	int (*quota_off)(struct super_block___58 *, int);
	int (*quota_enable)(struct super_block___58 *, unsigned int);
	int (*quota_disable)(struct super_block___58 *, unsigned int);
	int (*quota_sync)(struct super_block___58 *, int);
	int (*set_info)(struct super_block___58 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___58 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___58 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___58 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___58 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___58 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___26;

struct swap_info_struct___21;

struct address_space_operations___57 {
	int (*writepage)(struct page___58 *, struct writeback_control___26 *);
	int (*readpage)(struct file___58 *, struct page___58 *);
	int (*writepages)(struct address_space___57 *, struct writeback_control___26 *);
	int (*set_page_dirty)(struct page___58 *);
	int (*readpages)(struct file___58 *, struct address_space___57 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___58 *, struct address_space___57 *, loff_t, unsigned int, unsigned int, struct page___58 **, void **);
	int (*write_end)(struct file___58 *, struct address_space___57 *, loff_t, unsigned int, unsigned int, struct page___58 *, void *);
	sector_t (*bmap)(struct address_space___57 *, sector_t);
	void (*invalidatepage)(struct page___58 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___58 *, gfp_t);
	void (*freepage)(struct page___58 *);
	ssize_t (*direct_IO)(struct kiocb___58 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___57 *, struct page___58 *, struct page___58 *, enum migrate_mode);
	bool (*isolate_page)(struct page___58 *, isolate_mode_t);
	void (*putback_page)(struct page___58 *);
	int (*launder_page)(struct page___58 *);
	int (*is_partially_uptodate)(struct page___58 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___58 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___57 *, struct page___58 *);
	int (*swap_activate)(struct swap_info_struct___21 *, struct file___58 *, sector_t *);
	void (*swap_deactivate)(struct file___58 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___26 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___27 *wb;
	struct inode___59 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct swap_info_struct___21 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___58 *bdev;
	struct file___58 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___58 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___59 *bd_inode;
	struct super_block___58 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___58 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___14 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___14 *bd_disk;
	struct request_queue___14 *bd_queue;
	struct backing_dev_info___27 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___57 {
	struct dentry___58 * (*lookup)(struct inode___59 *, struct dentry___58 *, unsigned int);
	const char * (*get_link)(struct dentry___58 *, struct inode___59 *, struct delayed_call *);
	int (*permission)(struct inode___59 *, int);
	struct posix_acl * (*get_acl)(struct inode___59 *, int);
	int (*readlink)(struct dentry___58 *, char *, int);
	int (*create)(struct inode___59 *, struct dentry___58 *, umode_t, bool);
	int (*link)(struct dentry___58 *, struct inode___59 *, struct dentry___58 *);
	int (*unlink)(struct inode___59 *, struct dentry___58 *);
	int (*symlink)(struct inode___59 *, struct dentry___58 *, const char *);
	int (*mkdir)(struct inode___59 *, struct dentry___58 *, umode_t);
	int (*rmdir)(struct inode___59 *, struct dentry___58 *);
	int (*mknod)(struct inode___59 *, struct dentry___58 *, umode_t, dev_t);
	int (*rename)(struct inode___59 *, struct dentry___58 *, struct inode___59 *, struct dentry___58 *, unsigned int);
	int (*setattr)(struct dentry___58 *, struct iattr___58 *);
	int (*getattr)(const struct path___57 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___58 *, char *, size_t);
	int (*fiemap)(struct inode___59 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___59 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___59 *, struct dentry___58 *, struct file___58 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___59 *, struct dentry___58 *, umode_t);
	int (*set_acl)(struct inode___59 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___57 {
	void (*fl_copy_lock)(struct file_lock___58 *, struct file_lock___58 *);
	void (*fl_release_private)(struct file_lock___58 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___57;

struct lock_manager_operations___57;

struct file_lock___58 {
	struct file_lock___58 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___58 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___57 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___57 *fl_ops;
	const struct lock_manager_operations___57 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___57 {
	int (*lm_compare_owner)(struct file_lock___58 *, struct file_lock___58 *);
	long unsigned int (*lm_owner_key)(struct file_lock___58 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___58 *);
	int (*lm_grant)(struct file_lock___58 *, int);
	bool (*lm_break)(struct file_lock___58 *);
	int (*lm_change)(struct file_lock___58 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___58 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___57 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___57 *fa_next;
	struct file___58 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___57 {
	const char *name;
	int fs_flags;
	struct dentry___58 * (*mount)(struct file_system_type___57 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___58 *);
	struct module___52 *owner;
	struct file_system_type___57 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___57 {
	struct inode___59 * (*alloc_inode)(struct super_block___58 *);
	void (*destroy_inode)(struct inode___59 *);
	void (*dirty_inode)(struct inode___59 *, int);
	int (*write_inode)(struct inode___59 *, struct writeback_control___26 *);
	int (*drop_inode)(struct inode___59 *);
	void (*evict_inode)(struct inode___59 *);
	void (*put_super)(struct super_block___58 *);
	int (*sync_fs)(struct super_block___58 *, int);
	int (*freeze_super)(struct super_block___58 *);
	int (*freeze_fs)(struct super_block___58 *);
	int (*thaw_super)(struct super_block___58 *);
	int (*unfreeze_fs)(struct super_block___58 *);
	int (*statfs)(struct dentry___58 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___58 *, int *, char *);
	void (*umount_begin)(struct super_block___58 *);
	int (*show_options)(struct seq_file___55 *, struct dentry___58 *);
	int (*show_devname)(struct seq_file___55 *, struct dentry___58 *);
	int (*show_path)(struct seq_file___55 *, struct dentry___58 *);
	int (*show_stats)(struct seq_file___55 *, struct dentry___58 *);
	ssize_t (*quota_read)(struct super_block___58 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___58 *, int, const char *, size_t, loff_t);
	struct dquot___57 ** (*get_dquots)(struct inode___59 *);
	int (*bdev_try_to_free_page)(struct super_block___58 *, struct page___58 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___58 *, struct shrink_control___26 *);
	long int (*free_cached_objects)(struct super_block___58 *, struct shrink_control___26 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___14 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___14 *last_lookup;
	struct hd_struct___14 *part[0];
};

struct block_device_operations___14 {
	int (*open)(struct block_device___58 *, fmode_t);
	void (*release)(struct gendisk___14 *, fmode_t);
	int (*rw_page)(struct block_device___58 *, sector_t, struct page___58 *, unsigned int);
	int (*ioctl)(struct block_device___58 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___58 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___14 *, unsigned int);
	int (*media_changed)(struct gendisk___14 *);
	void (*unlock_native_capacity)(struct gendisk___14 *);
	int (*revalidate_disk)(struct gendisk___14 *);
	int (*getgeo)(struct block_device___58 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___58 *, long unsigned int);
	int (*report_zones)(struct gendisk___14 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___52 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___57(struct page___58 *);

struct bdi_writeback_congested___27 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___27 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bsg_ops___13 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___14 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___14 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___14 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___13(struct request___14 *, blk_status_t);

struct request___14 {
	struct request_queue___14 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___27 *bio;
	struct bio___27 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___27 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___13 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___13 *saved_end_io;
		} flush;
	};
	struct gendisk___14 *rq_disk;
	struct hd_struct___14 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___13 *end_io;
	void *end_io_data;
	struct request___14 *next_rq;
};

struct fwnode_reference_args___38;

struct fwnode_endpoint___38;

struct fwnode_operations___38 {
	struct fwnode_handle___38 * (*get)(struct fwnode_handle___38 *);
	void (*put)(struct fwnode_handle___38 *);
	bool (*device_is_available)(const struct fwnode_handle___38 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___38 *, const struct device___51 *);
	bool (*property_present)(const struct fwnode_handle___38 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___38 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___38 *, const char *, const char **, size_t);
	struct fwnode_handle___38 * (*get_parent)(const struct fwnode_handle___38 *);
	struct fwnode_handle___38 * (*get_next_child_node)(const struct fwnode_handle___38 *, struct fwnode_handle___38 *);
	struct fwnode_handle___38 * (*get_named_child_node)(const struct fwnode_handle___38 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___38 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___38 *);
	struct fwnode_handle___38 * (*graph_get_next_endpoint)(const struct fwnode_handle___38 *, struct fwnode_handle___38 *);
	struct fwnode_handle___38 * (*graph_get_remote_endpoint)(const struct fwnode_handle___38 *);
	struct fwnode_handle___38 * (*graph_get_port_parent)(struct fwnode_handle___38 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___38 *, struct fwnode_endpoint___38 *);
};

struct fwnode_endpoint___38 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___38 *local_fwnode;
};

struct fwnode_reference_args___38 {
	struct fwnode_handle___38 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct elevator_type___13;

struct elevator_mq_ops___13 {
	int (*init_sched)(struct request_queue___14 *, struct elevator_type___13 *);
	void (*exit_sched)(struct elevator_queue___13 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	bool (*allow_merge)(struct request_queue___14 *, struct request___14 *, struct bio___27 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx *, struct bio___27 *);
	int (*request_merge)(struct request_queue___14 *, struct request___14 **, struct bio___27 *);
	void (*request_merged)(struct request_queue___14 *, struct request___14 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___14 *, struct request___14 *, struct request___14 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___14 *, struct bio___27 *);
	void (*finish_request)(struct request___14 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___14 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___14 *, u64);
	void (*started_request)(struct request___14 *);
	void (*requeue_request)(struct request___14 *);
	struct request___14 * (*former_request)(struct request_queue___14 *, struct request___14 *);
	struct request___14 * (*next_request)(struct request_queue___14 *, struct request___14 *);
	void (*init_icq)(struct io_cq___13 *);
	void (*exit_icq)(struct io_cq___13 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___13;

struct elevator_type___13 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___13 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___13 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___52 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___13 {
	struct elevator_type___13 *type;
	void *elevator_data;
	struct kobject___55 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___13 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___13 *, char *);
	ssize_t (*store)(struct elevator_queue___13 *, const char *, size_t);
};

typedef int (*key_restrict_link_func_t___57)(struct key___58 *, const struct key_type *, const union key_payload *, struct key___58 *);

struct key_restriction___58;

struct key___58 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___58 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___58 *restrict_link;
};

struct key_restriction___58 {
	key_restrict_link_func_t___57 check;
	struct key___58 *key;
	struct key_type *keytype;
};

struct seq_operations___52 {
	void * (*start)(struct seq_file___55 *, loff_t *);
	void (*stop)(struct seq_file___55 *, void *);
	void * (*next)(struct seq_file___55 *, void *, loff_t *);
	int (*show)(struct seq_file___55 *, void *);
};

struct uts_namespace___17 {
	struct kref kref;
	struct new_utsname name;
	struct user_namespace___48 *user_ns;
	struct ucounts___48 *ucounts;
	struct ns_common ns;
};

struct cgroup_namespace___46 {
	refcount_t count;
	struct ns_common ns;
	struct user_namespace___48 *user_ns;
	struct ucounts___48 *ucounts;
	struct css_set___46 *root_cset;
};

struct ucounts___48 {
	struct hlist_node node;
	struct user_namespace___48 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___46;

struct bpf_map_ops___46 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___46 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___46 *, struct file___58 *);
	void (*map_free)(struct bpf_map___46 *);
	int (*map_get_next_key)(struct bpf_map___46 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___46 *);
	void * (*map_lookup_elem)(struct bpf_map___46 *, void *);
	int (*map_update_elem)(struct bpf_map___46 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___46 *, void *);
	int (*map_push_elem)(struct bpf_map___46 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___46 *, void *);
	int (*map_peek_elem)(struct bpf_map___46 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___46 *, struct file___58 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___46 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___46 *, void *, struct seq_file___55 *);
	int (*map_check_btf)(const struct bpf_map___46 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___46 {
	const struct bpf_map_ops___46 *ops;
	struct bpf_map___46 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___57 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___46;

typedef void (*kthread_work_func_t___46)(struct kthread_work___46 *);

struct kthread_worker___46;

struct kthread_work___46 {
	struct list_head node;
	kthread_work_func_t___46 func;
	struct kthread_worker___46 *worker;
	int canceling;
};

struct kthread_worker___46 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___58 *task;
	struct kthread_work___46 *current_work;
};

struct kthread_delayed_work___46 {
	struct kthread_work___46 work;
	struct timer_list timer;
};

struct psi_group___46 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___46 *poll_kworker;
	struct kthread_delayed_work___46 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___46;

struct cgroup_rstat_cpu___46;

struct cgroup___46 {
	struct cgroup_subsys_state___46 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___55 *kn;
	struct cgroup_file___46 procs_file;
	struct cgroup_file___46 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___46 *subsys[13];
	struct cgroup_root___46 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___46 *dom_cgrp;
	struct cgroup_rstat_cpu___46 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf bpf;
	atomic_t congestion_count;
	struct cgroup___46 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___46 psi;
	int ancestor_ids[0];
};

struct cftype___46;

struct cgroup_subsys___46 {
	struct cgroup_subsys_state___46 * (*css_alloc)(struct cgroup_subsys_state___46 *);
	int (*css_online)(struct cgroup_subsys_state___46 *);
	void (*css_offline)(struct cgroup_subsys_state___46 *);
	void (*css_released)(struct cgroup_subsys_state___46 *);
	void (*css_free)(struct cgroup_subsys_state___46 *);
	void (*css_reset)(struct cgroup_subsys_state___46 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___46 *, int);
	int (*css_extra_stat_show)(struct seq_file___55 *, struct cgroup_subsys_state___46 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___58 *);
	void (*cancel_fork)(struct task_struct___58 *);
	void (*fork)(struct task_struct___58 *);
	void (*exit)(struct task_struct___58 *);
	void (*free)(struct task_struct___58 *);
	void (*bind)(struct cgroup_subsys_state___46 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___46 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___46 *dfl_cftypes;
	struct cftype___46 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___46 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___46 *updated_children;
	struct cgroup___46 *updated_next;
};

struct cgroup_root___46 {
	struct kernfs_root___55 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___46 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___46 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___46 *ss;
	struct list_head node;
	struct kernfs_ops___55 *kf_ops;
	int (*open)(struct kernfs_open_file___55 *);
	void (*release)(struct kernfs_open_file___55 *);
	u64 (*read_u64)(struct cgroup_subsys_state___46 *, struct cftype___46 *);
	s64 (*read_s64)(struct cgroup_subsys_state___46 *, struct cftype___46 *);
	int (*seq_show)(struct seq_file___55 *, void *);
	void * (*seq_start)(struct seq_file___55 *, loff_t *);
	void * (*seq_next)(struct seq_file___55 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___55 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___46 *, struct cftype___46 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___46 *, struct cftype___46 *, s64);
	ssize_t (*write)(struct kernfs_open_file___55 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___55 *, struct poll_table_struct___6 *);
};

struct mem_cgroup_reclaim_iter___26 {
	struct mem_cgroup___26 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___26 {
	struct lruvec___57 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___26 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___26 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct node___48 {
	struct device___51 dev;
};

struct swap_map_page {
	sector_t entries[8191];
	sector_t next_swap;
};

struct swap_map_page_list {
	struct swap_map_page *map;
	struct swap_map_page_list *next;
};

struct swap_map_handle {
	struct swap_map_page *cur;
	struct swap_map_page_list *maps;
	sector_t cur_swap;
	sector_t first_sector;
	unsigned int k;
	long unsigned int reqd_free_pages;
	u32 crc32;
};

struct swsusp_header {
	char reserved[65500];
	u32 crc32;
	sector_t image;
	unsigned int flags;
	char orig_sig[10];
	char sig[10];
};

struct swsusp_extent {
	struct rb_node node;
	long unsigned int start;
	long unsigned int end;
};

struct hib_bio_batch {
	atomic_t count;
	wait_queue_head_t wait;
	blk_status_t error;
};

struct crc_data {
	struct task_struct___58 *thr;
	atomic_t ready;
	atomic_t stop;
	unsigned int run_threads;
	wait_queue_head_t go;
	wait_queue_head_t done;
	u32 *crc32;
	size_t *unc_len[3];
	unsigned char *unc[3];
};

struct cmp_data {
	struct task_struct___58 *thr;
	atomic_t ready;
	atomic_t stop;
	int ret;
	wait_queue_head_t go;
	wait_queue_head_t done;
	size_t unc_len;
	size_t cmp_len;
	unsigned char unc[2097152];
	unsigned char cmp[2293760];
	unsigned char wrk[16384];
};

struct dec_data {
	struct task_struct___58 *thr;
	atomic_t ready;
	atomic_t stop;
	int ret;
	wait_queue_head_t go;
	wait_queue_head_t done;
	size_t unc_len;
	size_t cmp_len;
	unsigned char unc[2097152];
	unsigned char cmp[2293760];
};

struct miscdevice___3 {
	int minor;
	const char *name;
	const struct file_operations___57 *fops;
	struct list_head list;
	struct device___50 *parent;
	struct device___50 *this_device;
	const struct attribute_group___51 **groups;
	const char *nodename;
	umode_t mode;
};

struct resume_swap_area {
	__kernel_loff_t offset;
	__u32 dev;
} __attribute__((packed));

struct snapshot_data {
	struct snapshot_handle handle;
	int swap;
	int mode;
	bool frozen;
	bool ready;
	bool platform_support;
	bool free_bitmaps;
};

struct sysrq_key_op {
	void (*handler)(int);
	char *help_msg;
	char *action_msg;
	int enable_mask;
};

struct module___53;

struct file___59;

struct kiocb___59;

struct poll_table_struct___38;

struct vm_area_struct___59;

struct inode___60;

struct file_lock___59;

struct page___59;

struct seq_file___56;

struct file_operations___59 {
	struct module___53 *owner;
	loff_t (*llseek)(struct file___59 *, loff_t, int);
	ssize_t (*read)(struct file___59 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___59 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___59 *, struct iov_iter___9 *);
	ssize_t (*write_iter)(struct kiocb___59 *, struct iov_iter___9 *);
	int (*iopoll)(struct kiocb___59 *, bool);
	int (*iterate)(struct file___59 *, struct dir_context *);
	int (*iterate_shared)(struct file___59 *, struct dir_context *);
	__poll_t (*poll)(struct file___59 *, struct poll_table_struct___38 *);
	long int (*unlocked_ioctl)(struct file___59 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___59 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___59 *, struct vm_area_struct___59 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___60 *, struct file___59 *);
	int (*flush)(struct file___59 *, fl_owner_t);
	int (*release)(struct inode___60 *, struct file___59 *);
	int (*fsync)(struct file___59 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___59 *, int);
	int (*lock)(struct file___59 *, int, struct file_lock___59 *);
	ssize_t (*sendpage)(struct file___59 *, struct page___59 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___59 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___59 *, int, struct file_lock___59 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___59 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___59 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___59 *, long int, struct file_lock___59 **, void **);
	long int (*fallocate)(struct file___59 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___56 *, struct file___59 *);
	ssize_t (*copy_file_range)(struct file___59 *, loff_t, struct file___59 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___59 *, loff_t, struct file___59 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___59 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___58 {
	u64 seqnum;
	struct vm_area_struct___59 *vmas[4];
};

struct page_frag___58 {
	struct page___59 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___37;

struct debug_info___37 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___37 *hbp_break[16];
	struct perf_event___37 *hbp_watch[16];
};

struct thread_struct___37 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___37 debug;
	long: 64;
};

struct mm_struct___58;

struct pid___51;

struct cred___58;

struct nsproxy___57;

struct signal_struct___53;

struct css_set___47;

struct perf_event_context___37;

struct task_struct___59 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___59 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___58 *mm;
	struct mm_struct___58 *active_mm;
	struct vmacache___58 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___59 *real_parent;
	struct task_struct___59 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___59 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___51 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___51 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___51 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___58 *ptracer_cred;
	const struct cred___58 *real_cred;
	const struct cred___58 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___57 *nsproxy;
	struct signal_struct___53 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___59 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___13 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___47 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___37 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___58 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___59 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___37 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___37 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___59 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___37)(struct perf_event___37 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___37;

struct fasync_struct___58;

struct pid_namespace___51;

struct trace_event_call___32;

struct perf_cgroup___37;

struct perf_event___37 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___37 *group_leader;
	struct pmu___37 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___37 hw;
	struct perf_event_context___37 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___37 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___59 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___58 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___37 *);
	struct callback_head callback_head;
	struct pid_namespace___51 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___37 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___37 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___32 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___37 *cgrp;
	struct list_head sb_list;
};

typedef struct page___59 *pgtable_t___58;

struct address_space___58;

struct dev_pagemap___58;

struct page___59 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___58 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___59 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___58 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___58 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___58 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___58;

struct lruvec___58 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___58 *pgdat;
};

struct zone___58 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___58 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___58 {
	struct zone___58 *zone;
	int zone_idx;
};

struct zonelist___58 {
	struct zoneref___58 _zonerefs[25];
};

struct pglist_data___58 {
	struct zone___58 node_zones[3];
	struct zonelist___58 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___59 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___59 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___58 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___59 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___59 *owner;
};

struct secondary_data___59 {
	void *stack;
	struct task_struct___59 *task;
	long int status;
};

struct blocking_notifier_head___58 {
	struct rw_semaphore___59 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___58;

struct vm_area_struct___59 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___59 *vm_next;
	struct vm_area_struct___59 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___58 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___58 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___59 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___58;

struct user_namespace___49;

struct mm_struct___58 {
	struct {
		struct vm_area_struct___59 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___59 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___59 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___58 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___59 *owner;
		struct user_namespace___49 *user_ns;
		struct file___59 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___58 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___58;

struct address_space___58 {
	struct inode___60 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___59 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___58 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___58)(struct vm_area_struct___59 *, long unsigned int, const struct page___59 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___58)(struct page___59 *, void *);

struct device___52;

struct dev_pagemap___58 {
	dev_page_fault_t___58 page_fault;
	dev_page_free_t___58 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___52 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct dentry___59;

struct path___58 {
	struct vfsmount *mnt;
	struct dentry___59 *dentry;
};

struct fown_struct___51 {
	rwlock_t lock;
	struct pid___51 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___59 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___58 f_path;
	struct inode___60 *f_inode;
	const struct file_operations___59 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___51 f_owner;
	const struct cred___58 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___58 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___58;

struct vm_operations_struct___58 {
	void (*open)(struct vm_area_struct___59 *);
	void (*close)(struct vm_area_struct___59 *);
	int (*split)(struct vm_area_struct___59 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___59 *);
	vm_fault_t (*fault)(struct vm_fault___58 *);
	vm_fault_t (*huge_fault)(struct vm_fault___58 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___58 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___59 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___58 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___58 *);
	int (*access)(struct vm_area_struct___59 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___59 *);
	int (*set_policy)(struct vm_area_struct___59 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___59 *, long unsigned int);
	struct page___59 * (*find_special_page)(struct vm_area_struct___59 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___58 {
	struct task_struct___59 *task;
	struct core_thread___58 *next;
};

struct core_state___58 {
	atomic_t nr_threads;
	struct core_thread___58 dumper;
	struct completion startup;
};

struct key___59;

struct ucounts___49;

struct user_namespace___49 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___49 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common ns;
	long unsigned int flags;
	struct key___59 *persistent_keyring_register;
	struct rw_semaphore___59 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___49 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___58 {
	struct vm_area_struct___59 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___59 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___59 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___58 prealloc_pte;
};

struct upid___51 {
	int nr;
	struct pid_namespace___51 *ns;
};

struct pid_namespace___51 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___59 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___51 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___59 *proc_self;
	struct dentry___59 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___49 *user_ns;
	struct ucounts___49 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common ns;
};

struct pid___51 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___51 numbers[1];
};

struct user_struct___58 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___59 *uid_keyring;
	struct key___59 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___58 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___59 *session_keyring;
	struct key___59 *process_keyring;
	struct key___59 *thread_keyring;
	struct key___59 *request_key_auth;
	void *security;
	struct user_struct___58 *user;
	struct user_namespace___49 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___47;

struct nsproxy___57 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___51 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___47 *cgroup_ns;
};

struct tty_struct___8;

struct signal_struct___53 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___59 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___59 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___51 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___51 *tty_old_pgrp;
	int leader;
	struct tty_struct___8 *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___58 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___51 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___47;

struct cgroup___47;

struct css_set___47 {
	struct cgroup_subsys_state___47 *subsys[13];
	refcount_t refcount;
	struct css_set___47 *dom_cset;
	struct cgroup___47 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___47 *mg_src_cgrp;
	struct cgroup___47 *mg_dst_cgrp;
	struct css_set___47 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___37 {
	struct pmu___37 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___59 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___37 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

union thread_union___53 {
	struct task_struct___59 task;
	long unsigned int stack[8192];
};

struct kset___55;

struct kobj_type___55;

struct kernfs_node___56;

struct kobject___56 {
	const char *name;
	struct list_head entry;
	struct kobject___56 *parent;
	struct kset___55 *kset;
	struct kobj_type___55 *ktype;
	struct kernfs_node___56 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___52 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___52 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___52;

struct bus_type___52;

struct device_driver___52;

struct dev_pm_domain___52;

struct class___52;

struct attribute_group___53;

struct device___52 {
	struct device___52 *parent;
	struct device_private *p;
	struct kobject___56 kobj;
	const char *init_name;
	const struct device_type___52 *type;
	struct mutex mutex;
	struct bus_type___52 *bus;
	struct device_driver___52 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___52 power;
	struct dev_pm_domain___52 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___52 *class;
	const struct attribute_group___53 **groups;
	void (*release)(struct device___52 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___58;

struct super_block___59;

struct dentry___59 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___59 *d_parent;
	struct qstr d_name;
	struct inode___60 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___58 *d_op;
	struct super_block___59 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___58;

struct block_device___59;

struct cdev___15;

struct inode___60 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___58 *i_op;
	struct super_block___59 *i_sb;
	struct address_space___58 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___59 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___59 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___58 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___59 *i_bdev;
		struct cdev___15 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___58 {
	int (*d_revalidate)(struct dentry___59 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___59 *, unsigned int);
	int (*d_hash)(const struct dentry___59 *, struct qstr *);
	int (*d_compare)(const struct dentry___59 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___59 *);
	int (*d_init)(struct dentry___59 *);
	void (*d_release)(struct dentry___59 *);
	void (*d_prune)(struct dentry___59 *);
	void (*d_iput)(struct dentry___59 *, struct inode___60 *);
	char * (*d_dname)(struct dentry___59 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___58 *);
	int (*d_manage)(const struct path___58 *, bool);
	struct dentry___59 * (*d_real)(struct dentry___59 *, const struct inode___60 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___58;

struct mem_dqinfo___58 {
	struct quota_format_type___58 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___58;

struct quota_info___58 {
	unsigned int flags;
	struct rw_semaphore___59 dqio_sem;
	struct inode___60 *files[3];
	struct mem_dqinfo___58 info[3];
	const struct quota_format_ops___58 *ops[3];
};

struct rcuwait___58 {
	struct task_struct___59 *task;
};

struct percpu_rw_semaphore___58 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___59 rw_sem;
	struct rcuwait___58 writer;
	int readers_block;
};

struct sb_writers___58 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___58 rw_sem[3];
};

struct file_system_type___58;

struct super_operations___58;

struct dquot_operations___58;

struct quotactl_ops___58;

struct super_block___59 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___58 *s_type;
	const struct super_operations___58 *s_op;
	const struct dquot_operations___58 *dq_op;
	const struct quotactl_ops___58 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___59 *s_root;
	struct rw_semaphore___59 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___59 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___58 s_dquot;
	struct sb_writers___58 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___58 *s_d_op;
	int cleancache_poolid;
	struct shrinker___26 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___49 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___59 {
	struct file___59 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___59 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___59 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___59 *ia_file;
};

struct dquot___58 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___59 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___58 {
	int qf_fmt_id;
	const struct quota_format_ops___58 *qf_ops;
	struct module___53 *qf_owner;
	struct quota_format_type___58 *qf_next;
};

struct quota_format_ops___58 {
	int (*check_quota_file)(struct super_block___59 *, int);
	int (*read_file_info)(struct super_block___59 *, int);
	int (*write_file_info)(struct super_block___59 *, int);
	int (*free_file_info)(struct super_block___59 *, int);
	int (*read_dqblk)(struct dquot___58 *);
	int (*commit_dqblk)(struct dquot___58 *);
	int (*release_dqblk)(struct dquot___58 *);
	int (*get_next_id)(struct super_block___59 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___58 {
	int (*write_dquot)(struct dquot___58 *);
	struct dquot___58 * (*alloc_dquot)(struct super_block___59 *, int);
	void (*destroy_dquot)(struct dquot___58 *);
	int (*acquire_dquot)(struct dquot___58 *);
	int (*release_dquot)(struct dquot___58 *);
	int (*mark_dirty)(struct dquot___58 *);
	int (*write_info)(struct super_block___59 *, int);
	qsize_t * (*get_reserved_space)(struct inode___60 *);
	int (*get_projid)(struct inode___60 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___60 *, qsize_t *);
	int (*get_next_id)(struct super_block___59 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___58 {
	int (*quota_on)(struct super_block___59 *, int, int, const struct path___58 *);
	int (*quota_off)(struct super_block___59 *, int);
	int (*quota_enable)(struct super_block___59 *, unsigned int);
	int (*quota_disable)(struct super_block___59 *, unsigned int);
	int (*quota_sync)(struct super_block___59 *, int);
	int (*set_info)(struct super_block___59 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___59 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___59 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___59 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___59 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___59 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___50 {
	struct kobject___56 kobj;
	struct module___53 *mod;
	struct kobject___56 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___50 {
	struct module___53 *mod;
	struct latch_tree_node node;
};

struct module_layout___50 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___50 mtn;
};

struct module_attribute___50;

struct kernel_param___50;

struct module___53 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___50 mkobj;
	struct module_attribute___50 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___56 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___50 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___50 core_layout;
	struct module_layout___50 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___32 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___58 {
	int (*writepage)(struct page___59 *, struct writeback_control___3 *);
	int (*readpage)(struct file___59 *, struct page___59 *);
	int (*writepages)(struct address_space___58 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___59 *);
	int (*readpages)(struct file___59 *, struct address_space___58 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___59 *, struct address_space___58 *, loff_t, unsigned int, unsigned int, struct page___59 **, void **);
	int (*write_end)(struct file___59 *, struct address_space___58 *, loff_t, unsigned int, unsigned int, struct page___59 *, void *);
	sector_t (*bmap)(struct address_space___58 *, sector_t);
	void (*invalidatepage)(struct page___59 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___59 *, gfp_t);
	void (*freepage)(struct page___59 *);
	ssize_t (*direct_IO)(struct kiocb___59 *, struct iov_iter___9 *);
	int (*migratepage)(struct address_space___58 *, struct page___59 *, struct page___59 *, enum migrate_mode);
	bool (*isolate_page)(struct page___59 *, isolate_mode_t);
	void (*putback_page)(struct page___59 *);
	int (*launder_page)(struct page___59 *);
	int (*is_partially_uptodate)(struct page___59 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___59 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___58 *, struct page___59 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___59 *, sector_t *);
	void (*swap_deactivate)(struct file___59 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___59 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___60 *bd_inode;
	struct super_block___59 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___59 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___15 {
	struct kobject___56 kobj;
	struct module___53 *owner;
	const struct file_operations___59 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___58 {
	struct dentry___59 * (*lookup)(struct inode___60 *, struct dentry___59 *, unsigned int);
	const char * (*get_link)(struct dentry___59 *, struct inode___60 *, struct delayed_call *);
	int (*permission)(struct inode___60 *, int);
	struct posix_acl * (*get_acl)(struct inode___60 *, int);
	int (*readlink)(struct dentry___59 *, char *, int);
	int (*create)(struct inode___60 *, struct dentry___59 *, umode_t, bool);
	int (*link)(struct dentry___59 *, struct inode___60 *, struct dentry___59 *);
	int (*unlink)(struct inode___60 *, struct dentry___59 *);
	int (*symlink)(struct inode___60 *, struct dentry___59 *, const char *);
	int (*mkdir)(struct inode___60 *, struct dentry___59 *, umode_t);
	int (*rmdir)(struct inode___60 *, struct dentry___59 *);
	int (*mknod)(struct inode___60 *, struct dentry___59 *, umode_t, dev_t);
	int (*rename)(struct inode___60 *, struct dentry___59 *, struct inode___60 *, struct dentry___59 *, unsigned int);
	int (*setattr)(struct dentry___59 *, struct iattr___59 *);
	int (*getattr)(const struct path___58 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___59 *, char *, size_t);
	int (*fiemap)(struct inode___60 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___60 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___60 *, struct dentry___59 *, struct file___59 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___60 *, struct dentry___59 *, umode_t);
	int (*set_acl)(struct inode___60 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___58 {
	void (*fl_copy_lock)(struct file_lock___59 *, struct file_lock___59 *);
	void (*fl_release_private)(struct file_lock___59 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___58;

struct file_lock___59 {
	struct file_lock___59 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___59 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___58 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___58 *fl_ops;
	const struct lock_manager_operations___58 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___58 {
	int (*lm_compare_owner)(struct file_lock___59 *, struct file_lock___59 *);
	long unsigned int (*lm_owner_key)(struct file_lock___59 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___59 *);
	int (*lm_grant)(struct file_lock___59 *, int);
	bool (*lm_break)(struct file_lock___59 *);
	int (*lm_change)(struct file_lock___59 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___59 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___58 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___58 *fa_next;
	struct file___59 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___58 {
	const char *name;
	int fs_flags;
	struct dentry___59 * (*mount)(struct file_system_type___58 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___59 *);
	struct module___53 *owner;
	struct file_system_type___58 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___58 {
	struct inode___60 * (*alloc_inode)(struct super_block___59 *);
	void (*destroy_inode)(struct inode___60 *);
	void (*dirty_inode)(struct inode___60 *, int);
	int (*write_inode)(struct inode___60 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___60 *);
	void (*evict_inode)(struct inode___60 *);
	void (*put_super)(struct super_block___59 *);
	int (*sync_fs)(struct super_block___59 *, int);
	int (*freeze_super)(struct super_block___59 *);
	int (*freeze_fs)(struct super_block___59 *);
	int (*thaw_super)(struct super_block___59 *);
	int (*unfreeze_fs)(struct super_block___59 *);
	int (*statfs)(struct dentry___59 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___59 *, int *, char *);
	void (*umount_begin)(struct super_block___59 *);
	int (*show_options)(struct seq_file___56 *, struct dentry___59 *);
	int (*show_devname)(struct seq_file___56 *, struct dentry___59 *);
	int (*show_path)(struct seq_file___56 *, struct dentry___59 *);
	int (*show_stats)(struct seq_file___56 *, struct dentry___59 *);
	ssize_t (*quota_read)(struct super_block___59 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___59 *, int, const char *, size_t, loff_t);
	struct dquot___58 ** (*get_dquots)(struct inode___60 *);
	int (*bdev_try_to_free_page)(struct super_block___59 *, struct page___59 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___59 *, struct shrink_control___26 *);
	long int (*free_cached_objects)(struct super_block___59 *, struct shrink_control___26 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___37)(struct file___59 *, wait_queue_head_t *, struct poll_table_struct___38 *);

struct poll_table_struct___38 {
	poll_queue_proc___37 _qproc;
	__poll_t _key;
};

struct seq_operations___53;

struct seq_file___56 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___53 *op;
	int poll_event;
	const struct file___59 *file;
	void *private;
};

struct kobj_attribute___56 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___56 *, struct kobj_attribute___56 *, char *);
	ssize_t (*store)(struct kobject___56 *, struct kobj_attribute___56 *, const char *, size_t);
};

typedef void compound_page_dtor___58(struct page___59 *);

struct kernfs_root___56;

struct kernfs_elem_dir___56 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___56 *root;
};

struct kernfs_syscall_ops___56;

struct kernfs_root___56 {
	struct kernfs_node___56 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___56 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___56 {
	struct kernfs_node___56 *target_kn;
};

struct kernfs_ops___56;

struct kernfs_elem_attr___56 {
	const struct kernfs_ops___56 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___56 *notify_next;
};

struct kernfs_node___56 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___56 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___56 dir;
		struct kernfs_elem_symlink___56 symlink;
		struct kernfs_elem_attr___56 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___56;

struct kernfs_ops___56 {
	int (*open)(struct kernfs_open_file___56 *);
	void (*release)(struct kernfs_open_file___56 *);
	int (*seq_show)(struct seq_file___56 *, void *);
	void * (*seq_start)(struct seq_file___56 *, loff_t *);
	void * (*seq_next)(struct seq_file___56 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___56 *, void *);
	ssize_t (*read)(struct kernfs_open_file___56 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___56 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___56 *, struct vm_area_struct___59 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___56 *, struct poll_table_struct___38 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___56 {
	int (*remount_fs)(struct kernfs_root___56 *, int *, char *);
	int (*show_options)(struct seq_file___56 *, struct kernfs_root___56 *);
	int (*mkdir)(struct kernfs_node___56 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___56 *);
	int (*rename)(struct kernfs_node___56 *, struct kernfs_node___56 *, const char *);
	int (*show_path)(struct seq_file___56 *, struct kernfs_node___56 *, struct kernfs_root___56 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___56 {
	struct kernfs_node___56 *kn;
	struct file___59 *file;
	struct seq_file___56 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___58 *vm_ops;
};

struct bin_attribute___53;

struct attribute_group___53 {
	const char *name;
	umode_t (*is_visible)(struct kobject___56 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___56 *, struct bin_attribute___53 *, int);
	struct attribute **attrs;
	struct bin_attribute___53 **bin_attrs;
};

struct bin_attribute___53 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___59 *, struct kobject___56 *, struct bin_attribute___53 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___59 *, struct kobject___56 *, struct bin_attribute___53 *, char *, loff_t, size_t);
	int (*mmap)(struct file___59 *, struct kobject___56 *, struct bin_attribute___53 *, struct vm_area_struct___59 *);
};

struct sysfs_ops___55 {
	ssize_t (*show)(struct kobject___56 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___56 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___55;

struct kset___55 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___56 kobj;
	const struct kset_uevent_ops___55 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___55 {
	void (*release)(struct kobject___56 *);
	const struct sysfs_ops___55 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___56 *);
	const void * (*namespace)(struct kobject___56 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___55 {
	int (* const filter)(struct kset___55 *, struct kobject___56 *);
	const char * (* const name)(struct kset___55 *, struct kobject___56 *);
	int (* const uevent)(struct kset___55 *, struct kobject___56 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___52 {
	int (*prepare)(struct device___52 *);
	void (*complete)(struct device___52 *);
	int (*suspend)(struct device___52 *);
	int (*resume)(struct device___52 *);
	int (*freeze)(struct device___52 *);
	int (*thaw)(struct device___52 *);
	int (*poweroff)(struct device___52 *);
	int (*restore)(struct device___52 *);
	int (*suspend_late)(struct device___52 *);
	int (*resume_early)(struct device___52 *);
	int (*freeze_late)(struct device___52 *);
	int (*thaw_early)(struct device___52 *);
	int (*poweroff_late)(struct device___52 *);
	int (*restore_early)(struct device___52 *);
	int (*suspend_noirq)(struct device___52 *);
	int (*resume_noirq)(struct device___52 *);
	int (*freeze_noirq)(struct device___52 *);
	int (*thaw_noirq)(struct device___52 *);
	int (*poweroff_noirq)(struct device___52 *);
	int (*restore_noirq)(struct device___52 *);
	int (*runtime_suspend)(struct device___52 *);
	int (*runtime_resume)(struct device___52 *);
	int (*runtime_idle)(struct device___52 *);
};

struct dev_pm_domain___52 {
	struct dev_pm_ops___52 ops;
	void (*detach)(struct device___52 *, bool);
	int (*activate)(struct device___52 *);
	void (*sync)(struct device___52 *);
	void (*dismiss)(struct device___52 *);
};

struct bus_type___52 {
	const char *name;
	const char *dev_name;
	struct device___52 *dev_root;
	const struct attribute_group___53 **bus_groups;
	const struct attribute_group___53 **dev_groups;
	const struct attribute_group___53 **drv_groups;
	int (*match)(struct device___52 *, struct device_driver___52 *);
	int (*uevent)(struct device___52 *, struct kobj_uevent_env *);
	int (*probe)(struct device___52 *);
	int (*remove)(struct device___52 *);
	void (*shutdown)(struct device___52 *);
	int (*online)(struct device___52 *);
	int (*offline)(struct device___52 *);
	int (*suspend)(struct device___52 *, pm_message_t);
	int (*resume)(struct device___52 *);
	int (*num_vf)(struct device___52 *);
	int (*dma_configure)(struct device___52 *);
	const struct dev_pm_ops___52 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___52 {
	const char *name;
	struct bus_type___52 *bus;
	struct module___53 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___52 *);
	int (*remove)(struct device___52 *);
	void (*shutdown)(struct device___52 *);
	int (*suspend)(struct device___52 *, pm_message_t);
	int (*resume)(struct device___52 *);
	const struct attribute_group___53 **groups;
	const struct dev_pm_ops___52 *pm;
	void (*coredump)(struct device___52 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___52 {
	const char *name;
	const struct attribute_group___53 **groups;
	int (*uevent)(struct device___52 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___52 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___52 *);
	const struct dev_pm_ops___52 *pm;
};

struct class___52 {
	const char *name;
	struct module___53 *owner;
	const struct attribute_group___53 **class_groups;
	const struct attribute_group___53 **dev_groups;
	struct kobject___56 *dev_kobj;
	int (*dev_uevent)(struct device___52 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___52 *, umode_t *);
	void (*class_release)(struct class___52 *);
	void (*dev_release)(struct device___52 *);
	int (*shutdown_pre)(struct device___52 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___52 *);
	const struct dev_pm_ops___52 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

typedef int (*key_restrict_link_func_t___58)(struct key___59 *, const struct key_type *, const union key_payload *, struct key___59 *);

struct key_restriction___59;

struct key___59 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___59 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___59 *restrict_link;
};

struct key_restriction___59 {
	key_restrict_link_func_t___58 check;
	struct key___59 *key;
	struct key_type *keytype;
};

struct seq_operations___53 {
	void * (*start)(struct seq_file___56 *, loff_t *);
	void (*stop)(struct seq_file___56 *, void *);
	void * (*next)(struct seq_file___56 *, void *, loff_t *);
	int (*show)(struct seq_file___56 *, void *);
};

struct tty_driver___8;

struct tty_operations___8 {
	struct tty_struct___8 * (*lookup)(struct tty_driver___8 *, struct file___59 *, int);
	int (*install)(struct tty_driver___8 *, struct tty_struct___8 *);
	void (*remove)(struct tty_driver___8 *, struct tty_struct___8 *);
	int (*open)(struct tty_struct___8 *, struct file___59 *);
	void (*close)(struct tty_struct___8 *, struct file___59 *);
	void (*shutdown)(struct tty_struct___8 *);
	void (*cleanup)(struct tty_struct___8 *);
	int (*write)(struct tty_struct___8 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___8 *, unsigned char);
	void (*flush_chars)(struct tty_struct___8 *);
	int (*write_room)(struct tty_struct___8 *);
	int (*chars_in_buffer)(struct tty_struct___8 *);
	int (*ioctl)(struct tty_struct___8 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___8 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___8 *, struct ktermios *);
	void (*throttle)(struct tty_struct___8 *);
	void (*unthrottle)(struct tty_struct___8 *);
	void (*stop)(struct tty_struct___8 *);
	void (*start)(struct tty_struct___8 *);
	void (*hangup)(struct tty_struct___8 *);
	int (*break_ctl)(struct tty_struct___8 *, int);
	void (*flush_buffer)(struct tty_struct___8 *);
	void (*set_ldisc)(struct tty_struct___8 *);
	void (*wait_until_sent)(struct tty_struct___8 *, int);
	void (*send_xchar)(struct tty_struct___8 *, char);
	int (*tiocmget)(struct tty_struct___8 *);
	int (*tiocmset)(struct tty_struct___8 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___8 *, struct winsize *);
	int (*set_termiox)(struct tty_struct___8 *, struct termiox *);
	int (*get_icount)(struct tty_struct___8 *, struct serial_icounter_struct *);
	void (*show_fdinfo)(struct tty_struct___8 *, struct seq_file___56 *);
	int (*poll_init)(struct tty_driver___8 *, int, char *);
	int (*poll_get_char)(struct tty_driver___8 *, int);
	void (*poll_put_char)(struct tty_driver___8 *, int, char);
	int (*proc_show)(struct seq_file___56 *, void *);
};

struct tty_ldisc___8;

struct tty_port___8;

struct tty_struct___8 {
	int magic;
	struct kref kref;
	struct device___52 *dev;
	struct tty_driver___8 *driver;
	const struct tty_operations___8 *ops;
	int index;
	struct ld_semaphore ldisc_sem;
	struct tty_ldisc___8 *ldisc;
	struct mutex atomic_write_lock;
	struct mutex legacy_mutex;
	struct mutex throttle_mutex;
	struct rw_semaphore___59 termios_rwsem;
	struct mutex winsize_mutex;
	spinlock_t ctrl_lock;
	spinlock_t flow_lock;
	struct ktermios termios;
	struct ktermios termios_locked;
	struct termiox *termiox;
	char name[64];
	struct pid___51 *pgrp;
	struct pid___51 *session;
	long unsigned int flags;
	int count;
	struct winsize winsize;
	long unsigned int stopped: 1;
	long unsigned int flow_stopped: 1;
	int: 30;
	long unsigned int unused: 62;
	int hw_stopped;
	long unsigned int ctrl_status: 8;
	long unsigned int packet: 1;
	int: 23;
	long unsigned int unused_ctrl: 55;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___8 *link;
	struct fasync_struct___58 *fasync;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	spinlock_t files_lock;
	struct list_head tty_files;
	int closing;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___8 *port;
};

struct tty_driver___8 {
	int magic;
	struct kref kref;
	struct cdev___15 **cdevs;
	struct module___53 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___8 *other;
	struct tty_struct___8 **ttys;
	struct tty_port___8 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___8 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___8;

struct tty_port_client_operations___8;

struct tty_port___8 {
	struct tty_bufhead buf;
	struct tty_struct___8 *tty;
	struct tty_struct___8 *itty;
	const struct tty_port_operations___8 *ops;
	const struct tty_port_client_operations___8 *client_ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	unsigned char low_latency: 1;
	struct mutex mutex;
	struct mutex buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
	void *client_data;
};

struct tty_ldisc_ops___8 {
	int magic;
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___8 *);
	void (*close)(struct tty_struct___8 *);
	void (*flush_buffer)(struct tty_struct___8 *);
	ssize_t (*read)(struct tty_struct___8 *, struct file___59 *, unsigned char *, size_t);
	ssize_t (*write)(struct tty_struct___8 *, struct file___59 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___8 *, struct file___59 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___8 *, struct file___59 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___8 *, struct ktermios *);
	__poll_t (*poll)(struct tty_struct___8 *, struct file___59 *, struct poll_table_struct___38 *);
	int (*hangup)(struct tty_struct___8 *);
	void (*receive_buf)(struct tty_struct___8 *, const unsigned char *, char *, int);
	void (*write_wakeup)(struct tty_struct___8 *);
	void (*dcd_change)(struct tty_struct___8 *, unsigned int);
	int (*receive_buf2)(struct tty_struct___8 *, const unsigned char *, char *, int);
	struct module___53 *owner;
	int refcount;
};

struct tty_ldisc___8 {
	struct tty_ldisc_ops___8 *ops;
	struct tty_struct___8 *tty;
};

struct tty_port_operations___8 {
	int (*carrier_raised)(struct tty_port___8 *);
	void (*dtr_rts)(struct tty_port___8 *, int);
	void (*shutdown)(struct tty_port___8 *);
	int (*activate)(struct tty_port___8 *, struct tty_struct___8 *);
	void (*destruct)(struct tty_port___8 *);
};

struct tty_port_client_operations___8 {
	int (*receive_buf)(struct tty_port___8 *, const unsigned char *, const unsigned char *, size_t);
	void (*write_wakeup)(struct tty_port___8 *);
};

struct consw___8 {
	struct module___53 *owner;
	const char * (*con_startup)();
	void (*con_init)(struct vc_data *, int);
	void (*con_deinit)(struct vc_data *);
	void (*con_clear)(struct vc_data *, int, int, int, int);
	void (*con_putc)(struct vc_data *, int, int, int);
	void (*con_putcs)(struct vc_data *, const short unsigned int *, int, int, int);
	void (*con_cursor)(struct vc_data *, int);
	bool (*con_scroll)(struct vc_data *, unsigned int, unsigned int, enum con_scroll, unsigned int);
	int (*con_switch)(struct vc_data *);
	int (*con_blank)(struct vc_data *, int, int);
	int (*con_font_set)(struct vc_data *, struct console_font *, unsigned int);
	int (*con_font_get)(struct vc_data *, struct console_font *);
	int (*con_font_default)(struct vc_data *, struct console_font *, char *);
	int (*con_font_copy)(struct vc_data *, int);
	int (*con_resize)(struct vc_data *, unsigned int, unsigned int, unsigned int);
	void (*con_set_palette)(struct vc_data *, const unsigned char *);
	void (*con_scrolldelta)(struct vc_data *, int);
	int (*con_set_origin)(struct vc_data *);
	void (*con_save_screen)(struct vc_data *);
	u8 (*con_build_attr)(struct vc_data *, u8, u8, u8, u8, u8, u8);
	void (*con_invert_region)(struct vc_data *, u16 *, int);
	u16 * (*con_screen_pos)(struct vc_data *, int);
	long unsigned int (*con_getxy)(struct vc_data *, long unsigned int, int *, int *);
	void (*con_flush_scrollback)(struct vc_data *);
	int (*con_debug_enter)(struct vc_data *);
	int (*con_debug_leave)(struct vc_data *);
};

struct console___3 {
	char name[16];
	void (*write)(struct console___3 *, const char *, unsigned int);
	int (*read)(struct console___3 *, char *, unsigned int);
	struct tty_driver___8 * (*device)(struct console___3 *, int *);
	void (*unblank)();
	int (*setup)(struct console___3 *, char *);
	int (*match)(struct console___3 *, char *, int, char *);
	short int flags;
	short int index;
	int cflag;
	void *data;
	struct console___3 *next;
};

struct kernel_param_ops___50 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___50 *);
	int (*get)(char *, const struct kernel_param___50 *);
	void (*free)(void *);
};

struct kparam_array___50;

struct kernel_param___50 {
	const char *name;
	struct module___53 *mod;
	const struct kernel_param_ops___50 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___50 *arr;
	};
};

struct kparam_array___50 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___50 *ops;
	void *elem;
};

struct module_attribute___50 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___50 *, struct module_kobject___50 *, char *);
	ssize_t (*store)(struct module_attribute___50 *, struct module_kobject___50 *, const char *, size_t);
	void (*setup)(struct module___53 *, const char *);
	int (*test)(struct module___53 *);
	void (*free)(struct module___53 *);
};

struct trace_event_class___32;

struct trace_event_call___32 {
	struct list_head list;
	struct trace_event_class___32 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array *prog_array;
	int (*perf_perm)(struct trace_event_call___32 *, struct perf_event___37 *);
};

typedef struct poll_table_struct___38 poll_table___3;

struct cgroup_namespace___47 {
	refcount_t count;
	struct ns_common ns;
	struct user_namespace___49 *user_ns;
	struct ucounts___49 *ucounts;
	struct css_set___47 *root_cset;
};

struct ucounts___49 {
	struct hlist_node node;
	struct user_namespace___49 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct node___49 {
	struct device___52 dev;
};

struct bpf_map___47;

struct bpf_map_ops___47 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___47 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___47 *, struct file___59 *);
	void (*map_free)(struct bpf_map___47 *);
	int (*map_get_next_key)(struct bpf_map___47 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___47 *);
	void * (*map_lookup_elem)(struct bpf_map___47 *, void *);
	int (*map_update_elem)(struct bpf_map___47 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___47 *, void *);
	int (*map_push_elem)(struct bpf_map___47 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___47 *, void *);
	int (*map_peek_elem)(struct bpf_map___47 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___47 *, struct file___59 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___47 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___47 *, void *, struct seq_file___56 *);
	int (*map_check_btf)(const struct bpf_map___47 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___47 {
	const struct bpf_map_ops___47 *ops;
	struct bpf_map___47 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___58 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___47;

typedef void (*kthread_work_func_t___47)(struct kthread_work___47 *);

struct kthread_worker___47;

struct kthread_work___47 {
	struct list_head node;
	kthread_work_func_t___47 func;
	struct kthread_worker___47 *worker;
	int canceling;
};

struct kthread_worker___47 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___59 *task;
	struct kthread_work___47 *current_work;
};

struct kthread_delayed_work___47 {
	struct kthread_work___47 work;
	struct timer_list timer;
};

struct psi_group___47 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___47 *poll_kworker;
	struct kthread_delayed_work___47 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___47 {
	struct kernfs_node___56 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___47;

struct cgroup_subsys_state___47 {
	struct cgroup___47 *cgroup;
	struct cgroup_subsys___47 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___47 *parent;
};

struct cgroup_root___47;

struct cgroup_rstat_cpu___47;

struct cgroup___47 {
	struct cgroup_subsys_state___47 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___56 *kn;
	struct cgroup_file___47 procs_file;
	struct cgroup_file___47 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___47 *subsys[13];
	struct cgroup_root___47 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___47 *dom_cgrp;
	struct cgroup_rstat_cpu___47 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf bpf;
	atomic_t congestion_count;
	struct cgroup___47 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___47 psi;
	int ancestor_ids[0];
};

struct cftype___47;

struct cgroup_subsys___47 {
	struct cgroup_subsys_state___47 * (*css_alloc)(struct cgroup_subsys_state___47 *);
	int (*css_online)(struct cgroup_subsys_state___47 *);
	void (*css_offline)(struct cgroup_subsys_state___47 *);
	void (*css_released)(struct cgroup_subsys_state___47 *);
	void (*css_free)(struct cgroup_subsys_state___47 *);
	void (*css_reset)(struct cgroup_subsys_state___47 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___47 *, int);
	int (*css_extra_stat_show)(struct seq_file___56 *, struct cgroup_subsys_state___47 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___59 *);
	void (*cancel_fork)(struct task_struct___59 *);
	void (*fork)(struct task_struct___59 *);
	void (*exit)(struct task_struct___59 *);
	void (*free)(struct task_struct___59 *);
	void (*bind)(struct cgroup_subsys_state___47 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___47 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___47 *dfl_cftypes;
	struct cftype___47 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___47 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___47 *updated_children;
	struct cgroup___47 *updated_next;
};

struct cgroup_root___47 {
	struct kernfs_root___56 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___47 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___47 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___47 *ss;
	struct list_head node;
	struct kernfs_ops___56 *kf_ops;
	int (*open)(struct kernfs_open_file___56 *);
	void (*release)(struct kernfs_open_file___56 *);
	u64 (*read_u64)(struct cgroup_subsys_state___47 *, struct cftype___47 *);
	s64 (*read_s64)(struct cgroup_subsys_state___47 *, struct cftype___47 *);
	int (*seq_show)(struct seq_file___56 *, void *);
	void * (*seq_start)(struct seq_file___56 *, loff_t *);
	void * (*seq_next)(struct seq_file___56 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___56 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___47 *, struct cftype___47 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___47 *, struct cftype___47 *, s64);
	ssize_t (*write)(struct kernfs_open_file___56 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___56 *, struct poll_table_struct___38 *);
};

struct perf_cpu_context___37;

struct pmu___37 {
	struct list_head entry;
	struct module___53 *module;
	struct device___52 *dev;
	const struct attribute_group___53 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___37 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___37 *);
	void (*pmu_disable)(struct pmu___37 *);
	int (*event_init)(struct perf_event___37 *);
	void (*event_mapped)(struct perf_event___37 *, struct mm_struct___58 *);
	void (*event_unmapped)(struct perf_event___37 *, struct mm_struct___58 *);
	int (*add)(struct perf_event___37 *, int);
	void (*del)(struct perf_event___37 *, int);
	void (*start)(struct perf_event___37 *, int);
	void (*stop)(struct perf_event___37 *, int);
	void (*read)(struct perf_event___37 *);
	void (*start_txn)(struct pmu___37 *, unsigned int);
	int (*commit_txn)(struct pmu___37 *);
	void (*cancel_txn)(struct pmu___37 *);
	int (*event_idx)(struct perf_event___37 *);
	void (*sched_task)(struct perf_event_context___37 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___37 *);
	int (*filter_match)(struct perf_event___37 *);
	int (*check_period)(struct perf_event___37 *, u64);
};

struct perf_cpu_context___37 {
	struct perf_event_context___37 ctx;
	struct perf_event_context___37 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___37 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___37 {
	struct cgroup_subsys_state___47 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___32 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___32 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___32 *);
	struct list_head * (*get_fields)(struct trace_event_call___32 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___32 *);
};

struct trace_event_file___11;

struct trace_event_buffer___11 {
	struct ring_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___11 *trace_file;
	void *entry;
	long unsigned int flags;
	int pc;
};

struct trace_event_file___11 {
	struct list_head list;
	struct trace_event_call___32 *event_call;
	struct event_filter *filter;
	struct dentry___59 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct syscall_metadata___14 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___32 *enter_event;
	struct trace_event_call___32 *exit_event;
};

enum kdb_msgsrc {
	KDB_MSGSRC_INTERNAL = 0,
	KDB_MSGSRC_PRINTK = 1,
};

struct kmsg_dumper {
	struct list_head list;
	void (*dump)(struct kmsg_dumper *, enum kmsg_dump_reason);
	enum kmsg_dump_reason max_reason;
	bool active;
	bool registered;
	u32 cur_idx;
	u32 next_idx;
	u64 cur_seq;
	u64 next_seq;
};

struct trace_event_raw_console {
	struct trace_entry ent;
	u32 __data_loc_msg;
	char __data[0];
};

struct trace_event_data_offsets_console {
	u32 msg;
};

struct console_cmdline {
	char name[16];
	int index;
	char *options;
};

enum devkmsg_log_bits {
	__DEVKMSG_LOG_BIT_ON = 0,
	__DEVKMSG_LOG_BIT_OFF = 1,
	__DEVKMSG_LOG_BIT_LOCK = 2,
};

enum devkmsg_log_masks {
	DEVKMSG_LOG_MASK_ON = 1,
	DEVKMSG_LOG_MASK_OFF = 2,
	DEVKMSG_LOG_MASK_LOCK = 4,
};

enum con_msg_format_flags {
	MSG_FORMAT_DEFAULT = 0,
	MSG_FORMAT_SYSLOG = 1,
};

enum log_flags {
	LOG_NOCONS = 1,
	LOG_NEWLINE = 2,
	LOG_PREFIX = 4,
	LOG_CONT = 8,
};

struct printk_log {
	u64 ts_nsec;
	u16 len;
	u16 text_len;
	u16 dict_len;
	u8 facility;
	u8 flags: 5;
	u8 level: 3;
};

struct devkmsg_user {
	u64 seq;
	u32 idx;
	struct ratelimit_state rs;
	struct mutex lock;
	char buf[8192];
};

struct cont {
	char buf[992];
	size_t len;
	struct task_struct___59 *owner;
	u64 ts_nsec;
	u8 level;
	u8 facility;
	enum log_flags flags;
};

struct printk_safe_seq_buf {
	atomic_t len;
	atomic_t message_lost;
	struct irq_work work;
	unsigned char buffer[8160];
};

enum {
	_IRQ_DEFAULT_INIT_FLAGS = 0,
	_IRQ_PER_CPU = 512,
	_IRQ_LEVEL = 256,
	_IRQ_NOPROBE = 1024,
	_IRQ_NOREQUEST = 2048,
	_IRQ_NOTHREAD = 65536,
	_IRQ_NOAUTOEN = 4096,
	_IRQ_MOVE_PCNTXT = 16384,
	_IRQ_NO_BALANCING = 8192,
	_IRQ_NESTED_THREAD = 32768,
	_IRQ_PER_CPU_DEVID = 131072,
	_IRQ_IS_POLLED = 262144,
	_IRQ_DISABLE_UNLAZY = 524288,
	_IRQF_MODIFY_MASK = 1048335,
};

enum {
	IRQTF_RUNTHREAD = 0,
	IRQTF_WARNED = 1,
	IRQTF_AFFINITY = 2,
	IRQTF_FORCED_THREAD = 3,
};

enum {
	IRQS_AUTODETECT = 1,
	IRQS_SPURIOUS_DISABLED = 2,
	IRQS_POLL_INPROGRESS = 8,
	IRQS_ONESHOT = 32,
	IRQS_REPLAY = 64,
	IRQS_WAITING = 128,
	IRQS_PENDING = 512,
	IRQS_SUSPENDED = 2048,
	IRQS_TIMINGS = 4096,
};

struct irq_desc___5;

typedef void (*irq_flow_handler_t___5)(struct irq_desc___5 *);

struct irq_desc___5 {
	struct irq_common_data irq_common_data;
	struct irq_data irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___5 handle_irq;
	struct irqaction___2 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int irq_count;
	unsigned int tot_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___7 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___10 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

enum {
	IRQ_SET_MASK_OK = 0,
	IRQ_SET_MASK_OK_NOCOPY = 1,
	IRQ_SET_MASK_OK_DONE = 2,
};

enum {
	IRQCHIP_SET_TYPE_MASKED = 1,
	IRQCHIP_EOI_IF_HANDLED = 2,
	IRQCHIP_MASK_ON_SUSPEND = 4,
	IRQCHIP_ONOFFLINE_ENABLED = 8,
	IRQCHIP_SKIP_SET_WAKE = 16,
	IRQCHIP_ONESHOT_SAFE = 32,
	IRQCHIP_EOI_THREADED = 64,
	IRQCHIP_SUPPORTS_LEVEL_MSI = 128,
};

enum {
	IRQC_IS_HARDIRQ = 0,
	IRQC_IS_NESTED = 1,
};

struct irq_desc___6;

typedef void (*irq_flow_handler_t___6)(struct irq_desc___6 *);

struct msi_desc___5;

struct irq_common_data___4 {
	unsigned int state_use_accessors;
	unsigned int node;
	void *handler_data;
	struct msi_desc___5 *msi_desc;
	cpumask_var_t affinity;
	cpumask_var_t effective_affinity;
};

struct irq_chip___9;

struct irq_domain___4;

struct irq_data___10 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___4 *common;
	struct irq_chip___9 *chip;
	struct irq_domain___4 *domain;
	struct irq_data___10 *parent_data;
	void *chip_data;
};

struct irq_desc___6 {
	struct irq_common_data___4 irq_common_data;
	struct irq_data___10 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___6 handle_irq;
	struct irqaction___2 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int irq_count;
	unsigned int tot_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___54 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___10 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_operations___39;

struct fwnode_handle___39 {
	struct fwnode_handle___39 *secondary;
	const struct fwnode_operations___39 *ops;
};

struct device___53;

struct fwnode_reference_args___39;

struct fwnode_endpoint___39;

struct fwnode_operations___39 {
	struct fwnode_handle___39 * (*get)(struct fwnode_handle___39 *);
	void (*put)(struct fwnode_handle___39 *);
	bool (*device_is_available)(const struct fwnode_handle___39 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___39 *, const struct device___53 *);
	bool (*property_present)(const struct fwnode_handle___39 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___39 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___39 *, const char *, const char **, size_t);
	struct fwnode_handle___39 * (*get_parent)(const struct fwnode_handle___39 *);
	struct fwnode_handle___39 * (*get_next_child_node)(const struct fwnode_handle___39 *, struct fwnode_handle___39 *);
	struct fwnode_handle___39 * (*get_named_child_node)(const struct fwnode_handle___39 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___39 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___39 *);
	struct fwnode_handle___39 * (*graph_get_next_endpoint)(const struct fwnode_handle___39 *, struct fwnode_handle___39 *);
	struct fwnode_handle___39 * (*graph_get_remote_endpoint)(const struct fwnode_handle___39 *);
	struct fwnode_handle___39 * (*graph_get_port_parent)(struct fwnode_handle___39 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___39 *, struct fwnode_endpoint___39 *);
};

struct fwnode_endpoint___39 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___39 *local_fwnode;
};

struct fwnode_reference_args___39 {
	struct fwnode_handle___39 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct dev_pm_info___53 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___53 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___53;

struct bus_type___53;

struct device_driver___53;

struct dev_pm_domain___53;

struct device_node___17;

struct class___53;

struct device___53 {
	struct device___53 *parent;
	struct device_private *p;
	struct kobject___54 kobj;
	const char *init_name;
	const struct device_type___53 *type;
	struct mutex mutex;
	struct bus_type___53 *bus;
	struct device_driver___53 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___53 power;
	struct dev_pm_domain___53 *pm_domain;
	struct irq_domain___4 *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___17 *of_node;
	struct fwnode_handle___39 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___53 *class;
	const struct attribute_group___51 **groups;
	void (*release)(struct device___53 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct msi_desc___5 {
	struct list_head list;
	unsigned int irq;
	unsigned int nvec_used;
	struct device___53 *dev;
	struct msi_msg msg;
	struct irq_affinity_desc *affinity;
	const void *iommu_cookie;
	union {
		struct {
			u32 masked;
			struct {
				u8 is_msix: 1;
				u8 multiple: 3;
				u8 multi_cap: 3;
				u8 maskbit: 1;
				u8 is_64: 1;
				u16 entry_nr;
				unsigned int default_irq;
			} msi_attrib;
			union {
				u8 mask_pos;
				void *mask_base;
			};
		};
		struct platform_msi_desc platform;
		struct fsl_mc_msi_desc fsl_mc;
	};
};

struct irq_chip___9 {
	struct device___53 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___10 *);
	void (*irq_shutdown)(struct irq_data___10 *);
	void (*irq_enable)(struct irq_data___10 *);
	void (*irq_disable)(struct irq_data___10 *);
	void (*irq_ack)(struct irq_data___10 *);
	void (*irq_mask)(struct irq_data___10 *);
	void (*irq_mask_ack)(struct irq_data___10 *);
	void (*irq_unmask)(struct irq_data___10 *);
	void (*irq_eoi)(struct irq_data___10 *);
	int (*irq_set_affinity)(struct irq_data___10 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___10 *);
	int (*irq_set_type)(struct irq_data___10 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___10 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___10 *);
	void (*irq_bus_sync_unlock)(struct irq_data___10 *);
	void (*irq_cpu_online)(struct irq_data___10 *);
	void (*irq_cpu_offline)(struct irq_data___10 *);
	void (*irq_suspend)(struct irq_data___10 *);
	void (*irq_resume)(struct irq_data___10 *);
	void (*irq_pm_shutdown)(struct irq_data___10 *);
	void (*irq_calc_mask)(struct irq_data___10 *);
	void (*irq_print_chip)(struct irq_data___10 *, struct seq_file___9 *);
	int (*irq_request_resources)(struct irq_data___10 *);
	void (*irq_release_resources)(struct irq_data___10 *);
	void (*irq_compose_msi_msg)(struct irq_data___10 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___10 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___10 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___10 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___10 *, void *);
	void (*ipi_send_single)(struct irq_data___10 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___10 *, const struct cpumask *);
	long unsigned int flags;
};

struct irq_domain_ops___4;

struct irq_domain_chip_generic___4;

struct irq_domain___4 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___4 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___39 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___4 *gc;
	struct irq_domain___4 *parent;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_direct_max_irq;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_tree_mutex;
	unsigned int linear_revmap[0];
};

struct irq_chip_type___3 {
	struct irq_chip___9 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___6 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___3 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___3 *);
	void (*resume)(struct irq_chip_generic___3 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___4 *domain;
	struct list_head list;
	struct irq_chip_type___3 chip_types[0];
};

struct irq_domain_chip_generic___4 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___3 *gc[0];
};

struct device_node___17 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___39 fwnode;
	struct property___7 *properties;
	struct property___7 *deadprops;
	struct device_node___17 *parent;
	struct device_node___17 *child;
	struct device_node___17 *sibling;
	struct kobject___54 kobj;
	long unsigned int _flags;
	void *data;
};

struct irq_fwspec___4 {
	struct fwnode_handle___39 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___4 {
	int (*match)(struct irq_domain___4 *, struct device_node___17 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___4 *, struct irq_fwspec___4 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___4 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___4 *, unsigned int);
	int (*xlate)(struct irq_domain___4 *, struct device_node___17 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___4 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___4 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___4 *, struct irq_data___10 *, bool);
	void (*deactivate)(struct irq_domain___4 *, struct irq_data___10 *);
	int (*translate)(struct irq_domain___4 *, struct irq_fwspec___4 *, long unsigned int *, unsigned int *);
};

struct dev_pm_ops___53 {
	int (*prepare)(struct device___53 *);
	void (*complete)(struct device___53 *);
	int (*suspend)(struct device___53 *);
	int (*resume)(struct device___53 *);
	int (*freeze)(struct device___53 *);
	int (*thaw)(struct device___53 *);
	int (*poweroff)(struct device___53 *);
	int (*restore)(struct device___53 *);
	int (*suspend_late)(struct device___53 *);
	int (*resume_early)(struct device___53 *);
	int (*freeze_late)(struct device___53 *);
	int (*thaw_early)(struct device___53 *);
	int (*poweroff_late)(struct device___53 *);
	int (*restore_early)(struct device___53 *);
	int (*suspend_noirq)(struct device___53 *);
	int (*resume_noirq)(struct device___53 *);
	int (*freeze_noirq)(struct device___53 *);
	int (*thaw_noirq)(struct device___53 *);
	int (*poweroff_noirq)(struct device___53 *);
	int (*restore_noirq)(struct device___53 *);
	int (*runtime_suspend)(struct device___53 *);
	int (*runtime_resume)(struct device___53 *);
	int (*runtime_idle)(struct device___53 *);
};

struct dev_pm_domain___53 {
	struct dev_pm_ops___53 ops;
	void (*detach)(struct device___53 *, bool);
	int (*activate)(struct device___53 *);
	void (*sync)(struct device___53 *);
	void (*dismiss)(struct device___53 *);
};

struct bus_type___53 {
	const char *name;
	const char *dev_name;
	struct device___53 *dev_root;
	const struct attribute_group___51 **bus_groups;
	const struct attribute_group___51 **dev_groups;
	const struct attribute_group___51 **drv_groups;
	int (*match)(struct device___53 *, struct device_driver___53 *);
	int (*uevent)(struct device___53 *, struct kobj_uevent_env *);
	int (*probe)(struct device___53 *);
	int (*remove)(struct device___53 *);
	void (*shutdown)(struct device___53 *);
	int (*online)(struct device___53 *);
	int (*offline)(struct device___53 *);
	int (*suspend)(struct device___53 *, pm_message_t);
	int (*resume)(struct device___53 *);
	int (*num_vf)(struct device___53 *);
	int (*dma_configure)(struct device___53 *);
	const struct dev_pm_ops___53 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___53 {
	const char *name;
	struct bus_type___53 *bus;
	struct module___10 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___53 *);
	int (*remove)(struct device___53 *);
	void (*shutdown)(struct device___53 *);
	int (*suspend)(struct device___53 *, pm_message_t);
	int (*resume)(struct device___53 *);
	const struct attribute_group___51 **groups;
	const struct dev_pm_ops___53 *pm;
	void (*coredump)(struct device___53 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___53 {
	const char *name;
	const struct attribute_group___51 **groups;
	int (*uevent)(struct device___53 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___53 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___53 *);
	const struct dev_pm_ops___53 *pm;
};

struct class___53 {
	const char *name;
	struct module___10 *owner;
	const struct attribute_group___51 **class_groups;
	const struct attribute_group___51 **dev_groups;
	struct kobject___54 *dev_kobj;
	int (*dev_uevent)(struct device___53 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___53 *, umode_t *);
	void (*class_release)(struct class___53 *);
	void (*dev_release)(struct device___53 *);
	int (*shutdown_pre)(struct device___53 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___53 *);
	const struct dev_pm_ops___53 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

enum {
	IRQ_STARTUP_NORMAL = 0,
	IRQ_STARTUP_MANAGED = 1,
	IRQ_STARTUP_ABORT = 2,
};

struct irqaction___6 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___6 *next;
	irq_handler_t thread_fn;
	struct task_struct *thread;
	struct irqaction___6 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef void (*dr_release_t___3)(struct device *, void *);

struct irq_desc___7;

typedef void (*irq_flow_handler_t___7)(struct irq_desc___7 *);

struct irq_chip___10;

struct irq_data___11 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___4 *common;
	struct irq_chip___10 *chip;
	struct irq_domain *domain;
	struct irq_data___11 *parent_data;
	void *chip_data;
};

struct irq_desc___7 {
	struct irq_common_data___4 irq_common_data;
	struct irq_data___11 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___7 handle_irq;
	struct irqaction___6 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int irq_count;
	unsigned int tot_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip___10 {
	struct device *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___11 *);
	void (*irq_shutdown)(struct irq_data___11 *);
	void (*irq_enable)(struct irq_data___11 *);
	void (*irq_disable)(struct irq_data___11 *);
	void (*irq_ack)(struct irq_data___11 *);
	void (*irq_mask)(struct irq_data___11 *);
	void (*irq_mask_ack)(struct irq_data___11 *);
	void (*irq_unmask)(struct irq_data___11 *);
	void (*irq_eoi)(struct irq_data___11 *);
	int (*irq_set_affinity)(struct irq_data___11 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___11 *);
	int (*irq_set_type)(struct irq_data___11 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___11 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___11 *);
	void (*irq_bus_sync_unlock)(struct irq_data___11 *);
	void (*irq_cpu_online)(struct irq_data___11 *);
	void (*irq_cpu_offline)(struct irq_data___11 *);
	void (*irq_suspend)(struct irq_data___11 *);
	void (*irq_resume)(struct irq_data___11 *);
	void (*irq_pm_shutdown)(struct irq_data___11 *);
	void (*irq_calc_mask)(struct irq_data___11 *);
	void (*irq_print_chip)(struct irq_data___11 *, struct seq_file___9 *);
	int (*irq_request_resources)(struct irq_data___11 *);
	void (*irq_release_resources)(struct irq_data___11 *);
	void (*irq_compose_msi_msg)(struct irq_data___11 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___11 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___11 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___11 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___11 *, void *);
	void (*ipi_send_single)(struct irq_data___11 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___11 *, const struct cpumask *);
	long unsigned int flags;
};

struct irq_chip_type___4 {
	struct irq_chip___10 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___7 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___4 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___4 *);
	void (*resume)(struct irq_chip_generic___4 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain *domain;
	struct list_head list;
	struct irq_chip_type___4 chip_types[0];
};

struct irq_devres {
	unsigned int irq;
	void *dev_id;
};

struct irq_desc_devres {
	unsigned int from;
	unsigned int cnt;
};

struct irq_generic_chip_devres {
	struct irq_chip_generic___4 *gc;
	u32 msk;
	unsigned int clr;
	unsigned int set;
};

typedef u64 acpi_size;

struct acpi_buffer {
	acpi_size length;
	void *pointer;
};

enum {
	IRQ_DOMAIN_FLAG_HIERARCHY = 1,
	IRQ_DOMAIN_NAME_ALLOCATED = 64,
	IRQ_DOMAIN_FLAG_IPI_PER_CPU = 4,
	IRQ_DOMAIN_FLAG_IPI_SINGLE = 8,
	IRQ_DOMAIN_FLAG_MSI = 16,
	IRQ_DOMAIN_FLAG_MSI_REMAP = 32,
	IRQ_DOMAIN_FLAG_NONCORE = 65536,
};

enum {
	IRQCHIP_FWNODE_REAL = 0,
	IRQCHIP_FWNODE_NAMED = 1,
	IRQCHIP_FWNODE_NAMED_ID = 2,
};

struct irqchip_fwid {
	struct fwnode_handle___12 fwnode;
	unsigned int type;
	char *name;
	void *data;
};

enum {
	AFFINITY = 0,
	AFFINITY_LIST = 1,
	EFFECTIVE = 2,
	EFFECTIVE_LIST = 3,
};

struct module___54;

struct file___60;

struct kiocb___60;

struct vm_area_struct___60;

struct inode___61;

struct file_lock___60;

struct page___60;

struct seq_file___57;

struct file_operations___60 {
	struct module___54 *owner;
	loff_t (*llseek)(struct file___60 *, loff_t, int);
	ssize_t (*read)(struct file___60 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___60 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___60 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___60 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___60 *, bool);
	int (*iterate)(struct file___60 *, struct dir_context *);
	int (*iterate_shared)(struct file___60 *, struct dir_context *);
	__poll_t (*poll)(struct file___60 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___60 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___60 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___60 *, struct vm_area_struct___60 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___61 *, struct file___60 *);
	int (*flush)(struct file___60 *, fl_owner_t);
	int (*release)(struct inode___61 *, struct file___60 *);
	int (*fsync)(struct file___60 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___60 *, int);
	int (*lock)(struct file___60 *, int, struct file_lock___60 *);
	ssize_t (*sendpage)(struct file___60 *, struct page___60 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___60 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___60 *, int, struct file_lock___60 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___60 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___60 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___60 *, long int, struct file_lock___60 **, void **);
	long int (*fallocate)(struct file___60 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___57 *, struct file___60 *);
	ssize_t (*copy_file_range)(struct file___60 *, loff_t, struct file___60 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___60 *, loff_t, struct file___60 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___60 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___59 {
	u64 seqnum;
	struct vm_area_struct___60 *vmas[4];
};

struct page_frag___59 {
	struct page___60 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___59;

struct mem_cgroup___27;

struct cred___59;

struct nsproxy___58;

struct bio_list___28;

struct backing_dev_info___28;

struct css_set___48;

struct vm_struct___43;

struct task_struct___60 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___60 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___59 *mm;
	struct mm_struct___59 *active_mm;
	struct vmacache___59 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___60 *real_parent;
	struct task_struct___60 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___60 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___27 *active_memcg;
	long int rh_reserved2;
	struct pid___51 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___51 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___51 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___59 *ptracer_cred;
	const struct cred___59 *real_cred;
	const struct cred___59 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___58 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___60 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___28 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___28 *backing_dev_info;
	struct io_context___13 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___48 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___59 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___27 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___60 *oom_reaper_list;
	struct vm_struct___43 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___37 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_desc___8;

typedef void (*irq_flow_handler_t___8)(struct irq_desc___8 *);

struct irq_chip___11;

struct irq_data___12 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___4 *common;
	struct irq_chip___11 *chip;
	struct irq_domain *domain;
	struct irq_data___12 *parent_data;
	void *chip_data;
};

struct kset___56;

struct kobj_type___56;

struct kernfs_node___57;

struct kobject___57 {
	const char *name;
	struct list_head entry;
	struct kobject___57 *parent;
	struct kset___56 *kset;
	struct kobj_type___56 *ktype;
	struct kernfs_node___57 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct irqaction___7;

struct irq_desc___8 {
	struct irq_common_data___4 irq_common_data;
	struct irq_data___12 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___8 handle_irq;
	struct irqaction___7 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int irq_count;
	unsigned int tot_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___57 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___54 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___60 *pgtable_t___59;

struct address_space___59;

struct dev_pagemap___59;

struct page___60 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___59 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___60 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___59 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___59 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___59 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___27 *mem_cgroup;
};

struct pglist_data___59;

struct lruvec___59 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___59 *pgdat;
};

struct zone___59 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___59 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___59 {
	struct zone___59 *zone;
	int zone_idx;
};

struct zonelist___59 {
	struct zoneref___59 _zonerefs[25];
};

struct pglist_data___59 {
	struct zone___59 node_zones[3];
	struct zonelist___59 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___60 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___60 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___59 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___60 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___60 *owner;
};

struct secondary_data___60 {
	void *stack;
	struct task_struct___60 *task;
	long int status;
};

struct blocking_notifier_head___59 {
	struct rw_semaphore___60 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___59;

struct vm_area_struct___60 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___60 *vm_next;
	struct vm_area_struct___60 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___59 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___59 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___60 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___59;

struct user_namespace___50;

struct mm_struct___59 {
	struct {
		struct vm_area_struct___60 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___60 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___60 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___59 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___60 *owner;
		struct user_namespace___50 *user_ns;
		struct file___60 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___59 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___59;

struct address_space___59 {
	struct inode___61 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___60 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___59 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___59)(struct vm_area_struct___60 *, long unsigned int, const struct page___60 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___59)(struct page___60 *, void *);

struct device___54;

struct dev_pagemap___59 {
	dev_page_fault_t___59 page_fault;
	dev_page_free_t___59 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___54 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct cgroup___48;

struct cgroup_subsys___48;

struct cgroup_subsys_state___48 {
	struct cgroup___48 *cgroup;
	struct cgroup_subsys___48 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___48 *parent;
};

struct cgroup_file___48 {
	struct kernfs_node___57 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___27;

struct mem_cgroup___27 {
	struct cgroup_subsys_state___48 css;
	struct mem_cgroup_id___2 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___48 events_file;
	struct cgroup_file___48 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___60 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___27 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry___60;

struct path___59 {
	struct vfsmount *mnt;
	struct dentry___60 *dentry;
};

struct file___60 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___59 f_path;
	struct inode___61 *f_inode;
	const struct file_operations___60 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___51 f_owner;
	const struct cred___59 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___59 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___59;

struct vm_operations_struct___59 {
	void (*open)(struct vm_area_struct___60 *);
	void (*close)(struct vm_area_struct___60 *);
	int (*split)(struct vm_area_struct___60 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___60 *);
	vm_fault_t (*fault)(struct vm_fault___59 *);
	vm_fault_t (*huge_fault)(struct vm_fault___59 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___59 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___60 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___59 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___59 *);
	int (*access)(struct vm_area_struct___60 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___60 *);
	int (*set_policy)(struct vm_area_struct___60 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___60 *, long unsigned int);
	struct page___60 * (*find_special_page)(struct vm_area_struct___60 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___59 {
	struct task_struct___60 *task;
	struct core_thread___59 *next;
};

struct core_state___59 {
	atomic_t nr_threads;
	struct core_thread___59 dumper;
	struct completion startup;
};

struct key___60;

struct ucounts___50;

struct user_namespace___50 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___50 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common ns;
	long unsigned int flags;
	struct key___60 *persistent_keyring_register;
	struct rw_semaphore___60 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___50 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___59 {
	struct vm_area_struct___60 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___60 *cow_page;
	struct mem_cgroup___27 *memcg;
	struct page___60 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___59 prealloc_pte;
};

struct user_struct___59 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___60 *uid_keyring;
	struct key___60 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___59 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___60 *session_keyring;
	struct key___60 *process_keyring;
	struct key___60 *thread_keyring;
	struct key___60 *request_key_auth;
	void *security;
	struct user_struct___59 *user;
	struct user_namespace___50 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___48;

struct nsproxy___58 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___48 *cgroup_ns;
};

struct bio___28;

struct bio_list___28 {
	struct bio___28 *head;
	struct bio___28 *tail;
};

struct bdi_writeback_congested___28;

struct bdi_writeback___28 {
	struct backing_dev_info___28 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___28 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___48 *memcg_css;
	struct cgroup_subsys_state___48 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___28 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___28 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___54 *dev;
	struct device___54 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___60 *debug_dir;
	struct dentry___60 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___48 {
	struct cgroup_subsys_state___48 *subsys[13];
	refcount_t refcount;
	struct css_set___48 *dom_cset;
	struct cgroup___48 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___48 *mg_src_cgrp;
	struct cgroup___48 *mg_dst_cgrp;
	struct css_set___48 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct vm_struct___43 {
	struct vm_struct___43 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___60 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct fwnode_operations___40;

struct fwnode_handle___40 {
	struct fwnode_handle___40 *secondary;
	const struct fwnode_operations___40 *ops;
};

struct fwnode_reference_args___40;

struct fwnode_endpoint___40;

struct fwnode_operations___40 {
	struct fwnode_handle___40 * (*get)(struct fwnode_handle___40 *);
	void (*put)(struct fwnode_handle___40 *);
	bool (*device_is_available)(const struct fwnode_handle___40 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___40 *, const struct device___54 *);
	bool (*property_present)(const struct fwnode_handle___40 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___40 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___40 *, const char *, const char **, size_t);
	struct fwnode_handle___40 * (*get_parent)(const struct fwnode_handle___40 *);
	struct fwnode_handle___40 * (*get_next_child_node)(const struct fwnode_handle___40 *, struct fwnode_handle___40 *);
	struct fwnode_handle___40 * (*get_named_child_node)(const struct fwnode_handle___40 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___40 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___40 *);
	struct fwnode_handle___40 * (*graph_get_next_endpoint)(const struct fwnode_handle___40 *, struct fwnode_handle___40 *);
	struct fwnode_handle___40 * (*graph_get_remote_endpoint)(const struct fwnode_handle___40 *);
	struct fwnode_handle___40 * (*graph_get_port_parent)(struct fwnode_handle___40 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___40 *, struct fwnode_endpoint___40 *);
};

struct fwnode_endpoint___40 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___40 *local_fwnode;
};

struct fwnode_reference_args___40 {
	struct fwnode_handle___40 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct dev_pm_info___54 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___54 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___54;

struct bus_type___54;

struct device_driver___54;

struct dev_pm_domain___54;

struct class___54;

struct attribute_group___54;

struct device___54 {
	struct device___54 *parent;
	struct device_private *p;
	struct kobject___57 kobj;
	const char *init_name;
	const struct device_type___54 *type;
	struct mutex mutex;
	struct bus_type___54 *bus;
	struct device_driver___54 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___54 power;
	struct dev_pm_domain___54 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___40 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___54 *class;
	const struct attribute_group___54 **groups;
	void (*release)(struct device___54 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct irq_chip___11 {
	struct device___54 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___12 *);
	void (*irq_shutdown)(struct irq_data___12 *);
	void (*irq_enable)(struct irq_data___12 *);
	void (*irq_disable)(struct irq_data___12 *);
	void (*irq_ack)(struct irq_data___12 *);
	void (*irq_mask)(struct irq_data___12 *);
	void (*irq_mask_ack)(struct irq_data___12 *);
	void (*irq_unmask)(struct irq_data___12 *);
	void (*irq_eoi)(struct irq_data___12 *);
	int (*irq_set_affinity)(struct irq_data___12 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___12 *);
	int (*irq_set_type)(struct irq_data___12 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___12 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___12 *);
	void (*irq_bus_sync_unlock)(struct irq_data___12 *);
	void (*irq_cpu_online)(struct irq_data___12 *);
	void (*irq_cpu_offline)(struct irq_data___12 *);
	void (*irq_suspend)(struct irq_data___12 *);
	void (*irq_resume)(struct irq_data___12 *);
	void (*irq_pm_shutdown)(struct irq_data___12 *);
	void (*irq_calc_mask)(struct irq_data___12 *);
	void (*irq_print_chip)(struct irq_data___12 *, struct seq_file___57 *);
	int (*irq_request_resources)(struct irq_data___12 *);
	void (*irq_release_resources)(struct irq_data___12 *);
	void (*irq_compose_msi_msg)(struct irq_data___12 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___12 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___12 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___12 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___12 *, void *);
	void (*ipi_send_single)(struct irq_data___12 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___12 *, const struct cpumask *);
	long unsigned int flags;
};

struct seq_operations___54;

struct seq_file___57 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___54 *op;
	int poll_event;
	const struct file___60 *file;
	void *private;
};

struct kernfs_root___57;

struct kernfs_elem_dir___57 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___57 *root;
};

struct kernfs_syscall_ops___57;

struct kernfs_root___57 {
	struct kernfs_node___57 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___57 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___57 {
	struct kernfs_node___57 *target_kn;
};

struct kernfs_ops___57;

struct kernfs_elem_attr___57 {
	const struct kernfs_ops___57 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___57 *notify_next;
};

struct kernfs_node___57 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___57 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___57 dir;
		struct kernfs_elem_symlink___57 symlink;
		struct kernfs_elem_attr___57 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___57;

struct kernfs_ops___57 {
	int (*open)(struct kernfs_open_file___57 *);
	void (*release)(struct kernfs_open_file___57 *);
	int (*seq_show)(struct seq_file___57 *, void *);
	void * (*seq_start)(struct seq_file___57 *, loff_t *);
	void * (*seq_next)(struct seq_file___57 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___57 *, void *);
	ssize_t (*read)(struct kernfs_open_file___57 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___57 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___57 *, struct vm_area_struct___60 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___57 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___57 {
	int (*remount_fs)(struct kernfs_root___57 *, int *, char *);
	int (*show_options)(struct seq_file___57 *, struct kernfs_root___57 *);
	int (*mkdir)(struct kernfs_node___57 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___57 *);
	int (*rename)(struct kernfs_node___57 *, struct kernfs_node___57 *, const char *);
	int (*show_path)(struct seq_file___57 *, struct kernfs_node___57 *, struct kernfs_root___57 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___57 {
	struct kernfs_node___57 *kn;
	struct file___60 *file;
	struct seq_file___57 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___59 *vm_ops;
};

struct bin_attribute___54;

struct attribute_group___54 {
	const char *name;
	umode_t (*is_visible)(struct kobject___57 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___57 *, struct bin_attribute___54 *, int);
	struct attribute **attrs;
	struct bin_attribute___54 **bin_attrs;
};

struct bin_attribute___54 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___60 *, struct kobject___57 *, struct bin_attribute___54 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___60 *, struct kobject___57 *, struct bin_attribute___54 *, char *, loff_t, size_t);
	int (*mmap)(struct file___60 *, struct kobject___57 *, struct bin_attribute___54 *, struct vm_area_struct___60 *);
};

struct sysfs_ops___56 {
	ssize_t (*show)(struct kobject___57 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___57 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___56;

struct kset___56 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___57 kobj;
	const struct kset_uevent_ops___56 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___56 {
	void (*release)(struct kobject___57 *);
	const struct sysfs_ops___56 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___57 *);
	const void * (*namespace)(struct kobject___57 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___56 {
	int (* const filter)(struct kset___56 *, struct kobject___57 *);
	const char * (* const name)(struct kset___56 *, struct kobject___57 *);
	int (* const uevent)(struct kset___56 *, struct kobject___57 *, struct kobj_uevent_env *);
};

struct kobj_attribute___57 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___57 *, struct kobj_attribute___57 *, char *);
	ssize_t (*store)(struct kobject___57 *, struct kobj_attribute___57 *, const char *, size_t);
};

struct irqaction___7 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___7 *next;
	irq_handler_t thread_fn;
	struct task_struct___60 *thread;
	struct irqaction___7 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___51 {
	struct kobject___57 kobj;
	struct module___54 *mod;
	struct kobject___57 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___51 {
	struct module___54 *mod;
	struct latch_tree_node node;
};

struct module_layout___51 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___51 mtn;
};

struct module_attribute___51;

struct kernel_param___51;

struct module___54 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___51 mkobj;
	struct module_attribute___51 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___57 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___51 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___51 core_layout;
	struct module_layout___51 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kernel_param_ops___51 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___51 *);
	int (*get)(char *, const struct kernel_param___51 *);
	void (*free)(void *);
};

struct kparam_array___51;

struct kernel_param___51 {
	const char *name;
	struct module___54 *mod;
	const struct kernel_param_ops___51 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___51 *arr;
	};
};

struct kparam_array___51 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___51 *ops;
	void *elem;
};

struct module_attribute___51 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___51 *, struct module_kobject___51 *, char *);
	ssize_t (*store)(struct module_attribute___51 *, struct module_kobject___51 *, const char *, size_t);
	void (*setup)(struct module___54 *, const char *);
	int (*test)(struct module___54 *);
	void (*free)(struct module___54 *);
};

struct dentry_operations___59;

struct super_block___60;

struct dentry___60 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___60 *d_parent;
	struct qstr d_name;
	struct inode___61 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___59 *d_op;
	struct super_block___60 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___59;

struct block_device___60;

struct inode___61 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___59 *i_op;
	struct super_block___60 *i_sb;
	struct address_space___59 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___60 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___28 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___60 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___59 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___60 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___59 {
	int (*d_revalidate)(struct dentry___60 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___60 *, unsigned int);
	int (*d_hash)(const struct dentry___60 *, struct qstr *);
	int (*d_compare)(const struct dentry___60 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___60 *);
	int (*d_init)(struct dentry___60 *);
	void (*d_release)(struct dentry___60 *);
	void (*d_prune)(struct dentry___60 *);
	void (*d_iput)(struct dentry___60 *, struct inode___61 *);
	char * (*d_dname)(struct dentry___60 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___59 *);
	int (*d_manage)(const struct path___59 *, bool);
	struct dentry___60 * (*d_real)(struct dentry___60 *, const struct inode___61 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___59;

struct mem_dqinfo___59 {
	struct quota_format_type___59 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___59;

struct quota_info___59 {
	unsigned int flags;
	struct rw_semaphore___60 dqio_sem;
	struct inode___61 *files[3];
	struct mem_dqinfo___59 info[3];
	const struct quota_format_ops___59 *ops[3];
};

struct rcuwait___59 {
	struct task_struct___60 *task;
};

struct percpu_rw_semaphore___59 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___60 rw_sem;
	struct rcuwait___59 writer;
	int readers_block;
};

struct sb_writers___59 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___59 rw_sem[3];
};

struct shrink_control___27;

struct shrinker___27 {
	long unsigned int (*count_objects)(struct shrinker___27 *, struct shrink_control___27 *);
	long unsigned int (*scan_objects)(struct shrinker___27 *, struct shrink_control___27 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___59;

struct super_operations___59;

struct dquot_operations___59;

struct quotactl_ops___59;

struct super_block___60 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___59 *s_type;
	const struct super_operations___59 *s_op;
	const struct dquot_operations___59 *dq_op;
	const struct quotactl_ops___59 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___60 *s_root;
	struct rw_semaphore___60 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___60 *s_bdev;
	struct backing_dev_info___28 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___59 s_dquot;
	struct sb_writers___59 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___59 *s_d_op;
	int cleancache_poolid;
	struct shrinker___27 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___50 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___27 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___27 *memcg;
};

struct kiocb___60 {
	struct file___60 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___60 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___60 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___60 *ia_file;
};

struct dquot___59 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___60 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___59 {
	int qf_fmt_id;
	const struct quota_format_ops___59 *qf_ops;
	struct module___54 *qf_owner;
	struct quota_format_type___59 *qf_next;
};

struct quota_format_ops___59 {
	int (*check_quota_file)(struct super_block___60 *, int);
	int (*read_file_info)(struct super_block___60 *, int);
	int (*write_file_info)(struct super_block___60 *, int);
	int (*free_file_info)(struct super_block___60 *, int);
	int (*read_dqblk)(struct dquot___59 *);
	int (*commit_dqblk)(struct dquot___59 *);
	int (*release_dqblk)(struct dquot___59 *);
	int (*get_next_id)(struct super_block___60 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___59 {
	int (*write_dquot)(struct dquot___59 *);
	struct dquot___59 * (*alloc_dquot)(struct super_block___60 *, int);
	void (*destroy_dquot)(struct dquot___59 *);
	int (*acquire_dquot)(struct dquot___59 *);
	int (*release_dquot)(struct dquot___59 *);
	int (*mark_dirty)(struct dquot___59 *);
	int (*write_info)(struct super_block___60 *, int);
	qsize_t * (*get_reserved_space)(struct inode___61 *);
	int (*get_projid)(struct inode___61 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___61 *, qsize_t *);
	int (*get_next_id)(struct super_block___60 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___59 {
	int (*quota_on)(struct super_block___60 *, int, int, const struct path___59 *);
	int (*quota_off)(struct super_block___60 *, int);
	int (*quota_enable)(struct super_block___60 *, unsigned int);
	int (*quota_disable)(struct super_block___60 *, unsigned int);
	int (*quota_sync)(struct super_block___60 *, int);
	int (*set_info)(struct super_block___60 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___60 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___60 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___60 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___60 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___60 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___27;

struct swap_info_struct___22;

struct address_space_operations___59 {
	int (*writepage)(struct page___60 *, struct writeback_control___27 *);
	int (*readpage)(struct file___60 *, struct page___60 *);
	int (*writepages)(struct address_space___59 *, struct writeback_control___27 *);
	int (*set_page_dirty)(struct page___60 *);
	int (*readpages)(struct file___60 *, struct address_space___59 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___60 *, struct address_space___59 *, loff_t, unsigned int, unsigned int, struct page___60 **, void **);
	int (*write_end)(struct file___60 *, struct address_space___59 *, loff_t, unsigned int, unsigned int, struct page___60 *, void *);
	sector_t (*bmap)(struct address_space___59 *, sector_t);
	void (*invalidatepage)(struct page___60 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___60 *, gfp_t);
	void (*freepage)(struct page___60 *);
	ssize_t (*direct_IO)(struct kiocb___60 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___59 *, struct page___60 *, struct page___60 *, enum migrate_mode);
	bool (*isolate_page)(struct page___60 *, isolate_mode_t);
	void (*putback_page)(struct page___60 *);
	int (*launder_page)(struct page___60 *);
	int (*is_partially_uptodate)(struct page___60 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___60 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___59 *, struct page___60 *);
	int (*swap_activate)(struct swap_info_struct___22 *, struct file___60 *, sector_t *);
	void (*swap_deactivate)(struct file___60 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___27 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___28 *wb;
	struct inode___61 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct swap_info_struct___22 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___60 *bdev;
	struct file___60 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___60 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___61 *bd_inode;
	struct super_block___60 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___60 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___28 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___59 {
	struct dentry___60 * (*lookup)(struct inode___61 *, struct dentry___60 *, unsigned int);
	const char * (*get_link)(struct dentry___60 *, struct inode___61 *, struct delayed_call *);
	int (*permission)(struct inode___61 *, int);
	struct posix_acl * (*get_acl)(struct inode___61 *, int);
	int (*readlink)(struct dentry___60 *, char *, int);
	int (*create)(struct inode___61 *, struct dentry___60 *, umode_t, bool);
	int (*link)(struct dentry___60 *, struct inode___61 *, struct dentry___60 *);
	int (*unlink)(struct inode___61 *, struct dentry___60 *);
	int (*symlink)(struct inode___61 *, struct dentry___60 *, const char *);
	int (*mkdir)(struct inode___61 *, struct dentry___60 *, umode_t);
	int (*rmdir)(struct inode___61 *, struct dentry___60 *);
	int (*mknod)(struct inode___61 *, struct dentry___60 *, umode_t, dev_t);
	int (*rename)(struct inode___61 *, struct dentry___60 *, struct inode___61 *, struct dentry___60 *, unsigned int);
	int (*setattr)(struct dentry___60 *, struct iattr___60 *);
	int (*getattr)(const struct path___59 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___60 *, char *, size_t);
	int (*fiemap)(struct inode___61 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___61 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___61 *, struct dentry___60 *, struct file___60 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___61 *, struct dentry___60 *, umode_t);
	int (*set_acl)(struct inode___61 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___59 {
	void (*fl_copy_lock)(struct file_lock___60 *, struct file_lock___60 *);
	void (*fl_release_private)(struct file_lock___60 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___59;

struct lock_manager_operations___59;

struct file_lock___60 {
	struct file_lock___60 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___60 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___59 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___59 *fl_ops;
	const struct lock_manager_operations___59 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___59 {
	int (*lm_compare_owner)(struct file_lock___60 *, struct file_lock___60 *);
	long unsigned int (*lm_owner_key)(struct file_lock___60 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___60 *);
	int (*lm_grant)(struct file_lock___60 *, int);
	bool (*lm_break)(struct file_lock___60 *);
	int (*lm_change)(struct file_lock___60 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___60 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___59 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___59 *fa_next;
	struct file___60 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___59 {
	const char *name;
	int fs_flags;
	struct dentry___60 * (*mount)(struct file_system_type___59 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___60 *);
	struct module___54 *owner;
	struct file_system_type___59 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___59 {
	struct inode___61 * (*alloc_inode)(struct super_block___60 *);
	void (*destroy_inode)(struct inode___61 *);
	void (*dirty_inode)(struct inode___61 *, int);
	int (*write_inode)(struct inode___61 *, struct writeback_control___27 *);
	int (*drop_inode)(struct inode___61 *);
	void (*evict_inode)(struct inode___61 *);
	void (*put_super)(struct super_block___60 *);
	int (*sync_fs)(struct super_block___60 *, int);
	int (*freeze_super)(struct super_block___60 *);
	int (*freeze_fs)(struct super_block___60 *);
	int (*thaw_super)(struct super_block___60 *);
	int (*unfreeze_fs)(struct super_block___60 *);
	int (*statfs)(struct dentry___60 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___60 *, int *, char *);
	void (*umount_begin)(struct super_block___60 *);
	int (*show_options)(struct seq_file___57 *, struct dentry___60 *);
	int (*show_devname)(struct seq_file___57 *, struct dentry___60 *);
	int (*show_path)(struct seq_file___57 *, struct dentry___60 *);
	int (*show_stats)(struct seq_file___57 *, struct dentry___60 *);
	ssize_t (*quota_read)(struct super_block___60 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___60 *, int, const char *, size_t, loff_t);
	struct dquot___59 ** (*get_dquots)(struct inode___61 *);
	int (*bdev_try_to_free_page)(struct super_block___60 *, struct page___60 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___60 *, struct shrink_control___27 *);
	long int (*free_cached_objects)(struct super_block___60 *, struct shrink_control___27 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___28(struct bio___28 *);

struct bio_vec___28 {
	struct page___60 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___28;

struct bio_set___28;

struct bio___28 {
	struct bio___28 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___28 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___28 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___28 *bi_io_vec;
	struct bio_set___28 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___28 bi_inline_vecs[0];
};

typedef int (*key_restrict_link_func_t___59)(struct key___60 *, const struct key_type *, const union key_payload *, struct key___60 *);

struct key_restriction___60;

struct key___60 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___60 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___60 *restrict_link;
};

struct key_restriction___60 {
	key_restrict_link_func_t___59 check;
	struct key___60 *key;
	struct key_type *keytype;
};

struct seq_operations___54 {
	void * (*start)(struct seq_file___57 *, loff_t *);
	void (*stop)(struct seq_file___57 *, void *);
	void * (*next)(struct seq_file___57 *, void *, loff_t *);
	int (*show)(struct seq_file___57 *, void *);
};

struct cgroup_namespace___48 {
	refcount_t count;
	struct ns_common ns;
	struct user_namespace___50 *user_ns;
	struct ucounts___50 *ucounts;
	struct css_set___48 *root_cset;
};

struct ucounts___50 {
	struct hlist_node node;
	struct user_namespace___50 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___48;

struct bpf_map_ops___48 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___48 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___48 *, struct file___60 *);
	void (*map_free)(struct bpf_map___48 *);
	int (*map_get_next_key)(struct bpf_map___48 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___48 *);
	void * (*map_lookup_elem)(struct bpf_map___48 *, void *);
	int (*map_update_elem)(struct bpf_map___48 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___48 *, void *);
	int (*map_push_elem)(struct bpf_map___48 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___48 *, void *);
	int (*map_peek_elem)(struct bpf_map___48 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___48 *, struct file___60 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___48 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___48 *, void *, struct seq_file___57 *);
	int (*map_check_btf)(const struct bpf_map___48 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___48 {
	const struct bpf_map_ops___48 *ops;
	struct bpf_map___48 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___59 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___48;

typedef void (*kthread_work_func_t___48)(struct kthread_work___48 *);

struct kthread_worker___48;

struct kthread_work___48 {
	struct list_head node;
	kthread_work_func_t___48 func;
	struct kthread_worker___48 *worker;
	int canceling;
};

struct kthread_worker___48 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___60 *task;
	struct kthread_work___48 *current_work;
};

struct kthread_delayed_work___48 {
	struct kthread_work___48 work;
	struct timer_list timer;
};

struct psi_group___48 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___48 *poll_kworker;
	struct kthread_delayed_work___48 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___48;

struct cgroup_rstat_cpu___48;

struct cgroup___48 {
	struct cgroup_subsys_state___48 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___57 *kn;
	struct cgroup_file___48 procs_file;
	struct cgroup_file___48 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___48 *subsys[13];
	struct cgroup_root___48 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___48 *dom_cgrp;
	struct cgroup_rstat_cpu___48 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf bpf;
	atomic_t congestion_count;
	struct cgroup___48 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___48 psi;
	int ancestor_ids[0];
};

struct cftype___48;

struct cgroup_subsys___48 {
	struct cgroup_subsys_state___48 * (*css_alloc)(struct cgroup_subsys_state___48 *);
	int (*css_online)(struct cgroup_subsys_state___48 *);
	void (*css_offline)(struct cgroup_subsys_state___48 *);
	void (*css_released)(struct cgroup_subsys_state___48 *);
	void (*css_free)(struct cgroup_subsys_state___48 *);
	void (*css_reset)(struct cgroup_subsys_state___48 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___48 *, int);
	int (*css_extra_stat_show)(struct seq_file___57 *, struct cgroup_subsys_state___48 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___60 *);
	void (*cancel_fork)(struct task_struct___60 *);
	void (*fork)(struct task_struct___60 *);
	void (*exit)(struct task_struct___60 *);
	void (*free)(struct task_struct___60 *);
	void (*bind)(struct cgroup_subsys_state___48 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___48 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___48 *dfl_cftypes;
	struct cftype___48 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___48 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___48 *updated_children;
	struct cgroup___48 *updated_next;
};

struct cgroup_root___48 {
	struct kernfs_root___57 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___48 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___48 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___48 *ss;
	struct list_head node;
	struct kernfs_ops___57 *kf_ops;
	int (*open)(struct kernfs_open_file___57 *);
	void (*release)(struct kernfs_open_file___57 *);
	u64 (*read_u64)(struct cgroup_subsys_state___48 *, struct cftype___48 *);
	s64 (*read_s64)(struct cgroup_subsys_state___48 *, struct cftype___48 *);
	int (*seq_show)(struct seq_file___57 *, void *);
	void * (*seq_start)(struct seq_file___57 *, loff_t *);
	void * (*seq_next)(struct seq_file___57 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___57 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___48 *, struct cftype___48 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___48 *, struct cftype___48 *, s64);
	ssize_t (*write)(struct kernfs_open_file___57 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___57 *, struct poll_table_struct___6 *);
};

typedef void compound_page_dtor___59(struct page___60 *);

struct bdi_writeback_congested___28 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___28 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___28 {
	struct bio___28 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___28 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___28 bip_inline_vecs[0];
};

struct bio_set___28 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___28 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___27 {
	struct mem_cgroup___27 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___27 {
	struct lruvec___59 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___27 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___27 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct dev_pm_ops___54 {
	int (*prepare)(struct device___54 *);
	void (*complete)(struct device___54 *);
	int (*suspend)(struct device___54 *);
	int (*resume)(struct device___54 *);
	int (*freeze)(struct device___54 *);
	int (*thaw)(struct device___54 *);
	int (*poweroff)(struct device___54 *);
	int (*restore)(struct device___54 *);
	int (*suspend_late)(struct device___54 *);
	int (*resume_early)(struct device___54 *);
	int (*freeze_late)(struct device___54 *);
	int (*thaw_early)(struct device___54 *);
	int (*poweroff_late)(struct device___54 *);
	int (*restore_early)(struct device___54 *);
	int (*suspend_noirq)(struct device___54 *);
	int (*resume_noirq)(struct device___54 *);
	int (*freeze_noirq)(struct device___54 *);
	int (*thaw_noirq)(struct device___54 *);
	int (*poweroff_noirq)(struct device___54 *);
	int (*restore_noirq)(struct device___54 *);
	int (*runtime_suspend)(struct device___54 *);
	int (*runtime_resume)(struct device___54 *);
	int (*runtime_idle)(struct device___54 *);
};

struct dev_pm_domain___54 {
	struct dev_pm_ops___54 ops;
	void (*detach)(struct device___54 *, bool);
	int (*activate)(struct device___54 *);
	void (*sync)(struct device___54 *);
	void (*dismiss)(struct device___54 *);
};

struct bus_type___54 {
	const char *name;
	const char *dev_name;
	struct device___54 *dev_root;
	const struct attribute_group___54 **bus_groups;
	const struct attribute_group___54 **dev_groups;
	const struct attribute_group___54 **drv_groups;
	int (*match)(struct device___54 *, struct device_driver___54 *);
	int (*uevent)(struct device___54 *, struct kobj_uevent_env *);
	int (*probe)(struct device___54 *);
	int (*remove)(struct device___54 *);
	void (*shutdown)(struct device___54 *);
	int (*online)(struct device___54 *);
	int (*offline)(struct device___54 *);
	int (*suspend)(struct device___54 *, pm_message_t);
	int (*resume)(struct device___54 *);
	int (*num_vf)(struct device___54 *);
	int (*dma_configure)(struct device___54 *);
	const struct dev_pm_ops___54 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___54 {
	const char *name;
	struct bus_type___54 *bus;
	struct module___54 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___54 *);
	int (*remove)(struct device___54 *);
	void (*shutdown)(struct device___54 *);
	int (*suspend)(struct device___54 *, pm_message_t);
	int (*resume)(struct device___54 *);
	const struct attribute_group___54 **groups;
	const struct dev_pm_ops___54 *pm;
	void (*coredump)(struct device___54 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___54 {
	const char *name;
	const struct attribute_group___54 **groups;
	int (*uevent)(struct device___54 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___54 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___54 *);
	const struct dev_pm_ops___54 *pm;
};

struct class___54 {
	const char *name;
	struct module___54 *owner;
	const struct attribute_group___54 **class_groups;
	const struct attribute_group___54 **dev_groups;
	struct kobject___57 *dev_kobj;
	int (*dev_uevent)(struct device___54 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___54 *, umode_t *);
	void (*class_release)(struct class___54 *);
	void (*dev_release)(struct device___54 *);
	int (*shutdown_pre)(struct device___54 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___54 *);
	const struct dev_pm_ops___54 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___50 {
	struct device___54 dev;
};

struct irq_desc___9;

typedef void (*irq_flow_handler_t___9)(struct irq_desc___9 *);

struct irq_chip___12;

struct irq_data___5 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___3 *common;
	struct irq_chip___12 *chip;
	struct irq_domain___2 *domain;
	struct irq_data___5 *parent_data;
	void *chip_data;
};

struct irq_desc___9 {
	struct irq_common_data___3 irq_common_data;
	struct irq_data___5 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___9 handle_irq;
	struct irqaction *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int irq_count;
	unsigned int tot_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___18 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___11 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip___12 {
	struct device___25 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___5 *);
	void (*irq_shutdown)(struct irq_data___5 *);
	void (*irq_enable)(struct irq_data___5 *);
	void (*irq_disable)(struct irq_data___5 *);
	void (*irq_ack)(struct irq_data___5 *);
	void (*irq_mask)(struct irq_data___5 *);
	void (*irq_mask_ack)(struct irq_data___5 *);
	void (*irq_unmask)(struct irq_data___5 *);
	void (*irq_eoi)(struct irq_data___5 *);
	int (*irq_set_affinity)(struct irq_data___5 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___5 *);
	int (*irq_set_type)(struct irq_data___5 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___5 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___5 *);
	void (*irq_bus_sync_unlock)(struct irq_data___5 *);
	void (*irq_cpu_online)(struct irq_data___5 *);
	void (*irq_cpu_offline)(struct irq_data___5 *);
	void (*irq_suspend)(struct irq_data___5 *);
	void (*irq_resume)(struct irq_data___5 *);
	void (*irq_pm_shutdown)(struct irq_data___5 *);
	void (*irq_calc_mask)(struct irq_data___5 *);
	void (*irq_print_chip)(struct irq_data___5 *, struct seq_file___9 *);
	int (*irq_request_resources)(struct irq_data___5 *);
	void (*irq_release_resources)(struct irq_data___5 *);
	void (*irq_compose_msi_msg)(struct irq_data___5 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___5 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___5 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___5 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___5 *, void *);
	void (*ipi_send_single)(struct irq_data___5 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___5 *, const struct cpumask *);
	long unsigned int flags;
};

struct irq_chip_type___5 {
	struct irq_chip___12 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___9 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___5 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___5 *);
	void (*resume)(struct irq_chip_generic___5 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___2 *domain;
	struct list_head list;
	struct irq_chip_type___5 chip_types[0];
};

struct irq_domain_chip_generic___2 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___5 *gc[0];
};

struct msi_alloc_info {
	struct msi_desc___4 *desc;
	irq_hw_number_t hwirq;
	union {
		long unsigned int ul;
		void *ptr;
	} scratchpad[2];
};

typedef struct msi_alloc_info msi_alloc_info_t;

struct msi_domain_info;

struct msi_domain_ops {
	irq_hw_number_t (*get_hwirq)(struct msi_domain_info *, msi_alloc_info_t *);
	int (*msi_init)(struct irq_domain___2 *, struct msi_domain_info *, unsigned int, irq_hw_number_t, msi_alloc_info_t *);
	void (*msi_free)(struct irq_domain___2 *, struct msi_domain_info *, unsigned int);
	int (*msi_check)(struct irq_domain___2 *, struct msi_domain_info *, struct device___25 *);
	int (*msi_prepare)(struct irq_domain___2 *, struct device___25 *, int, msi_alloc_info_t *);
	void (*msi_finish)(msi_alloc_info_t *, int);
	void (*set_desc)(msi_alloc_info_t *, struct msi_desc___4 *);
	int (*handle_error)(struct irq_domain___2 *, struct msi_desc___4 *, int);
};

struct msi_domain_info {
	u32 flags;
	struct msi_domain_ops *ops;
	struct irq_chip___12 *chip;
	void *chip_data;
	irq_flow_handler_t___9 handler;
	void *handler_data;
	const char *handler_name;
	void *data;
};

enum {
	MSI_FLAG_USE_DEF_DOM_OPS = 1,
	MSI_FLAG_USE_DEF_CHIP_OPS = 2,
	MSI_FLAG_MULTI_PCI_MSI = 4,
	MSI_FLAG_PCI_MSIX = 8,
	MSI_FLAG_ACTIVATE_EARLY = 16,
	MSI_FLAG_MUST_REACTIVATE = 32,
	MSI_FLAG_LEVEL_CAPABLE = 64,
};

struct irq_affinity {
	unsigned int pre_vectors;
	unsigned int post_vectors;
	unsigned int nr_sets;
	unsigned int set_size[4];
	void (*calc_sets)(struct irq_affinity *, unsigned int);
	void *priv;
};

struct module___55;

struct file___61;

struct kiocb___61;

struct poll_table_struct___39;

struct vm_area_struct___61;

struct inode___62;

struct file_lock___61;

struct page___61;

struct seq_file___58;

struct file_operations___61 {
	struct module___55 *owner;
	loff_t (*llseek)(struct file___61 *, loff_t, int);
	ssize_t (*read)(struct file___61 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___61 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___61 *, struct iov_iter___9 *);
	ssize_t (*write_iter)(struct kiocb___61 *, struct iov_iter___9 *);
	int (*iopoll)(struct kiocb___61 *, bool);
	int (*iterate)(struct file___61 *, struct dir_context *);
	int (*iterate_shared)(struct file___61 *, struct dir_context *);
	__poll_t (*poll)(struct file___61 *, struct poll_table_struct___39 *);
	long int (*unlocked_ioctl)(struct file___61 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___61 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___61 *, struct vm_area_struct___61 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___62 *, struct file___61 *);
	int (*flush)(struct file___61 *, fl_owner_t);
	int (*release)(struct inode___62 *, struct file___61 *);
	int (*fsync)(struct file___61 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___61 *, int);
	int (*lock)(struct file___61 *, int, struct file_lock___61 *);
	ssize_t (*sendpage)(struct file___61 *, struct page___61 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___61 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___61 *, int, struct file_lock___61 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___61 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___61 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___61 *, long int, struct file_lock___61 **, void **);
	long int (*fallocate)(struct file___61 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___58 *, struct file___61 *);
	ssize_t (*copy_file_range)(struct file___61 *, loff_t, struct file___61 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___61 *, loff_t, struct file___61 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___61 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___60 {
	u64 seqnum;
	struct vm_area_struct___61 *vmas[4];
};

struct page_frag___60 {
	struct page___61 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___38;

struct debug_info___38 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___38 *hbp_break[16];
	struct perf_event___38 *hbp_watch[16];
};

struct thread_struct___38 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___38 debug;
	long: 64;
};

struct mm_struct___60;

struct pid___52;

struct cred___60;

struct nsproxy___59;

struct signal_struct___54;

struct css_set___49;

struct perf_event_context___38;

struct vm_struct___44;

struct task_struct___61 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___61 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___60 *mm;
	struct mm_struct___60 *active_mm;
	struct vmacache___60 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___61 *real_parent;
	struct task_struct___61 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___61 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___52 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___52 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___52 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___60 *ptracer_cred;
	const struct cred___60 *real_cred;
	const struct cred___60 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___59 *nsproxy;
	struct signal_struct___54 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___61 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___13 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___49 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___38 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___60 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___61 *oom_reaper_list;
	struct vm_struct___44 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___38 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___38 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___61 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___38)(struct perf_event___38 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___38;

struct fasync_struct___60;

struct pid_namespace___52;

struct trace_event_call___33;

struct perf_cgroup___38;

struct perf_event___38 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___38 *group_leader;
	struct pmu___38 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___38 hw;
	struct perf_event_context___38 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___38 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___61 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___60 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___38 *);
	struct callback_head callback_head;
	struct pid_namespace___52 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___38 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___38 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___33 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___38 *cgrp;
	struct list_head sb_list;
};

struct secondary_data___61 {
	void *stack;
	struct task_struct___61 *task;
	long int status;
};

struct clock_event_device___10;

struct arch_timer_erratum_workaround___10 {
	enum arch_timer_erratum_match_type match_type;
	const void *id;
	const char *desc;
	u32 (*read_cntp_tval_el0)();
	u32 (*read_cntv_tval_el0)();
	u64 (*read_cntpct_el0)();
	u64 (*read_cntvct_el0)();
	int (*set_next_event_phys)(long unsigned int, struct clock_event_device___10 *);
	int (*set_next_event_virt)(long unsigned int, struct clock_event_device___10 *);
};

struct clock_event_device___10 {
	void (*event_handler)(struct clock_event_device___10 *);
	int (*set_next_event)(long unsigned int, struct clock_event_device___10 *);
	int (*set_next_ktime)(ktime_t, struct clock_event_device___10 *);
	ktime_t next_event;
	u64 max_delta_ns;
	u64 min_delta_ns;
	u32 mult;
	u32 shift;
	enum clock_event_state state_use_accessors;
	unsigned int features;
	long unsigned int retries;
	int (*set_state_periodic)(struct clock_event_device___10 *);
	int (*set_state_oneshot)(struct clock_event_device___10 *);
	int (*set_state_oneshot_stopped)(struct clock_event_device___10 *);
	int (*set_state_shutdown)(struct clock_event_device___10 *);
	int (*tick_resume)(struct clock_event_device___10 *);
	void (*broadcast)(const struct cpumask *);
	void (*suspend)(struct clock_event_device___10 *);
	void (*resume)(struct clock_event_device___10 *);
	long unsigned int min_delta_ticks;
	long unsigned int max_delta_ticks;
	const char *name;
	int rating;
	int irq;
	int bound_on;
	const struct cpumask *cpumask;
	struct list_head list;
	struct module___55 *owner;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct key___61;

struct user_struct___60 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___61 *uid_keyring;
	struct key___61 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct upid___52 {
	int nr;
	struct pid_namespace___52 *ns;
};

struct dentry___61;

struct user_namespace___51;

struct ucounts___51;

struct pid_namespace___52 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___61 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___52 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___61 *proc_self;
	struct dentry___61 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___51 *user_ns;
	struct ucounts___51 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common ns;
};

struct pid___52 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___52 numbers[1];
};

struct rw_semaphore___61 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___61 *owner;
};

struct user_namespace___51 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___51 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common ns;
	long unsigned int flags;
	struct key___61 *persistent_keyring_register;
	struct rw_semaphore___61 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___51 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___61 *pgtable_t___60;

struct address_space___60;

struct dev_pagemap___60;

struct page___61 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___60 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___61 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___60 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___60 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___60 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct vm_operations_struct___60;

struct vm_area_struct___61 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___61 *vm_next;
	struct vm_area_struct___61 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___60 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___60 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___61 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___60;

struct mm_struct___60 {
	struct {
		struct vm_area_struct___61 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___61 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___61 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___60 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___61 *owner;
		struct user_namespace___51 *user_ns;
		struct file___61 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___60 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___60 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___61 *session_keyring;
	struct key___61 *process_keyring;
	struct key___61 *thread_keyring;
	struct key___61 *request_key_auth;
	void *security;
	struct user_struct___60 *user;
	struct user_namespace___51 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___49;

struct nsproxy___59 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___52 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___49 *cgroup_ns;
};

struct signal_struct___54 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___61 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___61 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___52 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___52 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___60 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___52 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___49;

struct cgroup___49;

struct css_set___49 {
	struct cgroup_subsys_state___49 *subsys[13];
	refcount_t refcount;
	struct css_set___49 *dom_cset;
	struct cgroup___49 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___49 *mg_src_cgrp;
	struct cgroup___49 *mg_dst_cgrp;
	struct css_set___49 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___38 {
	struct pmu___38 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___61 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___38 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___44 {
	struct vm_struct___44 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___61 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___54 {
	struct task_struct___61 task;
	long unsigned int stack[8192];
};

typedef int (*key_restrict_link_func_t___60)(struct key___61 *, const struct key_type *, const union key_payload *, struct key___61 *);

struct key_restriction___61;

struct key___61 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___61 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___61 *restrict_link;
};

struct key_restriction___61 {
	key_restrict_link_func_t___60 check;
	struct key___61 *key;
	struct key_type *keytype;
};

struct blocking_notifier_head___60 {
	struct rw_semaphore___61 rwsem;
	struct notifier_block *head;
};

struct pglist_data___60;

struct lruvec___60 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___60 *pgdat;
};

struct zone___60 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___60 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___60 {
	struct zone___60 *zone;
	int zone_idx;
};

struct zonelist___60 {
	struct zoneref___60 _zonerefs[25];
};

struct pglist_data___60 {
	struct zone___60 node_zones[3];
	struct zonelist___60 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___61 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___61 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___60 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct kernfs_root___58;

struct kernfs_elem_dir___58 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___58 *root;
};

struct kernfs_node___58;

struct kernfs_syscall_ops___58;

struct kernfs_root___58 {
	struct kernfs_node___58 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___58 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___58 {
	struct kernfs_node___58 *target_kn;
};

struct kernfs_ops___58;

struct kernfs_elem_attr___58 {
	const struct kernfs_ops___58 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___58 *notify_next;
};

struct kernfs_node___58 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___58 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___58 dir;
		struct kernfs_elem_symlink___58 symlink;
		struct kernfs_elem_attr___58 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___58;

struct kernfs_ops___58 {
	int (*open)(struct kernfs_open_file___58 *);
	void (*release)(struct kernfs_open_file___58 *);
	int (*seq_show)(struct seq_file___58 *, void *);
	void * (*seq_start)(struct seq_file___58 *, loff_t *);
	void * (*seq_next)(struct seq_file___58 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___58 *, void *);
	ssize_t (*read)(struct kernfs_open_file___58 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___58 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___58 *, struct vm_area_struct___61 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___58 *, struct poll_table_struct___39 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___58 {
	int (*remount_fs)(struct kernfs_root___58 *, int *, char *);
	int (*show_options)(struct seq_file___58 *, struct kernfs_root___58 *);
	int (*mkdir)(struct kernfs_node___58 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___58 *);
	int (*rename)(struct kernfs_node___58 *, struct kernfs_node___58 *, const char *);
	int (*show_path)(struct seq_file___58 *, struct kernfs_node___58 *, struct kernfs_root___58 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___55;

struct seq_file___58 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___55 *op;
	int poll_event;
	const struct file___61 *file;
	void *private;
};

struct kernfs_open_file___58 {
	struct kernfs_node___58 *kn;
	struct file___61 *file;
	struct seq_file___58 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___60 *vm_ops;
};

struct path___60 {
	struct vfsmount *mnt;
	struct dentry___61 *dentry;
};

struct fown_struct___52 {
	rwlock_t lock;
	struct pid___52 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___61 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___60 f_path;
	struct inode___62 *f_inode;
	const struct file_operations___61 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___52 f_owner;
	const struct cred___60 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___60 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___60;

struct vm_operations_struct___60 {
	void (*open)(struct vm_area_struct___61 *);
	void (*close)(struct vm_area_struct___61 *);
	int (*split)(struct vm_area_struct___61 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___61 *);
	vm_fault_t (*fault)(struct vm_fault___60 *);
	vm_fault_t (*huge_fault)(struct vm_fault___60 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___60 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___61 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___60 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___60 *);
	int (*access)(struct vm_area_struct___61 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___61 *);
	int (*set_policy)(struct vm_area_struct___61 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___61 *, long unsigned int);
	struct page___61 * (*find_special_page)(struct vm_area_struct___61 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___38)(struct file___61 *, wait_queue_head_t *, struct poll_table_struct___39 *);

struct poll_table_struct___39 {
	poll_queue_proc___38 _qproc;
	__poll_t _key;
};

struct kobject___58;

struct bin_attribute___55;

struct attribute_group___55 {
	const char *name;
	umode_t (*is_visible)(struct kobject___58 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___58 *, struct bin_attribute___55 *, int);
	struct attribute **attrs;
	struct bin_attribute___55 **bin_attrs;
};

struct kset___57;

struct kobj_type___57;

struct kobject___58 {
	const char *name;
	struct list_head entry;
	struct kobject___58 *parent;
	struct kset___57 *kset;
	struct kobj_type___57 *ktype;
	struct kernfs_node___58 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___55 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___61 *, struct kobject___58 *, struct bin_attribute___55 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___61 *, struct kobject___58 *, struct bin_attribute___55 *, char *, loff_t, size_t);
	int (*mmap)(struct file___61 *, struct kobject___58 *, struct bin_attribute___55 *, struct vm_area_struct___61 *);
};

struct sysfs_ops___57 {
	ssize_t (*show)(struct kobject___58 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___58 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___57;

struct kset___57 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___58 kobj;
	const struct kset_uevent_ops___57 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___57 {
	void (*release)(struct kobject___58 *);
	const struct sysfs_ops___57 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___58 *);
	const void * (*namespace)(struct kobject___58 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___57 {
	int (* const filter)(struct kset___57 *, struct kobject___58 *);
	const char * (* const name)(struct kset___57 *, struct kobject___58 *);
	int (* const uevent)(struct kset___57 *, struct kobject___58 *, struct kobj_uevent_env *);
};

struct kobj_attribute___58 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___58 *, struct kobj_attribute___58 *, char *);
	ssize_t (*store)(struct kobject___58 *, struct kobj_attribute___58 *, const char *, size_t);
};

struct device___55;

struct dev_pm_ops___55 {
	int (*prepare)(struct device___55 *);
	void (*complete)(struct device___55 *);
	int (*suspend)(struct device___55 *);
	int (*resume)(struct device___55 *);
	int (*freeze)(struct device___55 *);
	int (*thaw)(struct device___55 *);
	int (*poweroff)(struct device___55 *);
	int (*restore)(struct device___55 *);
	int (*suspend_late)(struct device___55 *);
	int (*resume_early)(struct device___55 *);
	int (*freeze_late)(struct device___55 *);
	int (*thaw_early)(struct device___55 *);
	int (*poweroff_late)(struct device___55 *);
	int (*restore_early)(struct device___55 *);
	int (*suspend_noirq)(struct device___55 *);
	int (*resume_noirq)(struct device___55 *);
	int (*freeze_noirq)(struct device___55 *);
	int (*thaw_noirq)(struct device___55 *);
	int (*poweroff_noirq)(struct device___55 *);
	int (*restore_noirq)(struct device___55 *);
	int (*runtime_suspend)(struct device___55 *);
	int (*runtime_resume)(struct device___55 *);
	int (*runtime_idle)(struct device___55 *);
};

struct dev_pm_info___55 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___55 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___55;

struct bus_type___55;

struct device_driver___55;

struct dev_pm_domain___55;

struct device_node___18;

struct fwnode_handle___41;

struct class___55;

struct device___55 {
	struct device___55 *parent;
	struct device_private *p;
	struct kobject___58 kobj;
	const char *init_name;
	const struct device_type___55 *type;
	struct mutex mutex;
	struct bus_type___55 *bus;
	struct device_driver___55 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___55 power;
	struct dev_pm_domain___55 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___18 *of_node;
	struct fwnode_handle___41 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___55 *class;
	const struct attribute_group___55 **groups;
	void (*release)(struct device___55 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___55 {
	struct dev_pm_ops___55 ops;
	void (*detach)(struct device___55 *, bool);
	int (*activate)(struct device___55 *);
	void (*sync)(struct device___55 *);
	void (*dismiss)(struct device___55 *);
};

struct bus_type___55 {
	const char *name;
	const char *dev_name;
	struct device___55 *dev_root;
	const struct attribute_group___55 **bus_groups;
	const struct attribute_group___55 **dev_groups;
	const struct attribute_group___55 **drv_groups;
	int (*match)(struct device___55 *, struct device_driver___55 *);
	int (*uevent)(struct device___55 *, struct kobj_uevent_env *);
	int (*probe)(struct device___55 *);
	int (*remove)(struct device___55 *);
	void (*shutdown)(struct device___55 *);
	int (*online)(struct device___55 *);
	int (*offline)(struct device___55 *);
	int (*suspend)(struct device___55 *, pm_message_t);
	int (*resume)(struct device___55 *);
	int (*num_vf)(struct device___55 *);
	int (*dma_configure)(struct device___55 *);
	const struct dev_pm_ops___55 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___55 {
	const char *name;
	struct bus_type___55 *bus;
	struct module___55 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___55 *);
	int (*remove)(struct device___55 *);
	void (*shutdown)(struct device___55 *);
	int (*suspend)(struct device___55 *, pm_message_t);
	int (*resume)(struct device___55 *);
	const struct attribute_group___55 **groups;
	const struct dev_pm_ops___55 *pm;
	void (*coredump)(struct device___55 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___55 {
	const char *name;
	const struct attribute_group___55 **groups;
	int (*uevent)(struct device___55 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___55 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___55 *);
	const struct dev_pm_ops___55 *pm;
};

struct module_kobject___52 {
	struct kobject___58 kobj;
	struct module___55 *mod;
	struct kobject___58 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___52 {
	struct module___55 *mod;
	struct latch_tree_node node;
};

struct module_layout___52 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___52 mtn;
};

struct module_attribute___52;

struct kernel_param___52;

struct module___55 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___52 mkobj;
	struct module_attribute___52 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___58 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___52 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___52 core_layout;
	struct module_layout___52 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___33 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct class___55 {
	const char *name;
	struct module___55 *owner;
	const struct attribute_group___55 **class_groups;
	const struct attribute_group___55 **dev_groups;
	struct kobject___58 *dev_kobj;
	int (*dev_uevent)(struct device___55 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___55 *, umode_t *);
	void (*class_release)(struct class___55 *);
	void (*dev_release)(struct device___55 *);
	int (*shutdown_pre)(struct device___55 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___55 *);
	const struct dev_pm_ops___55 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct fwnode_operations___41;

struct fwnode_handle___41 {
	struct fwnode_handle___41 *secondary;
	const struct fwnode_operations___41 *ops;
};

struct property___17;

struct device_node___18 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___41 fwnode;
	struct property___17 *properties;
	struct property___17 *deadprops;
	struct device_node___18 *parent;
	struct device_node___18 *child;
	struct device_node___18 *sibling;
	struct kobject___58 kobj;
	long unsigned int _flags;
	void *data;
};

struct node___51 {
	struct device___55 dev;
};

struct kernel_param_ops___52 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___52 *);
	int (*get)(char *, const struct kernel_param___52 *);
	void (*free)(void *);
};

struct kparam_array___52;

struct kernel_param___52 {
	const char *name;
	struct module___55 *mod;
	const struct kernel_param_ops___52 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___52 *arr;
	};
};

struct kparam_array___52 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___52 *ops;
	void *elem;
};

struct kthread_work___49;

typedef void (*kthread_work_func_t___49)(struct kthread_work___49 *);

struct kthread_worker___49;

struct kthread_work___49 {
	struct list_head node;
	kthread_work_func_t___49 func;
	struct kthread_worker___49 *worker;
	int canceling;
};

struct kthread_worker___49 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___61 *task;
	struct kthread_work___49 *current_work;
};

struct kthread_delayed_work___49 {
	struct kthread_work___49 work;
	struct timer_list timer;
};

struct fwnode_reference_args___41;

struct fwnode_endpoint___41;

struct fwnode_operations___41 {
	struct fwnode_handle___41 * (*get)(struct fwnode_handle___41 *);
	void (*put)(struct fwnode_handle___41 *);
	bool (*device_is_available)(const struct fwnode_handle___41 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___41 *, const struct device___55 *);
	bool (*property_present)(const struct fwnode_handle___41 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___41 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___41 *, const char *, const char **, size_t);
	struct fwnode_handle___41 * (*get_parent)(const struct fwnode_handle___41 *);
	struct fwnode_handle___41 * (*get_next_child_node)(const struct fwnode_handle___41 *, struct fwnode_handle___41 *);
	struct fwnode_handle___41 * (*get_named_child_node)(const struct fwnode_handle___41 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___41 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___41 *);
	struct fwnode_handle___41 * (*graph_get_next_endpoint)(const struct fwnode_handle___41 *, struct fwnode_handle___41 *);
	struct fwnode_handle___41 * (*graph_get_remote_endpoint)(const struct fwnode_handle___41 *);
	struct fwnode_handle___41 * (*graph_get_port_parent)(struct fwnode_handle___41 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___41 *, struct fwnode_endpoint___41 *);
};

struct fwnode_endpoint___41 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___41 *local_fwnode;
};

struct fwnode_reference_args___41 {
	struct fwnode_handle___41 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct property___17 {
	char *name;
	int length;
	void *value;
	struct property___17 *next;
	long unsigned int _flags;
	struct bin_attribute___55 attr;
};

struct address_space_operations___60;

struct address_space___60 {
	struct inode___62 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___61 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___60 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___60)(struct vm_area_struct___61 *, long unsigned int, const struct page___61 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___60)(struct page___61 *, void *);

struct dev_pagemap___60 {
	dev_page_fault_t___60 page_fault;
	dev_page_free_t___60 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___55 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___60 {
	struct task_struct___61 *task;
	struct core_thread___60 *next;
};

struct core_state___60 {
	atomic_t nr_threads;
	struct core_thread___60 dumper;
	struct completion startup;
};

struct vm_fault___60 {
	struct vm_area_struct___61 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___61 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___61 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___60 prealloc_pte;
};

struct dentry_operations___60;

struct super_block___61;

struct dentry___61 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___61 *d_parent;
	struct qstr d_name;
	struct inode___62 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___60 *d_op;
	struct super_block___61 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___60;

struct block_device___61;

struct inode___62 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___60 *i_op;
	struct super_block___61 *i_sb;
	struct address_space___60 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___61 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___61 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___60 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___61 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___60 {
	int (*d_revalidate)(struct dentry___61 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___61 *, unsigned int);
	int (*d_hash)(const struct dentry___61 *, struct qstr *);
	int (*d_compare)(const struct dentry___61 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___61 *);
	int (*d_init)(struct dentry___61 *);
	void (*d_release)(struct dentry___61 *);
	void (*d_prune)(struct dentry___61 *);
	void (*d_iput)(struct dentry___61 *, struct inode___62 *);
	char * (*d_dname)(struct dentry___61 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___60 *);
	int (*d_manage)(const struct path___60 *, bool);
	struct dentry___61 * (*d_real)(struct dentry___61 *, const struct inode___62 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___60;

struct mem_dqinfo___60 {
	struct quota_format_type___60 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___60;

struct quota_info___60 {
	unsigned int flags;
	struct rw_semaphore___61 dqio_sem;
	struct inode___62 *files[3];
	struct mem_dqinfo___60 info[3];
	const struct quota_format_ops___60 *ops[3];
};

struct rcuwait___60 {
	struct task_struct___61 *task;
};

struct percpu_rw_semaphore___60 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___61 rw_sem;
	struct rcuwait___60 writer;
	int readers_block;
};

struct sb_writers___60 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___60 rw_sem[3];
};

struct file_system_type___60;

struct super_operations___60;

struct dquot_operations___60;

struct quotactl_ops___60;

struct super_block___61 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___60 *s_type;
	const struct super_operations___60 *s_op;
	const struct dquot_operations___60 *dq_op;
	const struct quotactl_ops___60 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___61 *s_root;
	struct rw_semaphore___61 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___61 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___60 s_dquot;
	struct sb_writers___60 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___60 *s_d_op;
	int cleancache_poolid;
	struct shrinker___27 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___51 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___61 {
	struct file___61 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___61 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___61 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___61 *ia_file;
};

struct dquot___60 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___61 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___60 {
	int qf_fmt_id;
	const struct quota_format_ops___60 *qf_ops;
	struct module___55 *qf_owner;
	struct quota_format_type___60 *qf_next;
};

struct quota_format_ops___60 {
	int (*check_quota_file)(struct super_block___61 *, int);
	int (*read_file_info)(struct super_block___61 *, int);
	int (*write_file_info)(struct super_block___61 *, int);
	int (*free_file_info)(struct super_block___61 *, int);
	int (*read_dqblk)(struct dquot___60 *);
	int (*commit_dqblk)(struct dquot___60 *);
	int (*release_dqblk)(struct dquot___60 *);
	int (*get_next_id)(struct super_block___61 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___60 {
	int (*write_dquot)(struct dquot___60 *);
	struct dquot___60 * (*alloc_dquot)(struct super_block___61 *, int);
	void (*destroy_dquot)(struct dquot___60 *);
	int (*acquire_dquot)(struct dquot___60 *);
	int (*release_dquot)(struct dquot___60 *);
	int (*mark_dirty)(struct dquot___60 *);
	int (*write_info)(struct super_block___61 *, int);
	qsize_t * (*get_reserved_space)(struct inode___62 *);
	int (*get_projid)(struct inode___62 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___62 *, qsize_t *);
	int (*get_next_id)(struct super_block___61 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___60 {
	int (*quota_on)(struct super_block___61 *, int, int, const struct path___60 *);
	int (*quota_off)(struct super_block___61 *, int);
	int (*quota_enable)(struct super_block___61 *, unsigned int);
	int (*quota_disable)(struct super_block___61 *, unsigned int);
	int (*quota_sync)(struct super_block___61 *, int);
	int (*set_info)(struct super_block___61 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___61 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___61 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___61 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___61 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___61 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___60 {
	int (*writepage)(struct page___61 *, struct writeback_control___3 *);
	int (*readpage)(struct file___61 *, struct page___61 *);
	int (*writepages)(struct address_space___60 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___61 *);
	int (*readpages)(struct file___61 *, struct address_space___60 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___61 *, struct address_space___60 *, loff_t, unsigned int, unsigned int, struct page___61 **, void **);
	int (*write_end)(struct file___61 *, struct address_space___60 *, loff_t, unsigned int, unsigned int, struct page___61 *, void *);
	sector_t (*bmap)(struct address_space___60 *, sector_t);
	void (*invalidatepage)(struct page___61 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___61 *, gfp_t);
	void (*freepage)(struct page___61 *);
	ssize_t (*direct_IO)(struct kiocb___61 *, struct iov_iter___9 *);
	int (*migratepage)(struct address_space___60 *, struct page___61 *, struct page___61 *, enum migrate_mode);
	bool (*isolate_page)(struct page___61 *, isolate_mode_t);
	void (*putback_page)(struct page___61 *);
	int (*launder_page)(struct page___61 *);
	int (*is_partially_uptodate)(struct page___61 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___61 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___60 *, struct page___61 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___61 *, sector_t *);
	void (*swap_deactivate)(struct file___61 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___61 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___62 *bd_inode;
	struct super_block___61 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___61 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___60 {
	struct dentry___61 * (*lookup)(struct inode___62 *, struct dentry___61 *, unsigned int);
	const char * (*get_link)(struct dentry___61 *, struct inode___62 *, struct delayed_call *);
	int (*permission)(struct inode___62 *, int);
	struct posix_acl * (*get_acl)(struct inode___62 *, int);
	int (*readlink)(struct dentry___61 *, char *, int);
	int (*create)(struct inode___62 *, struct dentry___61 *, umode_t, bool);
	int (*link)(struct dentry___61 *, struct inode___62 *, struct dentry___61 *);
	int (*unlink)(struct inode___62 *, struct dentry___61 *);
	int (*symlink)(struct inode___62 *, struct dentry___61 *, const char *);
	int (*mkdir)(struct inode___62 *, struct dentry___61 *, umode_t);
	int (*rmdir)(struct inode___62 *, struct dentry___61 *);
	int (*mknod)(struct inode___62 *, struct dentry___61 *, umode_t, dev_t);
	int (*rename)(struct inode___62 *, struct dentry___61 *, struct inode___62 *, struct dentry___61 *, unsigned int);
	int (*setattr)(struct dentry___61 *, struct iattr___61 *);
	int (*getattr)(const struct path___60 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___61 *, char *, size_t);
	int (*fiemap)(struct inode___62 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___62 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___62 *, struct dentry___61 *, struct file___61 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___62 *, struct dentry___61 *, umode_t);
	int (*set_acl)(struct inode___62 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___60 {
	void (*fl_copy_lock)(struct file_lock___61 *, struct file_lock___61 *);
	void (*fl_release_private)(struct file_lock___61 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___60;

struct file_lock___61 {
	struct file_lock___61 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___61 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___60 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___60 *fl_ops;
	const struct lock_manager_operations___60 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___60 {
	int (*lm_compare_owner)(struct file_lock___61 *, struct file_lock___61 *);
	long unsigned int (*lm_owner_key)(struct file_lock___61 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___61 *);
	int (*lm_grant)(struct file_lock___61 *, int);
	bool (*lm_break)(struct file_lock___61 *);
	int (*lm_change)(struct file_lock___61 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___61 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___60 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___60 *fa_next;
	struct file___61 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___60 {
	const char *name;
	int fs_flags;
	struct dentry___61 * (*mount)(struct file_system_type___60 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___61 *);
	struct module___55 *owner;
	struct file_system_type___60 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___60 {
	struct inode___62 * (*alloc_inode)(struct super_block___61 *);
	void (*destroy_inode)(struct inode___62 *);
	void (*dirty_inode)(struct inode___62 *, int);
	int (*write_inode)(struct inode___62 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___62 *);
	void (*evict_inode)(struct inode___62 *);
	void (*put_super)(struct super_block___61 *);
	int (*sync_fs)(struct super_block___61 *, int);
	int (*freeze_super)(struct super_block___61 *);
	int (*freeze_fs)(struct super_block___61 *);
	int (*thaw_super)(struct super_block___61 *);
	int (*unfreeze_fs)(struct super_block___61 *);
	int (*statfs)(struct dentry___61 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___61 *, int *, char *);
	void (*umount_begin)(struct super_block___61 *);
	int (*show_options)(struct seq_file___58 *, struct dentry___61 *);
	int (*show_devname)(struct seq_file___58 *, struct dentry___61 *);
	int (*show_path)(struct seq_file___58 *, struct dentry___61 *);
	int (*show_stats)(struct seq_file___58 *, struct dentry___61 *);
	ssize_t (*quota_read)(struct super_block___61 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___61 *, int, const char *, size_t, loff_t);
	struct dquot___60 ** (*get_dquots)(struct inode___62 *);
	int (*bdev_try_to_free_page)(struct super_block___61 *, struct page___61 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___61 *, struct shrink_control___27 *);
	long int (*free_cached_objects)(struct super_block___61 *, struct shrink_control___27 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___60(struct page___61 *);

struct seq_operations___55 {
	void * (*start)(struct seq_file___58 *, loff_t *);
	void (*stop)(struct seq_file___58 *, void *);
	void * (*next)(struct seq_file___58 *, void *, loff_t *);
	int (*show)(struct seq_file___58 *, void *);
};

struct cgroup_namespace___49 {
	refcount_t count;
	struct ns_common ns;
	struct user_namespace___51 *user_ns;
	struct ucounts___51 *ucounts;
	struct css_set___49 *root_cset;
};

struct ucounts___51 {
	struct hlist_node node;
	struct user_namespace___51 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct module_attribute___52 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___52 *, struct module_kobject___52 *, char *);
	ssize_t (*store)(struct module_attribute___52 *, struct module_kobject___52 *, const char *, size_t);
	void (*setup)(struct module___55 *, const char *);
	int (*test)(struct module___55 *);
	void (*free)(struct module___55 *);
};

struct trace_event_class___33;

struct trace_event_call___33 {
	struct list_head list;
	struct trace_event_class___33 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array *prog_array;
	int (*perf_perm)(struct trace_event_call___33 *, struct perf_event___38 *);
};

struct bpf_map___49;

struct bpf_map_ops___49 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___49 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___49 *, struct file___61 *);
	void (*map_free)(struct bpf_map___49 *);
	int (*map_get_next_key)(struct bpf_map___49 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___49 *);
	void * (*map_lookup_elem)(struct bpf_map___49 *, void *);
	int (*map_update_elem)(struct bpf_map___49 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___49 *, void *);
	int (*map_push_elem)(struct bpf_map___49 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___49 *, void *);
	int (*map_peek_elem)(struct bpf_map___49 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___49 *, struct file___61 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___49 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___49 *, void *, struct seq_file___58 *);
	int (*map_check_btf)(const struct bpf_map___49 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___49 {
	const struct bpf_map_ops___49 *ops;
	struct bpf_map___49 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___60 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct psi_group___49 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___49 *poll_kworker;
	struct kthread_delayed_work___49 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___49 {
	struct kernfs_node___58 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___49;

struct cgroup_subsys_state___49 {
	struct cgroup___49 *cgroup;
	struct cgroup_subsys___49 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___49 *parent;
};

struct cgroup_root___49;

struct cgroup_rstat_cpu___49;

struct cgroup___49 {
	struct cgroup_subsys_state___49 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___58 *kn;
	struct cgroup_file___49 procs_file;
	struct cgroup_file___49 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___49 *subsys[13];
	struct cgroup_root___49 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___49 *dom_cgrp;
	struct cgroup_rstat_cpu___49 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf bpf;
	atomic_t congestion_count;
	struct cgroup___49 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___49 psi;
	int ancestor_ids[0];
};

struct cftype___49;

struct cgroup_subsys___49 {
	struct cgroup_subsys_state___49 * (*css_alloc)(struct cgroup_subsys_state___49 *);
	int (*css_online)(struct cgroup_subsys_state___49 *);
	void (*css_offline)(struct cgroup_subsys_state___49 *);
	void (*css_released)(struct cgroup_subsys_state___49 *);
	void (*css_free)(struct cgroup_subsys_state___49 *);
	void (*css_reset)(struct cgroup_subsys_state___49 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___49 *, int);
	int (*css_extra_stat_show)(struct seq_file___58 *, struct cgroup_subsys_state___49 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___61 *);
	void (*cancel_fork)(struct task_struct___61 *);
	void (*fork)(struct task_struct___61 *);
	void (*exit)(struct task_struct___61 *);
	void (*free)(struct task_struct___61 *);
	void (*bind)(struct cgroup_subsys_state___49 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___49 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___49 *dfl_cftypes;
	struct cftype___49 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___49 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___49 *updated_children;
	struct cgroup___49 *updated_next;
};

struct cgroup_root___49 {
	struct kernfs_root___58 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___49 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___49 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___49 *ss;
	struct list_head node;
	struct kernfs_ops___58 *kf_ops;
	int (*open)(struct kernfs_open_file___58 *);
	void (*release)(struct kernfs_open_file___58 *);
	u64 (*read_u64)(struct cgroup_subsys_state___49 *, struct cftype___49 *);
	s64 (*read_s64)(struct cgroup_subsys_state___49 *, struct cftype___49 *);
	int (*seq_show)(struct seq_file___58 *, void *);
	void * (*seq_start)(struct seq_file___58 *, loff_t *);
	void * (*seq_next)(struct seq_file___58 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___58 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___49 *, struct cftype___49 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___49 *, struct cftype___49 *, s64);
	ssize_t (*write)(struct kernfs_open_file___58 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___58 *, struct poll_table_struct___39 *);
};

struct perf_cpu_context___38;

struct pmu___38 {
	struct list_head entry;
	struct module___55 *module;
	struct device___55 *dev;
	const struct attribute_group___55 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___38 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___38 *);
	void (*pmu_disable)(struct pmu___38 *);
	int (*event_init)(struct perf_event___38 *);
	void (*event_mapped)(struct perf_event___38 *, struct mm_struct___60 *);
	void (*event_unmapped)(struct perf_event___38 *, struct mm_struct___60 *);
	int (*add)(struct perf_event___38 *, int);
	void (*del)(struct perf_event___38 *, int);
	void (*start)(struct perf_event___38 *, int);
	void (*stop)(struct perf_event___38 *, int);
	void (*read)(struct perf_event___38 *);
	void (*start_txn)(struct pmu___38 *, unsigned int);
	int (*commit_txn)(struct pmu___38 *);
	void (*cancel_txn)(struct pmu___38 *);
	int (*event_idx)(struct perf_event___38 *);
	void (*sched_task)(struct perf_event_context___38 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___38 *);
	int (*filter_match)(struct perf_event___38 *);
	int (*check_period)(struct perf_event___38 *, u64);
};

struct perf_cpu_context___38 {
	struct perf_event_context___38 ctx;
	struct perf_event_context___38 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___38 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___38 {
	struct cgroup_subsys_state___49 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___33 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___33 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___33 *);
	struct list_head * (*get_fields)(struct trace_event_call___33 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___33 *);
};

struct trace_event_file___12;

struct trace_event_buffer___12 {
	struct ring_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___12 *trace_file;
	void *entry;
	long unsigned int flags;
	int pc;
};

struct trace_event_file___12 {
	struct list_head list;
	struct trace_event_call___33 *event_call;
	struct event_filter *filter;
	struct dentry___61 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_rcu_utilization {
	struct trace_entry ent;
	const char *s;
	char __data[0];
};

struct trace_event_data_offsets_rcu_utilization {};

enum {
	GP_IDLE = 0,
	GP_PENDING = 1,
	GP_PASSED = 2,
};

enum {
	CB_IDLE = 0,
	CB_PENDING = 1,
	CB_REPLAY = 2,
};

struct rcu_cblist {
	struct callback_head *head;
	struct callback_head **tail;
	long int len;
	long int len_lazy;
};

enum rcutorture_type {
	RCU_FLAVOR = 0,
	RCU_BH_FLAVOR = 1,
	RCU_SCHED_FLAVOR = 2,
	RCU_TASKS_FLAVOR = 3,
	SRCU_FLAVOR = 4,
	INVALID_RCU_FLAVOR = 5,
};

struct module___56;

struct file___62;

struct kiocb___62;

struct iov_iter___28;

struct poll_table_struct___40;

struct vm_area_struct___62;

struct inode___63;

struct file_lock___62;

struct page___62;

struct seq_file___59;

struct file_operations___62 {
	struct module___56 *owner;
	loff_t (*llseek)(struct file___62 *, loff_t, int);
	ssize_t (*read)(struct file___62 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___62 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___62 *, struct iov_iter___28 *);
	ssize_t (*write_iter)(struct kiocb___62 *, struct iov_iter___28 *);
	int (*iopoll)(struct kiocb___62 *, bool);
	int (*iterate)(struct file___62 *, struct dir_context *);
	int (*iterate_shared)(struct file___62 *, struct dir_context *);
	__poll_t (*poll)(struct file___62 *, struct poll_table_struct___40 *);
	long int (*unlocked_ioctl)(struct file___62 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___62 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___62 *, struct vm_area_struct___62 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___63 *, struct file___62 *);
	int (*flush)(struct file___62 *, fl_owner_t);
	int (*release)(struct inode___63 *, struct file___62 *);
	int (*fsync)(struct file___62 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___62 *, int);
	int (*lock)(struct file___62 *, int, struct file_lock___62 *);
	ssize_t (*sendpage)(struct file___62 *, struct page___62 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___62 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___62 *, int, struct file_lock___62 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___62 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___62 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___62 *, long int, struct file_lock___62 **, void **);
	long int (*fallocate)(struct file___62 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___59 *, struct file___62 *);
	ssize_t (*copy_file_range)(struct file___62 *, loff_t, struct file___62 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___62 *, loff_t, struct file___62 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___62 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___61 {
	u64 seqnum;
	struct vm_area_struct___62 *vmas[4];
};

struct page_frag___61 {
	struct page___62 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___39;

struct debug_info___39 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___39 *hbp_break[16];
	struct perf_event___39 *hbp_watch[16];
};

struct thread_struct___39 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___39 debug;
	long: 64;
};

struct mm_struct___61;

struct mem_cgroup___28;

struct pid___53;

struct cred___61;

struct nsproxy___60;

struct signal_struct___55;

struct bio_list___29;

struct backing_dev_info___29;

struct css_set___50;

struct perf_event_context___39;

struct vm_struct___45;

struct task_struct___62 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___62 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___61 *mm;
	struct mm_struct___61 *active_mm;
	struct vmacache___61 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___62 *real_parent;
	struct task_struct___62 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___62 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___28 *active_memcg;
	long int rh_reserved2;
	struct pid___53 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___53 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___53 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___61 *ptracer_cred;
	const struct cred___61 *real_cred;
	const struct cred___61 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___60 *nsproxy;
	struct signal_struct___55 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___62 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___29 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___29 *backing_dev_info;
	struct io_context___13 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___50 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___39 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___61 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___28 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___62 *oom_reaper_list;
	struct vm_struct___45 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___39 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___39 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___62 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___39)(struct perf_event___39 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___39;

struct fasync_struct___61;

struct pid_namespace___53;

struct trace_event_call___34;

struct perf_cgroup___39;

struct perf_event___39 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___39 *group_leader;
	struct pmu___39 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___39 hw;
	struct perf_event_context___39 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___39 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___62 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___61 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___39 *);
	struct callback_head callback_head;
	struct pid_namespace___53 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___39 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___39 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___34 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___39 *cgrp;
	struct list_head sb_list;
};

struct secondary_data___62 {
	void *stack;
	struct task_struct___62 *task;
	long int status;
};

struct clock_event_device___11;

struct arch_timer_erratum_workaround___11 {
	enum arch_timer_erratum_match_type match_type;
	const void *id;
	const char *desc;
	u32 (*read_cntp_tval_el0)();
	u32 (*read_cntv_tval_el0)();
	u64 (*read_cntpct_el0)();
	u64 (*read_cntvct_el0)();
	int (*set_next_event_phys)(long unsigned int, struct clock_event_device___11 *);
	int (*set_next_event_virt)(long unsigned int, struct clock_event_device___11 *);
};

struct clock_event_device___11 {
	void (*event_handler)(struct clock_event_device___11 *);
	int (*set_next_event)(long unsigned int, struct clock_event_device___11 *);
	int (*set_next_ktime)(ktime_t, struct clock_event_device___11 *);
	ktime_t next_event;
	u64 max_delta_ns;
	u64 min_delta_ns;
	u32 mult;
	u32 shift;
	enum clock_event_state state_use_accessors;
	unsigned int features;
	long unsigned int retries;
	int (*set_state_periodic)(struct clock_event_device___11 *);
	int (*set_state_oneshot)(struct clock_event_device___11 *);
	int (*set_state_oneshot_stopped)(struct clock_event_device___11 *);
	int (*set_state_shutdown)(struct clock_event_device___11 *);
	int (*tick_resume)(struct clock_event_device___11 *);
	void (*broadcast)(const struct cpumask *);
	void (*suspend)(struct clock_event_device___11 *);
	void (*resume)(struct clock_event_device___11 *);
	long unsigned int min_delta_ticks;
	long unsigned int max_delta_ticks;
	const char *name;
	int rating;
	int irq;
	int bound_on;
	const struct cpumask *cpumask;
	struct list_head list;
	struct module___56 *owner;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

enum tick_device_mode {
	TICKDEV_MODE_PERIODIC = 0,
	TICKDEV_MODE_ONESHOT = 1,
};

struct tick_device___2 {
	struct clock_event_device___11 *evtdev;
	enum tick_device_mode mode;
};

struct upid___53 {
	int nr;
	struct pid_namespace___53 *ns;
};

struct dentry___62;

struct user_namespace___52;

struct ucounts___52;

struct pid_namespace___53 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___62 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___53 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___62 *proc_self;
	struct dentry___62 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___52 *user_ns;
	struct ucounts___52 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common ns;
};

struct pid___53 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___53 numbers[1];
};

struct rw_semaphore___62 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___62 *owner;
};

struct key___62;

struct user_namespace___52 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___52 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common ns;
	long unsigned int flags;
	struct key___62 *persistent_keyring_register;
	struct rw_semaphore___62 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___52 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___62 *pgtable_t___61;

struct address_space___61;

struct dev_pagemap___61;

struct page___62 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___61 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___62 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___61 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___61 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___61 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___28 *mem_cgroup;
};

struct user_struct___61 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___62 *uid_keyring;
	struct key___62 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___61;

struct vm_area_struct___62 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___62 *vm_next;
	struct vm_area_struct___62 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___61 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___61 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___62 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___61;

struct mm_struct___61 {
	struct {
		struct vm_area_struct___62 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___62 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___62 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___61 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___62 *owner;
		struct user_namespace___52 *user_ns;
		struct file___62 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___61 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup___50;

struct cgroup_subsys___50;

struct cgroup_subsys_state___50 {
	struct cgroup___50 *cgroup;
	struct cgroup_subsys___50 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___50 *parent;
};

struct kernfs_node___59;

struct cgroup_file___50 {
	struct kernfs_node___59 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___28;

struct mem_cgroup___28 {
	struct cgroup_subsys_state___50 css;
	struct mem_cgroup_id___11 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___50 events_file;
	struct cgroup_file___50 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___62 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___28 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cred___61 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___62 *session_keyring;
	struct key___62 *process_keyring;
	struct key___62 *thread_keyring;
	struct key___62 *request_key_auth;
	void *security;
	struct user_struct___61 *user;
	struct user_namespace___52 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___50;

struct nsproxy___60 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___53 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___50 *cgroup_ns;
};

struct signal_struct___55 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___62 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___62 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___53 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___53 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___61 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___53 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___29;

struct bio_list___29 {
	struct bio___29 *head;
	struct bio___29 *tail;
};

struct bdi_writeback_congested___29;

struct bdi_writeback___29 {
	struct backing_dev_info___29 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___29 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___50 *memcg_css;
	struct cgroup_subsys_state___50 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___56;

struct backing_dev_info___29 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___29 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___56 *dev;
	struct device___56 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___62 *debug_dir;
	struct dentry___62 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___50 {
	struct cgroup_subsys_state___50 *subsys[13];
	refcount_t refcount;
	struct css_set___50 *dom_cset;
	struct cgroup___50 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___50 *mg_src_cgrp;
	struct cgroup___50 *mg_dst_cgrp;
	struct css_set___50 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___39 {
	struct pmu___39 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___62 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___39 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___45 {
	struct vm_struct___45 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___62 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___55 {
	struct task_struct___62 task;
	long unsigned int stack[8192];
};

struct kernel_param___53;

struct kernel_param_ops___53 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___53 *);
	int (*get)(char *, const struct kernel_param___53 *);
	void (*free)(void *);
};

struct kparam_array___53;

struct kernel_param___53 {
	const char *name;
	struct module___56 *mod;
	const struct kernel_param_ops___53 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___53 *arr;
	};
};

struct kparam_array___53 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___53 *ops;
	void *elem;
};

struct kset___58;

struct kobj_type___58;

struct kobject___59 {
	const char *name;
	struct list_head entry;
	struct kobject___59 *parent;
	struct kset___58 *kset;
	struct kobj_type___58 *ktype;
	struct kernfs_node___59 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___53 {
	struct kobject___59 kobj;
	struct module___56 *mod;
	struct kobject___59 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___53 {
	struct module___56 *mod;
	struct latch_tree_node node;
};

struct module_layout___53 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___53 mtn;
};

struct module_attribute___53;

struct module___56 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___53 mkobj;
	struct module_attribute___53 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___59 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___53 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___53 core_layout;
	struct module_layout___53 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___34 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct blocking_notifier_head___61 {
	struct rw_semaphore___62 rwsem;
	struct notifier_block *head;
};

struct pglist_data___61;

struct lruvec___61 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___61 *pgdat;
};

struct zone___61 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___61 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___61 {
	struct zone___61 *zone;
	int zone_idx;
};

struct zonelist___61 {
	struct zoneref___61 _zonerefs[25];
};

struct pglist_data___61 {
	struct zone___61 node_zones[3];
	struct zonelist___61 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___62 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___62 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___61 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct kernfs_root___59;

struct kernfs_elem_dir___59 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___59 *root;
};

struct kernfs_syscall_ops___59;

struct kernfs_root___59 {
	struct kernfs_node___59 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___59 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___59 {
	struct kernfs_node___59 *target_kn;
};

struct kernfs_ops___59;

struct kernfs_elem_attr___59 {
	const struct kernfs_ops___59 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___59 *notify_next;
};

struct kernfs_node___59 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___59 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___59 dir;
		struct kernfs_elem_symlink___59 symlink;
		struct kernfs_elem_attr___59 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___59;

struct kernfs_ops___59 {
	int (*open)(struct kernfs_open_file___59 *);
	void (*release)(struct kernfs_open_file___59 *);
	int (*seq_show)(struct seq_file___59 *, void *);
	void * (*seq_start)(struct seq_file___59 *, loff_t *);
	void * (*seq_next)(struct seq_file___59 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___59 *, void *);
	ssize_t (*read)(struct kernfs_open_file___59 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___59 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___59 *, struct vm_area_struct___62 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___59 *, struct poll_table_struct___40 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___59 {
	int (*remount_fs)(struct kernfs_root___59 *, int *, char *);
	int (*show_options)(struct seq_file___59 *, struct kernfs_root___59 *);
	int (*mkdir)(struct kernfs_node___59 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___59 *);
	int (*rename)(struct kernfs_node___59 *, struct kernfs_node___59 *, const char *);
	int (*show_path)(struct seq_file___59 *, struct kernfs_node___59 *, struct kernfs_root___59 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___56;

struct seq_file___59 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___56 *op;
	int poll_event;
	const struct file___62 *file;
	void *private;
};

struct kernfs_open_file___59 {
	struct kernfs_node___59 *kn;
	struct file___62 *file;
	struct seq_file___59 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___61 *vm_ops;
};

struct path___61 {
	struct vfsmount *mnt;
	struct dentry___62 *dentry;
};

struct fown_struct___53 {
	rwlock_t lock;
	struct pid___53 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___62 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___61 f_path;
	struct inode___63 *f_inode;
	const struct file_operations___62 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___53 f_owner;
	const struct cred___61 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___61 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___61;

struct vm_operations_struct___61 {
	void (*open)(struct vm_area_struct___62 *);
	void (*close)(struct vm_area_struct___62 *);
	int (*split)(struct vm_area_struct___62 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___62 *);
	vm_fault_t (*fault)(struct vm_fault___61 *);
	vm_fault_t (*huge_fault)(struct vm_fault___61 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___61 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___62 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___61 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___61 *);
	int (*access)(struct vm_area_struct___62 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___62 *);
	int (*set_policy)(struct vm_area_struct___62 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___62 *, long unsigned int);
	struct page___62 * (*find_special_page)(struct vm_area_struct___62 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___39)(struct file___62 *, wait_queue_head_t *, struct poll_table_struct___40 *);

struct poll_table_struct___40 {
	poll_queue_proc___39 _qproc;
	__poll_t _key;
};

struct bin_attribute___56;

struct attribute_group___56 {
	const char *name;
	umode_t (*is_visible)(struct kobject___59 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___59 *, struct bin_attribute___56 *, int);
	struct attribute **attrs;
	struct bin_attribute___56 **bin_attrs;
};

struct bin_attribute___56 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___62 *, struct kobject___59 *, struct bin_attribute___56 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___62 *, struct kobject___59 *, struct bin_attribute___56 *, char *, loff_t, size_t);
	int (*mmap)(struct file___62 *, struct kobject___59 *, struct bin_attribute___56 *, struct vm_area_struct___62 *);
};

struct sysfs_ops___58 {
	ssize_t (*show)(struct kobject___59 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___59 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___58;

struct kset___58 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___59 kobj;
	const struct kset_uevent_ops___58 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___58 {
	void (*release)(struct kobject___59 *);
	const struct sysfs_ops___58 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___59 *);
	const void * (*namespace)(struct kobject___59 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___58 {
	int (* const filter)(struct kset___58 *, struct kobject___59 *);
	const char * (* const name)(struct kset___58 *, struct kobject___59 *);
	int (* const uevent)(struct kset___58 *, struct kobject___59 *, struct kobj_uevent_env *);
};

struct kobj_attribute___59 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___59 *, struct kobj_attribute___59 *, char *);
	ssize_t (*store)(struct kobject___59 *, struct kobj_attribute___59 *, const char *, size_t);
};

struct dev_pm_ops___56 {
	int (*prepare)(struct device___56 *);
	void (*complete)(struct device___56 *);
	int (*suspend)(struct device___56 *);
	int (*resume)(struct device___56 *);
	int (*freeze)(struct device___56 *);
	int (*thaw)(struct device___56 *);
	int (*poweroff)(struct device___56 *);
	int (*restore)(struct device___56 *);
	int (*suspend_late)(struct device___56 *);
	int (*resume_early)(struct device___56 *);
	int (*freeze_late)(struct device___56 *);
	int (*thaw_early)(struct device___56 *);
	int (*poweroff_late)(struct device___56 *);
	int (*restore_early)(struct device___56 *);
	int (*suspend_noirq)(struct device___56 *);
	int (*resume_noirq)(struct device___56 *);
	int (*freeze_noirq)(struct device___56 *);
	int (*thaw_noirq)(struct device___56 *);
	int (*poweroff_noirq)(struct device___56 *);
	int (*restore_noirq)(struct device___56 *);
	int (*runtime_suspend)(struct device___56 *);
	int (*runtime_resume)(struct device___56 *);
	int (*runtime_idle)(struct device___56 *);
};

struct dev_pm_info___56 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___56 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___56;

struct bus_type___56;

struct device_driver___56;

struct dev_pm_domain___56;

struct device_node___19;

struct fwnode_handle___42;

struct class___56;

struct device___56 {
	struct device___56 *parent;
	struct device_private *p;
	struct kobject___59 kobj;
	const char *init_name;
	const struct device_type___56 *type;
	struct mutex mutex;
	struct bus_type___56 *bus;
	struct device_driver___56 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___56 power;
	struct dev_pm_domain___56 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___19 *of_node;
	struct fwnode_handle___42 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___56 *class;
	const struct attribute_group___56 **groups;
	void (*release)(struct device___56 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___56 {
	struct dev_pm_ops___56 ops;
	void (*detach)(struct device___56 *, bool);
	int (*activate)(struct device___56 *);
	void (*sync)(struct device___56 *);
	void (*dismiss)(struct device___56 *);
};

struct bus_type___56 {
	const char *name;
	const char *dev_name;
	struct device___56 *dev_root;
	const struct attribute_group___56 **bus_groups;
	const struct attribute_group___56 **dev_groups;
	const struct attribute_group___56 **drv_groups;
	int (*match)(struct device___56 *, struct device_driver___56 *);
	int (*uevent)(struct device___56 *, struct kobj_uevent_env *);
	int (*probe)(struct device___56 *);
	int (*remove)(struct device___56 *);
	void (*shutdown)(struct device___56 *);
	int (*online)(struct device___56 *);
	int (*offline)(struct device___56 *);
	int (*suspend)(struct device___56 *, pm_message_t);
	int (*resume)(struct device___56 *);
	int (*num_vf)(struct device___56 *);
	int (*dma_configure)(struct device___56 *);
	const struct dev_pm_ops___56 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___56 {
	const char *name;
	struct bus_type___56 *bus;
	struct module___56 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___56 *);
	int (*remove)(struct device___56 *);
	void (*shutdown)(struct device___56 *);
	int (*suspend)(struct device___56 *, pm_message_t);
	int (*resume)(struct device___56 *);
	const struct attribute_group___56 **groups;
	const struct dev_pm_ops___56 *pm;
	void (*coredump)(struct device___56 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___56 {
	const char *name;
	const struct attribute_group___56 **groups;
	int (*uevent)(struct device___56 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___56 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___56 *);
	const struct dev_pm_ops___56 *pm;
};

struct class___56 {
	const char *name;
	struct module___56 *owner;
	const struct attribute_group___56 **class_groups;
	const struct attribute_group___56 **dev_groups;
	struct kobject___59 *dev_kobj;
	int (*dev_uevent)(struct device___56 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___56 *, umode_t *);
	void (*class_release)(struct class___56 *);
	void (*dev_release)(struct device___56 *);
	int (*shutdown_pre)(struct device___56 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___56 *);
	const struct dev_pm_ops___56 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct fwnode_operations___42;

struct fwnode_handle___42 {
	struct fwnode_handle___42 *secondary;
	const struct fwnode_operations___42 *ops;
};

struct property___18;

struct device_node___19 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___42 fwnode;
	struct property___18 *properties;
	struct property___18 *deadprops;
	struct device_node___19 *parent;
	struct device_node___19 *child;
	struct device_node___19 *sibling;
	struct kobject___59 kobj;
	long unsigned int _flags;
	void *data;
};

struct node___52 {
	struct device___56 dev;
};

struct kthread_work___50;

typedef void (*kthread_work_func_t___50)(struct kthread_work___50 *);

struct kthread_worker___50;

struct kthread_work___50 {
	struct list_head node;
	kthread_work_func_t___50 func;
	struct kthread_worker___50 *worker;
	int canceling;
};

struct kthread_worker___50 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___62 *task;
	struct kthread_work___50 *current_work;
};

struct kthread_delayed_work___50 {
	struct kthread_work___50 work;
	struct timer_list timer;
};

struct address_space_operations___61;

struct address_space___61 {
	struct inode___63 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___62 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___61 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___61)(struct vm_area_struct___62 *, long unsigned int, const struct page___62 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___61)(struct page___62 *, void *);

struct dev_pagemap___61 {
	dev_page_fault_t___61 page_fault;
	dev_page_free_t___61 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___56 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___61 {
	struct task_struct___62 *task;
	struct core_thread___61 *next;
};

struct core_state___61 {
	atomic_t nr_threads;
	struct core_thread___61 dumper;
	struct completion startup;
};

struct vm_fault___61 {
	struct vm_area_struct___62 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___62 *cow_page;
	struct mem_cgroup___28 *memcg;
	struct page___62 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___61 prealloc_pte;
};

struct shrink_control___28 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___28 *memcg;
};

struct shrinker___28 {
	long unsigned int (*count_objects)(struct shrinker___28 *, struct shrink_control___28 *);
	long unsigned int (*scan_objects)(struct shrinker___28 *, struct shrink_control___28 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct dentry_operations___61;

struct super_block___62;

struct dentry___62 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___62 *d_parent;
	struct qstr d_name;
	struct inode___63 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___61 *d_op;
	struct super_block___62 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___61;

struct block_device___62;

struct inode___63 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___61 *i_op;
	struct super_block___62 *i_sb;
	struct address_space___61 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___62 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___29 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___62 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___61 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___62 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___61 {
	int (*d_revalidate)(struct dentry___62 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___62 *, unsigned int);
	int (*d_hash)(const struct dentry___62 *, struct qstr *);
	int (*d_compare)(const struct dentry___62 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___62 *);
	int (*d_init)(struct dentry___62 *);
	void (*d_release)(struct dentry___62 *);
	void (*d_prune)(struct dentry___62 *);
	void (*d_iput)(struct dentry___62 *, struct inode___63 *);
	char * (*d_dname)(struct dentry___62 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___61 *);
	int (*d_manage)(const struct path___61 *, bool);
	struct dentry___62 * (*d_real)(struct dentry___62 *, const struct inode___63 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___61;

struct mem_dqinfo___61 {
	struct quota_format_type___61 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___61;

struct quota_info___61 {
	unsigned int flags;
	struct rw_semaphore___62 dqio_sem;
	struct inode___63 *files[3];
	struct mem_dqinfo___61 info[3];
	const struct quota_format_ops___61 *ops[3];
};

struct rcuwait___61 {
	struct task_struct___62 *task;
};

struct percpu_rw_semaphore___61 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___62 rw_sem;
	struct rcuwait___61 writer;
	int readers_block;
};

struct sb_writers___61 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___61 rw_sem[3];
};

struct file_system_type___61;

struct super_operations___61;

struct dquot_operations___61;

struct quotactl_ops___61;

struct super_block___62 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___61 *s_type;
	const struct super_operations___61 *s_op;
	const struct dquot_operations___61 *dq_op;
	const struct quotactl_ops___61 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___62 *s_root;
	struct rw_semaphore___62 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___62 *s_bdev;
	struct backing_dev_info___29 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___61 s_dquot;
	struct sb_writers___61 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___61 *s_d_op;
	int cleancache_poolid;
	struct shrinker___28 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___52 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___62 {
	struct file___62 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___62 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___62 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___62 *ia_file;
};

struct dquot___61 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___62 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___61 {
	int qf_fmt_id;
	const struct quota_format_ops___61 *qf_ops;
	struct module___56 *qf_owner;
	struct quota_format_type___61 *qf_next;
};

struct quota_format_ops___61 {
	int (*check_quota_file)(struct super_block___62 *, int);
	int (*read_file_info)(struct super_block___62 *, int);
	int (*write_file_info)(struct super_block___62 *, int);
	int (*free_file_info)(struct super_block___62 *, int);
	int (*read_dqblk)(struct dquot___61 *);
	int (*commit_dqblk)(struct dquot___61 *);
	int (*release_dqblk)(struct dquot___61 *);
	int (*get_next_id)(struct super_block___62 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___61 {
	int (*write_dquot)(struct dquot___61 *);
	struct dquot___61 * (*alloc_dquot)(struct super_block___62 *, int);
	void (*destroy_dquot)(struct dquot___61 *);
	int (*acquire_dquot)(struct dquot___61 *);
	int (*release_dquot)(struct dquot___61 *);
	int (*mark_dirty)(struct dquot___61 *);
	int (*write_info)(struct super_block___62 *, int);
	qsize_t * (*get_reserved_space)(struct inode___63 *);
	int (*get_projid)(struct inode___63 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___63 *, qsize_t *);
	int (*get_next_id)(struct super_block___62 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___61 {
	int (*quota_on)(struct super_block___62 *, int, int, const struct path___61 *);
	int (*quota_off)(struct super_block___62 *, int);
	int (*quota_enable)(struct super_block___62 *, unsigned int);
	int (*quota_disable)(struct super_block___62 *, unsigned int);
	int (*quota_sync)(struct super_block___62 *, int);
	int (*set_info)(struct super_block___62 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___62 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___62 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___62 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___62 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___62 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___28;

struct swap_info_struct___23;

struct address_space_operations___61 {
	int (*writepage)(struct page___62 *, struct writeback_control___28 *);
	int (*readpage)(struct file___62 *, struct page___62 *);
	int (*writepages)(struct address_space___61 *, struct writeback_control___28 *);
	int (*set_page_dirty)(struct page___62 *);
	int (*readpages)(struct file___62 *, struct address_space___61 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___62 *, struct address_space___61 *, loff_t, unsigned int, unsigned int, struct page___62 **, void **);
	int (*write_end)(struct file___62 *, struct address_space___61 *, loff_t, unsigned int, unsigned int, struct page___62 *, void *);
	sector_t (*bmap)(struct address_space___61 *, sector_t);
	void (*invalidatepage)(struct page___62 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___62 *, gfp_t);
	void (*freepage)(struct page___62 *);
	ssize_t (*direct_IO)(struct kiocb___62 *, struct iov_iter___28 *);
	int (*migratepage)(struct address_space___61 *, struct page___62 *, struct page___62 *, enum migrate_mode);
	bool (*isolate_page)(struct page___62 *, isolate_mode_t);
	void (*putback_page)(struct page___62 *);
	int (*launder_page)(struct page___62 *);
	int (*is_partially_uptodate)(struct page___62 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___62 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___61 *, struct page___62 *);
	int (*swap_activate)(struct swap_info_struct___23 *, struct file___62 *, sector_t *);
	void (*swap_deactivate)(struct file___62 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___28 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___29 *wb;
	struct inode___63 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___29;

struct iov_iter___28 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___29 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct swap_info_struct___23 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___62 *bdev;
	struct file___62 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___62 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___63 *bd_inode;
	struct super_block___62 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___62 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___29 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___61 {
	struct dentry___62 * (*lookup)(struct inode___63 *, struct dentry___62 *, unsigned int);
	const char * (*get_link)(struct dentry___62 *, struct inode___63 *, struct delayed_call *);
	int (*permission)(struct inode___63 *, int);
	struct posix_acl * (*get_acl)(struct inode___63 *, int);
	int (*readlink)(struct dentry___62 *, char *, int);
	int (*create)(struct inode___63 *, struct dentry___62 *, umode_t, bool);
	int (*link)(struct dentry___62 *, struct inode___63 *, struct dentry___62 *);
	int (*unlink)(struct inode___63 *, struct dentry___62 *);
	int (*symlink)(struct inode___63 *, struct dentry___62 *, const char *);
	int (*mkdir)(struct inode___63 *, struct dentry___62 *, umode_t);
	int (*rmdir)(struct inode___63 *, struct dentry___62 *);
	int (*mknod)(struct inode___63 *, struct dentry___62 *, umode_t, dev_t);
	int (*rename)(struct inode___63 *, struct dentry___62 *, struct inode___63 *, struct dentry___62 *, unsigned int);
	int (*setattr)(struct dentry___62 *, struct iattr___62 *);
	int (*getattr)(const struct path___61 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___62 *, char *, size_t);
	int (*fiemap)(struct inode___63 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___63 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___63 *, struct dentry___62 *, struct file___62 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___63 *, struct dentry___62 *, umode_t);
	int (*set_acl)(struct inode___63 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___61 {
	void (*fl_copy_lock)(struct file_lock___62 *, struct file_lock___62 *);
	void (*fl_release_private)(struct file_lock___62 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___61;

struct file_lock___62 {
	struct file_lock___62 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___62 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___61 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___61 *fl_ops;
	const struct lock_manager_operations___61 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___61 {
	int (*lm_compare_owner)(struct file_lock___62 *, struct file_lock___62 *);
	long unsigned int (*lm_owner_key)(struct file_lock___62 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___62 *);
	int (*lm_grant)(struct file_lock___62 *, int);
	bool (*lm_break)(struct file_lock___62 *);
	int (*lm_change)(struct file_lock___62 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___62 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___61 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___61 *fa_next;
	struct file___62 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___61 {
	const char *name;
	int fs_flags;
	struct dentry___62 * (*mount)(struct file_system_type___61 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___62 *);
	struct module___56 *owner;
	struct file_system_type___61 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___61 {
	struct inode___63 * (*alloc_inode)(struct super_block___62 *);
	void (*destroy_inode)(struct inode___63 *);
	void (*dirty_inode)(struct inode___63 *, int);
	int (*write_inode)(struct inode___63 *, struct writeback_control___28 *);
	int (*drop_inode)(struct inode___63 *);
	void (*evict_inode)(struct inode___63 *);
	void (*put_super)(struct super_block___62 *);
	int (*sync_fs)(struct super_block___62 *, int);
	int (*freeze_super)(struct super_block___62 *);
	int (*freeze_fs)(struct super_block___62 *);
	int (*thaw_super)(struct super_block___62 *);
	int (*unfreeze_fs)(struct super_block___62 *);
	int (*statfs)(struct dentry___62 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___62 *, int *, char *);
	void (*umount_begin)(struct super_block___62 *);
	int (*show_options)(struct seq_file___59 *, struct dentry___62 *);
	int (*show_devname)(struct seq_file___59 *, struct dentry___62 *);
	int (*show_path)(struct seq_file___59 *, struct dentry___62 *);
	int (*show_stats)(struct seq_file___59 *, struct dentry___62 *);
	ssize_t (*quota_read)(struct super_block___62 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___62 *, int, const char *, size_t, loff_t);
	struct dquot___61 ** (*get_dquots)(struct inode___63 *);
	int (*bdev_try_to_free_page)(struct super_block___62 *, struct page___62 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___62 *, struct shrink_control___28 *);
	long int (*free_cached_objects)(struct super_block___62 *, struct shrink_control___28 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___29(struct bio___29 *);

struct bio_vec___29 {
	struct page___62 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___29;

struct bio_set___29;

struct bio___29 {
	struct bio___29 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___29 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___29 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___29 *bi_io_vec;
	struct bio_set___29 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___29 bi_inline_vecs[0];
};

typedef void compound_page_dtor___61(struct page___62 *);

typedef int (*key_restrict_link_func_t___61)(struct key___62 *, const struct key_type *, const union key_payload *, struct key___62 *);

struct key_restriction___62;

struct key___62 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___62 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___62 *restrict_link;
};

struct key_restriction___62 {
	key_restrict_link_func_t___61 check;
	struct key___62 *key;
	struct key_type *keytype;
};

struct seq_operations___56 {
	void * (*start)(struct seq_file___59 *, loff_t *);
	void (*stop)(struct seq_file___59 *, void *);
	void * (*next)(struct seq_file___59 *, void *, loff_t *);
	int (*show)(struct seq_file___59 *, void *);
};

struct cgroup_namespace___50 {
	refcount_t count;
	struct ns_common ns;
	struct user_namespace___52 *user_ns;
	struct ucounts___52 *ucounts;
	struct css_set___50 *root_cset;
};

struct ucounts___52 {
	struct hlist_node node;
	struct user_namespace___52 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct module_attribute___53 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___53 *, struct module_kobject___53 *, char *);
	ssize_t (*store)(struct module_attribute___53 *, struct module_kobject___53 *, const char *, size_t);
	void (*setup)(struct module___56 *, const char *);
	int (*test)(struct module___56 *);
	void (*free)(struct module___56 *);
};

struct trace_event_class___34;

struct trace_event_call___34 {
	struct list_head list;
	struct trace_event_class___34 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array *prog_array;
	int (*perf_perm)(struct trace_event_call___34 *, struct perf_event___39 *);
};

struct bpf_map___50;

struct bpf_map_ops___50 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___50 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___50 *, struct file___62 *);
	void (*map_free)(struct bpf_map___50 *);
	int (*map_get_next_key)(struct bpf_map___50 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___50 *);
	void * (*map_lookup_elem)(struct bpf_map___50 *, void *);
	int (*map_update_elem)(struct bpf_map___50 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___50 *, void *);
	int (*map_push_elem)(struct bpf_map___50 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___50 *, void *);
	int (*map_peek_elem)(struct bpf_map___50 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___50 *, struct file___62 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___50 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___50 *, void *, struct seq_file___59 *);
	int (*map_check_btf)(const struct bpf_map___50 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___50 {
	const struct bpf_map_ops___50 *ops;
	struct bpf_map___50 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___61 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct psi_group___50 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___50 *poll_kworker;
	struct kthread_delayed_work___50 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___50;

struct cgroup_rstat_cpu___50;

struct cgroup___50 {
	struct cgroup_subsys_state___50 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___59 *kn;
	struct cgroup_file___50 procs_file;
	struct cgroup_file___50 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___50 *subsys[13];
	struct cgroup_root___50 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___50 *dom_cgrp;
	struct cgroup_rstat_cpu___50 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf bpf;
	atomic_t congestion_count;
	struct cgroup___50 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___50 psi;
	int ancestor_ids[0];
};

struct cftype___50;

struct cgroup_subsys___50 {
	struct cgroup_subsys_state___50 * (*css_alloc)(struct cgroup_subsys_state___50 *);
	int (*css_online)(struct cgroup_subsys_state___50 *);
	void (*css_offline)(struct cgroup_subsys_state___50 *);
	void (*css_released)(struct cgroup_subsys_state___50 *);
	void (*css_free)(struct cgroup_subsys_state___50 *);
	void (*css_reset)(struct cgroup_subsys_state___50 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___50 *, int);
	int (*css_extra_stat_show)(struct seq_file___59 *, struct cgroup_subsys_state___50 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___62 *);
	void (*cancel_fork)(struct task_struct___62 *);
	void (*fork)(struct task_struct___62 *);
	void (*exit)(struct task_struct___62 *);
	void (*free)(struct task_struct___62 *);
	void (*bind)(struct cgroup_subsys_state___50 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___50 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___50 *dfl_cftypes;
	struct cftype___50 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___50 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___50 *updated_children;
	struct cgroup___50 *updated_next;
};

struct cgroup_root___50 {
	struct kernfs_root___59 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___50 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___50 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___50 *ss;
	struct list_head node;
	struct kernfs_ops___59 *kf_ops;
	int (*open)(struct kernfs_open_file___59 *);
	void (*release)(struct kernfs_open_file___59 *);
	u64 (*read_u64)(struct cgroup_subsys_state___50 *, struct cftype___50 *);
	s64 (*read_s64)(struct cgroup_subsys_state___50 *, struct cftype___50 *);
	int (*seq_show)(struct seq_file___59 *, void *);
	void * (*seq_start)(struct seq_file___59 *, loff_t *);
	void * (*seq_next)(struct seq_file___59 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___59 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___50 *, struct cftype___50 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___50 *, struct cftype___50 *, s64);
	ssize_t (*write)(struct kernfs_open_file___59 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___59 *, struct poll_table_struct___40 *);
};

struct perf_cpu_context___39;

struct pmu___39 {
	struct list_head entry;
	struct module___56 *module;
	struct device___56 *dev;
	const struct attribute_group___56 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___39 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___39 *);
	void (*pmu_disable)(struct pmu___39 *);
	int (*event_init)(struct perf_event___39 *);
	void (*event_mapped)(struct perf_event___39 *, struct mm_struct___61 *);
	void (*event_unmapped)(struct perf_event___39 *, struct mm_struct___61 *);
	int (*add)(struct perf_event___39 *, int);
	void (*del)(struct perf_event___39 *, int);
	void (*start)(struct perf_event___39 *, int);
	void (*stop)(struct perf_event___39 *, int);
	void (*read)(struct perf_event___39 *);
	void (*start_txn)(struct pmu___39 *, unsigned int);
	int (*commit_txn)(struct pmu___39 *);
	void (*cancel_txn)(struct pmu___39 *);
	int (*event_idx)(struct perf_event___39 *);
	void (*sched_task)(struct perf_event_context___39 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___39 *);
	int (*filter_match)(struct perf_event___39 *);
	int (*check_period)(struct perf_event___39 *, u64);
};

struct perf_cpu_context___39 {
	struct perf_event_context___39 ctx;
	struct perf_event_context___39 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___39 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___39 {
	struct cgroup_subsys_state___50 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___34 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___34 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___34 *);
	struct list_head * (*get_fields)(struct trace_event_call___34 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___34 *);
};

struct bdi_writeback_congested___29 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___29 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___29 {
	struct bio___29 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___29 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___29 bip_inline_vecs[0];
};

struct bio_set___29 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___29 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___28 {
	struct mem_cgroup___28 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___28 {
	struct lruvec___61 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___28 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___28 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct fwnode_reference_args___42;

struct fwnode_endpoint___42;

struct fwnode_operations___42 {
	struct fwnode_handle___42 * (*get)(struct fwnode_handle___42 *);
	void (*put)(struct fwnode_handle___42 *);
	bool (*device_is_available)(const struct fwnode_handle___42 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___42 *, const struct device___56 *);
	bool (*property_present)(const struct fwnode_handle___42 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___42 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___42 *, const char *, const char **, size_t);
	struct fwnode_handle___42 * (*get_parent)(const struct fwnode_handle___42 *);
	struct fwnode_handle___42 * (*get_next_child_node)(const struct fwnode_handle___42 *, struct fwnode_handle___42 *);
	struct fwnode_handle___42 * (*get_named_child_node)(const struct fwnode_handle___42 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___42 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___42 *);
	struct fwnode_handle___42 * (*graph_get_next_endpoint)(const struct fwnode_handle___42 *, struct fwnode_handle___42 *);
	struct fwnode_handle___42 * (*graph_get_remote_endpoint)(const struct fwnode_handle___42 *);
	struct fwnode_handle___42 * (*graph_get_port_parent)(struct fwnode_handle___42 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___42 *, struct fwnode_endpoint___42 *);
};

struct fwnode_endpoint___42 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___42 *local_fwnode;
};

struct fwnode_reference_args___42 {
	struct fwnode_handle___42 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct property___18 {
	char *name;
	int length;
	void *value;
	struct property___18 *next;
	long unsigned int _flags;
	struct bin_attribute___56 attr;
};

struct rt_mutex___2 {
	raw_spinlock_t wait_lock;
	struct rb_root_cached waiters;
	struct task_struct___62 *owner;
};

struct swait_queue___4 {
	struct task_struct___62 *task;
	struct list_head task_list;
};

struct rcu_exp_work {
	smp_call_func_t rew_func;
	long unsigned int rew_s;
	struct work_struct rew_work;
};

struct rcu_node {
	raw_spinlock_t lock;
	long unsigned int gp_seq;
	long unsigned int gp_seq_needed;
	long unsigned int completedqs;
	long unsigned int qsmask;
	long unsigned int rcu_gp_init_mask;
	long unsigned int qsmaskinit;
	long unsigned int qsmaskinitnext;
	long unsigned int expmask;
	long unsigned int expmaskinit;
	long unsigned int expmaskinitnext;
	long unsigned int ffmask;
	long unsigned int grpmask;
	int grplo;
	int grphi;
	u8 grpnum;
	u8 level;
	bool wait_blkd_tasks;
	struct rcu_node *parent;
	struct list_head blkd_tasks;
	struct list_head *gp_tasks;
	struct list_head *exp_tasks;
	struct list_head *boost_tasks;
	struct rt_mutex___2 boost_mtx;
	long unsigned int boost_time;
	struct task_struct___62 *boost_kthread_task;
	unsigned int boost_kthread_status;
	struct swait_queue_head nocb_gp_wq[2];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	raw_spinlock_t fqslock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t exp_lock;
	long unsigned int exp_seq_rq;
	wait_queue_head_t exp_wq[4];
	struct rcu_exp_work rew;
	bool exp_need_flush;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

union rcu_noqs {
	struct {
		u8 norm;
		u8 exp;
	} b;
	u16 s;
};

struct rcu_data {
	long unsigned int gp_seq;
	long unsigned int gp_seq_needed;
	union rcu_noqs cpu_no_qs;
	bool core_needs_qs;
	bool beenonline;
	bool gpwrap;
	bool deferred_qs;
	struct rcu_node *mynode;
	long unsigned int grpmask;
	long unsigned int ticks_this_gp;
	struct rcu_segcblist cblist;
	long int qlen_last_fqs_check;
	long unsigned int n_force_qs_snap;
	long int blimit;
	int dynticks_snap;
	long int dynticks_nesting;
	long int dynticks_nmi_nesting;
	atomic_t dynticks;
	bool rcu_need_heavy_qs;
	bool rcu_urgent_qs;
	struct callback_head barrier_head;
	int exp_dynticks_snap;
	struct callback_head *nocb_head;
	struct callback_head **nocb_tail;
	atomic_long_t nocb_q_count;
	atomic_long_t nocb_q_count_lazy;
	struct callback_head *nocb_follower_head;
	struct callback_head **nocb_follower_tail;
	struct swait_queue_head nocb_wq;
	struct task_struct___62 *nocb_kthread;
	raw_spinlock_t nocb_lock;
	int nocb_defer_wakeup;
	struct timer_list nocb_timer;
	long: 64;
	struct callback_head *nocb_gp_head;
	struct callback_head **nocb_gp_tail;
	bool nocb_leader_sleep;
	struct rcu_data *nocb_next_follower;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rcu_data *nocb_leader;
	unsigned int softirq_snap;
	struct irq_work rcu_iw;
	bool rcu_iw_pending;
	long unsigned int rcu_iw_gp_seq;
	long unsigned int rcu_ofl_gp_seq;
	short int rcu_ofl_gp_flags;
	long unsigned int rcu_onl_gp_seq;
	short int rcu_onl_gp_flags;
	long unsigned int last_fqs_resched;
	int cpu;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
};

struct rcu_state {
	struct rcu_node node[261];
	struct rcu_node *level[4];
	int ncpus;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	u8 boost;
	long unsigned int gp_seq;
	struct task_struct___62 *gp_kthread;
	struct swait_queue_head gp_wq;
	short int gp_flags;
	short int gp_state;
	struct mutex barrier_mutex;
	atomic_t barrier_cpu_count;
	struct completion barrier_completion;
	long unsigned int barrier_sequence;
	struct mutex exp_mutex;
	struct mutex exp_wake_mutex;
	long unsigned int expedited_sequence;
	atomic_t expedited_need_qs;
	struct swait_queue_head expedited_wq;
	int ncpus_snap;
	long unsigned int jiffies_force_qs;
	long unsigned int jiffies_kick_kthreads;
	long unsigned int n_force_qs;
	long unsigned int gp_start;
	long unsigned int gp_activity;
	long unsigned int gp_req_activity;
	long unsigned int jiffies_stall;
	long unsigned int jiffies_resched;
	long unsigned int n_force_qs_gpstart;
	long unsigned int gp_max;
	const char *name;
	char abbr;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	raw_spinlock_t ofl_lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef void (*dr_release_t___4)(struct device___2 *, void *);

struct dma_devres {
	size_t size;
	void *vaddr;
	dma_addr_t dma_handle;
	long unsigned int attrs;
};

struct file___63;

struct kiocb___63;

struct vm_area_struct___63;

struct inode___64;

struct file_lock___63;

struct page___63;

struct file_operations___63 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___63 *, loff_t, int);
	ssize_t (*read)(struct file___63 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___63 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___63 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___63 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___63 *, bool);
	int (*iterate)(struct file___63 *, struct dir_context *);
	int (*iterate_shared)(struct file___63 *, struct dir_context *);
	__poll_t (*poll)(struct file___63 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___63 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___63 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___63 *, struct vm_area_struct___63 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___64 *, struct file___63 *);
	int (*flush)(struct file___63 *, fl_owner_t);
	int (*release)(struct inode___64 *, struct file___63 *);
	int (*fsync)(struct file___63 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___63 *, int);
	int (*lock)(struct file___63 *, int, struct file_lock___63 *);
	ssize_t (*sendpage)(struct file___63 *, struct page___63 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___63 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___63 *, int, struct file_lock___63 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___63 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___63 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___63 *, long int, struct file_lock___63 **, void **);
	long int (*fallocate)(struct file___63 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___63 *);
	ssize_t (*copy_file_range)(struct file___63 *, loff_t, struct file___63 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___63 *, loff_t, struct file___63 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___63 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___62 {
	u64 seqnum;
	struct vm_area_struct___63 *vmas[4];
};

struct page_frag___62 {
	struct page___63 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___62;

struct vm_struct___46;

struct task_struct___63 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___63 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___62 *mm;
	struct mm_struct___62 *active_mm;
	struct vmacache___62 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___63 *real_parent;
	struct task_struct___63 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___63 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___53 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___53 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___53 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___2 *ptracer_cred;
	const struct cred___2 *real_cred;
	const struct cred___2 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___63 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___13 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___62 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___63 *oom_reaper_list;
	struct vm_struct___46 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___39 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___63 *pgtable_t___62;

struct address_space___62;

struct dev_pagemap___62;

struct page___63 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___62 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___63 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___62 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___62 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___62 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___62;

struct lruvec___62 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___62 *pgdat;
};

struct zone___62 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___62 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___62 {
	struct zone___62 *zone;
	int zone_idx;
};

struct zonelist___62 {
	struct zoneref___62 _zonerefs[25];
};

struct pglist_data___62 {
	struct zone___62 node_zones[3];
	struct zonelist___62 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___63 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___63 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___62 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___63 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___63 *owner;
};

struct secondary_data___63 {
	void *stack;
	struct task_struct___63 *task;
	long int status;
};

struct blocking_notifier_head___62 {
	struct rw_semaphore___63 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___62;

struct vm_area_struct___63 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___63 *vm_next;
	struct vm_area_struct___63 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___62 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___62 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___63 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___62;

struct mm_struct___62 {
	struct {
		struct vm_area_struct___63 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___63 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___63 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___62 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___63 *owner;
		struct user_namespace___3 *user_ns;
		struct file___63 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___62 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___62;

struct address_space___62 {
	struct inode___64 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___63 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___62 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___62)(struct vm_area_struct___63 *, long unsigned int, const struct page___63 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___62)(struct page___63 *, void *);

struct device___57;

struct dev_pagemap___62 {
	dev_page_fault_t___62 page_fault;
	dev_page_free_t___62 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___57 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct dentry___63;

struct path___62 {
	struct vfsmount *mnt;
	struct dentry___63 *dentry;
};

struct file___63 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___62 f_path;
	struct inode___64 *f_inode;
	const struct file_operations___63 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___53 f_owner;
	const struct cred___2 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___62 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___62;

struct vm_operations_struct___62 {
	void (*open)(struct vm_area_struct___63 *);
	void (*close)(struct vm_area_struct___63 *);
	int (*split)(struct vm_area_struct___63 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___63 *);
	vm_fault_t (*fault)(struct vm_fault___62 *);
	vm_fault_t (*huge_fault)(struct vm_fault___62 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___62 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___63 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___62 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___62 *);
	int (*access)(struct vm_area_struct___63 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___63 *);
	int (*set_policy)(struct vm_area_struct___63 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___63 *, long unsigned int);
	struct page___63 * (*find_special_page)(struct vm_area_struct___63 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___62 {
	struct task_struct___63 *task;
	struct core_thread___62 *next;
};

struct core_state___62 {
	atomic_t nr_threads;
	struct core_thread___62 dumper;
	struct completion startup;
};

struct vm_fault___62 {
	struct vm_area_struct___63 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___63 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___63 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___62 prealloc_pte;
};

struct vm_struct___46 {
	struct vm_struct___46 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___63 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct kset___59;

struct kobj_type___59;

struct kernfs_node___60;

struct kobject___60 {
	const char *name;
	struct list_head entry;
	struct kobject___60 *parent;
	struct kset___59 *kset;
	struct kobj_type___59 *ktype;
	struct kernfs_node___60 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___57 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___57 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___57;

struct bus_type___57;

struct device_driver___57;

struct dev_pm_domain___57;

struct dma_map_ops___15;

struct fwnode_handle___43;

struct class___57;

struct attribute_group___57;

struct device___57 {
	struct device___57 *parent;
	struct device_private *p;
	struct kobject___60 kobj;
	const char *init_name;
	const struct device_type___57 *type;
	struct mutex mutex;
	struct bus_type___57 *bus;
	struct device_driver___57 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___57 power;
	struct dev_pm_domain___57 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___15 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___43 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___57 *class;
	const struct attribute_group___57 **groups;
	void (*release)(struct device___57 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___62;

struct super_block___63;

struct dentry___63 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___63 *d_parent;
	struct qstr d_name;
	struct inode___64 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___62 *d_op;
	struct super_block___63 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___62;

struct block_device___63;

struct inode___64 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___62 *i_op;
	struct super_block___63 *i_sb;
	struct address_space___62 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___63 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___63 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___62 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___63 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___62 {
	int (*d_revalidate)(struct dentry___63 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___63 *, unsigned int);
	int (*d_hash)(const struct dentry___63 *, struct qstr *);
	int (*d_compare)(const struct dentry___63 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___63 *);
	int (*d_init)(struct dentry___63 *);
	void (*d_release)(struct dentry___63 *);
	void (*d_prune)(struct dentry___63 *);
	void (*d_iput)(struct dentry___63 *, struct inode___64 *);
	char * (*d_dname)(struct dentry___63 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___62 *);
	int (*d_manage)(const struct path___62 *, bool);
	struct dentry___63 * (*d_real)(struct dentry___63 *, const struct inode___64 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___62;

struct mem_dqinfo___62 {
	struct quota_format_type___62 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___62;

struct quota_info___62 {
	unsigned int flags;
	struct rw_semaphore___63 dqio_sem;
	struct inode___64 *files[3];
	struct mem_dqinfo___62 info[3];
	const struct quota_format_ops___62 *ops[3];
};

struct rcuwait___62 {
	struct task_struct___63 *task;
};

struct percpu_rw_semaphore___62 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___63 rw_sem;
	struct rcuwait___62 writer;
	int readers_block;
};

struct sb_writers___62 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___62 rw_sem[3];
};

struct file_system_type___62;

struct super_operations___62;

struct dquot_operations___62;

struct quotactl_ops___62;

struct super_block___63 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___62 *s_type;
	const struct super_operations___62 *s_op;
	const struct dquot_operations___62 *dq_op;
	const struct quotactl_ops___62 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___63 *s_root;
	struct rw_semaphore___63 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___63 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___62 s_dquot;
	struct sb_writers___62 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___62 *s_d_op;
	int cleancache_poolid;
	struct shrinker___28 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___63 {
	struct file___63 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___63 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___63 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___63 *ia_file;
};

struct dquot___62 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___63 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___62 {
	int qf_fmt_id;
	const struct quota_format_ops___62 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___62 *qf_next;
};

struct quota_format_ops___62 {
	int (*check_quota_file)(struct super_block___63 *, int);
	int (*read_file_info)(struct super_block___63 *, int);
	int (*write_file_info)(struct super_block___63 *, int);
	int (*free_file_info)(struct super_block___63 *, int);
	int (*read_dqblk)(struct dquot___62 *);
	int (*commit_dqblk)(struct dquot___62 *);
	int (*release_dqblk)(struct dquot___62 *);
	int (*get_next_id)(struct super_block___63 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___62 {
	int (*write_dquot)(struct dquot___62 *);
	struct dquot___62 * (*alloc_dquot)(struct super_block___63 *, int);
	void (*destroy_dquot)(struct dquot___62 *);
	int (*acquire_dquot)(struct dquot___62 *);
	int (*release_dquot)(struct dquot___62 *);
	int (*mark_dirty)(struct dquot___62 *);
	int (*write_info)(struct super_block___63 *, int);
	qsize_t * (*get_reserved_space)(struct inode___64 *);
	int (*get_projid)(struct inode___64 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___64 *, qsize_t *);
	int (*get_next_id)(struct super_block___63 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___62 {
	int (*quota_on)(struct super_block___63 *, int, int, const struct path___62 *);
	int (*quota_off)(struct super_block___63 *, int);
	int (*quota_enable)(struct super_block___63 *, unsigned int);
	int (*quota_disable)(struct super_block___63 *, unsigned int);
	int (*quota_sync)(struct super_block___63 *, int);
	int (*set_info)(struct super_block___63 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___63 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___63 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___63 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___63 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___63 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___62 {
	int (*writepage)(struct page___63 *, struct writeback_control___3 *);
	int (*readpage)(struct file___63 *, struct page___63 *);
	int (*writepages)(struct address_space___62 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___63 *);
	int (*readpages)(struct file___63 *, struct address_space___62 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___63 *, struct address_space___62 *, loff_t, unsigned int, unsigned int, struct page___63 **, void **);
	int (*write_end)(struct file___63 *, struct address_space___62 *, loff_t, unsigned int, unsigned int, struct page___63 *, void *);
	sector_t (*bmap)(struct address_space___62 *, sector_t);
	void (*invalidatepage)(struct page___63 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___63 *, gfp_t);
	void (*freepage)(struct page___63 *);
	ssize_t (*direct_IO)(struct kiocb___63 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___62 *, struct page___63 *, struct page___63 *, enum migrate_mode);
	bool (*isolate_page)(struct page___63 *, isolate_mode_t);
	void (*putback_page)(struct page___63 *);
	int (*launder_page)(struct page___63 *);
	int (*is_partially_uptodate)(struct page___63 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___63 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___62 *, struct page___63 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___63 *, sector_t *);
	void (*swap_deactivate)(struct file___63 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___63 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___64 *bd_inode;
	struct super_block___63 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___63 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___62 {
	struct dentry___63 * (*lookup)(struct inode___64 *, struct dentry___63 *, unsigned int);
	const char * (*get_link)(struct dentry___63 *, struct inode___64 *, struct delayed_call *);
	int (*permission)(struct inode___64 *, int);
	struct posix_acl * (*get_acl)(struct inode___64 *, int);
	int (*readlink)(struct dentry___63 *, char *, int);
	int (*create)(struct inode___64 *, struct dentry___63 *, umode_t, bool);
	int (*link)(struct dentry___63 *, struct inode___64 *, struct dentry___63 *);
	int (*unlink)(struct inode___64 *, struct dentry___63 *);
	int (*symlink)(struct inode___64 *, struct dentry___63 *, const char *);
	int (*mkdir)(struct inode___64 *, struct dentry___63 *, umode_t);
	int (*rmdir)(struct inode___64 *, struct dentry___63 *);
	int (*mknod)(struct inode___64 *, struct dentry___63 *, umode_t, dev_t);
	int (*rename)(struct inode___64 *, struct dentry___63 *, struct inode___64 *, struct dentry___63 *, unsigned int);
	int (*setattr)(struct dentry___63 *, struct iattr___63 *);
	int (*getattr)(const struct path___62 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___63 *, char *, size_t);
	int (*fiemap)(struct inode___64 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___64 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___64 *, struct dentry___63 *, struct file___63 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___64 *, struct dentry___63 *, umode_t);
	int (*set_acl)(struct inode___64 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___62 {
	void (*fl_copy_lock)(struct file_lock___63 *, struct file_lock___63 *);
	void (*fl_release_private)(struct file_lock___63 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___62;

struct lock_manager_operations___62;

struct file_lock___63 {
	struct file_lock___63 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___63 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___62 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___62 *fl_ops;
	const struct lock_manager_operations___62 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___62 {
	int (*lm_compare_owner)(struct file_lock___63 *, struct file_lock___63 *);
	long unsigned int (*lm_owner_key)(struct file_lock___63 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___63 *);
	int (*lm_grant)(struct file_lock___63 *, int);
	bool (*lm_break)(struct file_lock___63 *);
	int (*lm_change)(struct file_lock___63 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___63 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___62 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___62 *fa_next;
	struct file___63 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___62 {
	const char *name;
	int fs_flags;
	struct dentry___63 * (*mount)(struct file_system_type___62 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___63 *);
	struct module___11 *owner;
	struct file_system_type___62 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___62 {
	struct inode___64 * (*alloc_inode)(struct super_block___63 *);
	void (*destroy_inode)(struct inode___64 *);
	void (*dirty_inode)(struct inode___64 *, int);
	int (*write_inode)(struct inode___64 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___64 *);
	void (*evict_inode)(struct inode___64 *);
	void (*put_super)(struct super_block___63 *);
	int (*sync_fs)(struct super_block___63 *, int);
	int (*freeze_super)(struct super_block___63 *);
	int (*freeze_fs)(struct super_block___63 *);
	int (*thaw_super)(struct super_block___63 *);
	int (*unfreeze_fs)(struct super_block___63 *);
	int (*statfs)(struct dentry___63 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___63 *, int *, char *);
	void (*umount_begin)(struct super_block___63 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___63 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___63 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___63 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___63 *);
	ssize_t (*quota_read)(struct super_block___63 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___63 *, int, const char *, size_t, loff_t);
	struct dquot___62 ** (*get_dquots)(struct inode___64 *);
	int (*bdev_try_to_free_page)(struct super_block___63 *, struct page___63 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___63 *, struct shrink_control___28 *);
	long int (*free_cached_objects)(struct super_block___63 *, struct shrink_control___28 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_attribute___60 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___60 *, struct kobj_attribute___60 *, char *);
	ssize_t (*store)(struct kobject___60 *, struct kobj_attribute___60 *, const char *, size_t);
};

typedef void compound_page_dtor___62(struct page___63 *);

struct kernfs_root___60;

struct kernfs_elem_dir___60 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___60 *root;
};

struct kernfs_syscall_ops___60;

struct kernfs_root___60 {
	struct kernfs_node___60 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___60 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___60 {
	struct kernfs_node___60 *target_kn;
};

struct kernfs_ops___60;

struct kernfs_elem_attr___60 {
	const struct kernfs_ops___60 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___60 *notify_next;
};

struct kernfs_node___60 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___60 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___60 dir;
		struct kernfs_elem_symlink___60 symlink;
		struct kernfs_elem_attr___60 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___60;

struct kernfs_ops___60 {
	int (*open)(struct kernfs_open_file___60 *);
	void (*release)(struct kernfs_open_file___60 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___60 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___60 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___60 *, struct vm_area_struct___63 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___60 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___60 {
	int (*remount_fs)(struct kernfs_root___60 *, int *, char *);
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___60 *);
	int (*mkdir)(struct kernfs_node___60 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___60 *);
	int (*rename)(struct kernfs_node___60 *, struct kernfs_node___60 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___60 *, struct kernfs_root___60 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___60 {
	struct kernfs_node___60 *kn;
	struct file___63 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___62 *vm_ops;
};

struct bin_attribute___57;

struct attribute_group___57 {
	const char *name;
	umode_t (*is_visible)(struct kobject___60 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___60 *, struct bin_attribute___57 *, int);
	struct attribute **attrs;
	struct bin_attribute___57 **bin_attrs;
};

struct bin_attribute___57 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___63 *, struct kobject___60 *, struct bin_attribute___57 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___63 *, struct kobject___60 *, struct bin_attribute___57 *, char *, loff_t, size_t);
	int (*mmap)(struct file___63 *, struct kobject___60 *, struct bin_attribute___57 *, struct vm_area_struct___63 *);
};

struct sysfs_ops___59 {
	ssize_t (*show)(struct kobject___60 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___60 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___59;

struct kset___59 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___60 kobj;
	const struct kset_uevent_ops___59 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___59 {
	void (*release)(struct kobject___60 *);
	const struct sysfs_ops___59 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___60 *);
	const void * (*namespace)(struct kobject___60 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___59 {
	int (* const filter)(struct kset___59 *, struct kobject___60 *);
	const char * (* const name)(struct kset___59 *, struct kobject___60 *);
	int (* const uevent)(struct kset___59 *, struct kobject___60 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___57 {
	int (*prepare)(struct device___57 *);
	void (*complete)(struct device___57 *);
	int (*suspend)(struct device___57 *);
	int (*resume)(struct device___57 *);
	int (*freeze)(struct device___57 *);
	int (*thaw)(struct device___57 *);
	int (*poweroff)(struct device___57 *);
	int (*restore)(struct device___57 *);
	int (*suspend_late)(struct device___57 *);
	int (*resume_early)(struct device___57 *);
	int (*freeze_late)(struct device___57 *);
	int (*thaw_early)(struct device___57 *);
	int (*poweroff_late)(struct device___57 *);
	int (*restore_early)(struct device___57 *);
	int (*suspend_noirq)(struct device___57 *);
	int (*resume_noirq)(struct device___57 *);
	int (*freeze_noirq)(struct device___57 *);
	int (*thaw_noirq)(struct device___57 *);
	int (*poweroff_noirq)(struct device___57 *);
	int (*restore_noirq)(struct device___57 *);
	int (*runtime_suspend)(struct device___57 *);
	int (*runtime_resume)(struct device___57 *);
	int (*runtime_idle)(struct device___57 *);
};

struct dev_pm_domain___57 {
	struct dev_pm_ops___57 ops;
	void (*detach)(struct device___57 *, bool);
	int (*activate)(struct device___57 *);
	void (*sync)(struct device___57 *);
	void (*dismiss)(struct device___57 *);
};

struct bus_type___57 {
	const char *name;
	const char *dev_name;
	struct device___57 *dev_root;
	const struct attribute_group___57 **bus_groups;
	const struct attribute_group___57 **dev_groups;
	const struct attribute_group___57 **drv_groups;
	int (*match)(struct device___57 *, struct device_driver___57 *);
	int (*uevent)(struct device___57 *, struct kobj_uevent_env *);
	int (*probe)(struct device___57 *);
	int (*remove)(struct device___57 *);
	void (*shutdown)(struct device___57 *);
	int (*online)(struct device___57 *);
	int (*offline)(struct device___57 *);
	int (*suspend)(struct device___57 *, pm_message_t);
	int (*resume)(struct device___57 *);
	int (*num_vf)(struct device___57 *);
	int (*dma_configure)(struct device___57 *);
	const struct dev_pm_ops___57 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___57 {
	const char *name;
	struct bus_type___57 *bus;
	struct module___11 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___57 *);
	int (*remove)(struct device___57 *);
	void (*shutdown)(struct device___57 *);
	int (*suspend)(struct device___57 *, pm_message_t);
	int (*resume)(struct device___57 *);
	const struct attribute_group___57 **groups;
	const struct dev_pm_ops___57 *pm;
	void (*coredump)(struct device___57 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___57 {
	const char *name;
	const struct attribute_group___57 **groups;
	int (*uevent)(struct device___57 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___57 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___57 *);
	const struct dev_pm_ops___57 *pm;
};

struct class___57 {
	const char *name;
	struct module___11 *owner;
	const struct attribute_group___57 **class_groups;
	const struct attribute_group___57 **dev_groups;
	struct kobject___60 *dev_kobj;
	int (*dev_uevent)(struct device___57 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___57 *, umode_t *);
	void (*class_release)(struct class___57 *);
	void (*dev_release)(struct device___57 *);
	int (*shutdown_pre)(struct device___57 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___57 *);
	const struct dev_pm_ops___57 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___15 {
	void * (*alloc)(struct device___57 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___57 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___57 *, struct vm_area_struct___63 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___57 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___57 *, struct page___63 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___57 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___57 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___57 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___57 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___57 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___57 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___57 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___57 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___57 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___57 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___57 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___57 *, u64);
	u64 (*get_required_mask)(struct device___57 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___43;

struct fwnode_handle___43 {
	struct fwnode_handle___43 *secondary;
	const struct fwnode_operations___43 *ops;
};

struct fwnode_reference_args___43;

struct fwnode_endpoint___43;

struct fwnode_operations___43 {
	struct fwnode_handle___43 * (*get)(struct fwnode_handle___43 *);
	void (*put)(struct fwnode_handle___43 *);
	bool (*device_is_available)(const struct fwnode_handle___43 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___43 *, const struct device___57 *);
	bool (*property_present)(const struct fwnode_handle___43 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___43 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___43 *, const char *, const char **, size_t);
	struct fwnode_handle___43 * (*get_parent)(const struct fwnode_handle___43 *);
	struct fwnode_handle___43 * (*get_next_child_node)(const struct fwnode_handle___43 *, struct fwnode_handle___43 *);
	struct fwnode_handle___43 * (*get_named_child_node)(const struct fwnode_handle___43 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___43 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___43 *);
	struct fwnode_handle___43 * (*graph_get_next_endpoint)(const struct fwnode_handle___43 *, struct fwnode_handle___43 *);
	struct fwnode_handle___43 * (*graph_get_remote_endpoint)(const struct fwnode_handle___43 *);
	struct fwnode_handle___43 * (*graph_get_port_parent)(struct fwnode_handle___43 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___43 *, struct fwnode_endpoint___43 *);
};

struct fwnode_endpoint___43 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___43 *local_fwnode;
};

struct fwnode_reference_args___43 {
	struct fwnode_handle___43 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

enum dma_sync_target {
	SYNC_FOR_CPU = 0,
	SYNC_FOR_DEVICE = 1,
};

struct file___64;

struct kiocb___64;

struct vm_area_struct___64;

struct inode___65;

struct file_lock___64;

struct page___64;

struct file_operations___64 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___64 *, loff_t, int);
	ssize_t (*read)(struct file___64 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___64 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___64 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___64 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___64 *, bool);
	int (*iterate)(struct file___64 *, struct dir_context *);
	int (*iterate_shared)(struct file___64 *, struct dir_context *);
	__poll_t (*poll)(struct file___64 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___64 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___64 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___64 *, struct vm_area_struct___64 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___65 *, struct file___64 *);
	int (*flush)(struct file___64 *, fl_owner_t);
	int (*release)(struct inode___65 *, struct file___64 *);
	int (*fsync)(struct file___64 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___64 *, int);
	int (*lock)(struct file___64 *, int, struct file_lock___64 *);
	ssize_t (*sendpage)(struct file___64 *, struct page___64 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___64 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___64 *, int, struct file_lock___64 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___64 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___64 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___64 *, long int, struct file_lock___64 **, void **);
	long int (*fallocate)(struct file___64 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___64 *);
	ssize_t (*copy_file_range)(struct file___64 *, loff_t, struct file___64 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___64 *, loff_t, struct file___64 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___64 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___63 {
	u64 seqnum;
	struct vm_area_struct___64 *vmas[4];
};

struct page_frag___63 {
	struct page___64 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___63;

struct vm_struct___47;

struct task_struct___64 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___64 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___63 *mm;
	struct mm_struct___63 *active_mm;
	struct vmacache___63 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___64 *real_parent;
	struct task_struct___64 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___64 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___53 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___53 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___53 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___2 *ptracer_cred;
	const struct cred___2 *real_cred;
	const struct cred___2 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___64 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___13 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___63 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___64 *oom_reaper_list;
	struct vm_struct___47 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___39 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___64 *pgtable_t___63;

struct address_space___63;

struct dev_pagemap___63;

struct page___64 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___63 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___64 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___63 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___63 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___63 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___63;

struct lruvec___63 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___63 *pgdat;
};

struct zone___63 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___63 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___63 {
	struct zone___63 *zone;
	int zone_idx;
};

struct zonelist___63 {
	struct zoneref___63 _zonerefs[25];
};

struct pglist_data___63 {
	struct zone___63 node_zones[3];
	struct zonelist___63 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___64 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___64 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___63 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___64 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___64 *owner;
};

struct secondary_data___64 {
	void *stack;
	struct task_struct___64 *task;
	long int status;
};

struct blocking_notifier_head___63 {
	struct rw_semaphore___64 rwsem;
	struct notifier_block *head;
};

struct kernfs_root___61;

struct kernfs_elem_dir___61 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___61 *root;
};

struct kernfs_node___61;

struct kernfs_syscall_ops___61;

struct kernfs_root___61 {
	struct kernfs_node___61 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___61 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___61 {
	struct kernfs_node___61 *target_kn;
};

struct kernfs_ops___61;

struct kernfs_elem_attr___61 {
	const struct kernfs_ops___61 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___61 *notify_next;
};

struct kernfs_node___61 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___61 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___61 dir;
		struct kernfs_elem_symlink___61 symlink;
		struct kernfs_elem_attr___61 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___61;

struct kernfs_ops___61 {
	int (*open)(struct kernfs_open_file___61 *);
	void (*release)(struct kernfs_open_file___61 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___61 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___61 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___61 *, struct vm_area_struct___64 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___61 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___61 {
	int (*remount_fs)(struct kernfs_root___61 *, int *, char *);
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___61 *);
	int (*mkdir)(struct kernfs_node___61 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___61 *);
	int (*rename)(struct kernfs_node___61 *, struct kernfs_node___61 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___61 *, struct kernfs_root___61 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_operations_struct___63;

struct kernfs_open_file___61 {
	struct kernfs_node___61 *kn;
	struct file___64 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___63 *vm_ops;
};

struct dentry___64;

struct path___63 {
	struct vfsmount *mnt;
	struct dentry___64 *dentry;
};

struct file___64 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___63 f_path;
	struct inode___65 *f_inode;
	const struct file_operations___64 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___53 f_owner;
	const struct cred___2 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___63 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___63;

struct vm_operations_struct___63 {
	void (*open)(struct vm_area_struct___64 *);
	void (*close)(struct vm_area_struct___64 *);
	int (*split)(struct vm_area_struct___64 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___64 *);
	vm_fault_t (*fault)(struct vm_fault___63 *);
	vm_fault_t (*huge_fault)(struct vm_fault___63 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___63 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___64 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___63 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___63 *);
	int (*access)(struct vm_area_struct___64 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___64 *);
	int (*set_policy)(struct vm_area_struct___64 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___64 *, long unsigned int);
	struct page___64 * (*find_special_page)(struct vm_area_struct___64 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_area_struct___64 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___64 *vm_next;
	struct vm_area_struct___64 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___63 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___63 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___64 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___61;

struct bin_attribute___58;

struct attribute_group___58 {
	const char *name;
	umode_t (*is_visible)(struct kobject___61 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___61 *, struct bin_attribute___58 *, int);
	struct attribute **attrs;
	struct bin_attribute___58 **bin_attrs;
};

struct kset___60;

struct kobj_type___60;

struct kobject___61 {
	const char *name;
	struct list_head entry;
	struct kobject___61 *parent;
	struct kset___60 *kset;
	struct kobj_type___60 *ktype;
	struct kernfs_node___61 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___58 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___64 *, struct kobject___61 *, struct bin_attribute___58 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___64 *, struct kobject___61 *, struct bin_attribute___58 *, char *, loff_t, size_t);
	int (*mmap)(struct file___64 *, struct kobject___61 *, struct bin_attribute___58 *, struct vm_area_struct___64 *);
};

struct sysfs_ops___60 {
	ssize_t (*show)(struct kobject___61 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___61 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___60;

struct kset___60 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___61 kobj;
	const struct kset_uevent_ops___60 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___60 {
	void (*release)(struct kobject___61 *);
	const struct sysfs_ops___60 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___61 *);
	const void * (*namespace)(struct kobject___61 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___60 {
	int (* const filter)(struct kset___60 *, struct kobject___61 *);
	const char * (* const name)(struct kset___60 *, struct kobject___61 *);
	int (* const uevent)(struct kset___60 *, struct kobject___61 *, struct kobj_uevent_env *);
};

struct kobj_attribute___61 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___61 *, struct kobj_attribute___61 *, char *);
	ssize_t (*store)(struct kobject___61 *, struct kobj_attribute___61 *, const char *, size_t);
};

struct device___58;

struct dev_pm_ops___58 {
	int (*prepare)(struct device___58 *);
	void (*complete)(struct device___58 *);
	int (*suspend)(struct device___58 *);
	int (*resume)(struct device___58 *);
	int (*freeze)(struct device___58 *);
	int (*thaw)(struct device___58 *);
	int (*poweroff)(struct device___58 *);
	int (*restore)(struct device___58 *);
	int (*suspend_late)(struct device___58 *);
	int (*resume_early)(struct device___58 *);
	int (*freeze_late)(struct device___58 *);
	int (*thaw_early)(struct device___58 *);
	int (*poweroff_late)(struct device___58 *);
	int (*restore_early)(struct device___58 *);
	int (*suspend_noirq)(struct device___58 *);
	int (*resume_noirq)(struct device___58 *);
	int (*freeze_noirq)(struct device___58 *);
	int (*thaw_noirq)(struct device___58 *);
	int (*poweroff_noirq)(struct device___58 *);
	int (*restore_noirq)(struct device___58 *);
	int (*runtime_suspend)(struct device___58 *);
	int (*runtime_resume)(struct device___58 *);
	int (*runtime_idle)(struct device___58 *);
};

struct dev_pm_info___58 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___58 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___58;

struct bus_type___58;

struct device_driver___58;

struct dev_pm_domain___58;

struct dma_map_ops___16;

struct fwnode_handle___44;

struct class___58;

struct device___58 {
	struct device___58 *parent;
	struct device_private *p;
	struct kobject___61 kobj;
	const char *init_name;
	const struct device_type___58 *type;
	struct mutex mutex;
	struct bus_type___58 *bus;
	struct device_driver___58 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___58 power;
	struct dev_pm_domain___58 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___16 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___44 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___58 *class;
	const struct attribute_group___58 **groups;
	void (*release)(struct device___58 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___58 {
	struct dev_pm_ops___58 ops;
	void (*detach)(struct device___58 *, bool);
	int (*activate)(struct device___58 *);
	void (*sync)(struct device___58 *);
	void (*dismiss)(struct device___58 *);
};

struct core_state___63;

struct mm_struct___63 {
	struct {
		struct vm_area_struct___64 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___64 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___64 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___63 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___64 *owner;
		struct user_namespace___3 *user_ns;
		struct file___64 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___63 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct vm_struct___47 {
	struct vm_struct___47 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___64 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bus_type___58 {
	const char *name;
	const char *dev_name;
	struct device___58 *dev_root;
	const struct attribute_group___58 **bus_groups;
	const struct attribute_group___58 **dev_groups;
	const struct attribute_group___58 **drv_groups;
	int (*match)(struct device___58 *, struct device_driver___58 *);
	int (*uevent)(struct device___58 *, struct kobj_uevent_env *);
	int (*probe)(struct device___58 *);
	int (*remove)(struct device___58 *);
	void (*shutdown)(struct device___58 *);
	int (*online)(struct device___58 *);
	int (*offline)(struct device___58 *);
	int (*suspend)(struct device___58 *, pm_message_t);
	int (*resume)(struct device___58 *);
	int (*num_vf)(struct device___58 *);
	int (*dma_configure)(struct device___58 *);
	const struct dev_pm_ops___58 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___58 {
	const char *name;
	struct bus_type___58 *bus;
	struct module___11 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___58 *);
	int (*remove)(struct device___58 *);
	void (*shutdown)(struct device___58 *);
	int (*suspend)(struct device___58 *, pm_message_t);
	int (*resume)(struct device___58 *);
	const struct attribute_group___58 **groups;
	const struct dev_pm_ops___58 *pm;
	void (*coredump)(struct device___58 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___58 {
	const char *name;
	const struct attribute_group___58 **groups;
	int (*uevent)(struct device___58 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___58 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___58 *);
	const struct dev_pm_ops___58 *pm;
};

struct class___58 {
	const char *name;
	struct module___11 *owner;
	const struct attribute_group___58 **class_groups;
	const struct attribute_group___58 **dev_groups;
	struct kobject___61 *dev_kobj;
	int (*dev_uevent)(struct device___58 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___58 *, umode_t *);
	void (*class_release)(struct class___58 *);
	void (*dev_release)(struct device___58 *);
	int (*shutdown_pre)(struct device___58 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___58 *);
	const struct dev_pm_ops___58 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___16 {
	void * (*alloc)(struct device___58 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___58 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___58 *, struct vm_area_struct___64 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___58 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___58 *, struct page___64 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___58 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___58 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___58 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___58 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___58 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___58 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___58 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___58 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___58 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___58 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___58 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___58 *, u64);
	u64 (*get_required_mask)(struct device___58 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___44;

struct fwnode_handle___44 {
	struct fwnode_handle___44 *secondary;
	const struct fwnode_operations___44 *ops;
};

struct address_space_operations___63;

struct address_space___63 {
	struct inode___65 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___64 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___63 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___63)(struct vm_area_struct___64 *, long unsigned int, const struct page___64 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___63)(struct page___64 *, void *);

struct dev_pagemap___63 {
	dev_page_fault_t___63 page_fault;
	dev_page_free_t___63 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___58 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___63 {
	struct task_struct___64 *task;
	struct core_thread___63 *next;
};

struct core_state___63 {
	atomic_t nr_threads;
	struct core_thread___63 dumper;
	struct completion startup;
};

struct vm_fault___63 {
	struct vm_area_struct___64 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___64 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___64 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___63 prealloc_pte;
};

struct dentry_operations___63;

struct super_block___64;

struct dentry___64 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___64 *d_parent;
	struct qstr d_name;
	struct inode___65 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___63 *d_op;
	struct super_block___64 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___63;

struct block_device___64;

struct inode___65 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___63 *i_op;
	struct super_block___64 *i_sb;
	struct address_space___63 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___64 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___64 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___63 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___64 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___63 {
	int (*d_revalidate)(struct dentry___64 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___64 *, unsigned int);
	int (*d_hash)(const struct dentry___64 *, struct qstr *);
	int (*d_compare)(const struct dentry___64 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___64 *);
	int (*d_init)(struct dentry___64 *);
	void (*d_release)(struct dentry___64 *);
	void (*d_prune)(struct dentry___64 *);
	void (*d_iput)(struct dentry___64 *, struct inode___65 *);
	char * (*d_dname)(struct dentry___64 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___63 *);
	int (*d_manage)(const struct path___63 *, bool);
	struct dentry___64 * (*d_real)(struct dentry___64 *, const struct inode___65 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___63;

struct mem_dqinfo___63 {
	struct quota_format_type___63 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___63;

struct quota_info___63 {
	unsigned int flags;
	struct rw_semaphore___64 dqio_sem;
	struct inode___65 *files[3];
	struct mem_dqinfo___63 info[3];
	const struct quota_format_ops___63 *ops[3];
};

struct rcuwait___63 {
	struct task_struct___64 *task;
};

struct percpu_rw_semaphore___63 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___64 rw_sem;
	struct rcuwait___63 writer;
	int readers_block;
};

struct sb_writers___63 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___63 rw_sem[3];
};

struct file_system_type___63;

struct super_operations___63;

struct dquot_operations___63;

struct quotactl_ops___63;

struct super_block___64 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___63 *s_type;
	const struct super_operations___63 *s_op;
	const struct dquot_operations___63 *dq_op;
	const struct quotactl_ops___63 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___64 *s_root;
	struct rw_semaphore___64 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___64 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___63 s_dquot;
	struct sb_writers___63 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___63 *s_d_op;
	int cleancache_poolid;
	struct shrinker___28 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___64 {
	struct file___64 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___64 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___64 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___64 *ia_file;
};

struct dquot___63 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___64 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___63 {
	int qf_fmt_id;
	const struct quota_format_ops___63 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___63 *qf_next;
};

struct quota_format_ops___63 {
	int (*check_quota_file)(struct super_block___64 *, int);
	int (*read_file_info)(struct super_block___64 *, int);
	int (*write_file_info)(struct super_block___64 *, int);
	int (*free_file_info)(struct super_block___64 *, int);
	int (*read_dqblk)(struct dquot___63 *);
	int (*commit_dqblk)(struct dquot___63 *);
	int (*release_dqblk)(struct dquot___63 *);
	int (*get_next_id)(struct super_block___64 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___63 {
	int (*write_dquot)(struct dquot___63 *);
	struct dquot___63 * (*alloc_dquot)(struct super_block___64 *, int);
	void (*destroy_dquot)(struct dquot___63 *);
	int (*acquire_dquot)(struct dquot___63 *);
	int (*release_dquot)(struct dquot___63 *);
	int (*mark_dirty)(struct dquot___63 *);
	int (*write_info)(struct super_block___64 *, int);
	qsize_t * (*get_reserved_space)(struct inode___65 *);
	int (*get_projid)(struct inode___65 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___65 *, qsize_t *);
	int (*get_next_id)(struct super_block___64 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___63 {
	int (*quota_on)(struct super_block___64 *, int, int, const struct path___63 *);
	int (*quota_off)(struct super_block___64 *, int);
	int (*quota_enable)(struct super_block___64 *, unsigned int);
	int (*quota_disable)(struct super_block___64 *, unsigned int);
	int (*quota_sync)(struct super_block___64 *, int);
	int (*set_info)(struct super_block___64 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___64 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___64 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___64 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___64 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___64 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___63 {
	int (*writepage)(struct page___64 *, struct writeback_control___3 *);
	int (*readpage)(struct file___64 *, struct page___64 *);
	int (*writepages)(struct address_space___63 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___64 *);
	int (*readpages)(struct file___64 *, struct address_space___63 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___64 *, struct address_space___63 *, loff_t, unsigned int, unsigned int, struct page___64 **, void **);
	int (*write_end)(struct file___64 *, struct address_space___63 *, loff_t, unsigned int, unsigned int, struct page___64 *, void *);
	sector_t (*bmap)(struct address_space___63 *, sector_t);
	void (*invalidatepage)(struct page___64 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___64 *, gfp_t);
	void (*freepage)(struct page___64 *);
	ssize_t (*direct_IO)(struct kiocb___64 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___63 *, struct page___64 *, struct page___64 *, enum migrate_mode);
	bool (*isolate_page)(struct page___64 *, isolate_mode_t);
	void (*putback_page)(struct page___64 *);
	int (*launder_page)(struct page___64 *);
	int (*is_partially_uptodate)(struct page___64 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___64 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___63 *, struct page___64 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___64 *, sector_t *);
	void (*swap_deactivate)(struct file___64 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___64 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___65 *bd_inode;
	struct super_block___64 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___64 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___63 {
	struct dentry___64 * (*lookup)(struct inode___65 *, struct dentry___64 *, unsigned int);
	const char * (*get_link)(struct dentry___64 *, struct inode___65 *, struct delayed_call *);
	int (*permission)(struct inode___65 *, int);
	struct posix_acl * (*get_acl)(struct inode___65 *, int);
	int (*readlink)(struct dentry___64 *, char *, int);
	int (*create)(struct inode___65 *, struct dentry___64 *, umode_t, bool);
	int (*link)(struct dentry___64 *, struct inode___65 *, struct dentry___64 *);
	int (*unlink)(struct inode___65 *, struct dentry___64 *);
	int (*symlink)(struct inode___65 *, struct dentry___64 *, const char *);
	int (*mkdir)(struct inode___65 *, struct dentry___64 *, umode_t);
	int (*rmdir)(struct inode___65 *, struct dentry___64 *);
	int (*mknod)(struct inode___65 *, struct dentry___64 *, umode_t, dev_t);
	int (*rename)(struct inode___65 *, struct dentry___64 *, struct inode___65 *, struct dentry___64 *, unsigned int);
	int (*setattr)(struct dentry___64 *, struct iattr___64 *);
	int (*getattr)(const struct path___63 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___64 *, char *, size_t);
	int (*fiemap)(struct inode___65 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___65 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___65 *, struct dentry___64 *, struct file___64 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___65 *, struct dentry___64 *, umode_t);
	int (*set_acl)(struct inode___65 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___63 {
	void (*fl_copy_lock)(struct file_lock___64 *, struct file_lock___64 *);
	void (*fl_release_private)(struct file_lock___64 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___63;

struct lock_manager_operations___63;

struct file_lock___64 {
	struct file_lock___64 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___64 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___63 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___63 *fl_ops;
	const struct lock_manager_operations___63 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___63 {
	int (*lm_compare_owner)(struct file_lock___64 *, struct file_lock___64 *);
	long unsigned int (*lm_owner_key)(struct file_lock___64 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___64 *);
	int (*lm_grant)(struct file_lock___64 *, int);
	bool (*lm_break)(struct file_lock___64 *);
	int (*lm_change)(struct file_lock___64 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___64 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___63 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___63 *fa_next;
	struct file___64 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___63 {
	const char *name;
	int fs_flags;
	struct dentry___64 * (*mount)(struct file_system_type___63 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___64 *);
	struct module___11 *owner;
	struct file_system_type___63 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___63 {
	struct inode___65 * (*alloc_inode)(struct super_block___64 *);
	void (*destroy_inode)(struct inode___65 *);
	void (*dirty_inode)(struct inode___65 *, int);
	int (*write_inode)(struct inode___65 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___65 *);
	void (*evict_inode)(struct inode___65 *);
	void (*put_super)(struct super_block___64 *);
	int (*sync_fs)(struct super_block___64 *, int);
	int (*freeze_super)(struct super_block___64 *);
	int (*freeze_fs)(struct super_block___64 *);
	int (*thaw_super)(struct super_block___64 *);
	int (*unfreeze_fs)(struct super_block___64 *);
	int (*statfs)(struct dentry___64 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___64 *, int *, char *);
	void (*umount_begin)(struct super_block___64 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___64 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___64 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___64 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___64 *);
	ssize_t (*quota_read)(struct super_block___64 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___64 *, int, const char *, size_t, loff_t);
	struct dquot___63 ** (*get_dquots)(struct inode___65 *);
	int (*bdev_try_to_free_page)(struct super_block___64 *, struct page___64 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___64 *, struct shrink_control___28 *);
	long int (*free_cached_objects)(struct super_block___64 *, struct shrink_control___28 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___63(struct page___64 *);

struct fwnode_reference_args___44;

struct fwnode_endpoint___44;

struct fwnode_operations___44 {
	struct fwnode_handle___44 * (*get)(struct fwnode_handle___44 *);
	void (*put)(struct fwnode_handle___44 *);
	bool (*device_is_available)(const struct fwnode_handle___44 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___44 *, const struct device___58 *);
	bool (*property_present)(const struct fwnode_handle___44 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___44 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___44 *, const char *, const char **, size_t);
	struct fwnode_handle___44 * (*get_parent)(const struct fwnode_handle___44 *);
	struct fwnode_handle___44 * (*get_next_child_node)(const struct fwnode_handle___44 *, struct fwnode_handle___44 *);
	struct fwnode_handle___44 * (*get_named_child_node)(const struct fwnode_handle___44 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___44 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___44 *);
	struct fwnode_handle___44 * (*graph_get_next_endpoint)(const struct fwnode_handle___44 *, struct fwnode_handle___44 *);
	struct fwnode_handle___44 * (*graph_get_remote_endpoint)(const struct fwnode_handle___44 *);
	struct fwnode_handle___44 * (*graph_get_port_parent)(struct fwnode_handle___44 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___44 *, struct fwnode_endpoint___44 *);
};

struct fwnode_endpoint___44 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___44 *local_fwnode;
};

struct fwnode_reference_args___44 {
	struct fwnode_handle___44 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct module___57;

struct file___65;

struct kiocb___65;

struct vm_area_struct___65;

struct inode___66;

struct file_lock___65;

struct page___65;

struct file_operations___65 {
	struct module___57 *owner;
	loff_t (*llseek)(struct file___65 *, loff_t, int);
	ssize_t (*read)(struct file___65 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___65 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___65 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___65 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___65 *, bool);
	int (*iterate)(struct file___65 *, struct dir_context *);
	int (*iterate_shared)(struct file___65 *, struct dir_context *);
	__poll_t (*poll)(struct file___65 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___65 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___65 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___65 *, struct vm_area_struct___65 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___66 *, struct file___65 *);
	int (*flush)(struct file___65 *, fl_owner_t);
	int (*release)(struct inode___66 *, struct file___65 *);
	int (*fsync)(struct file___65 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___65 *, int);
	int (*lock)(struct file___65 *, int, struct file_lock___65 *);
	ssize_t (*sendpage)(struct file___65 *, struct page___65 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___65 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___65 *, int, struct file_lock___65 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___65 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___65 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___65 *, long int, struct file_lock___65 **, void **);
	long int (*fallocate)(struct file___65 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___65 *);
	ssize_t (*copy_file_range)(struct file___65 *, loff_t, struct file___65 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___65 *, loff_t, struct file___65 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___65 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___65 *pgtable_t___64;

struct address_space___64;

struct mm_struct___64;

struct dev_pagemap___64;

struct page___65 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___64 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___65 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___64 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___64 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___64 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct vmacache___64 {
	u64 seqnum;
	struct vm_area_struct___65 *vmas[4];
};

struct vm_operations_struct___64;

struct vm_area_struct___65 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___65 *vm_next;
	struct vm_area_struct___65 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___64 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___64 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___65 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct page_frag___64 {
	struct page___65 *page;
	__u32 offset;
	__u32 size;
};

struct vm_struct___48;

struct task_struct___65 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___65 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___64 *mm;
	struct mm_struct___64 *active_mm;
	struct vmacache___64 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___65 *real_parent;
	struct task_struct___65 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___65 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___53 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___53 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___53 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___2 *ptracer_cred;
	const struct cred___2 *real_cred;
	const struct cred___2 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___65 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___13 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___64 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___65 *oom_reaper_list;
	struct vm_struct___48 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___39 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rw_semaphore___65 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___65 *owner;
};

struct core_state___64;

struct mm_struct___64 {
	struct {
		struct vm_area_struct___65 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___65 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___65 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___64 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___65 *owner;
		struct user_namespace___3 *user_ns;
		struct file___65 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___64 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct secondary_data___65 {
	void *stack;
	struct task_struct___65 *task;
	long int status;
};

struct address_space_operations___64;

struct address_space___64 {
	struct inode___66 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___65 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___64 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___64)(struct vm_area_struct___65 *, long unsigned int, const struct page___65 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___64)(struct page___65 *, void *);

struct device___59;

struct dev_pagemap___64 {
	dev_page_fault_t___64 page_fault;
	dev_page_free_t___64 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___59 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct dentry___65;

struct path___64 {
	struct vfsmount *mnt;
	struct dentry___65 *dentry;
};

struct file___65 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___64 f_path;
	struct inode___66 *f_inode;
	const struct file_operations___65 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___53 f_owner;
	const struct cred___2 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___64 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___64;

struct vm_operations_struct___64 {
	void (*open)(struct vm_area_struct___65 *);
	void (*close)(struct vm_area_struct___65 *);
	int (*split)(struct vm_area_struct___65 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___65 *);
	vm_fault_t (*fault)(struct vm_fault___64 *);
	vm_fault_t (*huge_fault)(struct vm_fault___64 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___64 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___65 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___64 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___64 *);
	int (*access)(struct vm_area_struct___65 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___65 *);
	int (*set_policy)(struct vm_area_struct___65 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___65 *, long unsigned int);
	struct page___65 * (*find_special_page)(struct vm_area_struct___65 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___64 {
	struct task_struct___65 *task;
	struct core_thread___64 *next;
};

struct core_state___64 {
	atomic_t nr_threads;
	struct core_thread___64 dumper;
	struct completion startup;
};

struct vm_fault___64 {
	struct vm_area_struct___65 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___65 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___65 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___64 prealloc_pte;
};

struct vm_struct___48 {
	struct vm_struct___48 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___65 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct fwnode_operations___45;

struct fwnode_handle___45 {
	struct fwnode_handle___45 *secondary;
	const struct fwnode_operations___45 *ops;
};

struct fwnode_reference_args___45;

struct fwnode_endpoint___45;

struct fwnode_operations___45 {
	struct fwnode_handle___45 * (*get)(struct fwnode_handle___45 *);
	void (*put)(struct fwnode_handle___45 *);
	bool (*device_is_available)(const struct fwnode_handle___45 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___45 *, const struct device___59 *);
	bool (*property_present)(const struct fwnode_handle___45 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___45 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___45 *, const char *, const char **, size_t);
	struct fwnode_handle___45 * (*get_parent)(const struct fwnode_handle___45 *);
	struct fwnode_handle___45 * (*get_next_child_node)(const struct fwnode_handle___45 *, struct fwnode_handle___45 *);
	struct fwnode_handle___45 * (*get_named_child_node)(const struct fwnode_handle___45 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___45 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___45 *);
	struct fwnode_handle___45 * (*graph_get_next_endpoint)(const struct fwnode_handle___45 *, struct fwnode_handle___45 *);
	struct fwnode_handle___45 * (*graph_get_remote_endpoint)(const struct fwnode_handle___45 *);
	struct fwnode_handle___45 * (*graph_get_port_parent)(struct fwnode_handle___45 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___45 *, struct fwnode_endpoint___45 *);
};

struct fwnode_endpoint___45 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___45 *local_fwnode;
};

struct fwnode_reference_args___45 {
	struct fwnode_handle___45 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct kset___61;

struct kobj_type___61;

struct kernfs_node___62;

struct kobject___62 {
	const char *name;
	struct list_head entry;
	struct kobject___62 *parent;
	struct kset___61 *kset;
	struct kobj_type___61 *ktype;
	struct kernfs_node___62 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___59 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___59 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___59;

struct bus_type___59;

struct device_driver___59;

struct dev_pm_domain___59;

struct dma_map_ops___17;

struct device_node___20;

struct class___59;

struct attribute_group___59;

struct device___59 {
	struct device___59 *parent;
	struct device_private *p;
	struct kobject___62 kobj;
	const char *init_name;
	const struct device_type___59 *type;
	struct mutex mutex;
	struct bus_type___59 *bus;
	struct device_driver___59 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___59 power;
	struct dev_pm_domain___59 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___17 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___20 *of_node;
	struct fwnode_handle___45 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___59 *class;
	const struct attribute_group___59 **groups;
	void (*release)(struct device___59 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct pglist_data___64;

struct lruvec___64 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___64 *pgdat;
};

struct zone___64 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___64 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___64 {
	struct zone___64 *zone;
	int zone_idx;
};

struct zonelist___64 {
	struct zoneref___64 _zonerefs[25];
};

struct pglist_data___64 {
	struct zone___64 node_zones[3];
	struct zonelist___64 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___65 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___65 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___64 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___64 {
	struct rw_semaphore___65 rwsem;
	struct notifier_block *head;
};

struct kernfs_root___62;

struct kernfs_elem_dir___62 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___62 *root;
};

struct kernfs_syscall_ops___62;

struct kernfs_root___62 {
	struct kernfs_node___62 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___62 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___62 {
	struct kernfs_node___62 *target_kn;
};

struct kernfs_ops___62;

struct kernfs_elem_attr___62 {
	const struct kernfs_ops___62 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___62 *notify_next;
};

struct kernfs_node___62 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___62 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___62 dir;
		struct kernfs_elem_symlink___62 symlink;
		struct kernfs_elem_attr___62 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___62;

struct kernfs_ops___62 {
	int (*open)(struct kernfs_open_file___62 *);
	void (*release)(struct kernfs_open_file___62 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___62 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___62 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___62 *, struct vm_area_struct___65 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___62 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___62 {
	int (*remount_fs)(struct kernfs_root___62 *, int *, char *);
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___62 *);
	int (*mkdir)(struct kernfs_node___62 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___62 *);
	int (*rename)(struct kernfs_node___62 *, struct kernfs_node___62 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___62 *, struct kernfs_root___62 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___62 {
	struct kernfs_node___62 *kn;
	struct file___65 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___64 *vm_ops;
};

struct bin_attribute___59;

struct attribute_group___59 {
	const char *name;
	umode_t (*is_visible)(struct kobject___62 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___62 *, struct bin_attribute___59 *, int);
	struct attribute **attrs;
	struct bin_attribute___59 **bin_attrs;
};

struct bin_attribute___59 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___65 *, struct kobject___62 *, struct bin_attribute___59 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___65 *, struct kobject___62 *, struct bin_attribute___59 *, char *, loff_t, size_t);
	int (*mmap)(struct file___65 *, struct kobject___62 *, struct bin_attribute___59 *, struct vm_area_struct___65 *);
};

struct sysfs_ops___61 {
	ssize_t (*show)(struct kobject___62 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___62 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___61;

struct kset___61 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___62 kobj;
	const struct kset_uevent_ops___61 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___61 {
	void (*release)(struct kobject___62 *);
	const struct sysfs_ops___61 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___62 *);
	const void * (*namespace)(struct kobject___62 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___61 {
	int (* const filter)(struct kset___61 *, struct kobject___62 *);
	const char * (* const name)(struct kset___61 *, struct kobject___62 *);
	int (* const uevent)(struct kset___61 *, struct kobject___62 *, struct kobj_uevent_env *);
};

struct kobj_attribute___62 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___62 *, struct kobj_attribute___62 *, char *);
	ssize_t (*store)(struct kobject___62 *, struct kobj_attribute___62 *, const char *, size_t);
};

struct kernel_param___54;

struct kernel_param_ops___54 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___54 *);
	int (*get)(char *, const struct kernel_param___54 *);
	void (*free)(void *);
};

struct kparam_array___54;

struct kernel_param___54 {
	const char *name;
	struct module___57 *mod;
	const struct kernel_param_ops___54 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___54 *arr;
	};
};

struct kparam_array___54 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___54 *ops;
	void *elem;
};

struct module_kobject___54 {
	struct kobject___62 kobj;
	struct module___57 *mod;
	struct kobject___62 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___54 {
	struct module___57 *mod;
	struct latch_tree_node node;
};

struct module_layout___54 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___54 mtn;
};

struct module_attribute___54;

struct module___57 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___54 mkobj;
	struct module_attribute___54 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___62 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___54 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___54 core_layout;
	struct module_layout___54 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___54 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___54 *, struct module_kobject___54 *, char *);
	ssize_t (*store)(struct module_attribute___54 *, struct module_kobject___54 *, const char *, size_t);
	void (*setup)(struct module___57 *, const char *);
	int (*test)(struct module___57 *);
	void (*free)(struct module___57 *);
};

struct dev_pm_ops___59 {
	int (*prepare)(struct device___59 *);
	void (*complete)(struct device___59 *);
	int (*suspend)(struct device___59 *);
	int (*resume)(struct device___59 *);
	int (*freeze)(struct device___59 *);
	int (*thaw)(struct device___59 *);
	int (*poweroff)(struct device___59 *);
	int (*restore)(struct device___59 *);
	int (*suspend_late)(struct device___59 *);
	int (*resume_early)(struct device___59 *);
	int (*freeze_late)(struct device___59 *);
	int (*thaw_early)(struct device___59 *);
	int (*poweroff_late)(struct device___59 *);
	int (*restore_early)(struct device___59 *);
	int (*suspend_noirq)(struct device___59 *);
	int (*resume_noirq)(struct device___59 *);
	int (*freeze_noirq)(struct device___59 *);
	int (*thaw_noirq)(struct device___59 *);
	int (*poweroff_noirq)(struct device___59 *);
	int (*restore_noirq)(struct device___59 *);
	int (*runtime_suspend)(struct device___59 *);
	int (*runtime_resume)(struct device___59 *);
	int (*runtime_idle)(struct device___59 *);
};

struct dev_pm_domain___59 {
	struct dev_pm_ops___59 ops;
	void (*detach)(struct device___59 *, bool);
	int (*activate)(struct device___59 *);
	void (*sync)(struct device___59 *);
	void (*dismiss)(struct device___59 *);
};

struct bus_type___59 {
	const char *name;
	const char *dev_name;
	struct device___59 *dev_root;
	const struct attribute_group___59 **bus_groups;
	const struct attribute_group___59 **dev_groups;
	const struct attribute_group___59 **drv_groups;
	int (*match)(struct device___59 *, struct device_driver___59 *);
	int (*uevent)(struct device___59 *, struct kobj_uevent_env *);
	int (*probe)(struct device___59 *);
	int (*remove)(struct device___59 *);
	void (*shutdown)(struct device___59 *);
	int (*online)(struct device___59 *);
	int (*offline)(struct device___59 *);
	int (*suspend)(struct device___59 *, pm_message_t);
	int (*resume)(struct device___59 *);
	int (*num_vf)(struct device___59 *);
	int (*dma_configure)(struct device___59 *);
	const struct dev_pm_ops___59 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___59 {
	const char *name;
	struct bus_type___59 *bus;
	struct module___57 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___59 *);
	int (*remove)(struct device___59 *);
	void (*shutdown)(struct device___59 *);
	int (*suspend)(struct device___59 *, pm_message_t);
	int (*resume)(struct device___59 *);
	const struct attribute_group___59 **groups;
	const struct dev_pm_ops___59 *pm;
	void (*coredump)(struct device___59 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___59 {
	const char *name;
	const struct attribute_group___59 **groups;
	int (*uevent)(struct device___59 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___59 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___59 *);
	const struct dev_pm_ops___59 *pm;
};

struct class___59 {
	const char *name;
	struct module___57 *owner;
	const struct attribute_group___59 **class_groups;
	const struct attribute_group___59 **dev_groups;
	struct kobject___62 *dev_kobj;
	int (*dev_uevent)(struct device___59 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___59 *, umode_t *);
	void (*class_release)(struct class___59 *);
	void (*dev_release)(struct device___59 *);
	int (*shutdown_pre)(struct device___59 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___59 *);
	const struct dev_pm_ops___59 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___17 {
	void * (*alloc)(struct device___59 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___59 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___59 *, struct vm_area_struct___65 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___59 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___59 *, struct page___65 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___59 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___59 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___59 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___59 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___59 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___59 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___59 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___59 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___59 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___59 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___59 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___59 *, u64);
	u64 (*get_required_mask)(struct device___59 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct dma_coherent_mem {
	void *virt_base;
	dma_addr_t device_base;
	long unsigned int pfn_base;
	int size;
	int flags;
	long unsigned int *bitmap;
	spinlock_t spinlock;
	bool use_dev_dma_pfn_offset;
};

struct property___19;

struct device_node___20 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___45 fwnode;
	struct property___19 *properties;
	struct property___19 *deadprops;
	struct device_node___20 *parent;
	struct device_node___20 *child;
	struct device_node___20 *sibling;
	struct kobject___62 kobj;
	long unsigned int _flags;
	void *data;
};

struct dentry_operations___64;

struct super_block___65;

struct dentry___65 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___65 *d_parent;
	struct qstr d_name;
	struct inode___66 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___64 *d_op;
	struct super_block___65 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___64;

struct block_device___65;

struct inode___66 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___64 *i_op;
	struct super_block___65 *i_sb;
	struct address_space___64 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___65 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___65 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___64 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___65 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___64 {
	int (*d_revalidate)(struct dentry___65 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___65 *, unsigned int);
	int (*d_hash)(const struct dentry___65 *, struct qstr *);
	int (*d_compare)(const struct dentry___65 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___65 *);
	int (*d_init)(struct dentry___65 *);
	void (*d_release)(struct dentry___65 *);
	void (*d_prune)(struct dentry___65 *);
	void (*d_iput)(struct dentry___65 *, struct inode___66 *);
	char * (*d_dname)(struct dentry___65 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___64 *);
	int (*d_manage)(const struct path___64 *, bool);
	struct dentry___65 * (*d_real)(struct dentry___65 *, const struct inode___66 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___64;

struct mem_dqinfo___64 {
	struct quota_format_type___64 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___64;

struct quota_info___64 {
	unsigned int flags;
	struct rw_semaphore___65 dqio_sem;
	struct inode___66 *files[3];
	struct mem_dqinfo___64 info[3];
	const struct quota_format_ops___64 *ops[3];
};

struct rcuwait___64 {
	struct task_struct___65 *task;
};

struct percpu_rw_semaphore___64 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___65 rw_sem;
	struct rcuwait___64 writer;
	int readers_block;
};

struct sb_writers___64 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___64 rw_sem[3];
};

struct file_system_type___64;

struct super_operations___64;

struct dquot_operations___64;

struct quotactl_ops___64;

struct super_block___65 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___64 *s_type;
	const struct super_operations___64 *s_op;
	const struct dquot_operations___64 *dq_op;
	const struct quotactl_ops___64 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___65 *s_root;
	struct rw_semaphore___65 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___65 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___64 s_dquot;
	struct sb_writers___64 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___64 *s_d_op;
	int cleancache_poolid;
	struct shrinker___28 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___65 {
	struct file___65 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___65 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___65 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___65 *ia_file;
};

struct dquot___64 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___65 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___64 {
	int qf_fmt_id;
	const struct quota_format_ops___64 *qf_ops;
	struct module___57 *qf_owner;
	struct quota_format_type___64 *qf_next;
};

struct quota_format_ops___64 {
	int (*check_quota_file)(struct super_block___65 *, int);
	int (*read_file_info)(struct super_block___65 *, int);
	int (*write_file_info)(struct super_block___65 *, int);
	int (*free_file_info)(struct super_block___65 *, int);
	int (*read_dqblk)(struct dquot___64 *);
	int (*commit_dqblk)(struct dquot___64 *);
	int (*release_dqblk)(struct dquot___64 *);
	int (*get_next_id)(struct super_block___65 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___64 {
	int (*write_dquot)(struct dquot___64 *);
	struct dquot___64 * (*alloc_dquot)(struct super_block___65 *, int);
	void (*destroy_dquot)(struct dquot___64 *);
	int (*acquire_dquot)(struct dquot___64 *);
	int (*release_dquot)(struct dquot___64 *);
	int (*mark_dirty)(struct dquot___64 *);
	int (*write_info)(struct super_block___65 *, int);
	qsize_t * (*get_reserved_space)(struct inode___66 *);
	int (*get_projid)(struct inode___66 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___66 *, qsize_t *);
	int (*get_next_id)(struct super_block___65 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___64 {
	int (*quota_on)(struct super_block___65 *, int, int, const struct path___64 *);
	int (*quota_off)(struct super_block___65 *, int);
	int (*quota_enable)(struct super_block___65 *, unsigned int);
	int (*quota_disable)(struct super_block___65 *, unsigned int);
	int (*quota_sync)(struct super_block___65 *, int);
	int (*set_info)(struct super_block___65 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___65 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___65 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___65 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___65 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___65 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___64 {
	int (*writepage)(struct page___65 *, struct writeback_control___3 *);
	int (*readpage)(struct file___65 *, struct page___65 *);
	int (*writepages)(struct address_space___64 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___65 *);
	int (*readpages)(struct file___65 *, struct address_space___64 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___65 *, struct address_space___64 *, loff_t, unsigned int, unsigned int, struct page___65 **, void **);
	int (*write_end)(struct file___65 *, struct address_space___64 *, loff_t, unsigned int, unsigned int, struct page___65 *, void *);
	sector_t (*bmap)(struct address_space___64 *, sector_t);
	void (*invalidatepage)(struct page___65 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___65 *, gfp_t);
	void (*freepage)(struct page___65 *);
	ssize_t (*direct_IO)(struct kiocb___65 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___64 *, struct page___65 *, struct page___65 *, enum migrate_mode);
	bool (*isolate_page)(struct page___65 *, isolate_mode_t);
	void (*putback_page)(struct page___65 *);
	int (*launder_page)(struct page___65 *);
	int (*is_partially_uptodate)(struct page___65 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___65 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___64 *, struct page___65 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___65 *, sector_t *);
	void (*swap_deactivate)(struct file___65 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___65 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___66 *bd_inode;
	struct super_block___65 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___65 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___64 {
	struct dentry___65 * (*lookup)(struct inode___66 *, struct dentry___65 *, unsigned int);
	const char * (*get_link)(struct dentry___65 *, struct inode___66 *, struct delayed_call *);
	int (*permission)(struct inode___66 *, int);
	struct posix_acl * (*get_acl)(struct inode___66 *, int);
	int (*readlink)(struct dentry___65 *, char *, int);
	int (*create)(struct inode___66 *, struct dentry___65 *, umode_t, bool);
	int (*link)(struct dentry___65 *, struct inode___66 *, struct dentry___65 *);
	int (*unlink)(struct inode___66 *, struct dentry___65 *);
	int (*symlink)(struct inode___66 *, struct dentry___65 *, const char *);
	int (*mkdir)(struct inode___66 *, struct dentry___65 *, umode_t);
	int (*rmdir)(struct inode___66 *, struct dentry___65 *);
	int (*mknod)(struct inode___66 *, struct dentry___65 *, umode_t, dev_t);
	int (*rename)(struct inode___66 *, struct dentry___65 *, struct inode___66 *, struct dentry___65 *, unsigned int);
	int (*setattr)(struct dentry___65 *, struct iattr___65 *);
	int (*getattr)(const struct path___64 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___65 *, char *, size_t);
	int (*fiemap)(struct inode___66 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___66 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___66 *, struct dentry___65 *, struct file___65 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___66 *, struct dentry___65 *, umode_t);
	int (*set_acl)(struct inode___66 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___64 {
	void (*fl_copy_lock)(struct file_lock___65 *, struct file_lock___65 *);
	void (*fl_release_private)(struct file_lock___65 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___64;

struct lock_manager_operations___64;

struct file_lock___65 {
	struct file_lock___65 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___65 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___64 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___64 *fl_ops;
	const struct lock_manager_operations___64 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___64 {
	int (*lm_compare_owner)(struct file_lock___65 *, struct file_lock___65 *);
	long unsigned int (*lm_owner_key)(struct file_lock___65 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___65 *);
	int (*lm_grant)(struct file_lock___65 *, int);
	bool (*lm_break)(struct file_lock___65 *);
	int (*lm_change)(struct file_lock___65 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___65 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___64 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___64 *fa_next;
	struct file___65 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___64 {
	const char *name;
	int fs_flags;
	struct dentry___65 * (*mount)(struct file_system_type___64 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___65 *);
	struct module___57 *owner;
	struct file_system_type___64 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___64 {
	struct inode___66 * (*alloc_inode)(struct super_block___65 *);
	void (*destroy_inode)(struct inode___66 *);
	void (*dirty_inode)(struct inode___66 *, int);
	int (*write_inode)(struct inode___66 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___66 *);
	void (*evict_inode)(struct inode___66 *);
	void (*put_super)(struct super_block___65 *);
	int (*sync_fs)(struct super_block___65 *, int);
	int (*freeze_super)(struct super_block___65 *);
	int (*freeze_fs)(struct super_block___65 *);
	int (*thaw_super)(struct super_block___65 *);
	int (*unfreeze_fs)(struct super_block___65 *);
	int (*statfs)(struct dentry___65 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___65 *, int *, char *);
	void (*umount_begin)(struct super_block___65 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___65 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___65 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___65 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___65 *);
	ssize_t (*quota_read)(struct super_block___65 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___65 *, int, const char *, size_t, loff_t);
	struct dquot___64 ** (*get_dquots)(struct inode___66 *);
	int (*bdev_try_to_free_page)(struct super_block___65 *, struct page___65 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___65 *, struct shrink_control___28 *);
	long int (*free_cached_objects)(struct super_block___65 *, struct shrink_control___28 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___64(struct page___65 *);

struct property___19 {
	char *name;
	int length;
	void *value;
	struct property___19 *next;
	long unsigned int _flags;
	struct bin_attribute___59 attr;
};

struct reserved_mem_ops;

struct reserved_mem {
	const char *name;
	long unsigned int fdt_node;
	long unsigned int phandle;
	const struct reserved_mem_ops *ops;
	phys_addr_t base;
	phys_addr_t size;
	void *priv;
};

struct reserved_mem_ops {
	int (*device_init)(struct reserved_mem *, struct device___59 *);
	void (*device_release)(struct reserved_mem *, struct device___59 *);
};

typedef int (*reservedmem_of_init_fn)(struct reserved_mem *);

struct module___58;

struct file___66;

struct kiocb___66;

struct poll_table_struct___41;

struct vm_area_struct___66;

struct inode___67;

struct file_lock___66;

struct page___66;

struct seq_file___60;

struct file_operations___66 {
	struct module___58 *owner;
	loff_t (*llseek)(struct file___66 *, loff_t, int);
	ssize_t (*read)(struct file___66 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___66 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___66 *, struct iov_iter___28 *);
	ssize_t (*write_iter)(struct kiocb___66 *, struct iov_iter___28 *);
	int (*iopoll)(struct kiocb___66 *, bool);
	int (*iterate)(struct file___66 *, struct dir_context *);
	int (*iterate_shared)(struct file___66 *, struct dir_context *);
	__poll_t (*poll)(struct file___66 *, struct poll_table_struct___41 *);
	long int (*unlocked_ioctl)(struct file___66 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___66 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___66 *, struct vm_area_struct___66 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___67 *, struct file___66 *);
	int (*flush)(struct file___66 *, fl_owner_t);
	int (*release)(struct inode___67 *, struct file___66 *);
	int (*fsync)(struct file___66 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___66 *, int);
	int (*lock)(struct file___66 *, int, struct file_lock___66 *);
	ssize_t (*sendpage)(struct file___66 *, struct page___66 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___66 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___66 *, int, struct file_lock___66 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___66 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___66 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___66 *, long int, struct file_lock___66 **, void **);
	long int (*fallocate)(struct file___66 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___60 *, struct file___66 *);
	ssize_t (*copy_file_range)(struct file___66 *, loff_t, struct file___66 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___66 *, loff_t, struct file___66 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___66 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct perf_event___40;

struct debug_info___40 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___40 *hbp_break[16];
	struct perf_event___40 *hbp_watch[16];
};

struct task_struct___66;

struct hw_perf_event___40 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___66 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___40)(struct perf_event___40 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___40;

struct perf_event_context___40;

struct fasync_struct___65;

struct pid_namespace___54;

struct trace_event_call___35;

struct perf_cgroup___40;

struct perf_event___40 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___40 *group_leader;
	struct pmu___40 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___40 hw;
	struct perf_event_context___40 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___40 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___66 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___65 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___40 *);
	struct callback_head callback_head;
	struct pid_namespace___54 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___40 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___40 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___35 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___40 *cgrp;
	struct list_head sb_list;
};

struct thread_struct___40 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___40 debug;
	long: 64;
};

struct vmacache___65 {
	u64 seqnum;
	struct vm_area_struct___66 *vmas[4];
};

struct page_frag___65 {
	struct page___66 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___65;

struct pid___54;

struct cred___62;

struct nsproxy___61;

struct signal_struct___56;

struct css_set___51;

struct vm_struct___49;

struct task_struct___66 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___66 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___65 *mm;
	struct mm_struct___65 *active_mm;
	struct vmacache___65 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___66 *real_parent;
	struct task_struct___66 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___66 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___54 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___54 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___54 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___62 *ptracer_cred;
	const struct cred___62 *real_cred;
	const struct cred___62 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___61 *nsproxy;
	struct signal_struct___56 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___66 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___13 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___51 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___40 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___65 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___66 *oom_reaper_list;
	struct vm_struct___49 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___40 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___66 *pgtable_t___65;

struct address_space___65;

struct dev_pagemap___65;

struct page___66 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___65 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___66 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___65 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___65 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___65 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___65;

struct lruvec___65 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___65 *pgdat;
};

struct zone___65 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___65 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___65 {
	struct zone___65 *zone;
	int zone_idx;
};

struct zonelist___65 {
	struct zoneref___65 _zonerefs[25];
};

struct pglist_data___65 {
	struct zone___65 node_zones[3];
	struct zonelist___65 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___66 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___66 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___65 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___66 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___66 *owner;
};

struct secondary_data___66 {
	void *stack;
	struct task_struct___66 *task;
	long int status;
};

struct blocking_notifier_head___65 {
	struct rw_semaphore___66 rwsem;
	struct notifier_block *head;
};

struct key___63;

struct ucounts___53;

struct user_namespace___53 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___53 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common ns;
	long unsigned int flags;
	struct key___63 *persistent_keyring_register;
	struct rw_semaphore___66 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___53 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_root___63;

struct kernfs_elem_dir___63 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___63 *root;
};

struct kernfs_node___63;

struct kernfs_syscall_ops___63;

struct kernfs_root___63 {
	struct kernfs_node___63 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___63 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___63 {
	struct kernfs_node___63 *target_kn;
};

struct kernfs_ops___63;

struct kernfs_elem_attr___63 {
	const struct kernfs_ops___63 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___63 *notify_next;
};

struct kernfs_node___63 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___63 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___63 dir;
		struct kernfs_elem_symlink___63 symlink;
		struct kernfs_elem_attr___63 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___63;

struct kernfs_ops___63 {
	int (*open)(struct kernfs_open_file___63 *);
	void (*release)(struct kernfs_open_file___63 *);
	int (*seq_show)(struct seq_file___60 *, void *);
	void * (*seq_start)(struct seq_file___60 *, loff_t *);
	void * (*seq_next)(struct seq_file___60 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___60 *, void *);
	ssize_t (*read)(struct kernfs_open_file___63 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___63 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___63 *, struct vm_area_struct___66 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___63 *, struct poll_table_struct___41 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___63 {
	int (*remount_fs)(struct kernfs_root___63 *, int *, char *);
	int (*show_options)(struct seq_file___60 *, struct kernfs_root___63 *);
	int (*mkdir)(struct kernfs_node___63 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___63 *);
	int (*rename)(struct kernfs_node___63 *, struct kernfs_node___63 *, const char *);
	int (*show_path)(struct seq_file___60 *, struct kernfs_node___63 *, struct kernfs_root___63 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___57;

struct seq_file___60 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___57 *op;
	int poll_event;
	const struct file___66 *file;
	void *private;
};

struct vm_operations_struct___65;

struct kernfs_open_file___63 {
	struct kernfs_node___63 *kn;
	struct file___66 *file;
	struct seq_file___60 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___65 *vm_ops;
};

struct dentry___66;

struct path___65 {
	struct vfsmount *mnt;
	struct dentry___66 *dentry;
};

struct fown_struct___54 {
	rwlock_t lock;
	struct pid___54 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___66 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___65 f_path;
	struct inode___67 *f_inode;
	const struct file_operations___66 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___54 f_owner;
	const struct cred___62 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___65 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___65;

struct vm_operations_struct___65 {
	void (*open)(struct vm_area_struct___66 *);
	void (*close)(struct vm_area_struct___66 *);
	int (*split)(struct vm_area_struct___66 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___66 *);
	vm_fault_t (*fault)(struct vm_fault___65 *);
	vm_fault_t (*huge_fault)(struct vm_fault___65 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___65 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___66 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___65 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___65 *);
	int (*access)(struct vm_area_struct___66 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___66 *);
	int (*set_policy)(struct vm_area_struct___66 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___66 *, long unsigned int);
	struct page___66 * (*find_special_page)(struct vm_area_struct___66 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___40)(struct file___66 *, wait_queue_head_t *, struct poll_table_struct___41 *);

struct poll_table_struct___41 {
	poll_queue_proc___40 _qproc;
	__poll_t _key;
};

struct vm_area_struct___66 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___66 *vm_next;
	struct vm_area_struct___66 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___65 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___65 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___66 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___63;

struct bin_attribute___60;

struct attribute_group___60 {
	const char *name;
	umode_t (*is_visible)(struct kobject___63 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___63 *, struct bin_attribute___60 *, int);
	struct attribute **attrs;
	struct bin_attribute___60 **bin_attrs;
};

struct kset___62;

struct kobj_type___62;

struct kobject___63 {
	const char *name;
	struct list_head entry;
	struct kobject___63 *parent;
	struct kset___62 *kset;
	struct kobj_type___62 *ktype;
	struct kernfs_node___63 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___60 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___66 *, struct kobject___63 *, struct bin_attribute___60 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___66 *, struct kobject___63 *, struct bin_attribute___60 *, char *, loff_t, size_t);
	int (*mmap)(struct file___66 *, struct kobject___63 *, struct bin_attribute___60 *, struct vm_area_struct___66 *);
};

struct sysfs_ops___62 {
	ssize_t (*show)(struct kobject___63 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___63 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___62;

struct kset___62 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___63 kobj;
	const struct kset_uevent_ops___62 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___62 {
	void (*release)(struct kobject___63 *);
	const struct sysfs_ops___62 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___63 *);
	const void * (*namespace)(struct kobject___63 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___62 {
	int (* const filter)(struct kset___62 *, struct kobject___63 *);
	const char * (* const name)(struct kset___62 *, struct kobject___63 *);
	int (* const uevent)(struct kset___62 *, struct kobject___63 *, struct kobj_uevent_env *);
};

struct kobj_attribute___63 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___63 *, struct kobj_attribute___63 *, char *);
	ssize_t (*store)(struct kobject___63 *, struct kobj_attribute___63 *, const char *, size_t);
};

struct device___60;

struct dev_pm_ops___60 {
	int (*prepare)(struct device___60 *);
	void (*complete)(struct device___60 *);
	int (*suspend)(struct device___60 *);
	int (*resume)(struct device___60 *);
	int (*freeze)(struct device___60 *);
	int (*thaw)(struct device___60 *);
	int (*poweroff)(struct device___60 *);
	int (*restore)(struct device___60 *);
	int (*suspend_late)(struct device___60 *);
	int (*resume_early)(struct device___60 *);
	int (*freeze_late)(struct device___60 *);
	int (*thaw_early)(struct device___60 *);
	int (*poweroff_late)(struct device___60 *);
	int (*restore_early)(struct device___60 *);
	int (*suspend_noirq)(struct device___60 *);
	int (*resume_noirq)(struct device___60 *);
	int (*freeze_noirq)(struct device___60 *);
	int (*thaw_noirq)(struct device___60 *);
	int (*poweroff_noirq)(struct device___60 *);
	int (*restore_noirq)(struct device___60 *);
	int (*runtime_suspend)(struct device___60 *);
	int (*runtime_resume)(struct device___60 *);
	int (*runtime_idle)(struct device___60 *);
};

struct dev_pm_info___60 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___60 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___60;

struct bus_type___60;

struct device_driver___60;

struct dev_pm_domain___60;

struct dma_map_ops___18;

struct fwnode_handle___46;

struct class___60;

struct device___60 {
	struct device___60 *parent;
	struct device_private *p;
	struct kobject___63 kobj;
	const char *init_name;
	const struct device_type___60 *type;
	struct mutex mutex;
	struct bus_type___60 *bus;
	struct device_driver___60 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___60 power;
	struct dev_pm_domain___60 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___18 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___46 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___60 *class;
	const struct attribute_group___60 **groups;
	void (*release)(struct device___60 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___60 {
	struct dev_pm_ops___60 ops;
	void (*detach)(struct device___60 *, bool);
	int (*activate)(struct device___60 *);
	void (*sync)(struct device___60 *);
	void (*dismiss)(struct device___60 *);
};

struct upid___54 {
	int nr;
	struct pid_namespace___54 *ns;
};

struct pid_namespace___54 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___66 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___54 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___66 *proc_self;
	struct dentry___66 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___53 *user_ns;
	struct ucounts___53 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common ns;
};

struct pid___54 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___54 numbers[1];
};

struct user_struct___62 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___63 *uid_keyring;
	struct key___63 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___65;

struct mm_struct___65 {
	struct {
		struct vm_area_struct___66 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___66 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___66 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___65 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___66 *owner;
		struct user_namespace___53 *user_ns;
		struct file___66 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___65 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___62 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___63 *session_keyring;
	struct key___63 *process_keyring;
	struct key___63 *thread_keyring;
	struct key___63 *request_key_auth;
	void *security;
	struct user_struct___62 *user;
	struct user_namespace___53 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___51;

struct nsproxy___61 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___54 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___51 *cgroup_ns;
};

struct signal_struct___56 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___66 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___66 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___54 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___54 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___65 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___54 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___51;

struct cgroup___51;

struct css_set___51 {
	struct cgroup_subsys_state___51 *subsys[13];
	refcount_t refcount;
	struct css_set___51 *dom_cset;
	struct cgroup___51 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___51 *mg_src_cgrp;
	struct cgroup___51 *mg_dst_cgrp;
	struct css_set___51 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___40 {
	struct pmu___40 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___66 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___40 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___49 {
	struct vm_struct___49 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___66 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___56 {
	struct task_struct___66 task;
	long unsigned int stack[8192];
};

struct bus_type___60 {
	const char *name;
	const char *dev_name;
	struct device___60 *dev_root;
	const struct attribute_group___60 **bus_groups;
	const struct attribute_group___60 **dev_groups;
	const struct attribute_group___60 **drv_groups;
	int (*match)(struct device___60 *, struct device_driver___60 *);
	int (*uevent)(struct device___60 *, struct kobj_uevent_env *);
	int (*probe)(struct device___60 *);
	int (*remove)(struct device___60 *);
	void (*shutdown)(struct device___60 *);
	int (*online)(struct device___60 *);
	int (*offline)(struct device___60 *);
	int (*suspend)(struct device___60 *, pm_message_t);
	int (*resume)(struct device___60 *);
	int (*num_vf)(struct device___60 *);
	int (*dma_configure)(struct device___60 *);
	const struct dev_pm_ops___60 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___60 {
	const char *name;
	struct bus_type___60 *bus;
	struct module___58 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___60 *);
	int (*remove)(struct device___60 *);
	void (*shutdown)(struct device___60 *);
	int (*suspend)(struct device___60 *, pm_message_t);
	int (*resume)(struct device___60 *);
	const struct attribute_group___60 **groups;
	const struct dev_pm_ops___60 *pm;
	void (*coredump)(struct device___60 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___60 {
	const char *name;
	const struct attribute_group___60 **groups;
	int (*uevent)(struct device___60 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___60 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___60 *);
	const struct dev_pm_ops___60 *pm;
};

struct module_kobject___55 {
	struct kobject___63 kobj;
	struct module___58 *mod;
	struct kobject___63 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___55 {
	struct module___58 *mod;
	struct latch_tree_node node;
};

struct module_layout___55 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___55 mtn;
};

struct module_attribute___55;

struct kernel_param___55;

struct module___58 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___55 mkobj;
	struct module_attribute___55 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___63 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___55 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___55 core_layout;
	struct module_layout___55 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___35 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide21;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct class___60 {
	const char *name;
	struct module___58 *owner;
	const struct attribute_group___60 **class_groups;
	const struct attribute_group___60 **dev_groups;
	struct kobject___63 *dev_kobj;
	int (*dev_uevent)(struct device___60 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___60 *, umode_t *);
	void (*class_release)(struct class___60 *);
	void (*dev_release)(struct device___60 *);
	int (*shutdown_pre)(struct device___60 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___60 *);
	const struct dev_pm_ops___60 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___18 {
	void * (*alloc)(struct device___60 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___60 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___60 *, struct vm_area_struct___66 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___60 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___60 *, struct page___66 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___60 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___60 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___60 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___60 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___60 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___60 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___60 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___60 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___60 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___60 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___60 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___60 *, u64);
	u64 (*get_required_mask)(struct device___60 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___46;

struct fwnode_handle___46 {
	struct fwnode_handle___46 *secondary;
	const struct fwnode_operations___46 *ops;
};

struct address_space_operations___65;

struct address_space___65 {
	struct inode___67 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___66 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___65 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___65)(struct vm_area_struct___66 *, long unsigned int, const struct page___66 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___65)(struct page___66 *, void *);

struct dev_pagemap___65 {
	dev_page_fault_t___65 page_fault;
	dev_page_free_t___65 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___60 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___65 {
	struct task_struct___66 *task;
	struct core_thread___65 *next;
};

struct core_state___65 {
	atomic_t nr_threads;
	struct core_thread___65 dumper;
	struct completion startup;
};

struct vm_fault___65 {
	struct vm_area_struct___66 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___66 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___66 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___65 prealloc_pte;
};

struct dentry_operations___65;

struct super_block___66;

struct dentry___66 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___66 *d_parent;
	struct qstr d_name;
	struct inode___67 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___65 *d_op;
	struct super_block___66 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___65;

struct block_device___66;

struct inode___67 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___65 *i_op;
	struct super_block___66 *i_sb;
	struct address_space___65 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___66 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___66 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___65 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___66 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___65 {
	int (*d_revalidate)(struct dentry___66 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___66 *, unsigned int);
	int (*d_hash)(const struct dentry___66 *, struct qstr *);
	int (*d_compare)(const struct dentry___66 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___66 *);
	int (*d_init)(struct dentry___66 *);
	void (*d_release)(struct dentry___66 *);
	void (*d_prune)(struct dentry___66 *);
	void (*d_iput)(struct dentry___66 *, struct inode___67 *);
	char * (*d_dname)(struct dentry___66 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___65 *);
	int (*d_manage)(const struct path___65 *, bool);
	struct dentry___66 * (*d_real)(struct dentry___66 *, const struct inode___67 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___65;

struct mem_dqinfo___65 {
	struct quota_format_type___65 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___65;

struct quota_info___65 {
	unsigned int flags;
	struct rw_semaphore___66 dqio_sem;
	struct inode___67 *files[3];
	struct mem_dqinfo___65 info[3];
	const struct quota_format_ops___65 *ops[3];
};

struct rcuwait___65 {
	struct task_struct___66 *task;
};

struct percpu_rw_semaphore___65 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___66 rw_sem;
	struct rcuwait___65 writer;
	int readers_block;
};

struct sb_writers___65 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___65 rw_sem[3];
};

struct file_system_type___65;

struct super_operations___65;

struct dquot_operations___65;

struct quotactl_ops___65;

struct super_block___66 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___65 *s_type;
	const struct super_operations___65 *s_op;
	const struct dquot_operations___65 *dq_op;
	const struct quotactl_ops___65 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___66 *s_root;
	struct rw_semaphore___66 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___66 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___65 s_dquot;
	struct sb_writers___65 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___65 *s_d_op;
	int cleancache_poolid;
	struct shrinker___28 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___53 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___66 {
	struct file___66 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___66 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___66 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___66 *ia_file;
};

struct dquot___65 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___66 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___65 {
	int qf_fmt_id;
	const struct quota_format_ops___65 *qf_ops;
	struct module___58 *qf_owner;
	struct quota_format_type___65 *qf_next;
};

struct quota_format_ops___65 {
	int (*check_quota_file)(struct super_block___66 *, int);
	int (*read_file_info)(struct super_block___66 *, int);
	int (*write_file_info)(struct super_block___66 *, int);
	int (*free_file_info)(struct super_block___66 *, int);
	int (*read_dqblk)(struct dquot___65 *);
	int (*commit_dqblk)(struct dquot___65 *);
	int (*release_dqblk)(struct dquot___65 *);
	int (*get_next_id)(struct super_block___66 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___65 {
	int (*write_dquot)(struct dquot___65 *);
	struct dquot___65 * (*alloc_dquot)(struct super_block___66 *, int);
	void (*destroy_dquot)(struct dquot___65 *);
	int (*acquire_dquot)(struct dquot___65 *);
	int (*release_dquot)(struct dquot___65 *);
	int (*mark_dirty)(struct dquot___65 *);
	int (*write_info)(struct super_block___66 *, int);
	qsize_t * (*get_reserved_space)(struct inode___67 *);
	int (*get_projid)(struct inode___67 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___67 *, qsize_t *);
	int (*get_next_id)(struct super_block___66 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___65 {
	int (*quota_on)(struct super_block___66 *, int, int, const struct path___65 *);
	int (*quota_off)(struct super_block___66 *, int);
	int (*quota_enable)(struct super_block___66 *, unsigned int);
	int (*quota_disable)(struct super_block___66 *, unsigned int);
	int (*quota_sync)(struct super_block___66 *, int);
	int (*set_info)(struct super_block___66 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___66 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___66 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___66 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___66 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___66 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___65 {
	int (*writepage)(struct page___66 *, struct writeback_control___3 *);
	int (*readpage)(struct file___66 *, struct page___66 *);
	int (*writepages)(struct address_space___65 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___66 *);
	int (*readpages)(struct file___66 *, struct address_space___65 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___66 *, struct address_space___65 *, loff_t, unsigned int, unsigned int, struct page___66 **, void **);
	int (*write_end)(struct file___66 *, struct address_space___65 *, loff_t, unsigned int, unsigned int, struct page___66 *, void *);
	sector_t (*bmap)(struct address_space___65 *, sector_t);
	void (*invalidatepage)(struct page___66 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___66 *, gfp_t);
	void (*freepage)(struct page___66 *);
	ssize_t (*direct_IO)(struct kiocb___66 *, struct iov_iter___28 *);
	int (*migratepage)(struct address_space___65 *, struct page___66 *, struct page___66 *, enum migrate_mode);
	bool (*isolate_page)(struct page___66 *, isolate_mode_t);
	void (*putback_page)(struct page___66 *);
	int (*launder_page)(struct page___66 *);
	int (*is_partially_uptodate)(struct page___66 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___66 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___65 *, struct page___66 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___66 *, sector_t *);
	void (*swap_deactivate)(struct file___66 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___66 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___67 *bd_inode;
	struct super_block___66 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___66 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___65 {
	struct dentry___66 * (*lookup)(struct inode___67 *, struct dentry___66 *, unsigned int);
	const char * (*get_link)(struct dentry___66 *, struct inode___67 *, struct delayed_call *);
	int (*permission)(struct inode___67 *, int);
	struct posix_acl * (*get_acl)(struct inode___67 *, int);
	int (*readlink)(struct dentry___66 *, char *, int);
	int (*create)(struct inode___67 *, struct dentry___66 *, umode_t, bool);
	int (*link)(struct dentry___66 *, struct inode___67 *, struct dentry___66 *);
	int (*unlink)(struct inode___67 *, struct dentry___66 *);
	int (*symlink)(struct inode___67 *, struct dentry___66 *, const char *);
	int (*mkdir)(struct inode___67 *, struct dentry___66 *, umode_t);
	int (*rmdir)(struct inode___67 *, struct dentry___66 *);
	int (*mknod)(struct inode___67 *, struct dentry___66 *, umode_t, dev_t);
	int (*rename)(struct inode___67 *, struct dentry___66 *, struct inode___67 *, struct dentry___66 *, unsigned int);
	int (*setattr)(struct dentry___66 *, struct iattr___66 *);
	int (*getattr)(const struct path___65 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___66 *, char *, size_t);
	int (*fiemap)(struct inode___67 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___67 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___67 *, struct dentry___66 *, struct file___66 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___67 *, struct dentry___66 *, umode_t);
	int (*set_acl)(struct inode___67 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___65 {
	void (*fl_copy_lock)(struct file_lock___66 *, struct file_lock___66 *);
	void (*fl_release_private)(struct file_lock___66 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___65;

struct file_lock___66 {
	struct file_lock___66 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___66 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___65 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___65 *fl_ops;
	const struct lock_manager_operations___65 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___65 {
	int (*lm_compare_owner)(struct file_lock___66 *, struct file_lock___66 *);
	long unsigned int (*lm_owner_key)(struct file_lock___66 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___66 *);
	int (*lm_grant)(struct file_lock___66 *, int);
	bool (*lm_break)(struct file_lock___66 *);
	int (*lm_change)(struct file_lock___66 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___66 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___65 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___65 *fa_next;
	struct file___66 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___65 {
	const char *name;
	int fs_flags;
	struct dentry___66 * (*mount)(struct file_system_type___65 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___66 *);
	struct module___58 *owner;
	struct file_system_type___65 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___65 {
	struct inode___67 * (*alloc_inode)(struct super_block___66 *);
	void (*destroy_inode)(struct inode___67 *);
	void (*dirty_inode)(struct inode___67 *, int);
	int (*write_inode)(struct inode___67 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___67 *);
	void (*evict_inode)(struct inode___67 *);
	void (*put_super)(struct super_block___66 *);
	int (*sync_fs)(struct super_block___66 *, int);
	int (*freeze_super)(struct super_block___66 *);
	int (*freeze_fs)(struct super_block___66 *);
	int (*thaw_super)(struct super_block___66 *);
	int (*unfreeze_fs)(struct super_block___66 *);
	int (*statfs)(struct dentry___66 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___66 *, int *, char *);
	void (*umount_begin)(struct super_block___66 *);
	int (*show_options)(struct seq_file___60 *, struct dentry___66 *);
	int (*show_devname)(struct seq_file___60 *, struct dentry___66 *);
	int (*show_path)(struct seq_file___60 *, struct dentry___66 *);
	int (*show_stats)(struct seq_file___60 *, struct dentry___66 *);
	ssize_t (*quota_read)(struct super_block___66 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___66 *, int, const char *, size_t, loff_t);
	struct dquot___65 ** (*get_dquots)(struct inode___67 *);
	int (*bdev_try_to_free_page)(struct super_block___66 *, struct page___66 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___66 *, struct shrink_control___28 *);
	long int (*free_cached_objects)(struct super_block___66 *, struct shrink_control___28 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___65(struct page___66 *);

struct fwnode_reference_args___46;

struct fwnode_endpoint___46;

struct fwnode_operations___46 {
	struct fwnode_handle___46 * (*get)(struct fwnode_handle___46 *);
	void (*put)(struct fwnode_handle___46 *);
	bool (*device_is_available)(const struct fwnode_handle___46 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___46 *, const struct device___60 *);
	bool (*property_present)(const struct fwnode_handle___46 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___46 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___46 *, const char *, const char **, size_t);
	struct fwnode_handle___46 * (*get_parent)(const struct fwnode_handle___46 *);
	struct fwnode_handle___46 * (*get_next_child_node)(const struct fwnode_handle___46 *, struct fwnode_handle___46 *);
	struct fwnode_handle___46 * (*get_named_child_node)(const struct fwnode_handle___46 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___46 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___46 *);
	struct fwnode_handle___46 * (*graph_get_next_endpoint)(const struct fwnode_handle___46 *, struct fwnode_handle___46 *);
	struct fwnode_handle___46 * (*graph_get_remote_endpoint)(const struct fwnode_handle___46 *);
	struct fwnode_handle___46 * (*graph_get_port_parent)(struct fwnode_handle___46 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___46 *, struct fwnode_endpoint___46 *);
};

struct fwnode_endpoint___46 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___46 *local_fwnode;
};

struct fwnode_reference_args___46 {
	struct fwnode_handle___46 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

typedef int (*key_restrict_link_func_t___62)(struct key___63 *, const struct key_type *, const union key_payload *, struct key___63 *);

struct key_restriction___63;

struct key___63 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___66 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___63 *restrict_link;
};

struct key_restriction___63 {
	key_restrict_link_func_t___62 check;
	struct key___63 *key;
	struct key_type *keytype;
};

struct seq_operations___57 {
	void * (*start)(struct seq_file___60 *, loff_t *);
	void (*stop)(struct seq_file___60 *, void *);
	void * (*next)(struct seq_file___60 *, void *, loff_t *);
	int (*show)(struct seq_file___60 *, void *);
};

struct cgroup_namespace___51 {
	refcount_t count;
	struct ns_common ns;
	struct user_namespace___53 *user_ns;
	struct ucounts___53 *ucounts;
	struct css_set___51 *root_cset;
};

struct ucounts___53 {
	struct hlist_node node;
	struct user_namespace___53 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct kernel_param_ops___55 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___55 *);
	int (*get)(char *, const struct kernel_param___55 *);
	void (*free)(void *);
};

struct kparam_array___55;

struct kernel_param___55 {
	const char *name;
	struct module___58 *mod;
	const struct kernel_param_ops___55 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___55 *arr;
	};
};

struct kparam_array___55 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___55 *ops;
	void *elem;
};

struct module_attribute___55 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___55 *, struct module_kobject___55 *, char *);
	ssize_t (*store)(struct module_attribute___55 *, struct module_kobject___55 *, const char *, size_t);
	void (*setup)(struct module___58 *, const char *);
	int (*test)(struct module___58 *);
	void (*free)(struct module___58 *);
};

struct trace_event_class___35;

struct trace_event_call___35 {
	struct list_head list;
	struct trace_event_class___35 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array *prog_array;
	int (*perf_perm)(struct trace_event_call___35 *, struct perf_event___40 *);
};

struct node___53 {
	struct device___60 dev;
};

struct bpf_map___51;

struct bpf_map_ops___51 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___51 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___51 *, struct file___66 *);
	void (*map_free)(struct bpf_map___51 *);
	int (*map_get_next_key)(struct bpf_map___51 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___51 *);
	void * (*map_lookup_elem)(struct bpf_map___51 *, void *);
	int (*map_update_elem)(struct bpf_map___51 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___51 *, void *);
	int (*map_push_elem)(struct bpf_map___51 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___51 *, void *);
	int (*map_peek_elem)(struct bpf_map___51 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___51 *, struct file___66 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___51 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___51 *, void *, struct seq_file___60 *);
	int (*map_check_btf)(const struct bpf_map___51 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___51 {
	const struct bpf_map_ops___51 *ops;
	struct bpf_map___51 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___62 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___51;

typedef void (*kthread_work_func_t___51)(struct kthread_work___51 *);

struct kthread_worker___51;

struct kthread_work___51 {
	struct list_head node;
	kthread_work_func_t___51 func;
	struct kthread_worker___51 *worker;
	int canceling;
};

struct kthread_worker___51 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___66 *task;
	struct kthread_work___51 *current_work;
};

struct kthread_delayed_work___51 {
	struct kthread_work___51 work;
	struct timer_list timer;
};

struct psi_group___51 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___51 *poll_kworker;
	struct kthread_delayed_work___51 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___51 {
	struct kernfs_node___63 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___51;

struct cgroup_subsys_state___51 {
	struct cgroup___51 *cgroup;
	struct cgroup_subsys___51 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___51 *parent;
};

struct cgroup_root___51;

struct cgroup_rstat_cpu___51;

struct cgroup___51 {
	struct cgroup_subsys_state___51 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___63 *kn;
	struct cgroup_file___51 procs_file;
	struct cgroup_file___51 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___51 *subsys[13];
	struct cgroup_root___51 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___51 *dom_cgrp;
	struct cgroup_rstat_cpu___51 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf bpf;
	atomic_t congestion_count;
	struct cgroup___51 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___51 psi;
	int ancestor_ids[0];
};

struct cftype___51;

struct cgroup_subsys___51 {
	struct cgroup_subsys_state___51 * (*css_alloc)(struct cgroup_subsys_state___51 *);
	int (*css_online)(struct cgroup_subsys_state___51 *);
	void (*css_offline)(struct cgroup_subsys_state___51 *);
	void (*css_released)(struct cgroup_subsys_state___51 *);
	void (*css_free)(struct cgroup_subsys_state___51 *);
	void (*css_reset)(struct cgroup_subsys_state___51 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___51 *, int);
	int (*css_extra_stat_show)(struct seq_file___60 *, struct cgroup_subsys_state___51 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___66 *);
	void (*cancel_fork)(struct task_struct___66 *);
	void (*fork)(struct task_struct___66 *);
	void (*exit)(struct task_struct___66 *);
	void (*free)(struct task_struct___66 *);
	void (*bind)(struct cgroup_subsys_state___51 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___51 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___51 *dfl_cftypes;
	struct cftype___51 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___51 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___51 *updated_children;
	struct cgroup___51 *updated_next;
};

struct cgroup_root___51 {
	struct kernfs_root___63 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___51 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___51 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___51 *ss;
	struct list_head node;
	struct kernfs_ops___63 *kf_ops;
	int (*open)(struct kernfs_open_file___63 *);
	void (*release)(struct kernfs_open_file___63 *);
	u64 (*read_u64)(struct cgroup_subsys_state___51 *, struct cftype___51 *);
	s64 (*read_s64)(struct cgroup_subsys_state___51 *, struct cftype___51 *);
	int (*seq_show)(struct seq_file___60 *, void *);
	void * (*seq_start)(struct seq_file___60 *, loff_t *);
	void * (*seq_next)(struct seq_file___60 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___60 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___51 *, struct cftype___51 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___51 *, struct cftype___51 *, s64);
	ssize_t (*write)(struct kernfs_open_file___63 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___63 *, struct poll_table_struct___41 *);
};

struct perf_cpu_context___40;

struct pmu___40 {
	struct list_head entry;
	struct module___58 *module;
	struct device___60 *dev;
	const struct attribute_group___60 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___40 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___40 *);
	void (*pmu_disable)(struct pmu___40 *);
	int (*event_init)(struct perf_event___40 *);
	void (*event_mapped)(struct perf_event___40 *, struct mm_struct___65 *);
	void (*event_unmapped)(struct perf_event___40 *, struct mm_struct___65 *);
	int (*add)(struct perf_event___40 *, int);
	void (*del)(struct perf_event___40 *, int);
	void (*start)(struct perf_event___40 *, int);
	void (*stop)(struct perf_event___40 *, int);
	void (*read)(struct perf_event___40 *);
	void (*start_txn)(struct pmu___40 *, unsigned int);
	int (*commit_txn)(struct pmu___40 *);
	void (*cancel_txn)(struct pmu___40 *);
	int (*event_idx)(struct perf_event___40 *);
	void (*sched_task)(struct perf_event_context___40 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___40 *);
	int (*filter_match)(struct perf_event___40 *);
	int (*check_period)(struct perf_event___40 *, u64);
};

struct perf_cpu_context___40 {
	struct perf_event_context___40 ctx;
	struct perf_event_context___40 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___40 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___40 {
	struct cgroup_subsys_state___51 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___35 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___35 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___35 *);
	struct list_head * (*get_fields)(struct trace_event_call___35 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___35 *);
};

struct trace_event_file___13;

struct trace_event_buffer___13 {
	struct ring_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___13 *trace_file;
	void *entry;
	long unsigned int flags;
	int pc;
};

struct trace_event_file___13 {
	struct list_head list;
	struct trace_event_call___35 *event_call;
	struct event_filter *filter;
	struct dentry___66 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_swiotlb_bounced {
	struct trace_entry ent;
	u32 __data_loc_dev_name;
	u64 dma_mask;
	dma_addr_t dev_addr;
	size_t size;
	enum swiotlb_force swiotlb_force;
	char __data[0];
};

struct trace_event_data_offsets_swiotlb_bounced {
	u32 dev_name;
};

struct gen_pool;

typedef long unsigned int (*genpool_algo_t)(long unsigned int *, long unsigned int, long unsigned int, unsigned int, void *, struct gen_pool *, long unsigned int);

struct gen_pool {
	spinlock_t lock;
	struct list_head chunks;
	int min_alloc_order;
	genpool_algo_t algo;
	void *data;
	const char *name;
};

struct cma;

struct module___59;

struct file___67;

struct kiocb___67;

struct poll_table_struct___42;

struct vm_area_struct___67;

struct inode___68;

struct file_lock___67;

struct page___67;

struct seq_file___61;

struct file_operations___67 {
	struct module___59 *owner;
	loff_t (*llseek)(struct file___67 *, loff_t, int);
	ssize_t (*read)(struct file___67 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___67 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___67 *, struct iov_iter___28 *);
	ssize_t (*write_iter)(struct kiocb___67 *, struct iov_iter___28 *);
	int (*iopoll)(struct kiocb___67 *, bool);
	int (*iterate)(struct file___67 *, struct dir_context *);
	int (*iterate_shared)(struct file___67 *, struct dir_context *);
	__poll_t (*poll)(struct file___67 *, struct poll_table_struct___42 *);
	long int (*unlocked_ioctl)(struct file___67 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___67 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___67 *, struct vm_area_struct___67 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___68 *, struct file___67 *);
	int (*flush)(struct file___67 *, fl_owner_t);
	int (*release)(struct inode___68 *, struct file___67 *);
	int (*fsync)(struct file___67 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___67 *, int);
	int (*lock)(struct file___67 *, int, struct file_lock___67 *);
	ssize_t (*sendpage)(struct file___67 *, struct page___67 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___67 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___67 *, int, struct file_lock___67 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___67 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___67 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___67 *, long int, struct file_lock___67 **, void **);
	long int (*fallocate)(struct file___67 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___61 *, struct file___67 *);
	ssize_t (*copy_file_range)(struct file___67 *, loff_t, struct file___67 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___67 *, loff_t, struct file___67 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___67 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___66 {
	u64 seqnum;
	struct vm_area_struct___67 *vmas[4];
};

struct page_frag___66 {
	struct page___67 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___41;

struct debug_info___41 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___41 *hbp_break[16];
	struct perf_event___41 *hbp_watch[16];
};

struct thread_struct___41 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___41 debug;
	long: 64;
};

struct mm_struct___66;

struct pid___55;

struct cred___63;

struct files_struct___4;

struct nsproxy___62;

struct signal_struct___57;

struct css_set___52;

struct perf_event_context___41;

struct task_struct___67 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___67 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___66 *mm;
	struct mm_struct___66 *active_mm;
	struct vmacache___66 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___67 *real_parent;
	struct task_struct___67 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___67 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___55 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___55 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___55 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___63 *ptracer_cred;
	const struct cred___63 *real_cred;
	const struct cred___63 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct___4 *files;
	struct nsproxy___62 *nsproxy;
	struct signal_struct___57 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___67 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___13 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___52 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___41 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___66 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___67 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___41 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___41 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___67 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___41)(struct perf_event___41 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___41;

struct fasync_struct___66;

struct pid_namespace___55;

struct trace_event_call___36;

struct perf_cgroup___41;

struct perf_event___41 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___41 *group_leader;
	struct pmu___41 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___41 hw;
	struct perf_event_context___41 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___41 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___67 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___66 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___41 *);
	struct callback_head callback_head;
	struct pid_namespace___55 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___41 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___41 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___36 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___41 *cgrp;
	struct list_head sb_list;
};

struct dentry_operations___66;

struct super_block___67;

struct dentry___67 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___67 *d_parent;
	struct qstr d_name;
	struct inode___68 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___66 *d_op;
	struct super_block___67 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct rw_semaphore___67 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___67 *owner;
};

struct address_space_operations___66;

struct address_space___66 {
	struct inode___68 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___67 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___66 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___66;

struct block_device___67;

struct inode___68 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___66 *i_op;
	struct super_block___67 *i_sb;
	struct address_space___66 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___67 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___67 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___66 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___67 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___66;

struct dentry_operations___66 {
	int (*d_revalidate)(struct dentry___67 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___67 *, unsigned int);
	int (*d_hash)(const struct dentry___67 *, struct qstr *);
	int (*d_compare)(const struct dentry___67 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___67 *);
	int (*d_init)(struct dentry___67 *);
	void (*d_release)(struct dentry___67 *);
	void (*d_prune)(struct dentry___67 *);
	void (*d_iput)(struct dentry___67 *, struct inode___68 *);
	char * (*d_dname)(struct dentry___67 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___66 *);
	int (*d_manage)(const struct path___66 *, bool);
	struct dentry___67 * (*d_real)(struct dentry___67 *, const struct inode___68 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___66;

struct mem_dqinfo___66 {
	struct quota_format_type___66 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___66;

struct quota_info___66 {
	unsigned int flags;
	struct rw_semaphore___67 dqio_sem;
	struct inode___68 *files[3];
	struct mem_dqinfo___66 info[3];
	const struct quota_format_ops___66 *ops[3];
};

struct rcuwait___66 {
	struct task_struct___67 *task;
};

struct percpu_rw_semaphore___66 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___67 rw_sem;
	struct rcuwait___66 writer;
	int readers_block;
};

struct sb_writers___66 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___66 rw_sem[3];
};

struct file_system_type___66;

struct super_operations___66;

struct dquot_operations___66;

struct quotactl_ops___66;

struct user_namespace___54;

struct super_block___67 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___66 *s_type;
	const struct super_operations___66 *s_op;
	const struct dquot_operations___66 *dq_op;
	const struct quotactl_ops___66 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___67 *s_root;
	struct rw_semaphore___67 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___67 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___66 s_dquot;
	struct sb_writers___66 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___66 *s_d_op;
	int cleancache_poolid;
	struct shrinker___28 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___54 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct path___66 {
	struct vfsmount *mnt;
	struct dentry___67 *dentry;
};

struct key___64;

struct ucounts___54;

struct user_namespace___54 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___54 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common ns;
	long unsigned int flags;
	struct key___64 *persistent_keyring_register;
	struct rw_semaphore___67 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___54 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___67 *pgtable_t___66;

struct dev_pagemap___66;

struct page___67 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___66 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___67 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___66 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___66 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___66 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___66;

struct lruvec___66 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___66 *pgdat;
};

struct zone___66 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___66 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___66 {
	struct zone___66 *zone;
	int zone_idx;
};

struct zonelist___66 {
	struct zoneref___66 _zonerefs[25];
};

struct pglist_data___66 {
	struct zone___66 node_zones[3];
	struct zonelist___66 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___67 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___67 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___66 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___67 {
	void *stack;
	struct task_struct___67 *task;
	long int status;
};

struct blocking_notifier_head___66 {
	struct rw_semaphore___67 rwsem;
	struct notifier_block *head;
};

struct upid___55 {
	int nr;
	struct pid_namespace___55 *ns;
};

struct pid_namespace___55 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___67 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___55 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___67 *proc_self;
	struct dentry___67 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___54 *user_ns;
	struct ucounts___54 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common ns;
};

struct pid___55 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___55 numbers[1];
};

struct vm_operations_struct___66;

struct vm_area_struct___67 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___67 *vm_next;
	struct vm_area_struct___67 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___66 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___66 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___67 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___66;

struct mm_struct___66 {
	struct {
		struct vm_area_struct___67 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___67 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___67 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___66 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___67 *owner;
		struct user_namespace___54 *user_ns;
		struct file___67 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___66 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___66)(struct vm_area_struct___67 *, long unsigned int, const struct page___67 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___66)(struct page___67 *, void *);

struct device___61;

struct dev_pagemap___66 {
	dev_page_fault_t___66 page_fault;
	dev_page_free_t___66 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___61 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct fown_struct___55 {
	rwlock_t lock;
	struct pid___55 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___67 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___66 f_path;
	struct inode___68 *f_inode;
	const struct file_operations___67 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___55 f_owner;
	const struct cred___63 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___66 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___66;

struct vm_operations_struct___66 {
	void (*open)(struct vm_area_struct___67 *);
	void (*close)(struct vm_area_struct___67 *);
	int (*split)(struct vm_area_struct___67 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___67 *);
	vm_fault_t (*fault)(struct vm_fault___66 *);
	vm_fault_t (*huge_fault)(struct vm_fault___66 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___66 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___67 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___66 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___66 *);
	int (*access)(struct vm_area_struct___67 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___67 *);
	int (*set_policy)(struct vm_area_struct___67 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___67 *, long unsigned int);
	struct page___67 * (*find_special_page)(struct vm_area_struct___67 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___66 {
	struct task_struct___67 *task;
	struct core_thread___66 *next;
};

struct core_state___66 {
	atomic_t nr_threads;
	struct core_thread___66 dumper;
	struct completion startup;
};

struct vm_fault___66 {
	struct vm_area_struct___67 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___67 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___67 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___66 prealloc_pte;
};

struct user_struct___63 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___64 *uid_keyring;
	struct key___64 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___63 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___64 *session_keyring;
	struct key___64 *process_keyring;
	struct key___64 *thread_keyring;
	struct key___64 *request_key_auth;
	void *security;
	struct user_struct___63 *user;
	struct user_namespace___54 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct fdtable___4 {
	unsigned int max_fds;
	struct file___67 **fd;
	long unsigned int *close_on_exec;
	long unsigned int *open_fds;
	long unsigned int *full_fds_bits;
	struct callback_head rcu;
};

struct files_struct___4 {
	atomic_t count;
	bool resize_in_progress;
	wait_queue_head_t resize_wait;
	struct fdtable___4 *fdt;
	struct fdtable___4 fdtab;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t file_lock;
	unsigned int next_fd;
	long unsigned int close_on_exec_init[1];
	long unsigned int open_fds_init[1];
	long unsigned int full_fds_bits_init[1];
	struct file___67 *fd_array[64];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cgroup_namespace___52;

struct nsproxy___62 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___55 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___52 *cgroup_ns;
};

struct signal_struct___57 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___67 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___67 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___55 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___55 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___66 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___55 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___52;

struct cgroup___52;

struct css_set___52 {
	struct cgroup_subsys_state___52 *subsys[13];
	refcount_t refcount;
	struct css_set___52 *dom_cset;
	struct cgroup___52 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___52 *mg_src_cgrp;
	struct cgroup___52 *mg_dst_cgrp;
	struct css_set___52 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___41 {
	struct pmu___41 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___67 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___41 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

union thread_union___57 {
	struct task_struct___67 task;
	long unsigned int stack[8192];
};

struct kiocb___67 {
	struct file___67 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___67 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___67 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___67 *ia_file;
};

struct dquot___66 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___67 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___66 {
	int qf_fmt_id;
	const struct quota_format_ops___66 *qf_ops;
	struct module___59 *qf_owner;
	struct quota_format_type___66 *qf_next;
};

struct quota_format_ops___66 {
	int (*check_quota_file)(struct super_block___67 *, int);
	int (*read_file_info)(struct super_block___67 *, int);
	int (*write_file_info)(struct super_block___67 *, int);
	int (*free_file_info)(struct super_block___67 *, int);
	int (*read_dqblk)(struct dquot___66 *);
	int (*commit_dqblk)(struct dquot___66 *);
	int (*release_dqblk)(struct dquot___66 *);
	int (*get_next_id)(struct super_block___67 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___66 {
	int (*write_dquot)(struct dquot___66 *);
	struct dquot___66 * (*alloc_dquot)(struct super_block___67 *, int);
	void (*destroy_dquot)(struct dquot___66 *);
	int (*acquire_dquot)(struct dquot___66 *);
	int (*release_dquot)(struct dquot___66 *);
	int (*mark_dirty)(struct dquot___66 *);
	int (*write_info)(struct super_block___67 *, int);
	qsize_t * (*get_reserved_space)(struct inode___68 *);
	int (*get_projid)(struct inode___68 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___68 *, qsize_t *);
	int (*get_next_id)(struct super_block___67 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___66 {
	int (*quota_on)(struct super_block___67 *, int, int, const struct path___66 *);
	int (*quota_off)(struct super_block___67 *, int);
	int (*quota_enable)(struct super_block___67 *, unsigned int);
	int (*quota_disable)(struct super_block___67 *, unsigned int);
	int (*quota_sync)(struct super_block___67 *, int);
	int (*set_info)(struct super_block___67 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___67 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___67 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___67 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___67 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___67 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___63;

struct kobj_type___63;

struct kernfs_node___64;

struct kobject___64 {
	const char *name;
	struct list_head entry;
	struct kobject___64 *parent;
	struct kset___63 *kset;
	struct kobj_type___63 *ktype;
	struct kernfs_node___64 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___56 {
	struct kobject___64 kobj;
	struct module___59 *mod;
	struct kobject___64 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___56 {
	struct module___59 *mod;
	struct latch_tree_node node;
};

struct module_layout___56 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___56 mtn;
};

struct module_attribute___56;

struct kernel_param___56;

struct module___59 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___56 mkobj;
	struct module_attribute___56 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___64 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___56 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___56 core_layout;
	struct module_layout___56 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___36 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___66 {
	int (*writepage)(struct page___67 *, struct writeback_control___3 *);
	int (*readpage)(struct file___67 *, struct page___67 *);
	int (*writepages)(struct address_space___66 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___67 *);
	int (*readpages)(struct file___67 *, struct address_space___66 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___67 *, struct address_space___66 *, loff_t, unsigned int, unsigned int, struct page___67 **, void **);
	int (*write_end)(struct file___67 *, struct address_space___66 *, loff_t, unsigned int, unsigned int, struct page___67 *, void *);
	sector_t (*bmap)(struct address_space___66 *, sector_t);
	void (*invalidatepage)(struct page___67 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___67 *, gfp_t);
	void (*freepage)(struct page___67 *);
	ssize_t (*direct_IO)(struct kiocb___67 *, struct iov_iter___28 *);
	int (*migratepage)(struct address_space___66 *, struct page___67 *, struct page___67 *, enum migrate_mode);
	bool (*isolate_page)(struct page___67 *, isolate_mode_t);
	void (*putback_page)(struct page___67 *);
	int (*launder_page)(struct page___67 *);
	int (*is_partially_uptodate)(struct page___67 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___67 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___66 *, struct page___67 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___67 *, sector_t *);
	void (*swap_deactivate)(struct file___67 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___67 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___68 *bd_inode;
	struct super_block___67 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___67 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___66 {
	struct dentry___67 * (*lookup)(struct inode___68 *, struct dentry___67 *, unsigned int);
	const char * (*get_link)(struct dentry___67 *, struct inode___68 *, struct delayed_call *);
	int (*permission)(struct inode___68 *, int);
	struct posix_acl * (*get_acl)(struct inode___68 *, int);
	int (*readlink)(struct dentry___67 *, char *, int);
	int (*create)(struct inode___68 *, struct dentry___67 *, umode_t, bool);
	int (*link)(struct dentry___67 *, struct inode___68 *, struct dentry___67 *);
	int (*unlink)(struct inode___68 *, struct dentry___67 *);
	int (*symlink)(struct inode___68 *, struct dentry___67 *, const char *);
	int (*mkdir)(struct inode___68 *, struct dentry___67 *, umode_t);
	int (*rmdir)(struct inode___68 *, struct dentry___67 *);
	int (*mknod)(struct inode___68 *, struct dentry___67 *, umode_t, dev_t);
	int (*rename)(struct inode___68 *, struct dentry___67 *, struct inode___68 *, struct dentry___67 *, unsigned int);
	int (*setattr)(struct dentry___67 *, struct iattr___67 *);
	int (*getattr)(const struct path___66 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___67 *, char *, size_t);
	int (*fiemap)(struct inode___68 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___68 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___68 *, struct dentry___67 *, struct file___67 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___68 *, struct dentry___67 *, umode_t);
	int (*set_acl)(struct inode___68 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___66 {
	void (*fl_copy_lock)(struct file_lock___67 *, struct file_lock___67 *);
	void (*fl_release_private)(struct file_lock___67 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___66;

struct file_lock___67 {
	struct file_lock___67 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___67 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___66 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___66 *fl_ops;
	const struct lock_manager_operations___66 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___66 {
	int (*lm_compare_owner)(struct file_lock___67 *, struct file_lock___67 *);
	long unsigned int (*lm_owner_key)(struct file_lock___67 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___67 *);
	int (*lm_grant)(struct file_lock___67 *, int);
	bool (*lm_break)(struct file_lock___67 *);
	int (*lm_change)(struct file_lock___67 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___67 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___66 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___66 *fa_next;
	struct file___67 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___66 {
	const char *name;
	int fs_flags;
	struct dentry___67 * (*mount)(struct file_system_type___66 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___67 *);
	struct module___59 *owner;
	struct file_system_type___66 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___66 {
	struct inode___68 * (*alloc_inode)(struct super_block___67 *);
	void (*destroy_inode)(struct inode___68 *);
	void (*dirty_inode)(struct inode___68 *, int);
	int (*write_inode)(struct inode___68 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___68 *);
	void (*evict_inode)(struct inode___68 *);
	void (*put_super)(struct super_block___67 *);
	int (*sync_fs)(struct super_block___67 *, int);
	int (*freeze_super)(struct super_block___67 *);
	int (*freeze_fs)(struct super_block___67 *);
	int (*thaw_super)(struct super_block___67 *);
	int (*unfreeze_fs)(struct super_block___67 *);
	int (*statfs)(struct dentry___67 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___67 *, int *, char *);
	void (*umount_begin)(struct super_block___67 *);
	int (*show_options)(struct seq_file___61 *, struct dentry___67 *);
	int (*show_devname)(struct seq_file___61 *, struct dentry___67 *);
	int (*show_path)(struct seq_file___61 *, struct dentry___67 *);
	int (*show_stats)(struct seq_file___61 *, struct dentry___67 *);
	ssize_t (*quota_read)(struct super_block___67 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___67 *, int, const char *, size_t, loff_t);
	struct dquot___66 ** (*get_dquots)(struct inode___68 *);
	int (*bdev_try_to_free_page)(struct super_block___67 *, struct page___67 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___67 *, struct shrink_control___28 *);
	long int (*free_cached_objects)(struct super_block___67 *, struct shrink_control___28 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___41)(struct file___67 *, wait_queue_head_t *, struct poll_table_struct___42 *);

struct poll_table_struct___42 {
	poll_queue_proc___41 _qproc;
	__poll_t _key;
};

struct seq_operations___58;

struct seq_file___61 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___58 *op;
	int poll_event;
	const struct file___67 *file;
	void *private;
};

typedef int (*key_restrict_link_func_t___63)(struct key___64 *, const struct key_type *, const union key_payload *, struct key___64 *);

struct key_restriction___64;

struct key___64 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___67 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___64 *restrict_link;
};

struct key_restriction___64 {
	key_restrict_link_func_t___63 check;
	struct key___64 *key;
	struct key_type *keytype;
};

struct dev_pm_info___61 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___61 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___61;

struct bus_type___61;

struct device_driver___61;

struct dev_pm_domain___61;

struct class___61;

struct attribute_group___61;

struct device___61 {
	struct device___61 *parent;
	struct device_private *p;
	struct kobject___64 kobj;
	const char *init_name;
	const struct device_type___61 *type;
	struct mutex mutex;
	struct bus_type___61 *bus;
	struct device_driver___61 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___61 power;
	struct dev_pm_domain___61 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___61 *class;
	const struct attribute_group___61 **groups;
	void (*release)(struct device___61 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct kobj_attribute___64 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___64 *, struct kobj_attribute___64 *, char *);
	ssize_t (*store)(struct kobject___64 *, struct kobj_attribute___64 *, const char *, size_t);
};

typedef void compound_page_dtor___66(struct page___67 *);

struct seq_operations___58 {
	void * (*start)(struct seq_file___61 *, loff_t *);
	void (*stop)(struct seq_file___61 *, void *);
	void * (*next)(struct seq_file___61 *, void *, loff_t *);
	int (*show)(struct seq_file___61 *, void *);
};

struct cgroup_namespace___52 {
	refcount_t count;
	struct ns_common ns;
	struct user_namespace___54 *user_ns;
	struct ucounts___54 *ucounts;
	struct css_set___52 *root_cset;
};

struct ucounts___54 {
	struct hlist_node node;
	struct user_namespace___54 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct kernfs_root___64;

struct kernfs_elem_dir___64 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___64 *root;
};

struct kernfs_syscall_ops___64;

struct kernfs_root___64 {
	struct kernfs_node___64 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___64 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___64 {
	struct kernfs_node___64 *target_kn;
};

struct kernfs_ops___64;

struct kernfs_elem_attr___64 {
	const struct kernfs_ops___64 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___64 *notify_next;
};

struct kernfs_node___64 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___64 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___64 dir;
		struct kernfs_elem_symlink___64 symlink;
		struct kernfs_elem_attr___64 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___64;

struct kernfs_ops___64 {
	int (*open)(struct kernfs_open_file___64 *);
	void (*release)(struct kernfs_open_file___64 *);
	int (*seq_show)(struct seq_file___61 *, void *);
	void * (*seq_start)(struct seq_file___61 *, loff_t *);
	void * (*seq_next)(struct seq_file___61 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___61 *, void *);
	ssize_t (*read)(struct kernfs_open_file___64 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___64 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___64 *, struct vm_area_struct___67 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___64 *, struct poll_table_struct___42 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___64 {
	int (*remount_fs)(struct kernfs_root___64 *, int *, char *);
	int (*show_options)(struct seq_file___61 *, struct kernfs_root___64 *);
	int (*mkdir)(struct kernfs_node___64 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___64 *);
	int (*rename)(struct kernfs_node___64 *, struct kernfs_node___64 *, const char *);
	int (*show_path)(struct seq_file___61 *, struct kernfs_node___64 *, struct kernfs_root___64 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___64 {
	struct kernfs_node___64 *kn;
	struct file___67 *file;
	struct seq_file___61 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___66 *vm_ops;
};

struct bin_attribute___61;

struct attribute_group___61 {
	const char *name;
	umode_t (*is_visible)(struct kobject___64 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___64 *, struct bin_attribute___61 *, int);
	struct attribute **attrs;
	struct bin_attribute___61 **bin_attrs;
};

struct bin_attribute___61 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___67 *, struct kobject___64 *, struct bin_attribute___61 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___67 *, struct kobject___64 *, struct bin_attribute___61 *, char *, loff_t, size_t);
	int (*mmap)(struct file___67 *, struct kobject___64 *, struct bin_attribute___61 *, struct vm_area_struct___67 *);
};

struct sysfs_ops___63 {
	ssize_t (*show)(struct kobject___64 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___64 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___63;

struct kset___63 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___64 kobj;
	const struct kset_uevent_ops___63 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___63 {
	void (*release)(struct kobject___64 *);
	const struct sysfs_ops___63 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___64 *);
	const void * (*namespace)(struct kobject___64 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___63 {
	int (* const filter)(struct kset___63 *, struct kobject___64 *);
	const char * (* const name)(struct kset___63 *, struct kobject___64 *);
	int (* const uevent)(struct kset___63 *, struct kobject___64 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___56 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___56 *);
	int (*get)(char *, const struct kernel_param___56 *);
	void (*free)(void *);
};

struct kparam_array___56;

struct kernel_param___56 {
	const char *name;
	struct module___59 *mod;
	const struct kernel_param_ops___56 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___56 *arr;
	};
};

struct kparam_array___56 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___56 *ops;
	void *elem;
};

struct module_attribute___56 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___56 *, struct module_kobject___56 *, char *);
	ssize_t (*store)(struct module_attribute___56 *, struct module_kobject___56 *, const char *, size_t);
	void (*setup)(struct module___59 *, const char *);
	int (*test)(struct module___59 *);
	void (*free)(struct module___59 *);
};

struct trace_event_class___36;

struct trace_event_call___36 {
	struct list_head list;
	struct trace_event_class___36 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array *prog_array;
	int (*perf_perm)(struct trace_event_call___36 *, struct perf_event___41 *);
};

struct dev_pm_ops___61 {
	int (*prepare)(struct device___61 *);
	void (*complete)(struct device___61 *);
	int (*suspend)(struct device___61 *);
	int (*resume)(struct device___61 *);
	int (*freeze)(struct device___61 *);
	int (*thaw)(struct device___61 *);
	int (*poweroff)(struct device___61 *);
	int (*restore)(struct device___61 *);
	int (*suspend_late)(struct device___61 *);
	int (*resume_early)(struct device___61 *);
	int (*freeze_late)(struct device___61 *);
	int (*thaw_early)(struct device___61 *);
	int (*poweroff_late)(struct device___61 *);
	int (*restore_early)(struct device___61 *);
	int (*suspend_noirq)(struct device___61 *);
	int (*resume_noirq)(struct device___61 *);
	int (*freeze_noirq)(struct device___61 *);
	int (*thaw_noirq)(struct device___61 *);
	int (*poweroff_noirq)(struct device___61 *);
	int (*restore_noirq)(struct device___61 *);
	int (*runtime_suspend)(struct device___61 *);
	int (*runtime_resume)(struct device___61 *);
	int (*runtime_idle)(struct device___61 *);
};

struct dev_pm_domain___61 {
	struct dev_pm_ops___61 ops;
	void (*detach)(struct device___61 *, bool);
	int (*activate)(struct device___61 *);
	void (*sync)(struct device___61 *);
	void (*dismiss)(struct device___61 *);
};

struct bus_type___61 {
	const char *name;
	const char *dev_name;
	struct device___61 *dev_root;
	const struct attribute_group___61 **bus_groups;
	const struct attribute_group___61 **dev_groups;
	const struct attribute_group___61 **drv_groups;
	int (*match)(struct device___61 *, struct device_driver___61 *);
	int (*uevent)(struct device___61 *, struct kobj_uevent_env *);
	int (*probe)(struct device___61 *);
	int (*remove)(struct device___61 *);
	void (*shutdown)(struct device___61 *);
	int (*online)(struct device___61 *);
	int (*offline)(struct device___61 *);
	int (*suspend)(struct device___61 *, pm_message_t);
	int (*resume)(struct device___61 *);
	int (*num_vf)(struct device___61 *);
	int (*dma_configure)(struct device___61 *);
	const struct dev_pm_ops___61 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___61 {
	const char *name;
	struct bus_type___61 *bus;
	struct module___59 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___61 *);
	int (*remove)(struct device___61 *);
	void (*shutdown)(struct device___61 *);
	int (*suspend)(struct device___61 *, pm_message_t);
	int (*resume)(struct device___61 *);
	const struct attribute_group___61 **groups;
	const struct dev_pm_ops___61 *pm;
	void (*coredump)(struct device___61 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___61 {
	const char *name;
	const struct attribute_group___61 **groups;
	int (*uevent)(struct device___61 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___61 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___61 *);
	const struct dev_pm_ops___61 *pm;
};

struct class___61 {
	const char *name;
	struct module___59 *owner;
	const struct attribute_group___61 **class_groups;
	const struct attribute_group___61 **dev_groups;
	struct kobject___64 *dev_kobj;
	int (*dev_uevent)(struct device___61 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___61 *, umode_t *);
	void (*class_release)(struct class___61 *);
	void (*dev_release)(struct device___61 *);
	int (*shutdown_pre)(struct device___61 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___61 *);
	const struct dev_pm_ops___61 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___54 {
	struct device___61 dev;
};

struct bpf_map___52;

struct bpf_map_ops___52 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___52 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___52 *, struct file___67 *);
	void (*map_free)(struct bpf_map___52 *);
	int (*map_get_next_key)(struct bpf_map___52 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___52 *);
	void * (*map_lookup_elem)(struct bpf_map___52 *, void *);
	int (*map_update_elem)(struct bpf_map___52 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___52 *, void *);
	int (*map_push_elem)(struct bpf_map___52 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___52 *, void *);
	int (*map_peek_elem)(struct bpf_map___52 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___52 *, struct file___67 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___52 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___52 *, void *, struct seq_file___61 *);
	int (*map_check_btf)(const struct bpf_map___52 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___52 {
	const struct bpf_map_ops___52 *ops;
	struct bpf_map___52 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___63 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___52;

typedef void (*kthread_work_func_t___52)(struct kthread_work___52 *);

struct kthread_worker___52;

struct kthread_work___52 {
	struct list_head node;
	kthread_work_func_t___52 func;
	struct kthread_worker___52 *worker;
	int canceling;
};

struct kthread_worker___52 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___67 *task;
	struct kthread_work___52 *current_work;
};

struct kthread_delayed_work___52 {
	struct kthread_work___52 work;
	struct timer_list timer;
};

struct psi_group___52 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___52 *poll_kworker;
	struct kthread_delayed_work___52 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___52 {
	struct kernfs_node___64 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___52;

struct cgroup_subsys_state___52 {
	struct cgroup___52 *cgroup;
	struct cgroup_subsys___52 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___52 *parent;
};

struct cgroup_root___52;

struct cgroup_rstat_cpu___52;

struct cgroup___52 {
	struct cgroup_subsys_state___52 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___64 *kn;
	struct cgroup_file___52 procs_file;
	struct cgroup_file___52 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___52 *subsys[13];
	struct cgroup_root___52 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___52 *dom_cgrp;
	struct cgroup_rstat_cpu___52 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf bpf;
	atomic_t congestion_count;
	struct cgroup___52 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___52 psi;
	int ancestor_ids[0];
};

struct cftype___52;

struct cgroup_subsys___52 {
	struct cgroup_subsys_state___52 * (*css_alloc)(struct cgroup_subsys_state___52 *);
	int (*css_online)(struct cgroup_subsys_state___52 *);
	void (*css_offline)(struct cgroup_subsys_state___52 *);
	void (*css_released)(struct cgroup_subsys_state___52 *);
	void (*css_free)(struct cgroup_subsys_state___52 *);
	void (*css_reset)(struct cgroup_subsys_state___52 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___52 *, int);
	int (*css_extra_stat_show)(struct seq_file___61 *, struct cgroup_subsys_state___52 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___67 *);
	void (*cancel_fork)(struct task_struct___67 *);
	void (*fork)(struct task_struct___67 *);
	void (*exit)(struct task_struct___67 *);
	void (*free)(struct task_struct___67 *);
	void (*bind)(struct cgroup_subsys_state___52 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___52 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___52 *dfl_cftypes;
	struct cftype___52 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___52 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___52 *updated_children;
	struct cgroup___52 *updated_next;
};

struct cgroup_root___52 {
	struct kernfs_root___64 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___52 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___52 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___52 *ss;
	struct list_head node;
	struct kernfs_ops___64 *kf_ops;
	int (*open)(struct kernfs_open_file___64 *);
	void (*release)(struct kernfs_open_file___64 *);
	u64 (*read_u64)(struct cgroup_subsys_state___52 *, struct cftype___52 *);
	s64 (*read_s64)(struct cgroup_subsys_state___52 *, struct cftype___52 *);
	int (*seq_show)(struct seq_file___61 *, void *);
	void * (*seq_start)(struct seq_file___61 *, loff_t *);
	void * (*seq_next)(struct seq_file___61 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___61 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___52 *, struct cftype___52 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___52 *, struct cftype___52 *, s64);
	ssize_t (*write)(struct kernfs_open_file___64 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___64 *, struct poll_table_struct___42 *);
};

struct perf_cpu_context___41;

struct pmu___41 {
	struct list_head entry;
	struct module___59 *module;
	struct device___61 *dev;
	const struct attribute_group___61 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___41 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___41 *);
	void (*pmu_disable)(struct pmu___41 *);
	int (*event_init)(struct perf_event___41 *);
	void (*event_mapped)(struct perf_event___41 *, struct mm_struct___66 *);
	void (*event_unmapped)(struct perf_event___41 *, struct mm_struct___66 *);
	int (*add)(struct perf_event___41 *, int);
	void (*del)(struct perf_event___41 *, int);
	void (*start)(struct perf_event___41 *, int);
	void (*stop)(struct perf_event___41 *, int);
	void (*read)(struct perf_event___41 *);
	void (*start_txn)(struct pmu___41 *, unsigned int);
	int (*commit_txn)(struct pmu___41 *);
	void (*cancel_txn)(struct pmu___41 *);
	int (*event_idx)(struct perf_event___41 *);
	void (*sched_task)(struct perf_event_context___41 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___41 *);
	int (*filter_match)(struct perf_event___41 *);
	int (*check_period)(struct perf_event___41 *, u64);
};

struct perf_cpu_context___41 {
	struct perf_event_context___41 ctx;
	struct perf_event_context___41 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___41 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___41 {
	struct cgroup_subsys_state___52 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___36 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___36 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___36 *);
	struct list_head * (*get_fields)(struct trace_event_call___36 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___36 *);
};

struct syscall_metadata___15 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___36 *enter_event;
	struct trace_event_call___36 *exit_event;
};

enum kcmp_type {
	KCMP_FILE = 0,
	KCMP_VM = 1,
	KCMP_FILES = 2,
	KCMP_FS = 3,
	KCMP_SIGHAND = 4,
	KCMP_IO = 5,
	KCMP_SYSVSEM = 6,
	KCMP_EPOLL_TFD = 7,
	KCMP_TYPES = 8,
};

struct kcmp_epoll_slot {
	__u32 efd;
	__u32 tfd;
	__u32 toff;
};

enum profile_type {
	PROFILE_TASK_EXIT = 0,
	PROFILE_MUNMAP = 1,
};

struct profile_hit {
	u32 pc;
	u32 hits;
};

typedef __kernel_suseconds_t suseconds_t;

typedef __kernel_time_t time_t;

typedef __kernel_clock_t clock_t;

struct module___60;

struct file___68;

struct kiocb___68;

struct poll_table_struct___43;

struct vm_area_struct___68;

struct inode___69;

struct file_lock___68;

struct page___68;

struct seq_file___62;

struct file_operations___68 {
	struct module___60 *owner;
	loff_t (*llseek)(struct file___68 *, loff_t, int);
	ssize_t (*read)(struct file___68 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___68 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___68 *, struct iov_iter___28 *);
	ssize_t (*write_iter)(struct kiocb___68 *, struct iov_iter___28 *);
	int (*iopoll)(struct kiocb___68 *, bool);
	int (*iterate)(struct file___68 *, struct dir_context *);
	int (*iterate_shared)(struct file___68 *, struct dir_context *);
	__poll_t (*poll)(struct file___68 *, struct poll_table_struct___43 *);
	long int (*unlocked_ioctl)(struct file___68 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___68 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___68 *, struct vm_area_struct___68 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___69 *, struct file___68 *);
	int (*flush)(struct file___68 *, fl_owner_t);
	int (*release)(struct inode___69 *, struct file___68 *);
	int (*fsync)(struct file___68 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___68 *, int);
	int (*lock)(struct file___68 *, int, struct file_lock___68 *);
	ssize_t (*sendpage)(struct file___68 *, struct page___68 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___68 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___68 *, int, struct file_lock___68 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___68 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___68 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___68 *, long int, struct file_lock___68 **, void **);
	long int (*fallocate)(struct file___68 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___62 *, struct file___68 *);
	ssize_t (*copy_file_range)(struct file___68 *, loff_t, struct file___68 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___68 *, loff_t, struct file___68 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___68 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef __u64 timeu64_t;

struct itimerspec {
	struct timespec it_interval;
	struct timespec it_value;
};

struct __kernel_old_timeval {
	__kernel_long_t tv_sec;
	__kernel_long_t tv_usec;
};

struct itimerspec64 {
	struct timespec64 it_interval;
	struct timespec64 it_value;
};

struct vmacache___67 {
	u64 seqnum;
	struct vm_area_struct___68 *vmas[4];
};

struct page_frag___67 {
	struct page___68 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___42;

struct debug_info___42 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___42 *hbp_break[16];
	struct perf_event___42 *hbp_watch[16];
};

struct thread_struct___42 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___42 debug;
	long: 64;
};

struct mm_struct___67;

struct pid___56;

struct cred___64;

struct nsproxy___63;

struct signal_struct___58;

struct css_set___53;

struct perf_event_context___42;

struct vm_struct___50;

struct task_struct___68 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___68 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___67 *mm;
	struct mm_struct___67 *active_mm;
	struct vmacache___67 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___68 *real_parent;
	struct task_struct___68 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___68 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___56 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___56 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___56 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___64 *ptracer_cred;
	const struct cred___64 *real_cred;
	const struct cred___64 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___63 *nsproxy;
	struct signal_struct___58 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___68 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___13 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___53 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___42 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___67 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___68 *oom_reaper_list;
	struct vm_struct___50 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___42 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___42 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___68 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___42)(struct perf_event___42 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___42;

struct fasync_struct___67;

struct pid_namespace___56;

struct trace_event_call___37;

struct perf_cgroup___42;

struct perf_event___42 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___42 *group_leader;
	struct pmu___42 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___42 hw;
	struct perf_event_context___42 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___42 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___68 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___67 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___42 *);
	struct callback_head callback_head;
	struct pid_namespace___56 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___42 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___42 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___37 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___42 *cgrp;
	struct list_head sb_list;
};

struct timex {
	unsigned int modes;
	__kernel_long_t offset;
	__kernel_long_t freq;
	__kernel_long_t maxerror;
	__kernel_long_t esterror;
	int status;
	__kernel_long_t constant;
	__kernel_long_t precision;
	__kernel_long_t tolerance;
	struct timeval time;
	__kernel_long_t tick;
	__kernel_long_t ppsfreq;
	__kernel_long_t jitter;
	int shift;
	__kernel_long_t stabil;
	__kernel_long_t jitcnt;
	__kernel_long_t calcnt;
	__kernel_long_t errcnt;
	__kernel_long_t stbcnt;
	int tai;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct secondary_data___68 {
	void *stack;
	struct task_struct___68 *task;
	long int status;
};

typedef struct page___68 *pgtable_t___67;

struct address_space___67;

struct dev_pagemap___67;

struct page___68 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___67 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___68 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___67 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___67 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___67 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___67;

struct lruvec___67 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___67 *pgdat;
};

struct zone___67 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___67 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___67 {
	struct zone___67 *zone;
	int zone_idx;
};

struct zonelist___67 {
	struct zoneref___67 _zonerefs[25];
};

struct pglist_data___67 {
	struct zone___67 node_zones[3];
	struct zonelist___67 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___68 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___68 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___67 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___68 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___68 *owner;
};

struct blocking_notifier_head___67 {
	struct rw_semaphore___68 rwsem;
	struct notifier_block *head;
};

struct key___65;

struct ucounts___55;

struct user_namespace___55 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___55 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common ns;
	long unsigned int flags;
	struct key___65 *persistent_keyring_register;
	struct rw_semaphore___68 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___55 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_root___65;

struct kernfs_elem_dir___65 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___65 *root;
};

struct kernfs_node___65;

struct kernfs_syscall_ops___65;

struct kernfs_root___65 {
	struct kernfs_node___65 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___65 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___65 {
	struct kernfs_node___65 *target_kn;
};

struct kernfs_ops___65;

struct kernfs_elem_attr___65 {
	const struct kernfs_ops___65 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___65 *notify_next;
};

struct kernfs_node___65 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___65 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___65 dir;
		struct kernfs_elem_symlink___65 symlink;
		struct kernfs_elem_attr___65 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___65;

struct kernfs_ops___65 {
	int (*open)(struct kernfs_open_file___65 *);
	void (*release)(struct kernfs_open_file___65 *);
	int (*seq_show)(struct seq_file___62 *, void *);
	void * (*seq_start)(struct seq_file___62 *, loff_t *);
	void * (*seq_next)(struct seq_file___62 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___62 *, void *);
	ssize_t (*read)(struct kernfs_open_file___65 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___65 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___65 *, struct vm_area_struct___68 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___65 *, struct poll_table_struct___43 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___65 {
	int (*remount_fs)(struct kernfs_root___65 *, int *, char *);
	int (*show_options)(struct seq_file___62 *, struct kernfs_root___65 *);
	int (*mkdir)(struct kernfs_node___65 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___65 *);
	int (*rename)(struct kernfs_node___65 *, struct kernfs_node___65 *, const char *);
	int (*show_path)(struct seq_file___62 *, struct kernfs_node___65 *, struct kernfs_root___65 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___59;

struct seq_file___62 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___59 *op;
	int poll_event;
	const struct file___68 *file;
	void *private;
};

struct vm_operations_struct___67;

struct kernfs_open_file___65 {
	struct kernfs_node___65 *kn;
	struct file___68 *file;
	struct seq_file___62 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___67 *vm_ops;
};

struct dentry___68;

struct path___67 {
	struct vfsmount *mnt;
	struct dentry___68 *dentry;
};

struct fown_struct___56 {
	rwlock_t lock;
	struct pid___56 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___68 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___67 f_path;
	struct inode___69 *f_inode;
	const struct file_operations___68 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___56 f_owner;
	const struct cred___64 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___67 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___67;

struct vm_operations_struct___67 {
	void (*open)(struct vm_area_struct___68 *);
	void (*close)(struct vm_area_struct___68 *);
	int (*split)(struct vm_area_struct___68 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___68 *);
	vm_fault_t (*fault)(struct vm_fault___67 *);
	vm_fault_t (*huge_fault)(struct vm_fault___67 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___67 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___68 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___67 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___67 *);
	int (*access)(struct vm_area_struct___68 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___68 *);
	int (*set_policy)(struct vm_area_struct___68 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___68 *, long unsigned int);
	struct page___68 * (*find_special_page)(struct vm_area_struct___68 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___42)(struct file___68 *, wait_queue_head_t *, struct poll_table_struct___43 *);

struct poll_table_struct___43 {
	poll_queue_proc___42 _qproc;
	__poll_t _key;
};

struct vm_area_struct___68 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___68 *vm_next;
	struct vm_area_struct___68 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___67 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___67 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___68 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___65;

struct bin_attribute___62;

struct attribute_group___62 {
	const char *name;
	umode_t (*is_visible)(struct kobject___65 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___65 *, struct bin_attribute___62 *, int);
	struct attribute **attrs;
	struct bin_attribute___62 **bin_attrs;
};

struct kset___64;

struct kobj_type___64;

struct kobject___65 {
	const char *name;
	struct list_head entry;
	struct kobject___65 *parent;
	struct kset___64 *kset;
	struct kobj_type___64 *ktype;
	struct kernfs_node___65 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___62 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___68 *, struct kobject___65 *, struct bin_attribute___62 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___68 *, struct kobject___65 *, struct bin_attribute___62 *, char *, loff_t, size_t);
	int (*mmap)(struct file___68 *, struct kobject___65 *, struct bin_attribute___62 *, struct vm_area_struct___68 *);
};

struct sysfs_ops___64 {
	ssize_t (*show)(struct kobject___65 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___65 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___64;

struct kset___64 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___65 kobj;
	const struct kset_uevent_ops___64 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___64 {
	void (*release)(struct kobject___65 *);
	const struct sysfs_ops___64 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___65 *);
	const void * (*namespace)(struct kobject___65 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___64 {
	int (* const filter)(struct kset___64 *, struct kobject___65 *);
	const char * (* const name)(struct kset___64 *, struct kobject___65 *);
	int (* const uevent)(struct kset___64 *, struct kobject___65 *, struct kobj_uevent_env *);
};

struct kobj_attribute___65 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___65 *, struct kobj_attribute___65 *, char *);
	ssize_t (*store)(struct kobject___65 *, struct kobj_attribute___65 *, const char *, size_t);
};

struct fwnode_operations___47;

struct fwnode_handle___47 {
	struct fwnode_handle___47 *secondary;
	const struct fwnode_operations___47 *ops;
};

struct device___62;

struct fwnode_reference_args___47;

struct fwnode_endpoint___47;

struct fwnode_operations___47 {
	struct fwnode_handle___47 * (*get)(struct fwnode_handle___47 *);
	void (*put)(struct fwnode_handle___47 *);
	bool (*device_is_available)(const struct fwnode_handle___47 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___47 *, const struct device___62 *);
	bool (*property_present)(const struct fwnode_handle___47 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___47 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___47 *, const char *, const char **, size_t);
	struct fwnode_handle___47 * (*get_parent)(const struct fwnode_handle___47 *);
	struct fwnode_handle___47 * (*get_next_child_node)(const struct fwnode_handle___47 *, struct fwnode_handle___47 *);
	struct fwnode_handle___47 * (*get_named_child_node)(const struct fwnode_handle___47 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___47 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___47 *);
	struct fwnode_handle___47 * (*graph_get_next_endpoint)(const struct fwnode_handle___47 *, struct fwnode_handle___47 *);
	struct fwnode_handle___47 * (*graph_get_remote_endpoint)(const struct fwnode_handle___47 *);
	struct fwnode_handle___47 * (*graph_get_port_parent)(struct fwnode_handle___47 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___47 *, struct fwnode_endpoint___47 *);
};

struct fwnode_endpoint___47 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___47 *local_fwnode;
};

struct fwnode_reference_args___47 {
	struct fwnode_handle___47 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct dev_pm_info___62 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___62 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___62;

struct bus_type___62;

struct device_driver___62;

struct dev_pm_domain___62;

struct device_node___21;

struct class___62;

struct device___62 {
	struct device___62 *parent;
	struct device_private *p;
	struct kobject___65 kobj;
	const char *init_name;
	const struct device_type___62 *type;
	struct mutex mutex;
	struct bus_type___62 *bus;
	struct device_driver___62 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___62 power;
	struct dev_pm_domain___62 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___21 *of_node;
	struct fwnode_handle___47 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___62 *class;
	const struct attribute_group___62 **groups;
	void (*release)(struct device___62 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct property___20 {
	char *name;
	int length;
	void *value;
	struct property___20 *next;
	long unsigned int _flags;
	struct bin_attribute___62 attr;
};

struct device_node___21 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___47 fwnode;
	struct property___20 *properties;
	struct property___20 *deadprops;
	struct device_node___21 *parent;
	struct device_node___21 *child;
	struct device_node___21 *sibling;
	struct kobject___65 kobj;
	long unsigned int _flags;
	void *data;
};

struct core_state___67;

struct mm_struct___67 {
	struct {
		struct vm_area_struct___68 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___68 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___68 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___67 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___68 *owner;
		struct user_namespace___55 *user_ns;
		struct file___68 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___67 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___67;

struct address_space___67 {
	struct inode___69 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___68 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___67 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___67)(struct vm_area_struct___68 *, long unsigned int, const struct page___68 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___67)(struct page___68 *, void *);

struct dev_pagemap___67 {
	dev_page_fault_t___67 page_fault;
	dev_page_free_t___67 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___62 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___67 {
	struct task_struct___68 *task;
	struct core_thread___67 *next;
};

struct core_state___67 {
	atomic_t nr_threads;
	struct core_thread___67 dumper;
	struct completion startup;
};

struct vm_fault___67 {
	struct vm_area_struct___68 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___68 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___68 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___67 prealloc_pte;
};

struct upid___56 {
	int nr;
	struct pid_namespace___56 *ns;
};

struct pid_namespace___56 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___68 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___56 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___68 *proc_self;
	struct dentry___68 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___55 *user_ns;
	struct ucounts___55 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common ns;
};

struct pid___56 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___56 numbers[1];
};

struct user_struct___64 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___65 *uid_keyring;
	struct key___65 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___64 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___65 *session_keyring;
	struct key___65 *process_keyring;
	struct key___65 *thread_keyring;
	struct key___65 *request_key_auth;
	void *security;
	struct user_struct___64 *user;
	struct user_namespace___55 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___53;

struct nsproxy___63 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___56 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___53 *cgroup_ns;
};

struct signal_struct___58 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___68 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___68 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___56 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___56 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___67 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___56 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___53;

struct cgroup___53;

struct css_set___53 {
	struct cgroup_subsys_state___53 *subsys[13];
	refcount_t refcount;
	struct css_set___53 *dom_cset;
	struct cgroup___53 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___53 *mg_src_cgrp;
	struct cgroup___53 *mg_dst_cgrp;
	struct css_set___53 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___42 {
	struct pmu___42 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___68 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___42 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___50 {
	struct vm_struct___50 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___68 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___58 {
	struct task_struct___68 task;
	long unsigned int stack[8192];
};

struct module_kobject___57 {
	struct kobject___65 kobj;
	struct module___60 *mod;
	struct kobject___65 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___57 {
	struct module___60 *mod;
	struct latch_tree_node node;
};

struct module_layout___57 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___57 mtn;
};

struct module_attribute___57;

struct kernel_param___57;

struct module___60 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___57 mkobj;
	struct module_attribute___57 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___65 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___57 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___57 core_layout;
	struct module_layout___57 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___37 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___67;

struct super_block___68;

struct dentry___68 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___68 *d_parent;
	struct qstr d_name;
	struct inode___69 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___67 *d_op;
	struct super_block___68 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___67;

struct block_device___68;

struct inode___69 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___67 *i_op;
	struct super_block___68 *i_sb;
	struct address_space___67 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___68 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___68 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___67 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___68 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___67 {
	int (*d_revalidate)(struct dentry___68 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___68 *, unsigned int);
	int (*d_hash)(const struct dentry___68 *, struct qstr *);
	int (*d_compare)(const struct dentry___68 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___68 *);
	int (*d_init)(struct dentry___68 *);
	void (*d_release)(struct dentry___68 *);
	void (*d_prune)(struct dentry___68 *);
	void (*d_iput)(struct dentry___68 *, struct inode___69 *);
	char * (*d_dname)(struct dentry___68 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___67 *);
	int (*d_manage)(const struct path___67 *, bool);
	struct dentry___68 * (*d_real)(struct dentry___68 *, const struct inode___69 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___67;

struct mem_dqinfo___67 {
	struct quota_format_type___67 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___67;

struct quota_info___67 {
	unsigned int flags;
	struct rw_semaphore___68 dqio_sem;
	struct inode___69 *files[3];
	struct mem_dqinfo___67 info[3];
	const struct quota_format_ops___67 *ops[3];
};

struct rcuwait___67 {
	struct task_struct___68 *task;
};

struct percpu_rw_semaphore___67 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___68 rw_sem;
	struct rcuwait___67 writer;
	int readers_block;
};

struct sb_writers___67 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___67 rw_sem[3];
};

struct file_system_type___67;

struct super_operations___67;

struct dquot_operations___67;

struct quotactl_ops___67;

struct super_block___68 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___67 *s_type;
	const struct super_operations___67 *s_op;
	const struct dquot_operations___67 *dq_op;
	const struct quotactl_ops___67 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___68 *s_root;
	struct rw_semaphore___68 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___68 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___67 s_dquot;
	struct sb_writers___67 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___67 *s_d_op;
	int cleancache_poolid;
	struct shrinker___28 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___55 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___68 {
	struct file___68 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___68 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___68 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___68 *ia_file;
};

struct dquot___67 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___68 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___67 {
	int qf_fmt_id;
	const struct quota_format_ops___67 *qf_ops;
	struct module___60 *qf_owner;
	struct quota_format_type___67 *qf_next;
};

struct quota_format_ops___67 {
	int (*check_quota_file)(struct super_block___68 *, int);
	int (*read_file_info)(struct super_block___68 *, int);
	int (*write_file_info)(struct super_block___68 *, int);
	int (*free_file_info)(struct super_block___68 *, int);
	int (*read_dqblk)(struct dquot___67 *);
	int (*commit_dqblk)(struct dquot___67 *);
	int (*release_dqblk)(struct dquot___67 *);
	int (*get_next_id)(struct super_block___68 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___67 {
	int (*write_dquot)(struct dquot___67 *);
	struct dquot___67 * (*alloc_dquot)(struct super_block___68 *, int);
	void (*destroy_dquot)(struct dquot___67 *);
	int (*acquire_dquot)(struct dquot___67 *);
	int (*release_dquot)(struct dquot___67 *);
	int (*mark_dirty)(struct dquot___67 *);
	int (*write_info)(struct super_block___68 *, int);
	qsize_t * (*get_reserved_space)(struct inode___69 *);
	int (*get_projid)(struct inode___69 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___69 *, qsize_t *);
	int (*get_next_id)(struct super_block___68 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___67 {
	int (*quota_on)(struct super_block___68 *, int, int, const struct path___67 *);
	int (*quota_off)(struct super_block___68 *, int);
	int (*quota_enable)(struct super_block___68 *, unsigned int);
	int (*quota_disable)(struct super_block___68 *, unsigned int);
	int (*quota_sync)(struct super_block___68 *, int);
	int (*set_info)(struct super_block___68 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___68 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___68 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___68 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___68 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___68 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___67 {
	int (*writepage)(struct page___68 *, struct writeback_control___3 *);
	int (*readpage)(struct file___68 *, struct page___68 *);
	int (*writepages)(struct address_space___67 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___68 *);
	int (*readpages)(struct file___68 *, struct address_space___67 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___68 *, struct address_space___67 *, loff_t, unsigned int, unsigned int, struct page___68 **, void **);
	int (*write_end)(struct file___68 *, struct address_space___67 *, loff_t, unsigned int, unsigned int, struct page___68 *, void *);
	sector_t (*bmap)(struct address_space___67 *, sector_t);
	void (*invalidatepage)(struct page___68 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___68 *, gfp_t);
	void (*freepage)(struct page___68 *);
	ssize_t (*direct_IO)(struct kiocb___68 *, struct iov_iter___28 *);
	int (*migratepage)(struct address_space___67 *, struct page___68 *, struct page___68 *, enum migrate_mode);
	bool (*isolate_page)(struct page___68 *, isolate_mode_t);
	void (*putback_page)(struct page___68 *);
	int (*launder_page)(struct page___68 *);
	int (*is_partially_uptodate)(struct page___68 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___68 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___67 *, struct page___68 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___68 *, sector_t *);
	void (*swap_deactivate)(struct file___68 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___68 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___69 *bd_inode;
	struct super_block___68 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___68 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___67 {
	struct dentry___68 * (*lookup)(struct inode___69 *, struct dentry___68 *, unsigned int);
	const char * (*get_link)(struct dentry___68 *, struct inode___69 *, struct delayed_call *);
	int (*permission)(struct inode___69 *, int);
	struct posix_acl * (*get_acl)(struct inode___69 *, int);
	int (*readlink)(struct dentry___68 *, char *, int);
	int (*create)(struct inode___69 *, struct dentry___68 *, umode_t, bool);
	int (*link)(struct dentry___68 *, struct inode___69 *, struct dentry___68 *);
	int (*unlink)(struct inode___69 *, struct dentry___68 *);
	int (*symlink)(struct inode___69 *, struct dentry___68 *, const char *);
	int (*mkdir)(struct inode___69 *, struct dentry___68 *, umode_t);
	int (*rmdir)(struct inode___69 *, struct dentry___68 *);
	int (*mknod)(struct inode___69 *, struct dentry___68 *, umode_t, dev_t);
	int (*rename)(struct inode___69 *, struct dentry___68 *, struct inode___69 *, struct dentry___68 *, unsigned int);
	int (*setattr)(struct dentry___68 *, struct iattr___68 *);
	int (*getattr)(const struct path___67 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___68 *, char *, size_t);
	int (*fiemap)(struct inode___69 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___69 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___69 *, struct dentry___68 *, struct file___68 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___69 *, struct dentry___68 *, umode_t);
	int (*set_acl)(struct inode___69 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___67 {
	void (*fl_copy_lock)(struct file_lock___68 *, struct file_lock___68 *);
	void (*fl_release_private)(struct file_lock___68 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___67;

struct file_lock___68 {
	struct file_lock___68 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___68 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___67 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___67 *fl_ops;
	const struct lock_manager_operations___67 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___67 {
	int (*lm_compare_owner)(struct file_lock___68 *, struct file_lock___68 *);
	long unsigned int (*lm_owner_key)(struct file_lock___68 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___68 *);
	int (*lm_grant)(struct file_lock___68 *, int);
	bool (*lm_break)(struct file_lock___68 *);
	int (*lm_change)(struct file_lock___68 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___68 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___67 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___67 *fa_next;
	struct file___68 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___67 {
	const char *name;
	int fs_flags;
	struct dentry___68 * (*mount)(struct file_system_type___67 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___68 *);
	struct module___60 *owner;
	struct file_system_type___67 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___67 {
	struct inode___69 * (*alloc_inode)(struct super_block___68 *);
	void (*destroy_inode)(struct inode___69 *);
	void (*dirty_inode)(struct inode___69 *, int);
	int (*write_inode)(struct inode___69 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___69 *);
	void (*evict_inode)(struct inode___69 *);
	void (*put_super)(struct super_block___68 *);
	int (*sync_fs)(struct super_block___68 *, int);
	int (*freeze_super)(struct super_block___68 *);
	int (*freeze_fs)(struct super_block___68 *);
	int (*thaw_super)(struct super_block___68 *);
	int (*unfreeze_fs)(struct super_block___68 *);
	int (*statfs)(struct dentry___68 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___68 *, int *, char *);
	void (*umount_begin)(struct super_block___68 *);
	int (*show_options)(struct seq_file___62 *, struct dentry___68 *);
	int (*show_devname)(struct seq_file___62 *, struct dentry___68 *);
	int (*show_path)(struct seq_file___62 *, struct dentry___68 *);
	int (*show_stats)(struct seq_file___62 *, struct dentry___68 *);
	ssize_t (*quota_read)(struct super_block___68 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___68 *, int, const char *, size_t, loff_t);
	struct dquot___67 ** (*get_dquots)(struct inode___69 *);
	int (*bdev_try_to_free_page)(struct super_block___68 *, struct page___68 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___68 *, struct shrink_control___28 *);
	long int (*free_cached_objects)(struct super_block___68 *, struct shrink_control___28 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*key_restrict_link_func_t___64)(struct key___65 *, const struct key_type *, const union key_payload *, struct key___65 *);

struct key_restriction___65;

struct key___65 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___68 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___65 *restrict_link;
};

struct key_restriction___65 {
	key_restrict_link_func_t___64 check;
	struct key___65 *key;
	struct key_type *keytype;
};

typedef void compound_page_dtor___67(struct page___68 *);

struct seq_operations___59 {
	void * (*start)(struct seq_file___62 *, loff_t *);
	void (*stop)(struct seq_file___62 *, void *);
	void * (*next)(struct seq_file___62 *, void *, loff_t *);
	int (*show)(struct seq_file___62 *, void *);
};

struct cgroup_namespace___53 {
	refcount_t count;
	struct ns_common ns;
	struct user_namespace___55 *user_ns;
	struct ucounts___55 *ucounts;
	struct css_set___53 *root_cset;
};

struct ucounts___55 {
	struct hlist_node node;
	struct user_namespace___55 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct kernel_param_ops___57 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___57 *);
	int (*get)(char *, const struct kernel_param___57 *);
	void (*free)(void *);
};

struct kparam_array___57;

struct kernel_param___57 {
	const char *name;
	struct module___60 *mod;
	const struct kernel_param_ops___57 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___57 *arr;
	};
};

struct kparam_array___57 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___57 *ops;
	void *elem;
};

struct module_attribute___57 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___57 *, struct module_kobject___57 *, char *);
	ssize_t (*store)(struct module_attribute___57 *, struct module_kobject___57 *, const char *, size_t);
	void (*setup)(struct module___60 *, const char *);
	int (*test)(struct module___60 *);
	void (*free)(struct module___60 *);
};

struct trace_event_class___37;

struct trace_event_call___37 {
	struct list_head list;
	struct trace_event_class___37 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array *prog_array;
	int (*perf_perm)(struct trace_event_call___37 *, struct perf_event___42 *);
};

struct dev_pm_ops___62 {
	int (*prepare)(struct device___62 *);
	void (*complete)(struct device___62 *);
	int (*suspend)(struct device___62 *);
	int (*resume)(struct device___62 *);
	int (*freeze)(struct device___62 *);
	int (*thaw)(struct device___62 *);
	int (*poweroff)(struct device___62 *);
	int (*restore)(struct device___62 *);
	int (*suspend_late)(struct device___62 *);
	int (*resume_early)(struct device___62 *);
	int (*freeze_late)(struct device___62 *);
	int (*thaw_early)(struct device___62 *);
	int (*poweroff_late)(struct device___62 *);
	int (*restore_early)(struct device___62 *);
	int (*suspend_noirq)(struct device___62 *);
	int (*resume_noirq)(struct device___62 *);
	int (*freeze_noirq)(struct device___62 *);
	int (*thaw_noirq)(struct device___62 *);
	int (*poweroff_noirq)(struct device___62 *);
	int (*restore_noirq)(struct device___62 *);
	int (*runtime_suspend)(struct device___62 *);
	int (*runtime_resume)(struct device___62 *);
	int (*runtime_idle)(struct device___62 *);
};

struct dev_pm_domain___62 {
	struct dev_pm_ops___62 ops;
	void (*detach)(struct device___62 *, bool);
	int (*activate)(struct device___62 *);
	void (*sync)(struct device___62 *);
	void (*dismiss)(struct device___62 *);
};

struct bus_type___62 {
	const char *name;
	const char *dev_name;
	struct device___62 *dev_root;
	const struct attribute_group___62 **bus_groups;
	const struct attribute_group___62 **dev_groups;
	const struct attribute_group___62 **drv_groups;
	int (*match)(struct device___62 *, struct device_driver___62 *);
	int (*uevent)(struct device___62 *, struct kobj_uevent_env *);
	int (*probe)(struct device___62 *);
	int (*remove)(struct device___62 *);
	void (*shutdown)(struct device___62 *);
	int (*online)(struct device___62 *);
	int (*offline)(struct device___62 *);
	int (*suspend)(struct device___62 *, pm_message_t);
	int (*resume)(struct device___62 *);
	int (*num_vf)(struct device___62 *);
	int (*dma_configure)(struct device___62 *);
	const struct dev_pm_ops___62 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___62 {
	const char *name;
	struct bus_type___62 *bus;
	struct module___60 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___62 *);
	int (*remove)(struct device___62 *);
	void (*shutdown)(struct device___62 *);
	int (*suspend)(struct device___62 *, pm_message_t);
	int (*resume)(struct device___62 *);
	const struct attribute_group___62 **groups;
	const struct dev_pm_ops___62 *pm;
	void (*coredump)(struct device___62 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___62 {
	const char *name;
	const struct attribute_group___62 **groups;
	int (*uevent)(struct device___62 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___62 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___62 *);
	const struct dev_pm_ops___62 *pm;
};

struct class___62 {
	const char *name;
	struct module___60 *owner;
	const struct attribute_group___62 **class_groups;
	const struct attribute_group___62 **dev_groups;
	struct kobject___65 *dev_kobj;
	int (*dev_uevent)(struct device___62 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___62 *, umode_t *);
	void (*class_release)(struct class___62 *);
	void (*dev_release)(struct device___62 *);
	int (*shutdown_pre)(struct device___62 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___62 *);
	const struct dev_pm_ops___62 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___55 {
	struct device___62 dev;
};

struct bpf_map___53;

struct bpf_map_ops___53 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___53 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___53 *, struct file___68 *);
	void (*map_free)(struct bpf_map___53 *);
	int (*map_get_next_key)(struct bpf_map___53 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___53 *);
	void * (*map_lookup_elem)(struct bpf_map___53 *, void *);
	int (*map_update_elem)(struct bpf_map___53 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___53 *, void *);
	int (*map_push_elem)(struct bpf_map___53 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___53 *, void *);
	int (*map_peek_elem)(struct bpf_map___53 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___53 *, struct file___68 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___53 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___53 *, void *, struct seq_file___62 *);
	int (*map_check_btf)(const struct bpf_map___53 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___53 {
	const struct bpf_map_ops___53 *ops;
	struct bpf_map___53 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___64 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___53;

typedef void (*kthread_work_func_t___53)(struct kthread_work___53 *);

struct kthread_worker___53;

struct kthread_work___53 {
	struct list_head node;
	kthread_work_func_t___53 func;
	struct kthread_worker___53 *worker;
	int canceling;
};

struct kthread_worker___53 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___68 *task;
	struct kthread_work___53 *current_work;
};

struct kthread_delayed_work___53 {
	struct kthread_work___53 work;
	struct timer_list timer;
};

struct psi_group___53 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___53 *poll_kworker;
	struct kthread_delayed_work___53 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___53 {
	struct kernfs_node___65 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___53;

struct cgroup_subsys_state___53 {
	struct cgroup___53 *cgroup;
	struct cgroup_subsys___53 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___53 *parent;
};

struct cgroup_root___53;

struct cgroup_rstat_cpu___53;

struct cgroup___53 {
	struct cgroup_subsys_state___53 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___65 *kn;
	struct cgroup_file___53 procs_file;
	struct cgroup_file___53 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___53 *subsys[13];
	struct cgroup_root___53 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___53 *dom_cgrp;
	struct cgroup_rstat_cpu___53 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf bpf;
	atomic_t congestion_count;
	struct cgroup___53 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___53 psi;
	int ancestor_ids[0];
};

struct cftype___53;

struct cgroup_subsys___53 {
	struct cgroup_subsys_state___53 * (*css_alloc)(struct cgroup_subsys_state___53 *);
	int (*css_online)(struct cgroup_subsys_state___53 *);
	void (*css_offline)(struct cgroup_subsys_state___53 *);
	void (*css_released)(struct cgroup_subsys_state___53 *);
	void (*css_free)(struct cgroup_subsys_state___53 *);
	void (*css_reset)(struct cgroup_subsys_state___53 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___53 *, int);
	int (*css_extra_stat_show)(struct seq_file___62 *, struct cgroup_subsys_state___53 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___68 *);
	void (*cancel_fork)(struct task_struct___68 *);
	void (*fork)(struct task_struct___68 *);
	void (*exit)(struct task_struct___68 *);
	void (*free)(struct task_struct___68 *);
	void (*bind)(struct cgroup_subsys_state___53 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___53 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___53 *dfl_cftypes;
	struct cftype___53 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___53 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___53 *updated_children;
	struct cgroup___53 *updated_next;
};

struct cgroup_root___53 {
	struct kernfs_root___65 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___53 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___53 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___53 *ss;
	struct list_head node;
	struct kernfs_ops___65 *kf_ops;
	int (*open)(struct kernfs_open_file___65 *);
	void (*release)(struct kernfs_open_file___65 *);
	u64 (*read_u64)(struct cgroup_subsys_state___53 *, struct cftype___53 *);
	s64 (*read_s64)(struct cgroup_subsys_state___53 *, struct cftype___53 *);
	int (*seq_show)(struct seq_file___62 *, void *);
	void * (*seq_start)(struct seq_file___62 *, loff_t *);
	void * (*seq_next)(struct seq_file___62 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___62 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___53 *, struct cftype___53 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___53 *, struct cftype___53 *, s64);
	ssize_t (*write)(struct kernfs_open_file___65 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___65 *, struct poll_table_struct___43 *);
};

struct perf_cpu_context___42;

struct pmu___42 {
	struct list_head entry;
	struct module___60 *module;
	struct device___62 *dev;
	const struct attribute_group___62 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___42 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___42 *);
	void (*pmu_disable)(struct pmu___42 *);
	int (*event_init)(struct perf_event___42 *);
	void (*event_mapped)(struct perf_event___42 *, struct mm_struct___67 *);
	void (*event_unmapped)(struct perf_event___42 *, struct mm_struct___67 *);
	int (*add)(struct perf_event___42 *, int);
	void (*del)(struct perf_event___42 *, int);
	void (*start)(struct perf_event___42 *, int);
	void (*stop)(struct perf_event___42 *, int);
	void (*read)(struct perf_event___42 *);
	void (*start_txn)(struct pmu___42 *, unsigned int);
	int (*commit_txn)(struct pmu___42 *);
	void (*cancel_txn)(struct pmu___42 *);
	int (*event_idx)(struct perf_event___42 *);
	void (*sched_task)(struct perf_event_context___42 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___42 *);
	int (*filter_match)(struct perf_event___42 *);
	int (*check_period)(struct perf_event___42 *, u64);
};

struct perf_cpu_context___42 {
	struct perf_event_context___42 ctx;
	struct perf_event_context___42 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___42 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___42 {
	struct cgroup_subsys_state___53 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___37 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___37 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___37 *);
	struct list_head * (*get_fields)(struct trace_event_call___37 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___37 *);
};

struct syscall_metadata___16 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___37 *enter_event;
	struct trace_event_call___37 *exit_event;
};

struct module___61;

struct file___69;

struct kiocb___69;

struct iov_iter___29;

struct poll_table_struct___44;

struct vm_area_struct___69;

struct inode___70;

struct file_lock___69;

struct page___69;

struct seq_file___63;

struct file_operations___69 {
	struct module___61 *owner;
	loff_t (*llseek)(struct file___69 *, loff_t, int);
	ssize_t (*read)(struct file___69 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___69 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___69 *, struct iov_iter___29 *);
	ssize_t (*write_iter)(struct kiocb___69 *, struct iov_iter___29 *);
	int (*iopoll)(struct kiocb___69 *, bool);
	int (*iterate)(struct file___69 *, struct dir_context *);
	int (*iterate_shared)(struct file___69 *, struct dir_context *);
	__poll_t (*poll)(struct file___69 *, struct poll_table_struct___44 *);
	long int (*unlocked_ioctl)(struct file___69 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___69 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___69 *, struct vm_area_struct___69 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___70 *, struct file___69 *);
	int (*flush)(struct file___69 *, fl_owner_t);
	int (*release)(struct inode___70 *, struct file___69 *);
	int (*fsync)(struct file___69 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___69 *, int);
	int (*lock)(struct file___69 *, int, struct file_lock___69 *);
	ssize_t (*sendpage)(struct file___69 *, struct page___69 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___69 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___69 *, int, struct file_lock___69 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___69 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___69 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___69 *, long int, struct file_lock___69 **, void **);
	long int (*fallocate)(struct file___69 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___63 *, struct file___69 *);
	ssize_t (*copy_file_range)(struct file___69 *, loff_t, struct file___69 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___69 *, loff_t, struct file___69 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___69 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct itimerval {
	struct timeval it_interval;
	struct timeval it_value;
};

struct vmacache___68 {
	u64 seqnum;
	struct vm_area_struct___69 *vmas[4];
};

struct page_frag___68 {
	struct page___69 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___43;

struct debug_info___43 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___43 *hbp_break[16];
	struct perf_event___43 *hbp_watch[16];
};

struct thread_struct___43 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___43 debug;
	long: 64;
};

struct mm_struct___68;

struct mem_cgroup___29;

struct pid___57;

struct cred___65;

struct nsproxy___64;

struct signal_struct___59;

struct bio_list___30;

struct backing_dev_info___30;

struct css_set___54;

struct perf_event_context___43;

struct vm_struct___51;

struct task_struct___69 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___69 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___68 *mm;
	struct mm_struct___68 *active_mm;
	struct vmacache___68 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___69 *real_parent;
	struct task_struct___69 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___69 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___29 *active_memcg;
	long int rh_reserved2;
	struct pid___57 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___57 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___57 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___65 *ptracer_cred;
	const struct cred___65 *real_cred;
	const struct cred___65 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___64 *nsproxy;
	struct signal_struct___59 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___69 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___30 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___30 *backing_dev_info;
	struct io_context___13 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___54 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___43 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___68 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___29 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___69 *oom_reaper_list;
	struct vm_struct___51 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___43 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct secondary_data___69 {
	void *stack;
	struct task_struct___69 *task;
	long int status;
};

struct hw_perf_event___43 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___69 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___43)(struct perf_event___43 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___43;

struct fasync_struct___68;

struct pid_namespace___57;

struct trace_event_call___38;

struct perf_cgroup___43;

struct perf_event___43 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___43 *group_leader;
	struct pmu___43 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___43 hw;
	struct perf_event_context___43 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___43 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___69 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___68 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___43 *);
	struct callback_head callback_head;
	struct pid_namespace___57 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___43 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___43 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___38 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___43 *cgrp;
	struct list_head sb_list;
};

struct clock_event_device___12;

struct arch_timer_erratum_workaround___12 {
	enum arch_timer_erratum_match_type match_type;
	const void *id;
	const char *desc;
	u32 (*read_cntp_tval_el0)();
	u32 (*read_cntv_tval_el0)();
	u64 (*read_cntpct_el0)();
	u64 (*read_cntvct_el0)();
	int (*set_next_event_phys)(long unsigned int, struct clock_event_device___12 *);
	int (*set_next_event_virt)(long unsigned int, struct clock_event_device___12 *);
};

struct clock_event_device___12 {
	void (*event_handler)(struct clock_event_device___12 *);
	int (*set_next_event)(long unsigned int, struct clock_event_device___12 *);
	int (*set_next_ktime)(ktime_t, struct clock_event_device___12 *);
	ktime_t next_event;
	u64 max_delta_ns;
	u64 min_delta_ns;
	u32 mult;
	u32 shift;
	enum clock_event_state state_use_accessors;
	unsigned int features;
	long unsigned int retries;
	int (*set_state_periodic)(struct clock_event_device___12 *);
	int (*set_state_oneshot)(struct clock_event_device___12 *);
	int (*set_state_oneshot_stopped)(struct clock_event_device___12 *);
	int (*set_state_shutdown)(struct clock_event_device___12 *);
	int (*tick_resume)(struct clock_event_device___12 *);
	void (*broadcast)(const struct cpumask *);
	void (*suspend)(struct clock_event_device___12 *);
	void (*resume)(struct clock_event_device___12 *);
	long unsigned int min_delta_ticks;
	long unsigned int max_delta_ticks;
	const char *name;
	int rating;
	int irq;
	int bound_on;
	const struct cpumask *cpumask;
	struct list_head list;
	struct module___61 *owner;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct tick_device___3 {
	struct clock_event_device___12 *evtdev;
	enum tick_device_mode mode;
};

struct upid___57 {
	int nr;
	struct pid_namespace___57 *ns;
};

struct dentry___69;

struct user_namespace___56;

struct ucounts___56;

struct pid_namespace___57 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___69 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___57 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___69 *proc_self;
	struct dentry___69 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___56 *user_ns;
	struct ucounts___56 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common ns;
};

struct pid___57 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___57 numbers[1];
};

struct rw_semaphore___69 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___69 *owner;
};

struct key___66;

struct user_namespace___56 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___56 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common ns;
	long unsigned int flags;
	struct key___66 *persistent_keyring_register;
	struct rw_semaphore___69 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___56 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___69 *pgtable_t___68;

struct address_space___68;

struct dev_pagemap___68;

struct page___69 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___68 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___69 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___68 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___68 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___68 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___29 *mem_cgroup;
};

struct user_struct___65 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___66 *uid_keyring;
	struct key___66 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___68;

struct vm_area_struct___69 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___69 *vm_next;
	struct vm_area_struct___69 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___68 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___68 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___69 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___68;

struct mm_struct___68 {
	struct {
		struct vm_area_struct___69 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___69 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___69 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___68 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___69 *owner;
		struct user_namespace___56 *user_ns;
		struct file___69 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___68 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup___54;

struct cgroup_subsys___54;

struct cgroup_subsys_state___54 {
	struct cgroup___54 *cgroup;
	struct cgroup_subsys___54 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___54 *parent;
};

struct kernfs_node___66;

struct cgroup_file___54 {
	struct kernfs_node___66 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___29;

struct mem_cgroup___29 {
	struct cgroup_subsys_state___54 css;
	struct mem_cgroup_id___6 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___54 events_file;
	struct cgroup_file___54 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___69 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___29 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cred___65 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___66 *session_keyring;
	struct key___66 *process_keyring;
	struct key___66 *thread_keyring;
	struct key___66 *request_key_auth;
	void *security;
	struct user_struct___65 *user;
	struct user_namespace___56 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___54;

struct nsproxy___64 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___57 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___54 *cgroup_ns;
};

struct signal_struct___59 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___69 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___69 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___57 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___57 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___68 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___57 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___30;

struct bio_list___30 {
	struct bio___30 *head;
	struct bio___30 *tail;
};

struct bdi_writeback_congested___30;

struct bdi_writeback___30 {
	struct backing_dev_info___30 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___30 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___54 *memcg_css;
	struct cgroup_subsys_state___54 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___63;

struct backing_dev_info___30 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___30 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___63 *dev;
	struct device___63 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___69 *debug_dir;
	struct dentry___69 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___54 {
	struct cgroup_subsys_state___54 *subsys[13];
	refcount_t refcount;
	struct css_set___54 *dom_cset;
	struct cgroup___54 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___54 *mg_src_cgrp;
	struct cgroup___54 *mg_dst_cgrp;
	struct css_set___54 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___43 {
	struct pmu___43 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___69 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___43 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___51 {
	struct vm_struct___51 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___69 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___59 {
	struct task_struct___69 task;
	long unsigned int stack[8192];
};

struct pglist_data___68;

struct lruvec___68 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___68 *pgdat;
};

struct zone___68 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___68 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___68 {
	struct zone___68 *zone;
	int zone_idx;
};

struct zonelist___68 {
	struct zoneref___68 _zonerefs[25];
};

struct pglist_data___68 {
	struct zone___68 node_zones[3];
	struct zonelist___68 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___69 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___69 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___68 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___68 {
	struct rw_semaphore___69 rwsem;
	struct notifier_block *head;
};

struct address_space_operations___68;

struct address_space___68 {
	struct inode___70 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___69 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___68 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___68)(struct vm_area_struct___69 *, long unsigned int, const struct page___69 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___68)(struct page___69 *, void *);

struct dev_pagemap___68 {
	dev_page_fault_t___68 page_fault;
	dev_page_free_t___68 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___63 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___68 {
	struct vfsmount *mnt;
	struct dentry___69 *dentry;
};

struct fown_struct___57 {
	rwlock_t lock;
	struct pid___57 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___69 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___68 f_path;
	struct inode___70 *f_inode;
	const struct file_operations___69 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___57 f_owner;
	const struct cred___65 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___68 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___68;

struct vm_operations_struct___68 {
	void (*open)(struct vm_area_struct___69 *);
	void (*close)(struct vm_area_struct___69 *);
	int (*split)(struct vm_area_struct___69 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___69 *);
	vm_fault_t (*fault)(struct vm_fault___68 *);
	vm_fault_t (*huge_fault)(struct vm_fault___68 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___68 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___69 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___68 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___68 *);
	int (*access)(struct vm_area_struct___69 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___69 *);
	int (*set_policy)(struct vm_area_struct___69 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___69 *, long unsigned int);
	struct page___69 * (*find_special_page)(struct vm_area_struct___69 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___68 {
	struct task_struct___69 *task;
	struct core_thread___68 *next;
};

struct core_state___68 {
	atomic_t nr_threads;
	struct core_thread___68 dumper;
	struct completion startup;
};

struct vm_fault___68 {
	struct vm_area_struct___69 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___69 *cow_page;
	struct mem_cgroup___29 *memcg;
	struct page___69 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___68 prealloc_pte;
};

struct shrink_control___29 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___29 *memcg;
};

struct shrinker___29 {
	long unsigned int (*count_objects)(struct shrinker___29 *, struct shrink_control___29 *);
	long unsigned int (*scan_objects)(struct shrinker___29 *, struct shrink_control___29 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct kset___65;

struct kobj_type___65;

struct kobject___66 {
	const char *name;
	struct list_head entry;
	struct kobject___66 *parent;
	struct kset___65 *kset;
	struct kobj_type___65 *ktype;
	struct kernfs_node___66 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___63 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___63 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___63;

struct bus_type___63;

struct device_driver___63;

struct dev_pm_domain___63;

struct device_node___22;

struct fwnode_handle___48;

struct class___63;

struct attribute_group___63;

struct device___63 {
	struct device___63 *parent;
	struct device_private *p;
	struct kobject___66 kobj;
	const char *init_name;
	const struct device_type___63 *type;
	struct mutex mutex;
	struct bus_type___63 *bus;
	struct device_driver___63 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___63 power;
	struct dev_pm_domain___63 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___22 *of_node;
	struct fwnode_handle___48 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___63 *class;
	const struct attribute_group___63 **groups;
	void (*release)(struct device___63 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___68;

struct super_block___69;

struct dentry___69 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___69 *d_parent;
	struct qstr d_name;
	struct inode___70 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___68 *d_op;
	struct super_block___69 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___68;

struct block_device___69;

struct cdev___16;

struct inode___70 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___68 *i_op;
	struct super_block___69 *i_sb;
	struct address_space___68 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___69 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___30 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___69 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___68 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___69 *i_bdev;
		struct cdev___16 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___68 {
	int (*d_revalidate)(struct dentry___69 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___69 *, unsigned int);
	int (*d_hash)(const struct dentry___69 *, struct qstr *);
	int (*d_compare)(const struct dentry___69 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___69 *);
	int (*d_init)(struct dentry___69 *);
	void (*d_release)(struct dentry___69 *);
	void (*d_prune)(struct dentry___69 *);
	void (*d_iput)(struct dentry___69 *, struct inode___70 *);
	char * (*d_dname)(struct dentry___69 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___68 *);
	int (*d_manage)(const struct path___68 *, bool);
	struct dentry___69 * (*d_real)(struct dentry___69 *, const struct inode___70 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___68;

struct mem_dqinfo___68 {
	struct quota_format_type___68 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___68;

struct quota_info___68 {
	unsigned int flags;
	struct rw_semaphore___69 dqio_sem;
	struct inode___70 *files[3];
	struct mem_dqinfo___68 info[3];
	const struct quota_format_ops___68 *ops[3];
};

struct rcuwait___68 {
	struct task_struct___69 *task;
};

struct percpu_rw_semaphore___68 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___69 rw_sem;
	struct rcuwait___68 writer;
	int readers_block;
};

struct sb_writers___68 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___68 rw_sem[3];
};

struct file_system_type___68;

struct super_operations___68;

struct dquot_operations___68;

struct quotactl_ops___68;

struct super_block___69 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___68 *s_type;
	const struct super_operations___68 *s_op;
	const struct dquot_operations___68 *dq_op;
	const struct quotactl_ops___68 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___69 *s_root;
	struct rw_semaphore___69 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___69 *s_bdev;
	struct backing_dev_info___30 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___68 s_dquot;
	struct sb_writers___68 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___68 *s_d_op;
	int cleancache_poolid;
	struct shrinker___29 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___56 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___69 {
	struct file___69 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___69 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___69 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___69 *ia_file;
};

struct dquot___68 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___69 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___68 {
	int qf_fmt_id;
	const struct quota_format_ops___68 *qf_ops;
	struct module___61 *qf_owner;
	struct quota_format_type___68 *qf_next;
};

struct quota_format_ops___68 {
	int (*check_quota_file)(struct super_block___69 *, int);
	int (*read_file_info)(struct super_block___69 *, int);
	int (*write_file_info)(struct super_block___69 *, int);
	int (*free_file_info)(struct super_block___69 *, int);
	int (*read_dqblk)(struct dquot___68 *);
	int (*commit_dqblk)(struct dquot___68 *);
	int (*release_dqblk)(struct dquot___68 *);
	int (*get_next_id)(struct super_block___69 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___68 {
	int (*write_dquot)(struct dquot___68 *);
	struct dquot___68 * (*alloc_dquot)(struct super_block___69 *, int);
	void (*destroy_dquot)(struct dquot___68 *);
	int (*acquire_dquot)(struct dquot___68 *);
	int (*release_dquot)(struct dquot___68 *);
	int (*mark_dirty)(struct dquot___68 *);
	int (*write_info)(struct super_block___69 *, int);
	qsize_t * (*get_reserved_space)(struct inode___70 *);
	int (*get_projid)(struct inode___70 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___70 *, qsize_t *);
	int (*get_next_id)(struct super_block___69 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___68 {
	int (*quota_on)(struct super_block___69 *, int, int, const struct path___68 *);
	int (*quota_off)(struct super_block___69 *, int);
	int (*quota_enable)(struct super_block___69 *, unsigned int);
	int (*quota_disable)(struct super_block___69 *, unsigned int);
	int (*quota_sync)(struct super_block___69 *, int);
	int (*set_info)(struct super_block___69 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___69 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___69 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___69 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___69 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___69 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___58 {
	struct kobject___66 kobj;
	struct module___61 *mod;
	struct kobject___66 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___58 {
	struct module___61 *mod;
	struct latch_tree_node node;
};

struct module_layout___58 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___58 mtn;
};

struct module_attribute___58;

struct kernel_param___58;

struct module___61 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___58 mkobj;
	struct module_attribute___58 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___66 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___58 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___58 core_layout;
	struct module_layout___58 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___38 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___29;

struct swap_info_struct___24;

struct address_space_operations___68 {
	int (*writepage)(struct page___69 *, struct writeback_control___29 *);
	int (*readpage)(struct file___69 *, struct page___69 *);
	int (*writepages)(struct address_space___68 *, struct writeback_control___29 *);
	int (*set_page_dirty)(struct page___69 *);
	int (*readpages)(struct file___69 *, struct address_space___68 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___69 *, struct address_space___68 *, loff_t, unsigned int, unsigned int, struct page___69 **, void **);
	int (*write_end)(struct file___69 *, struct address_space___68 *, loff_t, unsigned int, unsigned int, struct page___69 *, void *);
	sector_t (*bmap)(struct address_space___68 *, sector_t);
	void (*invalidatepage)(struct page___69 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___69 *, gfp_t);
	void (*freepage)(struct page___69 *);
	ssize_t (*direct_IO)(struct kiocb___69 *, struct iov_iter___29 *);
	int (*migratepage)(struct address_space___68 *, struct page___69 *, struct page___69 *, enum migrate_mode);
	bool (*isolate_page)(struct page___69 *, isolate_mode_t);
	void (*putback_page)(struct page___69 *);
	int (*launder_page)(struct page___69 *);
	int (*is_partially_uptodate)(struct page___69 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___69 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___68 *, struct page___69 *);
	int (*swap_activate)(struct swap_info_struct___24 *, struct file___69 *, sector_t *);
	void (*swap_deactivate)(struct file___69 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___29 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___30 *wb;
	struct inode___70 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___30;

struct iov_iter___29 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___30 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct swap_info_struct___24 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___69 *bdev;
	struct file___69 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___69 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___70 *bd_inode;
	struct super_block___69 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___69 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___30 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___16 {
	struct kobject___66 kobj;
	struct module___61 *owner;
	const struct file_operations___69 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___68 {
	struct dentry___69 * (*lookup)(struct inode___70 *, struct dentry___69 *, unsigned int);
	const char * (*get_link)(struct dentry___69 *, struct inode___70 *, struct delayed_call *);
	int (*permission)(struct inode___70 *, int);
	struct posix_acl * (*get_acl)(struct inode___70 *, int);
	int (*readlink)(struct dentry___69 *, char *, int);
	int (*create)(struct inode___70 *, struct dentry___69 *, umode_t, bool);
	int (*link)(struct dentry___69 *, struct inode___70 *, struct dentry___69 *);
	int (*unlink)(struct inode___70 *, struct dentry___69 *);
	int (*symlink)(struct inode___70 *, struct dentry___69 *, const char *);
	int (*mkdir)(struct inode___70 *, struct dentry___69 *, umode_t);
	int (*rmdir)(struct inode___70 *, struct dentry___69 *);
	int (*mknod)(struct inode___70 *, struct dentry___69 *, umode_t, dev_t);
	int (*rename)(struct inode___70 *, struct dentry___69 *, struct inode___70 *, struct dentry___69 *, unsigned int);
	int (*setattr)(struct dentry___69 *, struct iattr___69 *);
	int (*getattr)(const struct path___68 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___69 *, char *, size_t);
	int (*fiemap)(struct inode___70 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___70 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___70 *, struct dentry___69 *, struct file___69 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___70 *, struct dentry___69 *, umode_t);
	int (*set_acl)(struct inode___70 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___68 {
	void (*fl_copy_lock)(struct file_lock___69 *, struct file_lock___69 *);
	void (*fl_release_private)(struct file_lock___69 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___68;

struct file_lock___69 {
	struct file_lock___69 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___69 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___68 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___68 *fl_ops;
	const struct lock_manager_operations___68 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___68 {
	int (*lm_compare_owner)(struct file_lock___69 *, struct file_lock___69 *);
	long unsigned int (*lm_owner_key)(struct file_lock___69 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___69 *);
	int (*lm_grant)(struct file_lock___69 *, int);
	bool (*lm_break)(struct file_lock___69 *);
	int (*lm_change)(struct file_lock___69 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___69 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___68 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___68 *fa_next;
	struct file___69 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___68 {
	const char *name;
	int fs_flags;
	struct dentry___69 * (*mount)(struct file_system_type___68 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___69 *);
	struct module___61 *owner;
	struct file_system_type___68 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___68 {
	struct inode___70 * (*alloc_inode)(struct super_block___69 *);
	void (*destroy_inode)(struct inode___70 *);
	void (*dirty_inode)(struct inode___70 *, int);
	int (*write_inode)(struct inode___70 *, struct writeback_control___29 *);
	int (*drop_inode)(struct inode___70 *);
	void (*evict_inode)(struct inode___70 *);
	void (*put_super)(struct super_block___69 *);
	int (*sync_fs)(struct super_block___69 *, int);
	int (*freeze_super)(struct super_block___69 *);
	int (*freeze_fs)(struct super_block___69 *);
	int (*thaw_super)(struct super_block___69 *);
	int (*unfreeze_fs)(struct super_block___69 *);
	int (*statfs)(struct dentry___69 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___69 *, int *, char *);
	void (*umount_begin)(struct super_block___69 *);
	int (*show_options)(struct seq_file___63 *, struct dentry___69 *);
	int (*show_devname)(struct seq_file___63 *, struct dentry___69 *);
	int (*show_path)(struct seq_file___63 *, struct dentry___69 *);
	int (*show_stats)(struct seq_file___63 *, struct dentry___69 *);
	ssize_t (*quota_read)(struct super_block___69 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___69 *, int, const char *, size_t, loff_t);
	struct dquot___68 ** (*get_dquots)(struct inode___70 *);
	int (*bdev_try_to_free_page)(struct super_block___69 *, struct page___69 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___69 *, struct shrink_control___29 *);
	long int (*free_cached_objects)(struct super_block___69 *, struct shrink_control___29 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___43)(struct file___69 *, wait_queue_head_t *, struct poll_table_struct___44 *);

struct poll_table_struct___44 {
	poll_queue_proc___43 _qproc;
	__poll_t _key;
};

struct seq_operations___60;

struct seq_file___63 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___60 *op;
	int poll_event;
	const struct file___69 *file;
	void *private;
};

typedef void bio_end_io_t___30(struct bio___30 *);

struct bio_vec___30 {
	struct page___69 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___30;

struct bio_set___30;

struct bio___30 {
	struct bio___30 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___30 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___30 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___30 *bi_io_vec;
	struct bio_set___30 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___30 bi_inline_vecs[0];
};

struct kobj_attribute___66 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___66 *, struct kobj_attribute___66 *, char *);
	ssize_t (*store)(struct kobject___66 *, struct kobj_attribute___66 *, const char *, size_t);
};

typedef void compound_page_dtor___68(struct page___69 *);

typedef int (*key_restrict_link_func_t___65)(struct key___66 *, const struct key_type *, const union key_payload *, struct key___66 *);

struct key_restriction___66;

struct key___66 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___69 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___66 *restrict_link;
};

struct key_restriction___66 {
	key_restrict_link_func_t___65 check;
	struct key___66 *key;
	struct key_type *keytype;
};

struct seq_operations___60 {
	void * (*start)(struct seq_file___63 *, loff_t *);
	void (*stop)(struct seq_file___63 *, void *);
	void * (*next)(struct seq_file___63 *, void *, loff_t *);
	int (*show)(struct seq_file___63 *, void *);
};

struct kernfs_root___66;

struct kernfs_elem_dir___66 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___66 *root;
};

struct kernfs_syscall_ops___66;

struct kernfs_root___66 {
	struct kernfs_node___66 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___66 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___66 {
	struct kernfs_node___66 *target_kn;
};

struct kernfs_ops___66;

struct kernfs_elem_attr___66 {
	const struct kernfs_ops___66 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___66 *notify_next;
};

struct kernfs_node___66 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___66 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___66 dir;
		struct kernfs_elem_symlink___66 symlink;
		struct kernfs_elem_attr___66 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___66;

struct kernfs_ops___66 {
	int (*open)(struct kernfs_open_file___66 *);
	void (*release)(struct kernfs_open_file___66 *);
	int (*seq_show)(struct seq_file___63 *, void *);
	void * (*seq_start)(struct seq_file___63 *, loff_t *);
	void * (*seq_next)(struct seq_file___63 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___63 *, void *);
	ssize_t (*read)(struct kernfs_open_file___66 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___66 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___66 *, struct vm_area_struct___69 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___66 *, struct poll_table_struct___44 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___66 {
	int (*remount_fs)(struct kernfs_root___66 *, int *, char *);
	int (*show_options)(struct seq_file___63 *, struct kernfs_root___66 *);
	int (*mkdir)(struct kernfs_node___66 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___66 *);
	int (*rename)(struct kernfs_node___66 *, struct kernfs_node___66 *, const char *);
	int (*show_path)(struct seq_file___63 *, struct kernfs_node___66 *, struct kernfs_root___66 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___66 {
	struct kernfs_node___66 *kn;
	struct file___69 *file;
	struct seq_file___63 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___68 *vm_ops;
};

struct cgroup_namespace___54 {
	refcount_t count;
	struct ns_common ns;
	struct user_namespace___56 *user_ns;
	struct ucounts___56 *ucounts;
	struct css_set___54 *root_cset;
};

struct ucounts___56 {
	struct hlist_node node;
	struct user_namespace___56 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___54;

struct bpf_map_ops___54 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___54 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___54 *, struct file___69 *);
	void (*map_free)(struct bpf_map___54 *);
	int (*map_get_next_key)(struct bpf_map___54 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___54 *);
	void * (*map_lookup_elem)(struct bpf_map___54 *, void *);
	int (*map_update_elem)(struct bpf_map___54 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___54 *, void *);
	int (*map_push_elem)(struct bpf_map___54 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___54 *, void *);
	int (*map_peek_elem)(struct bpf_map___54 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___54 *, struct file___69 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___54 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___54 *, void *, struct seq_file___63 *);
	int (*map_check_btf)(const struct bpf_map___54 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___54 {
	const struct bpf_map_ops___54 *ops;
	struct bpf_map___54 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___65 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___54;

typedef void (*kthread_work_func_t___54)(struct kthread_work___54 *);

struct kthread_worker___54;

struct kthread_work___54 {
	struct list_head node;
	kthread_work_func_t___54 func;
	struct kthread_worker___54 *worker;
	int canceling;
};

struct kthread_worker___54 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___69 *task;
	struct kthread_work___54 *current_work;
};

struct kthread_delayed_work___54 {
	struct kthread_work___54 work;
	struct timer_list timer;
};

struct psi_group___54 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___54 *poll_kworker;
	struct kthread_delayed_work___54 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___54;

struct cgroup_rstat_cpu___54;

struct cgroup___54 {
	struct cgroup_subsys_state___54 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___66 *kn;
	struct cgroup_file___54 procs_file;
	struct cgroup_file___54 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___54 *subsys[13];
	struct cgroup_root___54 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___54 *dom_cgrp;
	struct cgroup_rstat_cpu___54 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf bpf;
	atomic_t congestion_count;
	struct cgroup___54 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___54 psi;
	int ancestor_ids[0];
};

struct cftype___54;

struct cgroup_subsys___54 {
	struct cgroup_subsys_state___54 * (*css_alloc)(struct cgroup_subsys_state___54 *);
	int (*css_online)(struct cgroup_subsys_state___54 *);
	void (*css_offline)(struct cgroup_subsys_state___54 *);
	void (*css_released)(struct cgroup_subsys_state___54 *);
	void (*css_free)(struct cgroup_subsys_state___54 *);
	void (*css_reset)(struct cgroup_subsys_state___54 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___54 *, int);
	int (*css_extra_stat_show)(struct seq_file___63 *, struct cgroup_subsys_state___54 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___69 *);
	void (*cancel_fork)(struct task_struct___69 *);
	void (*fork)(struct task_struct___69 *);
	void (*exit)(struct task_struct___69 *);
	void (*free)(struct task_struct___69 *);
	void (*bind)(struct cgroup_subsys_state___54 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___54 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___54 *dfl_cftypes;
	struct cftype___54 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___54 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___54 *updated_children;
	struct cgroup___54 *updated_next;
};

struct cgroup_root___54 {
	struct kernfs_root___66 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___54 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___54 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___54 *ss;
	struct list_head node;
	struct kernfs_ops___66 *kf_ops;
	int (*open)(struct kernfs_open_file___66 *);
	void (*release)(struct kernfs_open_file___66 *);
	u64 (*read_u64)(struct cgroup_subsys_state___54 *, struct cftype___54 *);
	s64 (*read_s64)(struct cgroup_subsys_state___54 *, struct cftype___54 *);
	int (*seq_show)(struct seq_file___63 *, void *);
	void * (*seq_start)(struct seq_file___63 *, loff_t *);
	void * (*seq_next)(struct seq_file___63 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___63 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___54 *, struct cftype___54 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___54 *, struct cftype___54 *, s64);
	ssize_t (*write)(struct kernfs_open_file___66 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___66 *, struct poll_table_struct___44 *);
};

struct bdi_writeback_congested___30 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___30 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___30 {
	struct bio___30 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___30 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___30 bip_inline_vecs[0];
};

struct bio_set___30 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___30 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___29 {
	struct mem_cgroup___29 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___29 {
	struct lruvec___68 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___29 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___29 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct bin_attribute___63;

struct attribute_group___63 {
	const char *name;
	umode_t (*is_visible)(struct kobject___66 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___66 *, struct bin_attribute___63 *, int);
	struct attribute **attrs;
	struct bin_attribute___63 **bin_attrs;
};

struct bin_attribute___63 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___69 *, struct kobject___66 *, struct bin_attribute___63 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___69 *, struct kobject___66 *, struct bin_attribute___63 *, char *, loff_t, size_t);
	int (*mmap)(struct file___69 *, struct kobject___66 *, struct bin_attribute___63 *, struct vm_area_struct___69 *);
};

struct sysfs_ops___65 {
	ssize_t (*show)(struct kobject___66 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___66 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___65;

struct kset___65 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___66 kobj;
	const struct kset_uevent_ops___65 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___65 {
	void (*release)(struct kobject___66 *);
	const struct sysfs_ops___65 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___66 *);
	const void * (*namespace)(struct kobject___66 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___65 {
	int (* const filter)(struct kset___65 *, struct kobject___66 *);
	const char * (* const name)(struct kset___65 *, struct kobject___66 *);
	int (* const uevent)(struct kset___65 *, struct kobject___66 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___63 {
	int (*prepare)(struct device___63 *);
	void (*complete)(struct device___63 *);
	int (*suspend)(struct device___63 *);
	int (*resume)(struct device___63 *);
	int (*freeze)(struct device___63 *);
	int (*thaw)(struct device___63 *);
	int (*poweroff)(struct device___63 *);
	int (*restore)(struct device___63 *);
	int (*suspend_late)(struct device___63 *);
	int (*resume_early)(struct device___63 *);
	int (*freeze_late)(struct device___63 *);
	int (*thaw_early)(struct device___63 *);
	int (*poweroff_late)(struct device___63 *);
	int (*restore_early)(struct device___63 *);
	int (*suspend_noirq)(struct device___63 *);
	int (*resume_noirq)(struct device___63 *);
	int (*freeze_noirq)(struct device___63 *);
	int (*thaw_noirq)(struct device___63 *);
	int (*poweroff_noirq)(struct device___63 *);
	int (*restore_noirq)(struct device___63 *);
	int (*runtime_suspend)(struct device___63 *);
	int (*runtime_resume)(struct device___63 *);
	int (*runtime_idle)(struct device___63 *);
};

struct dev_pm_domain___63 {
	struct dev_pm_ops___63 ops;
	void (*detach)(struct device___63 *, bool);
	int (*activate)(struct device___63 *);
	void (*sync)(struct device___63 *);
	void (*dismiss)(struct device___63 *);
};

struct bus_type___63 {
	const char *name;
	const char *dev_name;
	struct device___63 *dev_root;
	const struct attribute_group___63 **bus_groups;
	const struct attribute_group___63 **dev_groups;
	const struct attribute_group___63 **drv_groups;
	int (*match)(struct device___63 *, struct device_driver___63 *);
	int (*uevent)(struct device___63 *, struct kobj_uevent_env *);
	int (*probe)(struct device___63 *);
	int (*remove)(struct device___63 *);
	void (*shutdown)(struct device___63 *);
	int (*online)(struct device___63 *);
	int (*offline)(struct device___63 *);
	int (*suspend)(struct device___63 *, pm_message_t);
	int (*resume)(struct device___63 *);
	int (*num_vf)(struct device___63 *);
	int (*dma_configure)(struct device___63 *);
	const struct dev_pm_ops___63 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___63 {
	const char *name;
	struct bus_type___63 *bus;
	struct module___61 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___63 *);
	int (*remove)(struct device___63 *);
	void (*shutdown)(struct device___63 *);
	int (*suspend)(struct device___63 *, pm_message_t);
	int (*resume)(struct device___63 *);
	const struct attribute_group___63 **groups;
	const struct dev_pm_ops___63 *pm;
	void (*coredump)(struct device___63 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___63 {
	const char *name;
	const struct attribute_group___63 **groups;
	int (*uevent)(struct device___63 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___63 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___63 *);
	const struct dev_pm_ops___63 *pm;
};

struct class___63 {
	const char *name;
	struct module___61 *owner;
	const struct attribute_group___63 **class_groups;
	const struct attribute_group___63 **dev_groups;
	struct kobject___66 *dev_kobj;
	int (*dev_uevent)(struct device___63 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___63 *, umode_t *);
	void (*class_release)(struct class___63 *);
	void (*dev_release)(struct device___63 *);
	int (*shutdown_pre)(struct device___63 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___63 *);
	const struct dev_pm_ops___63 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct fwnode_operations___48;

struct fwnode_handle___48 {
	struct fwnode_handle___48 *secondary;
	const struct fwnode_operations___48 *ops;
};

struct property___21;

struct device_node___22 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___48 fwnode;
	struct property___21 *properties;
	struct property___21 *deadprops;
	struct device_node___22 *parent;
	struct device_node___22 *child;
	struct device_node___22 *sibling;
	struct kobject___66 kobj;
	long unsigned int _flags;
	void *data;
};

struct node___56 {
	struct device___63 dev;
};

struct kernel_param_ops___58 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___58 *);
	int (*get)(char *, const struct kernel_param___58 *);
	void (*free)(void *);
};

struct kparam_array___58;

struct kernel_param___58 {
	const char *name;
	struct module___61 *mod;
	const struct kernel_param_ops___58 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___58 *arr;
	};
};

struct kparam_array___58 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___58 *ops;
	void *elem;
};

struct module_attribute___58 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___58 *, struct module_kobject___58 *, char *);
	ssize_t (*store)(struct module_attribute___58 *, struct module_kobject___58 *, const char *, size_t);
	void (*setup)(struct module___61 *, const char *);
	int (*test)(struct module___61 *);
	void (*free)(struct module___61 *);
};

struct trace_event_class___38;

struct trace_event_call___38 {
	struct list_head list;
	struct trace_event_class___38 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array *prog_array;
	int (*perf_perm)(struct trace_event_call___38 *, struct perf_event___43 *);
};

struct perf_cpu_context___43;

struct pmu___43 {
	struct list_head entry;
	struct module___61 *module;
	struct device___63 *dev;
	const struct attribute_group___63 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___43 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___43 *);
	void (*pmu_disable)(struct pmu___43 *);
	int (*event_init)(struct perf_event___43 *);
	void (*event_mapped)(struct perf_event___43 *, struct mm_struct___68 *);
	void (*event_unmapped)(struct perf_event___43 *, struct mm_struct___68 *);
	int (*add)(struct perf_event___43 *, int);
	void (*del)(struct perf_event___43 *, int);
	void (*start)(struct perf_event___43 *, int);
	void (*stop)(struct perf_event___43 *, int);
	void (*read)(struct perf_event___43 *);
	void (*start_txn)(struct pmu___43 *, unsigned int);
	int (*commit_txn)(struct pmu___43 *);
	void (*cancel_txn)(struct pmu___43 *);
	int (*event_idx)(struct perf_event___43 *);
	void (*sched_task)(struct perf_event_context___43 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___43 *);
	int (*filter_match)(struct perf_event___43 *);
	int (*check_period)(struct perf_event___43 *, u64);
};

struct perf_cpu_context___43 {
	struct perf_event_context___43 ctx;
	struct perf_event_context___43 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___43 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___43 {
	struct cgroup_subsys_state___54 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___38 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___38 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___38 *);
	struct list_head * (*get_fields)(struct trace_event_call___38 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___38 *);
};

struct trace_event_file___14;

struct trace_event_buffer___14 {
	struct ring_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___14 *trace_file;
	void *entry;
	long unsigned int flags;
	int pc;
};

struct trace_event_file___14 {
	struct list_head list;
	struct trace_event_call___38 *event_call;
	struct event_filter *filter;
	struct dentry___69 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct fwnode_reference_args___48;

struct fwnode_endpoint___48;

struct fwnode_operations___48 {
	struct fwnode_handle___48 * (*get)(struct fwnode_handle___48 *);
	void (*put)(struct fwnode_handle___48 *);
	bool (*device_is_available)(const struct fwnode_handle___48 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___48 *, const struct device___63 *);
	bool (*property_present)(const struct fwnode_handle___48 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___48 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___48 *, const char *, const char **, size_t);
	struct fwnode_handle___48 * (*get_parent)(const struct fwnode_handle___48 *);
	struct fwnode_handle___48 * (*get_next_child_node)(const struct fwnode_handle___48 *, struct fwnode_handle___48 *);
	struct fwnode_handle___48 * (*get_named_child_node)(const struct fwnode_handle___48 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___48 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___48 *);
	struct fwnode_handle___48 * (*graph_get_next_endpoint)(const struct fwnode_handle___48 *, struct fwnode_handle___48 *);
	struct fwnode_handle___48 * (*graph_get_remote_endpoint)(const struct fwnode_handle___48 *);
	struct fwnode_handle___48 * (*graph_get_port_parent)(struct fwnode_handle___48 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___48 *, struct fwnode_endpoint___48 *);
};

struct fwnode_endpoint___48 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___48 *local_fwnode;
};

struct fwnode_reference_args___48 {
	struct fwnode_handle___48 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct property___21 {
	char *name;
	int length;
	void *value;
	struct property___21 *next;
	long unsigned int _flags;
	struct bin_attribute___63 attr;
};

struct trace_event_raw_timer_class {
	struct trace_entry ent;
	void *timer;
	char __data[0];
};

struct trace_event_raw_timer_start {
	struct trace_entry ent;
	void *timer;
	void *function;
	long unsigned int expires;
	long unsigned int now;
	unsigned int flags;
	char __data[0];
};

struct trace_event_raw_timer_expire_entry {
	struct trace_entry ent;
	void *timer;
	long unsigned int now;
	void *function;
	char __data[0];
};

struct trace_event_raw_hrtimer_init {
	struct trace_entry ent;
	void *hrtimer;
	clockid_t clockid;
	enum hrtimer_mode mode;
	char __data[0];
};

struct trace_event_raw_hrtimer_start {
	struct trace_entry ent;
	void *hrtimer;
	void *function;
	s64 expires;
	s64 softexpires;
	enum hrtimer_mode mode;
	char __data[0];
};

struct trace_event_raw_hrtimer_expire_entry {
	struct trace_entry ent;
	void *hrtimer;
	s64 now;
	void *function;
	char __data[0];
};

struct trace_event_raw_hrtimer_class {
	struct trace_entry ent;
	void *hrtimer;
	char __data[0];
};

struct trace_event_raw_itimer_state {
	struct trace_entry ent;
	int which;
	long long unsigned int expires;
	long int value_sec;
	long int value_usec;
	long int interval_sec;
	long int interval_usec;
	char __data[0];
};

struct trace_event_raw_itimer_expire {
	struct trace_entry ent;
	int which;
	pid_t pid;
	long long unsigned int now;
	char __data[0];
};

struct trace_event_raw_tick_stop {
	struct trace_entry ent;
	int success;
	int dependency;
	char __data[0];
};

struct trace_event_data_offsets_timer_class {};

struct trace_event_data_offsets_timer_start {};

struct trace_event_data_offsets_timer_expire_entry {};

struct trace_event_data_offsets_hrtimer_init {};

struct trace_event_data_offsets_hrtimer_start {};

struct trace_event_data_offsets_hrtimer_expire_entry {};

struct trace_event_data_offsets_hrtimer_class {};

struct trace_event_data_offsets_itimer_state {};

struct trace_event_data_offsets_itimer_expire {};

struct trace_event_data_offsets_tick_stop {};

struct timer_base {
	raw_spinlock_t lock;
	struct timer_list *running_timer;
	long unsigned int clk;
	long unsigned int next_expiry;
	unsigned int cpu;
	bool is_idle;
	bool must_forward_clk;
	long unsigned int pending_map[8];
	struct hlist_head vectors[512];
	long: 64;
	long: 64;
	long: 64;
};

struct process_timer {
	struct timer_list timer;
	struct task_struct___69 *task;
};

struct clock_event_device___13;

struct arch_timer_erratum_workaround___13 {
	enum arch_timer_erratum_match_type match_type;
	const void *id;
	const char *desc;
	u32 (*read_cntp_tval_el0)();
	u32 (*read_cntv_tval_el0)();
	u64 (*read_cntpct_el0)();
	u64 (*read_cntvct_el0)();
	int (*set_next_event_phys)(long unsigned int, struct clock_event_device___13 *);
	int (*set_next_event_virt)(long unsigned int, struct clock_event_device___13 *);
};

struct clock_event_device___13 {
	void (*event_handler)(struct clock_event_device___13 *);
	int (*set_next_event)(long unsigned int, struct clock_event_device___13 *);
	int (*set_next_ktime)(ktime_t, struct clock_event_device___13 *);
	ktime_t next_event;
	u64 max_delta_ns;
	u64 min_delta_ns;
	u32 mult;
	u32 shift;
	enum clock_event_state state_use_accessors;
	unsigned int features;
	long unsigned int retries;
	int (*set_state_periodic)(struct clock_event_device___13 *);
	int (*set_state_oneshot)(struct clock_event_device___13 *);
	int (*set_state_oneshot_stopped)(struct clock_event_device___13 *);
	int (*set_state_shutdown)(struct clock_event_device___13 *);
	int (*tick_resume)(struct clock_event_device___13 *);
	void (*broadcast)(const struct cpumask *);
	void (*suspend)(struct clock_event_device___13 *);
	void (*resume)(struct clock_event_device___13 *);
	long unsigned int min_delta_ticks;
	long unsigned int max_delta_ticks;
	const char *name;
	int rating;
	int irq;
	int bound_on;
	const struct cpumask *cpumask;
	struct list_head list;
	struct module___60 *owner;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hrtimer_sleeper___2 {
	struct hrtimer timer;
	struct task_struct___68 *task;
};

struct tick_device___4 {
	struct clock_event_device___13 *evtdev;
	enum tick_device_mode mode;
};

struct system_time_snapshot {
	u64 cycles;
	ktime_t real;
	ktime_t raw;
	unsigned int clock_was_set_seq;
	u8 cs_was_changed_seq;
};

struct system_device_crosststamp {
	ktime_t device;
	ktime_t sys_realtime;
	ktime_t sys_monoraw;
};

struct clocksource___2;

struct system_counterval_t {
	u64 cycles;
	struct clocksource___2 *cs;
};

struct clocksource___2 {
	u64 (*read)(struct clocksource___2 *);
	u64 mask;
	u32 mult;
	u32 shift;
	u64 max_idle_ns;
	u32 maxadj;
	struct arch_clocksource_data archdata;
	u64 max_cycles;
	const char *name;
	struct list_head list;
	int rating;
	int (*enable)(struct clocksource___2 *);
	void (*disable)(struct clocksource___2 *);
	long unsigned int flags;
	void (*suspend)(struct clocksource___2 *);
	void (*resume)(struct clocksource___2 *);
	void (*mark_unstable)(struct clocksource___2 *);
	void (*tick_stable)(struct clocksource___2 *);
	struct module___16 *owner;
};

struct tick_device___5 {
	struct clock_event_device___4 *evtdev;
	enum tick_device_mode mode;
};

struct tk_read_base___2 {
	struct clocksource___2 *clock;
	u64 mask;
	u64 cycle_last;
	u32 mult;
	u32 shift;
	u64 xtime_nsec;
	ktime_t base;
	u64 base_real;
};

struct timekeeper___2 {
	struct tk_read_base___2 tkr_mono;
	struct tk_read_base___2 tkr_raw;
	u64 xtime_sec;
	long unsigned int ktime_sec;
	struct timespec64 wall_to_monotonic;
	ktime_t offs_real;
	ktime_t offs_boot;
	ktime_t offs_tai;
	s32 tai_offset;
	unsigned int clock_was_set_seq;
	u8 cs_was_changed_seq;
	ktime_t next_leap_ktime;
	u64 raw_sec;
	u64 cycle_interval;
	u64 xtime_interval;
	s64 xtime_remainder;
	u64 raw_interval;
	u64 ntp_tick;
	s64 ntp_error;
	u32 ntp_error_shift;
	u32 ntp_err_mult;
	u32 skip_second_overflow;
};

struct audit_ntp_val {
	long long int oldval;
	long long int newval;
};

struct audit_ntp_data {
	struct audit_ntp_val vals[6];
};

enum timekeeping_adv_mode {
	TK_ADV_TICK = 0,
	TK_ADV_FREQ = 1,
};

struct tk_fast {
	seqcount_t seq;
	struct tk_read_base___2 base[2];
};

struct module___62;

struct file___70;

struct kiocb___70;

struct poll_table_struct___45;

struct vm_area_struct___70;

struct inode___71;

struct file_lock___70;

struct page___70;

struct seq_file___64;

struct file_operations___70 {
	struct module___62 *owner;
	loff_t (*llseek)(struct file___70 *, loff_t, int);
	ssize_t (*read)(struct file___70 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___70 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___70 *, struct iov_iter___29 *);
	ssize_t (*write_iter)(struct kiocb___70 *, struct iov_iter___29 *);
	int (*iopoll)(struct kiocb___70 *, bool);
	int (*iterate)(struct file___70 *, struct dir_context *);
	int (*iterate_shared)(struct file___70 *, struct dir_context *);
	__poll_t (*poll)(struct file___70 *, struct poll_table_struct___45 *);
	long int (*unlocked_ioctl)(struct file___70 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___70 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___70 *, struct vm_area_struct___70 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___71 *, struct file___70 *);
	int (*flush)(struct file___70 *, fl_owner_t);
	int (*release)(struct inode___71 *, struct file___70 *);
	int (*fsync)(struct file___70 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___70 *, int);
	int (*lock)(struct file___70 *, int, struct file_lock___70 *);
	ssize_t (*sendpage)(struct file___70 *, struct page___70 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___70 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___70 *, int, struct file_lock___70 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___70 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___70 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___70 *, long int, struct file_lock___70 **, void **);
	long int (*fallocate)(struct file___70 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___64 *, struct file___70 *);
	ssize_t (*copy_file_range)(struct file___70 *, loff_t, struct file___70 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___70 *, loff_t, struct file___70 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___70 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___69 {
	u64 seqnum;
	struct vm_area_struct___70 *vmas[4];
};

struct page_frag___69 {
	struct page___70 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___69;

struct pid___58;

struct cred___66;

struct nsproxy___65;

struct signal_struct___60;

struct vm_struct___52;

struct task_struct___70 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___70 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___69 *mm;
	struct mm_struct___69 *active_mm;
	struct vmacache___69 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___70 *real_parent;
	struct task_struct___70 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___70 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___58 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___58 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___58 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___66 *ptracer_cred;
	const struct cred___66 *real_cred;
	const struct cred___66 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___65 *nsproxy;
	struct signal_struct___60 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___70 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___13 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___69 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___70 *oom_reaper_list;
	struct vm_struct___52 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___43 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct secondary_data___70 {
	void *stack;
	struct task_struct___70 *task;
	long int status;
};

typedef struct page___70 *pgtable_t___69;

struct address_space___69;

struct dev_pagemap___69;

struct page___70 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___69 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___70 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___69 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___69 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___69 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___69;

struct lruvec___69 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___69 *pgdat;
};

struct zone___69 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___69 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___69 {
	struct zone___69 *zone;
	int zone_idx;
};

struct zonelist___69 {
	struct zoneref___69 _zonerefs[25];
};

struct pglist_data___69 {
	struct zone___69 node_zones[3];
	struct zonelist___69 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___70 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___70 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___69 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___70 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___70 *owner;
};

struct blocking_notifier_head___69 {
	struct rw_semaphore___70 rwsem;
	struct notifier_block *head;
};

struct kernfs_root___67;

struct kernfs_elem_dir___67 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___67 *root;
};

struct kernfs_node___67;

struct kernfs_syscall_ops___67;

struct kernfs_root___67 {
	struct kernfs_node___67 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___67 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___67 {
	struct kernfs_node___67 *target_kn;
};

struct kernfs_ops___67;

struct kernfs_elem_attr___67 {
	const struct kernfs_ops___67 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___67 *notify_next;
};

struct kernfs_node___67 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___67 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___67 dir;
		struct kernfs_elem_symlink___67 symlink;
		struct kernfs_elem_attr___67 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___67;

struct kernfs_ops___67 {
	int (*open)(struct kernfs_open_file___67 *);
	void (*release)(struct kernfs_open_file___67 *);
	int (*seq_show)(struct seq_file___64 *, void *);
	void * (*seq_start)(struct seq_file___64 *, loff_t *);
	void * (*seq_next)(struct seq_file___64 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___64 *, void *);
	ssize_t (*read)(struct kernfs_open_file___67 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___67 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___67 *, struct vm_area_struct___70 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___67 *, struct poll_table_struct___45 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___67 {
	int (*remount_fs)(struct kernfs_root___67 *, int *, char *);
	int (*show_options)(struct seq_file___64 *, struct kernfs_root___67 *);
	int (*mkdir)(struct kernfs_node___67 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___67 *);
	int (*rename)(struct kernfs_node___67 *, struct kernfs_node___67 *, const char *);
	int (*show_path)(struct seq_file___64 *, struct kernfs_node___67 *, struct kernfs_root___67 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___61;

struct seq_file___64 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___61 *op;
	int poll_event;
	const struct file___70 *file;
	void *private;
};

struct vm_operations_struct___69;

struct kernfs_open_file___67 {
	struct kernfs_node___67 *kn;
	struct file___70 *file;
	struct seq_file___64 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___69 *vm_ops;
};

struct dentry___70;

struct path___69 {
	struct vfsmount *mnt;
	struct dentry___70 *dentry;
};

struct fown_struct___58 {
	rwlock_t lock;
	struct pid___58 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___70 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___69 f_path;
	struct inode___71 *f_inode;
	const struct file_operations___70 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___58 f_owner;
	const struct cred___66 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___69 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___69;

struct vm_operations_struct___69 {
	void (*open)(struct vm_area_struct___70 *);
	void (*close)(struct vm_area_struct___70 *);
	int (*split)(struct vm_area_struct___70 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___70 *);
	vm_fault_t (*fault)(struct vm_fault___69 *);
	vm_fault_t (*huge_fault)(struct vm_fault___69 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___69 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___70 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___69 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___69 *);
	int (*access)(struct vm_area_struct___70 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___70 *);
	int (*set_policy)(struct vm_area_struct___70 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___70 *, long unsigned int);
	struct page___70 * (*find_special_page)(struct vm_area_struct___70 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___44)(struct file___70 *, wait_queue_head_t *, struct poll_table_struct___45 *);

struct poll_table_struct___45 {
	poll_queue_proc___44 _qproc;
	__poll_t _key;
};

struct vm_area_struct___70 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___70 *vm_next;
	struct vm_area_struct___70 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___69 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___69 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___70 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___67;

struct bin_attribute___64;

struct attribute_group___64 {
	const char *name;
	umode_t (*is_visible)(struct kobject___67 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___67 *, struct bin_attribute___64 *, int);
	struct attribute **attrs;
	struct bin_attribute___64 **bin_attrs;
};

struct kset___66;

struct kobj_type___66;

struct kobject___67 {
	const char *name;
	struct list_head entry;
	struct kobject___67 *parent;
	struct kset___66 *kset;
	struct kobj_type___66 *ktype;
	struct kernfs_node___67 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___64 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___70 *, struct kobject___67 *, struct bin_attribute___64 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___70 *, struct kobject___67 *, struct bin_attribute___64 *, char *, loff_t, size_t);
	int (*mmap)(struct file___70 *, struct kobject___67 *, struct bin_attribute___64 *, struct vm_area_struct___70 *);
};

struct sysfs_ops___66 {
	ssize_t (*show)(struct kobject___67 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___67 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___66;

struct kset___66 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___67 kobj;
	const struct kset_uevent_ops___66 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___66 {
	void (*release)(struct kobject___67 *);
	const struct sysfs_ops___66 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___67 *);
	const void * (*namespace)(struct kobject___67 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___66 {
	int (* const filter)(struct kset___66 *, struct kobject___67 *);
	const char * (* const name)(struct kset___66 *, struct kobject___67 *);
	int (* const uevent)(struct kset___66 *, struct kobject___67 *, struct kobj_uevent_env *);
};

struct kobj_attribute___67 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___67 *, struct kobj_attribute___67 *, char *);
	ssize_t (*store)(struct kobject___67 *, struct kobj_attribute___67 *, const char *, size_t);
};

struct fwnode_operations___49;

struct fwnode_handle___49 {
	struct fwnode_handle___49 *secondary;
	const struct fwnode_operations___49 *ops;
};

struct device___64;

struct fwnode_reference_args___49;

struct fwnode_endpoint___49;

struct fwnode_operations___49 {
	struct fwnode_handle___49 * (*get)(struct fwnode_handle___49 *);
	void (*put)(struct fwnode_handle___49 *);
	bool (*device_is_available)(const struct fwnode_handle___49 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___49 *, const struct device___64 *);
	bool (*property_present)(const struct fwnode_handle___49 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___49 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___49 *, const char *, const char **, size_t);
	struct fwnode_handle___49 * (*get_parent)(const struct fwnode_handle___49 *);
	struct fwnode_handle___49 * (*get_next_child_node)(const struct fwnode_handle___49 *, struct fwnode_handle___49 *);
	struct fwnode_handle___49 * (*get_named_child_node)(const struct fwnode_handle___49 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___49 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___49 *);
	struct fwnode_handle___49 * (*graph_get_next_endpoint)(const struct fwnode_handle___49 *, struct fwnode_handle___49 *);
	struct fwnode_handle___49 * (*graph_get_remote_endpoint)(const struct fwnode_handle___49 *);
	struct fwnode_handle___49 * (*graph_get_port_parent)(struct fwnode_handle___49 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___49 *, struct fwnode_endpoint___49 *);
};

struct fwnode_endpoint___49 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___49 *local_fwnode;
};

struct fwnode_reference_args___49 {
	struct fwnode_handle___49 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct dev_pm_info___64 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___64 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___64;

struct bus_type___64;

struct device_driver___64;

struct dev_pm_domain___64;

struct device_node___23;

struct class___64;

struct device___64 {
	struct device___64 *parent;
	struct device_private *p;
	struct kobject___67 kobj;
	const char *init_name;
	const struct device_type___64 *type;
	struct mutex mutex;
	struct bus_type___64 *bus;
	struct device_driver___64 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___64 power;
	struct dev_pm_domain___64 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___23 *of_node;
	struct fwnode_handle___49 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___64 *class;
	const struct attribute_group___64 **groups;
	void (*release)(struct device___64 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct property___22 {
	char *name;
	int length;
	void *value;
	struct property___22 *next;
	long unsigned int _flags;
	struct bin_attribute___64 attr;
};

struct device_node___23 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___49 fwnode;
	struct property___22 *properties;
	struct property___22 *deadprops;
	struct device_node___23 *parent;
	struct device_node___23 *child;
	struct device_node___23 *sibling;
	struct kobject___67 kobj;
	long unsigned int _flags;
	void *data;
};

struct core_state___69;

struct mm_struct___69 {
	struct {
		struct vm_area_struct___70 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___70 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___70 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___69 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___70 *owner;
		struct user_namespace___3 *user_ns;
		struct file___70 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___69 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___69;

struct address_space___69 {
	struct inode___71 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___70 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___69 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___69)(struct vm_area_struct___70 *, long unsigned int, const struct page___70 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___69)(struct page___70 *, void *);

struct dev_pagemap___69 {
	dev_page_fault_t___69 page_fault;
	dev_page_free_t___69 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___64 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___69 {
	struct task_struct___70 *task;
	struct core_thread___69 *next;
};

struct core_state___69 {
	atomic_t nr_threads;
	struct core_thread___69 dumper;
	struct completion startup;
};

struct vm_fault___69 {
	struct vm_area_struct___70 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___70 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___70 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___69 prealloc_pte;
};

struct pid_namespace___58;

struct upid___58 {
	int nr;
	struct pid_namespace___58 *ns;
};

struct pid_namespace___58 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___70 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___58 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___70 *proc_self;
	struct dentry___70 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___3 *user_ns;
	struct ucounts___2 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common ns;
};

struct pid___58 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___58 numbers[1];
};

struct key___67;

struct user_struct___66 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___67 *uid_keyring;
	struct key___67 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___66 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___67 *session_keyring;
	struct key___67 *process_keyring;
	struct key___67 *thread_keyring;
	struct key___67 *request_key_auth;
	void *security;
	struct user_struct___66 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct nsproxy___65 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___58 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct signal_struct___60 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___70 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___70 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___58 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___58 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___69 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___58 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_struct___52 {
	struct vm_struct___52 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___70 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___60 {
	struct task_struct___70 task;
	long unsigned int stack[8192];
};

struct module_kobject___59 {
	struct kobject___67 kobj;
	struct module___62 *mod;
	struct kobject___67 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___59 {
	struct module___62 *mod;
	struct latch_tree_node node;
};

struct module_layout___59 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___59 mtn;
};

struct module_attribute___59;

struct kernel_param___59;

struct module___62 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___59 mkobj;
	struct module_attribute___59 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___67 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___59 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___59 core_layout;
	struct module_layout___59 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___69;

struct super_block___70;

struct dentry___70 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___70 *d_parent;
	struct qstr d_name;
	struct inode___71 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___69 *d_op;
	struct super_block___70 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___69;

struct block_device___70;

struct cdev___17;

struct inode___71 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___69 *i_op;
	struct super_block___70 *i_sb;
	struct address_space___69 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___70 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___70 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___69 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___70 *i_bdev;
		struct cdev___17 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___69 {
	int (*d_revalidate)(struct dentry___70 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___70 *, unsigned int);
	int (*d_hash)(const struct dentry___70 *, struct qstr *);
	int (*d_compare)(const struct dentry___70 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___70 *);
	int (*d_init)(struct dentry___70 *);
	void (*d_release)(struct dentry___70 *);
	void (*d_prune)(struct dentry___70 *);
	void (*d_iput)(struct dentry___70 *, struct inode___71 *);
	char * (*d_dname)(struct dentry___70 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___69 *);
	int (*d_manage)(const struct path___69 *, bool);
	struct dentry___70 * (*d_real)(struct dentry___70 *, const struct inode___71 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___69;

struct mem_dqinfo___69 {
	struct quota_format_type___69 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___69;

struct quota_info___69 {
	unsigned int flags;
	struct rw_semaphore___70 dqio_sem;
	struct inode___71 *files[3];
	struct mem_dqinfo___69 info[3];
	const struct quota_format_ops___69 *ops[3];
};

struct rcuwait___69 {
	struct task_struct___70 *task;
};

struct percpu_rw_semaphore___69 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___70 rw_sem;
	struct rcuwait___69 writer;
	int readers_block;
};

struct sb_writers___69 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___69 rw_sem[3];
};

struct file_system_type___69;

struct super_operations___69;

struct dquot_operations___69;

struct quotactl_ops___69;

struct super_block___70 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___69 *s_type;
	const struct super_operations___69 *s_op;
	const struct dquot_operations___69 *dq_op;
	const struct quotactl_ops___69 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___70 *s_root;
	struct rw_semaphore___70 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___70 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___69 s_dquot;
	struct sb_writers___69 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___69 *s_d_op;
	int cleancache_poolid;
	struct shrinker___29 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___70 {
	struct file___70 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___70 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___70 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___70 *ia_file;
};

struct dquot___69 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___70 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___69 {
	int qf_fmt_id;
	const struct quota_format_ops___69 *qf_ops;
	struct module___62 *qf_owner;
	struct quota_format_type___69 *qf_next;
};

struct quota_format_ops___69 {
	int (*check_quota_file)(struct super_block___70 *, int);
	int (*read_file_info)(struct super_block___70 *, int);
	int (*write_file_info)(struct super_block___70 *, int);
	int (*free_file_info)(struct super_block___70 *, int);
	int (*read_dqblk)(struct dquot___69 *);
	int (*commit_dqblk)(struct dquot___69 *);
	int (*release_dqblk)(struct dquot___69 *);
	int (*get_next_id)(struct super_block___70 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___69 {
	int (*write_dquot)(struct dquot___69 *);
	struct dquot___69 * (*alloc_dquot)(struct super_block___70 *, int);
	void (*destroy_dquot)(struct dquot___69 *);
	int (*acquire_dquot)(struct dquot___69 *);
	int (*release_dquot)(struct dquot___69 *);
	int (*mark_dirty)(struct dquot___69 *);
	int (*write_info)(struct super_block___70 *, int);
	qsize_t * (*get_reserved_space)(struct inode___71 *);
	int (*get_projid)(struct inode___71 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___71 *, qsize_t *);
	int (*get_next_id)(struct super_block___70 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___69 {
	int (*quota_on)(struct super_block___70 *, int, int, const struct path___69 *);
	int (*quota_off)(struct super_block___70 *, int);
	int (*quota_enable)(struct super_block___70 *, unsigned int);
	int (*quota_disable)(struct super_block___70 *, unsigned int);
	int (*quota_sync)(struct super_block___70 *, int);
	int (*set_info)(struct super_block___70 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___70 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___70 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___70 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___70 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___70 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___69 {
	int (*writepage)(struct page___70 *, struct writeback_control___3 *);
	int (*readpage)(struct file___70 *, struct page___70 *);
	int (*writepages)(struct address_space___69 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___70 *);
	int (*readpages)(struct file___70 *, struct address_space___69 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___70 *, struct address_space___69 *, loff_t, unsigned int, unsigned int, struct page___70 **, void **);
	int (*write_end)(struct file___70 *, struct address_space___69 *, loff_t, unsigned int, unsigned int, struct page___70 *, void *);
	sector_t (*bmap)(struct address_space___69 *, sector_t);
	void (*invalidatepage)(struct page___70 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___70 *, gfp_t);
	void (*freepage)(struct page___70 *);
	ssize_t (*direct_IO)(struct kiocb___70 *, struct iov_iter___29 *);
	int (*migratepage)(struct address_space___69 *, struct page___70 *, struct page___70 *, enum migrate_mode);
	bool (*isolate_page)(struct page___70 *, isolate_mode_t);
	void (*putback_page)(struct page___70 *);
	int (*launder_page)(struct page___70 *);
	int (*is_partially_uptodate)(struct page___70 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___70 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___69 *, struct page___70 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___70 *, sector_t *);
	void (*swap_deactivate)(struct file___70 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___70 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___71 *bd_inode;
	struct super_block___70 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___70 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___17 {
	struct kobject___67 kobj;
	struct module___62 *owner;
	const struct file_operations___70 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___69 {
	struct dentry___70 * (*lookup)(struct inode___71 *, struct dentry___70 *, unsigned int);
	const char * (*get_link)(struct dentry___70 *, struct inode___71 *, struct delayed_call *);
	int (*permission)(struct inode___71 *, int);
	struct posix_acl * (*get_acl)(struct inode___71 *, int);
	int (*readlink)(struct dentry___70 *, char *, int);
	int (*create)(struct inode___71 *, struct dentry___70 *, umode_t, bool);
	int (*link)(struct dentry___70 *, struct inode___71 *, struct dentry___70 *);
	int (*unlink)(struct inode___71 *, struct dentry___70 *);
	int (*symlink)(struct inode___71 *, struct dentry___70 *, const char *);
	int (*mkdir)(struct inode___71 *, struct dentry___70 *, umode_t);
	int (*rmdir)(struct inode___71 *, struct dentry___70 *);
	int (*mknod)(struct inode___71 *, struct dentry___70 *, umode_t, dev_t);
	int (*rename)(struct inode___71 *, struct dentry___70 *, struct inode___71 *, struct dentry___70 *, unsigned int);
	int (*setattr)(struct dentry___70 *, struct iattr___70 *);
	int (*getattr)(const struct path___69 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___70 *, char *, size_t);
	int (*fiemap)(struct inode___71 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___71 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___71 *, struct dentry___70 *, struct file___70 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___71 *, struct dentry___70 *, umode_t);
	int (*set_acl)(struct inode___71 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___69 {
	void (*fl_copy_lock)(struct file_lock___70 *, struct file_lock___70 *);
	void (*fl_release_private)(struct file_lock___70 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___69;

struct lock_manager_operations___69;

struct file_lock___70 {
	struct file_lock___70 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___70 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___69 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___69 *fl_ops;
	const struct lock_manager_operations___69 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___69 {
	int (*lm_compare_owner)(struct file_lock___70 *, struct file_lock___70 *);
	long unsigned int (*lm_owner_key)(struct file_lock___70 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___70 *);
	int (*lm_grant)(struct file_lock___70 *, int);
	bool (*lm_break)(struct file_lock___70 *);
	int (*lm_change)(struct file_lock___70 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___70 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___69 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___69 *fa_next;
	struct file___70 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___69 {
	const char *name;
	int fs_flags;
	struct dentry___70 * (*mount)(struct file_system_type___69 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___70 *);
	struct module___62 *owner;
	struct file_system_type___69 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___69 {
	struct inode___71 * (*alloc_inode)(struct super_block___70 *);
	void (*destroy_inode)(struct inode___71 *);
	void (*dirty_inode)(struct inode___71 *, int);
	int (*write_inode)(struct inode___71 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___71 *);
	void (*evict_inode)(struct inode___71 *);
	void (*put_super)(struct super_block___70 *);
	int (*sync_fs)(struct super_block___70 *, int);
	int (*freeze_super)(struct super_block___70 *);
	int (*freeze_fs)(struct super_block___70 *);
	int (*thaw_super)(struct super_block___70 *);
	int (*unfreeze_fs)(struct super_block___70 *);
	int (*statfs)(struct dentry___70 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___70 *, int *, char *);
	void (*umount_begin)(struct super_block___70 *);
	int (*show_options)(struct seq_file___64 *, struct dentry___70 *);
	int (*show_devname)(struct seq_file___64 *, struct dentry___70 *);
	int (*show_path)(struct seq_file___64 *, struct dentry___70 *);
	int (*show_stats)(struct seq_file___64 *, struct dentry___70 *);
	ssize_t (*quota_read)(struct super_block___70 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___70 *, int, const char *, size_t, loff_t);
	struct dquot___69 ** (*get_dquots)(struct inode___71 *);
	int (*bdev_try_to_free_page)(struct super_block___70 *, struct page___70 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___70 *, struct shrink_control___29 *);
	long int (*free_cached_objects)(struct super_block___70 *, struct shrink_control___29 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___69(struct page___70 *);

struct kernel_param_ops___59 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___59 *);
	int (*get)(char *, const struct kernel_param___59 *);
	void (*free)(void *);
};

struct kparam_array___59;

struct kernel_param___59 {
	const char *name;
	struct module___62 *mod;
	const struct kernel_param_ops___59 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___59 *arr;
	};
};

struct kparam_array___59 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___59 *ops;
	void *elem;
};

struct module_attribute___59 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___59 *, struct module_kobject___59 *, char *);
	ssize_t (*store)(struct module_attribute___59 *, struct module_kobject___59 *, const char *, size_t);
	void (*setup)(struct module___62 *, const char *);
	int (*test)(struct module___62 *);
	void (*free)(struct module___62 *);
};

struct dev_pm_ops___64 {
	int (*prepare)(struct device___64 *);
	void (*complete)(struct device___64 *);
	int (*suspend)(struct device___64 *);
	int (*resume)(struct device___64 *);
	int (*freeze)(struct device___64 *);
	int (*thaw)(struct device___64 *);
	int (*poweroff)(struct device___64 *);
	int (*restore)(struct device___64 *);
	int (*suspend_late)(struct device___64 *);
	int (*resume_early)(struct device___64 *);
	int (*freeze_late)(struct device___64 *);
	int (*thaw_early)(struct device___64 *);
	int (*poweroff_late)(struct device___64 *);
	int (*restore_early)(struct device___64 *);
	int (*suspend_noirq)(struct device___64 *);
	int (*resume_noirq)(struct device___64 *);
	int (*freeze_noirq)(struct device___64 *);
	int (*thaw_noirq)(struct device___64 *);
	int (*poweroff_noirq)(struct device___64 *);
	int (*restore_noirq)(struct device___64 *);
	int (*runtime_suspend)(struct device___64 *);
	int (*runtime_resume)(struct device___64 *);
	int (*runtime_idle)(struct device___64 *);
};

struct dev_pm_domain___64 {
	struct dev_pm_ops___64 ops;
	void (*detach)(struct device___64 *, bool);
	int (*activate)(struct device___64 *);
	void (*sync)(struct device___64 *);
	void (*dismiss)(struct device___64 *);
};

struct bus_type___64 {
	const char *name;
	const char *dev_name;
	struct device___64 *dev_root;
	const struct attribute_group___64 **bus_groups;
	const struct attribute_group___64 **dev_groups;
	const struct attribute_group___64 **drv_groups;
	int (*match)(struct device___64 *, struct device_driver___64 *);
	int (*uevent)(struct device___64 *, struct kobj_uevent_env *);
	int (*probe)(struct device___64 *);
	int (*remove)(struct device___64 *);
	void (*shutdown)(struct device___64 *);
	int (*online)(struct device___64 *);
	int (*offline)(struct device___64 *);
	int (*suspend)(struct device___64 *, pm_message_t);
	int (*resume)(struct device___64 *);
	int (*num_vf)(struct device___64 *);
	int (*dma_configure)(struct device___64 *);
	const struct dev_pm_ops___64 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___64 {
	const char *name;
	struct bus_type___64 *bus;
	struct module___62 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___64 *);
	int (*remove)(struct device___64 *);
	void (*shutdown)(struct device___64 *);
	int (*suspend)(struct device___64 *, pm_message_t);
	int (*resume)(struct device___64 *);
	const struct attribute_group___64 **groups;
	const struct dev_pm_ops___64 *pm;
	void (*coredump)(struct device___64 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___64 {
	const char *name;
	const struct attribute_group___64 **groups;
	int (*uevent)(struct device___64 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___64 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___64 *);
	const struct dev_pm_ops___64 *pm;
};

struct class___64 {
	const char *name;
	struct module___62 *owner;
	const struct attribute_group___64 **class_groups;
	const struct attribute_group___64 **dev_groups;
	struct kobject___67 *dev_kobj;
	int (*dev_uevent)(struct device___64 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___64 *, umode_t *);
	void (*class_release)(struct class___64 *);
	void (*dev_release)(struct device___64 *);
	int (*shutdown_pre)(struct device___64 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___64 *);
	const struct dev_pm_ops___64 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

typedef int (*key_restrict_link_func_t___66)(struct key___67 *, const struct key_type *, const union key_payload *, struct key___67 *);

struct key_restriction___67;

struct key___67 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___70 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___67 *restrict_link;
};

struct key_restriction___67 {
	key_restrict_link_func_t___66 check;
	struct key___67 *key;
	struct key_type *keytype;
};

struct seq_operations___61 {
	void * (*start)(struct seq_file___64 *, loff_t *);
	void (*stop)(struct seq_file___64 *, void *);
	void * (*next)(struct seq_file___64 *, void *, loff_t *);
	int (*show)(struct seq_file___64 *, void *);
};

struct tick_device___6 {
	struct clock_event_device___9 *evtdev;
	enum tick_device_mode mode;
};

enum tick_nohz_mode {
	NOHZ_MODE_INACTIVE = 0,
	NOHZ_MODE_LOWRES = 1,
	NOHZ_MODE_HIGHRES = 2,
};

struct tick_sched {
	struct hrtimer sched_timer;
	long unsigned int check_clocks;
	enum tick_nohz_mode nohz_mode;
	unsigned int inidle: 1;
	unsigned int tick_stopped: 1;
	unsigned int idle_active: 1;
	unsigned int do_timer_last: 1;
	unsigned int got_idle_tick: 1;
	ktime_t last_tick;
	ktime_t next_tick;
	long unsigned int idle_jiffies;
	long unsigned int idle_calls;
	long unsigned int idle_sleeps;
	ktime_t idle_entrytime;
	ktime_t idle_waketime;
	ktime_t idle_exittime;
	ktime_t idle_sleeptime;
	ktime_t iowait_sleeptime;
	long unsigned int last_jiffies;
	u64 timer_expires;
	u64 timer_expires_base;
	u64 next_timer;
	ktime_t idle_expires;
	atomic_t tick_dep_mask;
};

struct timer_list_iter {
	int cpu;
	bool second_pass;
	u64 now;
};

struct tm {
	int tm_sec;
	int tm_min;
	int tm_hour;
	int tm_mday;
	int tm_mon;
	long int tm_year;
	int tm_wday;
	int tm_yday;
};

typedef __kernel_timer_t timer_t;

struct module___63;

struct file___71;

struct kiocb___71;

struct poll_table_struct___46;

struct vm_area_struct___71;

struct inode___72;

struct file_lock___71;

struct page___71;

struct seq_file___65;

struct file_operations___71 {
	struct module___63 *owner;
	loff_t (*llseek)(struct file___71 *, loff_t, int);
	ssize_t (*read)(struct file___71 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___71 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___71 *, struct iov_iter___29 *);
	ssize_t (*write_iter)(struct kiocb___71 *, struct iov_iter___29 *);
	int (*iopoll)(struct kiocb___71 *, bool);
	int (*iterate)(struct file___71 *, struct dir_context *);
	int (*iterate_shared)(struct file___71 *, struct dir_context *);
	__poll_t (*poll)(struct file___71 *, struct poll_table_struct___46 *);
	long int (*unlocked_ioctl)(struct file___71 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___71 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___71 *, struct vm_area_struct___71 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___72 *, struct file___71 *);
	int (*flush)(struct file___71 *, fl_owner_t);
	int (*release)(struct inode___72 *, struct file___71 *);
	int (*fsync)(struct file___71 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___71 *, int);
	int (*lock)(struct file___71 *, int, struct file_lock___71 *);
	ssize_t (*sendpage)(struct file___71 *, struct page___71 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___71 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___71 *, int, struct file_lock___71 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___71 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___71 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___71 *, long int, struct file_lock___71 **, void **);
	long int (*fallocate)(struct file___71 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___65 *, struct file___71 *);
	ssize_t (*copy_file_range)(struct file___71 *, loff_t, struct file___71 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___71 *, loff_t, struct file___71 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___71 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___70 {
	u64 seqnum;
	struct vm_area_struct___71 *vmas[4];
};

struct page_frag___70 {
	struct page___71 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___44;

struct debug_info___44 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___44 *hbp_break[16];
	struct perf_event___44 *hbp_watch[16];
};

struct thread_struct___44 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___44 debug;
	long: 64;
};

struct mm_struct___70;

struct pid___59;

struct cred___67;

struct nsproxy___66;

struct signal_struct___61;

struct css_set___55;

struct perf_event_context___44;

struct task_struct___71 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___71 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___70 *mm;
	struct mm_struct___70 *active_mm;
	struct vmacache___70 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___71 *real_parent;
	struct task_struct___71 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___71 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___59 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___59 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___59 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___67 *ptracer_cred;
	const struct cred___67 *real_cred;
	const struct cred___67 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___66 *nsproxy;
	struct signal_struct___61 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___71 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___13 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___55 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___44 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___70 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___71 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___44 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___44 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___71 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___44)(struct perf_event___44 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___44;

struct fasync_struct___70;

struct pid_namespace___59;

struct trace_event_call___39;

struct perf_cgroup___44;

struct perf_event___44 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___44 *group_leader;
	struct pmu___44 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___44 hw;
	struct perf_event_context___44 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___44 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___71 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___70 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___44 *);
	struct callback_head callback_head;
	struct pid_namespace___59 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___44 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___44 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___39 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___44 *cgrp;
	struct list_head sb_list;
};

struct secondary_data___71 {
	void *stack;
	struct task_struct___71 *task;
	long int status;
};

struct kset___67;

struct kobj_type___67;

struct kernfs_node___68;

struct kobject___68 {
	const char *name;
	struct list_head entry;
	struct kobject___68 *parent;
	struct kset___67 *kset;
	struct kobj_type___67 *ktype;
	struct kernfs_node___68 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___65;

struct dev_pm_info___65 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___65 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___65;

struct bus_type___65;

struct device_driver___65;

struct dev_pm_domain___65;

struct class___65;

struct attribute_group___65;

struct device___65 {
	struct device___65 *parent;
	struct device_private *p;
	struct kobject___68 kobj;
	const char *init_name;
	const struct device_type___65 *type;
	struct mutex mutex;
	struct bus_type___65 *bus;
	struct device_driver___65 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___65 power;
	struct dev_pm_domain___65 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___65 *class;
	const struct attribute_group___65 **groups;
	void (*release)(struct device___65 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct module_kobject___60 {
	struct kobject___68 kobj;
	struct module___63 *mod;
	struct kobject___68 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___60 {
	struct module___63 *mod;
	struct latch_tree_node node;
};

struct module_layout___60 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___60 mtn;
};

struct module_attribute___60;

struct kernel_param___60;

struct module___63 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___60 mkobj;
	struct module_attribute___60 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___68 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___60 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___60 core_layout;
	struct module_layout___60 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___39 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rtc_time {
	int tm_sec;
	int tm_min;
	int tm_hour;
	int tm_mday;
	int tm_mon;
	int tm_year;
	int tm_wday;
	int tm_yday;
	int tm_isdst;
};

struct rtc_wkalrm {
	unsigned char enabled;
	unsigned char pending;
	struct rtc_time time;
};

typedef struct page___71 *pgtable_t___70;

struct address_space___70;

struct dev_pagemap___70;

struct page___71 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___70 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___71 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___70 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___70 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___70 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___70;

struct lruvec___70 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___70 *pgdat;
};

struct zone___70 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___70 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___70 {
	struct zone___70 *zone;
	int zone_idx;
};

struct zonelist___70 {
	struct zoneref___70 _zonerefs[25];
};

struct pglist_data___70 {
	struct zone___70 node_zones[3];
	struct zonelist___70 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___71 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___71 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___70 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___71 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___71 *owner;
};

struct blocking_notifier_head___70 {
	struct rw_semaphore___71 rwsem;
	struct notifier_block *head;
};

struct key___68;

struct ucounts___57;

struct user_namespace___57 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___57 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common ns;
	long unsigned int flags;
	struct key___68 *persistent_keyring_register;
	struct rw_semaphore___71 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___57 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_root___68;

struct kernfs_elem_dir___68 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___68 *root;
};

struct kernfs_syscall_ops___68;

struct kernfs_root___68 {
	struct kernfs_node___68 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___68 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___68 {
	struct kernfs_node___68 *target_kn;
};

struct kernfs_ops___68;

struct kernfs_elem_attr___68 {
	const struct kernfs_ops___68 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___68 *notify_next;
};

struct kernfs_node___68 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___68 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___68 dir;
		struct kernfs_elem_symlink___68 symlink;
		struct kernfs_elem_attr___68 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___68;

struct kernfs_ops___68 {
	int (*open)(struct kernfs_open_file___68 *);
	void (*release)(struct kernfs_open_file___68 *);
	int (*seq_show)(struct seq_file___65 *, void *);
	void * (*seq_start)(struct seq_file___65 *, loff_t *);
	void * (*seq_next)(struct seq_file___65 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___65 *, void *);
	ssize_t (*read)(struct kernfs_open_file___68 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___68 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___68 *, struct vm_area_struct___71 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___68 *, struct poll_table_struct___46 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___68 {
	int (*remount_fs)(struct kernfs_root___68 *, int *, char *);
	int (*show_options)(struct seq_file___65 *, struct kernfs_root___68 *);
	int (*mkdir)(struct kernfs_node___68 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___68 *);
	int (*rename)(struct kernfs_node___68 *, struct kernfs_node___68 *, const char *);
	int (*show_path)(struct seq_file___65 *, struct kernfs_node___68 *, struct kernfs_root___68 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___62;

struct seq_file___65 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___62 *op;
	int poll_event;
	const struct file___71 *file;
	void *private;
};

struct vm_operations_struct___70;

struct kernfs_open_file___68 {
	struct kernfs_node___68 *kn;
	struct file___71 *file;
	struct seq_file___65 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___70 *vm_ops;
};

struct dentry___71;

struct path___70 {
	struct vfsmount *mnt;
	struct dentry___71 *dentry;
};

struct fown_struct___59 {
	rwlock_t lock;
	struct pid___59 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___71 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___70 f_path;
	struct inode___72 *f_inode;
	const struct file_operations___71 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___59 f_owner;
	const struct cred___67 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___70 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___70;

struct vm_operations_struct___70 {
	void (*open)(struct vm_area_struct___71 *);
	void (*close)(struct vm_area_struct___71 *);
	int (*split)(struct vm_area_struct___71 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___71 *);
	vm_fault_t (*fault)(struct vm_fault___70 *);
	vm_fault_t (*huge_fault)(struct vm_fault___70 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___70 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___71 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___70 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___70 *);
	int (*access)(struct vm_area_struct___71 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___71 *);
	int (*set_policy)(struct vm_area_struct___71 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___71 *, long unsigned int);
	struct page___71 * (*find_special_page)(struct vm_area_struct___71 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___45)(struct file___71 *, wait_queue_head_t *, struct poll_table_struct___46 *);

struct poll_table_struct___46 {
	poll_queue_proc___45 _qproc;
	__poll_t _key;
};

struct vm_area_struct___71 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___71 *vm_next;
	struct vm_area_struct___71 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___70 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___70 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___71 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___65;

struct attribute_group___65 {
	const char *name;
	umode_t (*is_visible)(struct kobject___68 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___68 *, struct bin_attribute___65 *, int);
	struct attribute **attrs;
	struct bin_attribute___65 **bin_attrs;
};

struct bin_attribute___65 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___71 *, struct kobject___68 *, struct bin_attribute___65 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___71 *, struct kobject___68 *, struct bin_attribute___65 *, char *, loff_t, size_t);
	int (*mmap)(struct file___71 *, struct kobject___68 *, struct bin_attribute___65 *, struct vm_area_struct___71 *);
};

struct sysfs_ops___67 {
	ssize_t (*show)(struct kobject___68 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___68 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___67;

struct kset___67 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___68 kobj;
	const struct kset_uevent_ops___67 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___67 {
	void (*release)(struct kobject___68 *);
	const struct sysfs_ops___67 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___68 *);
	const void * (*namespace)(struct kobject___68 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___67 {
	int (* const filter)(struct kset___67 *, struct kobject___68 *);
	const char * (* const name)(struct kset___67 *, struct kobject___68 *);
	int (* const uevent)(struct kset___67 *, struct kobject___68 *, struct kobj_uevent_env *);
};

struct kobj_attribute___68 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___68 *, struct kobj_attribute___68 *, char *);
	ssize_t (*store)(struct kobject___68 *, struct kobj_attribute___68 *, const char *, size_t);
};

struct dev_pm_ops___65 {
	int (*prepare)(struct device___65 *);
	void (*complete)(struct device___65 *);
	int (*suspend)(struct device___65 *);
	int (*resume)(struct device___65 *);
	int (*freeze)(struct device___65 *);
	int (*thaw)(struct device___65 *);
	int (*poweroff)(struct device___65 *);
	int (*restore)(struct device___65 *);
	int (*suspend_late)(struct device___65 *);
	int (*resume_early)(struct device___65 *);
	int (*freeze_late)(struct device___65 *);
	int (*thaw_early)(struct device___65 *);
	int (*poweroff_late)(struct device___65 *);
	int (*restore_early)(struct device___65 *);
	int (*suspend_noirq)(struct device___65 *);
	int (*resume_noirq)(struct device___65 *);
	int (*freeze_noirq)(struct device___65 *);
	int (*thaw_noirq)(struct device___65 *);
	int (*poweroff_noirq)(struct device___65 *);
	int (*restore_noirq)(struct device___65 *);
	int (*runtime_suspend)(struct device___65 *);
	int (*runtime_resume)(struct device___65 *);
	int (*runtime_idle)(struct device___65 *);
};

struct dev_pm_domain___65 {
	struct dev_pm_ops___65 ops;
	void (*detach)(struct device___65 *, bool);
	int (*activate)(struct device___65 *);
	void (*sync)(struct device___65 *);
	void (*dismiss)(struct device___65 *);
};

struct upid___59 {
	int nr;
	struct pid_namespace___59 *ns;
};

struct pid_namespace___59 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___71 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___59 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___71 *proc_self;
	struct dentry___71 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___57 *user_ns;
	struct ucounts___57 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common ns;
};

struct pid___59 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___59 numbers[1];
};

struct user_struct___67;

struct sigqueue___3 {
	struct list_head list;
	int flags;
	kernel_siginfo_t info;
	struct user_struct___67 *user;
};

struct user_struct___67 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___68 *uid_keyring;
	struct key___68 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___70;

struct mm_struct___70 {
	struct {
		struct vm_area_struct___71 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___71 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___71 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___70 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___71 *owner;
		struct user_namespace___57 *user_ns;
		struct file___71 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___70 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___67 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___68 *session_keyring;
	struct key___68 *process_keyring;
	struct key___68 *thread_keyring;
	struct key___68 *request_key_auth;
	void *security;
	struct user_struct___67 *user;
	struct user_namespace___57 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___55;

struct nsproxy___66 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___59 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___55 *cgroup_ns;
};

struct signal_struct___61 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___71 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___71 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___59 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___59 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___70 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___59 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___55;

struct cgroup___55;

struct css_set___55 {
	struct cgroup_subsys_state___55 *subsys[13];
	refcount_t refcount;
	struct css_set___55 *dom_cset;
	struct cgroup___55 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___55 *mg_src_cgrp;
	struct cgroup___55 *mg_dst_cgrp;
	struct css_set___55 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___44 {
	struct pmu___44 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___71 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___44 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

union thread_union___61 {
	struct task_struct___71 task;
	long unsigned int stack[8192];
};

struct bus_type___65 {
	const char *name;
	const char *dev_name;
	struct device___65 *dev_root;
	const struct attribute_group___65 **bus_groups;
	const struct attribute_group___65 **dev_groups;
	const struct attribute_group___65 **drv_groups;
	int (*match)(struct device___65 *, struct device_driver___65 *);
	int (*uevent)(struct device___65 *, struct kobj_uevent_env *);
	int (*probe)(struct device___65 *);
	int (*remove)(struct device___65 *);
	void (*shutdown)(struct device___65 *);
	int (*online)(struct device___65 *);
	int (*offline)(struct device___65 *);
	int (*suspend)(struct device___65 *, pm_message_t);
	int (*resume)(struct device___65 *);
	int (*num_vf)(struct device___65 *);
	int (*dma_configure)(struct device___65 *);
	const struct dev_pm_ops___65 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___65 {
	const char *name;
	struct bus_type___65 *bus;
	struct module___63 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___65 *);
	int (*remove)(struct device___65 *);
	void (*shutdown)(struct device___65 *);
	int (*suspend)(struct device___65 *, pm_message_t);
	int (*resume)(struct device___65 *);
	const struct attribute_group___65 **groups;
	const struct dev_pm_ops___65 *pm;
	void (*coredump)(struct device___65 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___65 {
	const char *name;
	const struct attribute_group___65 **groups;
	int (*uevent)(struct device___65 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___65 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___65 *);
	const struct dev_pm_ops___65 *pm;
};

struct class___65 {
	const char *name;
	struct module___63 *owner;
	const struct attribute_group___65 **class_groups;
	const struct attribute_group___65 **dev_groups;
	struct kobject___68 *dev_kobj;
	int (*dev_uevent)(struct device___65 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___65 *, umode_t *);
	void (*class_release)(struct class___65 *);
	void (*dev_release)(struct device___65 *);
	int (*shutdown_pre)(struct device___65 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___65 *);
	const struct dev_pm_ops___65 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct class_interface {
	struct list_head node;
	struct class___65 *class;
	int (*add_dev)(struct device___65 *, struct class_interface *);
	void (*remove_dev)(struct device___65 *, struct class_interface *);
};

struct dentry_operations___70;

struct super_block___71;

struct dentry___71 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___71 *d_parent;
	struct qstr d_name;
	struct inode___72 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___70 *d_op;
	struct super_block___71 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___70;

struct address_space___70 {
	struct inode___72 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___71 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___70 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___70;

struct block_device___71;

struct cdev___18;

struct inode___72 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___70 *i_op;
	struct super_block___71 *i_sb;
	struct address_space___70 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___71 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___71 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___70 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___71 *i_bdev;
		struct cdev___18 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___70 {
	int (*d_revalidate)(struct dentry___71 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___71 *, unsigned int);
	int (*d_hash)(const struct dentry___71 *, struct qstr *);
	int (*d_compare)(const struct dentry___71 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___71 *);
	int (*d_init)(struct dentry___71 *);
	void (*d_release)(struct dentry___71 *);
	void (*d_prune)(struct dentry___71 *);
	void (*d_iput)(struct dentry___71 *, struct inode___72 *);
	char * (*d_dname)(struct dentry___71 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___70 *);
	int (*d_manage)(const struct path___70 *, bool);
	struct dentry___71 * (*d_real)(struct dentry___71 *, const struct inode___72 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___70;

struct mem_dqinfo___70 {
	struct quota_format_type___70 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___70;

struct quota_info___70 {
	unsigned int flags;
	struct rw_semaphore___71 dqio_sem;
	struct inode___72 *files[3];
	struct mem_dqinfo___70 info[3];
	const struct quota_format_ops___70 *ops[3];
};

struct rcuwait___70 {
	struct task_struct___71 *task;
};

struct percpu_rw_semaphore___70 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___71 rw_sem;
	struct rcuwait___70 writer;
	int readers_block;
};

struct sb_writers___70 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___70 rw_sem[3];
};

struct file_system_type___70;

struct super_operations___70;

struct dquot_operations___70;

struct quotactl_ops___70;

struct super_block___71 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___70 *s_type;
	const struct super_operations___70 *s_op;
	const struct dquot_operations___70 *dq_op;
	const struct quotactl_ops___70 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___71 *s_root;
	struct rw_semaphore___71 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___71 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___70 s_dquot;
	struct sb_writers___70 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___70 *s_d_op;
	int cleancache_poolid;
	struct shrinker___29 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___57 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

typedef int (*dev_page_fault_t___70)(struct vm_area_struct___71 *, long unsigned int, const struct page___71 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___70)(struct page___71 *, void *);

struct dev_pagemap___70 {
	dev_page_fault_t___70 page_fault;
	dev_page_free_t___70 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___65 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___70 {
	struct task_struct___71 *task;
	struct core_thread___70 *next;
};

struct core_state___70 {
	atomic_t nr_threads;
	struct core_thread___70 dumper;
	struct completion startup;
};

struct vm_fault___70 {
	struct vm_area_struct___71 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___71 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___71 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___70 prealloc_pte;
};

struct kiocb___71 {
	struct file___71 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___71 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___71 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___71 *ia_file;
};

struct dquot___70 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___71 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___70 {
	int qf_fmt_id;
	const struct quota_format_ops___70 *qf_ops;
	struct module___63 *qf_owner;
	struct quota_format_type___70 *qf_next;
};

struct quota_format_ops___70 {
	int (*check_quota_file)(struct super_block___71 *, int);
	int (*read_file_info)(struct super_block___71 *, int);
	int (*write_file_info)(struct super_block___71 *, int);
	int (*free_file_info)(struct super_block___71 *, int);
	int (*read_dqblk)(struct dquot___70 *);
	int (*commit_dqblk)(struct dquot___70 *);
	int (*release_dqblk)(struct dquot___70 *);
	int (*get_next_id)(struct super_block___71 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___70 {
	int (*write_dquot)(struct dquot___70 *);
	struct dquot___70 * (*alloc_dquot)(struct super_block___71 *, int);
	void (*destroy_dquot)(struct dquot___70 *);
	int (*acquire_dquot)(struct dquot___70 *);
	int (*release_dquot)(struct dquot___70 *);
	int (*mark_dirty)(struct dquot___70 *);
	int (*write_info)(struct super_block___71 *, int);
	qsize_t * (*get_reserved_space)(struct inode___72 *);
	int (*get_projid)(struct inode___72 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___72 *, qsize_t *);
	int (*get_next_id)(struct super_block___71 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___70 {
	int (*quota_on)(struct super_block___71 *, int, int, const struct path___70 *);
	int (*quota_off)(struct super_block___71 *, int);
	int (*quota_enable)(struct super_block___71 *, unsigned int);
	int (*quota_disable)(struct super_block___71 *, unsigned int);
	int (*quota_sync)(struct super_block___71 *, int);
	int (*set_info)(struct super_block___71 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___71 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___71 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___71 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___71 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___71 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___70 {
	int (*writepage)(struct page___71 *, struct writeback_control___3 *);
	int (*readpage)(struct file___71 *, struct page___71 *);
	int (*writepages)(struct address_space___70 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___71 *);
	int (*readpages)(struct file___71 *, struct address_space___70 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___71 *, struct address_space___70 *, loff_t, unsigned int, unsigned int, struct page___71 **, void **);
	int (*write_end)(struct file___71 *, struct address_space___70 *, loff_t, unsigned int, unsigned int, struct page___71 *, void *);
	sector_t (*bmap)(struct address_space___70 *, sector_t);
	void (*invalidatepage)(struct page___71 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___71 *, gfp_t);
	void (*freepage)(struct page___71 *);
	ssize_t (*direct_IO)(struct kiocb___71 *, struct iov_iter___29 *);
	int (*migratepage)(struct address_space___70 *, struct page___71 *, struct page___71 *, enum migrate_mode);
	bool (*isolate_page)(struct page___71 *, isolate_mode_t);
	void (*putback_page)(struct page___71 *);
	int (*launder_page)(struct page___71 *);
	int (*is_partially_uptodate)(struct page___71 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___71 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___70 *, struct page___71 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___71 *, sector_t *);
	void (*swap_deactivate)(struct file___71 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___71 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___72 *bd_inode;
	struct super_block___71 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___71 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___18 {
	struct kobject___68 kobj;
	struct module___63 *owner;
	const struct file_operations___71 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___70 {
	struct dentry___71 * (*lookup)(struct inode___72 *, struct dentry___71 *, unsigned int);
	const char * (*get_link)(struct dentry___71 *, struct inode___72 *, struct delayed_call *);
	int (*permission)(struct inode___72 *, int);
	struct posix_acl * (*get_acl)(struct inode___72 *, int);
	int (*readlink)(struct dentry___71 *, char *, int);
	int (*create)(struct inode___72 *, struct dentry___71 *, umode_t, bool);
	int (*link)(struct dentry___71 *, struct inode___72 *, struct dentry___71 *);
	int (*unlink)(struct inode___72 *, struct dentry___71 *);
	int (*symlink)(struct inode___72 *, struct dentry___71 *, const char *);
	int (*mkdir)(struct inode___72 *, struct dentry___71 *, umode_t);
	int (*rmdir)(struct inode___72 *, struct dentry___71 *);
	int (*mknod)(struct inode___72 *, struct dentry___71 *, umode_t, dev_t);
	int (*rename)(struct inode___72 *, struct dentry___71 *, struct inode___72 *, struct dentry___71 *, unsigned int);
	int (*setattr)(struct dentry___71 *, struct iattr___71 *);
	int (*getattr)(const struct path___70 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___71 *, char *, size_t);
	int (*fiemap)(struct inode___72 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___72 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___72 *, struct dentry___71 *, struct file___71 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___72 *, struct dentry___71 *, umode_t);
	int (*set_acl)(struct inode___72 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___70 {
	void (*fl_copy_lock)(struct file_lock___71 *, struct file_lock___71 *);
	void (*fl_release_private)(struct file_lock___71 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___70;

struct file_lock___71 {
	struct file_lock___71 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___71 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___70 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___70 *fl_ops;
	const struct lock_manager_operations___70 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___70 {
	int (*lm_compare_owner)(struct file_lock___71 *, struct file_lock___71 *);
	long unsigned int (*lm_owner_key)(struct file_lock___71 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___71 *);
	int (*lm_grant)(struct file_lock___71 *, int);
	bool (*lm_break)(struct file_lock___71 *);
	int (*lm_change)(struct file_lock___71 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___71 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___70 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___70 *fa_next;
	struct file___71 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___70 {
	const char *name;
	int fs_flags;
	struct dentry___71 * (*mount)(struct file_system_type___70 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___71 *);
	struct module___63 *owner;
	struct file_system_type___70 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___70 {
	struct inode___72 * (*alloc_inode)(struct super_block___71 *);
	void (*destroy_inode)(struct inode___72 *);
	void (*dirty_inode)(struct inode___72 *, int);
	int (*write_inode)(struct inode___72 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___72 *);
	void (*evict_inode)(struct inode___72 *);
	void (*put_super)(struct super_block___71 *);
	int (*sync_fs)(struct super_block___71 *, int);
	int (*freeze_super)(struct super_block___71 *);
	int (*freeze_fs)(struct super_block___71 *);
	int (*thaw_super)(struct super_block___71 *);
	int (*unfreeze_fs)(struct super_block___71 *);
	int (*statfs)(struct dentry___71 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___71 *, int *, char *);
	void (*umount_begin)(struct super_block___71 *);
	int (*show_options)(struct seq_file___65 *, struct dentry___71 *);
	int (*show_devname)(struct seq_file___65 *, struct dentry___71 *);
	int (*show_path)(struct seq_file___65 *, struct dentry___71 *);
	int (*show_stats)(struct seq_file___65 *, struct dentry___71 *);
	ssize_t (*quota_read)(struct super_block___71 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___71 *, int, const char *, size_t, loff_t);
	struct dquot___70 ** (*get_dquots)(struct inode___72 *);
	int (*bdev_try_to_free_page)(struct super_block___71 *, struct page___71 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___71 *, struct shrink_control___29 *);
	long int (*free_cached_objects)(struct super_block___71 *, struct shrink_control___29 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*key_restrict_link_func_t___67)(struct key___68 *, const struct key_type *, const union key_payload *, struct key___68 *);

struct key_restriction___68;

struct key___68 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___71 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___68 *restrict_link;
};

struct key_restriction___68 {
	key_restrict_link_func_t___67 check;
	struct key___68 *key;
	struct key_type *keytype;
};

struct seq_operations___62 {
	void * (*start)(struct seq_file___65 *, loff_t *);
	void (*stop)(struct seq_file___65 *, void *);
	void * (*next)(struct seq_file___65 *, void *, loff_t *);
	int (*show)(struct seq_file___65 *, void *);
};

struct rtc_class_ops {
	int (*ioctl)(struct device___65 *, unsigned int, long unsigned int);
	int (*read_time)(struct device___65 *, struct rtc_time *);
	int (*set_time)(struct device___65 *, struct rtc_time *);
	int (*read_alarm)(struct device___65 *, struct rtc_wkalrm *);
	int (*set_alarm)(struct device___65 *, struct rtc_wkalrm *);
	int (*proc)(struct device___65 *, struct seq_file___65 *);
	int (*set_mmss64)(struct device___65 *, time64_t);
	int (*set_mmss)(struct device___65 *, long unsigned int);
	int (*read_callback)(struct device___65 *, int);
	int (*alarm_irq_enable)(struct device___65 *, unsigned int);
	int (*read_offset)(struct device___65 *, long int *);
	int (*set_offset)(struct device___65 *, long int);
};

struct rtc_task {
	void (*func)(void *);
	void *private_data;
};

struct rtc_timer {
	struct rtc_task task;
	struct timerqueue_node node;
	ktime_t period;
	int enabled;
};

struct nvmem_device;

struct rtc_device {
	struct device___65 dev;
	struct module___63 *owner;
	int id;
	const struct rtc_class_ops *ops;
	struct mutex ops_lock;
	struct cdev___18 char_dev;
	long unsigned int flags;
	long unsigned int irq_data;
	spinlock_t irq_lock;
	wait_queue_head_t irq_queue;
	struct fasync_struct___70 *async_queue;
	struct rtc_task *irq_task;
	spinlock_t irq_task_lock;
	int irq_freq;
	int max_user_freq;
	struct timerqueue_head timerqueue;
	struct rtc_timer aie_timer;
	struct rtc_timer uie_rtctimer;
	struct hrtimer pie_timer;
	int pie_enabled;
	struct work_struct irqwork;
	int uie_unsupported;
	long int set_offset_nsec;
	bool registered;
	struct nvmem_device *nvmem;
	bool nvram_old_abi;
	struct bin_attribute___65 *nvram;
	time64_t range_min;
	timeu64_t range_max;
	time64_t start_secs;
	time64_t offset_secs;
	bool set_start_time;
};

enum alarmtimer_type {
	ALARM_REALTIME = 0,
	ALARM_BOOTTIME = 1,
	ALARM_NUMTYPE = 2,
	ALARM_REALTIME_FREEZER = 3,
	ALARM_BOOTTIME_FREEZER = 4,
};

enum alarmtimer_restart {
	ALARMTIMER_NORESTART = 0,
	ALARMTIMER_RESTART = 1,
};

struct alarm {
	struct timerqueue_node node;
	struct hrtimer timer;
	enum alarmtimer_restart (*function)(struct alarm *, ktime_t);
	enum alarmtimer_type type;
	int state;
	void *data;
};

struct platform_device___2 {
	const char *name;
	int id;
	bool id_auto;
	struct device___65 dev;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct property_entry;

struct platform_device_info {
	struct device___65 *parent;
	struct fwnode_handle___4 *fwnode;
	const char *name;
	int id;
	const struct resource *res;
	unsigned int num_res;
	const void *data;
	size_t size_data;
	u64 dma_mask;
	struct property_entry *properties;
};

struct platform_driver___2 {
	int (*probe)(struct platform_device___2 *);
	int (*remove)(struct platform_device___2 *);
	void (*shutdown)(struct platform_device___2 *);
	int (*suspend)(struct platform_device___2 *, pm_message_t);
	int (*resume)(struct platform_device___2 *);
	struct device_driver___65 driver;
	const struct platform_device_id *id_table;
	bool prevent_deferred_probe;
};

struct cpu_timer_list {
	struct list_head entry;
	u64 expires;
	u64 incr;
	struct task_struct___71 *task;
	int firing;
};

struct k_clock;

struct k_itimer {
	struct list_head list;
	struct hlist_node t_hash;
	spinlock_t it_lock;
	const struct k_clock *kclock;
	clockid_t it_clock;
	timer_t it_id;
	int it_active;
	s64 it_overrun;
	s64 it_overrun_last;
	int it_requeue_pending;
	int it_sigev_notify;
	ktime_t it_interval;
	struct signal_struct___61 *it_signal;
	union {
		struct pid___59 *it_pid;
		struct task_struct___71 *it_process;
	};
	struct sigqueue___3 *sigq;
	union {
		struct {
			struct hrtimer timer;
		} real;
		struct cpu_timer_list cpu;
		struct {
			struct alarm alarmtimer;
		} alarm;
		struct callback_head rcu;
	} it;
};

struct k_clock {
	int (*clock_getres)(const clockid_t, struct timespec64 *);
	int (*clock_set)(const clockid_t, const struct timespec64 *);
	int (*clock_get)(const clockid_t, struct timespec64 *);
	int (*clock_adj)(const clockid_t, struct timex *);
	int (*timer_create)(struct k_itimer *);
	int (*nsleep)(const clockid_t, int, const struct timespec64 *);
	int (*timer_set)(struct k_itimer *, int, struct itimerspec64 *, struct itimerspec64 *);
	int (*timer_del)(struct k_itimer *);
	void (*timer_get)(struct k_itimer *, struct itimerspec64 *);
	void (*timer_rearm)(struct k_itimer *);
	s64 (*timer_forward)(struct k_itimer *, ktime_t);
	ktime_t (*timer_remaining)(struct k_itimer *, ktime_t);
	int (*timer_try_to_cancel)(struct k_itimer *);
	void (*timer_arm)(struct k_itimer *, ktime_t, bool, bool);
};

struct kernel_param_ops___60 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___60 *);
	int (*get)(char *, const struct kernel_param___60 *);
	void (*free)(void *);
};

struct kparam_array___60;

struct kernel_param___60 {
	const char *name;
	struct module___63 *mod;
	const struct kernel_param_ops___60 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___60 *arr;
	};
};

struct kparam_array___60 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___60 *ops;
	void *elem;
};

struct module_attribute___60 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___60 *, struct module_kobject___60 *, char *);
	ssize_t (*store)(struct module_attribute___60 *, struct module_kobject___60 *, const char *, size_t);
	void (*setup)(struct module___63 *, const char *);
	int (*test)(struct module___63 *);
	void (*free)(struct module___63 *);
};

struct trace_event_class___39;

struct trace_event_call___39 {
	struct list_head list;
	struct trace_event_class___39 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array *prog_array;
	int (*perf_perm)(struct trace_event_call___39 *, struct perf_event___44 *);
};

typedef void compound_page_dtor___70(struct page___71 *);

struct cgroup_namespace___55 {
	refcount_t count;
	struct ns_common ns;
	struct user_namespace___57 *user_ns;
	struct ucounts___57 *ucounts;
	struct css_set___55 *root_cset;
};

struct ucounts___57 {
	struct hlist_node node;
	struct user_namespace___57 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct node___57 {
	struct device___65 dev;
};

struct bpf_map___55;

struct bpf_map_ops___55 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___55 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___55 *, struct file___71 *);
	void (*map_free)(struct bpf_map___55 *);
	int (*map_get_next_key)(struct bpf_map___55 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___55 *);
	void * (*map_lookup_elem)(struct bpf_map___55 *, void *);
	int (*map_update_elem)(struct bpf_map___55 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___55 *, void *);
	int (*map_push_elem)(struct bpf_map___55 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___55 *, void *);
	int (*map_peek_elem)(struct bpf_map___55 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___55 *, struct file___71 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___55 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___55 *, void *, struct seq_file___65 *);
	int (*map_check_btf)(const struct bpf_map___55 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___55 {
	const struct bpf_map_ops___55 *ops;
	struct bpf_map___55 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___67 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___55;

typedef void (*kthread_work_func_t___55)(struct kthread_work___55 *);

struct kthread_worker___55;

struct kthread_work___55 {
	struct list_head node;
	kthread_work_func_t___55 func;
	struct kthread_worker___55 *worker;
	int canceling;
};

struct kthread_worker___55 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___71 *task;
	struct kthread_work___55 *current_work;
};

struct kthread_delayed_work___55 {
	struct kthread_work___55 work;
	struct timer_list timer;
};

struct psi_group___55 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___55 *poll_kworker;
	struct kthread_delayed_work___55 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___55 {
	struct kernfs_node___68 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___55;

struct cgroup_subsys_state___55 {
	struct cgroup___55 *cgroup;
	struct cgroup_subsys___55 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___55 *parent;
};

struct cgroup_root___55;

struct cgroup_rstat_cpu___55;

struct cgroup___55 {
	struct cgroup_subsys_state___55 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___68 *kn;
	struct cgroup_file___55 procs_file;
	struct cgroup_file___55 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___55 *subsys[13];
	struct cgroup_root___55 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___55 *dom_cgrp;
	struct cgroup_rstat_cpu___55 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf bpf;
	atomic_t congestion_count;
	struct cgroup___55 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___55 psi;
	int ancestor_ids[0];
};

struct cftype___55;

struct cgroup_subsys___55 {
	struct cgroup_subsys_state___55 * (*css_alloc)(struct cgroup_subsys_state___55 *);
	int (*css_online)(struct cgroup_subsys_state___55 *);
	void (*css_offline)(struct cgroup_subsys_state___55 *);
	void (*css_released)(struct cgroup_subsys_state___55 *);
	void (*css_free)(struct cgroup_subsys_state___55 *);
	void (*css_reset)(struct cgroup_subsys_state___55 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___55 *, int);
	int (*css_extra_stat_show)(struct seq_file___65 *, struct cgroup_subsys_state___55 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___71 *);
	void (*cancel_fork)(struct task_struct___71 *);
	void (*fork)(struct task_struct___71 *);
	void (*exit)(struct task_struct___71 *);
	void (*free)(struct task_struct___71 *);
	void (*bind)(struct cgroup_subsys_state___55 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___55 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___55 *dfl_cftypes;
	struct cftype___55 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___55 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___55 *updated_children;
	struct cgroup___55 *updated_next;
};

struct cgroup_root___55 {
	struct kernfs_root___68 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___55 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___55 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___55 *ss;
	struct list_head node;
	struct kernfs_ops___68 *kf_ops;
	int (*open)(struct kernfs_open_file___68 *);
	void (*release)(struct kernfs_open_file___68 *);
	u64 (*read_u64)(struct cgroup_subsys_state___55 *, struct cftype___55 *);
	s64 (*read_s64)(struct cgroup_subsys_state___55 *, struct cftype___55 *);
	int (*seq_show)(struct seq_file___65 *, void *);
	void * (*seq_start)(struct seq_file___65 *, loff_t *);
	void * (*seq_next)(struct seq_file___65 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___65 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___55 *, struct cftype___55 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___55 *, struct cftype___55 *, s64);
	ssize_t (*write)(struct kernfs_open_file___68 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___68 *, struct poll_table_struct___46 *);
};

struct perf_cpu_context___44;

struct pmu___44 {
	struct list_head entry;
	struct module___63 *module;
	struct device___65 *dev;
	const struct attribute_group___65 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___44 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___44 *);
	void (*pmu_disable)(struct pmu___44 *);
	int (*event_init)(struct perf_event___44 *);
	void (*event_mapped)(struct perf_event___44 *, struct mm_struct___70 *);
	void (*event_unmapped)(struct perf_event___44 *, struct mm_struct___70 *);
	int (*add)(struct perf_event___44 *, int);
	void (*del)(struct perf_event___44 *, int);
	void (*start)(struct perf_event___44 *, int);
	void (*stop)(struct perf_event___44 *, int);
	void (*read)(struct perf_event___44 *);
	void (*start_txn)(struct pmu___44 *, unsigned int);
	int (*commit_txn)(struct pmu___44 *);
	void (*cancel_txn)(struct pmu___44 *);
	int (*event_idx)(struct perf_event___44 *);
	void (*sched_task)(struct perf_event_context___44 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___44 *);
	int (*filter_match)(struct perf_event___44 *);
	int (*check_period)(struct perf_event___44 *, u64);
};

struct perf_cpu_context___44 {
	struct perf_event_context___44 ctx;
	struct perf_event_context___44 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___44 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___44 {
	struct cgroup_subsys_state___55 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___39 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___39 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___39 *);
	struct list_head * (*get_fields)(struct trace_event_call___39 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___39 *);
};

struct trace_event_file___15;

struct trace_event_buffer___15 {
	struct ring_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___15 *trace_file;
	void *entry;
	long unsigned int flags;
	int pc;
};

struct trace_event_file___15 {
	struct list_head list;
	struct trace_event_call___39 *event_call;
	struct event_filter *filter;
	struct dentry___71 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_alarmtimer_suspend {
	struct trace_entry ent;
	s64 expires;
	unsigned char alarm_type;
	char __data[0];
};

struct trace_event_raw_alarm_class {
	struct trace_entry ent;
	void *alarm;
	unsigned char alarm_type;
	s64 expires;
	s64 now;
	char __data[0];
};

struct trace_event_data_offsets_alarmtimer_suspend {};

struct trace_event_data_offsets_alarm_class {};

struct alarm_base {
	spinlock_t lock;
	struct timerqueue_head timerqueue;
	ktime_t (*gettime)();
	clockid_t base_clockid;
};

struct module___64;

struct file___72;

struct kiocb___72;

struct poll_table_struct___47;

struct vm_area_struct___72;

struct inode___73;

struct file_lock___72;

struct page___72;

struct seq_file___66;

struct file_operations___72 {
	struct module___64 *owner;
	loff_t (*llseek)(struct file___72 *, loff_t, int);
	ssize_t (*read)(struct file___72 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___72 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___72 *, struct iov_iter___29 *);
	ssize_t (*write_iter)(struct kiocb___72 *, struct iov_iter___29 *);
	int (*iopoll)(struct kiocb___72 *, bool);
	int (*iterate)(struct file___72 *, struct dir_context *);
	int (*iterate_shared)(struct file___72 *, struct dir_context *);
	__poll_t (*poll)(struct file___72 *, struct poll_table_struct___47 *);
	long int (*unlocked_ioctl)(struct file___72 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___72 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___72 *, struct vm_area_struct___72 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___73 *, struct file___72 *);
	int (*flush)(struct file___72 *, fl_owner_t);
	int (*release)(struct inode___73 *, struct file___72 *);
	int (*fsync)(struct file___72 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___72 *, int);
	int (*lock)(struct file___72 *, int, struct file_lock___72 *);
	ssize_t (*sendpage)(struct file___72 *, struct page___72 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___72 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___72 *, int, struct file_lock___72 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___72 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___72 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___72 *, long int, struct file_lock___72 **, void **);
	long int (*fallocate)(struct file___72 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___66 *, struct file___72 *);
	ssize_t (*copy_file_range)(struct file___72 *, loff_t, struct file___72 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___72 *, loff_t, struct file___72 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___72 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___71 {
	u64 seqnum;
	struct vm_area_struct___72 *vmas[4];
};

struct page_frag___71 {
	struct page___72 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___45;

struct debug_info___45 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___45 *hbp_break[16];
	struct perf_event___45 *hbp_watch[16];
};

struct thread_struct___45 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___45 debug;
	long: 64;
};

struct mm_struct___71;

struct pid___60;

struct cred___68;

struct nsproxy___67;

struct signal_struct___62;

struct css_set___56;

struct perf_event_context___45;

struct task_struct___72 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___72 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___71 *mm;
	struct mm_struct___71 *active_mm;
	struct vmacache___71 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___72 *real_parent;
	struct task_struct___72 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___72 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___60 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___60 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___60 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___68 *ptracer_cred;
	const struct cred___68 *real_cred;
	const struct cred___68 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___67 *nsproxy;
	struct signal_struct___62 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___72 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___13 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___56 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___45 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___71 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___72 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___45 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___45 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___72 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___45)(struct perf_event___45 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___45;

struct fasync_struct___71;

struct pid_namespace___60;

struct trace_event_call___40;

struct perf_cgroup___45;

struct perf_event___45 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___45 *group_leader;
	struct pmu___45 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___45 hw;
	struct perf_event_context___45 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___45 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___72 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___71 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___45 *);
	struct callback_head callback_head;
	struct pid_namespace___60 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___45 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___45 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___40 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___45 *cgrp;
	struct list_head sb_list;
};

typedef struct page___72 *pgtable_t___71;

struct address_space___71;

struct dev_pagemap___71;

struct page___72 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___71 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___72 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___71 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___71 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___71 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___71;

struct lruvec___71 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___71 *pgdat;
};

struct zone___71 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___71 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___71 {
	struct zone___71 *zone;
	int zone_idx;
};

struct zonelist___71 {
	struct zoneref___71 _zonerefs[25];
};

struct pglist_data___71 {
	struct zone___71 node_zones[3];
	struct zonelist___71 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___72 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___72 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___71 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___72 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___72 *owner;
};

struct secondary_data___72 {
	void *stack;
	struct task_struct___72 *task;
	long int status;
};

struct blocking_notifier_head___71 {
	struct rw_semaphore___72 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___71;

struct vm_area_struct___72 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___72 *vm_next;
	struct vm_area_struct___72 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___71 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___71 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___72 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___71;

struct user_namespace___58;

struct mm_struct___71 {
	struct {
		struct vm_area_struct___72 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___72 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___72 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___71 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___72 *owner;
		struct user_namespace___58 *user_ns;
		struct file___72 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___71 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___71;

struct address_space___71 {
	struct inode___73 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___72 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___71 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___71)(struct vm_area_struct___72 *, long unsigned int, const struct page___72 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___71)(struct page___72 *, void *);

struct device___66;

struct dev_pagemap___71 {
	dev_page_fault_t___71 page_fault;
	dev_page_free_t___71 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___66 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct dentry___72;

struct path___71 {
	struct vfsmount *mnt;
	struct dentry___72 *dentry;
};

struct fown_struct___60 {
	rwlock_t lock;
	struct pid___60 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___72 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___71 f_path;
	struct inode___73 *f_inode;
	const struct file_operations___72 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___60 f_owner;
	const struct cred___68 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___71 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___71;

struct vm_operations_struct___71 {
	void (*open)(struct vm_area_struct___72 *);
	void (*close)(struct vm_area_struct___72 *);
	int (*split)(struct vm_area_struct___72 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___72 *);
	vm_fault_t (*fault)(struct vm_fault___71 *);
	vm_fault_t (*huge_fault)(struct vm_fault___71 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___71 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___72 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___71 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___71 *);
	int (*access)(struct vm_area_struct___72 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___72 *);
	int (*set_policy)(struct vm_area_struct___72 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___72 *, long unsigned int);
	struct page___72 * (*find_special_page)(struct vm_area_struct___72 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___71 {
	struct task_struct___72 *task;
	struct core_thread___71 *next;
};

struct core_state___71 {
	atomic_t nr_threads;
	struct core_thread___71 dumper;
	struct completion startup;
};

struct key___69;

struct ucounts___58;

struct user_namespace___58 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___58 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common ns;
	long unsigned int flags;
	struct key___69 *persistent_keyring_register;
	struct rw_semaphore___72 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___58 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___71 {
	struct vm_area_struct___72 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___72 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___72 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___71 prealloc_pte;
};

struct upid___60 {
	int nr;
	struct pid_namespace___60 *ns;
};

struct pid_namespace___60 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___72 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___60 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___72 *proc_self;
	struct dentry___72 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___58 *user_ns;
	struct ucounts___58 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common ns;
};

struct pid___60 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___60 numbers[1];
};

struct sigevent {
	sigval_t sigev_value;
	int sigev_signo;
	int sigev_notify;
	union {
		int _pad[12];
		int _tid;
		struct {
			void (*_function)(sigval_t);
			void *_attribute;
		} _sigev_thread;
	} _sigev_un;
};

typedef struct sigevent sigevent_t;

struct user_struct___68;

struct sigqueue___4 {
	struct list_head list;
	int flags;
	kernel_siginfo_t info;
	struct user_struct___68 *user;
};

struct user_struct___68 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___69 *uid_keyring;
	struct key___69 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___68 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___69 *session_keyring;
	struct key___69 *process_keyring;
	struct key___69 *thread_keyring;
	struct key___69 *request_key_auth;
	void *security;
	struct user_struct___68 *user;
	struct user_namespace___58 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___56;

struct nsproxy___67 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___60 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___56 *cgroup_ns;
};

struct signal_struct___62 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___72 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___72 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___60 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___60 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___71 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___60 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___56;

struct cgroup___56;

struct css_set___56 {
	struct cgroup_subsys_state___56 *subsys[13];
	refcount_t refcount;
	struct css_set___56 *dom_cset;
	struct cgroup___56 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___56 *mg_src_cgrp;
	struct cgroup___56 *mg_dst_cgrp;
	struct css_set___56 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___45 {
	struct pmu___45 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___72 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___45 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

union thread_union___62 {
	struct task_struct___72 task;
	long unsigned int stack[8192];
};

struct kset___68;

struct kobj_type___68;

struct kernfs_node___69;

struct kobject___69 {
	const char *name;
	struct list_head entry;
	struct kobject___69 *parent;
	struct kset___68 *kset;
	struct kobj_type___68 *ktype;
	struct kernfs_node___69 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___66 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___66 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___66;

struct bus_type___66;

struct device_driver___66;

struct dev_pm_domain___66;

struct class___66;

struct attribute_group___66;

struct device___66 {
	struct device___66 *parent;
	struct device_private *p;
	struct kobject___69 kobj;
	const char *init_name;
	const struct device_type___66 *type;
	struct mutex mutex;
	struct bus_type___66 *bus;
	struct device_driver___66 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___66 power;
	struct dev_pm_domain___66 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___66 *class;
	const struct attribute_group___66 **groups;
	void (*release)(struct device___66 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___71;

struct super_block___72;

struct dentry___72 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___72 *d_parent;
	struct qstr d_name;
	struct inode___73 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___71 *d_op;
	struct super_block___72 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___71;

struct block_device___72;

struct cdev___19;

struct inode___73 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___71 *i_op;
	struct super_block___72 *i_sb;
	struct address_space___71 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___72 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___72 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___71 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___72 *i_bdev;
		struct cdev___19 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___71 {
	int (*d_revalidate)(struct dentry___72 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___72 *, unsigned int);
	int (*d_hash)(const struct dentry___72 *, struct qstr *);
	int (*d_compare)(const struct dentry___72 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___72 *);
	int (*d_init)(struct dentry___72 *);
	void (*d_release)(struct dentry___72 *);
	void (*d_prune)(struct dentry___72 *);
	void (*d_iput)(struct dentry___72 *, struct inode___73 *);
	char * (*d_dname)(struct dentry___72 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___71 *);
	int (*d_manage)(const struct path___71 *, bool);
	struct dentry___72 * (*d_real)(struct dentry___72 *, const struct inode___73 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___71;

struct mem_dqinfo___71 {
	struct quota_format_type___71 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___71;

struct quota_info___71 {
	unsigned int flags;
	struct rw_semaphore___72 dqio_sem;
	struct inode___73 *files[3];
	struct mem_dqinfo___71 info[3];
	const struct quota_format_ops___71 *ops[3];
};

struct rcuwait___71 {
	struct task_struct___72 *task;
};

struct percpu_rw_semaphore___71 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___72 rw_sem;
	struct rcuwait___71 writer;
	int readers_block;
};

struct sb_writers___71 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___71 rw_sem[3];
};

struct file_system_type___71;

struct super_operations___71;

struct dquot_operations___71;

struct quotactl_ops___71;

struct super_block___72 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___71 *s_type;
	const struct super_operations___71 *s_op;
	const struct dquot_operations___71 *dq_op;
	const struct quotactl_ops___71 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___72 *s_root;
	struct rw_semaphore___72 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___72 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___71 s_dquot;
	struct sb_writers___71 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___71 *s_d_op;
	int cleancache_poolid;
	struct shrinker___29 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___58 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___72 {
	struct file___72 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___72 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___72 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___72 *ia_file;
};

struct dquot___71 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___72 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___71 {
	int qf_fmt_id;
	const struct quota_format_ops___71 *qf_ops;
	struct module___64 *qf_owner;
	struct quota_format_type___71 *qf_next;
};

struct quota_format_ops___71 {
	int (*check_quota_file)(struct super_block___72 *, int);
	int (*read_file_info)(struct super_block___72 *, int);
	int (*write_file_info)(struct super_block___72 *, int);
	int (*free_file_info)(struct super_block___72 *, int);
	int (*read_dqblk)(struct dquot___71 *);
	int (*commit_dqblk)(struct dquot___71 *);
	int (*release_dqblk)(struct dquot___71 *);
	int (*get_next_id)(struct super_block___72 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___71 {
	int (*write_dquot)(struct dquot___71 *);
	struct dquot___71 * (*alloc_dquot)(struct super_block___72 *, int);
	void (*destroy_dquot)(struct dquot___71 *);
	int (*acquire_dquot)(struct dquot___71 *);
	int (*release_dquot)(struct dquot___71 *);
	int (*mark_dirty)(struct dquot___71 *);
	int (*write_info)(struct super_block___72 *, int);
	qsize_t * (*get_reserved_space)(struct inode___73 *);
	int (*get_projid)(struct inode___73 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___73 *, qsize_t *);
	int (*get_next_id)(struct super_block___72 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___71 {
	int (*quota_on)(struct super_block___72 *, int, int, const struct path___71 *);
	int (*quota_off)(struct super_block___72 *, int);
	int (*quota_enable)(struct super_block___72 *, unsigned int);
	int (*quota_disable)(struct super_block___72 *, unsigned int);
	int (*quota_sync)(struct super_block___72 *, int);
	int (*set_info)(struct super_block___72 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___72 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___72 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___72 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___72 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___72 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___61 {
	struct kobject___69 kobj;
	struct module___64 *mod;
	struct kobject___69 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___61 {
	struct module___64 *mod;
	struct latch_tree_node node;
};

struct module_layout___61 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___61 mtn;
};

struct module_attribute___61;

struct kernel_param___61;

struct module___64 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___61 mkobj;
	struct module_attribute___61 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___69 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___61 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___61 core_layout;
	struct module_layout___61 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___40 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___71 {
	int (*writepage)(struct page___72 *, struct writeback_control___3 *);
	int (*readpage)(struct file___72 *, struct page___72 *);
	int (*writepages)(struct address_space___71 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___72 *);
	int (*readpages)(struct file___72 *, struct address_space___71 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___72 *, struct address_space___71 *, loff_t, unsigned int, unsigned int, struct page___72 **, void **);
	int (*write_end)(struct file___72 *, struct address_space___71 *, loff_t, unsigned int, unsigned int, struct page___72 *, void *);
	sector_t (*bmap)(struct address_space___71 *, sector_t);
	void (*invalidatepage)(struct page___72 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___72 *, gfp_t);
	void (*freepage)(struct page___72 *);
	ssize_t (*direct_IO)(struct kiocb___72 *, struct iov_iter___29 *);
	int (*migratepage)(struct address_space___71 *, struct page___72 *, struct page___72 *, enum migrate_mode);
	bool (*isolate_page)(struct page___72 *, isolate_mode_t);
	void (*putback_page)(struct page___72 *);
	int (*launder_page)(struct page___72 *);
	int (*is_partially_uptodate)(struct page___72 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___72 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___71 *, struct page___72 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___72 *, sector_t *);
	void (*swap_deactivate)(struct file___72 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___72 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___73 *bd_inode;
	struct super_block___72 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___72 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___19 {
	struct kobject___69 kobj;
	struct module___64 *owner;
	const struct file_operations___72 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___71 {
	struct dentry___72 * (*lookup)(struct inode___73 *, struct dentry___72 *, unsigned int);
	const char * (*get_link)(struct dentry___72 *, struct inode___73 *, struct delayed_call *);
	int (*permission)(struct inode___73 *, int);
	struct posix_acl * (*get_acl)(struct inode___73 *, int);
	int (*readlink)(struct dentry___72 *, char *, int);
	int (*create)(struct inode___73 *, struct dentry___72 *, umode_t, bool);
	int (*link)(struct dentry___72 *, struct inode___73 *, struct dentry___72 *);
	int (*unlink)(struct inode___73 *, struct dentry___72 *);
	int (*symlink)(struct inode___73 *, struct dentry___72 *, const char *);
	int (*mkdir)(struct inode___73 *, struct dentry___72 *, umode_t);
	int (*rmdir)(struct inode___73 *, struct dentry___72 *);
	int (*mknod)(struct inode___73 *, struct dentry___72 *, umode_t, dev_t);
	int (*rename)(struct inode___73 *, struct dentry___72 *, struct inode___73 *, struct dentry___72 *, unsigned int);
	int (*setattr)(struct dentry___72 *, struct iattr___72 *);
	int (*getattr)(const struct path___71 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___72 *, char *, size_t);
	int (*fiemap)(struct inode___73 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___73 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___73 *, struct dentry___72 *, struct file___72 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___73 *, struct dentry___72 *, umode_t);
	int (*set_acl)(struct inode___73 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___71 {
	void (*fl_copy_lock)(struct file_lock___72 *, struct file_lock___72 *);
	void (*fl_release_private)(struct file_lock___72 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___71;

struct file_lock___72 {
	struct file_lock___72 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___72 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___71 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___71 *fl_ops;
	const struct lock_manager_operations___71 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___71 {
	int (*lm_compare_owner)(struct file_lock___72 *, struct file_lock___72 *);
	long unsigned int (*lm_owner_key)(struct file_lock___72 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___72 *);
	int (*lm_grant)(struct file_lock___72 *, int);
	bool (*lm_break)(struct file_lock___72 *);
	int (*lm_change)(struct file_lock___72 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___72 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___71 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___71 *fa_next;
	struct file___72 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___71 {
	const char *name;
	int fs_flags;
	struct dentry___72 * (*mount)(struct file_system_type___71 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___72 *);
	struct module___64 *owner;
	struct file_system_type___71 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___71 {
	struct inode___73 * (*alloc_inode)(struct super_block___72 *);
	void (*destroy_inode)(struct inode___73 *);
	void (*dirty_inode)(struct inode___73 *, int);
	int (*write_inode)(struct inode___73 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___73 *);
	void (*evict_inode)(struct inode___73 *);
	void (*put_super)(struct super_block___72 *);
	int (*sync_fs)(struct super_block___72 *, int);
	int (*freeze_super)(struct super_block___72 *);
	int (*freeze_fs)(struct super_block___72 *);
	int (*thaw_super)(struct super_block___72 *);
	int (*unfreeze_fs)(struct super_block___72 *);
	int (*statfs)(struct dentry___72 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___72 *, int *, char *);
	void (*umount_begin)(struct super_block___72 *);
	int (*show_options)(struct seq_file___66 *, struct dentry___72 *);
	int (*show_devname)(struct seq_file___66 *, struct dentry___72 *);
	int (*show_path)(struct seq_file___66 *, struct dentry___72 *);
	int (*show_stats)(struct seq_file___66 *, struct dentry___72 *);
	ssize_t (*quota_read)(struct super_block___72 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___72 *, int, const char *, size_t, loff_t);
	struct dquot___71 ** (*get_dquots)(struct inode___73 *);
	int (*bdev_try_to_free_page)(struct super_block___72 *, struct page___72 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___72 *, struct shrink_control___29 *);
	long int (*free_cached_objects)(struct super_block___72 *, struct shrink_control___29 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___46)(struct file___72 *, wait_queue_head_t *, struct poll_table_struct___47 *);

struct poll_table_struct___47 {
	poll_queue_proc___46 _qproc;
	__poll_t _key;
};

struct seq_operations___63;

struct seq_file___66 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___63 *op;
	int poll_event;
	const struct file___72 *file;
	void *private;
};

struct kobj_attribute___69 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___69 *, struct kobj_attribute___69 *, char *);
	ssize_t (*store)(struct kobject___69 *, struct kobj_attribute___69 *, const char *, size_t);
};

typedef void compound_page_dtor___71(struct page___72 *);

struct kernfs_root___69;

struct kernfs_elem_dir___69 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___69 *root;
};

struct kernfs_syscall_ops___69;

struct kernfs_root___69 {
	struct kernfs_node___69 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___69 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___69 {
	struct kernfs_node___69 *target_kn;
};

struct kernfs_ops___69;

struct kernfs_elem_attr___69 {
	const struct kernfs_ops___69 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___69 *notify_next;
};

struct kernfs_node___69 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___69 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___69 dir;
		struct kernfs_elem_symlink___69 symlink;
		struct kernfs_elem_attr___69 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___69;

struct kernfs_ops___69 {
	int (*open)(struct kernfs_open_file___69 *);
	void (*release)(struct kernfs_open_file___69 *);
	int (*seq_show)(struct seq_file___66 *, void *);
	void * (*seq_start)(struct seq_file___66 *, loff_t *);
	void * (*seq_next)(struct seq_file___66 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___66 *, void *);
	ssize_t (*read)(struct kernfs_open_file___69 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___69 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___69 *, struct vm_area_struct___72 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___69 *, struct poll_table_struct___47 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___69 {
	int (*remount_fs)(struct kernfs_root___69 *, int *, char *);
	int (*show_options)(struct seq_file___66 *, struct kernfs_root___69 *);
	int (*mkdir)(struct kernfs_node___69 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___69 *);
	int (*rename)(struct kernfs_node___69 *, struct kernfs_node___69 *, const char *);
	int (*show_path)(struct seq_file___66 *, struct kernfs_node___69 *, struct kernfs_root___69 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___69 {
	struct kernfs_node___69 *kn;
	struct file___72 *file;
	struct seq_file___66 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___71 *vm_ops;
};

struct bin_attribute___66;

struct attribute_group___66 {
	const char *name;
	umode_t (*is_visible)(struct kobject___69 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___69 *, struct bin_attribute___66 *, int);
	struct attribute **attrs;
	struct bin_attribute___66 **bin_attrs;
};

struct bin_attribute___66 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___72 *, struct kobject___69 *, struct bin_attribute___66 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___72 *, struct kobject___69 *, struct bin_attribute___66 *, char *, loff_t, size_t);
	int (*mmap)(struct file___72 *, struct kobject___69 *, struct bin_attribute___66 *, struct vm_area_struct___72 *);
};

struct sysfs_ops___68 {
	ssize_t (*show)(struct kobject___69 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___69 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___68;

struct kset___68 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___69 kobj;
	const struct kset_uevent_ops___68 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___68 {
	void (*release)(struct kobject___69 *);
	const struct sysfs_ops___68 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___69 *);
	const void * (*namespace)(struct kobject___69 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___68 {
	int (* const filter)(struct kset___68 *, struct kobject___69 *);
	const char * (* const name)(struct kset___68 *, struct kobject___69 *);
	int (* const uevent)(struct kset___68 *, struct kobject___69 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___66 {
	int (*prepare)(struct device___66 *);
	void (*complete)(struct device___66 *);
	int (*suspend)(struct device___66 *);
	int (*resume)(struct device___66 *);
	int (*freeze)(struct device___66 *);
	int (*thaw)(struct device___66 *);
	int (*poweroff)(struct device___66 *);
	int (*restore)(struct device___66 *);
	int (*suspend_late)(struct device___66 *);
	int (*resume_early)(struct device___66 *);
	int (*freeze_late)(struct device___66 *);
	int (*thaw_early)(struct device___66 *);
	int (*poweroff_late)(struct device___66 *);
	int (*restore_early)(struct device___66 *);
	int (*suspend_noirq)(struct device___66 *);
	int (*resume_noirq)(struct device___66 *);
	int (*freeze_noirq)(struct device___66 *);
	int (*thaw_noirq)(struct device___66 *);
	int (*poweroff_noirq)(struct device___66 *);
	int (*restore_noirq)(struct device___66 *);
	int (*runtime_suspend)(struct device___66 *);
	int (*runtime_resume)(struct device___66 *);
	int (*runtime_idle)(struct device___66 *);
};

struct dev_pm_domain___66 {
	struct dev_pm_ops___66 ops;
	void (*detach)(struct device___66 *, bool);
	int (*activate)(struct device___66 *);
	void (*sync)(struct device___66 *);
	void (*dismiss)(struct device___66 *);
};

struct bus_type___66 {
	const char *name;
	const char *dev_name;
	struct device___66 *dev_root;
	const struct attribute_group___66 **bus_groups;
	const struct attribute_group___66 **dev_groups;
	const struct attribute_group___66 **drv_groups;
	int (*match)(struct device___66 *, struct device_driver___66 *);
	int (*uevent)(struct device___66 *, struct kobj_uevent_env *);
	int (*probe)(struct device___66 *);
	int (*remove)(struct device___66 *);
	void (*shutdown)(struct device___66 *);
	int (*online)(struct device___66 *);
	int (*offline)(struct device___66 *);
	int (*suspend)(struct device___66 *, pm_message_t);
	int (*resume)(struct device___66 *);
	int (*num_vf)(struct device___66 *);
	int (*dma_configure)(struct device___66 *);
	const struct dev_pm_ops___66 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___66 {
	const char *name;
	struct bus_type___66 *bus;
	struct module___64 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___66 *);
	int (*remove)(struct device___66 *);
	void (*shutdown)(struct device___66 *);
	int (*suspend)(struct device___66 *, pm_message_t);
	int (*resume)(struct device___66 *);
	const struct attribute_group___66 **groups;
	const struct dev_pm_ops___66 *pm;
	void (*coredump)(struct device___66 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___66 {
	const char *name;
	const struct attribute_group___66 **groups;
	int (*uevent)(struct device___66 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___66 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___66 *);
	const struct dev_pm_ops___66 *pm;
};

struct class___66 {
	const char *name;
	struct module___64 *owner;
	const struct attribute_group___66 **class_groups;
	const struct attribute_group___66 **dev_groups;
	struct kobject___69 *dev_kobj;
	int (*dev_uevent)(struct device___66 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___66 *, umode_t *);
	void (*class_release)(struct class___66 *);
	void (*dev_release)(struct device___66 *);
	int (*shutdown_pre)(struct device___66 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___66 *);
	const struct dev_pm_ops___66 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

typedef int (*key_restrict_link_func_t___68)(struct key___69 *, const struct key_type *, const union key_payload *, struct key___69 *);

struct key_restriction___69;

struct key___69 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___72 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___69 *restrict_link;
};

struct key_restriction___69 {
	key_restrict_link_func_t___68 check;
	struct key___69 *key;
	struct key_type *keytype;
};

struct seq_operations___63 {
	void * (*start)(struct seq_file___66 *, loff_t *);
	void (*stop)(struct seq_file___66 *, void *);
	void * (*next)(struct seq_file___66 *, void *, loff_t *);
	int (*show)(struct seq_file___66 *, void *);
};

struct cpu_timer_list___2 {
	struct list_head entry;
	u64 expires;
	u64 incr;
	struct task_struct___72 *task;
	int firing;
};

struct k_clock___2;

struct k_itimer___2 {
	struct list_head list;
	struct hlist_node t_hash;
	spinlock_t it_lock;
	const struct k_clock___2 *kclock;
	clockid_t it_clock;
	timer_t it_id;
	int it_active;
	s64 it_overrun;
	s64 it_overrun_last;
	int it_requeue_pending;
	int it_sigev_notify;
	ktime_t it_interval;
	struct signal_struct___62 *it_signal;
	union {
		struct pid___60 *it_pid;
		struct task_struct___72 *it_process;
	};
	struct sigqueue___4 *sigq;
	union {
		struct {
			struct hrtimer timer;
		} real;
		struct cpu_timer_list___2 cpu;
		struct {
			struct alarm alarmtimer;
		} alarm;
		struct callback_head rcu;
	} it;
};

struct k_clock___2 {
	int (*clock_getres)(const clockid_t, struct timespec64 *);
	int (*clock_set)(const clockid_t, const struct timespec64 *);
	int (*clock_get)(const clockid_t, struct timespec64 *);
	int (*clock_adj)(const clockid_t, struct timex *);
	int (*timer_create)(struct k_itimer___2 *);
	int (*nsleep)(const clockid_t, int, const struct timespec64 *);
	int (*timer_set)(struct k_itimer___2 *, int, struct itimerspec64 *, struct itimerspec64 *);
	int (*timer_del)(struct k_itimer___2 *);
	void (*timer_get)(struct k_itimer___2 *, struct itimerspec64 *);
	void (*timer_rearm)(struct k_itimer___2 *);
	s64 (*timer_forward)(struct k_itimer___2 *, ktime_t);
	ktime_t (*timer_remaining)(struct k_itimer___2 *, ktime_t);
	int (*timer_try_to_cancel)(struct k_itimer___2 *);
	void (*timer_arm)(struct k_itimer___2 *, ktime_t, bool, bool);
};

struct cgroup_namespace___56 {
	refcount_t count;
	struct ns_common ns;
	struct user_namespace___58 *user_ns;
	struct ucounts___58 *ucounts;
	struct css_set___56 *root_cset;
};

struct ucounts___58 {
	struct hlist_node node;
	struct user_namespace___58 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct kernel_param_ops___61 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___61 *);
	int (*get)(char *, const struct kernel_param___61 *);
	void (*free)(void *);
};

struct kparam_array___61;

struct kernel_param___61 {
	const char *name;
	struct module___64 *mod;
	const struct kernel_param_ops___61 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___61 *arr;
	};
};

struct kparam_array___61 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___61 *ops;
	void *elem;
};

struct module_attribute___61 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___61 *, struct module_kobject___61 *, char *);
	ssize_t (*store)(struct module_attribute___61 *, struct module_kobject___61 *, const char *, size_t);
	void (*setup)(struct module___64 *, const char *);
	int (*test)(struct module___64 *);
	void (*free)(struct module___64 *);
};

struct trace_event_class___40;

struct trace_event_call___40 {
	struct list_head list;
	struct trace_event_class___40 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array *prog_array;
	int (*perf_perm)(struct trace_event_call___40 *, struct perf_event___45 *);
};

struct node___58 {
	struct device___66 dev;
};

struct bpf_map___56;

struct bpf_map_ops___56 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___56 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___56 *, struct file___72 *);
	void (*map_free)(struct bpf_map___56 *);
	int (*map_get_next_key)(struct bpf_map___56 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___56 *);
	void * (*map_lookup_elem)(struct bpf_map___56 *, void *);
	int (*map_update_elem)(struct bpf_map___56 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___56 *, void *);
	int (*map_push_elem)(struct bpf_map___56 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___56 *, void *);
	int (*map_peek_elem)(struct bpf_map___56 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___56 *, struct file___72 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___56 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___56 *, void *, struct seq_file___66 *);
	int (*map_check_btf)(const struct bpf_map___56 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___56 {
	const struct bpf_map_ops___56 *ops;
	struct bpf_map___56 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___68 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___56;

typedef void (*kthread_work_func_t___56)(struct kthread_work___56 *);

struct kthread_worker___56;

struct kthread_work___56 {
	struct list_head node;
	kthread_work_func_t___56 func;
	struct kthread_worker___56 *worker;
	int canceling;
};

struct kthread_worker___56 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___72 *task;
	struct kthread_work___56 *current_work;
};

struct kthread_delayed_work___56 {
	struct kthread_work___56 work;
	struct timer_list timer;
};

struct psi_group___56 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___56 *poll_kworker;
	struct kthread_delayed_work___56 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___56 {
	struct kernfs_node___69 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___56;

struct cgroup_subsys_state___56 {
	struct cgroup___56 *cgroup;
	struct cgroup_subsys___56 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___56 *parent;
};

struct cgroup_root___56;

struct cgroup_rstat_cpu___56;

struct cgroup___56 {
	struct cgroup_subsys_state___56 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___69 *kn;
	struct cgroup_file___56 procs_file;
	struct cgroup_file___56 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___56 *subsys[13];
	struct cgroup_root___56 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___56 *dom_cgrp;
	struct cgroup_rstat_cpu___56 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf bpf;
	atomic_t congestion_count;
	struct cgroup___56 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___56 psi;
	int ancestor_ids[0];
};

struct cftype___56;

struct cgroup_subsys___56 {
	struct cgroup_subsys_state___56 * (*css_alloc)(struct cgroup_subsys_state___56 *);
	int (*css_online)(struct cgroup_subsys_state___56 *);
	void (*css_offline)(struct cgroup_subsys_state___56 *);
	void (*css_released)(struct cgroup_subsys_state___56 *);
	void (*css_free)(struct cgroup_subsys_state___56 *);
	void (*css_reset)(struct cgroup_subsys_state___56 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___56 *, int);
	int (*css_extra_stat_show)(struct seq_file___66 *, struct cgroup_subsys_state___56 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___72 *);
	void (*cancel_fork)(struct task_struct___72 *);
	void (*fork)(struct task_struct___72 *);
	void (*exit)(struct task_struct___72 *);
	void (*free)(struct task_struct___72 *);
	void (*bind)(struct cgroup_subsys_state___56 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___56 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___56 *dfl_cftypes;
	struct cftype___56 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___56 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___56 *updated_children;
	struct cgroup___56 *updated_next;
};

struct cgroup_root___56 {
	struct kernfs_root___69 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___56 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___56 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___56 *ss;
	struct list_head node;
	struct kernfs_ops___69 *kf_ops;
	int (*open)(struct kernfs_open_file___69 *);
	void (*release)(struct kernfs_open_file___69 *);
	u64 (*read_u64)(struct cgroup_subsys_state___56 *, struct cftype___56 *);
	s64 (*read_s64)(struct cgroup_subsys_state___56 *, struct cftype___56 *);
	int (*seq_show)(struct seq_file___66 *, void *);
	void * (*seq_start)(struct seq_file___66 *, loff_t *);
	void * (*seq_next)(struct seq_file___66 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___66 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___56 *, struct cftype___56 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___56 *, struct cftype___56 *, s64);
	ssize_t (*write)(struct kernfs_open_file___69 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___69 *, struct poll_table_struct___47 *);
};

struct perf_cpu_context___45;

struct pmu___45 {
	struct list_head entry;
	struct module___64 *module;
	struct device___66 *dev;
	const struct attribute_group___66 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___45 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___45 *);
	void (*pmu_disable)(struct pmu___45 *);
	int (*event_init)(struct perf_event___45 *);
	void (*event_mapped)(struct perf_event___45 *, struct mm_struct___71 *);
	void (*event_unmapped)(struct perf_event___45 *, struct mm_struct___71 *);
	int (*add)(struct perf_event___45 *, int);
	void (*del)(struct perf_event___45 *, int);
	void (*start)(struct perf_event___45 *, int);
	void (*stop)(struct perf_event___45 *, int);
	void (*read)(struct perf_event___45 *);
	void (*start_txn)(struct pmu___45 *, unsigned int);
	int (*commit_txn)(struct pmu___45 *);
	void (*cancel_txn)(struct pmu___45 *);
	int (*event_idx)(struct perf_event___45 *);
	void (*sched_task)(struct perf_event_context___45 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___45 *);
	int (*filter_match)(struct perf_event___45 *);
	int (*check_period)(struct perf_event___45 *, u64);
};

struct perf_cpu_context___45 {
	struct perf_event_context___45 ctx;
	struct perf_event_context___45 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___45 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___45 {
	struct cgroup_subsys_state___56 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___40 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___40 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___40 *);
	struct list_head * (*get_fields)(struct trace_event_call___40 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___40 *);
};

struct syscall_metadata___17 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___40 *enter_event;
	struct trace_event_call___40 *exit_event;
};

struct device___67;

struct dev_pm_info___67 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___67 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___67;

struct bus_type___67;

struct device_driver___67;

struct dev_pm_domain___67;

struct device_node___24;

struct fwnode_handle___50;

struct class___67;

struct device___67 {
	struct device___67 *parent;
	struct device_private *p;
	struct kobject___30 kobj;
	const char *init_name;
	const struct device_type___67 *type;
	struct mutex mutex;
	struct bus_type___67 *bus;
	struct device_driver___67 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___67 power;
	struct dev_pm_domain___67 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___24 *of_node;
	struct fwnode_handle___50 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___67 *class;
	const struct attribute_group___27 **groups;
	void (*release)(struct device___67 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_ops___67 {
	int (*prepare)(struct device___67 *);
	void (*complete)(struct device___67 *);
	int (*suspend)(struct device___67 *);
	int (*resume)(struct device___67 *);
	int (*freeze)(struct device___67 *);
	int (*thaw)(struct device___67 *);
	int (*poweroff)(struct device___67 *);
	int (*restore)(struct device___67 *);
	int (*suspend_late)(struct device___67 *);
	int (*resume_early)(struct device___67 *);
	int (*freeze_late)(struct device___67 *);
	int (*thaw_early)(struct device___67 *);
	int (*poweroff_late)(struct device___67 *);
	int (*restore_early)(struct device___67 *);
	int (*suspend_noirq)(struct device___67 *);
	int (*resume_noirq)(struct device___67 *);
	int (*freeze_noirq)(struct device___67 *);
	int (*thaw_noirq)(struct device___67 *);
	int (*poweroff_noirq)(struct device___67 *);
	int (*restore_noirq)(struct device___67 *);
	int (*runtime_suspend)(struct device___67 *);
	int (*runtime_resume)(struct device___67 *);
	int (*runtime_idle)(struct device___67 *);
};

struct dev_pm_domain___67 {
	struct dev_pm_ops___67 ops;
	void (*detach)(struct device___67 *, bool);
	int (*activate)(struct device___67 *);
	void (*sync)(struct device___67 *);
	void (*dismiss)(struct device___67 *);
};

struct bus_type___67 {
	const char *name;
	const char *dev_name;
	struct device___67 *dev_root;
	const struct attribute_group___27 **bus_groups;
	const struct attribute_group___27 **dev_groups;
	const struct attribute_group___27 **drv_groups;
	int (*match)(struct device___67 *, struct device_driver___67 *);
	int (*uevent)(struct device___67 *, struct kobj_uevent_env *);
	int (*probe)(struct device___67 *);
	int (*remove)(struct device___67 *);
	void (*shutdown)(struct device___67 *);
	int (*online)(struct device___67 *);
	int (*offline)(struct device___67 *);
	int (*suspend)(struct device___67 *, pm_message_t);
	int (*resume)(struct device___67 *);
	int (*num_vf)(struct device___67 *);
	int (*dma_configure)(struct device___67 *);
	const struct dev_pm_ops___67 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___67 {
	const char *name;
	struct bus_type___67 *bus;
	struct module___11 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___67 *);
	int (*remove)(struct device___67 *);
	void (*shutdown)(struct device___67 *);
	int (*suspend)(struct device___67 *, pm_message_t);
	int (*resume)(struct device___67 *);
	const struct attribute_group___27 **groups;
	const struct dev_pm_ops___67 *pm;
	void (*coredump)(struct device___67 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___67 {
	const char *name;
	const struct attribute_group___27 **groups;
	int (*uevent)(struct device___67 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___67 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___67 *);
	const struct dev_pm_ops___67 *pm;
};

struct class___67 {
	const char *name;
	struct module___11 *owner;
	const struct attribute_group___27 **class_groups;
	const struct attribute_group___27 **dev_groups;
	struct kobject___30 *dev_kobj;
	int (*dev_uevent)(struct device___67 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___67 *, umode_t *);
	void (*class_release)(struct class___67 *);
	void (*dev_release)(struct device___67 *);
	int (*shutdown_pre)(struct device___67 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___67 *);
	const struct dev_pm_ops___67 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct fwnode_operations___50;

struct fwnode_handle___50 {
	struct fwnode_handle___50 *secondary;
	const struct fwnode_operations___50 *ops;
};

struct property___23;

struct device_node___24 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___50 fwnode;
	struct property___23 *properties;
	struct property___23 *deadprops;
	struct device_node___24 *parent;
	struct device_node___24 *child;
	struct device_node___24 *sibling;
	struct kobject___30 kobj;
	long unsigned int _flags;
	void *data;
};

struct cpu_timer_list___3 {
	struct list_head entry;
	u64 expires;
	u64 incr;
	struct task_struct___33 *task;
	int firing;
};

struct k_clock___3;

struct k_itimer___3 {
	struct list_head list;
	struct hlist_node t_hash;
	spinlock_t it_lock;
	const struct k_clock___3 *kclock;
	clockid_t it_clock;
	timer_t it_id;
	int it_active;
	s64 it_overrun;
	s64 it_overrun_last;
	int it_requeue_pending;
	int it_sigev_notify;
	ktime_t it_interval;
	struct signal_struct___29 *it_signal;
	union {
		struct pid___27 *it_pid;
		struct task_struct___33 *it_process;
	};
	struct sigqueue___2 *sigq;
	union {
		struct {
			struct hrtimer timer;
		} real;
		struct cpu_timer_list___3 cpu;
		struct {
			struct alarm alarmtimer;
		} alarm;
		struct callback_head rcu;
	} it;
};

struct k_clock___3 {
	int (*clock_getres)(const clockid_t, struct timespec64 *);
	int (*clock_set)(const clockid_t, const struct timespec64 *);
	int (*clock_get)(const clockid_t, struct timespec64 *);
	int (*clock_adj)(const clockid_t, struct timex *);
	int (*timer_create)(struct k_itimer___3 *);
	int (*nsleep)(const clockid_t, int, const struct timespec64 *);
	int (*timer_set)(struct k_itimer___3 *, int, struct itimerspec64 *, struct itimerspec64 *);
	int (*timer_del)(struct k_itimer___3 *);
	void (*timer_get)(struct k_itimer___3 *, struct itimerspec64 *);
	void (*timer_rearm)(struct k_itimer___3 *);
	s64 (*timer_forward)(struct k_itimer___3 *, ktime_t);
	ktime_t (*timer_remaining)(struct k_itimer___3 *, ktime_t);
	int (*timer_try_to_cancel)(struct k_itimer___3 *);
	void (*timer_arm)(struct k_itimer___3 *, ktime_t, bool, bool);
};

struct fwnode_reference_args___50;

struct fwnode_endpoint___50;

struct fwnode_operations___50 {
	struct fwnode_handle___50 * (*get)(struct fwnode_handle___50 *);
	void (*put)(struct fwnode_handle___50 *);
	bool (*device_is_available)(const struct fwnode_handle___50 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___50 *, const struct device___67 *);
	bool (*property_present)(const struct fwnode_handle___50 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___50 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___50 *, const char *, const char **, size_t);
	struct fwnode_handle___50 * (*get_parent)(const struct fwnode_handle___50 *);
	struct fwnode_handle___50 * (*get_next_child_node)(const struct fwnode_handle___50 *, struct fwnode_handle___50 *);
	struct fwnode_handle___50 * (*get_named_child_node)(const struct fwnode_handle___50 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___50 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___50 *);
	struct fwnode_handle___50 * (*graph_get_next_endpoint)(const struct fwnode_handle___50 *, struct fwnode_handle___50 *);
	struct fwnode_handle___50 * (*graph_get_remote_endpoint)(const struct fwnode_handle___50 *);
	struct fwnode_handle___50 * (*graph_get_port_parent)(struct fwnode_handle___50 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___50 *, struct fwnode_endpoint___50 *);
};

struct fwnode_endpoint___50 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___50 *local_fwnode;
};

struct fwnode_reference_args___50 {
	struct fwnode_handle___50 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct property___23 {
	char *name;
	int length;
	void *value;
	struct property___23 *next;
	long unsigned int _flags;
	struct bin_attribute___27 attr;
};

typedef unsigned int uint;

struct module___65;

struct file___73;

struct kiocb___73;

struct poll_table_struct___48;

struct vm_area_struct___73;

struct inode___74;

struct file_lock___73;

struct page___73;

struct seq_file___67;

struct file_operations___73 {
	struct module___65 *owner;
	loff_t (*llseek)(struct file___73 *, loff_t, int);
	ssize_t (*read)(struct file___73 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___73 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___73 *, struct iov_iter___29 *);
	ssize_t (*write_iter)(struct kiocb___73 *, struct iov_iter___29 *);
	int (*iopoll)(struct kiocb___73 *, bool);
	int (*iterate)(struct file___73 *, struct dir_context *);
	int (*iterate_shared)(struct file___73 *, struct dir_context *);
	__poll_t (*poll)(struct file___73 *, struct poll_table_struct___48 *);
	long int (*unlocked_ioctl)(struct file___73 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___73 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___73 *, struct vm_area_struct___73 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___74 *, struct file___73 *);
	int (*flush)(struct file___73 *, fl_owner_t);
	int (*release)(struct inode___74 *, struct file___73 *);
	int (*fsync)(struct file___73 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___73 *, int);
	int (*lock)(struct file___73 *, int, struct file_lock___73 *);
	ssize_t (*sendpage)(struct file___73 *, struct page___73 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___73 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___73 *, int, struct file_lock___73 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___73 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___73 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___73 *, long int, struct file_lock___73 **, void **);
	long int (*fallocate)(struct file___73 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___67 *, struct file___73 *);
	ssize_t (*copy_file_range)(struct file___73 *, loff_t, struct file___73 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___73 *, loff_t, struct file___73 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___73 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct perf_event___46;

struct debug_info___46 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___46 *hbp_break[16];
	struct perf_event___46 *hbp_watch[16];
};

struct task_struct___73;

struct hw_perf_event___46 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___73 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___46)(struct perf_event___46 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___46;

struct perf_event_context___46;

struct fasync_struct___72;

struct pid_namespace___61;

struct trace_event_call___41;

struct perf_cgroup___46;

struct perf_event___46 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___46 *group_leader;
	struct pmu___46 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___46 hw;
	struct perf_event_context___46 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___46 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___73 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___72 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___46 *);
	struct callback_head callback_head;
	struct pid_namespace___61 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___46 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___46 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___41 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___46 *cgrp;
	struct list_head sb_list;
};

struct thread_struct___46 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___46 debug;
	long: 64;
};

struct vmacache___72 {
	u64 seqnum;
	struct vm_area_struct___73 *vmas[4];
};

struct page_frag___72 {
	struct page___73 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___72;

struct pid___61;

struct cred___69;

struct nsproxy___68;

struct signal_struct___63;

struct css_set___57;

struct task_struct___73 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___73 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___72 *mm;
	struct mm_struct___72 *active_mm;
	struct vmacache___72 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___73 *real_parent;
	struct task_struct___73 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___73 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___61 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___61 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___61 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___69 *ptracer_cred;
	const struct cred___69 *real_cred;
	const struct cred___69 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___68 *nsproxy;
	struct signal_struct___63 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___73 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___13 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___57 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___46 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___72 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___73 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___46 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___73 *pgtable_t___72;

struct address_space___72;

struct dev_pagemap___72;

struct page___73 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___72 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___73 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___72 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___72 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___72 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___72;

struct lruvec___72 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___72 *pgdat;
};

struct zone___72 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___72 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___72 {
	struct zone___72 *zone;
	int zone_idx;
};

struct zonelist___72 {
	struct zoneref___72 _zonerefs[25];
};

struct pglist_data___72 {
	struct zone___72 node_zones[3];
	struct zonelist___72 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___73 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___73 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___72 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___73 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___73 *owner;
};

struct secondary_data___73 {
	void *stack;
	struct task_struct___73 *task;
	long int status;
};

struct blocking_notifier_head___72 {
	struct rw_semaphore___73 rwsem;
	struct notifier_block *head;
};

struct key___70;

struct ucounts___59;

struct user_namespace___59 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___59 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common ns;
	long unsigned int flags;
	struct key___70 *persistent_keyring_register;
	struct rw_semaphore___73 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___59 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_root___70;

struct kernfs_elem_dir___70 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___70 *root;
};

struct kernfs_node___70;

struct kernfs_syscall_ops___70;

struct kernfs_root___70 {
	struct kernfs_node___70 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___70 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___70 {
	struct kernfs_node___70 *target_kn;
};

struct kernfs_ops___70;

struct kernfs_elem_attr___70 {
	const struct kernfs_ops___70 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___70 *notify_next;
};

struct kernfs_node___70 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___70 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___70 dir;
		struct kernfs_elem_symlink___70 symlink;
		struct kernfs_elem_attr___70 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___70;

struct kernfs_ops___70 {
	int (*open)(struct kernfs_open_file___70 *);
	void (*release)(struct kernfs_open_file___70 *);
	int (*seq_show)(struct seq_file___67 *, void *);
	void * (*seq_start)(struct seq_file___67 *, loff_t *);
	void * (*seq_next)(struct seq_file___67 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___67 *, void *);
	ssize_t (*read)(struct kernfs_open_file___70 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___70 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___70 *, struct vm_area_struct___73 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___70 *, struct poll_table_struct___48 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___70 {
	int (*remount_fs)(struct kernfs_root___70 *, int *, char *);
	int (*show_options)(struct seq_file___67 *, struct kernfs_root___70 *);
	int (*mkdir)(struct kernfs_node___70 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___70 *);
	int (*rename)(struct kernfs_node___70 *, struct kernfs_node___70 *, const char *);
	int (*show_path)(struct seq_file___67 *, struct kernfs_node___70 *, struct kernfs_root___70 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___64;

struct seq_file___67 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___64 *op;
	int poll_event;
	const struct file___73 *file;
	void *private;
};

struct vm_operations_struct___72;

struct kernfs_open_file___70 {
	struct kernfs_node___70 *kn;
	struct file___73 *file;
	struct seq_file___67 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___72 *vm_ops;
};

struct dentry___73;

struct path___72 {
	struct vfsmount *mnt;
	struct dentry___73 *dentry;
};

struct fown_struct___61 {
	rwlock_t lock;
	struct pid___61 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___73 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___72 f_path;
	struct inode___74 *f_inode;
	const struct file_operations___73 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___61 f_owner;
	const struct cred___69 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___72 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___72;

struct vm_operations_struct___72 {
	void (*open)(struct vm_area_struct___73 *);
	void (*close)(struct vm_area_struct___73 *);
	int (*split)(struct vm_area_struct___73 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___73 *);
	vm_fault_t (*fault)(struct vm_fault___72 *);
	vm_fault_t (*huge_fault)(struct vm_fault___72 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___72 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___73 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___72 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___72 *);
	int (*access)(struct vm_area_struct___73 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___73 *);
	int (*set_policy)(struct vm_area_struct___73 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___73 *, long unsigned int);
	struct page___73 * (*find_special_page)(struct vm_area_struct___73 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___47)(struct file___73 *, wait_queue_head_t *, struct poll_table_struct___48 *);

struct poll_table_struct___48 {
	poll_queue_proc___47 _qproc;
	__poll_t _key;
};

struct vm_area_struct___73 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___73 *vm_next;
	struct vm_area_struct___73 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___72 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___72 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___73 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___70;

struct bin_attribute___67;

struct attribute_group___67 {
	const char *name;
	umode_t (*is_visible)(struct kobject___70 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___70 *, struct bin_attribute___67 *, int);
	struct attribute **attrs;
	struct bin_attribute___67 **bin_attrs;
};

struct kset___69;

struct kobj_type___69;

struct kobject___70 {
	const char *name;
	struct list_head entry;
	struct kobject___70 *parent;
	struct kset___69 *kset;
	struct kobj_type___69 *ktype;
	struct kernfs_node___70 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___67 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___73 *, struct kobject___70 *, struct bin_attribute___67 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___73 *, struct kobject___70 *, struct bin_attribute___67 *, char *, loff_t, size_t);
	int (*mmap)(struct file___73 *, struct kobject___70 *, struct bin_attribute___67 *, struct vm_area_struct___73 *);
};

struct sysfs_ops___69 {
	ssize_t (*show)(struct kobject___70 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___70 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___69;

struct kset___69 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___70 kobj;
	const struct kset_uevent_ops___69 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___69 {
	void (*release)(struct kobject___70 *);
	const struct sysfs_ops___69 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___70 *);
	const void * (*namespace)(struct kobject___70 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___69 {
	int (* const filter)(struct kset___69 *, struct kobject___70 *);
	const char * (* const name)(struct kset___69 *, struct kobject___70 *);
	int (* const uevent)(struct kset___69 *, struct kobject___70 *, struct kobj_uevent_env *);
};

struct kobj_attribute___70 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___70 *, struct kobj_attribute___70 *, char *);
	ssize_t (*store)(struct kobject___70 *, struct kobj_attribute___70 *, const char *, size_t);
};

struct device___68;

struct dev_pm_ops___68 {
	int (*prepare)(struct device___68 *);
	void (*complete)(struct device___68 *);
	int (*suspend)(struct device___68 *);
	int (*resume)(struct device___68 *);
	int (*freeze)(struct device___68 *);
	int (*thaw)(struct device___68 *);
	int (*poweroff)(struct device___68 *);
	int (*restore)(struct device___68 *);
	int (*suspend_late)(struct device___68 *);
	int (*resume_early)(struct device___68 *);
	int (*freeze_late)(struct device___68 *);
	int (*thaw_early)(struct device___68 *);
	int (*poweroff_late)(struct device___68 *);
	int (*restore_early)(struct device___68 *);
	int (*suspend_noirq)(struct device___68 *);
	int (*resume_noirq)(struct device___68 *);
	int (*freeze_noirq)(struct device___68 *);
	int (*thaw_noirq)(struct device___68 *);
	int (*poweroff_noirq)(struct device___68 *);
	int (*restore_noirq)(struct device___68 *);
	int (*runtime_suspend)(struct device___68 *);
	int (*runtime_resume)(struct device___68 *);
	int (*runtime_idle)(struct device___68 *);
};

struct dev_pm_info___68 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___68 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___68;

struct bus_type___68;

struct device_driver___68;

struct dev_pm_domain___68;

struct class___68;

struct device___68 {
	struct device___68 *parent;
	struct device_private *p;
	struct kobject___70 kobj;
	const char *init_name;
	const struct device_type___68 *type;
	struct mutex mutex;
	struct bus_type___68 *bus;
	struct device_driver___68 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___68 power;
	struct dev_pm_domain___68 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___68 *class;
	const struct attribute_group___67 **groups;
	void (*release)(struct device___68 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___68 {
	struct dev_pm_ops___68 ops;
	void (*detach)(struct device___68 *, bool);
	int (*activate)(struct device___68 *);
	void (*sync)(struct device___68 *);
	void (*dismiss)(struct device___68 *);
};

struct upid___61 {
	int nr;
	struct pid_namespace___61 *ns;
};

struct pid_namespace___61 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___73 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___61 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___73 *proc_self;
	struct dentry___73 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___59 *user_ns;
	struct ucounts___59 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common ns;
};

struct pid___61 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___61 numbers[1];
};

struct user_struct___69;

struct sigqueue___5 {
	struct list_head list;
	int flags;
	kernel_siginfo_t info;
	struct user_struct___69 *user;
};

struct user_struct___69 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___70 *uid_keyring;
	struct key___70 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___72;

struct mm_struct___72 {
	struct {
		struct vm_area_struct___73 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___73 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___73 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___72 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___73 *owner;
		struct user_namespace___59 *user_ns;
		struct file___73 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___72 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___69 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___70 *session_keyring;
	struct key___70 *process_keyring;
	struct key___70 *thread_keyring;
	struct key___70 *request_key_auth;
	void *security;
	struct user_struct___69 *user;
	struct user_namespace___59 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___57;

struct nsproxy___68 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___61 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___57 *cgroup_ns;
};

struct signal_struct___63 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___73 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___73 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___61 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___61 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___72 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___61 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___57;

struct cgroup___57;

struct css_set___57 {
	struct cgroup_subsys_state___57 *subsys[13];
	refcount_t refcount;
	struct css_set___57 *dom_cset;
	struct cgroup___57 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___57 *mg_src_cgrp;
	struct cgroup___57 *mg_dst_cgrp;
	struct css_set___57 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___46 {
	struct pmu___46 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___73 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___46 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

union thread_union___63 {
	struct task_struct___73 task;
	long unsigned int stack[8192];
};

struct bus_type___68 {
	const char *name;
	const char *dev_name;
	struct device___68 *dev_root;
	const struct attribute_group___67 **bus_groups;
	const struct attribute_group___67 **dev_groups;
	const struct attribute_group___67 **drv_groups;
	int (*match)(struct device___68 *, struct device_driver___68 *);
	int (*uevent)(struct device___68 *, struct kobj_uevent_env *);
	int (*probe)(struct device___68 *);
	int (*remove)(struct device___68 *);
	void (*shutdown)(struct device___68 *);
	int (*online)(struct device___68 *);
	int (*offline)(struct device___68 *);
	int (*suspend)(struct device___68 *, pm_message_t);
	int (*resume)(struct device___68 *);
	int (*num_vf)(struct device___68 *);
	int (*dma_configure)(struct device___68 *);
	const struct dev_pm_ops___68 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___68 {
	const char *name;
	struct bus_type___68 *bus;
	struct module___65 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___68 *);
	int (*remove)(struct device___68 *);
	void (*shutdown)(struct device___68 *);
	int (*suspend)(struct device___68 *, pm_message_t);
	int (*resume)(struct device___68 *);
	const struct attribute_group___67 **groups;
	const struct dev_pm_ops___68 *pm;
	void (*coredump)(struct device___68 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___68 {
	const char *name;
	const struct attribute_group___67 **groups;
	int (*uevent)(struct device___68 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___68 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___68 *);
	const struct dev_pm_ops___68 *pm;
};

struct module_kobject___62 {
	struct kobject___70 kobj;
	struct module___65 *mod;
	struct kobject___70 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___62 {
	struct module___65 *mod;
	struct latch_tree_node node;
};

struct module_layout___62 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___62 mtn;
};

struct module_attribute___62;

struct kernel_param___62;

struct module___65 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___62 mkobj;
	struct module_attribute___62 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___70 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___62 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___62 core_layout;
	struct module_layout___62 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___41 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct class___68 {
	const char *name;
	struct module___65 *owner;
	const struct attribute_group___67 **class_groups;
	const struct attribute_group___67 **dev_groups;
	struct kobject___70 *dev_kobj;
	int (*dev_uevent)(struct device___68 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___68 *, umode_t *);
	void (*class_release)(struct class___68 *);
	void (*dev_release)(struct device___68 *);
	int (*shutdown_pre)(struct device___68 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___68 *);
	const struct dev_pm_ops___68 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct cdev___20 {
	struct kobject___70 kobj;
	struct module___65 *owner;
	const struct file_operations___73 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct dentry_operations___72;

struct super_block___73;

struct dentry___73 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___73 *d_parent;
	struct qstr d_name;
	struct inode___74 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___72 *d_op;
	struct super_block___73 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___72;

struct address_space___72 {
	struct inode___74 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___73 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___72 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___72;

struct block_device___73;

struct inode___74 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___72 *i_op;
	struct super_block___73 *i_sb;
	struct address_space___72 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___73 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___73 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___72 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___73 *i_bdev;
		struct cdev___20 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___72 {
	int (*d_revalidate)(struct dentry___73 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___73 *, unsigned int);
	int (*d_hash)(const struct dentry___73 *, struct qstr *);
	int (*d_compare)(const struct dentry___73 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___73 *);
	int (*d_init)(struct dentry___73 *);
	void (*d_release)(struct dentry___73 *);
	void (*d_prune)(struct dentry___73 *);
	void (*d_iput)(struct dentry___73 *, struct inode___74 *);
	char * (*d_dname)(struct dentry___73 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___72 *);
	int (*d_manage)(const struct path___72 *, bool);
	struct dentry___73 * (*d_real)(struct dentry___73 *, const struct inode___74 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___72;

struct mem_dqinfo___72 {
	struct quota_format_type___72 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___72;

struct quota_info___72 {
	unsigned int flags;
	struct rw_semaphore___73 dqio_sem;
	struct inode___74 *files[3];
	struct mem_dqinfo___72 info[3];
	const struct quota_format_ops___72 *ops[3];
};

struct rcuwait___72 {
	struct task_struct___73 *task;
};

struct percpu_rw_semaphore___72 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___73 rw_sem;
	struct rcuwait___72 writer;
	int readers_block;
};

struct sb_writers___72 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___72 rw_sem[3];
};

struct file_system_type___72;

struct super_operations___72;

struct dquot_operations___72;

struct quotactl_ops___72;

struct super_block___73 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___72 *s_type;
	const struct super_operations___72 *s_op;
	const struct dquot_operations___72 *dq_op;
	const struct quotactl_ops___72 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___73 *s_root;
	struct rw_semaphore___73 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___73 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___72 s_dquot;
	struct sb_writers___72 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___72 *s_d_op;
	int cleancache_poolid;
	struct shrinker___29 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___59 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

typedef int (*dev_page_fault_t___72)(struct vm_area_struct___73 *, long unsigned int, const struct page___73 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___72)(struct page___73 *, void *);

struct dev_pagemap___72 {
	dev_page_fault_t___72 page_fault;
	dev_page_free_t___72 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___68 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___72 {
	struct task_struct___73 *task;
	struct core_thread___72 *next;
};

struct core_state___72 {
	atomic_t nr_threads;
	struct core_thread___72 dumper;
	struct completion startup;
};

struct vm_fault___72 {
	struct vm_area_struct___73 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___73 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___73 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___72 prealloc_pte;
};

struct kiocb___73 {
	struct file___73 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___73 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___73 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___73 *ia_file;
};

struct dquot___72 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___73 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___72 {
	int qf_fmt_id;
	const struct quota_format_ops___72 *qf_ops;
	struct module___65 *qf_owner;
	struct quota_format_type___72 *qf_next;
};

struct quota_format_ops___72 {
	int (*check_quota_file)(struct super_block___73 *, int);
	int (*read_file_info)(struct super_block___73 *, int);
	int (*write_file_info)(struct super_block___73 *, int);
	int (*free_file_info)(struct super_block___73 *, int);
	int (*read_dqblk)(struct dquot___72 *);
	int (*commit_dqblk)(struct dquot___72 *);
	int (*release_dqblk)(struct dquot___72 *);
	int (*get_next_id)(struct super_block___73 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___72 {
	int (*write_dquot)(struct dquot___72 *);
	struct dquot___72 * (*alloc_dquot)(struct super_block___73 *, int);
	void (*destroy_dquot)(struct dquot___72 *);
	int (*acquire_dquot)(struct dquot___72 *);
	int (*release_dquot)(struct dquot___72 *);
	int (*mark_dirty)(struct dquot___72 *);
	int (*write_info)(struct super_block___73 *, int);
	qsize_t * (*get_reserved_space)(struct inode___74 *);
	int (*get_projid)(struct inode___74 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___74 *, qsize_t *);
	int (*get_next_id)(struct super_block___73 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___72 {
	int (*quota_on)(struct super_block___73 *, int, int, const struct path___72 *);
	int (*quota_off)(struct super_block___73 *, int);
	int (*quota_enable)(struct super_block___73 *, unsigned int);
	int (*quota_disable)(struct super_block___73 *, unsigned int);
	int (*quota_sync)(struct super_block___73 *, int);
	int (*set_info)(struct super_block___73 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___73 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___73 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___73 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___73 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___73 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___72 {
	int (*writepage)(struct page___73 *, struct writeback_control___3 *);
	int (*readpage)(struct file___73 *, struct page___73 *);
	int (*writepages)(struct address_space___72 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___73 *);
	int (*readpages)(struct file___73 *, struct address_space___72 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___73 *, struct address_space___72 *, loff_t, unsigned int, unsigned int, struct page___73 **, void **);
	int (*write_end)(struct file___73 *, struct address_space___72 *, loff_t, unsigned int, unsigned int, struct page___73 *, void *);
	sector_t (*bmap)(struct address_space___72 *, sector_t);
	void (*invalidatepage)(struct page___73 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___73 *, gfp_t);
	void (*freepage)(struct page___73 *);
	ssize_t (*direct_IO)(struct kiocb___73 *, struct iov_iter___29 *);
	int (*migratepage)(struct address_space___72 *, struct page___73 *, struct page___73 *, enum migrate_mode);
	bool (*isolate_page)(struct page___73 *, isolate_mode_t);
	void (*putback_page)(struct page___73 *);
	int (*launder_page)(struct page___73 *);
	int (*is_partially_uptodate)(struct page___73 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___73 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___72 *, struct page___73 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___73 *, sector_t *);
	void (*swap_deactivate)(struct file___73 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___73 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___74 *bd_inode;
	struct super_block___73 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___73 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___72 {
	struct dentry___73 * (*lookup)(struct inode___74 *, struct dentry___73 *, unsigned int);
	const char * (*get_link)(struct dentry___73 *, struct inode___74 *, struct delayed_call *);
	int (*permission)(struct inode___74 *, int);
	struct posix_acl * (*get_acl)(struct inode___74 *, int);
	int (*readlink)(struct dentry___73 *, char *, int);
	int (*create)(struct inode___74 *, struct dentry___73 *, umode_t, bool);
	int (*link)(struct dentry___73 *, struct inode___74 *, struct dentry___73 *);
	int (*unlink)(struct inode___74 *, struct dentry___73 *);
	int (*symlink)(struct inode___74 *, struct dentry___73 *, const char *);
	int (*mkdir)(struct inode___74 *, struct dentry___73 *, umode_t);
	int (*rmdir)(struct inode___74 *, struct dentry___73 *);
	int (*mknod)(struct inode___74 *, struct dentry___73 *, umode_t, dev_t);
	int (*rename)(struct inode___74 *, struct dentry___73 *, struct inode___74 *, struct dentry___73 *, unsigned int);
	int (*setattr)(struct dentry___73 *, struct iattr___73 *);
	int (*getattr)(const struct path___72 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___73 *, char *, size_t);
	int (*fiemap)(struct inode___74 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___74 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___74 *, struct dentry___73 *, struct file___73 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___74 *, struct dentry___73 *, umode_t);
	int (*set_acl)(struct inode___74 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___72 {
	void (*fl_copy_lock)(struct file_lock___73 *, struct file_lock___73 *);
	void (*fl_release_private)(struct file_lock___73 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___72;

struct file_lock___73 {
	struct file_lock___73 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___73 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___72 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___72 *fl_ops;
	const struct lock_manager_operations___72 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___72 {
	int (*lm_compare_owner)(struct file_lock___73 *, struct file_lock___73 *);
	long unsigned int (*lm_owner_key)(struct file_lock___73 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___73 *);
	int (*lm_grant)(struct file_lock___73 *, int);
	bool (*lm_break)(struct file_lock___73 *);
	int (*lm_change)(struct file_lock___73 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___73 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___72 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___72 *fa_next;
	struct file___73 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___72 {
	const char *name;
	int fs_flags;
	struct dentry___73 * (*mount)(struct file_system_type___72 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___73 *);
	struct module___65 *owner;
	struct file_system_type___72 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___72 {
	struct inode___74 * (*alloc_inode)(struct super_block___73 *);
	void (*destroy_inode)(struct inode___74 *);
	void (*dirty_inode)(struct inode___74 *, int);
	int (*write_inode)(struct inode___74 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___74 *);
	void (*evict_inode)(struct inode___74 *);
	void (*put_super)(struct super_block___73 *);
	int (*sync_fs)(struct super_block___73 *, int);
	int (*freeze_super)(struct super_block___73 *);
	int (*freeze_fs)(struct super_block___73 *);
	int (*thaw_super)(struct super_block___73 *);
	int (*unfreeze_fs)(struct super_block___73 *);
	int (*statfs)(struct dentry___73 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___73 *, int *, char *);
	void (*umount_begin)(struct super_block___73 *);
	int (*show_options)(struct seq_file___67 *, struct dentry___73 *);
	int (*show_devname)(struct seq_file___67 *, struct dentry___73 *);
	int (*show_path)(struct seq_file___67 *, struct dentry___73 *);
	int (*show_stats)(struct seq_file___67 *, struct dentry___73 *);
	ssize_t (*quota_read)(struct super_block___73 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___73 *, int, const char *, size_t, loff_t);
	struct dquot___72 ** (*get_dquots)(struct inode___74 *);
	int (*bdev_try_to_free_page)(struct super_block___73 *, struct page___73 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___73 *, struct shrink_control___29 *);
	long int (*free_cached_objects)(struct super_block___73 *, struct shrink_control___29 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct poll_table_struct___48 poll_table___4;

typedef int (*key_restrict_link_func_t___69)(struct key___70 *, const struct key_type *, const union key_payload *, struct key___70 *);

struct key_restriction___70;

struct key___70 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___73 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___70 *restrict_link;
};

struct key_restriction___70 {
	key_restrict_link_func_t___69 check;
	struct key___70 *key;
	struct key_type *keytype;
};

struct seq_operations___64 {
	void * (*start)(struct seq_file___67 *, loff_t *);
	void (*stop)(struct seq_file___67 *, void *);
	void * (*next)(struct seq_file___67 *, void *, loff_t *);
	int (*show)(struct seq_file___67 *, void *);
};

struct cpu_timer_list___4 {
	struct list_head entry;
	u64 expires;
	u64 incr;
	struct task_struct___73 *task;
	int firing;
};

struct k_clock___4;

struct k_itimer___4 {
	struct list_head list;
	struct hlist_node t_hash;
	spinlock_t it_lock;
	const struct k_clock___4 *kclock;
	clockid_t it_clock;
	timer_t it_id;
	int it_active;
	s64 it_overrun;
	s64 it_overrun_last;
	int it_requeue_pending;
	int it_sigev_notify;
	ktime_t it_interval;
	struct signal_struct___63 *it_signal;
	union {
		struct pid___61 *it_pid;
		struct task_struct___73 *it_process;
	};
	struct sigqueue___5 *sigq;
	union {
		struct {
			struct hrtimer timer;
		} real;
		struct cpu_timer_list___4 cpu;
		struct {
			struct alarm alarmtimer;
		} alarm;
		struct callback_head rcu;
	} it;
};

struct k_clock___4 {
	int (*clock_getres)(const clockid_t, struct timespec64 *);
	int (*clock_set)(const clockid_t, const struct timespec64 *);
	int (*clock_get)(const clockid_t, struct timespec64 *);
	int (*clock_adj)(const clockid_t, struct timex *);
	int (*timer_create)(struct k_itimer___4 *);
	int (*nsleep)(const clockid_t, int, const struct timespec64 *);
	int (*timer_set)(struct k_itimer___4 *, int, struct itimerspec64 *, struct itimerspec64 *);
	int (*timer_del)(struct k_itimer___4 *);
	void (*timer_get)(struct k_itimer___4 *, struct itimerspec64 *);
	void (*timer_rearm)(struct k_itimer___4 *);
	s64 (*timer_forward)(struct k_itimer___4 *, ktime_t);
	ktime_t (*timer_remaining)(struct k_itimer___4 *, ktime_t);
	int (*timer_try_to_cancel)(struct k_itimer___4 *);
	void (*timer_arm)(struct k_itimer___4 *, ktime_t, bool, bool);
};

struct posix_clock;

struct posix_clock_operations {
	struct module___65 *owner;
	int (*clock_adjtime)(struct posix_clock *, struct timex *);
	int (*clock_gettime)(struct posix_clock *, struct timespec64 *);
	int (*clock_getres)(struct posix_clock *, struct timespec64 *);
	int (*clock_settime)(struct posix_clock *, const struct timespec64 *);
	long int (*ioctl)(struct posix_clock *, unsigned int, long unsigned int);
	int (*open)(struct posix_clock *, fmode_t);
	__poll_t (*poll)(struct posix_clock *, struct file___73 *, poll_table___4 *);
	int (*release)(struct posix_clock *);
	ssize_t (*read)(struct posix_clock *, uint, char *, size_t);
};

struct posix_clock {
	struct posix_clock_operations ops;
	struct cdev___20 cdev;
	struct kref kref;
	struct rw_semaphore___73 rwsem;
	bool zombie;
	void (*release)(struct posix_clock *);
};

typedef void compound_page_dtor___72(struct page___73 *);

struct cgroup_namespace___57 {
	refcount_t count;
	struct ns_common ns;
	struct user_namespace___59 *user_ns;
	struct ucounts___59 *ucounts;
	struct css_set___57 *root_cset;
};

struct ucounts___59 {
	struct hlist_node node;
	struct user_namespace___59 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct kernel_param_ops___62 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___62 *);
	int (*get)(char *, const struct kernel_param___62 *);
	void (*free)(void *);
};

struct kparam_array___62;

struct kernel_param___62 {
	const char *name;
	struct module___65 *mod;
	const struct kernel_param_ops___62 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___62 *arr;
	};
};

struct kparam_array___62 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___62 *ops;
	void *elem;
};

struct module_attribute___62 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___62 *, struct module_kobject___62 *, char *);
	ssize_t (*store)(struct module_attribute___62 *, struct module_kobject___62 *, const char *, size_t);
	void (*setup)(struct module___65 *, const char *);
	int (*test)(struct module___65 *);
	void (*free)(struct module___65 *);
};

struct trace_event_class___41;

struct trace_event_call___41 {
	struct list_head list;
	struct trace_event_class___41 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array *prog_array;
	int (*perf_perm)(struct trace_event_call___41 *, struct perf_event___46 *);
};

struct node___59 {
	struct device___68 dev;
};

struct bpf_map___57;

struct bpf_map_ops___57 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___57 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___57 *, struct file___73 *);
	void (*map_free)(struct bpf_map___57 *);
	int (*map_get_next_key)(struct bpf_map___57 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___57 *);
	void * (*map_lookup_elem)(struct bpf_map___57 *, void *);
	int (*map_update_elem)(struct bpf_map___57 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___57 *, void *);
	int (*map_push_elem)(struct bpf_map___57 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___57 *, void *);
	int (*map_peek_elem)(struct bpf_map___57 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___57 *, struct file___73 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___57 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___57 *, void *, struct seq_file___67 *);
	int (*map_check_btf)(const struct bpf_map___57 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___57 {
	const struct bpf_map_ops___57 *ops;
	struct bpf_map___57 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___69 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___57;

typedef void (*kthread_work_func_t___57)(struct kthread_work___57 *);

struct kthread_worker___57;

struct kthread_work___57 {
	struct list_head node;
	kthread_work_func_t___57 func;
	struct kthread_worker___57 *worker;
	int canceling;
};

struct kthread_worker___57 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___73 *task;
	struct kthread_work___57 *current_work;
};

struct kthread_delayed_work___57 {
	struct kthread_work___57 work;
	struct timer_list timer;
};

struct psi_group___57 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___57 *poll_kworker;
	struct kthread_delayed_work___57 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___57 {
	struct kernfs_node___70 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___57;

struct cgroup_subsys_state___57 {
	struct cgroup___57 *cgroup;
	struct cgroup_subsys___57 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___57 *parent;
};

struct cgroup_root___57;

struct cgroup_rstat_cpu___57;

struct cgroup___57 {
	struct cgroup_subsys_state___57 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___70 *kn;
	struct cgroup_file___57 procs_file;
	struct cgroup_file___57 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___57 *subsys[13];
	struct cgroup_root___57 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___57 *dom_cgrp;
	struct cgroup_rstat_cpu___57 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf bpf;
	atomic_t congestion_count;
	struct cgroup___57 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___57 psi;
	int ancestor_ids[0];
};

struct cftype___57;

struct cgroup_subsys___57 {
	struct cgroup_subsys_state___57 * (*css_alloc)(struct cgroup_subsys_state___57 *);
	int (*css_online)(struct cgroup_subsys_state___57 *);
	void (*css_offline)(struct cgroup_subsys_state___57 *);
	void (*css_released)(struct cgroup_subsys_state___57 *);
	void (*css_free)(struct cgroup_subsys_state___57 *);
	void (*css_reset)(struct cgroup_subsys_state___57 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___57 *, int);
	int (*css_extra_stat_show)(struct seq_file___67 *, struct cgroup_subsys_state___57 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___73 *);
	void (*cancel_fork)(struct task_struct___73 *);
	void (*fork)(struct task_struct___73 *);
	void (*exit)(struct task_struct___73 *);
	void (*free)(struct task_struct___73 *);
	void (*bind)(struct cgroup_subsys_state___57 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___57 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___57 *dfl_cftypes;
	struct cftype___57 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___57 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___57 *updated_children;
	struct cgroup___57 *updated_next;
};

struct cgroup_root___57 {
	struct kernfs_root___70 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___57 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___57 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___57 *ss;
	struct list_head node;
	struct kernfs_ops___70 *kf_ops;
	int (*open)(struct kernfs_open_file___70 *);
	void (*release)(struct kernfs_open_file___70 *);
	u64 (*read_u64)(struct cgroup_subsys_state___57 *, struct cftype___57 *);
	s64 (*read_s64)(struct cgroup_subsys_state___57 *, struct cftype___57 *);
	int (*seq_show)(struct seq_file___67 *, void *);
	void * (*seq_start)(struct seq_file___67 *, loff_t *);
	void * (*seq_next)(struct seq_file___67 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___67 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___57 *, struct cftype___57 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___57 *, struct cftype___57 *, s64);
	ssize_t (*write)(struct kernfs_open_file___70 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___70 *, struct poll_table_struct___48 *);
};

struct perf_cpu_context___46;

struct pmu___46 {
	struct list_head entry;
	struct module___65 *module;
	struct device___68 *dev;
	const struct attribute_group___67 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___46 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___46 *);
	void (*pmu_disable)(struct pmu___46 *);
	int (*event_init)(struct perf_event___46 *);
	void (*event_mapped)(struct perf_event___46 *, struct mm_struct___72 *);
	void (*event_unmapped)(struct perf_event___46 *, struct mm_struct___72 *);
	int (*add)(struct perf_event___46 *, int);
	void (*del)(struct perf_event___46 *, int);
	void (*start)(struct perf_event___46 *, int);
	void (*stop)(struct perf_event___46 *, int);
	void (*read)(struct perf_event___46 *);
	void (*start_txn)(struct pmu___46 *, unsigned int);
	int (*commit_txn)(struct pmu___46 *);
	void (*cancel_txn)(struct pmu___46 *);
	int (*event_idx)(struct perf_event___46 *);
	void (*sched_task)(struct perf_event_context___46 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___46 *);
	int (*filter_match)(struct perf_event___46 *);
	int (*check_period)(struct perf_event___46 *, u64);
};

struct perf_cpu_context___46 {
	struct perf_event_context___46 ctx;
	struct perf_event_context___46 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___46 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___46 {
	struct cgroup_subsys_state___57 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___41 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___41 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___41 *);
	struct list_head * (*get_fields)(struct trace_event_call___41 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___41 *);
};

struct posix_clock_desc {
	struct file___73 *fp;
	struct posix_clock *clk;
};

struct module___66;

struct file___74;

struct kiocb___74;

struct poll_table_struct___49;

struct vm_area_struct___74;

struct inode___75;

struct file_lock___74;

struct page___74;

struct seq_file___68;

struct file_operations___74 {
	struct module___66 *owner;
	loff_t (*llseek)(struct file___74 *, loff_t, int);
	ssize_t (*read)(struct file___74 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___74 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___74 *, struct iov_iter___29 *);
	ssize_t (*write_iter)(struct kiocb___74 *, struct iov_iter___29 *);
	int (*iopoll)(struct kiocb___74 *, bool);
	int (*iterate)(struct file___74 *, struct dir_context *);
	int (*iterate_shared)(struct file___74 *, struct dir_context *);
	__poll_t (*poll)(struct file___74 *, struct poll_table_struct___49 *);
	long int (*unlocked_ioctl)(struct file___74 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___74 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___74 *, struct vm_area_struct___74 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___75 *, struct file___74 *);
	int (*flush)(struct file___74 *, fl_owner_t);
	int (*release)(struct inode___75 *, struct file___74 *);
	int (*fsync)(struct file___74 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___74 *, int);
	int (*lock)(struct file___74 *, int, struct file_lock___74 *);
	ssize_t (*sendpage)(struct file___74 *, struct page___74 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___74 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___74 *, int, struct file_lock___74 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___74 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___74 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___74 *, long int, struct file_lock___74 **, void **);
	long int (*fallocate)(struct file___74 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___68 *, struct file___74 *);
	ssize_t (*copy_file_range)(struct file___74 *, loff_t, struct file___74 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___74 *, loff_t, struct file___74 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___74 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___73 {
	u64 seqnum;
	struct vm_area_struct___74 *vmas[4];
};

struct page_frag___73 {
	struct page___74 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___47;

struct debug_info___47 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___47 *hbp_break[16];
	struct perf_event___47 *hbp_watch[16];
};

struct thread_struct___47 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___47 debug;
	long: 64;
};

struct mm_struct___73;

struct pid___62;

struct cred___70;

struct nsproxy___69;

struct signal_struct___64;

struct css_set___58;

struct perf_event_context___47;

struct task_struct___74 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___74 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___73 *mm;
	struct mm_struct___73 *active_mm;
	struct vmacache___73 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___74 *real_parent;
	struct task_struct___74 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___74 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___62 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___62 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___62 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___70 *ptracer_cred;
	const struct cred___70 *real_cred;
	const struct cred___70 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___69 *nsproxy;
	struct signal_struct___64 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___74 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___13 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___58 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___47 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___73 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___74 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___47 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___47 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___74 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___47)(struct perf_event___47 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___47;

struct fasync_struct___73;

struct pid_namespace___62;

struct trace_event_call___42;

struct perf_cgroup___47;

struct perf_event___47 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___47 *group_leader;
	struct pmu___47 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___47 hw;
	struct perf_event_context___47 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___47 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___74 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___73 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___47 *);
	struct callback_head callback_head;
	struct pid_namespace___62 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___47 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___47 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___42 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___47 *cgrp;
	struct list_head sb_list;
};

typedef struct page___74 *pgtable_t___73;

struct address_space___73;

struct dev_pagemap___73;

struct page___74 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___73 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___74 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___73 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___73 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___73 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___73;

struct lruvec___73 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___73 *pgdat;
};

struct zone___73 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___73 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___73 {
	struct zone___73 *zone;
	int zone_idx;
};

struct zonelist___73 {
	struct zoneref___73 _zonerefs[25];
};

struct pglist_data___73 {
	struct zone___73 node_zones[3];
	struct zonelist___73 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___74 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___74 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___73 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___74 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___74 *owner;
};

struct secondary_data___74 {
	void *stack;
	struct task_struct___74 *task;
	long int status;
};

struct blocking_notifier_head___73 {
	struct rw_semaphore___74 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___73;

struct vm_area_struct___74 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___74 *vm_next;
	struct vm_area_struct___74 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___73 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___73 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___74 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___73;

struct user_namespace___60;

struct mm_struct___73 {
	struct {
		struct vm_area_struct___74 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___74 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___74 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___73 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___74 *owner;
		struct user_namespace___60 *user_ns;
		struct file___74 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___73 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___73;

struct address_space___73 {
	struct inode___75 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___74 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___73 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___73)(struct vm_area_struct___74 *, long unsigned int, const struct page___74 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___73)(struct page___74 *, void *);

struct device___69;

struct dev_pagemap___73 {
	dev_page_fault_t___73 page_fault;
	dev_page_free_t___73 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___69 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct dentry___74;

struct path___73 {
	struct vfsmount *mnt;
	struct dentry___74 *dentry;
};

struct fown_struct___62 {
	rwlock_t lock;
	struct pid___62 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___74 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___73 f_path;
	struct inode___75 *f_inode;
	const struct file_operations___74 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___62 f_owner;
	const struct cred___70 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___73 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___73;

struct vm_operations_struct___73 {
	void (*open)(struct vm_area_struct___74 *);
	void (*close)(struct vm_area_struct___74 *);
	int (*split)(struct vm_area_struct___74 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___74 *);
	vm_fault_t (*fault)(struct vm_fault___73 *);
	vm_fault_t (*huge_fault)(struct vm_fault___73 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___73 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___74 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___73 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___73 *);
	int (*access)(struct vm_area_struct___74 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___74 *);
	int (*set_policy)(struct vm_area_struct___74 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___74 *, long unsigned int);
	struct page___74 * (*find_special_page)(struct vm_area_struct___74 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___73 {
	struct task_struct___74 *task;
	struct core_thread___73 *next;
};

struct core_state___73 {
	atomic_t nr_threads;
	struct core_thread___73 dumper;
	struct completion startup;
};

struct key___71;

struct ucounts___60;

struct user_namespace___60 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___60 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common ns;
	long unsigned int flags;
	struct key___71 *persistent_keyring_register;
	struct rw_semaphore___74 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___60 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___73 {
	struct vm_area_struct___74 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___74 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___74 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___73 prealloc_pte;
};

struct upid___62 {
	int nr;
	struct pid_namespace___62 *ns;
};

struct pid_namespace___62 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___74 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___62 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___74 *proc_self;
	struct dentry___74 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___60 *user_ns;
	struct ucounts___60 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common ns;
};

struct pid___62 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___62 numbers[1];
};

struct user_struct___70 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___71 *uid_keyring;
	struct key___71 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___70 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___71 *session_keyring;
	struct key___71 *process_keyring;
	struct key___71 *thread_keyring;
	struct key___71 *request_key_auth;
	void *security;
	struct user_struct___70 *user;
	struct user_namespace___60 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___58;

struct nsproxy___69 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___62 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___58 *cgroup_ns;
};

struct signal_struct___64 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___74 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___74 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___62 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___62 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___73 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___62 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___58;

struct cgroup___58;

struct css_set___58 {
	struct cgroup_subsys_state___58 *subsys[13];
	refcount_t refcount;
	struct css_set___58 *dom_cset;
	struct cgroup___58 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___58 *mg_src_cgrp;
	struct cgroup___58 *mg_dst_cgrp;
	struct css_set___58 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___47 {
	struct pmu___47 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___74 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___47 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

union thread_union___64 {
	struct task_struct___74 task;
	long unsigned int stack[8192];
};

struct kset___70;

struct kobj_type___70;

struct kernfs_node___71;

struct kobject___71 {
	const char *name;
	struct list_head entry;
	struct kobject___71 *parent;
	struct kset___70 *kset;
	struct kobj_type___70 *ktype;
	struct kernfs_node___71 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___69 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___69 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___69;

struct bus_type___69;

struct device_driver___69;

struct dev_pm_domain___69;

struct class___69;

struct attribute_group___68;

struct device___69 {
	struct device___69 *parent;
	struct device_private *p;
	struct kobject___71 kobj;
	const char *init_name;
	const struct device_type___69 *type;
	struct mutex mutex;
	struct bus_type___69 *bus;
	struct device_driver___69 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___69 power;
	struct dev_pm_domain___69 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___69 *class;
	const struct attribute_group___68 **groups;
	void (*release)(struct device___69 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___73;

struct super_block___74;

struct dentry___74 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___74 *d_parent;
	struct qstr d_name;
	struct inode___75 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___73 *d_op;
	struct super_block___74 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___73;

struct block_device___74;

struct cdev___21;

struct inode___75 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___73 *i_op;
	struct super_block___74 *i_sb;
	struct address_space___73 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___74 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___74 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___73 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___74 *i_bdev;
		struct cdev___21 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___73 {
	int (*d_revalidate)(struct dentry___74 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___74 *, unsigned int);
	int (*d_hash)(const struct dentry___74 *, struct qstr *);
	int (*d_compare)(const struct dentry___74 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___74 *);
	int (*d_init)(struct dentry___74 *);
	void (*d_release)(struct dentry___74 *);
	void (*d_prune)(struct dentry___74 *);
	void (*d_iput)(struct dentry___74 *, struct inode___75 *);
	char * (*d_dname)(struct dentry___74 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___73 *);
	int (*d_manage)(const struct path___73 *, bool);
	struct dentry___74 * (*d_real)(struct dentry___74 *, const struct inode___75 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___73;

struct mem_dqinfo___73 {
	struct quota_format_type___73 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___73;

struct quota_info___73 {
	unsigned int flags;
	struct rw_semaphore___74 dqio_sem;
	struct inode___75 *files[3];
	struct mem_dqinfo___73 info[3];
	const struct quota_format_ops___73 *ops[3];
};

struct rcuwait___73 {
	struct task_struct___74 *task;
};

struct percpu_rw_semaphore___73 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___74 rw_sem;
	struct rcuwait___73 writer;
	int readers_block;
};

struct sb_writers___73 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___73 rw_sem[3];
};

struct file_system_type___73;

struct super_operations___73;

struct dquot_operations___73;

struct quotactl_ops___73;

struct super_block___74 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___73 *s_type;
	const struct super_operations___73 *s_op;
	const struct dquot_operations___73 *dq_op;
	const struct quotactl_ops___73 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___74 *s_root;
	struct rw_semaphore___74 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___74 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___73 s_dquot;
	struct sb_writers___73 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___73 *s_d_op;
	int cleancache_poolid;
	struct shrinker___29 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___60 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___74 {
	struct file___74 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___74 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___74 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___74 *ia_file;
};

struct dquot___73 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___74 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___73 {
	int qf_fmt_id;
	const struct quota_format_ops___73 *qf_ops;
	struct module___66 *qf_owner;
	struct quota_format_type___73 *qf_next;
};

struct quota_format_ops___73 {
	int (*check_quota_file)(struct super_block___74 *, int);
	int (*read_file_info)(struct super_block___74 *, int);
	int (*write_file_info)(struct super_block___74 *, int);
	int (*free_file_info)(struct super_block___74 *, int);
	int (*read_dqblk)(struct dquot___73 *);
	int (*commit_dqblk)(struct dquot___73 *);
	int (*release_dqblk)(struct dquot___73 *);
	int (*get_next_id)(struct super_block___74 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___73 {
	int (*write_dquot)(struct dquot___73 *);
	struct dquot___73 * (*alloc_dquot)(struct super_block___74 *, int);
	void (*destroy_dquot)(struct dquot___73 *);
	int (*acquire_dquot)(struct dquot___73 *);
	int (*release_dquot)(struct dquot___73 *);
	int (*mark_dirty)(struct dquot___73 *);
	int (*write_info)(struct super_block___74 *, int);
	qsize_t * (*get_reserved_space)(struct inode___75 *);
	int (*get_projid)(struct inode___75 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___75 *, qsize_t *);
	int (*get_next_id)(struct super_block___74 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___73 {
	int (*quota_on)(struct super_block___74 *, int, int, const struct path___73 *);
	int (*quota_off)(struct super_block___74 *, int);
	int (*quota_enable)(struct super_block___74 *, unsigned int);
	int (*quota_disable)(struct super_block___74 *, unsigned int);
	int (*quota_sync)(struct super_block___74 *, int);
	int (*set_info)(struct super_block___74 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___74 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___74 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___74 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___74 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___74 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___63 {
	struct kobject___71 kobj;
	struct module___66 *mod;
	struct kobject___71 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___63 {
	struct module___66 *mod;
	struct latch_tree_node node;
};

struct module_layout___63 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___63 mtn;
};

struct module_attribute___63;

struct kernel_param___63;

struct module___66 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___63 mkobj;
	struct module_attribute___63 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___71 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___63 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___63 core_layout;
	struct module_layout___63 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___42 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___73 {
	int (*writepage)(struct page___74 *, struct writeback_control___3 *);
	int (*readpage)(struct file___74 *, struct page___74 *);
	int (*writepages)(struct address_space___73 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___74 *);
	int (*readpages)(struct file___74 *, struct address_space___73 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___74 *, struct address_space___73 *, loff_t, unsigned int, unsigned int, struct page___74 **, void **);
	int (*write_end)(struct file___74 *, struct address_space___73 *, loff_t, unsigned int, unsigned int, struct page___74 *, void *);
	sector_t (*bmap)(struct address_space___73 *, sector_t);
	void (*invalidatepage)(struct page___74 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___74 *, gfp_t);
	void (*freepage)(struct page___74 *);
	ssize_t (*direct_IO)(struct kiocb___74 *, struct iov_iter___29 *);
	int (*migratepage)(struct address_space___73 *, struct page___74 *, struct page___74 *, enum migrate_mode);
	bool (*isolate_page)(struct page___74 *, isolate_mode_t);
	void (*putback_page)(struct page___74 *);
	int (*launder_page)(struct page___74 *);
	int (*is_partially_uptodate)(struct page___74 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___74 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___73 *, struct page___74 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___74 *, sector_t *);
	void (*swap_deactivate)(struct file___74 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___74 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___75 *bd_inode;
	struct super_block___74 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___74 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___21 {
	struct kobject___71 kobj;
	struct module___66 *owner;
	const struct file_operations___74 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___73 {
	struct dentry___74 * (*lookup)(struct inode___75 *, struct dentry___74 *, unsigned int);
	const char * (*get_link)(struct dentry___74 *, struct inode___75 *, struct delayed_call *);
	int (*permission)(struct inode___75 *, int);
	struct posix_acl * (*get_acl)(struct inode___75 *, int);
	int (*readlink)(struct dentry___74 *, char *, int);
	int (*create)(struct inode___75 *, struct dentry___74 *, umode_t, bool);
	int (*link)(struct dentry___74 *, struct inode___75 *, struct dentry___74 *);
	int (*unlink)(struct inode___75 *, struct dentry___74 *);
	int (*symlink)(struct inode___75 *, struct dentry___74 *, const char *);
	int (*mkdir)(struct inode___75 *, struct dentry___74 *, umode_t);
	int (*rmdir)(struct inode___75 *, struct dentry___74 *);
	int (*mknod)(struct inode___75 *, struct dentry___74 *, umode_t, dev_t);
	int (*rename)(struct inode___75 *, struct dentry___74 *, struct inode___75 *, struct dentry___74 *, unsigned int);
	int (*setattr)(struct dentry___74 *, struct iattr___74 *);
	int (*getattr)(const struct path___73 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___74 *, char *, size_t);
	int (*fiemap)(struct inode___75 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___75 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___75 *, struct dentry___74 *, struct file___74 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___75 *, struct dentry___74 *, umode_t);
	int (*set_acl)(struct inode___75 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___73 {
	void (*fl_copy_lock)(struct file_lock___74 *, struct file_lock___74 *);
	void (*fl_release_private)(struct file_lock___74 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___73;

struct file_lock___74 {
	struct file_lock___74 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___74 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___73 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___73 *fl_ops;
	const struct lock_manager_operations___73 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___73 {
	int (*lm_compare_owner)(struct file_lock___74 *, struct file_lock___74 *);
	long unsigned int (*lm_owner_key)(struct file_lock___74 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___74 *);
	int (*lm_grant)(struct file_lock___74 *, int);
	bool (*lm_break)(struct file_lock___74 *);
	int (*lm_change)(struct file_lock___74 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___74 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___73 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___73 *fa_next;
	struct file___74 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___73 {
	const char *name;
	int fs_flags;
	struct dentry___74 * (*mount)(struct file_system_type___73 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___74 *);
	struct module___66 *owner;
	struct file_system_type___73 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___73 {
	struct inode___75 * (*alloc_inode)(struct super_block___74 *);
	void (*destroy_inode)(struct inode___75 *);
	void (*dirty_inode)(struct inode___75 *, int);
	int (*write_inode)(struct inode___75 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___75 *);
	void (*evict_inode)(struct inode___75 *);
	void (*put_super)(struct super_block___74 *);
	int (*sync_fs)(struct super_block___74 *, int);
	int (*freeze_super)(struct super_block___74 *);
	int (*freeze_fs)(struct super_block___74 *);
	int (*thaw_super)(struct super_block___74 *);
	int (*unfreeze_fs)(struct super_block___74 *);
	int (*statfs)(struct dentry___74 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___74 *, int *, char *);
	void (*umount_begin)(struct super_block___74 *);
	int (*show_options)(struct seq_file___68 *, struct dentry___74 *);
	int (*show_devname)(struct seq_file___68 *, struct dentry___74 *);
	int (*show_path)(struct seq_file___68 *, struct dentry___74 *);
	int (*show_stats)(struct seq_file___68 *, struct dentry___74 *);
	ssize_t (*quota_read)(struct super_block___74 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___74 *, int, const char *, size_t, loff_t);
	struct dquot___73 ** (*get_dquots)(struct inode___75 *);
	int (*bdev_try_to_free_page)(struct super_block___74 *, struct page___74 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___74 *, struct shrink_control___29 *);
	long int (*free_cached_objects)(struct super_block___74 *, struct shrink_control___29 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___48)(struct file___74 *, wait_queue_head_t *, struct poll_table_struct___49 *);

struct poll_table_struct___49 {
	poll_queue_proc___48 _qproc;
	__poll_t _key;
};

struct seq_operations___65;

struct seq_file___68 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___65 *op;
	int poll_event;
	const struct file___74 *file;
	void *private;
};

struct kobj_attribute___71 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___71 *, struct kobj_attribute___71 *, char *);
	ssize_t (*store)(struct kobject___71 *, struct kobj_attribute___71 *, const char *, size_t);
};

typedef void compound_page_dtor___73(struct page___74 *);

typedef int (*key_restrict_link_func_t___70)(struct key___71 *, const struct key_type *, const union key_payload *, struct key___71 *);

struct key_restriction___71;

struct key___71 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___74 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___71 *restrict_link;
};

struct key_restriction___71 {
	key_restrict_link_func_t___70 check;
	struct key___71 *key;
	struct key_type *keytype;
};

struct seq_operations___65 {
	void * (*start)(struct seq_file___68 *, loff_t *);
	void (*stop)(struct seq_file___68 *, void *);
	void * (*next)(struct seq_file___68 *, void *, loff_t *);
	int (*show)(struct seq_file___68 *, void *);
};

struct cgroup_namespace___58 {
	refcount_t count;
	struct ns_common ns;
	struct user_namespace___60 *user_ns;
	struct ucounts___60 *ucounts;
	struct css_set___58 *root_cset;
};

struct ucounts___60 {
	struct hlist_node node;
	struct user_namespace___60 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct kernfs_root___71;

struct kernfs_elem_dir___71 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___71 *root;
};

struct kernfs_syscall_ops___71;

struct kernfs_root___71 {
	struct kernfs_node___71 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___71 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___71 {
	struct kernfs_node___71 *target_kn;
};

struct kernfs_ops___71;

struct kernfs_elem_attr___71 {
	const struct kernfs_ops___71 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___71 *notify_next;
};

struct kernfs_node___71 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___71 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___71 dir;
		struct kernfs_elem_symlink___71 symlink;
		struct kernfs_elem_attr___71 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___71;

struct kernfs_ops___71 {
	int (*open)(struct kernfs_open_file___71 *);
	void (*release)(struct kernfs_open_file___71 *);
	int (*seq_show)(struct seq_file___68 *, void *);
	void * (*seq_start)(struct seq_file___68 *, loff_t *);
	void * (*seq_next)(struct seq_file___68 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___68 *, void *);
	ssize_t (*read)(struct kernfs_open_file___71 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___71 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___71 *, struct vm_area_struct___74 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___71 *, struct poll_table_struct___49 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___71 {
	int (*remount_fs)(struct kernfs_root___71 *, int *, char *);
	int (*show_options)(struct seq_file___68 *, struct kernfs_root___71 *);
	int (*mkdir)(struct kernfs_node___71 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___71 *);
	int (*rename)(struct kernfs_node___71 *, struct kernfs_node___71 *, const char *);
	int (*show_path)(struct seq_file___68 *, struct kernfs_node___71 *, struct kernfs_root___71 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___71 {
	struct kernfs_node___71 *kn;
	struct file___74 *file;
	struct seq_file___68 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___73 *vm_ops;
};

struct bin_attribute___68;

struct attribute_group___68 {
	const char *name;
	umode_t (*is_visible)(struct kobject___71 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___71 *, struct bin_attribute___68 *, int);
	struct attribute **attrs;
	struct bin_attribute___68 **bin_attrs;
};

struct bin_attribute___68 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___74 *, struct kobject___71 *, struct bin_attribute___68 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___74 *, struct kobject___71 *, struct bin_attribute___68 *, char *, loff_t, size_t);
	int (*mmap)(struct file___74 *, struct kobject___71 *, struct bin_attribute___68 *, struct vm_area_struct___74 *);
};

struct sysfs_ops___70 {
	ssize_t (*show)(struct kobject___71 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___71 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___70;

struct kset___70 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___71 kobj;
	const struct kset_uevent_ops___70 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___70 {
	void (*release)(struct kobject___71 *);
	const struct sysfs_ops___70 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___71 *);
	const void * (*namespace)(struct kobject___71 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___70 {
	int (* const filter)(struct kset___70 *, struct kobject___71 *);
	const char * (* const name)(struct kset___70 *, struct kobject___71 *);
	int (* const uevent)(struct kset___70 *, struct kobject___71 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___63 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___63 *);
	int (*get)(char *, const struct kernel_param___63 *);
	void (*free)(void *);
};

struct kparam_array___63;

struct kernel_param___63 {
	const char *name;
	struct module___66 *mod;
	const struct kernel_param_ops___63 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___63 *arr;
	};
};

struct kparam_array___63 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___63 *ops;
	void *elem;
};

struct module_attribute___63 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___63 *, struct module_kobject___63 *, char *);
	ssize_t (*store)(struct module_attribute___63 *, struct module_kobject___63 *, const char *, size_t);
	void (*setup)(struct module___66 *, const char *);
	int (*test)(struct module___66 *);
	void (*free)(struct module___66 *);
};

struct trace_event_class___42;

struct trace_event_call___42 {
	struct list_head list;
	struct trace_event_class___42 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array *prog_array;
	int (*perf_perm)(struct trace_event_call___42 *, struct perf_event___47 *);
};

struct dev_pm_ops___69 {
	int (*prepare)(struct device___69 *);
	void (*complete)(struct device___69 *);
	int (*suspend)(struct device___69 *);
	int (*resume)(struct device___69 *);
	int (*freeze)(struct device___69 *);
	int (*thaw)(struct device___69 *);
	int (*poweroff)(struct device___69 *);
	int (*restore)(struct device___69 *);
	int (*suspend_late)(struct device___69 *);
	int (*resume_early)(struct device___69 *);
	int (*freeze_late)(struct device___69 *);
	int (*thaw_early)(struct device___69 *);
	int (*poweroff_late)(struct device___69 *);
	int (*restore_early)(struct device___69 *);
	int (*suspend_noirq)(struct device___69 *);
	int (*resume_noirq)(struct device___69 *);
	int (*freeze_noirq)(struct device___69 *);
	int (*thaw_noirq)(struct device___69 *);
	int (*poweroff_noirq)(struct device___69 *);
	int (*restore_noirq)(struct device___69 *);
	int (*runtime_suspend)(struct device___69 *);
	int (*runtime_resume)(struct device___69 *);
	int (*runtime_idle)(struct device___69 *);
};

struct dev_pm_domain___69 {
	struct dev_pm_ops___69 ops;
	void (*detach)(struct device___69 *, bool);
	int (*activate)(struct device___69 *);
	void (*sync)(struct device___69 *);
	void (*dismiss)(struct device___69 *);
};

struct bus_type___69 {
	const char *name;
	const char *dev_name;
	struct device___69 *dev_root;
	const struct attribute_group___68 **bus_groups;
	const struct attribute_group___68 **dev_groups;
	const struct attribute_group___68 **drv_groups;
	int (*match)(struct device___69 *, struct device_driver___69 *);
	int (*uevent)(struct device___69 *, struct kobj_uevent_env *);
	int (*probe)(struct device___69 *);
	int (*remove)(struct device___69 *);
	void (*shutdown)(struct device___69 *);
	int (*online)(struct device___69 *);
	int (*offline)(struct device___69 *);
	int (*suspend)(struct device___69 *, pm_message_t);
	int (*resume)(struct device___69 *);
	int (*num_vf)(struct device___69 *);
	int (*dma_configure)(struct device___69 *);
	const struct dev_pm_ops___69 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___69 {
	const char *name;
	struct bus_type___69 *bus;
	struct module___66 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___69 *);
	int (*remove)(struct device___69 *);
	void (*shutdown)(struct device___69 *);
	int (*suspend)(struct device___69 *, pm_message_t);
	int (*resume)(struct device___69 *);
	const struct attribute_group___68 **groups;
	const struct dev_pm_ops___69 *pm;
	void (*coredump)(struct device___69 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___69 {
	const char *name;
	const struct attribute_group___68 **groups;
	int (*uevent)(struct device___69 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___69 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___69 *);
	const struct dev_pm_ops___69 *pm;
};

struct class___69 {
	const char *name;
	struct module___66 *owner;
	const struct attribute_group___68 **class_groups;
	const struct attribute_group___68 **dev_groups;
	struct kobject___71 *dev_kobj;
	int (*dev_uevent)(struct device___69 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___69 *, umode_t *);
	void (*class_release)(struct class___69 *);
	void (*dev_release)(struct device___69 *);
	int (*shutdown_pre)(struct device___69 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___69 *);
	const struct dev_pm_ops___69 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___60 {
	struct device___69 dev;
};

struct bpf_map___58;

struct bpf_map_ops___58 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___58 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___58 *, struct file___74 *);
	void (*map_free)(struct bpf_map___58 *);
	int (*map_get_next_key)(struct bpf_map___58 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___58 *);
	void * (*map_lookup_elem)(struct bpf_map___58 *, void *);
	int (*map_update_elem)(struct bpf_map___58 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___58 *, void *);
	int (*map_push_elem)(struct bpf_map___58 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___58 *, void *);
	int (*map_peek_elem)(struct bpf_map___58 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___58 *, struct file___74 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___58 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___58 *, void *, struct seq_file___68 *);
	int (*map_check_btf)(const struct bpf_map___58 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___58 {
	const struct bpf_map_ops___58 *ops;
	struct bpf_map___58 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___70 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___58;

typedef void (*kthread_work_func_t___58)(struct kthread_work___58 *);

struct kthread_worker___58;

struct kthread_work___58 {
	struct list_head node;
	kthread_work_func_t___58 func;
	struct kthread_worker___58 *worker;
	int canceling;
};

struct kthread_worker___58 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___74 *task;
	struct kthread_work___58 *current_work;
};

struct kthread_delayed_work___58 {
	struct kthread_work___58 work;
	struct timer_list timer;
};

struct psi_group___58 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___58 *poll_kworker;
	struct kthread_delayed_work___58 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___58 {
	struct kernfs_node___71 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___58;

struct cgroup_subsys_state___58 {
	struct cgroup___58 *cgroup;
	struct cgroup_subsys___58 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___58 *parent;
};

struct cgroup_root___58;

struct cgroup_rstat_cpu___58;

struct cgroup___58 {
	struct cgroup_subsys_state___58 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___71 *kn;
	struct cgroup_file___58 procs_file;
	struct cgroup_file___58 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___58 *subsys[13];
	struct cgroup_root___58 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___58 *dom_cgrp;
	struct cgroup_rstat_cpu___58 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf bpf;
	atomic_t congestion_count;
	struct cgroup___58 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___58 psi;
	int ancestor_ids[0];
};

struct cftype___58;

struct cgroup_subsys___58 {
	struct cgroup_subsys_state___58 * (*css_alloc)(struct cgroup_subsys_state___58 *);
	int (*css_online)(struct cgroup_subsys_state___58 *);
	void (*css_offline)(struct cgroup_subsys_state___58 *);
	void (*css_released)(struct cgroup_subsys_state___58 *);
	void (*css_free)(struct cgroup_subsys_state___58 *);
	void (*css_reset)(struct cgroup_subsys_state___58 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___58 *, int);
	int (*css_extra_stat_show)(struct seq_file___68 *, struct cgroup_subsys_state___58 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___74 *);
	void (*cancel_fork)(struct task_struct___74 *);
	void (*fork)(struct task_struct___74 *);
	void (*exit)(struct task_struct___74 *);
	void (*free)(struct task_struct___74 *);
	void (*bind)(struct cgroup_subsys_state___58 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___58 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___58 *dfl_cftypes;
	struct cftype___58 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___58 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___58 *updated_children;
	struct cgroup___58 *updated_next;
};

struct cgroup_root___58 {
	struct kernfs_root___71 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___58 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___58 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___58 *ss;
	struct list_head node;
	struct kernfs_ops___71 *kf_ops;
	int (*open)(struct kernfs_open_file___71 *);
	void (*release)(struct kernfs_open_file___71 *);
	u64 (*read_u64)(struct cgroup_subsys_state___58 *, struct cftype___58 *);
	s64 (*read_s64)(struct cgroup_subsys_state___58 *, struct cftype___58 *);
	int (*seq_show)(struct seq_file___68 *, void *);
	void * (*seq_start)(struct seq_file___68 *, loff_t *);
	void * (*seq_next)(struct seq_file___68 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___68 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___58 *, struct cftype___58 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___58 *, struct cftype___58 *, s64);
	ssize_t (*write)(struct kernfs_open_file___71 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___71 *, struct poll_table_struct___49 *);
};

struct perf_cpu_context___47;

struct pmu___47 {
	struct list_head entry;
	struct module___66 *module;
	struct device___69 *dev;
	const struct attribute_group___68 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___47 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___47 *);
	void (*pmu_disable)(struct pmu___47 *);
	int (*event_init)(struct perf_event___47 *);
	void (*event_mapped)(struct perf_event___47 *, struct mm_struct___73 *);
	void (*event_unmapped)(struct perf_event___47 *, struct mm_struct___73 *);
	int (*add)(struct perf_event___47 *, int);
	void (*del)(struct perf_event___47 *, int);
	void (*start)(struct perf_event___47 *, int);
	void (*stop)(struct perf_event___47 *, int);
	void (*read)(struct perf_event___47 *);
	void (*start_txn)(struct pmu___47 *, unsigned int);
	int (*commit_txn)(struct pmu___47 *);
	void (*cancel_txn)(struct pmu___47 *);
	int (*event_idx)(struct perf_event___47 *);
	void (*sched_task)(struct perf_event_context___47 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___47 *);
	int (*filter_match)(struct perf_event___47 *);
	int (*check_period)(struct perf_event___47 *, u64);
};

struct perf_cpu_context___47 {
	struct perf_event_context___47 ctx;
	struct perf_event_context___47 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___47 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___47 {
	struct cgroup_subsys_state___58 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___42 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___42 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___42 *);
	struct list_head * (*get_fields)(struct trace_event_call___42 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___42 *);
};

struct syscall_metadata___18 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___42 *enter_event;
	struct trace_event_call___42 *exit_event;
};

typedef s64 int64_t;

struct ce_unbind {
	struct clock_event_device___4 *ce;
	int res;
};

struct module___67;

struct file___75;

struct kiocb___75;

struct poll_table_struct___50;

struct vm_area_struct___75;

struct inode___76;

struct file_lock___75;

struct page___75;

struct seq_file___69;

struct file_operations___75 {
	struct module___67 *owner;
	loff_t (*llseek)(struct file___75 *, loff_t, int);
	ssize_t (*read)(struct file___75 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___75 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___75 *, struct iov_iter___29 *);
	ssize_t (*write_iter)(struct kiocb___75 *, struct iov_iter___29 *);
	int (*iopoll)(struct kiocb___75 *, bool);
	int (*iterate)(struct file___75 *, struct dir_context *);
	int (*iterate_shared)(struct file___75 *, struct dir_context *);
	__poll_t (*poll)(struct file___75 *, struct poll_table_struct___50 *);
	long int (*unlocked_ioctl)(struct file___75 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___75 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___75 *, struct vm_area_struct___75 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___76 *, struct file___75 *);
	int (*flush)(struct file___75 *, fl_owner_t);
	int (*release)(struct inode___76 *, struct file___75 *);
	int (*fsync)(struct file___75 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___75 *, int);
	int (*lock)(struct file___75 *, int, struct file_lock___75 *);
	ssize_t (*sendpage)(struct file___75 *, struct page___75 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___75 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___75 *, int, struct file_lock___75 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___75 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___75 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___75 *, long int, struct file_lock___75 **, void **);
	long int (*fallocate)(struct file___75 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___69 *, struct file___75 *);
	ssize_t (*copy_file_range)(struct file___75 *, loff_t, struct file___75 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___75 *, loff_t, struct file___75 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___75 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct perf_event___48;

struct debug_info___48 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___48 *hbp_break[16];
	struct perf_event___48 *hbp_watch[16];
};

struct task_struct___75;

struct hw_perf_event___48 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___75 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___48)(struct perf_event___48 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___48;

struct perf_event_context___48;

struct fasync_struct___74;

struct pid_namespace___63;

struct trace_event_call___43;

struct perf_cgroup___48;

struct perf_event___48 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___48 *group_leader;
	struct pmu___48 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___48 hw;
	struct perf_event_context___48 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___48 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___75 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___74 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___48 *);
	struct callback_head callback_head;
	struct pid_namespace___63 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___48 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___48 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___43 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___48 *cgrp;
	struct list_head sb_list;
};

struct thread_struct___48 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___48 debug;
	long: 64;
};

struct vmacache___74 {
	u64 seqnum;
	struct vm_area_struct___75 *vmas[4];
};

struct page_frag___74 {
	struct page___75 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___74;

struct pid___63;

struct cred___71;

struct nsproxy___70;

struct signal_struct___65;

struct css_set___59;

struct vm_struct___53;

struct task_struct___75 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___75 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___74 *mm;
	struct mm_struct___74 *active_mm;
	struct vmacache___74 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___75 *real_parent;
	struct task_struct___75 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___75 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___63 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___63 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___63 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___71 *ptracer_cred;
	const struct cred___71 *real_cred;
	const struct cred___71 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___70 *nsproxy;
	struct signal_struct___65 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___75 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___13 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___59 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___48 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___74 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___75 *oom_reaper_list;
	struct vm_struct___53 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___48 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___75 *pgtable_t___74;

struct address_space___74;

struct dev_pagemap___74;

struct page___75 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___74 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___75 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___74 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___74 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___74 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___74;

struct lruvec___74 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___74 *pgdat;
};

struct zone___74 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___74 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___74 {
	struct zone___74 *zone;
	int zone_idx;
};

struct zonelist___74 {
	struct zoneref___74 _zonerefs[25];
};

struct pglist_data___74 {
	struct zone___74 node_zones[3];
	struct zonelist___74 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___75 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___75 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___74 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___75 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___75 *owner;
};

struct secondary_data___75 {
	void *stack;
	struct task_struct___75 *task;
	long int status;
};

struct clock_event_device___14;

struct arch_timer_erratum_workaround___14 {
	enum arch_timer_erratum_match_type match_type;
	const void *id;
	const char *desc;
	u32 (*read_cntp_tval_el0)();
	u32 (*read_cntv_tval_el0)();
	u64 (*read_cntpct_el0)();
	u64 (*read_cntvct_el0)();
	int (*set_next_event_phys)(long unsigned int, struct clock_event_device___14 *);
	int (*set_next_event_virt)(long unsigned int, struct clock_event_device___14 *);
};

struct clock_event_device___14 {
	void (*event_handler)(struct clock_event_device___14 *);
	int (*set_next_event)(long unsigned int, struct clock_event_device___14 *);
	int (*set_next_ktime)(ktime_t, struct clock_event_device___14 *);
	ktime_t next_event;
	u64 max_delta_ns;
	u64 min_delta_ns;
	u32 mult;
	u32 shift;
	enum clock_event_state state_use_accessors;
	unsigned int features;
	long unsigned int retries;
	int (*set_state_periodic)(struct clock_event_device___14 *);
	int (*set_state_oneshot)(struct clock_event_device___14 *);
	int (*set_state_oneshot_stopped)(struct clock_event_device___14 *);
	int (*set_state_shutdown)(struct clock_event_device___14 *);
	int (*tick_resume)(struct clock_event_device___14 *);
	void (*broadcast)(const struct cpumask *);
	void (*suspend)(struct clock_event_device___14 *);
	void (*resume)(struct clock_event_device___14 *);
	long unsigned int min_delta_ticks;
	long unsigned int max_delta_ticks;
	const char *name;
	int rating;
	int irq;
	int bound_on;
	const struct cpumask *cpumask;
	struct list_head list;
	struct module___67 *owner;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct blocking_notifier_head___74 {
	struct rw_semaphore___75 rwsem;
	struct notifier_block *head;
};

struct key___72;

struct ucounts___61;

struct user_namespace___61 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___61 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common ns;
	long unsigned int flags;
	struct key___72 *persistent_keyring_register;
	struct rw_semaphore___75 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___61 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_root___72;

struct kernfs_elem_dir___72 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___72 *root;
};

struct kernfs_node___72;

struct kernfs_syscall_ops___72;

struct kernfs_root___72 {
	struct kernfs_node___72 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___72 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___72 {
	struct kernfs_node___72 *target_kn;
};

struct kernfs_ops___72;

struct kernfs_elem_attr___72 {
	const struct kernfs_ops___72 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___72 *notify_next;
};

struct kernfs_node___72 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___72 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___72 dir;
		struct kernfs_elem_symlink___72 symlink;
		struct kernfs_elem_attr___72 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___72;

struct kernfs_ops___72 {
	int (*open)(struct kernfs_open_file___72 *);
	void (*release)(struct kernfs_open_file___72 *);
	int (*seq_show)(struct seq_file___69 *, void *);
	void * (*seq_start)(struct seq_file___69 *, loff_t *);
	void * (*seq_next)(struct seq_file___69 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___69 *, void *);
	ssize_t (*read)(struct kernfs_open_file___72 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___72 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___72 *, struct vm_area_struct___75 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___72 *, struct poll_table_struct___50 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___72 {
	int (*remount_fs)(struct kernfs_root___72 *, int *, char *);
	int (*show_options)(struct seq_file___69 *, struct kernfs_root___72 *);
	int (*mkdir)(struct kernfs_node___72 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___72 *);
	int (*rename)(struct kernfs_node___72 *, struct kernfs_node___72 *, const char *);
	int (*show_path)(struct seq_file___69 *, struct kernfs_node___72 *, struct kernfs_root___72 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___66;

struct seq_file___69 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___66 *op;
	int poll_event;
	const struct file___75 *file;
	void *private;
};

struct vm_operations_struct___74;

struct kernfs_open_file___72 {
	struct kernfs_node___72 *kn;
	struct file___75 *file;
	struct seq_file___69 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___74 *vm_ops;
};

struct dentry___75;

struct path___74 {
	struct vfsmount *mnt;
	struct dentry___75 *dentry;
};

struct fown_struct___63 {
	rwlock_t lock;
	struct pid___63 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___75 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___74 f_path;
	struct inode___76 *f_inode;
	const struct file_operations___75 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___63 f_owner;
	const struct cred___71 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___74 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___74;

struct vm_operations_struct___74 {
	void (*open)(struct vm_area_struct___75 *);
	void (*close)(struct vm_area_struct___75 *);
	int (*split)(struct vm_area_struct___75 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___75 *);
	vm_fault_t (*fault)(struct vm_fault___74 *);
	vm_fault_t (*huge_fault)(struct vm_fault___74 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___74 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___75 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___74 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___74 *);
	int (*access)(struct vm_area_struct___75 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___75 *);
	int (*set_policy)(struct vm_area_struct___75 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___75 *, long unsigned int);
	struct page___75 * (*find_special_page)(struct vm_area_struct___75 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___49)(struct file___75 *, wait_queue_head_t *, struct poll_table_struct___50 *);

struct poll_table_struct___50 {
	poll_queue_proc___49 _qproc;
	__poll_t _key;
};

struct vm_area_struct___75 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___75 *vm_next;
	struct vm_area_struct___75 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___74 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___74 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___75 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___72;

struct bin_attribute___69;

struct attribute_group___69 {
	const char *name;
	umode_t (*is_visible)(struct kobject___72 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___72 *, struct bin_attribute___69 *, int);
	struct attribute **attrs;
	struct bin_attribute___69 **bin_attrs;
};

struct kset___71;

struct kobj_type___71;

struct kobject___72 {
	const char *name;
	struct list_head entry;
	struct kobject___72 *parent;
	struct kset___71 *kset;
	struct kobj_type___71 *ktype;
	struct kernfs_node___72 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___69 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___75 *, struct kobject___72 *, struct bin_attribute___69 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___75 *, struct kobject___72 *, struct bin_attribute___69 *, char *, loff_t, size_t);
	int (*mmap)(struct file___75 *, struct kobject___72 *, struct bin_attribute___69 *, struct vm_area_struct___75 *);
};

struct sysfs_ops___71 {
	ssize_t (*show)(struct kobject___72 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___72 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___71;

struct kset___71 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___72 kobj;
	const struct kset_uevent_ops___71 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___71 {
	void (*release)(struct kobject___72 *);
	const struct sysfs_ops___71 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___72 *);
	const void * (*namespace)(struct kobject___72 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___71 {
	int (* const filter)(struct kset___71 *, struct kobject___72 *);
	const char * (* const name)(struct kset___71 *, struct kobject___72 *);
	int (* const uevent)(struct kset___71 *, struct kobject___72 *, struct kobj_uevent_env *);
};

struct kobj_attribute___72 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___72 *, struct kobj_attribute___72 *, char *);
	ssize_t (*store)(struct kobject___72 *, struct kobj_attribute___72 *, const char *, size_t);
};

struct device___70;

struct dev_pm_ops___70 {
	int (*prepare)(struct device___70 *);
	void (*complete)(struct device___70 *);
	int (*suspend)(struct device___70 *);
	int (*resume)(struct device___70 *);
	int (*freeze)(struct device___70 *);
	int (*thaw)(struct device___70 *);
	int (*poweroff)(struct device___70 *);
	int (*restore)(struct device___70 *);
	int (*suspend_late)(struct device___70 *);
	int (*resume_early)(struct device___70 *);
	int (*freeze_late)(struct device___70 *);
	int (*thaw_early)(struct device___70 *);
	int (*poweroff_late)(struct device___70 *);
	int (*restore_early)(struct device___70 *);
	int (*suspend_noirq)(struct device___70 *);
	int (*resume_noirq)(struct device___70 *);
	int (*freeze_noirq)(struct device___70 *);
	int (*thaw_noirq)(struct device___70 *);
	int (*poweroff_noirq)(struct device___70 *);
	int (*restore_noirq)(struct device___70 *);
	int (*runtime_suspend)(struct device___70 *);
	int (*runtime_resume)(struct device___70 *);
	int (*runtime_idle)(struct device___70 *);
};

struct dev_pm_qos___8;

struct dev_pm_info___70 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___70 *, s32);
	struct dev_pm_qos___8 *qos;
};

struct device_type___70;

struct bus_type___70;

struct device_driver___70;

struct dev_pm_domain___70;

struct device_node___25;

struct fwnode_handle___51;

struct class___70;

struct device___70 {
	struct device___70 *parent;
	struct device_private *p;
	struct kobject___72 kobj;
	const char *init_name;
	const struct device_type___70 *type;
	struct mutex mutex;
	struct bus_type___70 *bus;
	struct device_driver___70 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___70 power;
	struct dev_pm_domain___70 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___25 *of_node;
	struct fwnode_handle___51 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___70 *class;
	const struct attribute_group___69 **groups;
	void (*release)(struct device___70 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct pm_qos_constraints___8 {
	struct plist_head list;
	s32 target_value;
	s32 default_value;
	s32 no_constraint_value;
	enum pm_qos_type type;
	struct blocking_notifier_head___74 *notifiers;
};

struct dev_pm_qos_request___8;

struct dev_pm_qos___8 {
	struct pm_qos_constraints___8 resume_latency;
	struct pm_qos_constraints___8 latency_tolerance;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___8 *resume_latency_req;
	struct dev_pm_qos_request___8 *latency_tolerance_req;
	struct dev_pm_qos_request___8 *flags_req;
};

struct dev_pm_domain___70 {
	struct dev_pm_ops___70 ops;
	void (*detach)(struct device___70 *, bool);
	int (*activate)(struct device___70 *);
	void (*sync)(struct device___70 *);
	void (*dismiss)(struct device___70 *);
};

struct upid___63 {
	int nr;
	struct pid_namespace___63 *ns;
};

struct pid_namespace___63 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___75 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___63 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___75 *proc_self;
	struct dentry___75 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___61 *user_ns;
	struct ucounts___61 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common ns;
};

struct pid___63 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___63 numbers[1];
};

struct tick_device___7 {
	struct clock_event_device___14 *evtdev;
	enum tick_device_mode mode;
};

struct user_struct___71 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___72 *uid_keyring;
	struct key___72 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___74;

struct mm_struct___74 {
	struct {
		struct vm_area_struct___75 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___75 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___75 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___74 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___75 *owner;
		struct user_namespace___61 *user_ns;
		struct file___75 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___74 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___71 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___72 *session_keyring;
	struct key___72 *process_keyring;
	struct key___72 *thread_keyring;
	struct key___72 *request_key_auth;
	void *security;
	struct user_struct___71 *user;
	struct user_namespace___61 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___59;

struct nsproxy___70 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___63 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___59 *cgroup_ns;
};

struct signal_struct___65 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___75 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___75 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___63 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___63 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___74 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___63 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___59;

struct cgroup___59;

struct css_set___59 {
	struct cgroup_subsys_state___59 *subsys[13];
	refcount_t refcount;
	struct css_set___59 *dom_cset;
	struct cgroup___59 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___59 *mg_src_cgrp;
	struct cgroup___59 *mg_dst_cgrp;
	struct css_set___59 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___48 {
	struct pmu___48 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___75 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___48 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___53 {
	struct vm_struct___53 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___75 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___65 {
	struct task_struct___75 task;
	long unsigned int stack[8192];
};

struct bus_type___70 {
	const char *name;
	const char *dev_name;
	struct device___70 *dev_root;
	const struct attribute_group___69 **bus_groups;
	const struct attribute_group___69 **dev_groups;
	const struct attribute_group___69 **drv_groups;
	int (*match)(struct device___70 *, struct device_driver___70 *);
	int (*uevent)(struct device___70 *, struct kobj_uevent_env *);
	int (*probe)(struct device___70 *);
	int (*remove)(struct device___70 *);
	void (*shutdown)(struct device___70 *);
	int (*online)(struct device___70 *);
	int (*offline)(struct device___70 *);
	int (*suspend)(struct device___70 *, pm_message_t);
	int (*resume)(struct device___70 *);
	int (*num_vf)(struct device___70 *);
	int (*dma_configure)(struct device___70 *);
	const struct dev_pm_ops___70 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___70 {
	const char *name;
	struct bus_type___70 *bus;
	struct module___67 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___70 *);
	int (*remove)(struct device___70 *);
	void (*shutdown)(struct device___70 *);
	int (*suspend)(struct device___70 *, pm_message_t);
	int (*resume)(struct device___70 *);
	const struct attribute_group___69 **groups;
	const struct dev_pm_ops___70 *pm;
	void (*coredump)(struct device___70 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___70 {
	const char *name;
	const struct attribute_group___69 **groups;
	int (*uevent)(struct device___70 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___70 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___70 *);
	const struct dev_pm_ops___70 *pm;
};

struct module_kobject___64 {
	struct kobject___72 kobj;
	struct module___67 *mod;
	struct kobject___72 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___64 {
	struct module___67 *mod;
	struct latch_tree_node node;
};

struct module_layout___64 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___64 mtn;
};

struct module_attribute___64;

struct kernel_param___64;

struct module___67 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___64 mkobj;
	struct module_attribute___64 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___72 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___64 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___64 core_layout;
	struct module_layout___64 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___43 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct class___70 {
	const char *name;
	struct module___67 *owner;
	const struct attribute_group___69 **class_groups;
	const struct attribute_group___69 **dev_groups;
	struct kobject___72 *dev_kobj;
	int (*dev_uevent)(struct device___70 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___70 *, umode_t *);
	void (*class_release)(struct class___70 *);
	void (*dev_release)(struct device___70 *);
	int (*shutdown_pre)(struct device___70 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___70 *);
	const struct dev_pm_ops___70 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct fwnode_operations___51;

struct fwnode_handle___51 {
	struct fwnode_handle___51 *secondary;
	const struct fwnode_operations___51 *ops;
};

struct property___24;

struct device_node___25 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___51 fwnode;
	struct property___24 *properties;
	struct property___24 *deadprops;
	struct device_node___25 *parent;
	struct device_node___25 *child;
	struct device_node___25 *sibling;
	struct kobject___72 kobj;
	long unsigned int _flags;
	void *data;
};

struct node___61 {
	struct device___70 dev;
};

struct kernel_param_ops___64 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___64 *);
	int (*get)(char *, const struct kernel_param___64 *);
	void (*free)(void *);
};

struct kparam_array___64;

struct kernel_param___64 {
	const char *name;
	struct module___67 *mod;
	const struct kernel_param_ops___64 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___64 *arr;
	};
};

struct kparam_array___64 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___64 *ops;
	void *elem;
};

struct module_attribute___64 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___64 *, struct module_kobject___64 *, char *);
	ssize_t (*store)(struct module_attribute___64 *, struct module_kobject___64 *, const char *, size_t);
	void (*setup)(struct module___67 *, const char *);
	int (*test)(struct module___67 *);
	void (*free)(struct module___67 *);
};

struct trace_event_class___43;

struct trace_event_call___43 {
	struct list_head list;
	struct trace_event_class___43 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array *prog_array;
	int (*perf_perm)(struct trace_event_call___43 *, struct perf_event___48 *);
};

struct dev_pm_qos_request___8 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___70 *dev;
};

struct address_space_operations___74;

struct address_space___74 {
	struct inode___76 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___75 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___74 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___74)(struct vm_area_struct___75 *, long unsigned int, const struct page___75 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___74)(struct page___75 *, void *);

struct dev_pagemap___74 {
	dev_page_fault_t___74 page_fault;
	dev_page_free_t___74 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___70 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___74 {
	struct task_struct___75 *task;
	struct core_thread___74 *next;
};

struct core_state___74 {
	atomic_t nr_threads;
	struct core_thread___74 dumper;
	struct completion startup;
};

struct vm_fault___74 {
	struct vm_area_struct___75 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___75 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___75 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___74 prealloc_pte;
};

struct dentry_operations___74;

struct super_block___75;

struct dentry___75 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___75 *d_parent;
	struct qstr d_name;
	struct inode___76 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___74 *d_op;
	struct super_block___75 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___74;

struct block_device___75;

struct inode___76 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___74 *i_op;
	struct super_block___75 *i_sb;
	struct address_space___74 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___75 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___75 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___74 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___75 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___74 {
	int (*d_revalidate)(struct dentry___75 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___75 *, unsigned int);
	int (*d_hash)(const struct dentry___75 *, struct qstr *);
	int (*d_compare)(const struct dentry___75 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___75 *);
	int (*d_init)(struct dentry___75 *);
	void (*d_release)(struct dentry___75 *);
	void (*d_prune)(struct dentry___75 *);
	void (*d_iput)(struct dentry___75 *, struct inode___76 *);
	char * (*d_dname)(struct dentry___75 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___74 *);
	int (*d_manage)(const struct path___74 *, bool);
	struct dentry___75 * (*d_real)(struct dentry___75 *, const struct inode___76 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___74;

struct mem_dqinfo___74 {
	struct quota_format_type___74 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___74;

struct quota_info___74 {
	unsigned int flags;
	struct rw_semaphore___75 dqio_sem;
	struct inode___76 *files[3];
	struct mem_dqinfo___74 info[3];
	const struct quota_format_ops___74 *ops[3];
};

struct rcuwait___74 {
	struct task_struct___75 *task;
};

struct percpu_rw_semaphore___74 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___75 rw_sem;
	struct rcuwait___74 writer;
	int readers_block;
};

struct sb_writers___74 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___74 rw_sem[3];
};

struct file_system_type___74;

struct super_operations___74;

struct dquot_operations___74;

struct quotactl_ops___74;

struct super_block___75 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___74 *s_type;
	const struct super_operations___74 *s_op;
	const struct dquot_operations___74 *dq_op;
	const struct quotactl_ops___74 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___75 *s_root;
	struct rw_semaphore___75 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___75 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___74 s_dquot;
	struct sb_writers___74 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___74 *s_d_op;
	int cleancache_poolid;
	struct shrinker___29 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___61 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___75 {
	struct file___75 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___75 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___75 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___75 *ia_file;
};

struct dquot___74 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___75 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___74 {
	int qf_fmt_id;
	const struct quota_format_ops___74 *qf_ops;
	struct module___67 *qf_owner;
	struct quota_format_type___74 *qf_next;
};

struct quota_format_ops___74 {
	int (*check_quota_file)(struct super_block___75 *, int);
	int (*read_file_info)(struct super_block___75 *, int);
	int (*write_file_info)(struct super_block___75 *, int);
	int (*free_file_info)(struct super_block___75 *, int);
	int (*read_dqblk)(struct dquot___74 *);
	int (*commit_dqblk)(struct dquot___74 *);
	int (*release_dqblk)(struct dquot___74 *);
	int (*get_next_id)(struct super_block___75 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___74 {
	int (*write_dquot)(struct dquot___74 *);
	struct dquot___74 * (*alloc_dquot)(struct super_block___75 *, int);
	void (*destroy_dquot)(struct dquot___74 *);
	int (*acquire_dquot)(struct dquot___74 *);
	int (*release_dquot)(struct dquot___74 *);
	int (*mark_dirty)(struct dquot___74 *);
	int (*write_info)(struct super_block___75 *, int);
	qsize_t * (*get_reserved_space)(struct inode___76 *);
	int (*get_projid)(struct inode___76 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___76 *, qsize_t *);
	int (*get_next_id)(struct super_block___75 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___74 {
	int (*quota_on)(struct super_block___75 *, int, int, const struct path___74 *);
	int (*quota_off)(struct super_block___75 *, int);
	int (*quota_enable)(struct super_block___75 *, unsigned int);
	int (*quota_disable)(struct super_block___75 *, unsigned int);
	int (*quota_sync)(struct super_block___75 *, int);
	int (*set_info)(struct super_block___75 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___75 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___75 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___75 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___75 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___75 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___74 {
	int (*writepage)(struct page___75 *, struct writeback_control___3 *);
	int (*readpage)(struct file___75 *, struct page___75 *);
	int (*writepages)(struct address_space___74 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___75 *);
	int (*readpages)(struct file___75 *, struct address_space___74 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___75 *, struct address_space___74 *, loff_t, unsigned int, unsigned int, struct page___75 **, void **);
	int (*write_end)(struct file___75 *, struct address_space___74 *, loff_t, unsigned int, unsigned int, struct page___75 *, void *);
	sector_t (*bmap)(struct address_space___74 *, sector_t);
	void (*invalidatepage)(struct page___75 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___75 *, gfp_t);
	void (*freepage)(struct page___75 *);
	ssize_t (*direct_IO)(struct kiocb___75 *, struct iov_iter___29 *);
	int (*migratepage)(struct address_space___74 *, struct page___75 *, struct page___75 *, enum migrate_mode);
	bool (*isolate_page)(struct page___75 *, isolate_mode_t);
	void (*putback_page)(struct page___75 *);
	int (*launder_page)(struct page___75 *);
	int (*is_partially_uptodate)(struct page___75 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___75 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___74 *, struct page___75 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___75 *, sector_t *);
	void (*swap_deactivate)(struct file___75 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___75 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___76 *bd_inode;
	struct super_block___75 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___75 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___74 {
	struct dentry___75 * (*lookup)(struct inode___76 *, struct dentry___75 *, unsigned int);
	const char * (*get_link)(struct dentry___75 *, struct inode___76 *, struct delayed_call *);
	int (*permission)(struct inode___76 *, int);
	struct posix_acl * (*get_acl)(struct inode___76 *, int);
	int (*readlink)(struct dentry___75 *, char *, int);
	int (*create)(struct inode___76 *, struct dentry___75 *, umode_t, bool);
	int (*link)(struct dentry___75 *, struct inode___76 *, struct dentry___75 *);
	int (*unlink)(struct inode___76 *, struct dentry___75 *);
	int (*symlink)(struct inode___76 *, struct dentry___75 *, const char *);
	int (*mkdir)(struct inode___76 *, struct dentry___75 *, umode_t);
	int (*rmdir)(struct inode___76 *, struct dentry___75 *);
	int (*mknod)(struct inode___76 *, struct dentry___75 *, umode_t, dev_t);
	int (*rename)(struct inode___76 *, struct dentry___75 *, struct inode___76 *, struct dentry___75 *, unsigned int);
	int (*setattr)(struct dentry___75 *, struct iattr___75 *);
	int (*getattr)(const struct path___74 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___75 *, char *, size_t);
	int (*fiemap)(struct inode___76 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___76 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___76 *, struct dentry___75 *, struct file___75 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___76 *, struct dentry___75 *, umode_t);
	int (*set_acl)(struct inode___76 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___74 {
	void (*fl_copy_lock)(struct file_lock___75 *, struct file_lock___75 *);
	void (*fl_release_private)(struct file_lock___75 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___74;

struct file_lock___75 {
	struct file_lock___75 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___75 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___74 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___74 *fl_ops;
	const struct lock_manager_operations___74 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___74 {
	int (*lm_compare_owner)(struct file_lock___75 *, struct file_lock___75 *);
	long unsigned int (*lm_owner_key)(struct file_lock___75 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___75 *);
	int (*lm_grant)(struct file_lock___75 *, int);
	bool (*lm_break)(struct file_lock___75 *);
	int (*lm_change)(struct file_lock___75 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___75 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___74 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___74 *fa_next;
	struct file___75 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___74 {
	const char *name;
	int fs_flags;
	struct dentry___75 * (*mount)(struct file_system_type___74 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___75 *);
	struct module___67 *owner;
	struct file_system_type___74 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___74 {
	struct inode___76 * (*alloc_inode)(struct super_block___75 *);
	void (*destroy_inode)(struct inode___76 *);
	void (*dirty_inode)(struct inode___76 *, int);
	int (*write_inode)(struct inode___76 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___76 *);
	void (*evict_inode)(struct inode___76 *);
	void (*put_super)(struct super_block___75 *);
	int (*sync_fs)(struct super_block___75 *, int);
	int (*freeze_super)(struct super_block___75 *);
	int (*freeze_fs)(struct super_block___75 *);
	int (*thaw_super)(struct super_block___75 *);
	int (*unfreeze_fs)(struct super_block___75 *);
	int (*statfs)(struct dentry___75 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___75 *, int *, char *);
	void (*umount_begin)(struct super_block___75 *);
	int (*show_options)(struct seq_file___69 *, struct dentry___75 *);
	int (*show_devname)(struct seq_file___69 *, struct dentry___75 *);
	int (*show_path)(struct seq_file___69 *, struct dentry___75 *);
	int (*show_stats)(struct seq_file___69 *, struct dentry___75 *);
	ssize_t (*quota_read)(struct super_block___75 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___75 *, int, const char *, size_t, loff_t);
	struct dquot___74 ** (*get_dquots)(struct inode___76 *);
	int (*bdev_try_to_free_page)(struct super_block___75 *, struct page___75 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___75 *, struct shrink_control___29 *);
	long int (*free_cached_objects)(struct super_block___75 *, struct shrink_control___29 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___74(struct page___75 *);

typedef int (*key_restrict_link_func_t___71)(struct key___72 *, const struct key_type *, const union key_payload *, struct key___72 *);

struct key_restriction___72;

struct key___72 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___75 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___72 *restrict_link;
};

struct key_restriction___72 {
	key_restrict_link_func_t___71 check;
	struct key___72 *key;
	struct key_type *keytype;
};

struct seq_operations___66 {
	void * (*start)(struct seq_file___69 *, loff_t *);
	void (*stop)(struct seq_file___69 *, void *);
	void * (*next)(struct seq_file___69 *, void *, loff_t *);
	int (*show)(struct seq_file___69 *, void *);
};

struct cgroup_namespace___59 {
	refcount_t count;
	struct ns_common ns;
	struct user_namespace___61 *user_ns;
	struct ucounts___61 *ucounts;
	struct css_set___59 *root_cset;
};

struct ucounts___61 {
	struct hlist_node node;
	struct user_namespace___61 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___59;

struct bpf_map_ops___59 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___59 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___59 *, struct file___75 *);
	void (*map_free)(struct bpf_map___59 *);
	int (*map_get_next_key)(struct bpf_map___59 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___59 *);
	void * (*map_lookup_elem)(struct bpf_map___59 *, void *);
	int (*map_update_elem)(struct bpf_map___59 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___59 *, void *);
	int (*map_push_elem)(struct bpf_map___59 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___59 *, void *);
	int (*map_peek_elem)(struct bpf_map___59 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___59 *, struct file___75 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___59 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___59 *, void *, struct seq_file___69 *);
	int (*map_check_btf)(const struct bpf_map___59 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___59 {
	const struct bpf_map_ops___59 *ops;
	struct bpf_map___59 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___71 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___59;

typedef void (*kthread_work_func_t___59)(struct kthread_work___59 *);

struct kthread_worker___59;

struct kthread_work___59 {
	struct list_head node;
	kthread_work_func_t___59 func;
	struct kthread_worker___59 *worker;
	int canceling;
};

struct kthread_worker___59 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___75 *task;
	struct kthread_work___59 *current_work;
};

struct kthread_delayed_work___59 {
	struct kthread_work___59 work;
	struct timer_list timer;
};

struct psi_group___59 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___59 *poll_kworker;
	struct kthread_delayed_work___59 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___59 {
	struct kernfs_node___72 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___59;

struct cgroup_subsys_state___59 {
	struct cgroup___59 *cgroup;
	struct cgroup_subsys___59 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___59 *parent;
};

struct cgroup_root___59;

struct cgroup_rstat_cpu___59;

struct cgroup___59 {
	struct cgroup_subsys_state___59 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___72 *kn;
	struct cgroup_file___59 procs_file;
	struct cgroup_file___59 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___59 *subsys[13];
	struct cgroup_root___59 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___59 *dom_cgrp;
	struct cgroup_rstat_cpu___59 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf bpf;
	atomic_t congestion_count;
	struct cgroup___59 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___59 psi;
	int ancestor_ids[0];
};

struct cftype___59;

struct cgroup_subsys___59 {
	struct cgroup_subsys_state___59 * (*css_alloc)(struct cgroup_subsys_state___59 *);
	int (*css_online)(struct cgroup_subsys_state___59 *);
	void (*css_offline)(struct cgroup_subsys_state___59 *);
	void (*css_released)(struct cgroup_subsys_state___59 *);
	void (*css_free)(struct cgroup_subsys_state___59 *);
	void (*css_reset)(struct cgroup_subsys_state___59 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___59 *, int);
	int (*css_extra_stat_show)(struct seq_file___69 *, struct cgroup_subsys_state___59 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___75 *);
	void (*cancel_fork)(struct task_struct___75 *);
	void (*fork)(struct task_struct___75 *);
	void (*exit)(struct task_struct___75 *);
	void (*free)(struct task_struct___75 *);
	void (*bind)(struct cgroup_subsys_state___59 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___59 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___59 *dfl_cftypes;
	struct cftype___59 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___59 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___59 *updated_children;
	struct cgroup___59 *updated_next;
};

struct cgroup_root___59 {
	struct kernfs_root___72 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___59 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___59 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___59 *ss;
	struct list_head node;
	struct kernfs_ops___72 *kf_ops;
	int (*open)(struct kernfs_open_file___72 *);
	void (*release)(struct kernfs_open_file___72 *);
	u64 (*read_u64)(struct cgroup_subsys_state___59 *, struct cftype___59 *);
	s64 (*read_s64)(struct cgroup_subsys_state___59 *, struct cftype___59 *);
	int (*seq_show)(struct seq_file___69 *, void *);
	void * (*seq_start)(struct seq_file___69 *, loff_t *);
	void * (*seq_next)(struct seq_file___69 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___69 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___59 *, struct cftype___59 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___59 *, struct cftype___59 *, s64);
	ssize_t (*write)(struct kernfs_open_file___72 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___72 *, struct poll_table_struct___50 *);
};

struct perf_cpu_context___48;

struct pmu___48 {
	struct list_head entry;
	struct module___67 *module;
	struct device___70 *dev;
	const struct attribute_group___69 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___48 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___48 *);
	void (*pmu_disable)(struct pmu___48 *);
	int (*event_init)(struct perf_event___48 *);
	void (*event_mapped)(struct perf_event___48 *, struct mm_struct___74 *);
	void (*event_unmapped)(struct perf_event___48 *, struct mm_struct___74 *);
	int (*add)(struct perf_event___48 *, int);
	void (*del)(struct perf_event___48 *, int);
	void (*start)(struct perf_event___48 *, int);
	void (*stop)(struct perf_event___48 *, int);
	void (*read)(struct perf_event___48 *);
	void (*start_txn)(struct pmu___48 *, unsigned int);
	int (*commit_txn)(struct pmu___48 *);
	void (*cancel_txn)(struct pmu___48 *);
	int (*event_idx)(struct perf_event___48 *);
	void (*sched_task)(struct perf_event_context___48 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___48 *);
	int (*filter_match)(struct perf_event___48 *);
	int (*check_period)(struct perf_event___48 *, u64);
};

struct perf_cpu_context___48 {
	struct perf_event_context___48 ctx;
	struct perf_event_context___48 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___48 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___48 {
	struct cgroup_subsys_state___59 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___43 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___43 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___43 *);
	struct list_head * (*get_fields)(struct trace_event_call___43 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___43 *);
};

struct fwnode_reference_args___51;

struct fwnode_endpoint___51;

struct fwnode_operations___51 {
	struct fwnode_handle___51 * (*get)(struct fwnode_handle___51 *);
	void (*put)(struct fwnode_handle___51 *);
	bool (*device_is_available)(const struct fwnode_handle___51 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___51 *, const struct device___70 *);
	bool (*property_present)(const struct fwnode_handle___51 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___51 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___51 *, const char *, const char **, size_t);
	struct fwnode_handle___51 * (*get_parent)(const struct fwnode_handle___51 *);
	struct fwnode_handle___51 * (*get_next_child_node)(const struct fwnode_handle___51 *, struct fwnode_handle___51 *);
	struct fwnode_handle___51 * (*get_named_child_node)(const struct fwnode_handle___51 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___51 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___51 *);
	struct fwnode_handle___51 * (*graph_get_next_endpoint)(const struct fwnode_handle___51 *, struct fwnode_handle___51 *);
	struct fwnode_handle___51 * (*graph_get_remote_endpoint)(const struct fwnode_handle___51 *);
	struct fwnode_handle___51 * (*graph_get_port_parent)(struct fwnode_handle___51 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___51 *, struct fwnode_endpoint___51 *);
};

struct fwnode_endpoint___51 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___51 *local_fwnode;
};

struct fwnode_reference_args___51 {
	struct fwnode_handle___51 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct property___24 {
	char *name;
	int length;
	void *value;
	struct property___24 *next;
	long unsigned int _flags;
	struct bin_attribute___69 attr;
};

enum tick_broadcast_state {
	TICK_BROADCAST_EXIT = 0,
	TICK_BROADCAST_ENTER = 1,
};

enum tick_broadcast_mode {
	TICK_BROADCAST_OFF = 0,
	TICK_BROADCAST_ON = 1,
	TICK_BROADCAST_FORCE = 2,
};

struct clock_read_data {
	u64 epoch_ns;
	u64 epoch_cyc;
	u64 sched_clock_mask;
	u64 (*read_sched_clock)();
	u32 mult;
	u32 shift;
};

struct clock_data {
	seqcount_t seq;
	struct clock_read_data read_data[2];
	ktime_t wrap_kt;
	long unsigned int rate;
	u64 (*actual_read_sched_clock)();
};

struct module___68;

struct file___76;

struct kiocb___76;

struct poll_table_struct___51;

struct vm_area_struct___76;

struct inode___77;

struct file_lock___76;

struct page___76;

struct seq_file___70;

struct file_operations___76 {
	struct module___68 *owner;
	loff_t (*llseek)(struct file___76 *, loff_t, int);
	ssize_t (*read)(struct file___76 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___76 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___76 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___76 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___76 *, bool);
	int (*iterate)(struct file___76 *, struct dir_context *);
	int (*iterate_shared)(struct file___76 *, struct dir_context *);
	__poll_t (*poll)(struct file___76 *, struct poll_table_struct___51 *);
	long int (*unlocked_ioctl)(struct file___76 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___76 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___76 *, struct vm_area_struct___76 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___77 *, struct file___76 *);
	int (*flush)(struct file___76 *, fl_owner_t);
	int (*release)(struct inode___77 *, struct file___76 *);
	int (*fsync)(struct file___76 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___76 *, int);
	int (*lock)(struct file___76 *, int, struct file_lock___76 *);
	ssize_t (*sendpage)(struct file___76 *, struct page___76 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___76 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___76 *, int, struct file_lock___76 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___76 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___76 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___76 *, long int, struct file_lock___76 **, void **);
	long int (*fallocate)(struct file___76 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___70 *, struct file___76 *);
	ssize_t (*copy_file_range)(struct file___76 *, loff_t, struct file___76 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___76 *, loff_t, struct file___76 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___76 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___75 {
	u64 seqnum;
	struct vm_area_struct___76 *vmas[4];
};

struct page_frag___75 {
	struct page___76 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___75;

struct cred___72;

struct signal_struct___66;

struct vm_struct___54;

struct task_struct___76 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___76 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___75 *mm;
	struct mm_struct___75 *active_mm;
	struct vmacache___75 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___76 *real_parent;
	struct task_struct___76 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___76 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___63 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___63 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___63 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___72 *ptracer_cred;
	const struct cred___72 *real_cred;
	const struct cred___72 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___66 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___76 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___13 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___75 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___76 *oom_reaper_list;
	struct vm_struct___54 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___48 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___76 *pgtable_t___75;

struct address_space___75;

struct dev_pagemap___75;

struct page___76 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___75 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___76 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___75 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___75 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___75 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___75;

struct lruvec___75 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___75 *pgdat;
};

struct zone___75 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___75 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___75 {
	struct zone___75 *zone;
	int zone_idx;
};

struct zonelist___75 {
	struct zoneref___75 _zonerefs[25];
};

struct pglist_data___75 {
	struct zone___75 node_zones[3];
	struct zonelist___75 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___76 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___76 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___75 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___76 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___76 *owner;
};

struct secondary_data___76 {
	void *stack;
	struct task_struct___76 *task;
	long int status;
};

struct clock_event_device___15;

struct arch_timer_erratum_workaround___15 {
	enum arch_timer_erratum_match_type match_type;
	const void *id;
	const char *desc;
	u32 (*read_cntp_tval_el0)();
	u32 (*read_cntv_tval_el0)();
	u64 (*read_cntpct_el0)();
	u64 (*read_cntvct_el0)();
	int (*set_next_event_phys)(long unsigned int, struct clock_event_device___15 *);
	int (*set_next_event_virt)(long unsigned int, struct clock_event_device___15 *);
};

struct clock_event_device___15 {
	void (*event_handler)(struct clock_event_device___15 *);
	int (*set_next_event)(long unsigned int, struct clock_event_device___15 *);
	int (*set_next_ktime)(ktime_t, struct clock_event_device___15 *);
	ktime_t next_event;
	u64 max_delta_ns;
	u64 min_delta_ns;
	u32 mult;
	u32 shift;
	enum clock_event_state state_use_accessors;
	unsigned int features;
	long unsigned int retries;
	int (*set_state_periodic)(struct clock_event_device___15 *);
	int (*set_state_oneshot)(struct clock_event_device___15 *);
	int (*set_state_oneshot_stopped)(struct clock_event_device___15 *);
	int (*set_state_shutdown)(struct clock_event_device___15 *);
	int (*tick_resume)(struct clock_event_device___15 *);
	void (*broadcast)(const struct cpumask *);
	void (*suspend)(struct clock_event_device___15 *);
	void (*resume)(struct clock_event_device___15 *);
	long unsigned int min_delta_ticks;
	long unsigned int max_delta_ticks;
	const char *name;
	int rating;
	int irq;
	int bound_on;
	const struct cpumask *cpumask;
	struct list_head list;
	struct module___68 *owner;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct blocking_notifier_head___75 {
	struct rw_semaphore___76 rwsem;
	struct notifier_block *head;
};

struct kernfs_root___73;

struct kernfs_elem_dir___73 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___73 *root;
};

struct kernfs_node___73;

struct kernfs_syscall_ops___73;

struct kernfs_root___73 {
	struct kernfs_node___73 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___73 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___73 {
	struct kernfs_node___73 *target_kn;
};

struct kernfs_ops___73;

struct kernfs_elem_attr___73 {
	const struct kernfs_ops___73 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___73 *notify_next;
};

struct kernfs_node___73 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___73 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___73 dir;
		struct kernfs_elem_symlink___73 symlink;
		struct kernfs_elem_attr___73 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___73;

struct kernfs_ops___73 {
	int (*open)(struct kernfs_open_file___73 *);
	void (*release)(struct kernfs_open_file___73 *);
	int (*seq_show)(struct seq_file___70 *, void *);
	void * (*seq_start)(struct seq_file___70 *, loff_t *);
	void * (*seq_next)(struct seq_file___70 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___70 *, void *);
	ssize_t (*read)(struct kernfs_open_file___73 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___73 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___73 *, struct vm_area_struct___76 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___73 *, struct poll_table_struct___51 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___73 {
	int (*remount_fs)(struct kernfs_root___73 *, int *, char *);
	int (*show_options)(struct seq_file___70 *, struct kernfs_root___73 *);
	int (*mkdir)(struct kernfs_node___73 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___73 *);
	int (*rename)(struct kernfs_node___73 *, struct kernfs_node___73 *, const char *);
	int (*show_path)(struct seq_file___70 *, struct kernfs_node___73 *, struct kernfs_root___73 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___67;

struct seq_file___70 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___67 *op;
	int poll_event;
	const struct file___76 *file;
	void *private;
};

struct vm_operations_struct___75;

struct kernfs_open_file___73 {
	struct kernfs_node___73 *kn;
	struct file___76 *file;
	struct seq_file___70 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___75 *vm_ops;
};

struct dentry___76;

struct path___75 {
	struct vfsmount *mnt;
	struct dentry___76 *dentry;
};

struct file___76 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___75 f_path;
	struct inode___77 *f_inode;
	const struct file_operations___76 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___63 f_owner;
	const struct cred___72 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___75 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___75;

struct vm_operations_struct___75 {
	void (*open)(struct vm_area_struct___76 *);
	void (*close)(struct vm_area_struct___76 *);
	int (*split)(struct vm_area_struct___76 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___76 *);
	vm_fault_t (*fault)(struct vm_fault___75 *);
	vm_fault_t (*huge_fault)(struct vm_fault___75 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___75 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___76 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___75 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___75 *);
	int (*access)(struct vm_area_struct___76 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___76 *);
	int (*set_policy)(struct vm_area_struct___76 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___76 *, long unsigned int);
	struct page___76 * (*find_special_page)(struct vm_area_struct___76 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___50)(struct file___76 *, wait_queue_head_t *, struct poll_table_struct___51 *);

struct poll_table_struct___51 {
	poll_queue_proc___50 _qproc;
	__poll_t _key;
};

struct vm_area_struct___76 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___76 *vm_next;
	struct vm_area_struct___76 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___75 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___75 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___76 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___73;

struct bin_attribute___70;

struct attribute_group___70 {
	const char *name;
	umode_t (*is_visible)(struct kobject___73 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___73 *, struct bin_attribute___70 *, int);
	struct attribute **attrs;
	struct bin_attribute___70 **bin_attrs;
};

struct kset___72;

struct kobj_type___72;

struct kobject___73 {
	const char *name;
	struct list_head entry;
	struct kobject___73 *parent;
	struct kset___72 *kset;
	struct kobj_type___72 *ktype;
	struct kernfs_node___73 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___70 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___76 *, struct kobject___73 *, struct bin_attribute___70 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___76 *, struct kobject___73 *, struct bin_attribute___70 *, char *, loff_t, size_t);
	int (*mmap)(struct file___76 *, struct kobject___73 *, struct bin_attribute___70 *, struct vm_area_struct___76 *);
};

struct sysfs_ops___72 {
	ssize_t (*show)(struct kobject___73 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___73 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___72;

struct kset___72 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___73 kobj;
	const struct kset_uevent_ops___72 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___72 {
	void (*release)(struct kobject___73 *);
	const struct sysfs_ops___72 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___73 *);
	const void * (*namespace)(struct kobject___73 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___72 {
	int (* const filter)(struct kset___72 *, struct kobject___73 *);
	const char * (* const name)(struct kset___72 *, struct kobject___73 *);
	int (* const uevent)(struct kset___72 *, struct kobject___73 *, struct kobj_uevent_env *);
};

struct kobj_attribute___73 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___73 *, struct kobj_attribute___73 *, char *);
	ssize_t (*store)(struct kobject___73 *, struct kobj_attribute___73 *, const char *, size_t);
};

struct device___71;

struct dev_pm_ops___71 {
	int (*prepare)(struct device___71 *);
	void (*complete)(struct device___71 *);
	int (*suspend)(struct device___71 *);
	int (*resume)(struct device___71 *);
	int (*freeze)(struct device___71 *);
	int (*thaw)(struct device___71 *);
	int (*poweroff)(struct device___71 *);
	int (*restore)(struct device___71 *);
	int (*suspend_late)(struct device___71 *);
	int (*resume_early)(struct device___71 *);
	int (*freeze_late)(struct device___71 *);
	int (*thaw_early)(struct device___71 *);
	int (*poweroff_late)(struct device___71 *);
	int (*restore_early)(struct device___71 *);
	int (*suspend_noirq)(struct device___71 *);
	int (*resume_noirq)(struct device___71 *);
	int (*freeze_noirq)(struct device___71 *);
	int (*thaw_noirq)(struct device___71 *);
	int (*poweroff_noirq)(struct device___71 *);
	int (*restore_noirq)(struct device___71 *);
	int (*runtime_suspend)(struct device___71 *);
	int (*runtime_resume)(struct device___71 *);
	int (*runtime_idle)(struct device___71 *);
};

struct dev_pm_info___71 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___71 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___71;

struct bus_type___71;

struct device_driver___71;

struct dev_pm_domain___71;

struct device_node___26;

struct fwnode_handle___52;

struct class___71;

struct device___71 {
	struct device___71 *parent;
	struct device_private *p;
	struct kobject___73 kobj;
	const char *init_name;
	const struct device_type___71 *type;
	struct mutex mutex;
	struct bus_type___71 *bus;
	struct device_driver___71 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___71 power;
	struct dev_pm_domain___71 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___26 *of_node;
	struct fwnode_handle___52 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___71 *class;
	const struct attribute_group___70 **groups;
	void (*release)(struct device___71 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___71 {
	struct dev_pm_ops___71 ops;
	void (*detach)(struct device___71 *, bool);
	int (*activate)(struct device___71 *);
	void (*sync)(struct device___71 *);
	void (*dismiss)(struct device___71 *);
};

struct tick_device___8 {
	struct clock_event_device___15 *evtdev;
	enum tick_device_mode mode;
};

struct key___73;

struct user_struct___72 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___73 *uid_keyring;
	struct key___73 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___75;

struct mm_struct___75 {
	struct {
		struct vm_area_struct___76 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___76 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___76 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___75 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___76 *owner;
		struct user_namespace___3 *user_ns;
		struct file___76 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___75 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___72 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___73 *session_keyring;
	struct key___73 *process_keyring;
	struct key___73 *thread_keyring;
	struct key___73 *request_key_auth;
	void *security;
	struct user_struct___72 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct signal_struct___66 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___76 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___76 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___63 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___63 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___75 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___63 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_struct___54 {
	struct vm_struct___54 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___76 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___66 {
	struct task_struct___76 task;
	long unsigned int stack[8192];
};

struct bus_type___71 {
	const char *name;
	const char *dev_name;
	struct device___71 *dev_root;
	const struct attribute_group___70 **bus_groups;
	const struct attribute_group___70 **dev_groups;
	const struct attribute_group___70 **drv_groups;
	int (*match)(struct device___71 *, struct device_driver___71 *);
	int (*uevent)(struct device___71 *, struct kobj_uevent_env *);
	int (*probe)(struct device___71 *);
	int (*remove)(struct device___71 *);
	void (*shutdown)(struct device___71 *);
	int (*online)(struct device___71 *);
	int (*offline)(struct device___71 *);
	int (*suspend)(struct device___71 *, pm_message_t);
	int (*resume)(struct device___71 *);
	int (*num_vf)(struct device___71 *);
	int (*dma_configure)(struct device___71 *);
	const struct dev_pm_ops___71 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___71 {
	const char *name;
	struct bus_type___71 *bus;
	struct module___68 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___71 *);
	int (*remove)(struct device___71 *);
	void (*shutdown)(struct device___71 *);
	int (*suspend)(struct device___71 *, pm_message_t);
	int (*resume)(struct device___71 *);
	const struct attribute_group___70 **groups;
	const struct dev_pm_ops___71 *pm;
	void (*coredump)(struct device___71 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___71 {
	const char *name;
	const struct attribute_group___70 **groups;
	int (*uevent)(struct device___71 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___71 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___71 *);
	const struct dev_pm_ops___71 *pm;
};

struct module_kobject___65 {
	struct kobject___73 kobj;
	struct module___68 *mod;
	struct kobject___73 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___65 {
	struct module___68 *mod;
	struct latch_tree_node node;
};

struct module_layout___65 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___65 mtn;
};

struct module_attribute___65;

struct kernel_param___65;

struct module___68 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___65 mkobj;
	struct module_attribute___65 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___73 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___65 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___65 core_layout;
	struct module_layout___65 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct class___71 {
	const char *name;
	struct module___68 *owner;
	const struct attribute_group___70 **class_groups;
	const struct attribute_group___70 **dev_groups;
	struct kobject___73 *dev_kobj;
	int (*dev_uevent)(struct device___71 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___71 *, umode_t *);
	void (*class_release)(struct class___71 *);
	void (*dev_release)(struct device___71 *);
	int (*shutdown_pre)(struct device___71 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___71 *);
	const struct dev_pm_ops___71 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct fwnode_operations___52;

struct fwnode_handle___52 {
	struct fwnode_handle___52 *secondary;
	const struct fwnode_operations___52 *ops;
};

struct property___25;

struct device_node___26 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___52 fwnode;
	struct property___25 *properties;
	struct property___25 *deadprops;
	struct device_node___26 *parent;
	struct device_node___26 *child;
	struct device_node___26 *sibling;
	struct kobject___73 kobj;
	long unsigned int _flags;
	void *data;
};

struct node___62 {
	struct device___71 dev;
};

typedef int (*key_restrict_link_func_t___72)(struct key___73 *, const struct key_type *, const union key_payload *, struct key___73 *);

struct key_restriction___73;

struct key___73 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___76 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___73 *restrict_link;
};

struct key_restriction___73 {
	key_restrict_link_func_t___72 check;
	struct key___73 *key;
	struct key_type *keytype;
};

struct kernel_param_ops___65 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___65 *);
	int (*get)(char *, const struct kernel_param___65 *);
	void (*free)(void *);
};

struct kparam_array___65;

struct kernel_param___65 {
	const char *name;
	struct module___68 *mod;
	const struct kernel_param_ops___65 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___65 *arr;
	};
};

struct kparam_array___65 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___65 *ops;
	void *elem;
};

struct module_attribute___65 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___65 *, struct module_kobject___65 *, char *);
	ssize_t (*store)(struct module_attribute___65 *, struct module_kobject___65 *, const char *, size_t);
	void (*setup)(struct module___68 *, const char *);
	int (*test)(struct module___68 *);
	void (*free)(struct module___68 *);
};

struct dentry_operations___75;

struct super_block___76;

struct dentry___76 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___76 *d_parent;
	struct qstr d_name;
	struct inode___77 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___75 *d_op;
	struct super_block___76 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___75;

struct address_space___75 {
	struct inode___77 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___76 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___75 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___75;

struct block_device___76;

struct cdev___22;

struct inode___77 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___75 *i_op;
	struct super_block___76 *i_sb;
	struct address_space___75 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___76 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___76 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___75 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___76 *i_bdev;
		struct cdev___22 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___75 {
	int (*d_revalidate)(struct dentry___76 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___76 *, unsigned int);
	int (*d_hash)(const struct dentry___76 *, struct qstr *);
	int (*d_compare)(const struct dentry___76 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___76 *);
	int (*d_init)(struct dentry___76 *);
	void (*d_release)(struct dentry___76 *);
	void (*d_prune)(struct dentry___76 *);
	void (*d_iput)(struct dentry___76 *, struct inode___77 *);
	char * (*d_dname)(struct dentry___76 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___75 *);
	int (*d_manage)(const struct path___75 *, bool);
	struct dentry___76 * (*d_real)(struct dentry___76 *, const struct inode___77 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___75;

struct mem_dqinfo___75 {
	struct quota_format_type___75 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___75;

struct quota_info___75 {
	unsigned int flags;
	struct rw_semaphore___76 dqio_sem;
	struct inode___77 *files[3];
	struct mem_dqinfo___75 info[3];
	const struct quota_format_ops___75 *ops[3];
};

struct rcuwait___75 {
	struct task_struct___76 *task;
};

struct percpu_rw_semaphore___75 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___76 rw_sem;
	struct rcuwait___75 writer;
	int readers_block;
};

struct sb_writers___75 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___75 rw_sem[3];
};

struct file_system_type___75;

struct super_operations___75;

struct dquot_operations___75;

struct quotactl_ops___75;

struct super_block___76 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___75 *s_type;
	const struct super_operations___75 *s_op;
	const struct dquot_operations___75 *dq_op;
	const struct quotactl_ops___75 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___76 *s_root;
	struct rw_semaphore___76 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___76 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___75 s_dquot;
	struct sb_writers___75 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___75 *s_d_op;
	int cleancache_poolid;
	struct shrinker___29 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

typedef int (*dev_page_fault_t___75)(struct vm_area_struct___76 *, long unsigned int, const struct page___76 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___75)(struct page___76 *, void *);

struct dev_pagemap___75 {
	dev_page_fault_t___75 page_fault;
	dev_page_free_t___75 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___71 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___75 {
	struct task_struct___76 *task;
	struct core_thread___75 *next;
};

struct core_state___75 {
	atomic_t nr_threads;
	struct core_thread___75 dumper;
	struct completion startup;
};

struct vm_fault___75 {
	struct vm_area_struct___76 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___76 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___76 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___75 prealloc_pte;
};

struct kiocb___76 {
	struct file___76 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___76 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___76 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___76 *ia_file;
};

struct dquot___75 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___76 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___75 {
	int qf_fmt_id;
	const struct quota_format_ops___75 *qf_ops;
	struct module___68 *qf_owner;
	struct quota_format_type___75 *qf_next;
};

struct quota_format_ops___75 {
	int (*check_quota_file)(struct super_block___76 *, int);
	int (*read_file_info)(struct super_block___76 *, int);
	int (*write_file_info)(struct super_block___76 *, int);
	int (*free_file_info)(struct super_block___76 *, int);
	int (*read_dqblk)(struct dquot___75 *);
	int (*commit_dqblk)(struct dquot___75 *);
	int (*release_dqblk)(struct dquot___75 *);
	int (*get_next_id)(struct super_block___76 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___75 {
	int (*write_dquot)(struct dquot___75 *);
	struct dquot___75 * (*alloc_dquot)(struct super_block___76 *, int);
	void (*destroy_dquot)(struct dquot___75 *);
	int (*acquire_dquot)(struct dquot___75 *);
	int (*release_dquot)(struct dquot___75 *);
	int (*mark_dirty)(struct dquot___75 *);
	int (*write_info)(struct super_block___76 *, int);
	qsize_t * (*get_reserved_space)(struct inode___77 *);
	int (*get_projid)(struct inode___77 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___77 *, qsize_t *);
	int (*get_next_id)(struct super_block___76 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___75 {
	int (*quota_on)(struct super_block___76 *, int, int, const struct path___75 *);
	int (*quota_off)(struct super_block___76 *, int);
	int (*quota_enable)(struct super_block___76 *, unsigned int);
	int (*quota_disable)(struct super_block___76 *, unsigned int);
	int (*quota_sync)(struct super_block___76 *, int);
	int (*set_info)(struct super_block___76 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___76 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___76 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___76 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___76 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___76 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___75 {
	int (*writepage)(struct page___76 *, struct writeback_control___3 *);
	int (*readpage)(struct file___76 *, struct page___76 *);
	int (*writepages)(struct address_space___75 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___76 *);
	int (*readpages)(struct file___76 *, struct address_space___75 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___76 *, struct address_space___75 *, loff_t, unsigned int, unsigned int, struct page___76 **, void **);
	int (*write_end)(struct file___76 *, struct address_space___75 *, loff_t, unsigned int, unsigned int, struct page___76 *, void *);
	sector_t (*bmap)(struct address_space___75 *, sector_t);
	void (*invalidatepage)(struct page___76 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___76 *, gfp_t);
	void (*freepage)(struct page___76 *);
	ssize_t (*direct_IO)(struct kiocb___76 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___75 *, struct page___76 *, struct page___76 *, enum migrate_mode);
	bool (*isolate_page)(struct page___76 *, isolate_mode_t);
	void (*putback_page)(struct page___76 *);
	int (*launder_page)(struct page___76 *);
	int (*is_partially_uptodate)(struct page___76 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___76 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___75 *, struct page___76 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___76 *, sector_t *);
	void (*swap_deactivate)(struct file___76 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___76 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___77 *bd_inode;
	struct super_block___76 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___76 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___22 {
	struct kobject___73 kobj;
	struct module___68 *owner;
	const struct file_operations___76 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___75 {
	struct dentry___76 * (*lookup)(struct inode___77 *, struct dentry___76 *, unsigned int);
	const char * (*get_link)(struct dentry___76 *, struct inode___77 *, struct delayed_call *);
	int (*permission)(struct inode___77 *, int);
	struct posix_acl * (*get_acl)(struct inode___77 *, int);
	int (*readlink)(struct dentry___76 *, char *, int);
	int (*create)(struct inode___77 *, struct dentry___76 *, umode_t, bool);
	int (*link)(struct dentry___76 *, struct inode___77 *, struct dentry___76 *);
	int (*unlink)(struct inode___77 *, struct dentry___76 *);
	int (*symlink)(struct inode___77 *, struct dentry___76 *, const char *);
	int (*mkdir)(struct inode___77 *, struct dentry___76 *, umode_t);
	int (*rmdir)(struct inode___77 *, struct dentry___76 *);
	int (*mknod)(struct inode___77 *, struct dentry___76 *, umode_t, dev_t);
	int (*rename)(struct inode___77 *, struct dentry___76 *, struct inode___77 *, struct dentry___76 *, unsigned int);
	int (*setattr)(struct dentry___76 *, struct iattr___76 *);
	int (*getattr)(const struct path___75 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___76 *, char *, size_t);
	int (*fiemap)(struct inode___77 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___77 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___77 *, struct dentry___76 *, struct file___76 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___77 *, struct dentry___76 *, umode_t);
	int (*set_acl)(struct inode___77 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___75 {
	void (*fl_copy_lock)(struct file_lock___76 *, struct file_lock___76 *);
	void (*fl_release_private)(struct file_lock___76 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___75;

struct lock_manager_operations___75;

struct file_lock___76 {
	struct file_lock___76 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___76 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___75 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___75 *fl_ops;
	const struct lock_manager_operations___75 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___75 {
	int (*lm_compare_owner)(struct file_lock___76 *, struct file_lock___76 *);
	long unsigned int (*lm_owner_key)(struct file_lock___76 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___76 *);
	int (*lm_grant)(struct file_lock___76 *, int);
	bool (*lm_break)(struct file_lock___76 *);
	int (*lm_change)(struct file_lock___76 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___76 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___75 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___75 *fa_next;
	struct file___76 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___75 {
	const char *name;
	int fs_flags;
	struct dentry___76 * (*mount)(struct file_system_type___75 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___76 *);
	struct module___68 *owner;
	struct file_system_type___75 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___75 {
	struct inode___77 * (*alloc_inode)(struct super_block___76 *);
	void (*destroy_inode)(struct inode___77 *);
	void (*dirty_inode)(struct inode___77 *, int);
	int (*write_inode)(struct inode___77 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___77 *);
	void (*evict_inode)(struct inode___77 *);
	void (*put_super)(struct super_block___76 *);
	int (*sync_fs)(struct super_block___76 *, int);
	int (*freeze_super)(struct super_block___76 *);
	int (*freeze_fs)(struct super_block___76 *);
	int (*thaw_super)(struct super_block___76 *);
	int (*unfreeze_fs)(struct super_block___76 *);
	int (*statfs)(struct dentry___76 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___76 *, int *, char *);
	void (*umount_begin)(struct super_block___76 *);
	int (*show_options)(struct seq_file___70 *, struct dentry___76 *);
	int (*show_devname)(struct seq_file___70 *, struct dentry___76 *);
	int (*show_path)(struct seq_file___70 *, struct dentry___76 *);
	int (*show_stats)(struct seq_file___70 *, struct dentry___76 *);
	ssize_t (*quota_read)(struct super_block___76 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___76 *, int, const char *, size_t, loff_t);
	struct dquot___75 ** (*get_dquots)(struct inode___77 *);
	int (*bdev_try_to_free_page)(struct super_block___76 *, struct page___76 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___76 *, struct shrink_control___29 *);
	long int (*free_cached_objects)(struct super_block___76 *, struct shrink_control___29 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___67 {
	void * (*start)(struct seq_file___70 *, loff_t *);
	void (*stop)(struct seq_file___70 *, void *);
	void * (*next)(struct seq_file___70 *, void *, loff_t *);
	int (*show)(struct seq_file___70 *, void *);
};

typedef void compound_page_dtor___75(struct page___76 *);

struct fwnode_reference_args___52;

struct fwnode_endpoint___52;

struct fwnode_operations___52 {
	struct fwnode_handle___52 * (*get)(struct fwnode_handle___52 *);
	void (*put)(struct fwnode_handle___52 *);
	bool (*device_is_available)(const struct fwnode_handle___52 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___52 *, const struct device___71 *);
	bool (*property_present)(const struct fwnode_handle___52 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___52 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___52 *, const char *, const char **, size_t);
	struct fwnode_handle___52 * (*get_parent)(const struct fwnode_handle___52 *);
	struct fwnode_handle___52 * (*get_next_child_node)(const struct fwnode_handle___52 *, struct fwnode_handle___52 *);
	struct fwnode_handle___52 * (*get_named_child_node)(const struct fwnode_handle___52 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___52 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___52 *);
	struct fwnode_handle___52 * (*graph_get_next_endpoint)(const struct fwnode_handle___52 *, struct fwnode_handle___52 *);
	struct fwnode_handle___52 * (*graph_get_remote_endpoint)(const struct fwnode_handle___52 *);
	struct fwnode_handle___52 * (*graph_get_port_parent)(struct fwnode_handle___52 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___52 *, struct fwnode_endpoint___52 *);
};

struct fwnode_endpoint___52 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___52 *local_fwnode;
};

struct fwnode_reference_args___52 {
	struct fwnode_handle___52 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct property___25 {
	char *name;
	int length;
	void *value;
	struct property___25 *next;
	long unsigned int _flags;
	struct bin_attribute___70 attr;
};

struct module___69;

struct file___77;

struct kiocb___77;

struct poll_table_struct___52;

struct vm_area_struct___77;

struct inode___78;

struct file_lock___77;

struct page___77;

struct seq_file___71;

struct file_operations___77 {
	struct module___69 *owner;
	loff_t (*llseek)(struct file___77 *, loff_t, int);
	ssize_t (*read)(struct file___77 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___77 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___77 *, struct iov_iter___29 *);
	ssize_t (*write_iter)(struct kiocb___77 *, struct iov_iter___29 *);
	int (*iopoll)(struct kiocb___77 *, bool);
	int (*iterate)(struct file___77 *, struct dir_context *);
	int (*iterate_shared)(struct file___77 *, struct dir_context *);
	__poll_t (*poll)(struct file___77 *, struct poll_table_struct___52 *);
	long int (*unlocked_ioctl)(struct file___77 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___77 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___77 *, struct vm_area_struct___77 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___78 *, struct file___77 *);
	int (*flush)(struct file___77 *, fl_owner_t);
	int (*release)(struct inode___78 *, struct file___77 *);
	int (*fsync)(struct file___77 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___77 *, int);
	int (*lock)(struct file___77 *, int, struct file_lock___77 *);
	ssize_t (*sendpage)(struct file___77 *, struct page___77 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___77 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___77 *, int, struct file_lock___77 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___77 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___77 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___77 *, long int, struct file_lock___77 **, void **);
	long int (*fallocate)(struct file___77 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___71 *, struct file___77 *);
	ssize_t (*copy_file_range)(struct file___77 *, loff_t, struct file___77 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___77 *, loff_t, struct file___77 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___77 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___76 {
	u64 seqnum;
	struct vm_area_struct___77 *vmas[4];
};

struct page_frag___76 {
	struct page___77 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___49;

struct debug_info___49 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___49 *hbp_break[16];
	struct perf_event___49 *hbp_watch[16];
};

struct thread_struct___49 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___49 debug;
	long: 64;
};

struct mm_struct___76;

struct pid___64;

struct cred___73;

struct nsproxy___71;

struct signal_struct___67;

struct rt_mutex_waiter___2;

struct css_set___60;

struct futex_pi_state___2;

struct perf_event_context___49;

struct task_struct___77 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___77 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___76 *mm;
	struct mm_struct___76 *active_mm;
	struct vmacache___76 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___77 *real_parent;
	struct task_struct___77 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___77 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___64 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___64 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___64 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___73 *ptracer_cred;
	const struct cred___73 *real_cred;
	const struct cred___73 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___71 *nsproxy;
	struct signal_struct___67 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___77 *pi_top_task;
	struct rt_mutex_waiter___2 *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___13 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___60 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state___2 *pi_state_cache;
	struct perf_event_context___49 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___76 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___77 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___49 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___49 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___77 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___49)(struct perf_event___49 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___49;

struct fasync_struct___76;

struct pid_namespace___64;

struct trace_event_call___44;

struct perf_cgroup___49;

struct perf_event___49 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___49 *group_leader;
	struct pmu___49 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___49 hw;
	struct perf_event_context___49 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___49 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___77 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___76 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___49 *);
	struct callback_head callback_head;
	struct pid_namespace___64 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___49 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___49 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___44 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___49 *cgrp;
	struct list_head sb_list;
};

typedef struct page___77 *pgtable_t___76;

struct address_space___76;

struct dev_pagemap___76;

struct page___77 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___76 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___77 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___76 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___76 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___76 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___76;

struct lruvec___76 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___76 *pgdat;
};

struct zone___76 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___76 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___76 {
	struct zone___76 *zone;
	int zone_idx;
};

struct zonelist___76 {
	struct zoneref___76 _zonerefs[25];
};

struct pglist_data___76 {
	struct zone___76 node_zones[3];
	struct zonelist___76 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___77 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___77 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___76 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___77 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___77 *owner;
};

struct secondary_data___77 {
	void *stack;
	struct task_struct___77 *task;
	long int status;
};

struct blocking_notifier_head___76 {
	struct rw_semaphore___77 rwsem;
	struct notifier_block *head;
};

struct dentry_operations___76;

struct super_block___77;

struct dentry___77 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___77 *d_parent;
	struct qstr d_name;
	struct inode___78 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___76 *d_op;
	struct super_block___77 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___76;

struct address_space___76 {
	struct inode___78 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___77 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___76 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___76;

struct block_device___77;

struct inode___78 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___76 *i_op;
	struct super_block___77 *i_sb;
	struct address_space___76 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___77 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___77 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___76 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___77 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vfsmount___10;

struct path___76;

struct dentry_operations___76 {
	int (*d_revalidate)(struct dentry___77 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___77 *, unsigned int);
	int (*d_hash)(const struct dentry___77 *, struct qstr *);
	int (*d_compare)(const struct dentry___77 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___77 *);
	int (*d_init)(struct dentry___77 *);
	void (*d_release)(struct dentry___77 *);
	void (*d_prune)(struct dentry___77 *);
	void (*d_iput)(struct dentry___77 *, struct inode___78 *);
	char * (*d_dname)(struct dentry___77 *, char *, int);
	struct vfsmount___10 * (*d_automount)(struct path___76 *);
	int (*d_manage)(const struct path___76 *, bool);
	struct dentry___77 * (*d_real)(struct dentry___77 *, const struct inode___78 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___76;

struct mem_dqinfo___76 {
	struct quota_format_type___76 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___76;

struct quota_info___76 {
	unsigned int flags;
	struct rw_semaphore___77 dqio_sem;
	struct inode___78 *files[3];
	struct mem_dqinfo___76 info[3];
	const struct quota_format_ops___76 *ops[3];
};

struct rcuwait___76 {
	struct task_struct___77 *task;
};

struct percpu_rw_semaphore___76 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___77 rw_sem;
	struct rcuwait___76 writer;
	int readers_block;
};

struct sb_writers___76 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___76 rw_sem[3];
};

struct file_system_type___76;

struct super_operations___76;

struct dquot_operations___76;

struct quotactl_ops___76;

struct user_namespace___62;

struct super_block___77 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___76 *s_type;
	const struct super_operations___76 *s_op;
	const struct dquot_operations___76 *dq_op;
	const struct quotactl_ops___76 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___77 *s_root;
	struct rw_semaphore___77 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___77 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___76 s_dquot;
	struct sb_writers___76 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___76 *s_d_op;
	int cleancache_poolid;
	struct shrinker___29 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___62 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___10 {
	struct dentry___77 *mnt_root;
	struct super_block___77 *mnt_sb;
	int mnt_flags;
};

struct path___76 {
	struct vfsmount___10 *mnt;
	struct dentry___77 *dentry;
};

struct key___74;

struct ucounts___62;

struct user_namespace___62 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___62 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common ns;
	long unsigned int flags;
	struct key___74 *persistent_keyring_register;
	struct rw_semaphore___77 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___62 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct upid___64 {
	int nr;
	struct pid_namespace___64 *ns;
};

struct pid_namespace___64 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___77 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___64 *parent;
	struct vfsmount___10 *proc_mnt;
	struct dentry___77 *proc_self;
	struct dentry___77 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___62 *user_ns;
	struct ucounts___62 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common ns;
};

struct pid___64 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___64 numbers[1];
};

struct vm_operations_struct___76;

struct vm_area_struct___77 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___77 *vm_next;
	struct vm_area_struct___77 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___76 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___76 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___77 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___76;

struct mm_struct___76 {
	struct {
		struct vm_area_struct___77 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___77 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___77 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___76 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___77 *owner;
		struct user_namespace___62 *user_ns;
		struct file___77 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___76 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___76)(struct vm_area_struct___77 *, long unsigned int, const struct page___77 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___76)(struct page___77 *, void *);

struct device___72;

struct dev_pagemap___76 {
	dev_page_fault_t___76 page_fault;
	dev_page_free_t___76 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___72 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct fown_struct___64 {
	rwlock_t lock;
	struct pid___64 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___77 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___76 f_path;
	struct inode___78 *f_inode;
	const struct file_operations___77 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___64 f_owner;
	const struct cred___73 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___76 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___76;

struct vm_operations_struct___76 {
	void (*open)(struct vm_area_struct___77 *);
	void (*close)(struct vm_area_struct___77 *);
	int (*split)(struct vm_area_struct___77 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___77 *);
	vm_fault_t (*fault)(struct vm_fault___76 *);
	vm_fault_t (*huge_fault)(struct vm_fault___76 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___76 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___77 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___76 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___76 *);
	int (*access)(struct vm_area_struct___77 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___77 *);
	int (*set_policy)(struct vm_area_struct___77 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___77 *, long unsigned int);
	struct page___77 * (*find_special_page)(struct vm_area_struct___77 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___76 {
	struct task_struct___77 *task;
	struct core_thread___76 *next;
};

struct core_state___76 {
	atomic_t nr_threads;
	struct core_thread___76 dumper;
	struct completion startup;
};

struct vm_fault___76 {
	struct vm_area_struct___77 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___77 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___77 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___76 prealloc_pte;
};

struct hrtimer_sleeper___3 {
	struct hrtimer timer;
	struct task_struct___77 *task;
};

struct user_struct___73 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___74 *uid_keyring;
	struct key___74 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___73 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___74 *session_keyring;
	struct key___74 *process_keyring;
	struct key___74 *thread_keyring;
	struct key___74 *request_key_auth;
	void *security;
	struct user_struct___73 *user;
	struct user_namespace___62 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___60;

struct nsproxy___71 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___64 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___60 *cgroup_ns;
};

struct signal_struct___67 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___77 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___77 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___64 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___64 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___76 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___64 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct rt_mutex___3;

struct rt_mutex_waiter___2 {
	struct rb_node tree_entry;
	struct rb_node pi_tree_entry;
	struct task_struct___77 *task;
	struct rt_mutex___3 *lock;
	int prio;
	u64 deadline;
};

struct cgroup_subsys_state___60;

struct cgroup___60;

struct css_set___60 {
	struct cgroup_subsys_state___60 *subsys[13];
	refcount_t refcount;
	struct css_set___60 *dom_cset;
	struct cgroup___60 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___60 *mg_src_cgrp;
	struct cgroup___60 *mg_dst_cgrp;
	struct css_set___60 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct rt_mutex___3 {
	raw_spinlock_t wait_lock;
	struct rb_root_cached waiters;
	struct task_struct___77 *owner;
};

union futex_key {
	struct {
		long unsigned int pgoff;
		struct inode___78 *inode;
		int offset;
	} shared;
	struct {
		long unsigned int address;
		struct mm_struct___76 *mm;
		int offset;
	} private;
	struct {
		long unsigned int word;
		void *ptr;
		int offset;
	} both;
};

struct futex_pi_state___2 {
	struct list_head list;
	struct rt_mutex___3 pi_mutex;
	struct task_struct___77 *owner;
	atomic_t refcount;
	union futex_key key;
};

struct perf_event_context___49 {
	struct pmu___49 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___77 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___49 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

union thread_union___67 {
	struct task_struct___77 task;
	long unsigned int stack[8192];
};

struct kiocb___77 {
	struct file___77 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___77 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___77 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___77 *ia_file;
};

struct dquot___76 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___77 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___76 {
	int qf_fmt_id;
	const struct quota_format_ops___76 *qf_ops;
	struct module___69 *qf_owner;
	struct quota_format_type___76 *qf_next;
};

struct quota_format_ops___76 {
	int (*check_quota_file)(struct super_block___77 *, int);
	int (*read_file_info)(struct super_block___77 *, int);
	int (*write_file_info)(struct super_block___77 *, int);
	int (*free_file_info)(struct super_block___77 *, int);
	int (*read_dqblk)(struct dquot___76 *);
	int (*commit_dqblk)(struct dquot___76 *);
	int (*release_dqblk)(struct dquot___76 *);
	int (*get_next_id)(struct super_block___77 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___76 {
	int (*write_dquot)(struct dquot___76 *);
	struct dquot___76 * (*alloc_dquot)(struct super_block___77 *, int);
	void (*destroy_dquot)(struct dquot___76 *);
	int (*acquire_dquot)(struct dquot___76 *);
	int (*release_dquot)(struct dquot___76 *);
	int (*mark_dirty)(struct dquot___76 *);
	int (*write_info)(struct super_block___77 *, int);
	qsize_t * (*get_reserved_space)(struct inode___78 *);
	int (*get_projid)(struct inode___78 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___78 *, qsize_t *);
	int (*get_next_id)(struct super_block___77 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___76 {
	int (*quota_on)(struct super_block___77 *, int, int, const struct path___76 *);
	int (*quota_off)(struct super_block___77 *, int);
	int (*quota_enable)(struct super_block___77 *, unsigned int);
	int (*quota_disable)(struct super_block___77 *, unsigned int);
	int (*quota_sync)(struct super_block___77 *, int);
	int (*set_info)(struct super_block___77 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___77 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___77 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___77 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___77 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___77 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___73;

struct kobj_type___73;

struct kernfs_node___74;

struct kobject___74 {
	const char *name;
	struct list_head entry;
	struct kobject___74 *parent;
	struct kset___73 *kset;
	struct kobj_type___73 *ktype;
	struct kernfs_node___74 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___66 {
	struct kobject___74 kobj;
	struct module___69 *mod;
	struct kobject___74 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___66 {
	struct module___69 *mod;
	struct latch_tree_node node;
};

struct module_layout___66 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___66 mtn;
};

struct module_attribute___66;

struct kernel_param___66;

struct module___69 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___66 mkobj;
	struct module_attribute___66 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___74 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___66 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___66 core_layout;
	struct module_layout___66 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___44 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___76 {
	int (*writepage)(struct page___77 *, struct writeback_control___3 *);
	int (*readpage)(struct file___77 *, struct page___77 *);
	int (*writepages)(struct address_space___76 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___77 *);
	int (*readpages)(struct file___77 *, struct address_space___76 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___77 *, struct address_space___76 *, loff_t, unsigned int, unsigned int, struct page___77 **, void **);
	int (*write_end)(struct file___77 *, struct address_space___76 *, loff_t, unsigned int, unsigned int, struct page___77 *, void *);
	sector_t (*bmap)(struct address_space___76 *, sector_t);
	void (*invalidatepage)(struct page___77 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___77 *, gfp_t);
	void (*freepage)(struct page___77 *);
	ssize_t (*direct_IO)(struct kiocb___77 *, struct iov_iter___29 *);
	int (*migratepage)(struct address_space___76 *, struct page___77 *, struct page___77 *, enum migrate_mode);
	bool (*isolate_page)(struct page___77 *, isolate_mode_t);
	void (*putback_page)(struct page___77 *);
	int (*launder_page)(struct page___77 *);
	int (*is_partially_uptodate)(struct page___77 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___77 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___76 *, struct page___77 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___77 *, sector_t *);
	void (*swap_deactivate)(struct file___77 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___77 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___78 *bd_inode;
	struct super_block___77 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___77 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___76 {
	struct dentry___77 * (*lookup)(struct inode___78 *, struct dentry___77 *, unsigned int);
	const char * (*get_link)(struct dentry___77 *, struct inode___78 *, struct delayed_call *);
	int (*permission)(struct inode___78 *, int);
	struct posix_acl * (*get_acl)(struct inode___78 *, int);
	int (*readlink)(struct dentry___77 *, char *, int);
	int (*create)(struct inode___78 *, struct dentry___77 *, umode_t, bool);
	int (*link)(struct dentry___77 *, struct inode___78 *, struct dentry___77 *);
	int (*unlink)(struct inode___78 *, struct dentry___77 *);
	int (*symlink)(struct inode___78 *, struct dentry___77 *, const char *);
	int (*mkdir)(struct inode___78 *, struct dentry___77 *, umode_t);
	int (*rmdir)(struct inode___78 *, struct dentry___77 *);
	int (*mknod)(struct inode___78 *, struct dentry___77 *, umode_t, dev_t);
	int (*rename)(struct inode___78 *, struct dentry___77 *, struct inode___78 *, struct dentry___77 *, unsigned int);
	int (*setattr)(struct dentry___77 *, struct iattr___77 *);
	int (*getattr)(const struct path___76 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___77 *, char *, size_t);
	int (*fiemap)(struct inode___78 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___78 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___78 *, struct dentry___77 *, struct file___77 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___78 *, struct dentry___77 *, umode_t);
	int (*set_acl)(struct inode___78 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___76 {
	void (*fl_copy_lock)(struct file_lock___77 *, struct file_lock___77 *);
	void (*fl_release_private)(struct file_lock___77 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___76;

struct file_lock___77 {
	struct file_lock___77 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___77 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___76 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___76 *fl_ops;
	const struct lock_manager_operations___76 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___76 {
	int (*lm_compare_owner)(struct file_lock___77 *, struct file_lock___77 *);
	long unsigned int (*lm_owner_key)(struct file_lock___77 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___77 *);
	int (*lm_grant)(struct file_lock___77 *, int);
	bool (*lm_break)(struct file_lock___77 *);
	int (*lm_change)(struct file_lock___77 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___77 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___76 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___76 *fa_next;
	struct file___77 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___76 {
	const char *name;
	int fs_flags;
	struct dentry___77 * (*mount)(struct file_system_type___76 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___77 *);
	struct module___69 *owner;
	struct file_system_type___76 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___76 {
	struct inode___78 * (*alloc_inode)(struct super_block___77 *);
	void (*destroy_inode)(struct inode___78 *);
	void (*dirty_inode)(struct inode___78 *, int);
	int (*write_inode)(struct inode___78 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___78 *);
	void (*evict_inode)(struct inode___78 *);
	void (*put_super)(struct super_block___77 *);
	int (*sync_fs)(struct super_block___77 *, int);
	int (*freeze_super)(struct super_block___77 *);
	int (*freeze_fs)(struct super_block___77 *);
	int (*thaw_super)(struct super_block___77 *);
	int (*unfreeze_fs)(struct super_block___77 *);
	int (*statfs)(struct dentry___77 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___77 *, int *, char *);
	void (*umount_begin)(struct super_block___77 *);
	int (*show_options)(struct seq_file___71 *, struct dentry___77 *);
	int (*show_devname)(struct seq_file___71 *, struct dentry___77 *);
	int (*show_path)(struct seq_file___71 *, struct dentry___77 *);
	int (*show_stats)(struct seq_file___71 *, struct dentry___77 *);
	ssize_t (*quota_read)(struct super_block___77 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___77 *, int, const char *, size_t, loff_t);
	struct dquot___76 ** (*get_dquots)(struct inode___78 *);
	int (*bdev_try_to_free_page)(struct super_block___77 *, struct page___77 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___77 *, struct shrink_control___29 *);
	long int (*free_cached_objects)(struct super_block___77 *, struct shrink_control___29 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___51)(struct file___77 *, wait_queue_head_t *, struct poll_table_struct___52 *);

struct poll_table_struct___52 {
	poll_queue_proc___51 _qproc;
	__poll_t _key;
};

struct seq_operations___68;

struct seq_file___71 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___68 *op;
	int poll_event;
	const struct file___77 *file;
	void *private;
};

struct dev_pm_info___72 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___72 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___72;

struct bus_type___72;

struct device_driver___72;

struct dev_pm_domain___72;

struct class___72;

struct attribute_group___71;

struct device___72 {
	struct device___72 *parent;
	struct device_private *p;
	struct kobject___74 kobj;
	const char *init_name;
	const struct device_type___72 *type;
	struct mutex mutex;
	struct bus_type___72 *bus;
	struct device_driver___72 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___72 power;
	struct dev_pm_domain___72 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___72 *class;
	const struct attribute_group___71 **groups;
	void (*release)(struct device___72 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct kobj_attribute___74 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___74 *, struct kobj_attribute___74 *, char *);
	ssize_t (*store)(struct kobject___74 *, struct kobj_attribute___74 *, const char *, size_t);
};

typedef void compound_page_dtor___76(struct page___77 *);

typedef int (*key_restrict_link_func_t___73)(struct key___74 *, const struct key_type *, const union key_payload *, struct key___74 *);

struct key_restriction___74;

struct key___74 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___77 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___74 *restrict_link;
};

struct key_restriction___74 {
	key_restrict_link_func_t___73 check;
	struct key___74 *key;
	struct key_type *keytype;
};

struct seq_operations___68 {
	void * (*start)(struct seq_file___71 *, loff_t *);
	void (*stop)(struct seq_file___71 *, void *);
	void * (*next)(struct seq_file___71 *, void *, loff_t *);
	int (*show)(struct seq_file___71 *, void *);
};

struct cgroup_namespace___60 {
	refcount_t count;
	struct ns_common ns;
	struct user_namespace___62 *user_ns;
	struct ucounts___62 *ucounts;
	struct css_set___60 *root_cset;
};

struct ucounts___62 {
	struct hlist_node node;
	struct user_namespace___62 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct kernfs_root___74;

struct kernfs_elem_dir___74 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___74 *root;
};

struct kernfs_syscall_ops___74;

struct kernfs_root___74 {
	struct kernfs_node___74 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___74 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___74 {
	struct kernfs_node___74 *target_kn;
};

struct kernfs_ops___74;

struct kernfs_elem_attr___74 {
	const struct kernfs_ops___74 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___74 *notify_next;
};

struct kernfs_node___74 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___74 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___74 dir;
		struct kernfs_elem_symlink___74 symlink;
		struct kernfs_elem_attr___74 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___74;

struct kernfs_ops___74 {
	int (*open)(struct kernfs_open_file___74 *);
	void (*release)(struct kernfs_open_file___74 *);
	int (*seq_show)(struct seq_file___71 *, void *);
	void * (*seq_start)(struct seq_file___71 *, loff_t *);
	void * (*seq_next)(struct seq_file___71 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___71 *, void *);
	ssize_t (*read)(struct kernfs_open_file___74 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___74 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___74 *, struct vm_area_struct___77 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___74 *, struct poll_table_struct___52 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___74 {
	int (*remount_fs)(struct kernfs_root___74 *, int *, char *);
	int (*show_options)(struct seq_file___71 *, struct kernfs_root___74 *);
	int (*mkdir)(struct kernfs_node___74 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___74 *);
	int (*rename)(struct kernfs_node___74 *, struct kernfs_node___74 *, const char *);
	int (*show_path)(struct seq_file___71 *, struct kernfs_node___74 *, struct kernfs_root___74 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___74 {
	struct kernfs_node___74 *kn;
	struct file___77 *file;
	struct seq_file___71 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___76 *vm_ops;
};

struct bin_attribute___71;

struct attribute_group___71 {
	const char *name;
	umode_t (*is_visible)(struct kobject___74 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___74 *, struct bin_attribute___71 *, int);
	struct attribute **attrs;
	struct bin_attribute___71 **bin_attrs;
};

struct bin_attribute___71 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___77 *, struct kobject___74 *, struct bin_attribute___71 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___77 *, struct kobject___74 *, struct bin_attribute___71 *, char *, loff_t, size_t);
	int (*mmap)(struct file___77 *, struct kobject___74 *, struct bin_attribute___71 *, struct vm_area_struct___77 *);
};

struct sysfs_ops___73 {
	ssize_t (*show)(struct kobject___74 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___74 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___73;

struct kset___73 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___74 kobj;
	const struct kset_uevent_ops___73 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___73 {
	void (*release)(struct kobject___74 *);
	const struct sysfs_ops___73 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___74 *);
	const void * (*namespace)(struct kobject___74 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___73 {
	int (* const filter)(struct kset___73 *, struct kobject___74 *);
	const char * (* const name)(struct kset___73 *, struct kobject___74 *);
	int (* const uevent)(struct kset___73 *, struct kobject___74 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___66 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___66 *);
	int (*get)(char *, const struct kernel_param___66 *);
	void (*free)(void *);
};

struct kparam_array___66;

struct kernel_param___66 {
	const char *name;
	struct module___69 *mod;
	const struct kernel_param_ops___66 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___66 *arr;
	};
};

struct kparam_array___66 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___66 *ops;
	void *elem;
};

struct module_attribute___66 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___66 *, struct module_kobject___66 *, char *);
	ssize_t (*store)(struct module_attribute___66 *, struct module_kobject___66 *, const char *, size_t);
	void (*setup)(struct module___69 *, const char *);
	int (*test)(struct module___69 *);
	void (*free)(struct module___69 *);
};

struct trace_event_class___44;

struct trace_event_call___44 {
	struct list_head list;
	struct trace_event_class___44 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array *prog_array;
	int (*perf_perm)(struct trace_event_call___44 *, struct perf_event___49 *);
};

struct dev_pm_ops___72 {
	int (*prepare)(struct device___72 *);
	void (*complete)(struct device___72 *);
	int (*suspend)(struct device___72 *);
	int (*resume)(struct device___72 *);
	int (*freeze)(struct device___72 *);
	int (*thaw)(struct device___72 *);
	int (*poweroff)(struct device___72 *);
	int (*restore)(struct device___72 *);
	int (*suspend_late)(struct device___72 *);
	int (*resume_early)(struct device___72 *);
	int (*freeze_late)(struct device___72 *);
	int (*thaw_early)(struct device___72 *);
	int (*poweroff_late)(struct device___72 *);
	int (*restore_early)(struct device___72 *);
	int (*suspend_noirq)(struct device___72 *);
	int (*resume_noirq)(struct device___72 *);
	int (*freeze_noirq)(struct device___72 *);
	int (*thaw_noirq)(struct device___72 *);
	int (*poweroff_noirq)(struct device___72 *);
	int (*restore_noirq)(struct device___72 *);
	int (*runtime_suspend)(struct device___72 *);
	int (*runtime_resume)(struct device___72 *);
	int (*runtime_idle)(struct device___72 *);
};

struct dev_pm_domain___72 {
	struct dev_pm_ops___72 ops;
	void (*detach)(struct device___72 *, bool);
	int (*activate)(struct device___72 *);
	void (*sync)(struct device___72 *);
	void (*dismiss)(struct device___72 *);
};

struct bus_type___72 {
	const char *name;
	const char *dev_name;
	struct device___72 *dev_root;
	const struct attribute_group___71 **bus_groups;
	const struct attribute_group___71 **dev_groups;
	const struct attribute_group___71 **drv_groups;
	int (*match)(struct device___72 *, struct device_driver___72 *);
	int (*uevent)(struct device___72 *, struct kobj_uevent_env *);
	int (*probe)(struct device___72 *);
	int (*remove)(struct device___72 *);
	void (*shutdown)(struct device___72 *);
	int (*online)(struct device___72 *);
	int (*offline)(struct device___72 *);
	int (*suspend)(struct device___72 *, pm_message_t);
	int (*resume)(struct device___72 *);
	int (*num_vf)(struct device___72 *);
	int (*dma_configure)(struct device___72 *);
	const struct dev_pm_ops___72 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___72 {
	const char *name;
	struct bus_type___72 *bus;
	struct module___69 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___72 *);
	int (*remove)(struct device___72 *);
	void (*shutdown)(struct device___72 *);
	int (*suspend)(struct device___72 *, pm_message_t);
	int (*resume)(struct device___72 *);
	const struct attribute_group___71 **groups;
	const struct dev_pm_ops___72 *pm;
	void (*coredump)(struct device___72 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___72 {
	const char *name;
	const struct attribute_group___71 **groups;
	int (*uevent)(struct device___72 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___72 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___72 *);
	const struct dev_pm_ops___72 *pm;
};

struct class___72 {
	const char *name;
	struct module___69 *owner;
	const struct attribute_group___71 **class_groups;
	const struct attribute_group___71 **dev_groups;
	struct kobject___74 *dev_kobj;
	int (*dev_uevent)(struct device___72 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___72 *, umode_t *);
	void (*class_release)(struct class___72 *);
	void (*dev_release)(struct device___72 *);
	int (*shutdown_pre)(struct device___72 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___72 *);
	const struct dev_pm_ops___72 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___63 {
	struct device___72 dev;
};

struct bpf_map___60;

struct bpf_map_ops___60 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___60 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___60 *, struct file___77 *);
	void (*map_free)(struct bpf_map___60 *);
	int (*map_get_next_key)(struct bpf_map___60 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___60 *);
	void * (*map_lookup_elem)(struct bpf_map___60 *, void *);
	int (*map_update_elem)(struct bpf_map___60 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___60 *, void *);
	int (*map_push_elem)(struct bpf_map___60 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___60 *, void *);
	int (*map_peek_elem)(struct bpf_map___60 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___60 *, struct file___77 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___60 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___60 *, void *, struct seq_file___71 *);
	int (*map_check_btf)(const struct bpf_map___60 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___60 {
	const struct bpf_map_ops___60 *ops;
	struct bpf_map___60 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___73 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___60;

typedef void (*kthread_work_func_t___60)(struct kthread_work___60 *);

struct kthread_worker___60;

struct kthread_work___60 {
	struct list_head node;
	kthread_work_func_t___60 func;
	struct kthread_worker___60 *worker;
	int canceling;
};

struct kthread_worker___60 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___77 *task;
	struct kthread_work___60 *current_work;
};

struct kthread_delayed_work___60 {
	struct kthread_work___60 work;
	struct timer_list timer;
};

struct psi_group___60 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___60 *poll_kworker;
	struct kthread_delayed_work___60 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___60 {
	struct kernfs_node___74 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___60;

struct cgroup_subsys_state___60 {
	struct cgroup___60 *cgroup;
	struct cgroup_subsys___60 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___60 *parent;
};

struct cgroup_root___60;

struct cgroup_rstat_cpu___60;

struct cgroup___60 {
	struct cgroup_subsys_state___60 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___74 *kn;
	struct cgroup_file___60 procs_file;
	struct cgroup_file___60 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___60 *subsys[13];
	struct cgroup_root___60 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___60 *dom_cgrp;
	struct cgroup_rstat_cpu___60 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf bpf;
	atomic_t congestion_count;
	struct cgroup___60 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___60 psi;
	int ancestor_ids[0];
};

struct cftype___60;

struct cgroup_subsys___60 {
	struct cgroup_subsys_state___60 * (*css_alloc)(struct cgroup_subsys_state___60 *);
	int (*css_online)(struct cgroup_subsys_state___60 *);
	void (*css_offline)(struct cgroup_subsys_state___60 *);
	void (*css_released)(struct cgroup_subsys_state___60 *);
	void (*css_free)(struct cgroup_subsys_state___60 *);
	void (*css_reset)(struct cgroup_subsys_state___60 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___60 *, int);
	int (*css_extra_stat_show)(struct seq_file___71 *, struct cgroup_subsys_state___60 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___77 *);
	void (*cancel_fork)(struct task_struct___77 *);
	void (*fork)(struct task_struct___77 *);
	void (*exit)(struct task_struct___77 *);
	void (*free)(struct task_struct___77 *);
	void (*bind)(struct cgroup_subsys_state___60 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___60 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___60 *dfl_cftypes;
	struct cftype___60 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___60 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___60 *updated_children;
	struct cgroup___60 *updated_next;
};

struct cgroup_root___60 {
	struct kernfs_root___74 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___60 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___60 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___60 *ss;
	struct list_head node;
	struct kernfs_ops___74 *kf_ops;
	int (*open)(struct kernfs_open_file___74 *);
	void (*release)(struct kernfs_open_file___74 *);
	u64 (*read_u64)(struct cgroup_subsys_state___60 *, struct cftype___60 *);
	s64 (*read_s64)(struct cgroup_subsys_state___60 *, struct cftype___60 *);
	int (*seq_show)(struct seq_file___71 *, void *);
	void * (*seq_start)(struct seq_file___71 *, loff_t *);
	void * (*seq_next)(struct seq_file___71 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___71 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___60 *, struct cftype___60 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___60 *, struct cftype___60 *, s64);
	ssize_t (*write)(struct kernfs_open_file___74 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___74 *, struct poll_table_struct___52 *);
};

struct perf_cpu_context___49;

struct pmu___49 {
	struct list_head entry;
	struct module___69 *module;
	struct device___72 *dev;
	const struct attribute_group___71 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___49 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___49 *);
	void (*pmu_disable)(struct pmu___49 *);
	int (*event_init)(struct perf_event___49 *);
	void (*event_mapped)(struct perf_event___49 *, struct mm_struct___76 *);
	void (*event_unmapped)(struct perf_event___49 *, struct mm_struct___76 *);
	int (*add)(struct perf_event___49 *, int);
	void (*del)(struct perf_event___49 *, int);
	void (*start)(struct perf_event___49 *, int);
	void (*stop)(struct perf_event___49 *, int);
	void (*read)(struct perf_event___49 *);
	void (*start_txn)(struct pmu___49 *, unsigned int);
	int (*commit_txn)(struct pmu___49 *);
	void (*cancel_txn)(struct pmu___49 *);
	int (*event_idx)(struct perf_event___49 *);
	void (*sched_task)(struct perf_event_context___49 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___49 *);
	int (*filter_match)(struct perf_event___49 *);
	int (*check_period)(struct perf_event___49 *, u64);
};

struct perf_cpu_context___49 {
	struct perf_event_context___49 ctx;
	struct perf_event_context___49 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___49 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___49 {
	struct cgroup_subsys_state___60 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___44 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___44 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___44 *);
	struct list_head * (*get_fields)(struct trace_event_call___44 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___44 *);
};

struct syscall_metadata___19 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___44 *enter_event;
	struct trace_event_call___44 *exit_event;
};

struct hstate___10 {
	int next_nid_to_alloc;
	int next_nid_to_free;
	unsigned int order;
	long unsigned int mask;
	long unsigned int max_huge_pages;
	long unsigned int nr_huge_pages;
	long unsigned int free_huge_pages;
	long unsigned int resv_huge_pages;
	long unsigned int surplus_huge_pages;
	long unsigned int nr_overcommit_huge_pages;
	struct list_head hugepage_activelist;
	struct list_head hugepage_freelists[8];
	unsigned int nr_huge_pages_node[8];
	unsigned int free_huge_pages_node[8];
	unsigned int surplus_huge_pages_node[8];
	struct cftype___60 cgroup_files[5];
	char name[32];
};

struct futex_q {
	struct plist_node list;
	struct task_struct___77 *task;
	spinlock_t *lock_ptr;
	union futex_key key;
	struct futex_pi_state___2 *pi_state;
	struct rt_mutex_waiter___2 *rt_waiter;
	union futex_key *requeue_pi_key;
	u32 bitset;
};

struct futex_hash_bucket {
	atomic_t waiters;
	spinlock_t lock;
	struct plist_head chain;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

enum futex_access {
	FUTEX_READ = 0,
	FUTEX_WRITE = 1,
};

enum {
	CSD_FLAG_LOCK = 1,
	CSD_FLAG_SYNCHRONOUS = 2,
};

struct call_function_data {
	call_single_data_t *csd;
	cpumask_var_t cpumask;
	cpumask_var_t cpumask_ipi;
};

struct smp_call_on_cpu_struct {
	struct work_struct work;
	struct completion done;
	int (*func)(void *);
	void *data;
	int ret;
	int cpu;
};

struct module___70;

struct file___78;

struct kiocb___78;

struct poll_table_struct___53;

struct vm_area_struct___78;

struct inode___79;

struct file_lock___78;

struct page___78;

struct seq_file___72;

struct file_operations___78 {
	struct module___70 *owner;
	loff_t (*llseek)(struct file___78 *, loff_t, int);
	ssize_t (*read)(struct file___78 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___78 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___78 *, struct iov_iter___29 *);
	ssize_t (*write_iter)(struct kiocb___78 *, struct iov_iter___29 *);
	int (*iopoll)(struct kiocb___78 *, bool);
	int (*iterate)(struct file___78 *, struct dir_context *);
	int (*iterate_shared)(struct file___78 *, struct dir_context *);
	__poll_t (*poll)(struct file___78 *, struct poll_table_struct___53 *);
	long int (*unlocked_ioctl)(struct file___78 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___78 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___78 *, struct vm_area_struct___78 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___79 *, struct file___78 *);
	int (*flush)(struct file___78 *, fl_owner_t);
	int (*release)(struct inode___79 *, struct file___78 *);
	int (*fsync)(struct file___78 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___78 *, int);
	int (*lock)(struct file___78 *, int, struct file_lock___78 *);
	ssize_t (*sendpage)(struct file___78 *, struct page___78 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___78 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___78 *, int, struct file_lock___78 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___78 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___78 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___78 *, long int, struct file_lock___78 **, void **);
	long int (*fallocate)(struct file___78 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___72 *, struct file___78 *);
	ssize_t (*copy_file_range)(struct file___78 *, loff_t, struct file___78 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___78 *, loff_t, struct file___78 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___78 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___77 {
	u64 seqnum;
	struct vm_area_struct___78 *vmas[4];
};

struct page_frag___77 {
	struct page___78 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___50;

struct debug_info___50 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___50 *hbp_break[16];
	struct perf_event___50 *hbp_watch[16];
};

struct thread_struct___50 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___50 debug;
	long: 64;
};

struct mm_struct___77;

struct pid___65;

struct cred___74;

struct nsproxy___72;

struct signal_struct___68;

struct css_set___61;

struct perf_event_context___50;

struct vm_struct___55;

struct task_struct___78 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___78 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___77 *mm;
	struct mm_struct___77 *active_mm;
	struct vmacache___77 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___78 *real_parent;
	struct task_struct___78 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___78 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___65 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___65 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___65 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___74 *ptracer_cred;
	const struct cred___74 *real_cred;
	const struct cred___74 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___72 *nsproxy;
	struct signal_struct___68 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___78 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___13 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___61 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___50 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___77 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___78 *oom_reaper_list;
	struct vm_struct___55 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___50 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___50 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___78 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___50)(struct perf_event___50 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___50;

struct fasync_struct___77;

struct pid_namespace___65;

struct trace_event_call___45;

struct perf_cgroup___50;

struct perf_event___50 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___50 *group_leader;
	struct pmu___50 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___50 hw;
	struct perf_event_context___50 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___50 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___78 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___77 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___50 *);
	struct callback_head callback_head;
	struct pid_namespace___65 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___50 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___50 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___45 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___50 *cgrp;
	struct list_head sb_list;
};

struct rw_semaphore___78 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___78 *owner;
};

struct key___75;

struct ucounts___63;

struct user_namespace___63 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___63 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common ns;
	long unsigned int flags;
	struct key___75 *persistent_keyring_register;
	struct rw_semaphore___78 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___63 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___78 *pgtable_t___77;

struct address_space___77;

struct dev_pagemap___77;

struct page___78 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___77 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___78 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___77 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___77 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___77 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___77;

struct lruvec___77 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___77 *pgdat;
};

struct zone___77 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___77 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___77 {
	struct zone___77 *zone;
	int zone_idx;
};

struct zonelist___77 {
	struct zoneref___77 _zonerefs[25];
};

struct pglist_data___77 {
	struct zone___77 node_zones[3];
	struct zonelist___77 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___78 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___78 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___77 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___78 {
	void *stack;
	struct task_struct___78 *task;
	long int status;
};

struct blocking_notifier_head___77 {
	struct rw_semaphore___78 rwsem;
	struct notifier_block *head;
};

struct dentry___78;

struct path___77 {
	struct vfsmount *mnt;
	struct dentry___78 *dentry;
};

struct fown_struct___65 {
	rwlock_t lock;
	struct pid___65 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___78 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___77 f_path;
	struct inode___79 *f_inode;
	const struct file_operations___78 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___65 f_owner;
	const struct cred___74 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___77 *f_mapping;
	errseq_t f_wb_err;
};

struct user_struct___74;

struct cred___74 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___75 *session_keyring;
	struct key___75 *process_keyring;
	struct key___75 *thread_keyring;
	struct key___75 *request_key_auth;
	void *security;
	struct user_struct___74 *user;
	struct user_namespace___63 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___75;

struct kernfs_elem_dir___75 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___75 *root;
};

struct kernfs_node___75;

struct kernfs_syscall_ops___75;

struct kernfs_root___75 {
	struct kernfs_node___75 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___75 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___75 {
	struct kernfs_node___75 *target_kn;
};

struct kernfs_ops___75;

struct kernfs_elem_attr___75 {
	const struct kernfs_ops___75 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___75 *notify_next;
};

struct kernfs_node___75 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___75 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___75 dir;
		struct kernfs_elem_symlink___75 symlink;
		struct kernfs_elem_attr___75 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___75;

struct kernfs_ops___75 {
	int (*open)(struct kernfs_open_file___75 *);
	void (*release)(struct kernfs_open_file___75 *);
	int (*seq_show)(struct seq_file___72 *, void *);
	void * (*seq_start)(struct seq_file___72 *, loff_t *);
	void * (*seq_next)(struct seq_file___72 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___72 *, void *);
	ssize_t (*read)(struct kernfs_open_file___75 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___75 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___75 *, struct vm_area_struct___78 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___75 *, struct poll_table_struct___53 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___75 {
	int (*remount_fs)(struct kernfs_root___75 *, int *, char *);
	int (*show_options)(struct seq_file___72 *, struct kernfs_root___75 *);
	int (*mkdir)(struct kernfs_node___75 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___75 *);
	int (*rename)(struct kernfs_node___75 *, struct kernfs_node___75 *, const char *);
	int (*show_path)(struct seq_file___72 *, struct kernfs_node___75 *, struct kernfs_root___75 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___69;

struct seq_file___72 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___69 *op;
	int poll_event;
	const struct file___78 *file;
	void *private;
};

struct vm_operations_struct___77;

struct kernfs_open_file___75 {
	struct kernfs_node___75 *kn;
	struct file___78 *file;
	struct seq_file___72 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___77 *vm_ops;
};

struct vm_fault___77;

struct vm_operations_struct___77 {
	void (*open)(struct vm_area_struct___78 *);
	void (*close)(struct vm_area_struct___78 *);
	int (*split)(struct vm_area_struct___78 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___78 *);
	vm_fault_t (*fault)(struct vm_fault___77 *);
	vm_fault_t (*huge_fault)(struct vm_fault___77 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___77 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___78 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___77 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___77 *);
	int (*access)(struct vm_area_struct___78 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___78 *);
	int (*set_policy)(struct vm_area_struct___78 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___78 *, long unsigned int);
	struct page___78 * (*find_special_page)(struct vm_area_struct___78 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___52)(struct file___78 *, wait_queue_head_t *, struct poll_table_struct___53 *);

struct poll_table_struct___53 {
	poll_queue_proc___52 _qproc;
	__poll_t _key;
};

struct vm_area_struct___78 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___78 *vm_next;
	struct vm_area_struct___78 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___77 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___77 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___78 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___75;

struct bin_attribute___72;

struct attribute_group___72 {
	const char *name;
	umode_t (*is_visible)(struct kobject___75 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___75 *, struct bin_attribute___72 *, int);
	struct attribute **attrs;
	struct bin_attribute___72 **bin_attrs;
};

struct kset___74;

struct kobj_type___74;

struct kobject___75 {
	const char *name;
	struct list_head entry;
	struct kobject___75 *parent;
	struct kset___74 *kset;
	struct kobj_type___74 *ktype;
	struct kernfs_node___75 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___72 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___78 *, struct kobject___75 *, struct bin_attribute___72 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___78 *, struct kobject___75 *, struct bin_attribute___72 *, char *, loff_t, size_t);
	int (*mmap)(struct file___78 *, struct kobject___75 *, struct bin_attribute___72 *, struct vm_area_struct___78 *);
};

struct sysfs_ops___74 {
	ssize_t (*show)(struct kobject___75 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___75 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___74;

struct kset___74 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___75 kobj;
	const struct kset_uevent_ops___74 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___74 {
	void (*release)(struct kobject___75 *);
	const struct sysfs_ops___74 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___75 *);
	const void * (*namespace)(struct kobject___75 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___74 {
	int (* const filter)(struct kset___74 *, struct kobject___75 *);
	const char * (* const name)(struct kset___74 *, struct kobject___75 *);
	int (* const uevent)(struct kset___74 *, struct kobject___75 *, struct kobj_uevent_env *);
};

struct kobj_attribute___75 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___75 *, struct kobj_attribute___75 *, char *);
	ssize_t (*store)(struct kobject___75 *, struct kobj_attribute___75 *, const char *, size_t);
};

struct kernel_param___67;

struct kernel_param_ops___67 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___67 *);
	int (*get)(char *, const struct kernel_param___67 *);
	void (*free)(void *);
};

struct kparam_array___67;

struct kernel_param___67 {
	const char *name;
	struct module___70 *mod;
	const struct kernel_param_ops___67 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___67 *arr;
	};
};

struct kparam_array___67 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___67 *ops;
	void *elem;
};

struct module_kobject___67 {
	struct kobject___75 kobj;
	struct module___70 *mod;
	struct kobject___75 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___67 {
	struct module___70 *mod;
	struct latch_tree_node node;
};

struct module_layout___67 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___67 mtn;
};

struct module_attribute___67;

struct module_sect_attrs___2;

struct module_notes_attrs___2;

struct module___70 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___67 mkobj;
	struct module_attribute___67 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___75 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___67 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___67 core_layout;
	struct module_layout___67 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs___2 *sect_attrs;
	struct module_notes_attrs___2 *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___45 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct latch_tree_root {
	seqcount_t seq;
	struct rb_root tree[2];
};

struct latch_tree_ops {
	bool (*less)(struct latch_tree_node *, struct latch_tree_node *);
	int (*comp)(void *, struct latch_tree_node *);
};

struct modversion_info {
	long unsigned int crc;
	char name[56];
};

struct module_attribute___67 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___67 *, struct module_kobject___67 *, char *);
	ssize_t (*store)(struct module_attribute___67 *, struct module_kobject___67 *, const char *, size_t);
	void (*setup)(struct module___70 *, const char *);
	int (*test)(struct module___70 *);
	void (*free)(struct module___70 *);
};

struct module_use {
	struct list_head source_list;
	struct list_head target_list;
	struct module___70 *source;
	struct module___70 *target;
};

struct module_sect_attr {
	struct module_attribute___67 mattr;
	char *name;
	long unsigned int address;
};

struct module_sect_attrs___2 {
	struct attribute_group___72 grp;
	unsigned int nsections;
	struct module_sect_attr attrs[0];
};

struct module_notes_attrs___2 {
	struct kobject___75 *dir;
	unsigned int notes;
	struct bin_attribute___72 attrs[0];
};

struct trace_event_class___45;

struct trace_event_call___45 {
	struct list_head list;
	struct trace_event_class___45 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array *prog_array;
	int (*perf_perm)(struct trace_event_call___45 *, struct perf_event___50 *);
};

struct symsearch {
	const struct kernel_symbol *start;
	const struct kernel_symbol *stop;
	const s32 *crcs;
	enum {
		NOT_GPL_ONLY = 0,
		GPL_ONLY = 1,
		WILL_BE_GPL_ONLY = 2,
	} licence;
	bool unused;
};

struct core_state___77;

struct mm_struct___77 {
	struct {
		struct vm_area_struct___78 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___78 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___78 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___77 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___78 *owner;
		struct user_namespace___63 *user_ns;
		struct file___78 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___77 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___77;

struct address_space___77 {
	struct inode___79 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___78 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___77 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___77)(struct vm_area_struct___78 *, long unsigned int, const struct page___78 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___77)(struct page___78 *, void *);

struct device___73;

struct dev_pagemap___77 {
	dev_page_fault_t___77 page_fault;
	dev_page_free_t___77 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___73 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___77 {
	struct task_struct___78 *task;
	struct core_thread___77 *next;
};

struct core_state___77 {
	atomic_t nr_threads;
	struct core_thread___77 dumper;
	struct completion startup;
};

struct vm_fault___77 {
	struct vm_area_struct___78 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___78 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___78 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___77 prealloc_pte;
};

struct upid___65 {
	int nr;
	struct pid_namespace___65 *ns;
};

struct pid_namespace___65 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___78 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___65 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___78 *proc_self;
	struct dentry___78 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___63 *user_ns;
	struct ucounts___63 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common ns;
};

struct pid___65 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___65 numbers[1];
};

struct user_struct___74 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___75 *uid_keyring;
	struct key___75 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cgroup_namespace___61;

struct nsproxy___72 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___65 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___61 *cgroup_ns;
};

struct signal_struct___68 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___78 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___78 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___65 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___65 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___77 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___65 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___61;

struct cgroup___61;

struct css_set___61 {
	struct cgroup_subsys_state___61 *subsys[13];
	refcount_t refcount;
	struct css_set___61 *dom_cset;
	struct cgroup___61 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___61 *mg_src_cgrp;
	struct cgroup___61 *mg_dst_cgrp;
	struct css_set___61 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___50 {
	struct pmu___50 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___78 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___50 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___55 {
	struct vm_struct___55 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___78 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___68 {
	struct task_struct___78 task;
	long unsigned int stack[8192];
};

struct dev_pm_info___73 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___73 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___73;

struct bus_type___73;

struct device_driver___73;

struct dev_pm_domain___73;

struct class___73;

struct device___73 {
	struct device___73 *parent;
	struct device_private *p;
	struct kobject___75 kobj;
	const char *init_name;
	const struct device_type___73 *type;
	struct mutex mutex;
	struct bus_type___73 *bus;
	struct device_driver___73 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___73 power;
	struct dev_pm_domain___73 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___73 *class;
	const struct attribute_group___72 **groups;
	void (*release)(struct device___73 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___77;

struct super_block___78;

struct dentry___78 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___78 *d_parent;
	struct qstr d_name;
	struct inode___79 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___77 *d_op;
	struct super_block___78 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___77;

struct block_device___78;

struct inode___79 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___77 *i_op;
	struct super_block___78 *i_sb;
	struct address_space___77 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___78 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___78 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___77 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___78 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___77 {
	int (*d_revalidate)(struct dentry___78 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___78 *, unsigned int);
	int (*d_hash)(const struct dentry___78 *, struct qstr *);
	int (*d_compare)(const struct dentry___78 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___78 *);
	int (*d_init)(struct dentry___78 *);
	void (*d_release)(struct dentry___78 *);
	void (*d_prune)(struct dentry___78 *);
	void (*d_iput)(struct dentry___78 *, struct inode___79 *);
	char * (*d_dname)(struct dentry___78 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___77 *);
	int (*d_manage)(const struct path___77 *, bool);
	struct dentry___78 * (*d_real)(struct dentry___78 *, const struct inode___79 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___77;

struct mem_dqinfo___77 {
	struct quota_format_type___77 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___77;

struct quota_info___77 {
	unsigned int flags;
	struct rw_semaphore___78 dqio_sem;
	struct inode___79 *files[3];
	struct mem_dqinfo___77 info[3];
	const struct quota_format_ops___77 *ops[3];
};

struct rcuwait___77 {
	struct task_struct___78 *task;
};

struct percpu_rw_semaphore___77 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___78 rw_sem;
	struct rcuwait___77 writer;
	int readers_block;
};

struct sb_writers___77 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___77 rw_sem[3];
};

struct file_system_type___77;

struct super_operations___77;

struct dquot_operations___77;

struct quotactl_ops___77;

struct super_block___78 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___77 *s_type;
	const struct super_operations___77 *s_op;
	const struct dquot_operations___77 *dq_op;
	const struct quotactl_ops___77 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___78 *s_root;
	struct rw_semaphore___78 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___78 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___77 s_dquot;
	struct sb_writers___77 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___77 *s_d_op;
	int cleancache_poolid;
	struct shrinker___29 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___63 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___78 {
	struct file___78 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___78 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___78 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___78 *ia_file;
};

struct dquot___77 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___78 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___77 {
	int qf_fmt_id;
	const struct quota_format_ops___77 *qf_ops;
	struct module___70 *qf_owner;
	struct quota_format_type___77 *qf_next;
};

struct quota_format_ops___77 {
	int (*check_quota_file)(struct super_block___78 *, int);
	int (*read_file_info)(struct super_block___78 *, int);
	int (*write_file_info)(struct super_block___78 *, int);
	int (*free_file_info)(struct super_block___78 *, int);
	int (*read_dqblk)(struct dquot___77 *);
	int (*commit_dqblk)(struct dquot___77 *);
	int (*release_dqblk)(struct dquot___77 *);
	int (*get_next_id)(struct super_block___78 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___77 {
	int (*write_dquot)(struct dquot___77 *);
	struct dquot___77 * (*alloc_dquot)(struct super_block___78 *, int);
	void (*destroy_dquot)(struct dquot___77 *);
	int (*acquire_dquot)(struct dquot___77 *);
	int (*release_dquot)(struct dquot___77 *);
	int (*mark_dirty)(struct dquot___77 *);
	int (*write_info)(struct super_block___78 *, int);
	qsize_t * (*get_reserved_space)(struct inode___79 *);
	int (*get_projid)(struct inode___79 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___79 *, qsize_t *);
	int (*get_next_id)(struct super_block___78 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___77 {
	int (*quota_on)(struct super_block___78 *, int, int, const struct path___77 *);
	int (*quota_off)(struct super_block___78 *, int);
	int (*quota_enable)(struct super_block___78 *, unsigned int);
	int (*quota_disable)(struct super_block___78 *, unsigned int);
	int (*quota_sync)(struct super_block___78 *, int);
	int (*set_info)(struct super_block___78 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___78 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___78 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___78 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___78 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___78 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___77 {
	int (*writepage)(struct page___78 *, struct writeback_control___3 *);
	int (*readpage)(struct file___78 *, struct page___78 *);
	int (*writepages)(struct address_space___77 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___78 *);
	int (*readpages)(struct file___78 *, struct address_space___77 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___78 *, struct address_space___77 *, loff_t, unsigned int, unsigned int, struct page___78 **, void **);
	int (*write_end)(struct file___78 *, struct address_space___77 *, loff_t, unsigned int, unsigned int, struct page___78 *, void *);
	sector_t (*bmap)(struct address_space___77 *, sector_t);
	void (*invalidatepage)(struct page___78 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___78 *, gfp_t);
	void (*freepage)(struct page___78 *);
	ssize_t (*direct_IO)(struct kiocb___78 *, struct iov_iter___29 *);
	int (*migratepage)(struct address_space___77 *, struct page___78 *, struct page___78 *, enum migrate_mode);
	bool (*isolate_page)(struct page___78 *, isolate_mode_t);
	void (*putback_page)(struct page___78 *);
	int (*launder_page)(struct page___78 *);
	int (*is_partially_uptodate)(struct page___78 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___78 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___77 *, struct page___78 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___78 *, sector_t *);
	void (*swap_deactivate)(struct file___78 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___78 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___79 *bd_inode;
	struct super_block___78 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___78 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___77 {
	struct dentry___78 * (*lookup)(struct inode___79 *, struct dentry___78 *, unsigned int);
	const char * (*get_link)(struct dentry___78 *, struct inode___79 *, struct delayed_call *);
	int (*permission)(struct inode___79 *, int);
	struct posix_acl * (*get_acl)(struct inode___79 *, int);
	int (*readlink)(struct dentry___78 *, char *, int);
	int (*create)(struct inode___79 *, struct dentry___78 *, umode_t, bool);
	int (*link)(struct dentry___78 *, struct inode___79 *, struct dentry___78 *);
	int (*unlink)(struct inode___79 *, struct dentry___78 *);
	int (*symlink)(struct inode___79 *, struct dentry___78 *, const char *);
	int (*mkdir)(struct inode___79 *, struct dentry___78 *, umode_t);
	int (*rmdir)(struct inode___79 *, struct dentry___78 *);
	int (*mknod)(struct inode___79 *, struct dentry___78 *, umode_t, dev_t);
	int (*rename)(struct inode___79 *, struct dentry___78 *, struct inode___79 *, struct dentry___78 *, unsigned int);
	int (*setattr)(struct dentry___78 *, struct iattr___78 *);
	int (*getattr)(const struct path___77 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___78 *, char *, size_t);
	int (*fiemap)(struct inode___79 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___79 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___79 *, struct dentry___78 *, struct file___78 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___79 *, struct dentry___78 *, umode_t);
	int (*set_acl)(struct inode___79 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___77 {
	void (*fl_copy_lock)(struct file_lock___78 *, struct file_lock___78 *);
	void (*fl_release_private)(struct file_lock___78 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___77;

struct file_lock___78 {
	struct file_lock___78 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___78 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___77 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___77 *fl_ops;
	const struct lock_manager_operations___77 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___77 {
	int (*lm_compare_owner)(struct file_lock___78 *, struct file_lock___78 *);
	long unsigned int (*lm_owner_key)(struct file_lock___78 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___78 *);
	int (*lm_grant)(struct file_lock___78 *, int);
	bool (*lm_break)(struct file_lock___78 *);
	int (*lm_change)(struct file_lock___78 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___78 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___77 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___77 *fa_next;
	struct file___78 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___77 {
	const char *name;
	int fs_flags;
	struct dentry___78 * (*mount)(struct file_system_type___77 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___78 *);
	struct module___70 *owner;
	struct file_system_type___77 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___77 {
	struct inode___79 * (*alloc_inode)(struct super_block___78 *);
	void (*destroy_inode)(struct inode___79 *);
	void (*dirty_inode)(struct inode___79 *, int);
	int (*write_inode)(struct inode___79 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___79 *);
	void (*evict_inode)(struct inode___79 *);
	void (*put_super)(struct super_block___78 *);
	int (*sync_fs)(struct super_block___78 *, int);
	int (*freeze_super)(struct super_block___78 *);
	int (*freeze_fs)(struct super_block___78 *);
	int (*thaw_super)(struct super_block___78 *);
	int (*unfreeze_fs)(struct super_block___78 *);
	int (*statfs)(struct dentry___78 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___78 *, int *, char *);
	void (*umount_begin)(struct super_block___78 *);
	int (*show_options)(struct seq_file___72 *, struct dentry___78 *);
	int (*show_devname)(struct seq_file___72 *, struct dentry___78 *);
	int (*show_path)(struct seq_file___72 *, struct dentry___78 *);
	int (*show_stats)(struct seq_file___72 *, struct dentry___78 *);
	ssize_t (*quota_read)(struct super_block___78 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___78 *, int, const char *, size_t, loff_t);
	struct dquot___77 ** (*get_dquots)(struct inode___79 *);
	int (*bdev_try_to_free_page)(struct super_block___78 *, struct page___78 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___78 *, struct shrink_control___29 *);
	long int (*free_cached_objects)(struct super_block___78 *, struct shrink_control___29 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

enum kernel_read_file_id {
	READING_UNKNOWN = 0,
	READING_FIRMWARE = 1,
	READING_FIRMWARE_PREALLOC_BUFFER = 2,
	READING_MODULE = 3,
	READING_KEXEC_IMAGE = 4,
	READING_KEXEC_INITRAMFS = 5,
	READING_POLICY = 6,
	READING_X509_CERTIFICATE = 7,
	READING_MAX_ID = 8,
};

typedef void compound_page_dtor___77(struct page___78 *);

typedef int (*key_restrict_link_func_t___74)(struct key___75 *, const struct key_type *, const union key_payload *, struct key___75 *);

struct key_restriction___75;

struct key___75 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___78 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___75 *restrict_link;
};

struct key_restriction___75 {
	key_restrict_link_func_t___74 check;
	struct key___75 *key;
	struct key_type *keytype;
};

struct seq_operations___69 {
	void * (*start)(struct seq_file___72 *, loff_t *);
	void (*stop)(struct seq_file___72 *, void *);
	void * (*next)(struct seq_file___72 *, void *, loff_t *);
	int (*show)(struct seq_file___72 *, void *);
};

struct cgroup_namespace___61 {
	refcount_t count;
	struct ns_common ns;
	struct user_namespace___63 *user_ns;
	struct ucounts___63 *ucounts;
	struct css_set___61 *root_cset;
};

struct ucounts___63 {
	struct hlist_node node;
	struct user_namespace___63 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct dev_pm_ops___73 {
	int (*prepare)(struct device___73 *);
	void (*complete)(struct device___73 *);
	int (*suspend)(struct device___73 *);
	int (*resume)(struct device___73 *);
	int (*freeze)(struct device___73 *);
	int (*thaw)(struct device___73 *);
	int (*poweroff)(struct device___73 *);
	int (*restore)(struct device___73 *);
	int (*suspend_late)(struct device___73 *);
	int (*resume_early)(struct device___73 *);
	int (*freeze_late)(struct device___73 *);
	int (*thaw_early)(struct device___73 *);
	int (*poweroff_late)(struct device___73 *);
	int (*restore_early)(struct device___73 *);
	int (*suspend_noirq)(struct device___73 *);
	int (*resume_noirq)(struct device___73 *);
	int (*freeze_noirq)(struct device___73 *);
	int (*thaw_noirq)(struct device___73 *);
	int (*poweroff_noirq)(struct device___73 *);
	int (*restore_noirq)(struct device___73 *);
	int (*runtime_suspend)(struct device___73 *);
	int (*runtime_resume)(struct device___73 *);
	int (*runtime_idle)(struct device___73 *);
};

struct dev_pm_domain___73 {
	struct dev_pm_ops___73 ops;
	void (*detach)(struct device___73 *, bool);
	int (*activate)(struct device___73 *);
	void (*sync)(struct device___73 *);
	void (*dismiss)(struct device___73 *);
};

struct bus_type___73 {
	const char *name;
	const char *dev_name;
	struct device___73 *dev_root;
	const struct attribute_group___72 **bus_groups;
	const struct attribute_group___72 **dev_groups;
	const struct attribute_group___72 **drv_groups;
	int (*match)(struct device___73 *, struct device_driver___73 *);
	int (*uevent)(struct device___73 *, struct kobj_uevent_env *);
	int (*probe)(struct device___73 *);
	int (*remove)(struct device___73 *);
	void (*shutdown)(struct device___73 *);
	int (*online)(struct device___73 *);
	int (*offline)(struct device___73 *);
	int (*suspend)(struct device___73 *, pm_message_t);
	int (*resume)(struct device___73 *);
	int (*num_vf)(struct device___73 *);
	int (*dma_configure)(struct device___73 *);
	const struct dev_pm_ops___73 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___73 {
	const char *name;
	struct bus_type___73 *bus;
	struct module___70 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___73 *);
	int (*remove)(struct device___73 *);
	void (*shutdown)(struct device___73 *);
	int (*suspend)(struct device___73 *, pm_message_t);
	int (*resume)(struct device___73 *);
	const struct attribute_group___72 **groups;
	const struct dev_pm_ops___73 *pm;
	void (*coredump)(struct device___73 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___73 {
	const char *name;
	const struct attribute_group___72 **groups;
	int (*uevent)(struct device___73 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___73 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___73 *);
	const struct dev_pm_ops___73 *pm;
};

struct class___73 {
	const char *name;
	struct module___70 *owner;
	const struct attribute_group___72 **class_groups;
	const struct attribute_group___72 **dev_groups;
	struct kobject___75 *dev_kobj;
	int (*dev_uevent)(struct device___73 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___73 *, umode_t *);
	void (*class_release)(struct class___73 *);
	void (*dev_release)(struct device___73 *);
	int (*shutdown_pre)(struct device___73 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___73 *);
	const struct dev_pm_ops___73 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___64 {
	struct device___73 dev;
};

struct bpf_map___61;

struct bpf_map_ops___61 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___61 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___61 *, struct file___78 *);
	void (*map_free)(struct bpf_map___61 *);
	int (*map_get_next_key)(struct bpf_map___61 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___61 *);
	void * (*map_lookup_elem)(struct bpf_map___61 *, void *);
	int (*map_update_elem)(struct bpf_map___61 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___61 *, void *);
	int (*map_push_elem)(struct bpf_map___61 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___61 *, void *);
	int (*map_peek_elem)(struct bpf_map___61 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___61 *, struct file___78 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___61 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___61 *, void *, struct seq_file___72 *);
	int (*map_check_btf)(const struct bpf_map___61 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___61 {
	const struct bpf_map_ops___61 *ops;
	struct bpf_map___61 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___74 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___61;

typedef void (*kthread_work_func_t___61)(struct kthread_work___61 *);

struct kthread_worker___61;

struct kthread_work___61 {
	struct list_head node;
	kthread_work_func_t___61 func;
	struct kthread_worker___61 *worker;
	int canceling;
};

struct kthread_worker___61 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___78 *task;
	struct kthread_work___61 *current_work;
};

struct kthread_delayed_work___61 {
	struct kthread_work___61 work;
	struct timer_list timer;
};

struct psi_group___61 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___61 *poll_kworker;
	struct kthread_delayed_work___61 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___61 {
	struct kernfs_node___75 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___61;

struct cgroup_subsys_state___61 {
	struct cgroup___61 *cgroup;
	struct cgroup_subsys___61 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___61 *parent;
};

struct cgroup_root___61;

struct cgroup_rstat_cpu___61;

struct cgroup___61 {
	struct cgroup_subsys_state___61 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___75 *kn;
	struct cgroup_file___61 procs_file;
	struct cgroup_file___61 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___61 *subsys[13];
	struct cgroup_root___61 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___61 *dom_cgrp;
	struct cgroup_rstat_cpu___61 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf bpf;
	atomic_t congestion_count;
	struct cgroup___61 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___61 psi;
	int ancestor_ids[0];
};

struct cftype___61;

struct cgroup_subsys___61 {
	struct cgroup_subsys_state___61 * (*css_alloc)(struct cgroup_subsys_state___61 *);
	int (*css_online)(struct cgroup_subsys_state___61 *);
	void (*css_offline)(struct cgroup_subsys_state___61 *);
	void (*css_released)(struct cgroup_subsys_state___61 *);
	void (*css_free)(struct cgroup_subsys_state___61 *);
	void (*css_reset)(struct cgroup_subsys_state___61 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___61 *, int);
	int (*css_extra_stat_show)(struct seq_file___72 *, struct cgroup_subsys_state___61 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___78 *);
	void (*cancel_fork)(struct task_struct___78 *);
	void (*fork)(struct task_struct___78 *);
	void (*exit)(struct task_struct___78 *);
	void (*free)(struct task_struct___78 *);
	void (*bind)(struct cgroup_subsys_state___61 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___61 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___61 *dfl_cftypes;
	struct cftype___61 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___61 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___61 *updated_children;
	struct cgroup___61 *updated_next;
};

struct cgroup_root___61 {
	struct kernfs_root___75 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___61 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___61 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___61 *ss;
	struct list_head node;
	struct kernfs_ops___75 *kf_ops;
	int (*open)(struct kernfs_open_file___75 *);
	void (*release)(struct kernfs_open_file___75 *);
	u64 (*read_u64)(struct cgroup_subsys_state___61 *, struct cftype___61 *);
	s64 (*read_s64)(struct cgroup_subsys_state___61 *, struct cftype___61 *);
	int (*seq_show)(struct seq_file___72 *, void *);
	void * (*seq_start)(struct seq_file___72 *, loff_t *);
	void * (*seq_next)(struct seq_file___72 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___72 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___61 *, struct cftype___61 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___61 *, struct cftype___61 *, s64);
	ssize_t (*write)(struct kernfs_open_file___75 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___75 *, struct poll_table_struct___53 *);
};

struct perf_cpu_context___50;

struct pmu___50 {
	struct list_head entry;
	struct module___70 *module;
	struct device___73 *dev;
	const struct attribute_group___72 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___50 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___50 *);
	void (*pmu_disable)(struct pmu___50 *);
	int (*event_init)(struct perf_event___50 *);
	void (*event_mapped)(struct perf_event___50 *, struct mm_struct___77 *);
	void (*event_unmapped)(struct perf_event___50 *, struct mm_struct___77 *);
	int (*add)(struct perf_event___50 *, int);
	void (*del)(struct perf_event___50 *, int);
	void (*start)(struct perf_event___50 *, int);
	void (*stop)(struct perf_event___50 *, int);
	void (*read)(struct perf_event___50 *);
	void (*start_txn)(struct pmu___50 *, unsigned int);
	int (*commit_txn)(struct pmu___50 *);
	void (*cancel_txn)(struct pmu___50 *);
	int (*event_idx)(struct perf_event___50 *);
	void (*sched_task)(struct perf_event_context___50 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___50 *);
	int (*filter_match)(struct perf_event___50 *);
	int (*check_period)(struct perf_event___50 *, u64);
};

struct perf_cpu_context___50 {
	struct perf_event_context___50 ctx;
	struct perf_event_context___50 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___50 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___50 {
	struct cgroup_subsys_state___61 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___45 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___45 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___45 *);
	struct list_head * (*get_fields)(struct trace_event_call___45 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___45 *);
};

struct trace_event_file___16;

struct trace_event_buffer___16 {
	struct ring_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___16 *trace_file;
	void *entry;
	long unsigned int flags;
	int pc;
};

struct trace_event_file___16 {
	struct list_head list;
	struct trace_event_call___45 *event_call;
	struct event_filter *filter;
	struct dentry___78 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct syscall_metadata___20 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___45 *enter_event;
	struct trace_event_call___45 *exit_event;
};

struct trace_event_raw_module_load {
	struct trace_entry ent;
	unsigned int taints;
	u32 __data_loc_name;
	char __data[0];
};

struct trace_event_raw_module_free {
	struct trace_entry ent;
	u32 __data_loc_name;
	char __data[0];
};

struct trace_event_raw_module_refcnt {
	struct trace_entry ent;
	long unsigned int ip;
	int refcnt;
	u32 __data_loc_name;
	char __data[0];
};

struct trace_event_raw_module_request {
	struct trace_entry ent;
	long unsigned int ip;
	bool wait;
	u32 __data_loc_name;
	char __data[0];
};

struct trace_event_data_offsets_module_load {
	u32 name;
};

struct trace_event_data_offsets_module_free {
	u32 name;
};

struct trace_event_data_offsets_module_refcnt {
	u32 name;
};

struct trace_event_data_offsets_module_request {
	u32 name;
};

struct mod_tree_root {
	struct latch_tree_root root;
	long unsigned int addr_min;
	long unsigned int addr_max;
};

struct load_info {
	const char *name;
	Elf64_Ehdr *hdr;
	long unsigned int len;
	Elf64_Shdr *sechdrs;
	char *secstrings;
	char *strtab;
	long unsigned int symoffs;
	long unsigned int stroffs;
	struct _ddebug *debug;
	unsigned int num_debug;
	bool sig_ok;
	long unsigned int mod_kallsyms_init_off;
	struct {
		unsigned int sym;
		unsigned int str;
		unsigned int mod;
		unsigned int vers;
		unsigned int info;
		unsigned int pcpu;
	} index;
};

struct find_symbol_arg {
	const char *name;
	bool gplok;
	bool warn;
	struct module___70 *owner;
	const s32 *crc;
	const struct kernel_symbol *sym;
};

struct mod_initfree {
	struct callback_head rcu;
	void *module_init;
};

enum key_being_used_for {
	VERIFYING_MODULE_SIGNATURE = 0,
	VERIFYING_FIRMWARE_SIGNATURE = 1,
	VERIFYING_KEXEC_PE_SIGNATURE = 2,
	VERIFYING_KEY_SIGNATURE = 3,
	VERIFYING_KEY_SELF_SIGNATURE = 4,
	VERIFYING_UNSPECIFIED_SIGNATURE = 5,
	NR__KEY_BEING_USED_FOR = 6,
};

struct asymmetric_key_subtype;

enum pkey_id_type {
	PKEY_ID_PGP = 0,
	PKEY_ID_X509 = 1,
	PKEY_ID_PKCS7 = 2,
};

struct module_signature {
	u8 algo;
	u8 hash;
	u8 id_type;
	u8 signer_len;
	u8 key_id_len;
	u8 __pad[3];
	__be32 sig_len;
};

struct module___71;

struct file___79;

struct kiocb___79;

struct iov_iter___30;

struct vm_area_struct___79;

struct inode___80;

struct file_lock___79;

struct page___79;

struct pipe_inode_info___14;

struct seq_file___73;

struct file_operations___79 {
	struct module___71 *owner;
	loff_t (*llseek)(struct file___79 *, loff_t, int);
	ssize_t (*read)(struct file___79 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___79 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___79 *, struct iov_iter___30 *);
	ssize_t (*write_iter)(struct kiocb___79 *, struct iov_iter___30 *);
	int (*iopoll)(struct kiocb___79 *, bool);
	int (*iterate)(struct file___79 *, struct dir_context *);
	int (*iterate_shared)(struct file___79 *, struct dir_context *);
	__poll_t (*poll)(struct file___79 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___79 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___79 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___79 *, struct vm_area_struct___79 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___80 *, struct file___79 *);
	int (*flush)(struct file___79 *, fl_owner_t);
	int (*release)(struct inode___80 *, struct file___79 *);
	int (*fsync)(struct file___79 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___79 *, int);
	int (*lock)(struct file___79 *, int, struct file_lock___79 *);
	ssize_t (*sendpage)(struct file___79 *, struct page___79 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___79 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___79 *, int, struct file_lock___79 *);
	ssize_t (*splice_write)(struct pipe_inode_info___14 *, struct file___79 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___79 *, loff_t *, struct pipe_inode_info___14 *, size_t, unsigned int);
	int (*setlease)(struct file___79 *, long int, struct file_lock___79 **, void **);
	long int (*fallocate)(struct file___79 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___73 *, struct file___79 *);
	ssize_t (*copy_file_range)(struct file___79 *, loff_t, struct file___79 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___79 *, loff_t, struct file___79 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___79 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___78 {
	u64 seqnum;
	struct vm_area_struct___79 *vmas[4];
};

struct page_frag___78 {
	struct page___79 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___78;

struct pid___66;

struct cred___75;

struct nsproxy___73;

struct signal_struct___69;

struct css_set___62;

struct vm_struct___56;

struct task_struct___79 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___79 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___78 *mm;
	struct mm_struct___78 *active_mm;
	struct vmacache___78 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___79 *real_parent;
	struct task_struct___79 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___79 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___66 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___66 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___66 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___75 *ptracer_cred;
	const struct cred___75 *real_cred;
	const struct cred___75 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___73 *nsproxy;
	struct signal_struct___69 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___79 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___13 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___62 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___14 *splice_pipe;
	struct page_frag___78 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___79 *oom_reaper_list;
	struct vm_struct___56 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___50 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___79 *pgtable_t___78;

struct address_space___78;

struct dev_pagemap___78;

struct page___79 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___78 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___79 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___78 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___78 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___78 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___78;

struct lruvec___78 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___78 *pgdat;
};

struct zone___78 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___78 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___78 {
	struct zone___78 *zone;
	int zone_idx;
};

struct zonelist___78 {
	struct zoneref___78 _zonerefs[25];
};

struct pglist_data___78 {
	struct zone___78 node_zones[3];
	struct zonelist___78 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___79 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___79 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___78 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___79 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___79 *owner;
};

struct secondary_data___79 {
	void *stack;
	struct task_struct___79 *task;
	long int status;
};

struct blocking_notifier_head___78 {
	struct rw_semaphore___79 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___78;

struct vm_area_struct___79 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___79 *vm_next;
	struct vm_area_struct___79 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___78 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___78 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___79 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___78;

struct user_namespace___64;

struct mm_struct___78 {
	struct {
		struct vm_area_struct___79 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___79 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___79 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___78 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___79 *owner;
		struct user_namespace___64 *user_ns;
		struct file___79 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___78 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___78;

struct address_space___78 {
	struct inode___80 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___79 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___78 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___78)(struct vm_area_struct___79 *, long unsigned int, const struct page___79 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___78)(struct page___79 *, void *);

struct device___74;

struct dev_pagemap___78 {
	dev_page_fault_t___78 page_fault;
	dev_page_free_t___78 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___74 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct dentry___79;

struct path___78 {
	struct vfsmount *mnt;
	struct dentry___79 *dentry;
};

struct fown_struct___66 {
	rwlock_t lock;
	struct pid___66 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___79 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___78 f_path;
	struct inode___80 *f_inode;
	const struct file_operations___79 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___66 f_owner;
	const struct cred___75 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___78 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___78;

struct vm_operations_struct___78 {
	void (*open)(struct vm_area_struct___79 *);
	void (*close)(struct vm_area_struct___79 *);
	int (*split)(struct vm_area_struct___79 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___79 *);
	vm_fault_t (*fault)(struct vm_fault___78 *);
	vm_fault_t (*huge_fault)(struct vm_fault___78 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___78 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___79 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___78 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___78 *);
	int (*access)(struct vm_area_struct___79 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___79 *);
	int (*set_policy)(struct vm_area_struct___79 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___79 *, long unsigned int);
	struct page___79 * (*find_special_page)(struct vm_area_struct___79 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___78 {
	struct task_struct___79 *task;
	struct core_thread___78 *next;
};

struct core_state___78 {
	atomic_t nr_threads;
	struct core_thread___78 dumper;
	struct completion startup;
};

struct key___76;

struct ucounts___64;

struct user_namespace___64 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___64 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common ns;
	long unsigned int flags;
	struct key___76 *persistent_keyring_register;
	struct rw_semaphore___79 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___64 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___78 {
	struct vm_area_struct___79 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___79 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___79 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___78 prealloc_pte;
};

struct pid_namespace___66;

struct upid___66 {
	int nr;
	struct pid_namespace___66 *ns;
};

struct pid_namespace___66 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___79 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___66 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___79 *proc_self;
	struct dentry___79 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___64 *user_ns;
	struct ucounts___64 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common ns;
};

struct pid___66 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___66 numbers[1];
};

struct user_struct___75 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___76 *uid_keyring;
	struct key___76 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___75 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___76 *session_keyring;
	struct key___76 *process_keyring;
	struct key___76 *thread_keyring;
	struct key___76 *request_key_auth;
	void *security;
	struct user_struct___75 *user;
	struct user_namespace___64 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___15;

struct cgroup_namespace___62;

struct nsproxy___73 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___66 *pid_ns_for_children;
	struct net___15 *net_ns;
	struct cgroup_namespace___62 *cgroup_ns;
};

struct signal_struct___69 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___79 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___79 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___66 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___66 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___78 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___66 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___62;

struct cgroup___62;

struct css_set___62 {
	struct cgroup_subsys_state___62 *subsys[13];
	refcount_t refcount;
	struct css_set___62 *dom_cset;
	struct cgroup___62 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___62 *mg_src_cgrp;
	struct cgroup___62 *mg_dst_cgrp;
	struct css_set___62 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___78;

struct pipe_buffer___14;

struct pipe_inode_info___14 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___79 *tmp_page;
	struct fasync_struct___78 *fasync_readers;
	struct fasync_struct___78 *fasync_writers;
	struct pipe_buffer___14 *bufs;
	struct user_struct___75 *user;
};

struct vm_struct___56 {
	struct vm_struct___56 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___79 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___69 {
	struct task_struct___79 task;
	long unsigned int stack[8192];
};

struct kset___75;

struct kobj_type___75;

struct kernfs_node___76;

struct kobject___76 {
	const char *name;
	struct list_head entry;
	struct kobject___76 *parent;
	struct kset___75 *kset;
	struct kobj_type___75 *ktype;
	struct kernfs_node___76 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___74 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___74 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___74;

struct bus_type___74;

struct device_driver___74;

struct dev_pm_domain___74;

struct dma_map_ops___19;

struct fwnode_handle___53;

struct class___74;

struct attribute_group___73;

struct device___74 {
	struct device___74 *parent;
	struct device_private *p;
	struct kobject___76 kobj;
	const char *init_name;
	const struct device_type___74 *type;
	struct mutex mutex;
	struct bus_type___74 *bus;
	struct device_driver___74 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___74 power;
	struct dev_pm_domain___74 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___19 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___53 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___74 *class;
	const struct attribute_group___73 **groups;
	void (*release)(struct device___74 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___78;

struct super_block___79;

struct dentry___79 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___79 *d_parent;
	struct qstr d_name;
	struct inode___80 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___78 *d_op;
	struct super_block___79 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___78;

struct block_device___79;

struct inode___80 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___78 *i_op;
	struct super_block___79 *i_sb;
	struct address_space___78 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___79 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___79 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___78 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___14 *i_pipe;
		struct block_device___79 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___78 {
	int (*d_revalidate)(struct dentry___79 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___79 *, unsigned int);
	int (*d_hash)(const struct dentry___79 *, struct qstr *);
	int (*d_compare)(const struct dentry___79 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___79 *);
	int (*d_init)(struct dentry___79 *);
	void (*d_release)(struct dentry___79 *);
	void (*d_prune)(struct dentry___79 *);
	void (*d_iput)(struct dentry___79 *, struct inode___80 *);
	char * (*d_dname)(struct dentry___79 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___78 *);
	int (*d_manage)(const struct path___78 *, bool);
	struct dentry___79 * (*d_real)(struct dentry___79 *, const struct inode___80 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___78;

struct mem_dqinfo___78 {
	struct quota_format_type___78 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___78;

struct quota_info___78 {
	unsigned int flags;
	struct rw_semaphore___79 dqio_sem;
	struct inode___80 *files[3];
	struct mem_dqinfo___78 info[3];
	const struct quota_format_ops___78 *ops[3];
};

struct rcuwait___78 {
	struct task_struct___79 *task;
};

struct percpu_rw_semaphore___78 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___79 rw_sem;
	struct rcuwait___78 writer;
	int readers_block;
};

struct sb_writers___78 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___78 rw_sem[3];
};

struct file_system_type___78;

struct super_operations___78;

struct dquot_operations___78;

struct quotactl_ops___78;

struct super_block___79 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___78 *s_type;
	const struct super_operations___78 *s_op;
	const struct dquot_operations___78 *dq_op;
	const struct quotactl_ops___78 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___79 *s_root;
	struct rw_semaphore___79 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___79 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___78 s_dquot;
	struct sb_writers___78 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___78 *s_d_op;
	int cleancache_poolid;
	struct shrinker___29 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___64 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___79 {
	struct file___79 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___79 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___79 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___79 *ia_file;
};

struct dquot___78 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___79 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___78 {
	int qf_fmt_id;
	const struct quota_format_ops___78 *qf_ops;
	struct module___71 *qf_owner;
	struct quota_format_type___78 *qf_next;
};

struct quota_format_ops___78 {
	int (*check_quota_file)(struct super_block___79 *, int);
	int (*read_file_info)(struct super_block___79 *, int);
	int (*write_file_info)(struct super_block___79 *, int);
	int (*free_file_info)(struct super_block___79 *, int);
	int (*read_dqblk)(struct dquot___78 *);
	int (*commit_dqblk)(struct dquot___78 *);
	int (*release_dqblk)(struct dquot___78 *);
	int (*get_next_id)(struct super_block___79 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___78 {
	int (*write_dquot)(struct dquot___78 *);
	struct dquot___78 * (*alloc_dquot)(struct super_block___79 *, int);
	void (*destroy_dquot)(struct dquot___78 *);
	int (*acquire_dquot)(struct dquot___78 *);
	int (*release_dquot)(struct dquot___78 *);
	int (*mark_dirty)(struct dquot___78 *);
	int (*write_info)(struct super_block___79 *, int);
	qsize_t * (*get_reserved_space)(struct inode___80 *);
	int (*get_projid)(struct inode___80 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___80 *, qsize_t *);
	int (*get_next_id)(struct super_block___79 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___78 {
	int (*quota_on)(struct super_block___79 *, int, int, const struct path___78 *);
	int (*quota_off)(struct super_block___79 *, int);
	int (*quota_enable)(struct super_block___79 *, unsigned int);
	int (*quota_disable)(struct super_block___79 *, unsigned int);
	int (*quota_sync)(struct super_block___79 *, int);
	int (*set_info)(struct super_block___79 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___79 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___79 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___79 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___79 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___79 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___68 {
	struct kobject___76 kobj;
	struct module___71 *mod;
	struct kobject___76 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___68 {
	struct module___71 *mod;
	struct latch_tree_node node;
};

struct module_layout___68 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___68 mtn;
};

struct module_attribute___68;

struct kernel_param___68;

struct module___71 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___68 mkobj;
	struct module_attribute___68 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___76 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___68 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___68 core_layout;
	struct module_layout___68 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___78 {
	int (*writepage)(struct page___79 *, struct writeback_control___3 *);
	int (*readpage)(struct file___79 *, struct page___79 *);
	int (*writepages)(struct address_space___78 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___79 *);
	int (*readpages)(struct file___79 *, struct address_space___78 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___79 *, struct address_space___78 *, loff_t, unsigned int, unsigned int, struct page___79 **, void **);
	int (*write_end)(struct file___79 *, struct address_space___78 *, loff_t, unsigned int, unsigned int, struct page___79 *, void *);
	sector_t (*bmap)(struct address_space___78 *, sector_t);
	void (*invalidatepage)(struct page___79 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___79 *, gfp_t);
	void (*freepage)(struct page___79 *);
	ssize_t (*direct_IO)(struct kiocb___79 *, struct iov_iter___30 *);
	int (*migratepage)(struct address_space___78 *, struct page___79 *, struct page___79 *, enum migrate_mode);
	bool (*isolate_page)(struct page___79 *, isolate_mode_t);
	void (*putback_page)(struct page___79 *);
	int (*launder_page)(struct page___79 *);
	int (*is_partially_uptodate)(struct page___79 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___79 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___78 *, struct page___79 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___79 *, sector_t *);
	void (*swap_deactivate)(struct file___79 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct iov_iter___30 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___3 *bvec;
		struct pipe_inode_info___14 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___79 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___80 *bd_inode;
	struct super_block___79 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___79 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___78 {
	struct dentry___79 * (*lookup)(struct inode___80 *, struct dentry___79 *, unsigned int);
	const char * (*get_link)(struct dentry___79 *, struct inode___80 *, struct delayed_call *);
	int (*permission)(struct inode___80 *, int);
	struct posix_acl * (*get_acl)(struct inode___80 *, int);
	int (*readlink)(struct dentry___79 *, char *, int);
	int (*create)(struct inode___80 *, struct dentry___79 *, umode_t, bool);
	int (*link)(struct dentry___79 *, struct inode___80 *, struct dentry___79 *);
	int (*unlink)(struct inode___80 *, struct dentry___79 *);
	int (*symlink)(struct inode___80 *, struct dentry___79 *, const char *);
	int (*mkdir)(struct inode___80 *, struct dentry___79 *, umode_t);
	int (*rmdir)(struct inode___80 *, struct dentry___79 *);
	int (*mknod)(struct inode___80 *, struct dentry___79 *, umode_t, dev_t);
	int (*rename)(struct inode___80 *, struct dentry___79 *, struct inode___80 *, struct dentry___79 *, unsigned int);
	int (*setattr)(struct dentry___79 *, struct iattr___79 *);
	int (*getattr)(const struct path___78 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___79 *, char *, size_t);
	int (*fiemap)(struct inode___80 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___80 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___80 *, struct dentry___79 *, struct file___79 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___80 *, struct dentry___79 *, umode_t);
	int (*set_acl)(struct inode___80 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___78 {
	void (*fl_copy_lock)(struct file_lock___79 *, struct file_lock___79 *);
	void (*fl_release_private)(struct file_lock___79 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___78;

struct file_lock___79 {
	struct file_lock___79 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___79 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___78 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___78 *fl_ops;
	const struct lock_manager_operations___78 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___78 {
	int (*lm_compare_owner)(struct file_lock___79 *, struct file_lock___79 *);
	long unsigned int (*lm_owner_key)(struct file_lock___79 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___79 *);
	int (*lm_grant)(struct file_lock___79 *, int);
	bool (*lm_break)(struct file_lock___79 *);
	int (*lm_change)(struct file_lock___79 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___79 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___78 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___78 *fa_next;
	struct file___79 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___78 {
	const char *name;
	int fs_flags;
	struct dentry___79 * (*mount)(struct file_system_type___78 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___79 *);
	struct module___71 *owner;
	struct file_system_type___78 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___78 {
	struct inode___80 * (*alloc_inode)(struct super_block___79 *);
	void (*destroy_inode)(struct inode___80 *);
	void (*dirty_inode)(struct inode___80 *, int);
	int (*write_inode)(struct inode___80 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___80 *);
	void (*evict_inode)(struct inode___80 *);
	void (*put_super)(struct super_block___79 *);
	int (*sync_fs)(struct super_block___79 *, int);
	int (*freeze_super)(struct super_block___79 *);
	int (*freeze_fs)(struct super_block___79 *);
	int (*thaw_super)(struct super_block___79 *);
	int (*unfreeze_fs)(struct super_block___79 *);
	int (*statfs)(struct dentry___79 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___79 *, int *, char *);
	void (*umount_begin)(struct super_block___79 *);
	int (*show_options)(struct seq_file___73 *, struct dentry___79 *);
	int (*show_devname)(struct seq_file___73 *, struct dentry___79 *);
	int (*show_path)(struct seq_file___73 *, struct dentry___79 *);
	int (*show_stats)(struct seq_file___73 *, struct dentry___79 *);
	ssize_t (*quota_read)(struct super_block___79 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___79 *, int, const char *, size_t, loff_t);
	struct dquot___78 ** (*get_dquots)(struct inode___80 *);
	int (*bdev_try_to_free_page)(struct super_block___79 *, struct page___79 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___79 *, struct shrink_control___29 *);
	long int (*free_cached_objects)(struct super_block___79 *, struct shrink_control___29 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___70;

struct seq_file___73 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___70 *op;
	int poll_event;
	const struct file___79 *file;
	void *private;
};

struct kobj_attribute___76 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___76 *, struct kobj_attribute___76 *, char *);
	ssize_t (*store)(struct kobject___76 *, struct kobj_attribute___76 *, const char *, size_t);
};

typedef void compound_page_dtor___78(struct page___79 *);

struct kernfs_root___76;

struct kernfs_elem_dir___76 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___76 *root;
};

struct kernfs_syscall_ops___76;

struct kernfs_root___76 {
	struct kernfs_node___76 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___76 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___76 {
	struct kernfs_node___76 *target_kn;
};

struct kernfs_ops___76;

struct kernfs_elem_attr___76 {
	const struct kernfs_ops___76 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___76 *notify_next;
};

struct kernfs_node___76 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___76 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___76 dir;
		struct kernfs_elem_symlink___76 symlink;
		struct kernfs_elem_attr___76 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___76;

struct kernfs_ops___76 {
	int (*open)(struct kernfs_open_file___76 *);
	void (*release)(struct kernfs_open_file___76 *);
	int (*seq_show)(struct seq_file___73 *, void *);
	void * (*seq_start)(struct seq_file___73 *, loff_t *);
	void * (*seq_next)(struct seq_file___73 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___73 *, void *);
	ssize_t (*read)(struct kernfs_open_file___76 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___76 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___76 *, struct vm_area_struct___79 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___76 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___76 {
	int (*remount_fs)(struct kernfs_root___76 *, int *, char *);
	int (*show_options)(struct seq_file___73 *, struct kernfs_root___76 *);
	int (*mkdir)(struct kernfs_node___76 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___76 *);
	int (*rename)(struct kernfs_node___76 *, struct kernfs_node___76 *, const char *);
	int (*show_path)(struct seq_file___73 *, struct kernfs_node___76 *, struct kernfs_root___76 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___76 {
	struct kernfs_node___76 *kn;
	struct file___79 *file;
	struct seq_file___73 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___78 *vm_ops;
};

struct bin_attribute___73;

struct attribute_group___73 {
	const char *name;
	umode_t (*is_visible)(struct kobject___76 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___76 *, struct bin_attribute___73 *, int);
	struct attribute **attrs;
	struct bin_attribute___73 **bin_attrs;
};

struct bin_attribute___73 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___79 *, struct kobject___76 *, struct bin_attribute___73 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___79 *, struct kobject___76 *, struct bin_attribute___73 *, char *, loff_t, size_t);
	int (*mmap)(struct file___79 *, struct kobject___76 *, struct bin_attribute___73 *, struct vm_area_struct___79 *);
};

struct sysfs_ops___75 {
	ssize_t (*show)(struct kobject___76 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___76 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___75;

struct kset___75 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___76 kobj;
	const struct kset_uevent_ops___75 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___75 {
	void (*release)(struct kobject___76 *);
	const struct sysfs_ops___75 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___76 *);
	const void * (*namespace)(struct kobject___76 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___75 {
	int (* const filter)(struct kset___75 *, struct kobject___76 *);
	const char * (* const name)(struct kset___75 *, struct kobject___76 *);
	int (* const uevent)(struct kset___75 *, struct kobject___76 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___68 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___68 *);
	int (*get)(char *, const struct kernel_param___68 *);
	void (*free)(void *);
};

struct kparam_array___68;

struct kernel_param___68 {
	const char *name;
	struct module___71 *mod;
	const struct kernel_param_ops___68 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___68 *arr;
	};
};

struct kparam_array___68 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___68 *ops;
	void *elem;
};

struct module_attribute___68 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___68 *, struct module_kobject___68 *, char *);
	ssize_t (*store)(struct module_attribute___68 *, struct module_kobject___68 *, const char *, size_t);
	void (*setup)(struct module___71 *, const char *);
	int (*test)(struct module___71 *);
	void (*free)(struct module___71 *);
};

typedef int (*key_restrict_link_func_t___75)(struct key___76 *, const struct key_type *, const union key_payload *, struct key___76 *);

struct key_restriction___76;

struct key___76 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___79 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___76 *restrict_link;
};

struct key_restriction___76 {
	key_restrict_link_func_t___75 check;
	struct key___76 *key;
	struct key_type *keytype;
};

struct seq_operations___70 {
	void * (*start)(struct seq_file___73 *, loff_t *);
	void (*stop)(struct seq_file___73 *, void *);
	void * (*next)(struct seq_file___73 *, void *, loff_t *);
	int (*show)(struct seq_file___73 *, void *);
};

struct net_device___11;

struct nf_bridge_info___6;

struct sk_buff___10 {
	union {
		struct {
			struct sk_buff___10 *next;
			struct sk_buff___10 *prev;
			union {
				struct net_device___11 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___10 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___6 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___6;

struct netns_frags___6 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___6 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv4___6 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct sock *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock **tcp_sk;
	struct netns_frags___6 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct dst_ops___13 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___13 *);
	struct dst_entry___2 * (*check)(struct dst_entry___2 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___2 *);
	unsigned int (*mtu)(const struct dst_entry___2 *);
	u32 * (*cow_metrics)(struct dst_entry___2 *, long unsigned int);
	void (*destroy)(struct dst_entry___2 *);
	void (*ifdown)(struct dst_entry___2 *, struct net_device___11 *, int);
	struct dst_entry___2 * (*negative_advice)(struct dst_entry___2 *);
	void (*link_failure)(struct sk_buff___10 *);
	void (*update_pmtu)(struct dst_entry___2 *, struct sock *, struct sk_buff___10 *, u32);
	void (*redirect)(struct dst_entry___2 *, struct sock *, struct sk_buff___10 *);
	int (*local_out)(struct net___15 *, struct sock *, struct sk_buff___10 *);
	struct neighbour___2 * (*neigh_lookup)(const struct dst_entry___2 *, struct sk_buff___10 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___2 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___12 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___6 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___13 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct sock *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops *notifier_ops;
	struct fib_notifier_ops *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_nf_frag___6 {
	struct netns_frags___6 frags;
};

struct netns_xfrm___12 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___13 xfrm4_dst_ops;
	struct dst_ops___13 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___5;

struct net___15 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___64 *user_ns;
	struct ucounts___64 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___11 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___6 ipv4;
	struct netns_ipv6___12 ipv6;
	struct netns_sctp sctp;
	struct netns_nf nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___6 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock *nfnl;
	struct sock *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___12 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___5 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___74 {
	int (*prepare)(struct device___74 *);
	void (*complete)(struct device___74 *);
	int (*suspend)(struct device___74 *);
	int (*resume)(struct device___74 *);
	int (*freeze)(struct device___74 *);
	int (*thaw)(struct device___74 *);
	int (*poweroff)(struct device___74 *);
	int (*restore)(struct device___74 *);
	int (*suspend_late)(struct device___74 *);
	int (*resume_early)(struct device___74 *);
	int (*freeze_late)(struct device___74 *);
	int (*thaw_early)(struct device___74 *);
	int (*poweroff_late)(struct device___74 *);
	int (*restore_early)(struct device___74 *);
	int (*suspend_noirq)(struct device___74 *);
	int (*resume_noirq)(struct device___74 *);
	int (*freeze_noirq)(struct device___74 *);
	int (*thaw_noirq)(struct device___74 *);
	int (*poweroff_noirq)(struct device___74 *);
	int (*restore_noirq)(struct device___74 *);
	int (*runtime_suspend)(struct device___74 *);
	int (*runtime_resume)(struct device___74 *);
	int (*runtime_idle)(struct device___74 *);
};

struct dev_pm_domain___74 {
	struct dev_pm_ops___74 ops;
	void (*detach)(struct device___74 *, bool);
	int (*activate)(struct device___74 *);
	void (*sync)(struct device___74 *);
	void (*dismiss)(struct device___74 *);
};

struct bus_type___74 {
	const char *name;
	const char *dev_name;
	struct device___74 *dev_root;
	const struct attribute_group___73 **bus_groups;
	const struct attribute_group___73 **dev_groups;
	const struct attribute_group___73 **drv_groups;
	int (*match)(struct device___74 *, struct device_driver___74 *);
	int (*uevent)(struct device___74 *, struct kobj_uevent_env *);
	int (*probe)(struct device___74 *);
	int (*remove)(struct device___74 *);
	void (*shutdown)(struct device___74 *);
	int (*online)(struct device___74 *);
	int (*offline)(struct device___74 *);
	int (*suspend)(struct device___74 *, pm_message_t);
	int (*resume)(struct device___74 *);
	int (*num_vf)(struct device___74 *);
	int (*dma_configure)(struct device___74 *);
	const struct dev_pm_ops___74 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___74 {
	const char *name;
	struct bus_type___74 *bus;
	struct module___71 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___74 *);
	int (*remove)(struct device___74 *);
	void (*shutdown)(struct device___74 *);
	int (*suspend)(struct device___74 *, pm_message_t);
	int (*resume)(struct device___74 *);
	const struct attribute_group___73 **groups;
	const struct dev_pm_ops___74 *pm;
	void (*coredump)(struct device___74 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___74 {
	const char *name;
	const struct attribute_group___73 **groups;
	int (*uevent)(struct device___74 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___74 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___74 *);
	const struct dev_pm_ops___74 *pm;
};

struct class___74 {
	const char *name;
	struct module___71 *owner;
	const struct attribute_group___73 **class_groups;
	const struct attribute_group___73 **dev_groups;
	struct kobject___76 *dev_kobj;
	int (*dev_uevent)(struct device___74 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___74 *, umode_t *);
	void (*class_release)(struct class___74 *);
	void (*dev_release)(struct device___74 *);
	int (*shutdown_pre)(struct device___74 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___74 *);
	const struct dev_pm_ops___74 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___19 {
	void * (*alloc)(struct device___74 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___74 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___74 *, struct vm_area_struct___79 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___74 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___74 *, struct page___79 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___74 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___74 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___74 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___74 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___74 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___74 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___74 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___74 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___74 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___74 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___74 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___74 *, u64);
	u64 (*get_required_mask)(struct device___74 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___53;

struct fwnode_handle___53 {
	struct fwnode_handle___53 *secondary;
	const struct fwnode_operations___53 *ops;
};

struct fwnode_reference_args___53;

struct fwnode_endpoint___53;

struct fwnode_operations___53 {
	struct fwnode_handle___53 * (*get)(struct fwnode_handle___53 *);
	void (*put)(struct fwnode_handle___53 *);
	bool (*device_is_available)(const struct fwnode_handle___53 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___53 *, const struct device___74 *);
	bool (*property_present)(const struct fwnode_handle___53 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___53 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___53 *, const char *, const char **, size_t);
	struct fwnode_handle___53 * (*get_parent)(const struct fwnode_handle___53 *);
	struct fwnode_handle___53 * (*get_next_child_node)(const struct fwnode_handle___53 *, struct fwnode_handle___53 *);
	struct fwnode_handle___53 * (*get_named_child_node)(const struct fwnode_handle___53 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___53 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___53 *);
	struct fwnode_handle___53 * (*graph_get_next_endpoint)(const struct fwnode_handle___53 *, struct fwnode_handle___53 *);
	struct fwnode_handle___53 * (*graph_get_remote_endpoint)(const struct fwnode_handle___53 *);
	struct fwnode_handle___53 * (*graph_get_port_parent)(struct fwnode_handle___53 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___53 *, struct fwnode_endpoint___53 *);
};

struct fwnode_endpoint___53 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___53 *local_fwnode;
};

struct fwnode_reference_args___53 {
	struct fwnode_handle___53 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___14;

struct pipe_buffer___14 {
	struct page___79 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___14 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___14 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___14 *, struct pipe_buffer___14 *);
	void (*release)(struct pipe_inode_info___14 *, struct pipe_buffer___14 *);
	int (*steal)(struct pipe_inode_info___14 *, struct pipe_buffer___14 *);
	union {
		bool (*get)(struct pipe_inode_info___14 *, struct pipe_buffer___14 *);
		struct {
			void (*get)(struct pipe_inode_info___14 *, struct pipe_buffer___14 *);
		} __UNIQUE_ID_rh_kabi_hide21;
		union {		};
	};
};

struct nf_bridge_info___6 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___6 = 0,
		BRNF_PROTO_8021Q___6 = 1,
		BRNF_PROTO_PPPOE___6 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___11 *physindev;
	struct net_device___11 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___6(struct sk_buff___10 **);

typedef struct {
	struct net___15 *net;
} possible_net_t___6;

struct net_device_ops___6;

struct ethtool_ops___6;

struct xfrmdev_ops___6;

struct tlsdev_ops___6;

struct header_ops___6;

struct netdev_rx_queue___6;

struct mini_Qdisc___5;

struct netdev_queue___6;

struct Qdisc___5;

struct rtnl_link_ops___5;

struct dcbnl_rtnl_ops___6;

struct net_device___11 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___6 *netdev_ops;
	const struct ethtool_ops___6 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___2 *l3mdev_ops;
	const struct ndisc_ops___2 *ndisc_ops;
	const struct xfrmdev_ops___6 *xfrmdev_ops;
	const struct tlsdev_ops___6 *tlsdev_ops;
	const struct header_ops___6 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___75 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___2 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___6 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___5 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___6 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___5 *miniq_ingress;
	struct netdev_queue___6 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___6 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___5 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___5 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___6 = 0,
		NETREG_REGISTERED___6 = 1,
		NETREG_UNREGISTERING___6 = 2,
		NETREG_UNREGISTERED___6 = 3,
		NETREG_RELEASED___6 = 4,
		NETREG_DUMMY___6 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___6 = 0,
		RTNL_LINK_INITIALIZING___6 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___11 *);
	struct netpoll_info *npinfo;
	possible_net_t___6 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___74 dev;
	const struct attribute_group___73 *sysfs_groups[4];
	const struct attribute_group___73 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___5 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___6 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide35;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct sk_buff_head___7 {
	struct sk_buff___10 *next;
	struct sk_buff___10 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct ethtool_ops___6 {
	int (*get_settings)(struct net_device___11 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___11 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___11 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___11 *);
	void (*get_regs)(struct net_device___11 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___11 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___11 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___11 *);
	void (*set_msglevel)(struct net_device___11 *, u32);
	int (*nway_reset)(struct net_device___11 *);
	u32 (*get_link)(struct net_device___11 *);
	int (*get_eeprom_len)(struct net_device___11 *);
	int (*get_eeprom)(struct net_device___11 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___11 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___11 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___11 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___11 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___11 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___11 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___11 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___11 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___11 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___11 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___11 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___11 *);
	void (*complete)(struct net_device___11 *);
	u32 (*get_priv_flags)(struct net_device___11 *);
	int (*set_priv_flags)(struct net_device___11 *, u32);
	int (*get_sset_count)(struct net_device___11 *, int);
	int (*get_rxnfc)(struct net_device___11 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___11 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___11 *, struct ethtool_flash *);
	int (*reset)(struct net_device___11 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___11 *);
	u32 (*get_rxfh_indir_size)(struct net_device___11 *);
	int (*get_rxfh)(struct net_device___11 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___11 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___11 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___11 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___11 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___11 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___11 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___11 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___11 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___11 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___11 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___11 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___11 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___11 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___11 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___11 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___11 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___11 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___11 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___11 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___11 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___11 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	int (*get_fecparam)(struct net_device___11 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___11 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___11 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___11 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___11 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___6;

struct inet_frags___6 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___6 *, const void *);
	void (*destructor)(struct inet_frag_queue___6 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___6 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___10 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___10 *fragments_tail;
	struct sk_buff___10 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___6 *net;
	struct callback_head rcu;
};

struct ucounts___64 {
	struct hlist_node node;
	struct user_namespace___64 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_prog_aux___5;

struct bpf_prog___5 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___5 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

struct pernet_operations___6 {
	struct list_head list;
	int (*init)(struct net___15 *);
	void (*exit)(struct net___15 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___6 {
	int (*ieee_getets)(struct net_device___11 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___11 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___11 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___11 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___11 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___11 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___11 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___11 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___11 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___11 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___11 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___11 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___11 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___11 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___11 *);
	u8 (*setstate)(struct net_device___11 *, u8);
	void (*getpermhwaddr)(struct net_device___11 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___11 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___11 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___11 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___11 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___11 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___11 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___11 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___11 *, int, u8 *);
	void (*setpfccfg)(struct net_device___11 *, int, u8);
	void (*getpfccfg)(struct net_device___11 *, int, u8 *);
	u8 (*setall)(struct net_device___11 *);
	u8 (*getcap)(struct net_device___11 *, int, u8 *);
	int (*getnumtcs)(struct net_device___11 *, int, u8 *);
	int (*setnumtcs)(struct net_device___11 *, int, u8);
	u8 (*getpfcstate)(struct net_device___11 *);
	void (*setpfcstate)(struct net_device___11 *, u8);
	void (*getbcncfg)(struct net_device___11 *, int, u32 *);
	void (*setbcncfg)(struct net_device___11 *, int, u32);
	void (*getbcnrp)(struct net_device___11 *, int, u8 *);
	void (*setbcnrp)(struct net_device___11 *, int, u8);
	int (*setapp)(struct net_device___11 *, u8, u16, u8);
	int (*getapp)(struct net_device___11 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___11 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___11 *, int, u8);
	u8 (*getdcbx)(struct net_device___11 *);
	u8 (*setdcbx)(struct net_device___11 *, u8);
	int (*peer_getappinfo)(struct net_device___11 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___11 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___11 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___11 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___11 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___11 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___62 {
	refcount_t count;
	struct ns_common ns;
	struct user_namespace___64 *user_ns;
	struct ucounts___64 *ucounts;
	struct css_set___62 *root_cset;
};

struct bpf_map___62;

struct bpf_map_ops___62 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___62 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___62 *, struct file___79 *);
	void (*map_free)(struct bpf_map___62 *);
	int (*map_get_next_key)(struct bpf_map___62 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___62 *);
	void * (*map_lookup_elem)(struct bpf_map___62 *, void *);
	int (*map_update_elem)(struct bpf_map___62 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___62 *, void *);
	int (*map_push_elem)(struct bpf_map___62 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___62 *, void *);
	int (*map_peek_elem)(struct bpf_map___62 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___62 *, struct file___79 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___62 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___62 *, void *, struct seq_file___73 *);
	int (*map_check_btf)(const struct bpf_map___62 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___62 {
	const struct bpf_map_ops___62 *ops;
	struct bpf_map___62 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___75 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___6;

struct bpf_map_dev_ops___6 {
	int (*map_get_next_key)(struct bpf_offloaded_map___6 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___6 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___6 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___6 *, void *);
};

struct bpf_offloaded_map___6 {
	struct bpf_map___62 map;
	struct net_device___11 *netdev;
	const struct bpf_map_dev_ops___6 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___5 {
	int (*test_run)(struct bpf_prog___5 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___5 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___5 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___5 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___5 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___5 *, u32 *);
};

struct bpf_prog_offload_ops___5 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___5 *);
	int (*translate)(struct bpf_prog___5 *);
	void (*destroy)(struct bpf_prog___5 *);
};

struct bpf_prog_offload___5 {
	struct bpf_prog___5 *prog;
	struct net_device___11 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___5 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___5 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___5 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___5 *ops;
	struct bpf_map___62 **used_maps;
	struct bpf_prog___5 *prog;
	struct user_struct___75 *user;
	u64 load_time;
	struct bpf_map___62 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___5 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___5 {
	struct bpf_prog___5 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___5 {
	struct callback_head rcu;
	struct bpf_prog_array_item___5 items[0];
};

struct cgroup_bpf___5 {
	struct bpf_prog_array___5 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___5 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___62;

typedef void (*kthread_work_func_t___62)(struct kthread_work___62 *);

struct kthread_worker___62;

struct kthread_work___62 {
	struct list_head node;
	kthread_work_func_t___62 func;
	struct kthread_worker___62 *worker;
	int canceling;
};

struct kthread_worker___62 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___79 *task;
	struct kthread_work___62 *current_work;
};

struct kthread_delayed_work___62 {
	struct kthread_work___62 work;
	struct timer_list timer;
};

struct psi_group___62 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___62 *poll_kworker;
	struct kthread_delayed_work___62 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___62 {
	struct kernfs_node___76 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___62;

struct cgroup_subsys_state___62 {
	struct cgroup___62 *cgroup;
	struct cgroup_subsys___62 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___62 *parent;
};

struct cgroup_root___62;

struct cgroup_rstat_cpu___62;

struct cgroup___62 {
	struct cgroup_subsys_state___62 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___76 *kn;
	struct cgroup_file___62 procs_file;
	struct cgroup_file___62 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___62 *subsys[13];
	struct cgroup_root___62 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___62 *dom_cgrp;
	struct cgroup_rstat_cpu___62 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___5 bpf;
	atomic_t congestion_count;
	struct cgroup___62 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___62 psi;
	int ancestor_ids[0];
};

struct cftype___62;

struct cgroup_subsys___62 {
	struct cgroup_subsys_state___62 * (*css_alloc)(struct cgroup_subsys_state___62 *);
	int (*css_online)(struct cgroup_subsys_state___62 *);
	void (*css_offline)(struct cgroup_subsys_state___62 *);
	void (*css_released)(struct cgroup_subsys_state___62 *);
	void (*css_free)(struct cgroup_subsys_state___62 *);
	void (*css_reset)(struct cgroup_subsys_state___62 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___62 *, int);
	int (*css_extra_stat_show)(struct seq_file___73 *, struct cgroup_subsys_state___62 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___79 *);
	void (*cancel_fork)(struct task_struct___79 *);
	void (*fork)(struct task_struct___79 *);
	void (*exit)(struct task_struct___79 *);
	void (*free)(struct task_struct___79 *);
	void (*bind)(struct cgroup_subsys_state___62 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___62 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___62 *dfl_cftypes;
	struct cftype___62 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___62 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___62 *updated_children;
	struct cgroup___62 *updated_next;
};

struct cgroup_root___62 {
	struct kernfs_root___76 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___62 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___62 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___62 *ss;
	struct list_head node;
	struct kernfs_ops___76 *kf_ops;
	int (*open)(struct kernfs_open_file___76 *);
	void (*release)(struct kernfs_open_file___76 *);
	u64 (*read_u64)(struct cgroup_subsys_state___62 *, struct cftype___62 *);
	s64 (*read_s64)(struct cgroup_subsys_state___62 *, struct cftype___62 *);
	int (*seq_show)(struct seq_file___73 *, void *);
	void * (*seq_start)(struct seq_file___73 *, loff_t *);
	void * (*seq_next)(struct seq_file___73 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___73 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___62 *, struct cftype___62 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___62 *, struct cftype___62 *, s64);
	ssize_t (*write)(struct kernfs_open_file___76 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___76 *, struct poll_table_struct___6 *);
};

struct xdp_rxq_info___6 {
	struct net_device___11 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___6 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___11 *dev_rx;
};

struct netlink_callback___6 {
	struct sk_buff___10 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___6 *);
	int (*dump)(struct sk_buff___10 *, struct netlink_callback___6 *);
	int (*done)(struct netlink_callback___6 *);
	void *data;
	struct module___71 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___6 {
	int (*create)(struct sk_buff___10 *, struct net_device___11 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___10 *, unsigned char *);
	int (*cache)(const struct neighbour___2 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___11 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___6 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___6 *, int);
	int poll_owner;
	struct net_device___11 *dev;
	struct sk_buff___10 *gro_list;
	struct sk_buff___10 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___6 {
	struct net_device___11 *dev;
	struct Qdisc___5 *qdisc;
	struct Qdisc___5 *qdisc_sleeping;
	struct kobject___76 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___11 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___5 {
	struct sk_buff___10 *head;
	struct sk_buff___10 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___5;

struct Qdisc___5 {
	int (*enqueue)(struct sk_buff___10 *, struct Qdisc___5 *, struct sk_buff___10 **);
	struct sk_buff___10 * (*dequeue)(struct Qdisc___5 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___5 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___6 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___7 gso_skb;
	struct qdisc_skb_head___5 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___5 *next_sched;
	struct sk_buff_head___7 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___6 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___76 kobj;
	struct net_device___11 *dev;
	long: 64;
	struct xdp_rxq_info___6 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___6)(struct net_device___11 *, struct sk_buff___10 *, struct net_device___11 *);

struct netdev_bpf___6 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___5 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___5 *prog;
			const struct bpf_prog_offload_ops___5 *ops;
		} verifier;
		struct {
			struct bpf_prog___5 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___6 *offmap;
		};
		struct {
			struct xdp_umem *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___6 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___10 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___6 {
	int (*tls_dev_add)(struct net_device___11 *, struct sock *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___11 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___11 *, struct sock *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___6 {
	int (*ndo_init)(struct net_device___11 *);
	void (*ndo_uninit)(struct net_device___11 *);
	int (*ndo_open)(struct net_device___11 *);
	int (*ndo_stop)(struct net_device___11 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___10 *, struct net_device___11 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___10 *, struct net_device___11 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___11 *, struct sk_buff___10 *, struct net_device___11 *, select_queue_fallback_t___6);
	void (*ndo_change_rx_flags)(struct net_device___11 *, int);
	void (*ndo_set_rx_mode)(struct net_device___11 *);
	int (*ndo_set_mac_address)(struct net_device___11 *, void *);
	int (*ndo_validate_addr)(struct net_device___11 *);
	int (*ndo_do_ioctl)(struct net_device___11 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___11 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___11 *, int);
	int (*ndo_neigh_setup)(struct net_device___11 *, struct neigh_parms___3 *);
	void (*ndo_tx_timeout)(struct net_device___11 *);
	void (*ndo_get_stats64)(struct net_device___11 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___11 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___11 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___11 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___11 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___11 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___11 *);
	int (*ndo_netpoll_setup)(struct net_device___11 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___11 *);
	int (*ndo_set_vf_mac)(struct net_device___11 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___11 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___11 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___11 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___11 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___11 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___11 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___11 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___11 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___11 *, int, struct sk_buff___10 *);
	int (*ndo_set_vf_guid)(struct net_device___11 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___11 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___11 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___11 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___11 *, const struct sk_buff___10 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___11 *, struct net_device___11 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___11 *, struct net_device___11 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___11 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___11 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___11 *, struct neighbour___2 *);
	void (*ndo_neigh_destroy)(struct net_device___11 *, struct neighbour___2 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___11 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___11 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___11 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___10 *, struct netlink_callback___6 *, struct net_device___11 *, struct net_device___11 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___11 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___11 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___10 *, u32, u32, struct net_device___11 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___11 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___11 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___11 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___11 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___11 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___11 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___11 *, struct net_device___11 *);
	void (*ndo_dfwd_del_station)(struct net_device___11 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___11 *);
	int (*ndo_set_tx_maxrate)(struct net_device___11 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___11 *);
	int (*ndo_change_proto_down)(struct net_device___11 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___11 *, struct sk_buff___10 *);
	void (*ndo_set_rx_headroom)(struct net_device___11 *, int);
	int (*ndo_bpf)(struct net_device___11 *, struct netdev_bpf___6 *);
	int (*ndo_xdp_xmit)(struct net_device___11 *, int, struct xdp_frame___6 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___11 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___11 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct tcf_proto___5;

struct mini_Qdisc___5 {
	struct tcf_proto___5 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___5 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___11 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___15 *, struct net_device___11 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___11 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___11 *, struct list_head *);
	size_t (*get_size)(const struct net_device___11 *);
	int (*fill_info)(struct sk_buff___10 *, const struct net_device___11 *);
	size_t (*get_xstats_size)(const struct net_device___11 *);
	int (*fill_xstats)(struct sk_buff___10 *, const struct net_device___11 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___11 *, struct net_device___11 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___11 *, const struct net_device___11 *);
	int (*fill_slave_info)(struct sk_buff___10 *, const struct net_device___11 *, const struct net_device___11 *);
	struct net___15 * (*get_link_net)(const struct net_device___11 *);
	size_t (*get_linkxstats_size)(const struct net_device___11 *, int);
	int (*fill_linkxstats)(struct sk_buff___10 *, const struct net_device___11 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___6 {
	struct list_head poll_list;
	struct sk_buff_head___7 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___6 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___5 *output_queue;
	struct Qdisc___5 **output_queue_tailp;
	struct sk_buff___10 *completion_queue;
	struct sk_buff_head___7 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___6 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___7 input_pkt_queue;
	struct napi_struct___6 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct gnet_dump___5 {
	spinlock_t *lock;
	struct sk_buff___10 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___5;

struct Qdisc_ops___5 {
	struct Qdisc_ops___5 *next;
	const struct Qdisc_class_ops___5 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___10 *, struct Qdisc___5 *, struct sk_buff___10 **);
	struct sk_buff___10 * (*dequeue)(struct Qdisc___5 *);
	struct sk_buff___10 * (*peek)(struct Qdisc___5 *);
	int (*init)(struct Qdisc___5 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___5 *);
	void (*destroy)(struct Qdisc___5 *);
	int (*change)(struct Qdisc___5 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___5 *);
	int (*change_tx_queue_len)(struct Qdisc___5 *, unsigned int);
	int (*dump)(struct Qdisc___5 *, struct sk_buff___10 *);
	int (*dump_stats)(struct Qdisc___5 *, struct gnet_dump___5 *);
	void (*ingress_block_set)(struct Qdisc___5 *, u32);
	void (*egress_block_set)(struct Qdisc___5 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___5 *);
	u32 (*egress_block_get)(struct Qdisc___5 *);
	struct module___71 *owner;
};

struct tcf_block___5;

struct Qdisc_class_ops___5 {
	unsigned int flags;
	struct netdev_queue___6 * (*select_queue)(struct Qdisc___5 *, struct tcmsg *);
	int (*graft)(struct Qdisc___5 *, long unsigned int, struct Qdisc___5 *, struct Qdisc___5 **, struct netlink_ext_ack *);
	struct Qdisc___5 * (*leaf)(struct Qdisc___5 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___5 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___5 *, u32);
	int (*change)(struct Qdisc___5 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___5 *, long unsigned int);
	void (*walk)(struct Qdisc___5 *, struct qdisc_walker *);
	struct tcf_block___5 * (*tcf_block)(struct Qdisc___5 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___5 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___5 *, long unsigned int);
	int (*dump)(struct Qdisc___5 *, long unsigned int, struct sk_buff___10 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___5 *, long unsigned int, struct gnet_dump___5 *);
};

struct tcf_chain___5;

struct tcf_block___5 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___15 *net;
	struct Qdisc___5 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___5 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___5;

struct tcf_proto_ops___5;

struct tcf_proto___5 {
	struct tcf_proto___5 *next;
	void *root;
	int (*classify)(struct sk_buff___10 *, const struct tcf_proto___5 *, struct tcf_result___5 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___5 *ops;
	struct tcf_chain___5 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___5 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___5 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___5 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___10 *, const struct tcf_proto___5 *, struct tcf_result___5 *);
	int (*init)(struct tcf_proto___5 *);
	void (*destroy)(struct tcf_proto___5 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___5 *, u32);
	void (*put)(struct tcf_proto___5 *, void *);
	int (*change)(struct net___15 *, struct sk_buff___10 *, struct tcf_proto___5 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___5 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___5 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___5 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___15 *, struct tcf_chain___5 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___15 *, struct tcf_proto___5 *, void *, struct sk_buff___10 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___10 *, struct net___15 *, void *);
	struct module___71 *owner;
	int flags;
};

struct tcf_chain___5 {
	struct mutex filter_chain_lock;
	struct tcf_proto___5 *filter_chain;
	struct list_head list;
	struct tcf_block___5 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___5 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct bpf_redirect_info___5 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___62 *map;
	struct bpf_map___62 *map_to_flush;
	u32 kern_flags;
};

struct kallsym_iter {
	loff_t pos;
	loff_t pos_arch_end;
	loff_t pos_mod_end;
	loff_t pos_ftrace_mod_end;
	long unsigned int value;
	unsigned int nameoff;
	char type;
	char name[128];
	char module_name[56];
	int exported;
	int show_value;
};

typedef struct {
	int val[2];
} __kernel_fsid_t;

struct module___72;

struct file___80;

struct kiocb___80;

struct iov_iter___31;

struct poll_table_struct___54;

struct vm_area_struct___80;

struct inode___81;

struct file_lock___80;

struct page___80;

struct seq_file___74;

struct file_operations___80 {
	struct module___72 *owner;
	loff_t (*llseek)(struct file___80 *, loff_t, int);
	ssize_t (*read)(struct file___80 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___80 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___80 *, struct iov_iter___31 *);
	ssize_t (*write_iter)(struct kiocb___80 *, struct iov_iter___31 *);
	int (*iopoll)(struct kiocb___80 *, bool);
	int (*iterate)(struct file___80 *, struct dir_context *);
	int (*iterate_shared)(struct file___80 *, struct dir_context *);
	__poll_t (*poll)(struct file___80 *, struct poll_table_struct___54 *);
	long int (*unlocked_ioctl)(struct file___80 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___80 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___80 *, struct vm_area_struct___80 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___81 *, struct file___80 *);
	int (*flush)(struct file___80 *, fl_owner_t);
	int (*release)(struct inode___81 *, struct file___80 *);
	int (*fsync)(struct file___80 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___80 *, int);
	int (*lock)(struct file___80 *, int, struct file_lock___80 *);
	ssize_t (*sendpage)(struct file___80 *, struct page___80 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___80 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___80 *, int, struct file_lock___80 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___80 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___80 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___80 *, long int, struct file_lock___80 **, void **);
	long int (*fallocate)(struct file___80 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___74 *, struct file___80 *);
	ssize_t (*copy_file_range)(struct file___80 *, loff_t, struct file___80 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___80 *, loff_t, struct file___80 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___80 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___79 {
	u64 seqnum;
	struct vm_area_struct___80 *vmas[4];
};

struct page_frag___79 {
	struct page___80 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___51;

struct debug_info___51 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___51 *hbp_break[16];
	struct perf_event___51 *hbp_watch[16];
};

struct thread_struct___51 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___51 debug;
	long: 64;
};

struct mm_struct___79;

struct pid___67;

struct cred___76;

struct nsproxy___74;

struct signal_struct___70;

struct bio_list___31;

struct backing_dev_info___31;

struct io_context___14;

struct css_set___63;

struct perf_event_context___51;

struct request_queue___15;

struct vm_struct___57;

struct task_struct___80 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___80 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___79 *mm;
	struct mm_struct___79 *active_mm;
	struct vmacache___79 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___80 *real_parent;
	struct task_struct___80 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___80 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___67 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___67 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___67 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___76 *ptracer_cred;
	const struct cred___76 *real_cred;
	const struct cred___76 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___74 *nsproxy;
	struct signal_struct___70 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___80 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___31 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___31 *backing_dev_info;
	struct io_context___14 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___63 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___51 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___79 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___15 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___80 *oom_reaper_list;
	struct vm_struct___57 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___51 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___51 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___80 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___51)(struct perf_event___51 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___51;

struct fasync_struct___79;

struct pid_namespace___67;

struct trace_event_call___46;

struct perf_cgroup___51;

struct perf_event___51 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___51 *group_leader;
	struct pmu___51 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___51 hw;
	struct perf_event_context___51 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___51 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___80 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___79 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___51 *);
	struct callback_head callback_head;
	struct pid_namespace___67 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___51 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___51 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___46 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___51 *cgrp;
	struct list_head sb_list;
};

typedef struct page___80 *pgtable_t___79;

struct address_space___79;

struct dev_pagemap___79;

struct page___80 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___79 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___80 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___79 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___79 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___79 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___79;

struct lruvec___79 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___79 *pgdat;
};

struct zone___79 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___79 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___79 {
	struct zone___79 *zone;
	int zone_idx;
};

struct zonelist___79 {
	struct zoneref___79 _zonerefs[25];
};

struct pglist_data___79 {
	struct zone___79 node_zones[3];
	struct zonelist___79 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___80 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___80 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___79 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___80 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___80 *owner;
};

struct secondary_data___80 {
	void *stack;
	struct task_struct___80 *task;
	long int status;
};

struct blocking_notifier_head___79 {
	struct rw_semaphore___80 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___79;

struct vm_area_struct___80 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___80 *vm_next;
	struct vm_area_struct___80 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___79 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___79 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___80 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___79;

struct user_namespace___65;

struct mm_struct___79 {
	struct {
		struct vm_area_struct___80 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___80 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___80 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___79 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___80 *owner;
		struct user_namespace___65 *user_ns;
		struct file___80 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___79 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___79;

struct address_space___79 {
	struct inode___81 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___80 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___79 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___79)(struct vm_area_struct___80 *, long unsigned int, const struct page___80 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___79)(struct page___80 *, void *);

struct device___75;

struct dev_pagemap___79 {
	dev_page_fault_t___79 page_fault;
	dev_page_free_t___79 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___75 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct vfsmount___11;

struct dentry___80;

struct path___79 {
	struct vfsmount___11 *mnt;
	struct dentry___80 *dentry;
};

struct fown_struct___67 {
	rwlock_t lock;
	struct pid___67 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___80 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___79 f_path;
	struct inode___81 *f_inode;
	const struct file_operations___80 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___67 f_owner;
	const struct cred___76 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___79 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___79;

struct vm_operations_struct___79 {
	void (*open)(struct vm_area_struct___80 *);
	void (*close)(struct vm_area_struct___80 *);
	int (*split)(struct vm_area_struct___80 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___80 *);
	vm_fault_t (*fault)(struct vm_fault___79 *);
	vm_fault_t (*huge_fault)(struct vm_fault___79 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___79 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___80 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___79 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___79 *);
	int (*access)(struct vm_area_struct___80 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___80 *);
	int (*set_policy)(struct vm_area_struct___80 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___80 *, long unsigned int);
	struct page___80 * (*find_special_page)(struct vm_area_struct___80 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___79 {
	struct task_struct___80 *task;
	struct core_thread___79 *next;
};

struct core_state___79 {
	atomic_t nr_threads;
	struct core_thread___79 dumper;
	struct completion startup;
};

struct key___77;

struct ucounts___65;

struct user_namespace___65 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___65 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common ns;
	long unsigned int flags;
	struct key___77 *persistent_keyring_register;
	struct rw_semaphore___80 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___65 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___79 {
	struct vm_area_struct___80 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___80 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___80 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___79 prealloc_pte;
};

struct upid___67 {
	int nr;
	struct pid_namespace___67 *ns;
};

struct pid_namespace___67 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___80 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___67 *parent;
	struct vfsmount___11 *proc_mnt;
	struct dentry___80 *proc_self;
	struct dentry___80 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___65 *user_ns;
	struct ucounts___65 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common ns;
};

struct pid___67 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___67 numbers[1];
};

struct user_struct___76 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___77 *uid_keyring;
	struct key___77 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___76 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___77 *session_keyring;
	struct key___77 *process_keyring;
	struct key___77 *thread_keyring;
	struct key___77 *request_key_auth;
	void *security;
	struct user_struct___76 *user;
	struct user_namespace___65 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___63;

struct nsproxy___74 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___67 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___63 *cgroup_ns;
};

struct tty_struct___9;

struct signal_struct___70 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___80 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___80 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___67 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___67 *tty_old_pgrp;
	int leader;
	struct tty_struct___9 *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___79 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___67 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___31;

struct bio_list___31 {
	struct bio___31 *head;
	struct bio___31 *tail;
};

struct bdi_writeback_congested___31;

struct cgroup_subsys_state___63;

struct bdi_writeback___31 {
	struct backing_dev_info___31 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___31 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___63 *memcg_css;
	struct cgroup_subsys_state___63 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___31 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___31 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___75 *dev;
	struct device___75 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___80 *debug_dir;
	struct dentry___80 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___14;

struct io_context___14 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___14 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___63;

struct css_set___63 {
	struct cgroup_subsys_state___63 *subsys[13];
	refcount_t refcount;
	struct css_set___63 *dom_cset;
	struct cgroup___63 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___63 *mg_src_cgrp;
	struct cgroup___63 *mg_dst_cgrp;
	struct css_set___63 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___51 {
	struct pmu___51 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___80 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___51 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

typedef blk_qc_t make_request_fn___14(struct request_queue___15 *, struct bio___31 *);

struct request___15;

typedef int dma_drain_needed_fn___14(struct request___15 *);

struct kset___76;

struct kobj_type___76;

struct kernfs_node___77;

struct kobject___77 {
	const char *name;
	struct list_head entry;
	struct kobject___77 *parent;
	struct kset___76 *kset;
	struct kobj_type___76 *ktype;
	struct kernfs_node___77 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___14;

struct bsg_class_device___14 {
	struct device___75 *class_dev;
	int minor;
	struct request_queue___15 *queue;
	const struct bsg_ops___14 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___31 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___31 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___14;

struct request_queue___15 {
	struct list_head queue_head;
	struct request___15 *last_merge;
	struct elevator_queue___14 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___14 *make_request_fn;
	dma_drain_needed_fn___14 *dma_drain_needed;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___31 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___77 kobj;
	struct kobject___77 *mq_kobj;
	struct blk_integrity integrity;
	struct device___75 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide36;
		union {		};
	};
	struct bsg_class_device___14 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___31 bio_split;
	struct dentry___80 *debugfs_dir;
	struct dentry___80 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___57 {
	struct vm_struct___57 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___80 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___70 {
	struct task_struct___80 task;
	long unsigned int stack[8192];
};

struct dev_pm_info___75 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___75 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___75;

struct bus_type___75;

struct device_driver___75;

struct dev_pm_domain___75;

struct fwnode_handle___54;

struct class___75;

struct attribute_group___74;

struct device___75 {
	struct device___75 *parent;
	struct device_private *p;
	struct kobject___77 kobj;
	const char *init_name;
	const struct device_type___75 *type;
	struct mutex mutex;
	struct bus_type___75 *bus;
	struct device_driver___75 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___75 power;
	struct dev_pm_domain___75 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___54 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___75 *class;
	const struct attribute_group___74 **groups;
	void (*release)(struct device___75 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___79;

struct super_block___80;

struct dentry___80 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___80 *d_parent;
	struct qstr d_name;
	struct inode___81 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___79 *d_op;
	struct super_block___80 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___79;

struct block_device___80;

struct cdev___23;

struct inode___81 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___79 *i_op;
	struct super_block___80 *i_sb;
	struct address_space___79 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___80 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___31 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___80 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___79 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___80 *i_bdev;
		struct cdev___23 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___79 {
	int (*d_revalidate)(struct dentry___80 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___80 *, unsigned int);
	int (*d_hash)(const struct dentry___80 *, struct qstr *);
	int (*d_compare)(const struct dentry___80 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___80 *);
	int (*d_init)(struct dentry___80 *);
	void (*d_release)(struct dentry___80 *);
	void (*d_prune)(struct dentry___80 *);
	void (*d_iput)(struct dentry___80 *, struct inode___81 *);
	char * (*d_dname)(struct dentry___80 *, char *, int);
	struct vfsmount___11 * (*d_automount)(struct path___79 *);
	int (*d_manage)(const struct path___79 *, bool);
	struct dentry___80 * (*d_real)(struct dentry___80 *, const struct inode___81 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___79;

struct mem_dqinfo___79 {
	struct quota_format_type___79 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___79;

struct quota_info___79 {
	unsigned int flags;
	struct rw_semaphore___80 dqio_sem;
	struct inode___81 *files[3];
	struct mem_dqinfo___79 info[3];
	const struct quota_format_ops___79 *ops[3];
};

struct rcuwait___79 {
	struct task_struct___80 *task;
};

struct percpu_rw_semaphore___79 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___80 rw_sem;
	struct rcuwait___79 writer;
	int readers_block;
};

struct sb_writers___79 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___79 rw_sem[3];
};

struct file_system_type___79;

struct super_operations___79;

struct dquot_operations___79;

struct quotactl_ops___79;

struct super_block___80 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___79 *s_type;
	const struct super_operations___79 *s_op;
	const struct dquot_operations___79 *dq_op;
	const struct quotactl_ops___79 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___80 *s_root;
	struct rw_semaphore___80 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___80 *s_bdev;
	struct backing_dev_info___31 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___79 s_dquot;
	struct sb_writers___79 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___79 *s_d_op;
	int cleancache_poolid;
	struct shrinker___29 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___65 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___11 {
	struct dentry___80 *mnt_root;
	struct super_block___80 *mnt_sb;
	int mnt_flags;
};

struct io_cq___14 {
	struct request_queue___15 *q;
	struct io_context___14 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___80 {
	struct file___80 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___80 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___80 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___80 *ia_file;
};

struct dquot___79 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___80 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___79 {
	int qf_fmt_id;
	const struct quota_format_ops___79 *qf_ops;
	struct module___72 *qf_owner;
	struct quota_format_type___79 *qf_next;
};

struct quota_format_ops___79 {
	int (*check_quota_file)(struct super_block___80 *, int);
	int (*read_file_info)(struct super_block___80 *, int);
	int (*write_file_info)(struct super_block___80 *, int);
	int (*free_file_info)(struct super_block___80 *, int);
	int (*read_dqblk)(struct dquot___79 *);
	int (*commit_dqblk)(struct dquot___79 *);
	int (*release_dqblk)(struct dquot___79 *);
	int (*get_next_id)(struct super_block___80 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___79 {
	int (*write_dquot)(struct dquot___79 *);
	struct dquot___79 * (*alloc_dquot)(struct super_block___80 *, int);
	void (*destroy_dquot)(struct dquot___79 *);
	int (*acquire_dquot)(struct dquot___79 *);
	int (*release_dquot)(struct dquot___79 *);
	int (*mark_dirty)(struct dquot___79 *);
	int (*write_info)(struct super_block___80 *, int);
	qsize_t * (*get_reserved_space)(struct inode___81 *);
	int (*get_projid)(struct inode___81 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___81 *, qsize_t *);
	int (*get_next_id)(struct super_block___80 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___79 {
	int (*quota_on)(struct super_block___80 *, int, int, const struct path___79 *);
	int (*quota_off)(struct super_block___80 *, int);
	int (*quota_enable)(struct super_block___80 *, unsigned int);
	int (*quota_disable)(struct super_block___80 *, unsigned int);
	int (*quota_sync)(struct super_block___80 *, int);
	int (*set_info)(struct super_block___80 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___80 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___80 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___80 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___80 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___80 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___69 {
	struct kobject___77 kobj;
	struct module___72 *mod;
	struct kobject___77 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___69 {
	struct module___72 *mod;
	struct latch_tree_node node;
};

struct module_layout___69 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___69 mtn;
};

struct module_attribute___69;

struct kernel_param___69;

struct module___72 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___69 mkobj;
	struct module_attribute___69 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___77 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___69 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___69 core_layout;
	struct module_layout___69 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___46 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___79 {
	int (*writepage)(struct page___80 *, struct writeback_control___3 *);
	int (*readpage)(struct file___80 *, struct page___80 *);
	int (*writepages)(struct address_space___79 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___80 *);
	int (*readpages)(struct file___80 *, struct address_space___79 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___80 *, struct address_space___79 *, loff_t, unsigned int, unsigned int, struct page___80 **, void **);
	int (*write_end)(struct file___80 *, struct address_space___79 *, loff_t, unsigned int, unsigned int, struct page___80 *, void *);
	sector_t (*bmap)(struct address_space___79 *, sector_t);
	void (*invalidatepage)(struct page___80 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___80 *, gfp_t);
	void (*freepage)(struct page___80 *);
	ssize_t (*direct_IO)(struct kiocb___80 *, struct iov_iter___31 *);
	int (*migratepage)(struct address_space___79 *, struct page___80 *, struct page___80 *, enum migrate_mode);
	bool (*isolate_page)(struct page___80 *, isolate_mode_t);
	void (*putback_page)(struct page___80 *);
	int (*launder_page)(struct page___80 *);
	int (*is_partially_uptodate)(struct page___80 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___80 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___79 *, struct page___80 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___80 *, sector_t *);
	void (*swap_deactivate)(struct file___80 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio_vec___31;

struct iov_iter___31 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___31 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct hd_struct___15;

struct gendisk___15;

struct block_device___80 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___81 *bd_inode;
	struct super_block___80 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___80 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___15 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___15 *bd_disk;
	struct request_queue___15 *bd_queue;
	struct backing_dev_info___31 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct hd_struct___15 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___75 __dev;
	struct kobject___77 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___15;

struct block_device_operations___15;

struct gendisk___15 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___15 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___15 *part_tbl;
	struct hd_struct___15 part0;
	const struct block_device_operations___15 *fops;
	struct request_queue___15 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___80 lookup_sem;
	struct kobject___77 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___77 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___23 {
	struct kobject___77 kobj;
	struct module___72 *owner;
	const struct file_operations___80 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___79 {
	struct dentry___80 * (*lookup)(struct inode___81 *, struct dentry___80 *, unsigned int);
	const char * (*get_link)(struct dentry___80 *, struct inode___81 *, struct delayed_call *);
	int (*permission)(struct inode___81 *, int);
	struct posix_acl * (*get_acl)(struct inode___81 *, int);
	int (*readlink)(struct dentry___80 *, char *, int);
	int (*create)(struct inode___81 *, struct dentry___80 *, umode_t, bool);
	int (*link)(struct dentry___80 *, struct inode___81 *, struct dentry___80 *);
	int (*unlink)(struct inode___81 *, struct dentry___80 *);
	int (*symlink)(struct inode___81 *, struct dentry___80 *, const char *);
	int (*mkdir)(struct inode___81 *, struct dentry___80 *, umode_t);
	int (*rmdir)(struct inode___81 *, struct dentry___80 *);
	int (*mknod)(struct inode___81 *, struct dentry___80 *, umode_t, dev_t);
	int (*rename)(struct inode___81 *, struct dentry___80 *, struct inode___81 *, struct dentry___80 *, unsigned int);
	int (*setattr)(struct dentry___80 *, struct iattr___80 *);
	int (*getattr)(const struct path___79 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___80 *, char *, size_t);
	int (*fiemap)(struct inode___81 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___81 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___81 *, struct dentry___80 *, struct file___80 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___81 *, struct dentry___80 *, umode_t);
	int (*set_acl)(struct inode___81 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___79 {
	void (*fl_copy_lock)(struct file_lock___80 *, struct file_lock___80 *);
	void (*fl_release_private)(struct file_lock___80 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___79;

struct file_lock___80 {
	struct file_lock___80 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___80 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___79 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___79 *fl_ops;
	const struct lock_manager_operations___79 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___79 {
	int (*lm_compare_owner)(struct file_lock___80 *, struct file_lock___80 *);
	long unsigned int (*lm_owner_key)(struct file_lock___80 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___80 *);
	int (*lm_grant)(struct file_lock___80 *, int);
	bool (*lm_break)(struct file_lock___80 *);
	int (*lm_change)(struct file_lock___80 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___80 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___79 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___79 *fa_next;
	struct file___80 *fa_file;
	struct callback_head fa_rcu;
};

enum {
	SB_UNFROZEN = 0,
	SB_FREEZE_WRITE = 1,
	SB_FREEZE_PAGEFAULT = 2,
	SB_FREEZE_FS = 3,
	SB_FREEZE_COMPLETE = 4,
};

struct file_system_type___79 {
	const char *name;
	int fs_flags;
	struct dentry___80 * (*mount)(struct file_system_type___79 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___80 *);
	struct module___72 *owner;
	struct file_system_type___79 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___79 {
	struct inode___81 * (*alloc_inode)(struct super_block___80 *);
	void (*destroy_inode)(struct inode___81 *);
	void (*dirty_inode)(struct inode___81 *, int);
	int (*write_inode)(struct inode___81 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___81 *);
	void (*evict_inode)(struct inode___81 *);
	void (*put_super)(struct super_block___80 *);
	int (*sync_fs)(struct super_block___80 *, int);
	int (*freeze_super)(struct super_block___80 *);
	int (*freeze_fs)(struct super_block___80 *);
	int (*thaw_super)(struct super_block___80 *);
	int (*unfreeze_fs)(struct super_block___80 *);
	int (*statfs)(struct dentry___80 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___80 *, int *, char *);
	void (*umount_begin)(struct super_block___80 *);
	int (*show_options)(struct seq_file___74 *, struct dentry___80 *);
	int (*show_devname)(struct seq_file___74 *, struct dentry___80 *);
	int (*show_path)(struct seq_file___74 *, struct dentry___80 *);
	int (*show_stats)(struct seq_file___74 *, struct dentry___80 *);
	ssize_t (*quota_read)(struct super_block___80 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___80 *, int, const char *, size_t, loff_t);
	struct dquot___79 ** (*get_dquots)(struct inode___81 *);
	int (*bdev_try_to_free_page)(struct super_block___80 *, struct page___80 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___80 *, struct shrink_control___29 *);
	long int (*free_cached_objects)(struct super_block___80 *, struct shrink_control___29 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___53)(struct file___80 *, wait_queue_head_t *, struct poll_table_struct___54 *);

struct poll_table_struct___54 {
	poll_queue_proc___53 _qproc;
	__poll_t _key;
};

struct seq_operations___71;

struct seq_file___74 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___71 *op;
	int poll_event;
	const struct file___80 *file;
	void *private;
};

struct kstatfs {
	long int f_type;
	long int f_bsize;
	u64 f_blocks;
	u64 f_bfree;
	u64 f_bavail;
	u64 f_files;
	u64 f_ffree;
	__kernel_fsid_t f_fsid;
	long int f_namelen;
	long int f_frsize;
	long int f_flags;
	long int f_spare[4];
};

typedef void bio_end_io_t___31(struct bio___31 *);

struct bio_vec___31 {
	struct page___80 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___31;

struct bio___31 {
	struct bio___31 *bi_next;
	struct gendisk___15 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___31 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___31 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___31 *bi_io_vec;
	struct bio_set___31 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___31 bi_inline_vecs[0];
};

struct kobj_attribute___77 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___77 *, struct kobj_attribute___77 *, char *);
	ssize_t (*store)(struct kobject___77 *, struct kobj_attribute___77 *, const char *, size_t);
};

typedef void compound_page_dtor___79(struct page___80 *);

typedef __u16 comp_t;

struct acct_v3 {
	char ac_flag;
	char ac_version;
	__u16 ac_tty;
	__u32 ac_exitcode;
	__u32 ac_uid;
	__u32 ac_gid;
	__u32 ac_pid;
	__u32 ac_ppid;
	__u32 ac_btime;
	__u32 ac_etime;
	comp_t ac_utime;
	comp_t ac_stime;
	comp_t ac_mem;
	comp_t ac_io;
	comp_t ac_rw;
	comp_t ac_minflt;
	comp_t ac_majflt;
	comp_t ac_swaps;
	char ac_comm[16];
};

typedef struct acct_v3 acct_t;

struct kernfs_root___77;

struct kernfs_elem_dir___77 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___77 *root;
};

struct kernfs_syscall_ops___77;

struct kernfs_root___77 {
	struct kernfs_node___77 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___77 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___77 {
	struct kernfs_node___77 *target_kn;
};

struct kernfs_ops___77;

struct kernfs_elem_attr___77 {
	const struct kernfs_ops___77 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___77 *notify_next;
};

struct kernfs_node___77 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___77 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___77 dir;
		struct kernfs_elem_symlink___77 symlink;
		struct kernfs_elem_attr___77 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___77;

struct kernfs_ops___77 {
	int (*open)(struct kernfs_open_file___77 *);
	void (*release)(struct kernfs_open_file___77 *);
	int (*seq_show)(struct seq_file___74 *, void *);
	void * (*seq_start)(struct seq_file___74 *, loff_t *);
	void * (*seq_next)(struct seq_file___74 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___74 *, void *);
	ssize_t (*read)(struct kernfs_open_file___77 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___77 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___77 *, struct vm_area_struct___80 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___77 *, struct poll_table_struct___54 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___77 {
	int (*remount_fs)(struct kernfs_root___77 *, int *, char *);
	int (*show_options)(struct seq_file___74 *, struct kernfs_root___77 *);
	int (*mkdir)(struct kernfs_node___77 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___77 *);
	int (*rename)(struct kernfs_node___77 *, struct kernfs_node___77 *, const char *);
	int (*show_path)(struct seq_file___74 *, struct kernfs_node___77 *, struct kernfs_root___77 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___77 {
	struct kernfs_node___77 *kn;
	struct file___80 *file;
	struct seq_file___74 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___79 *vm_ops;
};

struct bin_attribute___74;

struct attribute_group___74 {
	const char *name;
	umode_t (*is_visible)(struct kobject___77 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___77 *, struct bin_attribute___74 *, int);
	struct attribute **attrs;
	struct bin_attribute___74 **bin_attrs;
};

struct bin_attribute___74 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___80 *, struct kobject___77 *, struct bin_attribute___74 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___80 *, struct kobject___77 *, struct bin_attribute___74 *, char *, loff_t, size_t);
	int (*mmap)(struct file___80 *, struct kobject___77 *, struct bin_attribute___74 *, struct vm_area_struct___80 *);
};

struct sysfs_ops___76 {
	ssize_t (*show)(struct kobject___77 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___77 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___76;

struct kset___76 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___77 kobj;
	const struct kset_uevent_ops___76 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___76 {
	void (*release)(struct kobject___77 *);
	const struct sysfs_ops___76 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___77 *);
	const void * (*namespace)(struct kobject___77 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___76 {
	int (* const filter)(struct kset___76 *, struct kobject___77 *);
	const char * (* const name)(struct kset___76 *, struct kobject___77 *);
	int (* const uevent)(struct kset___76 *, struct kobject___77 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___75 {
	int (*prepare)(struct device___75 *);
	void (*complete)(struct device___75 *);
	int (*suspend)(struct device___75 *);
	int (*resume)(struct device___75 *);
	int (*freeze)(struct device___75 *);
	int (*thaw)(struct device___75 *);
	int (*poweroff)(struct device___75 *);
	int (*restore)(struct device___75 *);
	int (*suspend_late)(struct device___75 *);
	int (*resume_early)(struct device___75 *);
	int (*freeze_late)(struct device___75 *);
	int (*thaw_early)(struct device___75 *);
	int (*poweroff_late)(struct device___75 *);
	int (*restore_early)(struct device___75 *);
	int (*suspend_noirq)(struct device___75 *);
	int (*resume_noirq)(struct device___75 *);
	int (*freeze_noirq)(struct device___75 *);
	int (*thaw_noirq)(struct device___75 *);
	int (*poweroff_noirq)(struct device___75 *);
	int (*restore_noirq)(struct device___75 *);
	int (*runtime_suspend)(struct device___75 *);
	int (*runtime_resume)(struct device___75 *);
	int (*runtime_idle)(struct device___75 *);
};

struct dev_pm_domain___75 {
	struct dev_pm_ops___75 ops;
	void (*detach)(struct device___75 *, bool);
	int (*activate)(struct device___75 *);
	void (*sync)(struct device___75 *);
	void (*dismiss)(struct device___75 *);
};

struct bus_type___75 {
	const char *name;
	const char *dev_name;
	struct device___75 *dev_root;
	const struct attribute_group___74 **bus_groups;
	const struct attribute_group___74 **dev_groups;
	const struct attribute_group___74 **drv_groups;
	int (*match)(struct device___75 *, struct device_driver___75 *);
	int (*uevent)(struct device___75 *, struct kobj_uevent_env *);
	int (*probe)(struct device___75 *);
	int (*remove)(struct device___75 *);
	void (*shutdown)(struct device___75 *);
	int (*online)(struct device___75 *);
	int (*offline)(struct device___75 *);
	int (*suspend)(struct device___75 *, pm_message_t);
	int (*resume)(struct device___75 *);
	int (*num_vf)(struct device___75 *);
	int (*dma_configure)(struct device___75 *);
	const struct dev_pm_ops___75 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___75 {
	const char *name;
	struct bus_type___75 *bus;
	struct module___72 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___75 *);
	int (*remove)(struct device___75 *);
	void (*shutdown)(struct device___75 *);
	int (*suspend)(struct device___75 *, pm_message_t);
	int (*resume)(struct device___75 *);
	const struct attribute_group___74 **groups;
	const struct dev_pm_ops___75 *pm;
	void (*coredump)(struct device___75 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___75 {
	const char *name;
	const struct attribute_group___74 **groups;
	int (*uevent)(struct device___75 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___75 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___75 *);
	const struct dev_pm_ops___75 *pm;
};

struct class___75 {
	const char *name;
	struct module___72 *owner;
	const struct attribute_group___74 **class_groups;
	const struct attribute_group___74 **dev_groups;
	struct kobject___77 *dev_kobj;
	int (*dev_uevent)(struct device___75 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___75 *, umode_t *);
	void (*class_release)(struct class___75 *);
	void (*dev_release)(struct device___75 *);
	int (*shutdown_pre)(struct device___75 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___75 *);
	const struct dev_pm_ops___75 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct fwnode_operations___54;

struct fwnode_handle___54 {
	struct fwnode_handle___54 *secondary;
	const struct fwnode_operations___54 *ops;
};

typedef int (*key_restrict_link_func_t___76)(struct key___77 *, const struct key_type *, const union key_payload *, struct key___77 *);

struct key_restriction___77;

struct key___77 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___80 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___77 *restrict_link;
};

struct key_restriction___77 {
	key_restrict_link_func_t___76 check;
	struct key___77 *key;
	struct key_type *keytype;
};

struct seq_operations___71 {
	void * (*start)(struct seq_file___74 *, loff_t *);
	void (*stop)(struct seq_file___74 *, void *);
	void * (*next)(struct seq_file___74 *, void *, loff_t *);
	int (*show)(struct seq_file___74 *, void *);
};

struct tty_driver___9;

struct tty_operations___9 {
	struct tty_struct___9 * (*lookup)(struct tty_driver___9 *, struct file___80 *, int);
	int (*install)(struct tty_driver___9 *, struct tty_struct___9 *);
	void (*remove)(struct tty_driver___9 *, struct tty_struct___9 *);
	int (*open)(struct tty_struct___9 *, struct file___80 *);
	void (*close)(struct tty_struct___9 *, struct file___80 *);
	void (*shutdown)(struct tty_struct___9 *);
	void (*cleanup)(struct tty_struct___9 *);
	int (*write)(struct tty_struct___9 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___9 *, unsigned char);
	void (*flush_chars)(struct tty_struct___9 *);
	int (*write_room)(struct tty_struct___9 *);
	int (*chars_in_buffer)(struct tty_struct___9 *);
	int (*ioctl)(struct tty_struct___9 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___9 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___9 *, struct ktermios *);
	void (*throttle)(struct tty_struct___9 *);
	void (*unthrottle)(struct tty_struct___9 *);
	void (*stop)(struct tty_struct___9 *);
	void (*start)(struct tty_struct___9 *);
	void (*hangup)(struct tty_struct___9 *);
	int (*break_ctl)(struct tty_struct___9 *, int);
	void (*flush_buffer)(struct tty_struct___9 *);
	void (*set_ldisc)(struct tty_struct___9 *);
	void (*wait_until_sent)(struct tty_struct___9 *, int);
	void (*send_xchar)(struct tty_struct___9 *, char);
	int (*tiocmget)(struct tty_struct___9 *);
	int (*tiocmset)(struct tty_struct___9 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___9 *, struct winsize *);
	int (*set_termiox)(struct tty_struct___9 *, struct termiox *);
	int (*get_icount)(struct tty_struct___9 *, struct serial_icounter_struct *);
	void (*show_fdinfo)(struct tty_struct___9 *, struct seq_file___74 *);
	int (*poll_init)(struct tty_driver___9 *, int, char *);
	int (*poll_get_char)(struct tty_driver___9 *, int);
	void (*poll_put_char)(struct tty_driver___9 *, int, char);
	int (*proc_show)(struct seq_file___74 *, void *);
};

struct tty_ldisc___9;

struct tty_port___9;

struct tty_struct___9 {
	int magic;
	struct kref kref;
	struct device___75 *dev;
	struct tty_driver___9 *driver;
	const struct tty_operations___9 *ops;
	int index;
	struct ld_semaphore ldisc_sem;
	struct tty_ldisc___9 *ldisc;
	struct mutex atomic_write_lock;
	struct mutex legacy_mutex;
	struct mutex throttle_mutex;
	struct rw_semaphore___80 termios_rwsem;
	struct mutex winsize_mutex;
	spinlock_t ctrl_lock;
	spinlock_t flow_lock;
	struct ktermios termios;
	struct ktermios termios_locked;
	struct termiox *termiox;
	char name[64];
	struct pid___67 *pgrp;
	struct pid___67 *session;
	long unsigned int flags;
	int count;
	struct winsize winsize;
	long unsigned int stopped: 1;
	long unsigned int flow_stopped: 1;
	int: 30;
	long unsigned int unused: 62;
	int hw_stopped;
	long unsigned int ctrl_status: 8;
	long unsigned int packet: 1;
	int: 23;
	long unsigned int unused_ctrl: 55;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___9 *link;
	struct fasync_struct___79 *fasync;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	spinlock_t files_lock;
	struct list_head tty_files;
	int closing;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___9 *port;
};

struct tty_driver___9 {
	int magic;
	struct kref kref;
	struct cdev___23 **cdevs;
	struct module___72 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___9 *other;
	struct tty_struct___9 **ttys;
	struct tty_port___9 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___9 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___9;

struct tty_port_client_operations___9;

struct tty_port___9 {
	struct tty_bufhead buf;
	struct tty_struct___9 *tty;
	struct tty_struct___9 *itty;
	const struct tty_port_operations___9 *ops;
	const struct tty_port_client_operations___9 *client_ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	unsigned char low_latency: 1;
	struct mutex mutex;
	struct mutex buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
	void *client_data;
};

struct tty_ldisc_ops___9 {
	int magic;
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___9 *);
	void (*close)(struct tty_struct___9 *);
	void (*flush_buffer)(struct tty_struct___9 *);
	ssize_t (*read)(struct tty_struct___9 *, struct file___80 *, unsigned char *, size_t);
	ssize_t (*write)(struct tty_struct___9 *, struct file___80 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___9 *, struct file___80 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___9 *, struct file___80 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___9 *, struct ktermios *);
	__poll_t (*poll)(struct tty_struct___9 *, struct file___80 *, struct poll_table_struct___54 *);
	int (*hangup)(struct tty_struct___9 *);
	void (*receive_buf)(struct tty_struct___9 *, const unsigned char *, char *, int);
	void (*write_wakeup)(struct tty_struct___9 *);
	void (*dcd_change)(struct tty_struct___9 *, unsigned int);
	int (*receive_buf2)(struct tty_struct___9 *, const unsigned char *, char *, int);
	struct module___72 *owner;
	int refcount;
};

struct tty_ldisc___9 {
	struct tty_ldisc_ops___9 *ops;
	struct tty_struct___9 *tty;
};

struct tty_port_operations___9 {
	int (*carrier_raised)(struct tty_port___9 *);
	void (*dtr_rts)(struct tty_port___9 *, int);
	void (*shutdown)(struct tty_port___9 *);
	int (*activate)(struct tty_port___9 *, struct tty_struct___9 *);
	void (*destruct)(struct tty_port___9 *);
};

struct tty_port_client_operations___9 {
	int (*receive_buf)(struct tty_port___9 *, const unsigned char *, const unsigned char *, size_t);
	void (*write_wakeup)(struct tty_port___9 *);
};

struct cgroup_namespace___63 {
	refcount_t count;
	struct ns_common ns;
	struct user_namespace___65 *user_ns;
	struct ucounts___65 *ucounts;
	struct css_set___63 *root_cset;
};

struct fs_pin {
	wait_queue_head_t wait;
	int done;
	struct hlist_node s_list;
	struct hlist_node m_list;
	void (*kill)(struct fs_pin *);
};

struct ucounts___65 {
	struct hlist_node node;
	struct user_namespace___65 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct kernel_param_ops___69 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___69 *);
	int (*get)(char *, const struct kernel_param___69 *);
	void (*free)(void *);
};

struct kparam_array___69;

struct kernel_param___69 {
	const char *name;
	struct module___72 *mod;
	const struct kernel_param_ops___69 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___69 *arr;
	};
};

struct kparam_array___69 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___69 *ops;
	void *elem;
};

struct module_attribute___69 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___69 *, struct module_kobject___69 *, char *);
	ssize_t (*store)(struct module_attribute___69 *, struct module_kobject___69 *, const char *, size_t);
	void (*setup)(struct module___72 *, const char *);
	int (*test)(struct module___72 *);
	void (*free)(struct module___72 *);
};

struct trace_event_class___46;

struct trace_event_call___46 {
	struct list_head list;
	struct trace_event_class___46 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___5 *prog_array;
	int (*perf_perm)(struct trace_event_call___46 *, struct perf_event___51 *);
};

struct node___65 {
	struct device___75 dev;
};

struct bpf_map___63;

struct bpf_map_ops___63 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___63 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___63 *, struct file___80 *);
	void (*map_free)(struct bpf_map___63 *);
	int (*map_get_next_key)(struct bpf_map___63 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___63 *);
	void * (*map_lookup_elem)(struct bpf_map___63 *, void *);
	int (*map_update_elem)(struct bpf_map___63 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___63 *, void *);
	int (*map_push_elem)(struct bpf_map___63 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___63 *, void *);
	int (*map_peek_elem)(struct bpf_map___63 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___63 *, struct file___80 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___63 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___63 *, void *, struct seq_file___74 *);
	int (*map_check_btf)(const struct bpf_map___63 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___63 {
	const struct bpf_map_ops___63 *ops;
	struct bpf_map___63 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___76 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___63;

typedef void (*kthread_work_func_t___63)(struct kthread_work___63 *);

struct kthread_worker___63;

struct kthread_work___63 {
	struct list_head node;
	kthread_work_func_t___63 func;
	struct kthread_worker___63 *worker;
	int canceling;
};

struct kthread_worker___63 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___80 *task;
	struct kthread_work___63 *current_work;
};

struct kthread_delayed_work___63 {
	struct kthread_work___63 work;
	struct timer_list timer;
};

struct psi_group___63 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___63 *poll_kworker;
	struct kthread_delayed_work___63 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___63 {
	struct kernfs_node___77 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___63;

struct cgroup_subsys_state___63 {
	struct cgroup___63 *cgroup;
	struct cgroup_subsys___63 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___63 *parent;
};

struct cgroup_root___63;

struct cgroup_rstat_cpu___63;

struct cgroup___63 {
	struct cgroup_subsys_state___63 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___77 *kn;
	struct cgroup_file___63 procs_file;
	struct cgroup_file___63 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___63 *subsys[13];
	struct cgroup_root___63 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___63 *dom_cgrp;
	struct cgroup_rstat_cpu___63 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___5 bpf;
	atomic_t congestion_count;
	struct cgroup___63 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___63 psi;
	int ancestor_ids[0];
};

struct cftype___63;

struct cgroup_subsys___63 {
	struct cgroup_subsys_state___63 * (*css_alloc)(struct cgroup_subsys_state___63 *);
	int (*css_online)(struct cgroup_subsys_state___63 *);
	void (*css_offline)(struct cgroup_subsys_state___63 *);
	void (*css_released)(struct cgroup_subsys_state___63 *);
	void (*css_free)(struct cgroup_subsys_state___63 *);
	void (*css_reset)(struct cgroup_subsys_state___63 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___63 *, int);
	int (*css_extra_stat_show)(struct seq_file___74 *, struct cgroup_subsys_state___63 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___80 *);
	void (*cancel_fork)(struct task_struct___80 *);
	void (*fork)(struct task_struct___80 *);
	void (*exit)(struct task_struct___80 *);
	void (*free)(struct task_struct___80 *);
	void (*bind)(struct cgroup_subsys_state___63 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___63 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___63 *dfl_cftypes;
	struct cftype___63 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___63 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___63 *updated_children;
	struct cgroup___63 *updated_next;
};

struct cgroup_root___63 {
	struct kernfs_root___77 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___63 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___63 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___63 *ss;
	struct list_head node;
	struct kernfs_ops___77 *kf_ops;
	int (*open)(struct kernfs_open_file___77 *);
	void (*release)(struct kernfs_open_file___77 *);
	u64 (*read_u64)(struct cgroup_subsys_state___63 *, struct cftype___63 *);
	s64 (*read_s64)(struct cgroup_subsys_state___63 *, struct cftype___63 *);
	int (*seq_show)(struct seq_file___74 *, void *);
	void * (*seq_start)(struct seq_file___74 *, loff_t *);
	void * (*seq_next)(struct seq_file___74 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___74 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___63 *, struct cftype___63 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___63 *, struct cftype___63 *, s64);
	ssize_t (*write)(struct kernfs_open_file___77 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___77 *, struct poll_table_struct___54 *);
};

struct perf_cpu_context___51;

struct pmu___51 {
	struct list_head entry;
	struct module___72 *module;
	struct device___75 *dev;
	const struct attribute_group___74 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___51 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___51 *);
	void (*pmu_disable)(struct pmu___51 *);
	int (*event_init)(struct perf_event___51 *);
	void (*event_mapped)(struct perf_event___51 *, struct mm_struct___79 *);
	void (*event_unmapped)(struct perf_event___51 *, struct mm_struct___79 *);
	int (*add)(struct perf_event___51 *, int);
	void (*del)(struct perf_event___51 *, int);
	void (*start)(struct perf_event___51 *, int);
	void (*stop)(struct perf_event___51 *, int);
	void (*read)(struct perf_event___51 *);
	void (*start_txn)(struct pmu___51 *, unsigned int);
	int (*commit_txn)(struct pmu___51 *);
	void (*cancel_txn)(struct pmu___51 *);
	int (*event_idx)(struct perf_event___51 *);
	void (*sched_task)(struct perf_event_context___51 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___51 *);
	int (*filter_match)(struct perf_event___51 *);
	int (*check_period)(struct perf_event___51 *, u64);
};

struct perf_cpu_context___51 {
	struct perf_event_context___51 ctx;
	struct perf_event_context___51 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___51 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___51 {
	struct cgroup_subsys_state___63 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___46 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___46 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___46 *);
	struct list_head * (*get_fields)(struct trace_event_call___46 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___46 *);
};

struct syscall_metadata___21 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___46 *enter_event;
	struct trace_event_call___46 *exit_event;
};

struct bio_integrity_payload___31 {
	struct bio___31 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___31 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___31 bip_inline_vecs[0];
};

struct disk_part_tbl___15 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___15 *last_lookup;
	struct hd_struct___15 *part[0];
};

struct block_device_operations___15 {
	int (*open)(struct block_device___80 *, fmode_t);
	void (*release)(struct gendisk___15 *, fmode_t);
	int (*rw_page)(struct block_device___80 *, sector_t, struct page___80 *, unsigned int);
	int (*ioctl)(struct block_device___80 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___80 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___15 *, unsigned int);
	int (*media_changed)(struct gendisk___15 *);
	void (*unlock_native_capacity)(struct gendisk___15 *);
	int (*revalidate_disk)(struct gendisk___15 *);
	int (*getgeo)(struct block_device___80 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___80 *, long unsigned int);
	int (*report_zones)(struct gendisk___15 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___72 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bdi_writeback_congested___31 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___31 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bsg_ops___14 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___15 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___15 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___15 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___14(struct request___15 *, blk_status_t);

struct request___15 {
	struct request_queue___15 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___31 *bio;
	struct bio___31 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___31 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___14 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___14 *saved_end_io;
		} flush;
	};
	struct gendisk___15 *rq_disk;
	struct hd_struct___15 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___14 *end_io;
	void *end_io_data;
	struct request___15 *next_rq;
};

struct fwnode_reference_args___54;

struct fwnode_endpoint___54;

struct fwnode_operations___54 {
	struct fwnode_handle___54 * (*get)(struct fwnode_handle___54 *);
	void (*put)(struct fwnode_handle___54 *);
	bool (*device_is_available)(const struct fwnode_handle___54 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___54 *, const struct device___75 *);
	bool (*property_present)(const struct fwnode_handle___54 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___54 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___54 *, const char *, const char **, size_t);
	struct fwnode_handle___54 * (*get_parent)(const struct fwnode_handle___54 *);
	struct fwnode_handle___54 * (*get_next_child_node)(const struct fwnode_handle___54 *, struct fwnode_handle___54 *);
	struct fwnode_handle___54 * (*get_named_child_node)(const struct fwnode_handle___54 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___54 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___54 *);
	struct fwnode_handle___54 * (*graph_get_next_endpoint)(const struct fwnode_handle___54 *, struct fwnode_handle___54 *);
	struct fwnode_handle___54 * (*graph_get_remote_endpoint)(const struct fwnode_handle___54 *);
	struct fwnode_handle___54 * (*graph_get_port_parent)(struct fwnode_handle___54 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___54 *, struct fwnode_endpoint___54 *);
};

struct fwnode_endpoint___54 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___54 *local_fwnode;
};

struct fwnode_reference_args___54 {
	struct fwnode_handle___54 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct elevator_type___14;

struct elevator_mq_ops___14 {
	int (*init_sched)(struct request_queue___15 *, struct elevator_type___14 *);
	void (*exit_sched)(struct elevator_queue___14 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	bool (*allow_merge)(struct request_queue___15 *, struct request___15 *, struct bio___31 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx *, struct bio___31 *);
	int (*request_merge)(struct request_queue___15 *, struct request___15 **, struct bio___31 *);
	void (*request_merged)(struct request_queue___15 *, struct request___15 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___15 *, struct request___15 *, struct request___15 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___15 *, struct bio___31 *);
	void (*finish_request)(struct request___15 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___15 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___15 *, u64);
	void (*started_request)(struct request___15 *);
	void (*requeue_request)(struct request___15 *);
	struct request___15 * (*former_request)(struct request_queue___15 *, struct request___15 *);
	struct request___15 * (*next_request)(struct request_queue___15 *, struct request___15 *);
	void (*init_icq)(struct io_cq___14 *);
	void (*exit_icq)(struct io_cq___14 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide35;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___14;

struct elevator_type___14 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___14 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___14 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___72 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___14 {
	struct elevator_type___14 *type;
	void *elevator_data;
	struct kobject___77 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___14 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___14 *, char *);
	ssize_t (*store)(struct elevator_queue___14 *, const char *, size_t);
};

struct bsd_acct_struct {
	struct fs_pin pin;
	atomic_long_t count;
	struct callback_head rcu;
	struct mutex lock;
	int active;
	long unsigned int needcheck;
	struct file___80 *file;
	struct pid_namespace___67 *ns;
	struct work_struct work;
	struct completion done;
};

enum compound_dtor_id {
	NULL_COMPOUND_DTOR = 0,
	COMPOUND_PAGE_DTOR = 1,
	HUGETLB_PAGE_DTOR = 2,
	TRANSHUGE_PAGE_DTOR = 3,
	NR_COMPOUND_DTORS = 4,
};

struct elf64_note {
	Elf64_Word n_namesz;
	Elf64_Word n_descsz;
	Elf64_Word n_type;
};

struct module___73;

struct file___81;

struct kiocb___81;

struct iov_iter___32;

struct poll_table_struct___55;

struct vm_area_struct___81;

struct inode___82;

struct file_lock___81;

struct page___81;

struct seq_file___75;

struct file_operations___81 {
	struct module___73 *owner;
	loff_t (*llseek)(struct file___81 *, loff_t, int);
	ssize_t (*read)(struct file___81 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___81 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___81 *, struct iov_iter___32 *);
	ssize_t (*write_iter)(struct kiocb___81 *, struct iov_iter___32 *);
	int (*iopoll)(struct kiocb___81 *, bool);
	int (*iterate)(struct file___81 *, struct dir_context *);
	int (*iterate_shared)(struct file___81 *, struct dir_context *);
	__poll_t (*poll)(struct file___81 *, struct poll_table_struct___55 *);
	long int (*unlocked_ioctl)(struct file___81 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___81 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___81 *, struct vm_area_struct___81 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___82 *, struct file___81 *);
	int (*flush)(struct file___81 *, fl_owner_t);
	int (*release)(struct inode___82 *, struct file___81 *);
	int (*fsync)(struct file___81 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___81 *, int);
	int (*lock)(struct file___81 *, int, struct file_lock___81 *);
	ssize_t (*sendpage)(struct file___81 *, struct page___81 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___81 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___81 *, int, struct file_lock___81 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___81 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___81 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___81 *, long int, struct file_lock___81 **, void **);
	long int (*fallocate)(struct file___81 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___75 *, struct file___81 *);
	ssize_t (*copy_file_range)(struct file___81 *, loff_t, struct file___81 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___81 *, loff_t, struct file___81 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___81 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___80 {
	u64 seqnum;
	struct vm_area_struct___81 *vmas[4];
};

struct page_frag___80 {
	struct page___81 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___52;

struct debug_info___52 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___52 *hbp_break[16];
	struct perf_event___52 *hbp_watch[16];
};

struct thread_struct___52 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___52 debug;
	long: 64;
};

struct mm_struct___80;

struct mem_cgroup___30;

struct pid___68;

struct cred___77;

struct nsproxy___75;

struct signal_struct___71;

struct bio_list___32;

struct backing_dev_info___32;

struct css_set___64;

struct perf_event_context___52;

struct vm_struct___58;

struct task_struct___81 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___81 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___80 *mm;
	struct mm_struct___80 *active_mm;
	struct vmacache___80 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___81 *real_parent;
	struct task_struct___81 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___81 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___30 *active_memcg;
	long int rh_reserved2;
	struct pid___68 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___68 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___68 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___77 *ptracer_cred;
	const struct cred___77 *real_cred;
	const struct cred___77 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___75 *nsproxy;
	struct signal_struct___71 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___81 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___32 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___32 *backing_dev_info;
	struct io_context___14 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___64 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___52 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___80 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___30 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___81 *oom_reaper_list;
	struct vm_struct___58 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___52 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___52 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___81 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___52)(struct perf_event___52 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___52;

struct fasync_struct___80;

struct pid_namespace___68;

struct trace_event_call___47;

struct perf_cgroup___52;

struct perf_event___52 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___52 *group_leader;
	struct pmu___52 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___52 hw;
	struct perf_event_context___52 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___52 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___81 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___80 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___52 *);
	struct callback_head callback_head;
	struct pid_namespace___68 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___52 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___52 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___47 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___52 *cgrp;
	struct list_head sb_list;
};

typedef struct page___81 *pgtable_t___80;

struct address_space___80;

struct dev_pagemap___80;

struct page___81 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___80 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___81 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___80 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___80 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___80 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___30 *mem_cgroup;
};

struct pglist_data___80;

struct lruvec___80 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___80 *pgdat;
};

struct zone___80 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___80 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___80 {
	struct zone___80 *zone;
	int zone_idx;
};

struct zonelist___80 {
	struct zoneref___80 _zonerefs[25];
};

struct pglist_data___80 {
	struct zone___80 node_zones[3];
	struct zonelist___80 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___81 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___81 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___80 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___81 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___81 *owner;
};

struct secondary_data___81 {
	void *stack;
	struct task_struct___81 *task;
	long int status;
};

struct blocking_notifier_head___80 {
	struct rw_semaphore___81 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___80;

struct vm_area_struct___81 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___81 *vm_next;
	struct vm_area_struct___81 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___80 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___80 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___81 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___80;

struct user_namespace___66;

struct mm_struct___80 {
	struct {
		struct vm_area_struct___81 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___81 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___81 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___80 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___81 *owner;
		struct user_namespace___66 *user_ns;
		struct file___81 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___80 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___80;

struct address_space___80 {
	struct inode___82 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___81 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___80 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___80)(struct vm_area_struct___81 *, long unsigned int, const struct page___81 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___80)(struct page___81 *, void *);

struct device___76;

struct dev_pagemap___80 {
	dev_page_fault_t___80 page_fault;
	dev_page_free_t___80 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___76 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct cgroup___64;

struct cgroup_subsys___64;

struct cgroup_subsys_state___64 {
	struct cgroup___64 *cgroup;
	struct cgroup_subsys___64 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___64 *parent;
};

struct kernfs_node___78;

struct cgroup_file___64 {
	struct kernfs_node___78 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___30;

struct mem_cgroup___30 {
	struct cgroup_subsys_state___64 css;
	struct mem_cgroup_id___11 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___64 events_file;
	struct cgroup_file___64 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___81 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___30 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry___81;

struct path___80 {
	struct vfsmount *mnt;
	struct dentry___81 *dentry;
};

struct fown_struct___68 {
	rwlock_t lock;
	struct pid___68 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___81 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___80 f_path;
	struct inode___82 *f_inode;
	const struct file_operations___81 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___68 f_owner;
	const struct cred___77 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___80 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___80;

struct vm_operations_struct___80 {
	void (*open)(struct vm_area_struct___81 *);
	void (*close)(struct vm_area_struct___81 *);
	int (*split)(struct vm_area_struct___81 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___81 *);
	vm_fault_t (*fault)(struct vm_fault___80 *);
	vm_fault_t (*huge_fault)(struct vm_fault___80 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___80 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___81 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___80 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___80 *);
	int (*access)(struct vm_area_struct___81 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___81 *);
	int (*set_policy)(struct vm_area_struct___81 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___81 *, long unsigned int);
	struct page___81 * (*find_special_page)(struct vm_area_struct___81 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___80 {
	struct task_struct___81 *task;
	struct core_thread___80 *next;
};

struct core_state___80 {
	atomic_t nr_threads;
	struct core_thread___80 dumper;
	struct completion startup;
};

struct key___78;

struct ucounts___66;

struct user_namespace___66 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___66 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common ns;
	long unsigned int flags;
	struct key___78 *persistent_keyring_register;
	struct rw_semaphore___81 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___66 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___80 {
	struct vm_area_struct___81 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___81 *cow_page;
	struct mem_cgroup___30 *memcg;
	struct page___81 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___80 prealloc_pte;
};

struct shrink_control___30 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___30 *memcg;
};

struct shrinker___30 {
	long unsigned int (*count_objects)(struct shrinker___30 *, struct shrink_control___30 *);
	long unsigned int (*scan_objects)(struct shrinker___30 *, struct shrink_control___30 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct upid___68 {
	int nr;
	struct pid_namespace___68 *ns;
};

struct pid_namespace___68 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___81 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___68 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___81 *proc_self;
	struct dentry___81 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___66 *user_ns;
	struct ucounts___66 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common ns;
};

struct pid___68 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___68 numbers[1];
};

struct user_struct___77 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___78 *uid_keyring;
	struct key___78 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___77 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___78 *session_keyring;
	struct key___78 *process_keyring;
	struct key___78 *thread_keyring;
	struct key___78 *request_key_auth;
	void *security;
	struct user_struct___77 *user;
	struct user_namespace___66 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct uts_namespace___18;

struct cgroup_namespace___64;

struct nsproxy___75 {
	atomic_t count;
	struct uts_namespace___18 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___68 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___64 *cgroup_ns;
};

struct signal_struct___71 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___81 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___81 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___68 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___68 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___80 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___68 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___32;

struct bio_list___32 {
	struct bio___32 *head;
	struct bio___32 *tail;
};

struct bdi_writeback_congested___32;

struct bdi_writeback___32 {
	struct backing_dev_info___32 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___32 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___64 *memcg_css;
	struct cgroup_subsys_state___64 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___32 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___32 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___76 *dev;
	struct device___76 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___81 *debug_dir;
	struct dentry___81 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___64 {
	struct cgroup_subsys_state___64 *subsys[13];
	refcount_t refcount;
	struct css_set___64 *dom_cset;
	struct cgroup___64 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___64 *mg_src_cgrp;
	struct cgroup___64 *mg_dst_cgrp;
	struct css_set___64 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___52 {
	struct pmu___52 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___81 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___52 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___58 {
	struct vm_struct___58 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___81 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___71 {
	struct task_struct___81 task;
	long unsigned int stack[8192];
};

struct kset___77;

struct kobj_type___77;

struct kobject___78 {
	const char *name;
	struct list_head entry;
	struct kobject___78 *parent;
	struct kset___77 *kset;
	struct kobj_type___77 *ktype;
	struct kernfs_node___78 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___76 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___76 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___76;

struct bus_type___76;

struct device_driver___76;

struct dev_pm_domain___76;

struct fwnode_handle___55;

struct class___76;

struct attribute_group___75;

struct device___76 {
	struct device___76 *parent;
	struct device_private *p;
	struct kobject___78 kobj;
	const char *init_name;
	const struct device_type___76 *type;
	struct mutex mutex;
	struct bus_type___76 *bus;
	struct device_driver___76 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___76 power;
	struct dev_pm_domain___76 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___55 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___76 *class;
	const struct attribute_group___75 **groups;
	void (*release)(struct device___76 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___80;

struct super_block___81;

struct dentry___81 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___81 *d_parent;
	struct qstr d_name;
	struct inode___82 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___80 *d_op;
	struct super_block___81 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___80;

struct block_device___81;

struct inode___82 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___80 *i_op;
	struct super_block___81 *i_sb;
	struct address_space___80 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___81 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___32 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___81 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___80 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___81 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___80 {
	int (*d_revalidate)(struct dentry___81 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___81 *, unsigned int);
	int (*d_hash)(const struct dentry___81 *, struct qstr *);
	int (*d_compare)(const struct dentry___81 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___81 *);
	int (*d_init)(struct dentry___81 *);
	void (*d_release)(struct dentry___81 *);
	void (*d_prune)(struct dentry___81 *);
	void (*d_iput)(struct dentry___81 *, struct inode___82 *);
	char * (*d_dname)(struct dentry___81 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___80 *);
	int (*d_manage)(const struct path___80 *, bool);
	struct dentry___81 * (*d_real)(struct dentry___81 *, const struct inode___82 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___80;

struct mem_dqinfo___80 {
	struct quota_format_type___80 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___80;

struct quota_info___80 {
	unsigned int flags;
	struct rw_semaphore___81 dqio_sem;
	struct inode___82 *files[3];
	struct mem_dqinfo___80 info[3];
	const struct quota_format_ops___80 *ops[3];
};

struct rcuwait___80 {
	struct task_struct___81 *task;
};

struct percpu_rw_semaphore___80 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___81 rw_sem;
	struct rcuwait___80 writer;
	int readers_block;
};

struct sb_writers___80 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___80 rw_sem[3];
};

struct file_system_type___80;

struct super_operations___80;

struct dquot_operations___80;

struct quotactl_ops___80;

struct super_block___81 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___80 *s_type;
	const struct super_operations___80 *s_op;
	const struct dquot_operations___80 *dq_op;
	const struct quotactl_ops___80 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___81 *s_root;
	struct rw_semaphore___81 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___81 *s_bdev;
	struct backing_dev_info___32 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___80 s_dquot;
	struct sb_writers___80 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___80 *s_d_op;
	int cleancache_poolid;
	struct shrinker___30 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___66 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___81 {
	struct file___81 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___81 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___81 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___81 *ia_file;
};

struct dquot___80 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___81 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___80 {
	int qf_fmt_id;
	const struct quota_format_ops___80 *qf_ops;
	struct module___73 *qf_owner;
	struct quota_format_type___80 *qf_next;
};

struct quota_format_ops___80 {
	int (*check_quota_file)(struct super_block___81 *, int);
	int (*read_file_info)(struct super_block___81 *, int);
	int (*write_file_info)(struct super_block___81 *, int);
	int (*free_file_info)(struct super_block___81 *, int);
	int (*read_dqblk)(struct dquot___80 *);
	int (*commit_dqblk)(struct dquot___80 *);
	int (*release_dqblk)(struct dquot___80 *);
	int (*get_next_id)(struct super_block___81 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___80 {
	int (*write_dquot)(struct dquot___80 *);
	struct dquot___80 * (*alloc_dquot)(struct super_block___81 *, int);
	void (*destroy_dquot)(struct dquot___80 *);
	int (*acquire_dquot)(struct dquot___80 *);
	int (*release_dquot)(struct dquot___80 *);
	int (*mark_dirty)(struct dquot___80 *);
	int (*write_info)(struct super_block___81 *, int);
	qsize_t * (*get_reserved_space)(struct inode___82 *);
	int (*get_projid)(struct inode___82 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___82 *, qsize_t *);
	int (*get_next_id)(struct super_block___81 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___80 {
	int (*quota_on)(struct super_block___81 *, int, int, const struct path___80 *);
	int (*quota_off)(struct super_block___81 *, int);
	int (*quota_enable)(struct super_block___81 *, unsigned int);
	int (*quota_disable)(struct super_block___81 *, unsigned int);
	int (*quota_sync)(struct super_block___81 *, int);
	int (*set_info)(struct super_block___81 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___81 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___81 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___81 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___81 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___81 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___70 {
	struct kobject___78 kobj;
	struct module___73 *mod;
	struct kobject___78 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___70 {
	struct module___73 *mod;
	struct latch_tree_node node;
};

struct module_layout___70 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___70 mtn;
};

struct module_attribute___70;

struct kernel_param___70;

struct module___73 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___70 mkobj;
	struct module_attribute___70 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___78 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___70 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___70 core_layout;
	struct module_layout___70 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___47 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___30;

struct swap_info_struct___25;

struct address_space_operations___80 {
	int (*writepage)(struct page___81 *, struct writeback_control___30 *);
	int (*readpage)(struct file___81 *, struct page___81 *);
	int (*writepages)(struct address_space___80 *, struct writeback_control___30 *);
	int (*set_page_dirty)(struct page___81 *);
	int (*readpages)(struct file___81 *, struct address_space___80 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___81 *, struct address_space___80 *, loff_t, unsigned int, unsigned int, struct page___81 **, void **);
	int (*write_end)(struct file___81 *, struct address_space___80 *, loff_t, unsigned int, unsigned int, struct page___81 *, void *);
	sector_t (*bmap)(struct address_space___80 *, sector_t);
	void (*invalidatepage)(struct page___81 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___81 *, gfp_t);
	void (*freepage)(struct page___81 *);
	ssize_t (*direct_IO)(struct kiocb___81 *, struct iov_iter___32 *);
	int (*migratepage)(struct address_space___80 *, struct page___81 *, struct page___81 *, enum migrate_mode);
	bool (*isolate_page)(struct page___81 *, isolate_mode_t);
	void (*putback_page)(struct page___81 *);
	int (*launder_page)(struct page___81 *);
	int (*is_partially_uptodate)(struct page___81 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___81 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___80 *, struct page___81 *);
	int (*swap_activate)(struct swap_info_struct___25 *, struct file___81 *, sector_t *);
	void (*swap_deactivate)(struct file___81 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___30 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___32 *wb;
	struct inode___82 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___32;

struct iov_iter___32 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___32 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct swap_info_struct___25 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___81 *bdev;
	struct file___81 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___81 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___82 *bd_inode;
	struct super_block___81 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___81 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___32 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___80 {
	struct dentry___81 * (*lookup)(struct inode___82 *, struct dentry___81 *, unsigned int);
	const char * (*get_link)(struct dentry___81 *, struct inode___82 *, struct delayed_call *);
	int (*permission)(struct inode___82 *, int);
	struct posix_acl * (*get_acl)(struct inode___82 *, int);
	int (*readlink)(struct dentry___81 *, char *, int);
	int (*create)(struct inode___82 *, struct dentry___81 *, umode_t, bool);
	int (*link)(struct dentry___81 *, struct inode___82 *, struct dentry___81 *);
	int (*unlink)(struct inode___82 *, struct dentry___81 *);
	int (*symlink)(struct inode___82 *, struct dentry___81 *, const char *);
	int (*mkdir)(struct inode___82 *, struct dentry___81 *, umode_t);
	int (*rmdir)(struct inode___82 *, struct dentry___81 *);
	int (*mknod)(struct inode___82 *, struct dentry___81 *, umode_t, dev_t);
	int (*rename)(struct inode___82 *, struct dentry___81 *, struct inode___82 *, struct dentry___81 *, unsigned int);
	int (*setattr)(struct dentry___81 *, struct iattr___81 *);
	int (*getattr)(const struct path___80 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___81 *, char *, size_t);
	int (*fiemap)(struct inode___82 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___82 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___82 *, struct dentry___81 *, struct file___81 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___82 *, struct dentry___81 *, umode_t);
	int (*set_acl)(struct inode___82 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___80 {
	void (*fl_copy_lock)(struct file_lock___81 *, struct file_lock___81 *);
	void (*fl_release_private)(struct file_lock___81 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___80;

struct file_lock___81 {
	struct file_lock___81 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___81 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___80 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___80 *fl_ops;
	const struct lock_manager_operations___80 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___80 {
	int (*lm_compare_owner)(struct file_lock___81 *, struct file_lock___81 *);
	long unsigned int (*lm_owner_key)(struct file_lock___81 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___81 *);
	int (*lm_grant)(struct file_lock___81 *, int);
	bool (*lm_break)(struct file_lock___81 *);
	int (*lm_change)(struct file_lock___81 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___81 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___80 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___80 *fa_next;
	struct file___81 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___80 {
	const char *name;
	int fs_flags;
	struct dentry___81 * (*mount)(struct file_system_type___80 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___81 *);
	struct module___73 *owner;
	struct file_system_type___80 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___80 {
	struct inode___82 * (*alloc_inode)(struct super_block___81 *);
	void (*destroy_inode)(struct inode___82 *);
	void (*dirty_inode)(struct inode___82 *, int);
	int (*write_inode)(struct inode___82 *, struct writeback_control___30 *);
	int (*drop_inode)(struct inode___82 *);
	void (*evict_inode)(struct inode___82 *);
	void (*put_super)(struct super_block___81 *);
	int (*sync_fs)(struct super_block___81 *, int);
	int (*freeze_super)(struct super_block___81 *);
	int (*freeze_fs)(struct super_block___81 *);
	int (*thaw_super)(struct super_block___81 *);
	int (*unfreeze_fs)(struct super_block___81 *);
	int (*statfs)(struct dentry___81 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___81 *, int *, char *);
	void (*umount_begin)(struct super_block___81 *);
	int (*show_options)(struct seq_file___75 *, struct dentry___81 *);
	int (*show_devname)(struct seq_file___75 *, struct dentry___81 *);
	int (*show_path)(struct seq_file___75 *, struct dentry___81 *);
	int (*show_stats)(struct seq_file___75 *, struct dentry___81 *);
	ssize_t (*quota_read)(struct super_block___81 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___81 *, int, const char *, size_t, loff_t);
	struct dquot___80 ** (*get_dquots)(struct inode___82 *);
	int (*bdev_try_to_free_page)(struct super_block___81 *, struct page___81 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___81 *, struct shrink_control___30 *);
	long int (*free_cached_objects)(struct super_block___81 *, struct shrink_control___30 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___54)(struct file___81 *, wait_queue_head_t *, struct poll_table_struct___55 *);

struct poll_table_struct___55 {
	poll_queue_proc___54 _qproc;
	__poll_t _key;
};

struct seq_operations___72;

struct seq_file___75 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___72 *op;
	int poll_event;
	const struct file___81 *file;
	void *private;
};

typedef void bio_end_io_t___32(struct bio___32 *);

struct bio_vec___32 {
	struct page___81 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___32;

struct bio_set___32;

struct bio___32 {
	struct bio___32 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___32 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___32 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___32 *bi_io_vec;
	struct bio_set___32 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___32 bi_inline_vecs[0];
};

struct kobj_attribute___78 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___78 *, struct kobj_attribute___78 *, char *);
	ssize_t (*store)(struct kobject___78 *, struct kobj_attribute___78 *, const char *, size_t);
};

typedef void compound_page_dtor___80(struct page___81 *);

typedef long unsigned int elf_greg_t;

typedef elf_greg_t elf_gregset_t[34];

typedef int (*key_restrict_link_func_t___77)(struct key___78 *, const struct key_type *, const union key_payload *, struct key___78 *);

struct key_restriction___78;

struct key___78 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___81 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___78 *restrict_link;
};

struct key_restriction___78 {
	key_restrict_link_func_t___77 check;
	struct key___78 *key;
	struct key_type *keytype;
};

struct uts_namespace___18 {
	struct kref kref;
	struct new_utsname name;
	struct user_namespace___66 *user_ns;
	struct ucounts___66 *ucounts;
	struct ns_common ns;
};

struct cgroup_namespace___64 {
	refcount_t count;
	struct ns_common ns;
	struct user_namespace___66 *user_ns;
	struct ucounts___66 *ucounts;
	struct css_set___64 *root_cset;
};

struct ucounts___66 {
	struct hlist_node node;
	struct user_namespace___66 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct elf_siginfo {
	int si_signo;
	int si_code;
	int si_errno;
};

struct elf_prstatus {
	struct elf_siginfo pr_info;
	short int pr_cursig;
	long unsigned int pr_sigpend;
	long unsigned int pr_sighold;
	pid_t pr_pid;
	pid_t pr_ppid;
	pid_t pr_pgrp;
	pid_t pr_sid;
	struct timeval pr_utime;
	struct timeval pr_stime;
	struct timeval pr_cutime;
	struct timeval pr_cstime;
	elf_gregset_t pr_reg;
	int pr_fpvalid;
};

struct fwnode_operations___55;

struct fwnode_handle___55 {
	struct fwnode_handle___55 *secondary;
	const struct fwnode_operations___55 *ops;
};

struct fwnode_reference_args___55;

struct fwnode_endpoint___55;

struct fwnode_operations___55 {
	struct fwnode_handle___55 * (*get)(struct fwnode_handle___55 *);
	void (*put)(struct fwnode_handle___55 *);
	bool (*device_is_available)(const struct fwnode_handle___55 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___55 *, const struct device___76 *);
	bool (*property_present)(const struct fwnode_handle___55 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___55 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___55 *, const char *, const char **, size_t);
	struct fwnode_handle___55 * (*get_parent)(const struct fwnode_handle___55 *);
	struct fwnode_handle___55 * (*get_next_child_node)(const struct fwnode_handle___55 *, struct fwnode_handle___55 *);
	struct fwnode_handle___55 * (*get_named_child_node)(const struct fwnode_handle___55 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___55 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___55 *);
	struct fwnode_handle___55 * (*graph_get_next_endpoint)(const struct fwnode_handle___55 *, struct fwnode_handle___55 *);
	struct fwnode_handle___55 * (*graph_get_remote_endpoint)(const struct fwnode_handle___55 *);
	struct fwnode_handle___55 * (*graph_get_port_parent)(struct fwnode_handle___55 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___55 *, struct fwnode_endpoint___55 *);
};

struct fwnode_endpoint___55 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___55 *local_fwnode;
};

struct fwnode_reference_args___55 {
	struct fwnode_handle___55 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct kernfs_root___78;

struct kernfs_elem_dir___78 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___78 *root;
};

struct kernfs_syscall_ops___78;

struct kernfs_root___78 {
	struct kernfs_node___78 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___78 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___78 {
	struct kernfs_node___78 *target_kn;
};

struct kernfs_ops___78;

struct kernfs_elem_attr___78 {
	const struct kernfs_ops___78 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___78 *notify_next;
};

struct kernfs_node___78 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___78 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___78 dir;
		struct kernfs_elem_symlink___78 symlink;
		struct kernfs_elem_attr___78 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___78;

struct kernfs_ops___78 {
	int (*open)(struct kernfs_open_file___78 *);
	void (*release)(struct kernfs_open_file___78 *);
	int (*seq_show)(struct seq_file___75 *, void *);
	void * (*seq_start)(struct seq_file___75 *, loff_t *);
	void * (*seq_next)(struct seq_file___75 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___75 *, void *);
	ssize_t (*read)(struct kernfs_open_file___78 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___78 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___78 *, struct vm_area_struct___81 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___78 *, struct poll_table_struct___55 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___78 {
	int (*remount_fs)(struct kernfs_root___78 *, int *, char *);
	int (*show_options)(struct seq_file___75 *, struct kernfs_root___78 *);
	int (*mkdir)(struct kernfs_node___78 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___78 *);
	int (*rename)(struct kernfs_node___78 *, struct kernfs_node___78 *, const char *);
	int (*show_path)(struct seq_file___75 *, struct kernfs_node___78 *, struct kernfs_root___78 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___78 {
	struct kernfs_node___78 *kn;
	struct file___81 *file;
	struct seq_file___75 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___80 *vm_ops;
};

struct bin_attribute___75;

struct attribute_group___75 {
	const char *name;
	umode_t (*is_visible)(struct kobject___78 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___78 *, struct bin_attribute___75 *, int);
	struct attribute **attrs;
	struct bin_attribute___75 **bin_attrs;
};

struct bin_attribute___75 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___81 *, struct kobject___78 *, struct bin_attribute___75 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___81 *, struct kobject___78 *, struct bin_attribute___75 *, char *, loff_t, size_t);
	int (*mmap)(struct file___81 *, struct kobject___78 *, struct bin_attribute___75 *, struct vm_area_struct___81 *);
};

struct sysfs_ops___77 {
	ssize_t (*show)(struct kobject___78 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___78 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___77;

struct kset___77 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___78 kobj;
	const struct kset_uevent_ops___77 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___77 {
	void (*release)(struct kobject___78 *);
	const struct sysfs_ops___77 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___78 *);
	const void * (*namespace)(struct kobject___78 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___77 {
	int (* const filter)(struct kset___77 *, struct kobject___78 *);
	const char * (* const name)(struct kset___77 *, struct kobject___78 *);
	int (* const uevent)(struct kset___77 *, struct kobject___78 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___70 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___70 *);
	int (*get)(char *, const struct kernel_param___70 *);
	void (*free)(void *);
};

struct kparam_array___70;

struct kernel_param___70 {
	const char *name;
	struct module___73 *mod;
	const struct kernel_param_ops___70 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___70 *arr;
	};
};

struct kparam_array___70 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___70 *ops;
	void *elem;
};

struct module_attribute___70 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___70 *, struct module_kobject___70 *, char *);
	ssize_t (*store)(struct module_attribute___70 *, struct module_kobject___70 *, const char *, size_t);
	void (*setup)(struct module___73 *, const char *);
	int (*test)(struct module___73 *);
	void (*free)(struct module___73 *);
};

struct trace_event_class___47;

struct trace_event_call___47 {
	struct list_head list;
	struct trace_event_class___47 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___5 *prog_array;
	int (*perf_perm)(struct trace_event_call___47 *, struct perf_event___52 *);
};

struct kimage___12;

typedef void *kexec_load_t___12(struct kimage___12 *, char *, long unsigned int, char *, long unsigned int, char *, long unsigned int);

struct kexec_file_ops___13 {
	kexec_probe_t *probe;
	kexec_load_t___12 *load;
	kexec_cleanup_t *cleanup;
};

struct kimage___12 {
	kimage_entry_t head;
	kimage_entry_t *entry;
	kimage_entry_t *last_entry;
	long unsigned int start;
	struct page___81 *control_code_page;
	struct page___81 *swap_page;
	void *vmcoreinfo_data_copy;
	long unsigned int nr_segments;
	struct kexec_segment segment[16];
	struct list_head control_pages;
	struct list_head dest_pages;
	struct list_head unusable_pages;
	long unsigned int control_page;
	unsigned int type: 1;
	unsigned int preserve_context: 1;
	unsigned int file_mode: 1;
	struct kimage_arch arch;
	void *kernel_buf;
	long unsigned int kernel_buf_len;
	void *initrd_buf;
	long unsigned int initrd_buf_len;
	char *cmdline_buf;
	long unsigned int cmdline_buf_len;
	const struct kexec_file_ops___13 *fops;
	void *image_loader_data;
	struct purgatory_info purgatory_info;
};

struct seq_operations___72 {
	void * (*start)(struct seq_file___75 *, loff_t *);
	void (*stop)(struct seq_file___75 *, void *);
	void * (*next)(struct seq_file___75 *, void *, loff_t *);
	int (*show)(struct seq_file___75 *, void *);
};

struct dev_pm_ops___76 {
	int (*prepare)(struct device___76 *);
	void (*complete)(struct device___76 *);
	int (*suspend)(struct device___76 *);
	int (*resume)(struct device___76 *);
	int (*freeze)(struct device___76 *);
	int (*thaw)(struct device___76 *);
	int (*poweroff)(struct device___76 *);
	int (*restore)(struct device___76 *);
	int (*suspend_late)(struct device___76 *);
	int (*resume_early)(struct device___76 *);
	int (*freeze_late)(struct device___76 *);
	int (*thaw_early)(struct device___76 *);
	int (*poweroff_late)(struct device___76 *);
	int (*restore_early)(struct device___76 *);
	int (*suspend_noirq)(struct device___76 *);
	int (*resume_noirq)(struct device___76 *);
	int (*freeze_noirq)(struct device___76 *);
	int (*thaw_noirq)(struct device___76 *);
	int (*poweroff_noirq)(struct device___76 *);
	int (*restore_noirq)(struct device___76 *);
	int (*runtime_suspend)(struct device___76 *);
	int (*runtime_resume)(struct device___76 *);
	int (*runtime_idle)(struct device___76 *);
};

struct dev_pm_domain___76 {
	struct dev_pm_ops___76 ops;
	void (*detach)(struct device___76 *, bool);
	int (*activate)(struct device___76 *);
	void (*sync)(struct device___76 *);
	void (*dismiss)(struct device___76 *);
};

struct bus_type___76 {
	const char *name;
	const char *dev_name;
	struct device___76 *dev_root;
	const struct attribute_group___75 **bus_groups;
	const struct attribute_group___75 **dev_groups;
	const struct attribute_group___75 **drv_groups;
	int (*match)(struct device___76 *, struct device_driver___76 *);
	int (*uevent)(struct device___76 *, struct kobj_uevent_env *);
	int (*probe)(struct device___76 *);
	int (*remove)(struct device___76 *);
	void (*shutdown)(struct device___76 *);
	int (*online)(struct device___76 *);
	int (*offline)(struct device___76 *);
	int (*suspend)(struct device___76 *, pm_message_t);
	int (*resume)(struct device___76 *);
	int (*num_vf)(struct device___76 *);
	int (*dma_configure)(struct device___76 *);
	const struct dev_pm_ops___76 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___76 {
	const char *name;
	struct bus_type___76 *bus;
	struct module___73 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___76 *);
	int (*remove)(struct device___76 *);
	void (*shutdown)(struct device___76 *);
	int (*suspend)(struct device___76 *, pm_message_t);
	int (*resume)(struct device___76 *);
	const struct attribute_group___75 **groups;
	const struct dev_pm_ops___76 *pm;
	void (*coredump)(struct device___76 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___76 {
	const char *name;
	const struct attribute_group___75 **groups;
	int (*uevent)(struct device___76 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___76 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___76 *);
	const struct dev_pm_ops___76 *pm;
};

struct class___76 {
	const char *name;
	struct module___73 *owner;
	const struct attribute_group___75 **class_groups;
	const struct attribute_group___75 **dev_groups;
	struct kobject___78 *dev_kobj;
	int (*dev_uevent)(struct device___76 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___76 *, umode_t *);
	void (*class_release)(struct class___76 *);
	void (*dev_release)(struct device___76 *);
	int (*shutdown_pre)(struct device___76 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___76 *);
	const struct dev_pm_ops___76 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___66 {
	struct device___76 dev;
};

struct bpf_map___64;

struct bpf_map_ops___64 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___64 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___64 *, struct file___81 *);
	void (*map_free)(struct bpf_map___64 *);
	int (*map_get_next_key)(struct bpf_map___64 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___64 *);
	void * (*map_lookup_elem)(struct bpf_map___64 *, void *);
	int (*map_update_elem)(struct bpf_map___64 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___64 *, void *);
	int (*map_push_elem)(struct bpf_map___64 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___64 *, void *);
	int (*map_peek_elem)(struct bpf_map___64 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___64 *, struct file___81 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___64 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___64 *, void *, struct seq_file___75 *);
	int (*map_check_btf)(const struct bpf_map___64 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___64 {
	const struct bpf_map_ops___64 *ops;
	struct bpf_map___64 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___77 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___64;

typedef void (*kthread_work_func_t___64)(struct kthread_work___64 *);

struct kthread_worker___64;

struct kthread_work___64 {
	struct list_head node;
	kthread_work_func_t___64 func;
	struct kthread_worker___64 *worker;
	int canceling;
};

struct kthread_worker___64 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___81 *task;
	struct kthread_work___64 *current_work;
};

struct kthread_delayed_work___64 {
	struct kthread_work___64 work;
	struct timer_list timer;
};

struct psi_group___64 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___64 *poll_kworker;
	struct kthread_delayed_work___64 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___64;

struct cgroup_rstat_cpu___64;

struct cgroup___64 {
	struct cgroup_subsys_state___64 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___78 *kn;
	struct cgroup_file___64 procs_file;
	struct cgroup_file___64 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___64 *subsys[13];
	struct cgroup_root___64 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___64 *dom_cgrp;
	struct cgroup_rstat_cpu___64 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___5 bpf;
	atomic_t congestion_count;
	struct cgroup___64 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___64 psi;
	int ancestor_ids[0];
};

struct cftype___64;

struct cgroup_subsys___64 {
	struct cgroup_subsys_state___64 * (*css_alloc)(struct cgroup_subsys_state___64 *);
	int (*css_online)(struct cgroup_subsys_state___64 *);
	void (*css_offline)(struct cgroup_subsys_state___64 *);
	void (*css_released)(struct cgroup_subsys_state___64 *);
	void (*css_free)(struct cgroup_subsys_state___64 *);
	void (*css_reset)(struct cgroup_subsys_state___64 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___64 *, int);
	int (*css_extra_stat_show)(struct seq_file___75 *, struct cgroup_subsys_state___64 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___81 *);
	void (*cancel_fork)(struct task_struct___81 *);
	void (*fork)(struct task_struct___81 *);
	void (*exit)(struct task_struct___81 *);
	void (*free)(struct task_struct___81 *);
	void (*bind)(struct cgroup_subsys_state___64 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___64 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___64 *dfl_cftypes;
	struct cftype___64 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___64 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___64 *updated_children;
	struct cgroup___64 *updated_next;
};

struct cgroup_root___64 {
	struct kernfs_root___78 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___64 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___64 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___64 *ss;
	struct list_head node;
	struct kernfs_ops___78 *kf_ops;
	int (*open)(struct kernfs_open_file___78 *);
	void (*release)(struct kernfs_open_file___78 *);
	u64 (*read_u64)(struct cgroup_subsys_state___64 *, struct cftype___64 *);
	s64 (*read_s64)(struct cgroup_subsys_state___64 *, struct cftype___64 *);
	int (*seq_show)(struct seq_file___75 *, void *);
	void * (*seq_start)(struct seq_file___75 *, loff_t *);
	void * (*seq_next)(struct seq_file___75 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___75 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___64 *, struct cftype___64 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___64 *, struct cftype___64 *, s64);
	ssize_t (*write)(struct kernfs_open_file___78 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___78 *, struct poll_table_struct___55 *);
};

struct perf_cpu_context___52;

struct pmu___52 {
	struct list_head entry;
	struct module___73 *module;
	struct device___76 *dev;
	const struct attribute_group___75 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___52 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___52 *);
	void (*pmu_disable)(struct pmu___52 *);
	int (*event_init)(struct perf_event___52 *);
	void (*event_mapped)(struct perf_event___52 *, struct mm_struct___80 *);
	void (*event_unmapped)(struct perf_event___52 *, struct mm_struct___80 *);
	int (*add)(struct perf_event___52 *, int);
	void (*del)(struct perf_event___52 *, int);
	void (*start)(struct perf_event___52 *, int);
	void (*stop)(struct perf_event___52 *, int);
	void (*read)(struct perf_event___52 *);
	void (*start_txn)(struct pmu___52 *, unsigned int);
	int (*commit_txn)(struct pmu___52 *);
	void (*cancel_txn)(struct pmu___52 *);
	int (*event_idx)(struct perf_event___52 *);
	void (*sched_task)(struct perf_event_context___52 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___52 *);
	int (*filter_match)(struct perf_event___52 *);
	int (*check_period)(struct perf_event___52 *, u64);
};

struct perf_cpu_context___52 {
	struct perf_event_context___52 ctx;
	struct perf_event_context___52 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___52 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___52 {
	struct cgroup_subsys_state___64 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___47 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___47 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___47 *);
	struct list_head * (*get_fields)(struct trace_event_call___47 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___47 *);
};

struct bdi_writeback_congested___32 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___32 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___32 {
	struct bio___32 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___32 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___32 bip_inline_vecs[0];
};

struct bio_set___32 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___32 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___30 {
	struct mem_cgroup___30 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___30 {
	struct lruvec___80 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___30 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___30 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct consw___9 {
	struct module___73 *owner;
	const char * (*con_startup)();
	void (*con_init)(struct vc_data *, int);
	void (*con_deinit)(struct vc_data *);
	void (*con_clear)(struct vc_data *, int, int, int, int);
	void (*con_putc)(struct vc_data *, int, int, int);
	void (*con_putcs)(struct vc_data *, const short unsigned int *, int, int, int);
	void (*con_cursor)(struct vc_data *, int);
	bool (*con_scroll)(struct vc_data *, unsigned int, unsigned int, enum con_scroll, unsigned int);
	int (*con_switch)(struct vc_data *);
	int (*con_blank)(struct vc_data *, int, int);
	int (*con_font_set)(struct vc_data *, struct console_font *, unsigned int);
	int (*con_font_get)(struct vc_data *, struct console_font *);
	int (*con_font_default)(struct vc_data *, struct console_font *, char *);
	int (*con_font_copy)(struct vc_data *, int);
	int (*con_resize)(struct vc_data *, unsigned int, unsigned int, unsigned int);
	void (*con_set_palette)(struct vc_data *, const unsigned char *);
	void (*con_scrolldelta)(struct vc_data *, int);
	int (*con_set_origin)(struct vc_data *);
	void (*con_save_screen)(struct vc_data *);
	u8 (*con_build_attr)(struct vc_data *, u8, u8, u8, u8, u8, u8);
	void (*con_invert_region)(struct vc_data *, u16 *, int);
	u16 * (*con_screen_pos)(struct vc_data *, int);
	long unsigned int (*con_getxy)(struct vc_data *, long unsigned int, int *, int *);
	void (*con_flush_scrollback)(struct vc_data *);
	int (*con_debug_enter)(struct vc_data *);
	int (*con_debug_leave)(struct vc_data *);
};

struct hstate___11 {
	int next_nid_to_alloc;
	int next_nid_to_free;
	unsigned int order;
	long unsigned int mask;
	long unsigned int max_huge_pages;
	long unsigned int nr_huge_pages;
	long unsigned int free_huge_pages;
	long unsigned int resv_huge_pages;
	long unsigned int surplus_huge_pages;
	long unsigned int nr_overcommit_huge_pages;
	struct list_head hugepage_activelist;
	struct list_head hugepage_freelists[8];
	unsigned int nr_huge_pages_node[8];
	unsigned int free_huge_pages_node[8];
	unsigned int surplus_huge_pages_node[8];
	struct cftype___64 cgroup_files[5];
	char name[32];
};

struct kexec_sha_region {
	long unsigned int start;
	long unsigned int len;
};

struct syscall_metadata___22 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___47 *enter_event;
	struct trace_event_call___47 *exit_event;
};

struct elf64_phdr {
	Elf64_Word p_type;
	Elf64_Word p_flags;
	Elf64_Off p_offset;
	Elf64_Addr p_vaddr;
	Elf64_Addr p_paddr;
	Elf64_Xword p_filesz;
	Elf64_Xword p_memsz;
	Elf64_Xword p_align;
};

typedef struct elf64_phdr Elf64_Phdr;

struct crypto_async_request___3;

typedef void (*crypto_completion_t___3)(struct crypto_async_request___3 *, int);

struct crypto_tfm___3;

struct crypto_async_request___3 {
	struct list_head list;
	crypto_completion_t___3 complete;
	void *data;
	struct crypto_tfm___3 *tfm;
	u32 flags;
};

struct crypto_ablkcipher___3;

struct ablkcipher_request___3;

struct ablkcipher_tfm___3 {
	int (*setkey)(struct crypto_ablkcipher___3 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___3 *);
	int (*decrypt)(struct ablkcipher_request___3 *);
	struct crypto_ablkcipher___3 *base;
	unsigned int ivsize;
	unsigned int reqsize;
};

struct blkcipher_desc___3;

struct blkcipher_tfm___3 {
	void *iv;
	int (*setkey)(struct crypto_tfm___3 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___3 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___3 *, struct scatterlist *, struct scatterlist *, unsigned int);
};

struct cipher_tfm___3 {
	int (*cit_setkey)(struct crypto_tfm___3 *, const u8 *, unsigned int);
	void (*cit_encrypt_one)(struct crypto_tfm___3 *, u8 *, const u8 *);
	void (*cit_decrypt_one)(struct crypto_tfm___3 *, u8 *, const u8 *);
};

struct compress_tfm___3 {
	int (*cot_compress)(struct crypto_tfm___3 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*cot_decompress)(struct crypto_tfm___3 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___3;

struct crypto_tfm___3 {
	u32 crt_flags;
	union {
		struct ablkcipher_tfm___3 ablkcipher;
		struct blkcipher_tfm___3 blkcipher;
		struct cipher_tfm___3 cipher;
		struct compress_tfm___3 compress;
	} crt_u;
	void (*exit)(struct crypto_tfm___3 *);
	struct crypto_alg___3 *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct ablkcipher_request___3 {
	struct crypto_async_request___3 base;
	unsigned int nbytes;
	void *info;
	struct scatterlist *src;
	struct scatterlist *dst;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_blkcipher___3;

struct blkcipher_desc___3 {
	struct crypto_blkcipher___3 *tfm;
	void *info;
	u32 flags;
};

struct crypto_blkcipher___3 {
	struct crypto_tfm___3 base;
};

struct ablkcipher_alg___3 {
	int (*setkey)(struct crypto_ablkcipher___3 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___3 *);
	int (*decrypt)(struct ablkcipher_request___3 *);
	int (*givencrypt)(struct skcipher_givcrypt_request *);
	int (*givdecrypt)(struct skcipher_givcrypt_request *);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct crypto_ablkcipher___3 {
	struct crypto_tfm___3 base;
};

struct blkcipher_alg___3 {
	int (*setkey)(struct crypto_tfm___3 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___3 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___3 *, struct scatterlist *, struct scatterlist *, unsigned int);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct cipher_alg___3 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___3 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___3 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___3 *, u8 *, const u8 *);
};

struct compress_alg___3 {
	int (*coa_compress)(struct crypto_tfm___3 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___3 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___3 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type *cra_type;
	union {
		struct ablkcipher_alg___3 ablkcipher;
		struct blkcipher_alg___3 blkcipher;
		struct cipher_alg___3 cipher;
		struct compress_alg___3 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___3 *);
	void (*cra_exit)(struct crypto_tfm___3 *);
	void (*cra_destroy)(struct crypto_alg___3 *);
	struct module___73 *cra_module;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct crypto_shash___2;

struct shash_desc___2 {
	struct crypto_shash___2 *tfm;
	u32 flags;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_shash___2 {
	unsigned int descsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_tfm___3 base;
};

struct kexec_buf___2 {
	struct kimage___12 *image;
	void *buffer;
	long unsigned int bufsz;
	long unsigned int mem;
	long unsigned int memsz;
	long unsigned int buf_align;
	long unsigned int buf_min;
	long unsigned int buf_max;
	bool top_down;
};

struct crash_mem_range {
	u64 start;
	u64 end;
};

struct crash_mem {
	unsigned int max_nr_ranges;
	unsigned int nr_ranges;
	struct crash_mem_range ranges[0];
};

struct module___74;

struct file___82;

struct kiocb___82;

struct iov_iter___33;

struct poll_table_struct___56;

struct vm_area_struct___82;

struct inode___83;

struct file_lock___82;

struct page___82;

struct pipe_inode_info___15;

struct seq_file___76;

struct file_operations___82 {
	struct module___74 *owner;
	loff_t (*llseek)(struct file___82 *, loff_t, int);
	ssize_t (*read)(struct file___82 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___82 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___82 *, struct iov_iter___33 *);
	ssize_t (*write_iter)(struct kiocb___82 *, struct iov_iter___33 *);
	int (*iopoll)(struct kiocb___82 *, bool);
	int (*iterate)(struct file___82 *, struct dir_context *);
	int (*iterate_shared)(struct file___82 *, struct dir_context *);
	__poll_t (*poll)(struct file___82 *, struct poll_table_struct___56 *);
	long int (*unlocked_ioctl)(struct file___82 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___82 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___82 *, struct vm_area_struct___82 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___83 *, struct file___82 *);
	int (*flush)(struct file___82 *, fl_owner_t);
	int (*release)(struct inode___83 *, struct file___82 *);
	int (*fsync)(struct file___82 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___82 *, int);
	int (*lock)(struct file___82 *, int, struct file_lock___82 *);
	ssize_t (*sendpage)(struct file___82 *, struct page___82 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___82 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___82 *, int, struct file_lock___82 *);
	ssize_t (*splice_write)(struct pipe_inode_info___15 *, struct file___82 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___82 *, loff_t *, struct pipe_inode_info___15 *, size_t, unsigned int);
	int (*setlease)(struct file___82 *, long int, struct file_lock___82 **, void **);
	long int (*fallocate)(struct file___82 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___76 *, struct file___82 *);
	ssize_t (*copy_file_range)(struct file___82 *, loff_t, struct file___82 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___82 *, loff_t, struct file___82 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___82 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___81 {
	u64 seqnum;
	struct vm_area_struct___82 *vmas[4];
};

struct page_frag___81 {
	struct page___82 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___53;

struct debug_info___53 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___53 *hbp_break[16];
	struct perf_event___53 *hbp_watch[16];
};

struct thread_struct___53 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___53 debug;
	long: 64;
};

struct mm_struct___81;

struct mem_cgroup___31;

struct pid___69;

struct cred___78;

struct nsproxy___76;

struct signal_struct___72;

struct bio_list___33;

struct backing_dev_info___33;

struct css_set___65;

struct perf_event_context___53;

struct vm_struct___59;

struct task_struct___82 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___82 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___81 *mm;
	struct mm_struct___81 *active_mm;
	struct vmacache___81 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___82 *real_parent;
	struct task_struct___82 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___82 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___31 *active_memcg;
	long int rh_reserved2;
	struct pid___69 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___69 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___69 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___78 *ptracer_cred;
	const struct cred___78 *real_cred;
	const struct cred___78 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___76 *nsproxy;
	struct signal_struct___72 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___82 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___33 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___33 *backing_dev_info;
	struct io_context___14 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___65 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___53 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___15 *splice_pipe;
	struct page_frag___81 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___31 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___82 *oom_reaper_list;
	struct vm_struct___59 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___53 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___53 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___82 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___53)(struct perf_event___53 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___53;

struct fasync_struct___81;

struct pid_namespace___69;

struct bpf_prog___6;

struct trace_event_call___48;

struct perf_cgroup___53;

struct perf_event___53 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___53 *group_leader;
	struct pmu___53 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___53 hw;
	struct perf_event_context___53 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___53 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___82 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___81 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___53 *);
	struct callback_head callback_head;
	struct pid_namespace___69 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___53 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___53 orig_overflow_handler;
	struct bpf_prog___6 *prog;
	struct trace_event_call___48 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___53 *cgrp;
	struct list_head sb_list;
};

struct upid___69 {
	int nr;
	struct pid_namespace___69 *ns;
};

struct proc_ns_operations___5;

struct ns_common___5 {
	atomic_long_t stashed;
	const struct proc_ns_operations___5 *ops;
	unsigned int inum;
};

struct vfsmount___12;

struct dentry___82;

struct user_namespace___67;

struct ucounts___67;

struct pid_namespace___69 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___82 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___69 *parent;
	struct vfsmount___12 *proc_mnt;
	struct dentry___82 *proc_self;
	struct dentry___82 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___67 *user_ns;
	struct ucounts___67 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___5 ns;
};

struct pid___69 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___69 numbers[1];
};

struct rw_semaphore___82 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___82 *owner;
};

struct key___79;

struct user_namespace___67 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___67 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___5 ns;
	long unsigned int flags;
	struct key___79 *persistent_keyring_register;
	struct rw_semaphore___82 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___67 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct secondary_data___82 {
	void *stack;
	struct task_struct___82 *task;
	long int status;
};

typedef struct page___82 *pgtable_t___81;

struct address_space___81;

struct dev_pagemap___81;

struct page___82 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___81 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___82 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___81 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___81 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___81 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___31 *mem_cgroup;
};

struct user_struct___78 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___79 *uid_keyring;
	struct key___79 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___81;

struct vm_area_struct___82 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___82 *vm_next;
	struct vm_area_struct___82 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___81 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___81 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___82 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___81;

struct mm_struct___81 {
	struct {
		struct vm_area_struct___82 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___82 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___82 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___81 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___82 *owner;
		struct user_namespace___67 *user_ns;
		struct file___82 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___81 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup___65;

struct cgroup_subsys___65;

struct cgroup_subsys_state___65 {
	struct cgroup___65 *cgroup;
	struct cgroup_subsys___65 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___65 *parent;
};

struct mem_cgroup_id___13 {
	int id;
	union {
		refcount_t ref;
		struct {
			atomic_t ref;
		} __UNIQUE_ID_rh_kabi_hide54;
		union {		};
	};
};

struct kernfs_node___79;

struct cgroup_file___65 {
	struct kernfs_node___79 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___31;

struct mem_cgroup___31 {
	struct cgroup_subsys_state___65 css;
	struct mem_cgroup_id___13 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___65 events_file;
	struct cgroup_file___65 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___82 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___31 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cred___78 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___79 *session_keyring;
	struct key___79 *process_keyring;
	struct key___79 *thread_keyring;
	struct key___79 *request_key_auth;
	void *security;
	struct user_struct___78 *user;
	struct user_namespace___67 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct uts_namespace___19;

struct net___16;

struct cgroup_namespace___65;

struct nsproxy___76 {
	atomic_t count;
	struct uts_namespace___19 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___69 *pid_ns_for_children;
	struct net___16 *net_ns;
	struct cgroup_namespace___65 *cgroup_ns;
};

struct signal_struct___72 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___82 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___82 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___69 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___69 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___81 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___69 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___33;

struct bio_list___33 {
	struct bio___33 *head;
	struct bio___33 *tail;
};

struct bdi_writeback_congested___33;

struct bdi_writeback___33 {
	struct backing_dev_info___33 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___33 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___65 *memcg_css;
	struct cgroup_subsys_state___65 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___77;

struct backing_dev_info___33 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___33 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___77 *dev;
	struct device___77 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___82 *debug_dir;
	struct dentry___82 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___65 {
	struct cgroup_subsys_state___65 *subsys[13];
	refcount_t refcount;
	struct css_set___65 *dom_cset;
	struct cgroup___65 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___65 *mg_src_cgrp;
	struct cgroup___65 *mg_dst_cgrp;
	struct css_set___65 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___53 {
	struct pmu___53 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___82 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___53 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___15;

struct pipe_inode_info___15 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___82 *tmp_page;
	struct fasync_struct___81 *fasync_readers;
	struct fasync_struct___81 *fasync_writers;
	struct pipe_buffer___15 *bufs;
	struct user_struct___78 *user;
};

struct vm_struct___59 {
	struct vm_struct___59 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___82 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___72 {
	struct task_struct___82 task;
	long unsigned int stack[8192];
};

struct dentry_operations___81;

struct super_block___82;

struct dentry___82 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___82 *d_parent;
	struct qstr d_name;
	struct inode___83 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___81 *d_op;
	struct super_block___82 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___81;

struct address_space___81 {
	struct inode___83 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___82 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___81 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___81;

struct block_device___82;

struct inode___83 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___81 *i_op;
	struct super_block___82 *i_sb;
	struct address_space___81 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___82 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___33 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___82 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___81 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___15 *i_pipe;
		struct block_device___82 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___81;

struct dentry_operations___81 {
	int (*d_revalidate)(struct dentry___82 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___82 *, unsigned int);
	int (*d_hash)(const struct dentry___82 *, struct qstr *);
	int (*d_compare)(const struct dentry___82 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___82 *);
	int (*d_init)(struct dentry___82 *);
	void (*d_release)(struct dentry___82 *);
	void (*d_prune)(struct dentry___82 *);
	void (*d_iput)(struct dentry___82 *, struct inode___83 *);
	char * (*d_dname)(struct dentry___82 *, char *, int);
	struct vfsmount___12 * (*d_automount)(struct path___81 *);
	int (*d_manage)(const struct path___81 *, bool);
	struct dentry___82 * (*d_real)(struct dentry___82 *, const struct inode___83 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___81;

struct mem_dqinfo___81 {
	struct quota_format_type___81 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___81;

struct quota_info___81 {
	unsigned int flags;
	struct rw_semaphore___82 dqio_sem;
	struct inode___83 *files[3];
	struct mem_dqinfo___81 info[3];
	const struct quota_format_ops___81 *ops[3];
};

struct rcuwait___81 {
	struct task_struct___82 *task;
};

struct percpu_rw_semaphore___81 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___82 rw_sem;
	struct rcuwait___81 writer;
	int readers_block;
};

struct sb_writers___81 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___81 rw_sem[3];
};

struct shrink_control___31;

struct shrinker___31 {
	long unsigned int (*count_objects)(struct shrinker___31 *, struct shrink_control___31 *);
	long unsigned int (*scan_objects)(struct shrinker___31 *, struct shrink_control___31 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___81;

struct super_operations___81;

struct dquot_operations___81;

struct quotactl_ops___81;

struct super_block___82 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___81 *s_type;
	const struct super_operations___81 *s_op;
	const struct dquot_operations___81 *dq_op;
	const struct quotactl_ops___81 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___82 *s_root;
	struct rw_semaphore___82 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___82 *s_bdev;
	struct backing_dev_info___33 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___81 s_dquot;
	struct sb_writers___81 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___81 *s_d_op;
	int cleancache_poolid;
	struct shrinker___31 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___67 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___12 {
	struct dentry___82 *mnt_root;
	struct super_block___82 *mnt_sb;
	int mnt_flags;
};

struct path___81 {
	struct vfsmount___12 *mnt;
	struct dentry___82 *dentry;
};

struct shrink_control___31 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___31 *memcg;
};

struct pglist_data___81;

struct lruvec___81 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___81 *pgdat;
};

struct zone___81 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___81 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___81 {
	struct zone___81 *zone;
	int zone_idx;
};

struct zonelist___81 {
	struct zoneref___81 _zonerefs[25];
};

struct pglist_data___81 {
	struct zone___81 node_zones[3];
	struct zonelist___81 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___82 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___82 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___81 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___81 {
	struct rw_semaphore___82 rwsem;
	struct notifier_block *head;
};

typedef int (*dev_page_fault_t___81)(struct vm_area_struct___82 *, long unsigned int, const struct page___82 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___81)(struct page___82 *, void *);

struct dev_pagemap___81 {
	dev_page_fault_t___81 page_fault;
	dev_page_free_t___81 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___77 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct fown_struct___69 {
	rwlock_t lock;
	struct pid___69 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___82 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___81 f_path;
	struct inode___83 *f_inode;
	const struct file_operations___82 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___69 f_owner;
	const struct cred___78 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___81 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___81;

struct vm_operations_struct___81 {
	void (*open)(struct vm_area_struct___82 *);
	void (*close)(struct vm_area_struct___82 *);
	int (*split)(struct vm_area_struct___82 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___82 *);
	vm_fault_t (*fault)(struct vm_fault___81 *);
	vm_fault_t (*huge_fault)(struct vm_fault___81 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___81 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___82 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___81 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___81 *);
	int (*access)(struct vm_area_struct___82 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___82 *);
	int (*set_policy)(struct vm_area_struct___82 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___82 *, long unsigned int);
	struct page___82 * (*find_special_page)(struct vm_area_struct___82 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___81 {
	struct task_struct___82 *task;
	struct core_thread___81 *next;
};

struct core_state___81 {
	atomic_t nr_threads;
	struct core_thread___81 dumper;
	struct completion startup;
};

struct vm_fault___81 {
	struct vm_area_struct___82 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___82 *cow_page;
	struct mem_cgroup___31 *memcg;
	struct page___82 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___81 prealloc_pte;
};

struct kiocb___82 {
	struct file___82 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___82 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___82 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___82 *ia_file;
};

struct dquot___81 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___82 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___81 {
	int qf_fmt_id;
	const struct quota_format_ops___81 *qf_ops;
	struct module___74 *qf_owner;
	struct quota_format_type___81 *qf_next;
};

struct quota_format_ops___81 {
	int (*check_quota_file)(struct super_block___82 *, int);
	int (*read_file_info)(struct super_block___82 *, int);
	int (*write_file_info)(struct super_block___82 *, int);
	int (*free_file_info)(struct super_block___82 *, int);
	int (*read_dqblk)(struct dquot___81 *);
	int (*commit_dqblk)(struct dquot___81 *);
	int (*release_dqblk)(struct dquot___81 *);
	int (*get_next_id)(struct super_block___82 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___81 {
	int (*write_dquot)(struct dquot___81 *);
	struct dquot___81 * (*alloc_dquot)(struct super_block___82 *, int);
	void (*destroy_dquot)(struct dquot___81 *);
	int (*acquire_dquot)(struct dquot___81 *);
	int (*release_dquot)(struct dquot___81 *);
	int (*mark_dirty)(struct dquot___81 *);
	int (*write_info)(struct super_block___82 *, int);
	qsize_t * (*get_reserved_space)(struct inode___83 *);
	int (*get_projid)(struct inode___83 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___83 *, qsize_t *);
	int (*get_next_id)(struct super_block___82 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___81 {
	int (*quota_on)(struct super_block___82 *, int, int, const struct path___81 *);
	int (*quota_off)(struct super_block___82 *, int);
	int (*quota_enable)(struct super_block___82 *, unsigned int);
	int (*quota_disable)(struct super_block___82 *, unsigned int);
	int (*quota_sync)(struct super_block___82 *, int);
	int (*set_info)(struct super_block___82 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___82 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___82 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___82 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___82 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___82 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___78;

struct kobj_type___78;

struct kobject___79 {
	const char *name;
	struct list_head entry;
	struct kobject___79 *parent;
	struct kset___78 *kset;
	struct kobj_type___78 *ktype;
	struct kernfs_node___79 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___71 {
	struct kobject___79 kobj;
	struct module___74 *mod;
	struct kobject___79 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___71 {
	struct module___74 *mod;
	struct latch_tree_node node;
};

struct module_layout___71 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___71 mtn;
};

struct module_attribute___71;

struct kernel_param___71;

struct module___74 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___71 mkobj;
	struct module_attribute___71 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___79 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___71 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___71 core_layout;
	struct module_layout___71 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___48 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___31;

struct address_space_operations___81 {
	int (*writepage)(struct page___82 *, struct writeback_control___31 *);
	int (*readpage)(struct file___82 *, struct page___82 *);
	int (*writepages)(struct address_space___81 *, struct writeback_control___31 *);
	int (*set_page_dirty)(struct page___82 *);
	int (*readpages)(struct file___82 *, struct address_space___81 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___82 *, struct address_space___81 *, loff_t, unsigned int, unsigned int, struct page___82 **, void **);
	int (*write_end)(struct file___82 *, struct address_space___81 *, loff_t, unsigned int, unsigned int, struct page___82 *, void *);
	sector_t (*bmap)(struct address_space___81 *, sector_t);
	void (*invalidatepage)(struct page___82 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___82 *, gfp_t);
	void (*freepage)(struct page___82 *);
	ssize_t (*direct_IO)(struct kiocb___82 *, struct iov_iter___33 *);
	int (*migratepage)(struct address_space___81 *, struct page___82 *, struct page___82 *, enum migrate_mode);
	bool (*isolate_page)(struct page___82 *, isolate_mode_t);
	void (*putback_page)(struct page___82 *);
	int (*launder_page)(struct page___82 *);
	int (*is_partially_uptodate)(struct page___82 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___82 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___81 *, struct page___82 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___82 *, sector_t *);
	void (*swap_deactivate)(struct file___82 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___31 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___33 *wb;
	struct inode___83 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___33;

struct iov_iter___33 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___33 *bvec;
		struct pipe_inode_info___15 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___82 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___83 *bd_inode;
	struct super_block___82 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___82 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___33 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___81 {
	struct dentry___82 * (*lookup)(struct inode___83 *, struct dentry___82 *, unsigned int);
	const char * (*get_link)(struct dentry___82 *, struct inode___83 *, struct delayed_call *);
	int (*permission)(struct inode___83 *, int);
	struct posix_acl * (*get_acl)(struct inode___83 *, int);
	int (*readlink)(struct dentry___82 *, char *, int);
	int (*create)(struct inode___83 *, struct dentry___82 *, umode_t, bool);
	int (*link)(struct dentry___82 *, struct inode___83 *, struct dentry___82 *);
	int (*unlink)(struct inode___83 *, struct dentry___82 *);
	int (*symlink)(struct inode___83 *, struct dentry___82 *, const char *);
	int (*mkdir)(struct inode___83 *, struct dentry___82 *, umode_t);
	int (*rmdir)(struct inode___83 *, struct dentry___82 *);
	int (*mknod)(struct inode___83 *, struct dentry___82 *, umode_t, dev_t);
	int (*rename)(struct inode___83 *, struct dentry___82 *, struct inode___83 *, struct dentry___82 *, unsigned int);
	int (*setattr)(struct dentry___82 *, struct iattr___82 *);
	int (*getattr)(const struct path___81 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___82 *, char *, size_t);
	int (*fiemap)(struct inode___83 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___83 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___83 *, struct dentry___82 *, struct file___82 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___83 *, struct dentry___82 *, umode_t);
	int (*set_acl)(struct inode___83 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___81 {
	void (*fl_copy_lock)(struct file_lock___82 *, struct file_lock___82 *);
	void (*fl_release_private)(struct file_lock___82 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___81;

struct file_lock___82 {
	struct file_lock___82 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___82 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___81 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___81 *fl_ops;
	const struct lock_manager_operations___81 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___81 {
	int (*lm_compare_owner)(struct file_lock___82 *, struct file_lock___82 *);
	long unsigned int (*lm_owner_key)(struct file_lock___82 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___82 *);
	int (*lm_grant)(struct file_lock___82 *, int);
	bool (*lm_break)(struct file_lock___82 *);
	int (*lm_change)(struct file_lock___82 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___82 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___81 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___81 *fa_next;
	struct file___82 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___81 {
	const char *name;
	int fs_flags;
	struct dentry___82 * (*mount)(struct file_system_type___81 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___82 *);
	struct module___74 *owner;
	struct file_system_type___81 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___81 {
	struct inode___83 * (*alloc_inode)(struct super_block___82 *);
	void (*destroy_inode)(struct inode___83 *);
	void (*dirty_inode)(struct inode___83 *, int);
	int (*write_inode)(struct inode___83 *, struct writeback_control___31 *);
	int (*drop_inode)(struct inode___83 *);
	void (*evict_inode)(struct inode___83 *);
	void (*put_super)(struct super_block___82 *);
	int (*sync_fs)(struct super_block___82 *, int);
	int (*freeze_super)(struct super_block___82 *);
	int (*freeze_fs)(struct super_block___82 *);
	int (*thaw_super)(struct super_block___82 *);
	int (*unfreeze_fs)(struct super_block___82 *);
	int (*statfs)(struct dentry___82 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___82 *, int *, char *);
	void (*umount_begin)(struct super_block___82 *);
	int (*show_options)(struct seq_file___76 *, struct dentry___82 *);
	int (*show_devname)(struct seq_file___76 *, struct dentry___82 *);
	int (*show_path)(struct seq_file___76 *, struct dentry___82 *);
	int (*show_stats)(struct seq_file___76 *, struct dentry___82 *);
	ssize_t (*quota_read)(struct super_block___82 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___82 *, int, const char *, size_t, loff_t);
	struct dquot___81 ** (*get_dquots)(struct inode___83 *);
	int (*bdev_try_to_free_page)(struct super_block___82 *, struct page___82 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___82 *, struct shrink_control___31 *);
	long int (*free_cached_objects)(struct super_block___82 *, struct shrink_control___31 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___55)(struct file___82 *, wait_queue_head_t *, struct poll_table_struct___56 *);

struct poll_table_struct___56 {
	poll_queue_proc___55 _qproc;
	__poll_t _key;
};

struct seq_operations___73;

struct seq_file___76 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___73 *op;
	int poll_event;
	const struct file___82 *file;
	void *private;
};

typedef void bio_end_io_t___33(struct bio___33 *);

struct bio_vec___33 {
	struct page___82 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___33;

struct bio_set___33;

struct bio___33 {
	struct bio___33 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___33 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___33 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___33 *bi_io_vec;
	struct bio_set___33 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___33 bi_inline_vecs[0];
};

typedef int (*key_restrict_link_func_t___78)(struct key___79 *, const struct key_type *, const union key_payload *, struct key___79 *);

struct key_restriction___79;

struct key___79 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___82 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___79 *restrict_link;
};

struct key_restriction___79 {
	key_restrict_link_func_t___78 check;
	struct key___79 *key;
	struct key_type *keytype;
};

struct seq_operations___73 {
	void * (*start)(struct seq_file___76 *, loff_t *);
	void (*stop)(struct seq_file___76 *, void *);
	void * (*next)(struct seq_file___76 *, void *, loff_t *);
	int (*show)(struct seq_file___76 *, void *);
};

enum kernfs_node_type {
	KERNFS_DIR = 1,
	KERNFS_FILE = 2,
	KERNFS_LINK = 4,
};

enum kernfs_root_flag {
	KERNFS_ROOT_CREATE_DEACTIVATED = 1,
	KERNFS_ROOT_EXTRA_OPEN_PERM_CHECK = 2,
	KERNFS_ROOT_SUPPORT_EXPORTOP = 4,
};

struct kernfs_root___79;

struct kernfs_elem_dir___79 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___79 *root;
};

struct kernfs_syscall_ops___79;

struct kernfs_root___79 {
	struct kernfs_node___79 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___79 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___79 {
	struct kernfs_node___79 *target_kn;
};

struct kernfs_ops___79;

struct kernfs_elem_attr___79 {
	const struct kernfs_ops___79 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___79 *notify_next;
};

struct kernfs_node___79 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___79 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___79 dir;
		struct kernfs_elem_symlink___79 symlink;
		struct kernfs_elem_attr___79 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___79;

struct kernfs_ops___79 {
	int (*open)(struct kernfs_open_file___79 *);
	void (*release)(struct kernfs_open_file___79 *);
	int (*seq_show)(struct seq_file___76 *, void *);
	void * (*seq_start)(struct seq_file___76 *, loff_t *);
	void * (*seq_next)(struct seq_file___76 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___76 *, void *);
	ssize_t (*read)(struct kernfs_open_file___79 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___79 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___79 *, struct vm_area_struct___82 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___79 *, struct poll_table_struct___56 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___79 {
	int (*remount_fs)(struct kernfs_root___79 *, int *, char *);
	int (*show_options)(struct seq_file___76 *, struct kernfs_root___79 *);
	int (*mkdir)(struct kernfs_node___79 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___79 *);
	int (*rename)(struct kernfs_node___79 *, struct kernfs_node___79 *, const char *);
	int (*show_path)(struct seq_file___76 *, struct kernfs_node___79 *, struct kernfs_root___79 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___79 {
	struct kernfs_node___79 *kn;
	struct file___82 *file;
	struct seq_file___76 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___81 *vm_ops;
};

struct proc_ns_operations___5 {
	const char *name;
	const char *real_ns_name;
	int type;
	struct ns_common___5 * (*get)(struct task_struct___82 *);
	void (*put)(struct ns_common___5 *);
	int (*install)(struct nsproxy___76 *, struct ns_common___5 *);
	struct user_namespace___67 * (*owner)(struct ns_common___5 *);
	struct ns_common___5 * (*get_parent)(struct ns_common___5 *);
};

struct uts_namespace___19 {
	struct kref kref;
	struct new_utsname name;
	struct user_namespace___67 *user_ns;
	struct ucounts___67 *ucounts;
	struct ns_common___5 ns;
};

struct inet_frags___7;

struct netns_frags___7 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___7 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_rules_ops___3;

struct sock___6;

struct fib_notifier_ops___3;

struct netns_ipv4___7 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___3 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___6 *fibnl;
	struct sock___6 **icmp_sk;
	struct sock___6 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___6 **tcp_sk;
	struct netns_frags___7 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___3 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___3 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___3 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct dst_entry___5;

struct net_device___12;

struct sk_buff___11;

struct neighbour___5;

struct dst_ops___14 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___14 *);
	struct dst_entry___5 * (*check)(struct dst_entry___5 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___5 *);
	unsigned int (*mtu)(const struct dst_entry___5 *);
	u32 * (*cow_metrics)(struct dst_entry___5 *, long unsigned int);
	void (*destroy)(struct dst_entry___5 *);
	void (*ifdown)(struct dst_entry___5 *, struct net_device___12 *, int);
	struct dst_entry___5 * (*negative_advice)(struct dst_entry___5 *);
	void (*link_failure)(struct sk_buff___11 *);
	void (*update_pmtu)(struct dst_entry___5 *, struct sock___6 *, struct sk_buff___11 *, u32);
	void (*redirect)(struct dst_entry___5 *, struct sock___6 *, struct sk_buff___11 *);
	int (*local_out)(struct net___16 *, struct sock___6 *, struct sk_buff___11 *);
	struct neighbour___5 * (*neigh_lookup)(const struct dst_entry___5 *, struct sk_buff___11 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___5 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___13 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___7 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___14 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___3 *fib6_rules_ops;
	struct sock___6 **icmp_sk;
	struct sock___6 *ndisc_sk;
	struct sock___6 *tcp_sk;
	struct sock___6 *igmp_sk;
	struct sock___6 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___3 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___3 *notifier_ops;
	struct fib_notifier_ops___3 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___3 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___6 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___7 {
	struct netns_frags___7 frags;
};

struct netns_xfrm___13 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___6 *nlsk;
	struct sock___6 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___14 xfrm4_dst_ops;
	struct dst_ops___14 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct net___16 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___67 *user_ns;
	struct ucounts___67 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___5 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___6 *rtnl;
	struct sock___6 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___12 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___7 ipv4;
	struct netns_ipv6___13 ipv6;
	struct netns_sctp___3 sctp;
	struct netns_nf nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___7 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___6 *nfnl;
	struct sock___6 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___13 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___6 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___6 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cgroup_namespace___65 {
	refcount_t count;
	struct ns_common___5 ns;
	struct user_namespace___67 *user_ns;
	struct ucounts___67 *ucounts;
	struct css_set___65 *root_cset;
};

struct ucounts___67 {
	struct hlist_node node;
	struct user_namespace___67 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___65;

struct bpf_map_ops___65 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___65 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___65 *, struct file___82 *);
	void (*map_free)(struct bpf_map___65 *);
	int (*map_get_next_key)(struct bpf_map___65 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___65 *);
	void * (*map_lookup_elem)(struct bpf_map___65 *, void *);
	int (*map_update_elem)(struct bpf_map___65 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___65 *, void *);
	int (*map_push_elem)(struct bpf_map___65 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___65 *, void *);
	int (*map_peek_elem)(struct bpf_map___65 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___65 *, struct file___82 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___65 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___65 *, void *, struct seq_file___76 *);
	int (*map_check_btf)(const struct bpf_map___65 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___65 {
	const struct bpf_map_ops___65 *ops;
	struct bpf_map___65 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___78 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___7;

struct bpf_map_dev_ops___7 {
	int (*map_get_next_key)(struct bpf_offloaded_map___7 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___7 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___7 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___7 *, void *);
};

struct bpf_offloaded_map___7 {
	struct bpf_map___65 map;
	struct net_device___12 *netdev;
	const struct bpf_map_dev_ops___7 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

typedef rx_handler_result_t rx_handler_func_t___7(struct sk_buff___11 **);

typedef struct {
	struct net___16 *net;
} possible_net_t___7;

struct dev_pm_info___77 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___77 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___77;

struct bus_type___77;

struct device_driver___77;

struct dev_pm_domain___77;

struct dma_map_ops___20;

struct fwnode_handle___56;

struct class___77;

struct attribute_group___76;

struct device___77 {
	struct device___77 *parent;
	struct device_private *p;
	struct kobject___79 kobj;
	const char *init_name;
	const struct device_type___77 *type;
	struct mutex mutex;
	struct bus_type___77 *bus;
	struct device_driver___77 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___77 power;
	struct dev_pm_domain___77 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___20 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___56 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___77 *class;
	const struct attribute_group___76 **groups;
	void (*release)(struct device___77 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct net_device_ops___7;

struct ethtool_ops___7;

struct l3mdev_ops___4;

struct xfrmdev_ops___7;

struct tlsdev_ops___7;

struct header_ops___7;

struct netdev_rx_queue___7;

struct mini_Qdisc___6;

struct netdev_queue___7;

struct Qdisc___6;

struct rtnl_link_ops___6;

struct dcbnl_rtnl_ops___7;

struct net_device___12 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___7 *netdev_ops;
	const struct ethtool_ops___7 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___4 *l3mdev_ops;
	const struct ndisc_ops___2 *ndisc_ops;
	const struct xfrmdev_ops___7 *xfrmdev_ops;
	const struct tlsdev_ops___7 *tlsdev_ops;
	const struct header_ops___7 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___78 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___2 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___7 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___6 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___7 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___6 *miniq_ingress;
	struct netdev_queue___7 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___7 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___6 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___6 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___7 = 0,
		NETREG_REGISTERED___7 = 1,
		NETREG_UNREGISTERING___7 = 2,
		NETREG_UNREGISTERED___7 = 3,
		NETREG_RELEASED___7 = 4,
		NETREG_DUMMY___7 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___7 = 0,
		RTNL_LINK_INITIALIZING___7 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___12 *);
	struct netpoll_info *npinfo;
	possible_net_t___7 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___77 dev;
	const struct attribute_group___76 *sysfs_groups[4];
	const struct attribute_group___76 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___6 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___7 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide35;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct bpf_prog_ops___6 {
	int (*test_run)(struct bpf_prog___6 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_aux___6;

struct bpf_prog___6 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___6 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

struct bpf_verifier_ops___6 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___6 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___6 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___6 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___6 *, u32 *);
};

struct bpf_prog_offload_ops___6 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___6 *);
	int (*translate)(struct bpf_prog___6 *);
	void (*destroy)(struct bpf_prog___6 *);
};

struct bpf_prog_offload___6 {
	struct bpf_prog___6 *prog;
	struct net_device___12 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___6 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___6 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___6 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___6 *ops;
	struct bpf_map___65 **used_maps;
	struct bpf_prog___6 *prog;
	struct user_struct___78 *user;
	u64 load_time;
	struct bpf_map___65 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___6 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___6 {
	struct bpf_prog___6 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___6 {
	struct callback_head rcu;
	struct bpf_prog_array_item___6 items[0];
};

struct cgroup_bpf___6 {
	struct bpf_prog_array___6 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___6 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___65;

typedef void (*kthread_work_func_t___65)(struct kthread_work___65 *);

struct kthread_worker___65;

struct kthread_work___65 {
	struct list_head node;
	kthread_work_func_t___65 func;
	struct kthread_worker___65 *worker;
	int canceling;
};

struct kthread_worker___65 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___82 *task;
	struct kthread_work___65 *current_work;
};

struct kthread_delayed_work___65 {
	struct kthread_work___65 work;
	struct timer_list timer;
};

struct psi_group___65;

struct psi_trigger___2 {
	enum psi_states state;
	u64 threshold;
	struct list_head node;
	struct psi_group___65 *group;
	wait_queue_head_t event_wait;
	int event;
	struct psi_window win;
	u64 last_event_time;
	struct kref refcount;
};

struct psi_group___65 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___65 *poll_kworker;
	struct kthread_delayed_work___65 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

enum {
	CGRP_NOTIFY_ON_RELEASE = 0,
	CGRP_CPUSET_CLONE_CHILDREN = 1,
	CGRP_FREEZE = 2,
	CGRP_FROZEN = 3,
};

enum {
	CGRP_ROOT_NOPREFIX = 2,
	CGRP_ROOT_XATTR = 4,
	CGRP_ROOT_NS_DELEGATE = 8,
	CGRP_ROOT_CPUSET_V2_MODE = 16,
};

struct cgroup_root___65;

struct cgroup_rstat_cpu___65;

struct cgroup___65 {
	struct cgroup_subsys_state___65 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___79 *kn;
	struct cgroup_file___65 procs_file;
	struct cgroup_file___65 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___65 *subsys[13];
	struct cgroup_root___65 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___65 *dom_cgrp;
	struct cgroup_rstat_cpu___65 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___6 bpf;
	atomic_t congestion_count;
	struct cgroup___65 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___65 psi;
	int ancestor_ids[0];
};

struct cgroup_taskset___2;

struct cftype___65;

struct cgroup_subsys___65 {
	struct cgroup_subsys_state___65 * (*css_alloc)(struct cgroup_subsys_state___65 *);
	int (*css_online)(struct cgroup_subsys_state___65 *);
	void (*css_offline)(struct cgroup_subsys_state___65 *);
	void (*css_released)(struct cgroup_subsys_state___65 *);
	void (*css_free)(struct cgroup_subsys_state___65 *);
	void (*css_reset)(struct cgroup_subsys_state___65 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___65 *, int);
	int (*css_extra_stat_show)(struct seq_file___76 *, struct cgroup_subsys_state___65 *);
	int (*can_attach)(struct cgroup_taskset___2 *);
	void (*cancel_attach)(struct cgroup_taskset___2 *);
	void (*attach)(struct cgroup_taskset___2 *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___82 *);
	void (*cancel_fork)(struct task_struct___82 *);
	void (*fork)(struct task_struct___82 *);
	void (*exit)(struct task_struct___82 *);
	void (*free)(struct task_struct___82 *);
	void (*bind)(struct cgroup_subsys_state___65 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___65 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___65 *dfl_cftypes;
	struct cftype___65 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___65 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___65 *updated_children;
	struct cgroup___65 *updated_next;
};

struct cgroup_root___65 {
	struct kernfs_root___79 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___65 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___65 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___65 *ss;
	struct list_head node;
	struct kernfs_ops___79 *kf_ops;
	int (*open)(struct kernfs_open_file___79 *);
	void (*release)(struct kernfs_open_file___79 *);
	u64 (*read_u64)(struct cgroup_subsys_state___65 *, struct cftype___65 *);
	s64 (*read_s64)(struct cgroup_subsys_state___65 *, struct cftype___65 *);
	int (*seq_show)(struct seq_file___76 *, void *);
	void * (*seq_start)(struct seq_file___76 *, loff_t *);
	void * (*seq_next)(struct seq_file___76 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___76 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___65 *, struct cftype___65 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___65 *, struct cftype___65 *, s64);
	ssize_t (*write)(struct kernfs_open_file___79 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___79 *, struct poll_table_struct___56 *);
};

struct cgroup_taskset___2 {
	struct list_head src_csets;
	struct list_head dst_csets;
	int nr_tasks;
	int ssid;
	struct list_head *csets;
	struct css_set___65 *cur_cset;
	struct task_struct___82 *cur_task;
};

struct css_task_iter {
	struct cgroup_subsys___65 *ss;
	unsigned int flags;
	struct list_head *cset_pos;
	struct list_head *cset_head;
	struct list_head *tcset_pos;
	struct list_head *tcset_head;
	struct list_head *task_pos;
	struct list_head *tasks_head;
	struct list_head *mg_tasks_head;
	struct css_set___65 *cur_cset;
	struct css_set___65 *cur_dcset;
	struct task_struct___82 *cur_task;
	struct list_head iters_node;
};

struct cgrp_cset_link {
	struct cgroup___65 *cgrp;
	struct css_set___65 *cset;
	struct list_head cset_link;
	struct list_head cgrp_link;
};

struct cgroup_mgctx {
	struct list_head preloaded_src_csets;
	struct list_head preloaded_dst_csets;
	struct cgroup_taskset___2 tset;
	u16 ss_mask;
};

struct cgroup_sb_opts {
	u16 subsys_mask;
	unsigned int flags;
	char *release_agent;
	bool cpuset_clone_children;
	char *name;
	bool none;
};

struct kobj_attribute___79 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___79 *, struct kobj_attribute___79 *, char *);
	ssize_t (*store)(struct kobject___79 *, struct kobj_attribute___79 *, const char *, size_t);
};

typedef void compound_page_dtor___81(struct page___82 *);

struct kobj_ns_type_operations___3 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___6 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct proto___3;

struct sock_common___3 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___3 *skc_prot;
	possible_net_t___7 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___6 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff_head___8 {
	struct sk_buff___11 *next;
	struct sk_buff___11 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___3;

struct socket_wq___3;

struct socket___3;

struct sock___6 {
	struct sock_common___3 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___8 sk_error_queue;
	struct sk_buff_head___8 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___11 *head;
		struct sk_buff___11 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___3 *sk_filter;
	union {
		struct socket_wq___3 *sk_wq;
		struct socket_wq___3 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___5 *sk_rx_dst;
	struct dst_entry___5 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___11 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___8 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___81 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___3 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___69 *sk_peer_pid;
	const struct cred___78 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___3 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___31 *sk_memcg;
	void (*sk_state_change)(struct sock___6 *);
	void (*sk_data_ready)(struct sock___6 *);
	void (*sk_write_space)(struct sock___6 *);
	void (*sk_error_report)(struct sock___6 *);
	int (*sk_backlog_rcv)(struct sock___6 *, struct sk_buff___11 *);
	struct sk_buff___11 * (*sk_validate_xmit_skb)(struct sock___6 *, struct net_device___12 *, struct sk_buff___11 *);
	void (*sk_destruct)(struct sock___6 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct bin_attribute___76;

struct attribute_group___76 {
	const char *name;
	umode_t (*is_visible)(struct kobject___79 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___79 *, struct bin_attribute___76 *, int);
	struct attribute **attrs;
	struct bin_attribute___76 **bin_attrs;
};

struct bin_attribute___76 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___82 *, struct kobject___79 *, struct bin_attribute___76 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___82 *, struct kobject___79 *, struct bin_attribute___76 *, char *, loff_t, size_t);
	int (*mmap)(struct file___82 *, struct kobject___79 *, struct bin_attribute___76 *, struct vm_area_struct___82 *);
};

struct sysfs_ops___78 {
	ssize_t (*show)(struct kobject___79 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___79 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___78;

struct kset___78 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___79 kobj;
	const struct kset_uevent_ops___78 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___78 {
	void (*release)(struct kobject___79 *);
	const struct sysfs_ops___78 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___3 * (*child_ns_type)(struct kobject___79 *);
	const void * (*namespace)(struct kobject___79 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___78 {
	int (* const filter)(struct kset___78 *, struct kobject___79 *);
	const char * (* const name)(struct kset___78 *, struct kobject___79 *);
	int (* const uevent)(struct kset___78 *, struct kobject___79 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___71 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___71 *);
	int (*get)(char *, const struct kernel_param___71 *);
	void (*free)(void *);
};

struct kparam_array___71;

struct kernel_param___71 {
	const char *name;
	struct module___74 *mod;
	const struct kernel_param_ops___71 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___71 *arr;
	};
};

struct kparam_array___71 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___71 *ops;
	void *elem;
};

struct module_attribute___71 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___71 *, struct module_kobject___71 *, char *);
	ssize_t (*store)(struct module_attribute___71 *, struct module_kobject___71 *, const char *, size_t);
	void (*setup)(struct module___74 *, const char *);
	int (*test)(struct module___74 *);
	void (*free)(struct module___74 *);
};

struct trace_event_class___48;

struct trace_event_call___48 {
	struct list_head list;
	struct trace_event_class___48 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___6 *prog_array;
	int (*perf_perm)(struct trace_event_call___48 *, struct perf_event___53 *);
};

struct msghdr___3 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___33 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___82 *msg_iocb;
};

struct inet_frag_queue___7;

struct inet_frags___7 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___7 *, const void *);
	void (*destructor)(struct inet_frag_queue___7 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___7 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___11 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___11 *fragments_tail;
	struct sk_buff___11 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___7 *net;
	struct callback_head rcu;
};

struct nf_bridge_info___7;

struct sk_buff___11 {
	union {
		struct {
			struct sk_buff___11 *next;
			struct sk_buff___11 *prev;
			union {
				struct net_device___12 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___6 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___11 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___7 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct fib_rule___3;

struct fib_lookup_arg___3;

struct fib_rules_ops___3 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___3 *, struct flowi *, int, struct fib_lookup_arg___3 *);
	bool (*suppress)(struct fib_rule___3 *, struct fib_lookup_arg___3 *);
	int (*match)(struct fib_rule___3 *, struct flowi *, int);
	int (*configure)(struct fib_rule___3 *, struct sk_buff___11 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___3 *);
	int (*compare)(struct fib_rule___3 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___3 *, struct sk_buff___11 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___3 *);
	void (*flush_cache)(struct fib_rules_ops___3 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___74 *owner;
	struct net___16 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___3 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___16 *);
	int (*fib_dump)(struct net___16 *, struct notifier_block *);
	struct module___74 *owner;
	struct callback_head rcu;
};

struct dst_entry___5 {
	struct net_device___12 *dev;
	struct dst_ops___14 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___11 *);
	int (*output)(struct net___16 *, struct sock___6 *, struct sk_buff___11 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___4;

struct neigh_parms___5;

struct neigh_ops___4;

struct neighbour___5 {
	struct neighbour___5 *next;
	struct neigh_table___4 *tbl;
	struct neigh_parms___5 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___8 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___5 *, struct sk_buff___11 *);
	const struct neigh_ops___4 *ops;
	struct callback_head rcu;
	struct net_device___12 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct socket_wq___3 {
	wait_queue_head_t wait;
	struct fasync_struct___81 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___3;

struct socket___3 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___3 *wq;
	struct file___82 *file;
	struct sock___6 *sk;
	const struct proto_ops___3 *ops;
};

typedef int (*sk_read_actor_t___3)(read_descriptor_t *, struct sk_buff___11 *, unsigned int, size_t);

struct proto_ops___3 {
	int family;
	struct module___74 *owner;
	int (*release)(struct socket___3 *);
	int (*bind)(struct socket___3 *, struct sockaddr *, int);
	int (*connect)(struct socket___3 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___3 *, struct socket___3 *);
	int (*accept)(struct socket___3 *, struct socket___3 *, int, bool);
	int (*getname)(struct socket___3 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___82 *, struct socket___3 *, struct poll_table_struct___56 *);
	int (*ioctl)(struct socket___3 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___3 *, int);
	int (*shutdown)(struct socket___3 *, int);
	int (*setsockopt)(struct socket___3 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___3 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___3 *, struct msghdr___3 *, size_t);
	int (*recvmsg)(struct socket___3 *, struct msghdr___3 *, size_t, int);
	int (*mmap)(struct file___82 *, struct socket___3 *, struct vm_area_struct___82 *);
	ssize_t (*sendpage)(struct socket___3 *, struct page___82 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___3 *, loff_t *, struct pipe_inode_info___15 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___6 *, int);
	int (*peek_len)(struct socket___3 *);
	int (*read_sock)(struct sock___6 *, read_descriptor_t *, sk_read_actor_t___3);
	int (*sendpage_locked)(struct sock___6 *, struct page___82 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___6 *, struct msghdr___3 *, size_t);
	int (*set_rcvlowat)(struct sock___6 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct dev_pm_ops___77 {
	int (*prepare)(struct device___77 *);
	void (*complete)(struct device___77 *);
	int (*suspend)(struct device___77 *);
	int (*resume)(struct device___77 *);
	int (*freeze)(struct device___77 *);
	int (*thaw)(struct device___77 *);
	int (*poweroff)(struct device___77 *);
	int (*restore)(struct device___77 *);
	int (*suspend_late)(struct device___77 *);
	int (*resume_early)(struct device___77 *);
	int (*freeze_late)(struct device___77 *);
	int (*thaw_early)(struct device___77 *);
	int (*poweroff_late)(struct device___77 *);
	int (*restore_early)(struct device___77 *);
	int (*suspend_noirq)(struct device___77 *);
	int (*resume_noirq)(struct device___77 *);
	int (*freeze_noirq)(struct device___77 *);
	int (*thaw_noirq)(struct device___77 *);
	int (*poweroff_noirq)(struct device___77 *);
	int (*restore_noirq)(struct device___77 *);
	int (*runtime_suspend)(struct device___77 *);
	int (*runtime_resume)(struct device___77 *);
	int (*runtime_idle)(struct device___77 *);
};

struct dev_pm_domain___77 {
	struct dev_pm_ops___77 ops;
	void (*detach)(struct device___77 *, bool);
	int (*activate)(struct device___77 *);
	void (*sync)(struct device___77 *);
	void (*dismiss)(struct device___77 *);
};

struct bus_type___77 {
	const char *name;
	const char *dev_name;
	struct device___77 *dev_root;
	const struct attribute_group___76 **bus_groups;
	const struct attribute_group___76 **dev_groups;
	const struct attribute_group___76 **drv_groups;
	int (*match)(struct device___77 *, struct device_driver___77 *);
	int (*uevent)(struct device___77 *, struct kobj_uevent_env *);
	int (*probe)(struct device___77 *);
	int (*remove)(struct device___77 *);
	void (*shutdown)(struct device___77 *);
	int (*online)(struct device___77 *);
	int (*offline)(struct device___77 *);
	int (*suspend)(struct device___77 *, pm_message_t);
	int (*resume)(struct device___77 *);
	int (*num_vf)(struct device___77 *);
	int (*dma_configure)(struct device___77 *);
	const struct dev_pm_ops___77 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___77 {
	const char *name;
	struct bus_type___77 *bus;
	struct module___74 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___77 *);
	int (*remove)(struct device___77 *);
	void (*shutdown)(struct device___77 *);
	int (*suspend)(struct device___77 *, pm_message_t);
	int (*resume)(struct device___77 *);
	const struct attribute_group___76 **groups;
	const struct dev_pm_ops___77 *pm;
	void (*coredump)(struct device___77 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___77 {
	const char *name;
	const struct attribute_group___76 **groups;
	int (*uevent)(struct device___77 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___77 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___77 *);
	const struct dev_pm_ops___77 *pm;
};

struct class___77 {
	const char *name;
	struct module___74 *owner;
	const struct attribute_group___76 **class_groups;
	const struct attribute_group___76 **dev_groups;
	struct kobject___79 *dev_kobj;
	int (*dev_uevent)(struct device___77 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___77 *, umode_t *);
	void (*class_release)(struct class___77 *);
	void (*dev_release)(struct device___77 *);
	int (*shutdown_pre)(struct device___77 *);
	const struct kobj_ns_type_operations___3 *ns_type;
	const void * (*namespace)(struct device___77 *);
	const struct dev_pm_ops___77 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___20 {
	void * (*alloc)(struct device___77 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___77 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___77 *, struct vm_area_struct___82 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___77 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___77 *, struct page___82 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___77 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___77 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___77 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___77 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___77 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___77 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___77 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___77 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___77 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___77 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___77 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___77 *, u64);
	u64 (*get_required_mask)(struct device___77 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___56;

struct fwnode_handle___56 {
	struct fwnode_handle___56 *secondary;
	const struct fwnode_operations___56 *ops;
};

struct fwnode_reference_args___56;

struct fwnode_endpoint___56;

struct fwnode_operations___56 {
	struct fwnode_handle___56 * (*get)(struct fwnode_handle___56 *);
	void (*put)(struct fwnode_handle___56 *);
	bool (*device_is_available)(const struct fwnode_handle___56 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___56 *, const struct device___77 *);
	bool (*property_present)(const struct fwnode_handle___56 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___56 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___56 *, const char *, const char **, size_t);
	struct fwnode_handle___56 * (*get_parent)(const struct fwnode_handle___56 *);
	struct fwnode_handle___56 * (*get_next_child_node)(const struct fwnode_handle___56 *, struct fwnode_handle___56 *);
	struct fwnode_handle___56 * (*get_named_child_node)(const struct fwnode_handle___56 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___56 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___56 *);
	struct fwnode_handle___56 * (*graph_get_next_endpoint)(const struct fwnode_handle___56 *, struct fwnode_handle___56 *);
	struct fwnode_handle___56 * (*graph_get_remote_endpoint)(const struct fwnode_handle___56 *);
	struct fwnode_handle___56 * (*graph_get_port_parent)(struct fwnode_handle___56 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___56 *, struct fwnode_endpoint___56 *);
};

struct fwnode_endpoint___56 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___56 *local_fwnode;
};

struct fwnode_reference_args___56 {
	struct fwnode_handle___56 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___15;

struct pipe_buffer___15 {
	struct page___82 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___15 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___15 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___15 *, struct pipe_buffer___15 *);
	void (*release)(struct pipe_inode_info___15 *, struct pipe_buffer___15 *);
	int (*steal)(struct pipe_inode_info___15 *, struct pipe_buffer___15 *);
	union {
		bool (*get)(struct pipe_inode_info___15 *, struct pipe_buffer___15 *);
		struct {
			void (*get)(struct pipe_inode_info___15 *, struct pipe_buffer___15 *);
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
};

struct nf_bridge_info___7 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___7 = 0,
		BRNF_PROTO_8021Q___7 = 1,
		BRNF_PROTO_PPPOE___7 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___12 *physindev;
	struct net_device___12 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

struct pernet_operations___7 {
	struct list_head list;
	int (*init)(struct net___16 *);
	void (*exit)(struct net___16 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

typedef struct poll_table_struct___56 poll_table___5;

struct ethtool_ops___7 {
	int (*get_settings)(struct net_device___12 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___12 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___12 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___12 *);
	void (*get_regs)(struct net_device___12 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___12 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___12 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___12 *);
	void (*set_msglevel)(struct net_device___12 *, u32);
	int (*nway_reset)(struct net_device___12 *);
	u32 (*get_link)(struct net_device___12 *);
	int (*get_eeprom_len)(struct net_device___12 *);
	int (*get_eeprom)(struct net_device___12 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___12 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___12 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___12 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___12 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___12 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___12 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___12 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___12 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___12 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___12 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___12 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___12 *);
	void (*complete)(struct net_device___12 *);
	u32 (*get_priv_flags)(struct net_device___12 *);
	int (*set_priv_flags)(struct net_device___12 *, u32);
	int (*get_sset_count)(struct net_device___12 *, int);
	int (*get_rxnfc)(struct net_device___12 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___12 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___12 *, struct ethtool_flash *);
	int (*reset)(struct net_device___12 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___12 *);
	u32 (*get_rxfh_indir_size)(struct net_device___12 *);
	int (*get_rxfh)(struct net_device___12 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___12 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___12 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___12 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___12 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___12 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___12 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___12 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___12 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___12 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___12 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___12 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___12 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___12 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___12 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___12 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___12 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___12 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___12 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___12 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___12 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___12 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	int (*get_fecparam)(struct net_device___12 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___12 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___12 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___12 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___12 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct dcbnl_rtnl_ops___7 {
	int (*ieee_getets)(struct net_device___12 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___12 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___12 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___12 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___12 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___12 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___12 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___12 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___12 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___12 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___12 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___12 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___12 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___12 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___12 *);
	u8 (*setstate)(struct net_device___12 *, u8);
	void (*getpermhwaddr)(struct net_device___12 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___12 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___12 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___12 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___12 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___12 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___12 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___12 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___12 *, int, u8 *);
	void (*setpfccfg)(struct net_device___12 *, int, u8);
	void (*getpfccfg)(struct net_device___12 *, int, u8 *);
	u8 (*setall)(struct net_device___12 *);
	u8 (*getcap)(struct net_device___12 *, int, u8 *);
	int (*getnumtcs)(struct net_device___12 *, int, u8 *);
	int (*setnumtcs)(struct net_device___12 *, int, u8);
	u8 (*getpfcstate)(struct net_device___12 *);
	void (*setpfcstate)(struct net_device___12 *, u8);
	void (*getbcncfg)(struct net_device___12 *, int, u32 *);
	void (*setbcncfg)(struct net_device___12 *, int, u32);
	void (*getbcnrp)(struct net_device___12 *, int, u8 *);
	void (*setbcnrp)(struct net_device___12 *, int, u8);
	int (*setapp)(struct net_device___12 *, u8, u16, u8);
	int (*getapp)(struct net_device___12 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___12 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___12 *, int, u8);
	u8 (*getdcbx)(struct net_device___12 *);
	u8 (*setdcbx)(struct net_device___12 *, u8);
	int (*peer_getappinfo)(struct net_device___12 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___12 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___12 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___12 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___12 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___12 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct xdp_rxq_info___7 {
	struct net_device___12 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___7 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___12 *dev_rx;
};

struct netlink_callback___7 {
	struct sk_buff___11 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___7 *);
	int (*dump)(struct sk_buff___11 *, struct netlink_callback___7 *);
	int (*done)(struct netlink_callback___7 *);
	void *data;
	struct module___74 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___7 {
	int (*create)(struct sk_buff___11 *, struct net_device___12 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___11 *, unsigned char *);
	int (*cache)(const struct neighbour___5 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___12 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___7 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___7 *, int);
	int poll_owner;
	struct net_device___12 *dev;
	struct sk_buff___11 *gro_list;
	struct sk_buff___11 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___7 {
	struct net_device___12 *dev;
	struct Qdisc___6 *qdisc;
	struct Qdisc___6 *qdisc_sleeping;
	struct kobject___79 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___12 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___6 {
	struct sk_buff___11 *head;
	struct sk_buff___11 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___6;

struct Qdisc___6 {
	int (*enqueue)(struct sk_buff___11 *, struct Qdisc___6 *, struct sk_buff___11 **);
	struct sk_buff___11 * (*dequeue)(struct Qdisc___6 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___6 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___7 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___8 gso_skb;
	struct qdisc_skb_head___6 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___6 *next_sched;
	struct sk_buff_head___8 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___7 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___79 kobj;
	struct net_device___12 *dev;
	long: 64;
	struct xdp_rxq_info___7 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___7)(struct net_device___12 *, struct sk_buff___11 *, struct net_device___12 *);

struct netdev_bpf___7 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___6 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___6 *prog;
			const struct bpf_prog_offload_ops___6 *ops;
		} verifier;
		struct {
			struct bpf_prog___6 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___7 *offmap;
		};
		struct {
			struct xdp_umem *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___7 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___11 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___7 {
	int (*tls_dev_add)(struct net_device___12 *, struct sock___6 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___12 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___12 *, struct sock___6 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___7 {
	int (*ndo_init)(struct net_device___12 *);
	void (*ndo_uninit)(struct net_device___12 *);
	int (*ndo_open)(struct net_device___12 *);
	int (*ndo_stop)(struct net_device___12 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___11 *, struct net_device___12 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___11 *, struct net_device___12 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___12 *, struct sk_buff___11 *, struct net_device___12 *, select_queue_fallback_t___7);
	void (*ndo_change_rx_flags)(struct net_device___12 *, int);
	void (*ndo_set_rx_mode)(struct net_device___12 *);
	int (*ndo_set_mac_address)(struct net_device___12 *, void *);
	int (*ndo_validate_addr)(struct net_device___12 *);
	int (*ndo_do_ioctl)(struct net_device___12 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___12 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___12 *, int);
	int (*ndo_neigh_setup)(struct net_device___12 *, struct neigh_parms___5 *);
	void (*ndo_tx_timeout)(struct net_device___12 *);
	void (*ndo_get_stats64)(struct net_device___12 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___12 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___12 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___12 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___12 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___12 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___12 *);
	int (*ndo_netpoll_setup)(struct net_device___12 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___12 *);
	int (*ndo_set_vf_mac)(struct net_device___12 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___12 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___12 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___12 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___12 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___12 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___12 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___12 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___12 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___12 *, int, struct sk_buff___11 *);
	int (*ndo_set_vf_guid)(struct net_device___12 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___12 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___12 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___12 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___12 *, const struct sk_buff___11 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___12 *, struct net_device___12 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___12 *, struct net_device___12 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___12 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___12 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___12 *, struct neighbour___5 *);
	void (*ndo_neigh_destroy)(struct net_device___12 *, struct neighbour___5 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___12 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___12 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___12 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___11 *, struct netlink_callback___7 *, struct net_device___12 *, struct net_device___12 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___12 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___12 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___11 *, u32, u32, struct net_device___12 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___12 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___12 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___12 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___12 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___12 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___12 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___12 *, struct net_device___12 *);
	void (*ndo_dfwd_del_station)(struct net_device___12 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___12 *);
	int (*ndo_set_tx_maxrate)(struct net_device___12 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___12 *);
	int (*ndo_change_proto_down)(struct net_device___12 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___12 *, struct sk_buff___11 *);
	void (*ndo_set_rx_headroom)(struct net_device___12 *, int);
	int (*ndo_bpf)(struct net_device___12 *, struct netdev_bpf___7 *);
	int (*ndo_xdp_xmit)(struct net_device___12 *, int, struct xdp_frame___7 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___12 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___12 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___5 {
	possible_net_t___7 net;
	struct net_device___12 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___5 *);
	void (*neigh_cleanup)(struct neighbour___5 *);
	struct neigh_table___4 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___4 {
	u32 (*l3mdev_fib_table)(const struct net_device___12 *);
	struct sk_buff___11 * (*l3mdev_l3_rcv)(struct net_device___12 *, struct sk_buff___11 *, u16);
	struct sk_buff___11 * (*l3mdev_l3_out)(struct net_device___12 *, struct sock___6 *, struct sk_buff___11 *, u16);
	struct dst_entry___5 * (*l3mdev_link_scope_lookup)(const struct net_device___12 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct tcf_proto___6;

struct mini_Qdisc___6 {
	struct tcf_proto___6 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___6 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___12 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___16 *, struct net_device___12 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___12 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___12 *, struct list_head *);
	size_t (*get_size)(const struct net_device___12 *);
	int (*fill_info)(struct sk_buff___11 *, const struct net_device___12 *);
	size_t (*get_xstats_size)(const struct net_device___12 *);
	int (*fill_xstats)(struct sk_buff___11 *, const struct net_device___12 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___12 *, struct net_device___12 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___12 *, const struct net_device___12 *);
	int (*fill_slave_info)(struct sk_buff___11 *, const struct net_device___12 *, const struct net_device___12 *);
	struct net___16 * (*get_link_net)(const struct net_device___12 *);
	size_t (*get_linkxstats_size)(const struct net_device___12 *, int);
	int (*fill_linkxstats)(struct sk_buff___11 *, const struct net_device___12 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___7 {
	struct list_head poll_list;
	struct sk_buff_head___8 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___7 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___6 *output_queue;
	struct Qdisc___6 **output_queue_tailp;
	struct sk_buff___11 *completion_queue;
	struct sk_buff_head___8 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___7 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___8 input_pkt_queue;
	struct napi_struct___7 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bdi_writeback_congested___33 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___33 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___33 {
	struct bio___33 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___33 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___33 bip_inline_vecs[0];
};

struct bio_set___33 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___33 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___31 {
	struct mem_cgroup___31 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___31 {
	struct lruvec___81 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___31 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___31 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct gnet_dump___6 {
	spinlock_t *lock;
	struct sk_buff___11 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___6;

struct Qdisc_ops___6 {
	struct Qdisc_ops___6 *next;
	const struct Qdisc_class_ops___6 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___11 *, struct Qdisc___6 *, struct sk_buff___11 **);
	struct sk_buff___11 * (*dequeue)(struct Qdisc___6 *);
	struct sk_buff___11 * (*peek)(struct Qdisc___6 *);
	int (*init)(struct Qdisc___6 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___6 *);
	void (*destroy)(struct Qdisc___6 *);
	int (*change)(struct Qdisc___6 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___6 *);
	int (*change_tx_queue_len)(struct Qdisc___6 *, unsigned int);
	int (*dump)(struct Qdisc___6 *, struct sk_buff___11 *);
	int (*dump_stats)(struct Qdisc___6 *, struct gnet_dump___6 *);
	void (*ingress_block_set)(struct Qdisc___6 *, u32);
	void (*egress_block_set)(struct Qdisc___6 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___6 *);
	u32 (*egress_block_get)(struct Qdisc___6 *);
	struct module___74 *owner;
};

struct tcf_block___6;

struct Qdisc_class_ops___6 {
	unsigned int flags;
	struct netdev_queue___7 * (*select_queue)(struct Qdisc___6 *, struct tcmsg *);
	int (*graft)(struct Qdisc___6 *, long unsigned int, struct Qdisc___6 *, struct Qdisc___6 **, struct netlink_ext_ack *);
	struct Qdisc___6 * (*leaf)(struct Qdisc___6 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___6 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___6 *, u32);
	int (*change)(struct Qdisc___6 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___6 *, long unsigned int);
	void (*walk)(struct Qdisc___6 *, struct qdisc_walker *);
	struct tcf_block___6 * (*tcf_block)(struct Qdisc___6 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___6 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___6 *, long unsigned int);
	int (*dump)(struct Qdisc___6 *, long unsigned int, struct sk_buff___11 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___6 *, long unsigned int, struct gnet_dump___6 *);
};

struct tcf_chain___6;

struct tcf_block___6 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___16 *net;
	struct Qdisc___6 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___6 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___6;

struct tcf_proto_ops___6;

struct tcf_proto___6 {
	struct tcf_proto___6 *next;
	void *root;
	int (*classify)(struct sk_buff___11 *, const struct tcf_proto___6 *, struct tcf_result___6 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___6 *ops;
	struct tcf_chain___6 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___6 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___6 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___6 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___11 *, const struct tcf_proto___6 *, struct tcf_result___6 *);
	int (*init)(struct tcf_proto___6 *);
	void (*destroy)(struct tcf_proto___6 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___6 *, u32);
	void (*put)(struct tcf_proto___6 *, void *);
	int (*change)(struct net___16 *, struct sk_buff___11 *, struct tcf_proto___6 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___6 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___6 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___6 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___16 *, struct tcf_chain___6 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___16 *, struct tcf_proto___6 *, void *, struct sk_buff___11 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___11 *, struct net___16 *, void *);
	struct module___74 *owner;
	int flags;
};

struct tcf_chain___6 {
	struct mutex filter_chain_lock;
	struct tcf_proto___6 *filter_chain;
	struct list_head list;
	struct tcf_block___6 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___6 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___3 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___6 *prog;
};

struct bpf_redirect_info___6 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___65 *map;
	struct bpf_map___65 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___3;

struct neigh_hash_table___3;

struct neigh_table___4 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___12 *, __u32 *);
	bool (*key_eq)(const struct neighbour___5 *, const void *);
	int (*constructor)(struct neighbour___5 *);
	int (*pconstructor)(struct pneigh_entry___3 *);
	void (*pdestructor)(struct pneigh_entry___3 *);
	void (*proxy_redo)(struct sk_buff___11 *);
	char *id;
	struct neigh_parms___5 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___8 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___3 *nht;
	struct pneigh_entry___3 **phash_buckets;
};

struct neigh_ops___4 {
	int family;
	void (*solicit)(struct neighbour___5 *, struct sk_buff___11 *);
	void (*error_report)(struct neighbour___5 *, struct sk_buff___11 *);
	int (*output)(struct neighbour___5 *, struct sk_buff___11 *);
	int (*connected_output)(struct neighbour___5 *, struct sk_buff___11 *);
};

struct pneigh_entry___3 {
	struct pneigh_entry___3 *next;
	possible_net_t___7 net;
	struct net_device___12 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___3 {
	struct neighbour___5 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___3 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___3 *ctarget;
	struct net___16 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___3 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___3 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___3;

struct timewait_sock_ops___3;

struct proto___3 {
	void (*close)(struct sock___6 *, long int);
	int (*pre_connect)(struct sock___6 *, struct sockaddr *, int);
	int (*connect)(struct sock___6 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___6 *, int);
	struct sock___6 * (*accept)(struct sock___6 *, int, int *, bool);
	int (*ioctl)(struct sock___6 *, int, long unsigned int);
	int (*init)(struct sock___6 *);
	void (*destroy)(struct sock___6 *);
	void (*shutdown)(struct sock___6 *, int);
	int (*setsockopt)(struct sock___6 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___6 *, int, int, char *, int *);
	void (*keepalive)(struct sock___6 *, int);
	int (*sendmsg)(struct sock___6 *, struct msghdr___3 *, size_t);
	int (*recvmsg)(struct sock___6 *, struct msghdr___3 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___6 *, struct page___82 *, int, size_t, int);
	int (*bind)(struct sock___6 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___6 *, struct sk_buff___11 *);
	void (*release_cb)(struct sock___6 *);
	int (*hash)(struct sock___6 *);
	void (*unhash)(struct sock___6 *);
	void (*rehash)(struct sock___6 *);
	int (*get_port)(struct sock___6 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___6 *);
	bool (*stream_memory_read)(const struct sock___6 *);
	void (*enter_memory_pressure)(struct sock___6 *);
	void (*leave_memory_pressure)(struct sock___6 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___3 *rsk_prot;
	struct timewait_sock_ops___3 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___74 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___6 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct node___67 {
	struct device___77 dev;
};

struct perf_cpu_context___53;

struct pmu___53 {
	struct list_head entry;
	struct module___74 *module;
	struct device___77 *dev;
	const struct attribute_group___76 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___53 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___53 *);
	void (*pmu_disable)(struct pmu___53 *);
	int (*event_init)(struct perf_event___53 *);
	void (*event_mapped)(struct perf_event___53 *, struct mm_struct___81 *);
	void (*event_unmapped)(struct perf_event___53 *, struct mm_struct___81 *);
	int (*add)(struct perf_event___53 *, int);
	void (*del)(struct perf_event___53 *, int);
	void (*start)(struct perf_event___53 *, int);
	void (*stop)(struct perf_event___53 *, int);
	void (*read)(struct perf_event___53 *);
	void (*start_txn)(struct pmu___53 *, unsigned int);
	int (*commit_txn)(struct pmu___53 *);
	void (*cancel_txn)(struct pmu___53 *);
	int (*event_idx)(struct perf_event___53 *);
	void (*sched_task)(struct perf_event_context___53 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___53 *);
	int (*filter_match)(struct perf_event___53 *);
	int (*check_period)(struct perf_event___53 *, u64);
};

struct perf_cpu_context___53 {
	struct perf_event_context___53 ctx;
	struct perf_event_context___53 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___53 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___53 {
	struct cgroup_subsys_state___65 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___48 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___48 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___48 *);
	struct list_head * (*get_fields)(struct trace_event_call___48 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___48 *);
};

struct trace_event_file___17;

struct trace_event_buffer___17 {
	struct ring_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___17 *trace_file;
	void *entry;
	long unsigned int flags;
	int pc;
};

struct trace_event_file___17 {
	struct list_head list;
	struct trace_event_call___48 *event_call;
	struct event_filter *filter;
	struct dentry___82 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_cgroup_root {
	struct trace_entry ent;
	int root;
	u16 ss_mask;
	u32 __data_loc_name;
	char __data[0];
};

struct trace_event_raw_cgroup {
	struct trace_entry ent;
	int root;
	int id;
	int level;
	u32 __data_loc_path;
	char __data[0];
};

struct trace_event_raw_cgroup_migrate {
	struct trace_entry ent;
	int dst_root;
	int dst_id;
	int dst_level;
	int pid;
	u32 __data_loc_dst_path;
	u32 __data_loc_comm;
	char __data[0];
};

struct trace_event_raw_cgroup_event {
	struct trace_entry ent;
	int root;
	int id;
	int level;
	u32 __data_loc_path;
	int val;
	char __data[0];
};

struct trace_event_data_offsets_cgroup_root {
	u32 name;
};

struct trace_event_data_offsets_cgroup {
	u32 path;
};

struct trace_event_data_offsets_cgroup_migrate {
	u32 dst_path;
	u32 comm;
};

struct trace_event_data_offsets_cgroup_event {
	u32 path;
};

struct file___83;

struct kiocb___83;

struct vm_area_struct___83;

struct inode___84;

struct file_lock___83;

struct page___83;

struct seq_file___77;

struct file_operations___83 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___83 *, loff_t, int);
	ssize_t (*read)(struct file___83 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___83 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___83 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___83 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___83 *, bool);
	int (*iterate)(struct file___83 *, struct dir_context *);
	int (*iterate_shared)(struct file___83 *, struct dir_context *);
	__poll_t (*poll)(struct file___83 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___83 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___83 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___83 *, struct vm_area_struct___83 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___84 *, struct file___83 *);
	int (*flush)(struct file___83 *, fl_owner_t);
	int (*release)(struct inode___84 *, struct file___83 *);
	int (*fsync)(struct file___83 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___83 *, int);
	int (*lock)(struct file___83 *, int, struct file_lock___83 *);
	ssize_t (*sendpage)(struct file___83 *, struct page___83 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___83 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___83 *, int, struct file_lock___83 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___83 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___83 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___83 *, long int, struct file_lock___83 **, void **);
	long int (*fallocate)(struct file___83 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___77 *, struct file___83 *);
	ssize_t (*copy_file_range)(struct file___83 *, loff_t, struct file___83 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___83 *, loff_t, struct file___83 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___83 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___82 {
	u64 seqnum;
	struct vm_area_struct___83 *vmas[4];
};

struct page_frag___82 {
	struct page___83 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___82;

struct cred___79;

struct nsproxy___77;

struct signal_struct___73;

struct css_set___66;

struct task_struct___83 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___83 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___82 *mm;
	struct mm_struct___82 *active_mm;
	struct vmacache___82 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___83 *real_parent;
	struct task_struct___83 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___83 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___69 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___69 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___69 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___79 *ptracer_cred;
	const struct cred___79 *real_cred;
	const struct cred___79 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___77 *nsproxy;
	struct signal_struct___73 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___83 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___14 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___66 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___82 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___83 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___53 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rw_semaphore___83 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___83 *owner;
};

struct key___80;

struct ucounts___68;

struct user_namespace___68 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___68 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___5 ns;
	long unsigned int flags;
	struct key___80 *persistent_keyring_register;
	struct rw_semaphore___83 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___68 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct secondary_data___83 {
	void *stack;
	struct task_struct___83 *task;
	long int status;
};

typedef struct page___83 *pgtable_t___82;

struct address_space___82;

struct page___83 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___82 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___83 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___82 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___82 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___81 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct user_struct___79 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___80 *uid_keyring;
	struct key___80 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_area_struct___83 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___83 *vm_next;
	struct vm_area_struct___83 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___82 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___13 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___83 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___82;

struct mm_struct___82 {
	struct {
		struct vm_area_struct___83 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___83 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___83 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___82 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___83 *owner;
		struct user_namespace___68 *user_ns;
		struct file___83 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___82 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___79 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___80 *session_keyring;
	struct key___80 *process_keyring;
	struct key___80 *thread_keyring;
	struct key___80 *request_key_auth;
	void *security;
	struct user_struct___79 *user;
	struct user_namespace___68 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___66;

struct nsproxy___77 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___66 *cgroup_ns;
};

struct signal_struct___73 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___83 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___83 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___69 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___69 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___82 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___69 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___66;

struct cgroup___66;

struct css_set___66 {
	struct cgroup_subsys_state___66 *subsys[13];
	refcount_t refcount;
	struct css_set___66 *dom_cset;
	struct cgroup___66 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___66 *mg_src_cgrp;
	struct cgroup___66 *mg_dst_cgrp;
	struct css_set___66 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

union thread_union___73 {
	struct task_struct___83 task;
	long unsigned int stack[8192];
};

struct dentry_operations___82;

struct super_block___83;

struct dentry___83 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___83 *d_parent;
	struct qstr d_name;
	struct inode___84 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___82 *d_op;
	struct super_block___83 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___82;

struct address_space___82 {
	struct inode___84 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___83 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___82 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___82;

struct block_device___83;

struct inode___84 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___82 *i_op;
	struct super_block___83 *i_sb;
	struct address_space___82 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___83 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___83 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___82 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___83 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___82;

struct dentry_operations___82 {
	int (*d_revalidate)(struct dentry___83 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___83 *, unsigned int);
	int (*d_hash)(const struct dentry___83 *, struct qstr *);
	int (*d_compare)(const struct dentry___83 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___83 *);
	int (*d_init)(struct dentry___83 *);
	void (*d_release)(struct dentry___83 *);
	void (*d_prune)(struct dentry___83 *);
	void (*d_iput)(struct dentry___83 *, struct inode___84 *);
	char * (*d_dname)(struct dentry___83 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___82 *);
	int (*d_manage)(const struct path___82 *, bool);
	struct dentry___83 * (*d_real)(struct dentry___83 *, const struct inode___84 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___82;

struct mem_dqinfo___82 {
	struct quota_format_type___82 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___82;

struct quota_info___82 {
	unsigned int flags;
	struct rw_semaphore___83 dqio_sem;
	struct inode___84 *files[3];
	struct mem_dqinfo___82 info[3];
	const struct quota_format_ops___82 *ops[3];
};

struct rcuwait___82 {
	struct task_struct___83 *task;
};

struct percpu_rw_semaphore___82 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___83 rw_sem;
	struct rcuwait___82 writer;
	int readers_block;
};

struct sb_writers___82 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___82 rw_sem[3];
};

struct file_system_type___82;

struct super_operations___82;

struct dquot_operations___82;

struct quotactl_ops___82;

struct super_block___83 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___82 *s_type;
	const struct super_operations___82 *s_op;
	const struct dquot_operations___82 *dq_op;
	const struct quotactl_ops___82 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___83 *s_root;
	struct rw_semaphore___83 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___83 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___82 s_dquot;
	struct sb_writers___82 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___82 *s_d_op;
	int cleancache_poolid;
	struct shrinker___31 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___68 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct path___82 {
	struct vfsmount *mnt;
	struct dentry___83 *dentry;
};

struct pglist_data___82;

struct lruvec___82 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___82 *pgdat;
};

struct zone___82 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___82 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___82 {
	struct zone___82 *zone;
	int zone_idx;
};

struct zonelist___82 {
	struct zoneref___82 _zonerefs[25];
};

struct pglist_data___82 {
	struct zone___82 node_zones[3];
	struct zonelist___82 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___83 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___83 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___82 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___82 {
	struct rw_semaphore___83 rwsem;
	struct notifier_block *head;
};

struct file___83 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___82 f_path;
	struct inode___84 *f_inode;
	const struct file_operations___83 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___69 f_owner;
	const struct cred___79 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___82 *f_mapping;
	errseq_t f_wb_err;
};

struct core_thread___82 {
	struct task_struct___83 *task;
	struct core_thread___82 *next;
};

struct core_state___82 {
	atomic_t nr_threads;
	struct core_thread___82 dumper;
	struct completion startup;
};

struct kiocb___83 {
	struct file___83 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___83 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___83 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___83 *ia_file;
};

struct dquot___82 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___83 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___82 {
	int qf_fmt_id;
	const struct quota_format_ops___82 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___82 *qf_next;
};

struct quota_format_ops___82 {
	int (*check_quota_file)(struct super_block___83 *, int);
	int (*read_file_info)(struct super_block___83 *, int);
	int (*write_file_info)(struct super_block___83 *, int);
	int (*free_file_info)(struct super_block___83 *, int);
	int (*read_dqblk)(struct dquot___82 *);
	int (*commit_dqblk)(struct dquot___82 *);
	int (*release_dqblk)(struct dquot___82 *);
	int (*get_next_id)(struct super_block___83 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___82 {
	int (*write_dquot)(struct dquot___82 *);
	struct dquot___82 * (*alloc_dquot)(struct super_block___83 *, int);
	void (*destroy_dquot)(struct dquot___82 *);
	int (*acquire_dquot)(struct dquot___82 *);
	int (*release_dquot)(struct dquot___82 *);
	int (*mark_dirty)(struct dquot___82 *);
	int (*write_info)(struct super_block___83 *, int);
	qsize_t * (*get_reserved_space)(struct inode___84 *);
	int (*get_projid)(struct inode___84 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___84 *, qsize_t *);
	int (*get_next_id)(struct super_block___83 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___82 {
	int (*quota_on)(struct super_block___83 *, int, int, const struct path___82 *);
	int (*quota_off)(struct super_block___83 *, int);
	int (*quota_enable)(struct super_block___83 *, unsigned int);
	int (*quota_disable)(struct super_block___83 *, unsigned int);
	int (*quota_sync)(struct super_block___83 *, int);
	int (*set_info)(struct super_block___83 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___83 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___83 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___83 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___83 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___83 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___82 {
	int (*writepage)(struct page___83 *, struct writeback_control___3 *);
	int (*readpage)(struct file___83 *, struct page___83 *);
	int (*writepages)(struct address_space___82 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___83 *);
	int (*readpages)(struct file___83 *, struct address_space___82 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___83 *, struct address_space___82 *, loff_t, unsigned int, unsigned int, struct page___83 **, void **);
	int (*write_end)(struct file___83 *, struct address_space___82 *, loff_t, unsigned int, unsigned int, struct page___83 *, void *);
	sector_t (*bmap)(struct address_space___82 *, sector_t);
	void (*invalidatepage)(struct page___83 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___83 *, gfp_t);
	void (*freepage)(struct page___83 *);
	ssize_t (*direct_IO)(struct kiocb___83 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___82 *, struct page___83 *, struct page___83 *, enum migrate_mode);
	bool (*isolate_page)(struct page___83 *, isolate_mode_t);
	void (*putback_page)(struct page___83 *);
	int (*launder_page)(struct page___83 *);
	int (*is_partially_uptodate)(struct page___83 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___83 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___82 *, struct page___83 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___83 *, sector_t *);
	void (*swap_deactivate)(struct file___83 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___83 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___84 *bd_inode;
	struct super_block___83 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___83 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___82 {
	struct dentry___83 * (*lookup)(struct inode___84 *, struct dentry___83 *, unsigned int);
	const char * (*get_link)(struct dentry___83 *, struct inode___84 *, struct delayed_call *);
	int (*permission)(struct inode___84 *, int);
	struct posix_acl * (*get_acl)(struct inode___84 *, int);
	int (*readlink)(struct dentry___83 *, char *, int);
	int (*create)(struct inode___84 *, struct dentry___83 *, umode_t, bool);
	int (*link)(struct dentry___83 *, struct inode___84 *, struct dentry___83 *);
	int (*unlink)(struct inode___84 *, struct dentry___83 *);
	int (*symlink)(struct inode___84 *, struct dentry___83 *, const char *);
	int (*mkdir)(struct inode___84 *, struct dentry___83 *, umode_t);
	int (*rmdir)(struct inode___84 *, struct dentry___83 *);
	int (*mknod)(struct inode___84 *, struct dentry___83 *, umode_t, dev_t);
	int (*rename)(struct inode___84 *, struct dentry___83 *, struct inode___84 *, struct dentry___83 *, unsigned int);
	int (*setattr)(struct dentry___83 *, struct iattr___83 *);
	int (*getattr)(const struct path___82 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___83 *, char *, size_t);
	int (*fiemap)(struct inode___84 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___84 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___84 *, struct dentry___83 *, struct file___83 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___84 *, struct dentry___83 *, umode_t);
	int (*set_acl)(struct inode___84 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___82 {
	void (*fl_copy_lock)(struct file_lock___83 *, struct file_lock___83 *);
	void (*fl_release_private)(struct file_lock___83 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___82;

struct lock_manager_operations___82;

struct file_lock___83 {
	struct file_lock___83 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___83 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___82 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___82 *fl_ops;
	const struct lock_manager_operations___82 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___82 {
	int (*lm_compare_owner)(struct file_lock___83 *, struct file_lock___83 *);
	long unsigned int (*lm_owner_key)(struct file_lock___83 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___83 *);
	int (*lm_grant)(struct file_lock___83 *, int);
	bool (*lm_break)(struct file_lock___83 *);
	int (*lm_change)(struct file_lock___83 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___83 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___82 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___82 *fa_next;
	struct file___83 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___82 {
	const char *name;
	int fs_flags;
	struct dentry___83 * (*mount)(struct file_system_type___82 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___83 *);
	struct module___11 *owner;
	struct file_system_type___82 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___82 {
	struct inode___84 * (*alloc_inode)(struct super_block___83 *);
	void (*destroy_inode)(struct inode___84 *);
	void (*dirty_inode)(struct inode___84 *, int);
	int (*write_inode)(struct inode___84 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___84 *);
	void (*evict_inode)(struct inode___84 *);
	void (*put_super)(struct super_block___83 *);
	int (*sync_fs)(struct super_block___83 *, int);
	int (*freeze_super)(struct super_block___83 *);
	int (*freeze_fs)(struct super_block___83 *);
	int (*thaw_super)(struct super_block___83 *);
	int (*unfreeze_fs)(struct super_block___83 *);
	int (*statfs)(struct dentry___83 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___83 *, int *, char *);
	void (*umount_begin)(struct super_block___83 *);
	int (*show_options)(struct seq_file___77 *, struct dentry___83 *);
	int (*show_devname)(struct seq_file___77 *, struct dentry___83 *);
	int (*show_path)(struct seq_file___77 *, struct dentry___83 *);
	int (*show_stats)(struct seq_file___77 *, struct dentry___83 *);
	ssize_t (*quota_read)(struct super_block___83 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___83 *, int, const char *, size_t, loff_t);
	struct dquot___82 ** (*get_dquots)(struct inode___84 *);
	int (*bdev_try_to_free_page)(struct super_block___83 *, struct page___83 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___83 *, struct shrink_control___31 *);
	long int (*free_cached_objects)(struct super_block___83 *, struct shrink_control___31 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___74;

struct seq_file___77 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___74 *op;
	int poll_event;
	const struct file___83 *file;
	void *private;
};

typedef int (*key_restrict_link_func_t___79)(struct key___80 *, const struct key_type *, const union key_payload *, struct key___80 *);

struct key_restriction___80;

struct key___80 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___83 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___80 *restrict_link;
};

struct key_restriction___80 {
	key_restrict_link_func_t___79 check;
	struct key___80 *key;
	struct key_type *keytype;
};

struct seq_operations___74 {
	void * (*start)(struct seq_file___77 *, loff_t *);
	void (*stop)(struct seq_file___77 *, void *);
	void * (*next)(struct seq_file___77 *, void *, loff_t *);
	int (*show)(struct seq_file___77 *, void *);
};

struct kernfs_root___80;

struct kernfs_elem_dir___80 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___80 *root;
};

struct kernfs_node___80;

struct kernfs_syscall_ops___80;

struct kernfs_root___80 {
	struct kernfs_node___80 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___80 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___80 {
	struct kernfs_node___80 *target_kn;
};

struct kernfs_ops___80;

struct kernfs_elem_attr___80 {
	const struct kernfs_ops___80 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___80 *notify_next;
};

struct kernfs_node___80 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___80 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___80 dir;
		struct kernfs_elem_symlink___80 symlink;
		struct kernfs_elem_attr___80 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___80;

struct kernfs_ops___80 {
	int (*open)(struct kernfs_open_file___80 *);
	void (*release)(struct kernfs_open_file___80 *);
	int (*seq_show)(struct seq_file___77 *, void *);
	void * (*seq_start)(struct seq_file___77 *, loff_t *);
	void * (*seq_next)(struct seq_file___77 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___77 *, void *);
	ssize_t (*read)(struct kernfs_open_file___80 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___80 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___80 *, struct vm_area_struct___83 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___80 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___80 {
	int (*remount_fs)(struct kernfs_root___80 *, int *, char *);
	int (*show_options)(struct seq_file___77 *, struct kernfs_root___80 *);
	int (*mkdir)(struct kernfs_node___80 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___80 *);
	int (*rename)(struct kernfs_node___80 *, struct kernfs_node___80 *, const char *);
	int (*show_path)(struct seq_file___77 *, struct kernfs_node___80 *, struct kernfs_root___80 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___80 {
	struct kernfs_node___80 *kn;
	struct file___83 *file;
	struct seq_file___77 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___13 *vm_ops;
};

struct cgroup_namespace___66 {
	refcount_t count;
	struct ns_common___5 ns;
	struct user_namespace___68 *user_ns;
	struct ucounts___68 *ucounts;
	struct css_set___66 *root_cset;
};

struct ucounts___68 {
	struct hlist_node node;
	struct user_namespace___68 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___66;

struct bpf_map_ops___66 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___66 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___66 *, struct file___83 *);
	void (*map_free)(struct bpf_map___66 *);
	int (*map_get_next_key)(struct bpf_map___66 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___66 *);
	void * (*map_lookup_elem)(struct bpf_map___66 *, void *);
	int (*map_update_elem)(struct bpf_map___66 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___66 *, void *);
	int (*map_push_elem)(struct bpf_map___66 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___66 *, void *);
	int (*map_peek_elem)(struct bpf_map___66 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___66 *, struct file___83 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___66 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___66 *, void *, struct seq_file___77 *);
	int (*map_check_btf)(const struct bpf_map___66 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___66 {
	const struct bpf_map_ops___66 *ops;
	struct bpf_map___66 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___79 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___66;

typedef void (*kthread_work_func_t___66)(struct kthread_work___66 *);

struct kthread_worker___66;

struct kthread_work___66 {
	struct list_head node;
	kthread_work_func_t___66 func;
	struct kthread_worker___66 *worker;
	int canceling;
};

struct kthread_worker___66 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___83 *task;
	struct kthread_work___66 *current_work;
};

struct kthread_delayed_work___66 {
	struct kthread_work___66 work;
	struct timer_list timer;
};

struct psi_group___66 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___66 *poll_kworker;
	struct kthread_delayed_work___66 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___66 {
	struct kernfs_node___80 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___66;

struct cgroup_subsys_state___66 {
	struct cgroup___66 *cgroup;
	struct cgroup_subsys___66 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___66 *parent;
};

struct cgroup_root___66;

struct cgroup_rstat_cpu___66;

struct cgroup___66 {
	struct cgroup_subsys_state___66 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___80 *kn;
	struct cgroup_file___66 procs_file;
	struct cgroup_file___66 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___66 *subsys[13];
	struct cgroup_root___66 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___66 *dom_cgrp;
	struct cgroup_rstat_cpu___66 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___6 bpf;
	atomic_t congestion_count;
	struct cgroup___66 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___66 psi;
	int ancestor_ids[0];
};

struct cgroup_taskset___3;

struct cftype___66;

struct cgroup_subsys___66 {
	struct cgroup_subsys_state___66 * (*css_alloc)(struct cgroup_subsys_state___66 *);
	int (*css_online)(struct cgroup_subsys_state___66 *);
	void (*css_offline)(struct cgroup_subsys_state___66 *);
	void (*css_released)(struct cgroup_subsys_state___66 *);
	void (*css_free)(struct cgroup_subsys_state___66 *);
	void (*css_reset)(struct cgroup_subsys_state___66 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___66 *, int);
	int (*css_extra_stat_show)(struct seq_file___77 *, struct cgroup_subsys_state___66 *);
	int (*can_attach)(struct cgroup_taskset___3 *);
	void (*cancel_attach)(struct cgroup_taskset___3 *);
	void (*attach)(struct cgroup_taskset___3 *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___83 *);
	void (*cancel_fork)(struct task_struct___83 *);
	void (*fork)(struct task_struct___83 *);
	void (*exit)(struct task_struct___83 *);
	void (*free)(struct task_struct___83 *);
	void (*bind)(struct cgroup_subsys_state___66 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___66 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___66 *dfl_cftypes;
	struct cftype___66 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___66 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___66 *updated_children;
	struct cgroup___66 *updated_next;
};

struct cgroup_root___66 {
	struct kernfs_root___80 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___66 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___66 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___66 *ss;
	struct list_head node;
	struct kernfs_ops___80 *kf_ops;
	int (*open)(struct kernfs_open_file___80 *);
	void (*release)(struct kernfs_open_file___80 *);
	u64 (*read_u64)(struct cgroup_subsys_state___66 *, struct cftype___66 *);
	s64 (*read_s64)(struct cgroup_subsys_state___66 *, struct cftype___66 *);
	int (*seq_show)(struct seq_file___77 *, void *);
	void * (*seq_start)(struct seq_file___77 *, loff_t *);
	void * (*seq_next)(struct seq_file___77 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___77 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___66 *, struct cftype___66 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___66 *, struct cftype___66 *, s64);
	ssize_t (*write)(struct kernfs_open_file___80 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___80 *, struct poll_table_struct___6 *);
};

struct cgroup_taskset___3 {
	struct list_head src_csets;
	struct list_head dst_csets;
	int nr_tasks;
	int ssid;
	struct list_head *csets;
	struct css_set___66 *cur_cset;
	struct task_struct___83 *cur_task;
};

struct file___84;

struct kiocb___84;

struct vm_area_struct___84;

struct inode___85;

struct file_lock___84;

struct page___84;

struct seq_file___78;

struct file_operations___84 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___84 *, loff_t, int);
	ssize_t (*read)(struct file___84 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___84 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___84 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___84 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___84 *, bool);
	int (*iterate)(struct file___84 *, struct dir_context *);
	int (*iterate_shared)(struct file___84 *, struct dir_context *);
	__poll_t (*poll)(struct file___84 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___84 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___84 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___84 *, struct vm_area_struct___84 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___85 *, struct file___84 *);
	int (*flush)(struct file___84 *, fl_owner_t);
	int (*release)(struct inode___85 *, struct file___84 *);
	int (*fsync)(struct file___84 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___84 *, int);
	int (*lock)(struct file___84 *, int, struct file_lock___84 *);
	ssize_t (*sendpage)(struct file___84 *, struct page___84 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___84 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___84 *, int, struct file_lock___84 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___84 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___84 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___84 *, long int, struct file_lock___84 **, void **);
	long int (*fallocate)(struct file___84 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___78 *, struct file___84 *);
	ssize_t (*copy_file_range)(struct file___84 *, loff_t, struct file___84 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___84 *, loff_t, struct file___84 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___84 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___83 {
	u64 seqnum;
	struct vm_area_struct___84 *vmas[4];
};

struct page_frag___83 {
	struct page___84 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___83;

struct pid___70;

struct cred___80;

struct nsproxy___78;

struct signal_struct___74;

struct css_set___67;

struct vm_struct___60;

struct task_struct___84 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___84 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___83 *mm;
	struct mm_struct___83 *active_mm;
	struct vmacache___83 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___84 *real_parent;
	struct task_struct___84 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___84 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___70 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___70 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___70 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___80 *ptracer_cred;
	const struct cred___80 *real_cred;
	const struct cred___80 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___78 *nsproxy;
	struct signal_struct___74 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___84 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___14 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___67 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___83 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___84 *oom_reaper_list;
	struct vm_struct___60 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___53 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___70;

struct upid___70 {
	int nr;
	struct pid_namespace___70 *ns;
};

struct dentry___84;

struct user_namespace___69;

struct ucounts___69;

struct pid_namespace___70 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___84 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___70 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___84 *proc_self;
	struct dentry___84 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___69 *user_ns;
	struct ucounts___69 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___5 ns;
};

struct pid___70 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___70 numbers[1];
};

struct rw_semaphore___84 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___84 *owner;
};

struct key___81;

struct user_namespace___69 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___69 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___5 ns;
	long unsigned int flags;
	struct key___81 *persistent_keyring_register;
	struct rw_semaphore___84 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___69 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct secondary_data___84 {
	void *stack;
	struct task_struct___84 *task;
	long int status;
};

typedef struct page___84 *pgtable_t___83;

struct address_space___83;

struct dev_pagemap___82;

struct page___84 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___83 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___84 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___83 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___83 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___82 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct user_struct___80 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___81 *uid_keyring;
	struct key___81 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___82;

struct vm_area_struct___84 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___84 *vm_next;
	struct vm_area_struct___84 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___83 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___82 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___84 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___83;

struct mm_struct___83 {
	struct {
		struct vm_area_struct___84 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___84 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___84 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___83 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___84 *owner;
		struct user_namespace___69 *user_ns;
		struct file___84 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___83 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___80 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___81 *session_keyring;
	struct key___81 *process_keyring;
	struct key___81 *thread_keyring;
	struct key___81 *request_key_auth;
	void *security;
	struct user_struct___80 *user;
	struct user_namespace___69 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___67;

struct nsproxy___78 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___70 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___67 *cgroup_ns;
};

struct signal_struct___74 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___84 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___84 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___70 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___70 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___83 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___70 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___67;

struct cgroup___67;

struct css_set___67 {
	struct cgroup_subsys_state___67 *subsys[13];
	refcount_t refcount;
	struct css_set___67 *dom_cset;
	struct cgroup___67 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___67 *mg_src_cgrp;
	struct cgroup___67 *mg_dst_cgrp;
	struct css_set___67 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct vm_struct___60 {
	struct vm_struct___60 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___84 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___74 {
	struct task_struct___84 task;
	long unsigned int stack[8192];
};

struct cgroupstats {
	__u64 nr_sleeping;
	__u64 nr_running;
	__u64 nr_stopped;
	__u64 nr_uninterruptible;
	__u64 nr_io_wait;
};

struct dentry_operations___83;

struct super_block___84;

struct dentry___84 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___84 *d_parent;
	struct qstr d_name;
	struct inode___85 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___83 *d_op;
	struct super_block___84 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___83;

struct address_space___83 {
	struct inode___85 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___84 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___83 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___83;

struct block_device___84;

struct inode___85 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___83 *i_op;
	struct super_block___84 *i_sb;
	struct address_space___83 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___84 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___84 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___83 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___84 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___83;

struct dentry_operations___83 {
	int (*d_revalidate)(struct dentry___84 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___84 *, unsigned int);
	int (*d_hash)(const struct dentry___84 *, struct qstr *);
	int (*d_compare)(const struct dentry___84 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___84 *);
	int (*d_init)(struct dentry___84 *);
	void (*d_release)(struct dentry___84 *);
	void (*d_prune)(struct dentry___84 *);
	void (*d_iput)(struct dentry___84 *, struct inode___85 *);
	char * (*d_dname)(struct dentry___84 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___83 *);
	int (*d_manage)(const struct path___83 *, bool);
	struct dentry___84 * (*d_real)(struct dentry___84 *, const struct inode___85 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___83;

struct mem_dqinfo___83 {
	struct quota_format_type___83 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___83;

struct quota_info___83 {
	unsigned int flags;
	struct rw_semaphore___84 dqio_sem;
	struct inode___85 *files[3];
	struct mem_dqinfo___83 info[3];
	const struct quota_format_ops___83 *ops[3];
};

struct rcuwait___83 {
	struct task_struct___84 *task;
};

struct percpu_rw_semaphore___83 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___84 rw_sem;
	struct rcuwait___83 writer;
	int readers_block;
};

struct sb_writers___83 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___83 rw_sem[3];
};

struct file_system_type___83;

struct super_operations___83;

struct dquot_operations___83;

struct quotactl_ops___83;

struct super_block___84 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___83 *s_type;
	const struct super_operations___83 *s_op;
	const struct dquot_operations___83 *dq_op;
	const struct quotactl_ops___83 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___84 *s_root;
	struct rw_semaphore___84 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___84 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___83 s_dquot;
	struct sb_writers___83 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___83 *s_d_op;
	int cleancache_poolid;
	struct shrinker___31 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___69 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct path___83 {
	struct vfsmount *mnt;
	struct dentry___84 *dentry;
};

struct pglist_data___83;

struct lruvec___83 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___83 *pgdat;
};

struct zone___83 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___83 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___83 {
	struct zone___83 *zone;
	int zone_idx;
};

struct zonelist___83 {
	struct zoneref___83 _zonerefs[25];
};

struct pglist_data___83 {
	struct zone___83 node_zones[3];
	struct zonelist___83 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___84 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___84 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___83 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___83 {
	struct rw_semaphore___84 rwsem;
	struct notifier_block *head;
};

typedef int (*dev_page_fault_t___82)(struct vm_area_struct___84 *, long unsigned int, const struct page___84 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___82)(struct page___84 *, void *);

struct dev_pagemap___82 {
	dev_page_fault_t___82 page_fault;
	dev_page_free_t___82 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___6 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct fown_struct___70 {
	rwlock_t lock;
	struct pid___70 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___84 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___83 f_path;
	struct inode___85 *f_inode;
	const struct file_operations___84 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___70 f_owner;
	const struct cred___80 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___83 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___82;

struct vm_operations_struct___82 {
	void (*open)(struct vm_area_struct___84 *);
	void (*close)(struct vm_area_struct___84 *);
	int (*split)(struct vm_area_struct___84 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___84 *);
	vm_fault_t (*fault)(struct vm_fault___82 *);
	vm_fault_t (*huge_fault)(struct vm_fault___82 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___82 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___84 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___82 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___82 *);
	int (*access)(struct vm_area_struct___84 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___84 *);
	int (*set_policy)(struct vm_area_struct___84 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___84 *, long unsigned int);
	struct page___84 * (*find_special_page)(struct vm_area_struct___84 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___83 {
	struct task_struct___84 *task;
	struct core_thread___83 *next;
};

struct core_state___83 {
	atomic_t nr_threads;
	struct core_thread___83 dumper;
	struct completion startup;
};

struct vm_fault___82 {
	struct vm_area_struct___84 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___84 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___84 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___83 prealloc_pte;
};

struct kiocb___84 {
	struct file___84 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___84 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___84 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___84 *ia_file;
};

struct dquot___83 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___84 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___83 {
	int qf_fmt_id;
	const struct quota_format_ops___83 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___83 *qf_next;
};

struct quota_format_ops___83 {
	int (*check_quota_file)(struct super_block___84 *, int);
	int (*read_file_info)(struct super_block___84 *, int);
	int (*write_file_info)(struct super_block___84 *, int);
	int (*free_file_info)(struct super_block___84 *, int);
	int (*read_dqblk)(struct dquot___83 *);
	int (*commit_dqblk)(struct dquot___83 *);
	int (*release_dqblk)(struct dquot___83 *);
	int (*get_next_id)(struct super_block___84 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___83 {
	int (*write_dquot)(struct dquot___83 *);
	struct dquot___83 * (*alloc_dquot)(struct super_block___84 *, int);
	void (*destroy_dquot)(struct dquot___83 *);
	int (*acquire_dquot)(struct dquot___83 *);
	int (*release_dquot)(struct dquot___83 *);
	int (*mark_dirty)(struct dquot___83 *);
	int (*write_info)(struct super_block___84 *, int);
	qsize_t * (*get_reserved_space)(struct inode___85 *);
	int (*get_projid)(struct inode___85 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___85 *, qsize_t *);
	int (*get_next_id)(struct super_block___84 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___83 {
	int (*quota_on)(struct super_block___84 *, int, int, const struct path___83 *);
	int (*quota_off)(struct super_block___84 *, int);
	int (*quota_enable)(struct super_block___84 *, unsigned int);
	int (*quota_disable)(struct super_block___84 *, unsigned int);
	int (*quota_sync)(struct super_block___84 *, int);
	int (*set_info)(struct super_block___84 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___84 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___84 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___84 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___84 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___84 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___83 {
	int (*writepage)(struct page___84 *, struct writeback_control___3 *);
	int (*readpage)(struct file___84 *, struct page___84 *);
	int (*writepages)(struct address_space___83 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___84 *);
	int (*readpages)(struct file___84 *, struct address_space___83 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___84 *, struct address_space___83 *, loff_t, unsigned int, unsigned int, struct page___84 **, void **);
	int (*write_end)(struct file___84 *, struct address_space___83 *, loff_t, unsigned int, unsigned int, struct page___84 *, void *);
	sector_t (*bmap)(struct address_space___83 *, sector_t);
	void (*invalidatepage)(struct page___84 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___84 *, gfp_t);
	void (*freepage)(struct page___84 *);
	ssize_t (*direct_IO)(struct kiocb___84 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___83 *, struct page___84 *, struct page___84 *, enum migrate_mode);
	bool (*isolate_page)(struct page___84 *, isolate_mode_t);
	void (*putback_page)(struct page___84 *);
	int (*launder_page)(struct page___84 *);
	int (*is_partially_uptodate)(struct page___84 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___84 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___83 *, struct page___84 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___84 *, sector_t *);
	void (*swap_deactivate)(struct file___84 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___84 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___85 *bd_inode;
	struct super_block___84 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___84 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___83 {
	struct dentry___84 * (*lookup)(struct inode___85 *, struct dentry___84 *, unsigned int);
	const char * (*get_link)(struct dentry___84 *, struct inode___85 *, struct delayed_call *);
	int (*permission)(struct inode___85 *, int);
	struct posix_acl * (*get_acl)(struct inode___85 *, int);
	int (*readlink)(struct dentry___84 *, char *, int);
	int (*create)(struct inode___85 *, struct dentry___84 *, umode_t, bool);
	int (*link)(struct dentry___84 *, struct inode___85 *, struct dentry___84 *);
	int (*unlink)(struct inode___85 *, struct dentry___84 *);
	int (*symlink)(struct inode___85 *, struct dentry___84 *, const char *);
	int (*mkdir)(struct inode___85 *, struct dentry___84 *, umode_t);
	int (*rmdir)(struct inode___85 *, struct dentry___84 *);
	int (*mknod)(struct inode___85 *, struct dentry___84 *, umode_t, dev_t);
	int (*rename)(struct inode___85 *, struct dentry___84 *, struct inode___85 *, struct dentry___84 *, unsigned int);
	int (*setattr)(struct dentry___84 *, struct iattr___84 *);
	int (*getattr)(const struct path___83 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___84 *, char *, size_t);
	int (*fiemap)(struct inode___85 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___85 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___85 *, struct dentry___84 *, struct file___84 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___85 *, struct dentry___84 *, umode_t);
	int (*set_acl)(struct inode___85 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___83 {
	void (*fl_copy_lock)(struct file_lock___84 *, struct file_lock___84 *);
	void (*fl_release_private)(struct file_lock___84 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___83;

struct lock_manager_operations___83;

struct file_lock___84 {
	struct file_lock___84 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___84 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___83 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___83 *fl_ops;
	const struct lock_manager_operations___83 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___83 {
	int (*lm_compare_owner)(struct file_lock___84 *, struct file_lock___84 *);
	long unsigned int (*lm_owner_key)(struct file_lock___84 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___84 *);
	int (*lm_grant)(struct file_lock___84 *, int);
	bool (*lm_break)(struct file_lock___84 *);
	int (*lm_change)(struct file_lock___84 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___84 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___83 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___83 *fa_next;
	struct file___84 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___83 {
	const char *name;
	int fs_flags;
	struct dentry___84 * (*mount)(struct file_system_type___83 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___84 *);
	struct module___11 *owner;
	struct file_system_type___83 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___83 {
	struct inode___85 * (*alloc_inode)(struct super_block___84 *);
	void (*destroy_inode)(struct inode___85 *);
	void (*dirty_inode)(struct inode___85 *, int);
	int (*write_inode)(struct inode___85 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___85 *);
	void (*evict_inode)(struct inode___85 *);
	void (*put_super)(struct super_block___84 *);
	int (*sync_fs)(struct super_block___84 *, int);
	int (*freeze_super)(struct super_block___84 *);
	int (*freeze_fs)(struct super_block___84 *);
	int (*thaw_super)(struct super_block___84 *);
	int (*unfreeze_fs)(struct super_block___84 *);
	int (*statfs)(struct dentry___84 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___84 *, int *, char *);
	void (*umount_begin)(struct super_block___84 *);
	int (*show_options)(struct seq_file___78 *, struct dentry___84 *);
	int (*show_devname)(struct seq_file___78 *, struct dentry___84 *);
	int (*show_path)(struct seq_file___78 *, struct dentry___84 *);
	int (*show_stats)(struct seq_file___78 *, struct dentry___84 *);
	ssize_t (*quota_read)(struct super_block___84 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___84 *, int, const char *, size_t, loff_t);
	struct dquot___83 ** (*get_dquots)(struct inode___85 *);
	int (*bdev_try_to_free_page)(struct super_block___84 *, struct page___84 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___84 *, struct shrink_control___31 *);
	long int (*free_cached_objects)(struct super_block___84 *, struct shrink_control___31 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___75;

struct seq_file___78 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___75 *op;
	int poll_event;
	const struct file___84 *file;
	void *private;
};

typedef int (*key_restrict_link_func_t___80)(struct key___81 *, const struct key_type *, const union key_payload *, struct key___81 *);

struct key_restriction___81;

struct key___81 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___84 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___81 *restrict_link;
};

struct key_restriction___81 {
	key_restrict_link_func_t___80 check;
	struct key___81 *key;
	struct key_type *keytype;
};

struct seq_operations___75 {
	void * (*start)(struct seq_file___78 *, loff_t *);
	void (*stop)(struct seq_file___78 *, void *);
	void * (*next)(struct seq_file___78 *, void *, loff_t *);
	int (*show)(struct seq_file___78 *, void *);
};

struct kernfs_root___81;

struct kernfs_elem_dir___81 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___81 *root;
};

struct kernfs_node___81;

struct kernfs_syscall_ops___81;

struct kernfs_root___81 {
	struct kernfs_node___81 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___81 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___81 {
	struct kernfs_node___81 *target_kn;
};

struct kernfs_ops___81;

struct kernfs_elem_attr___81 {
	const struct kernfs_ops___81 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___81 *notify_next;
};

struct kernfs_node___81 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___81 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___81 dir;
		struct kernfs_elem_symlink___81 symlink;
		struct kernfs_elem_attr___81 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___81;

struct kernfs_ops___81 {
	int (*open)(struct kernfs_open_file___81 *);
	void (*release)(struct kernfs_open_file___81 *);
	int (*seq_show)(struct seq_file___78 *, void *);
	void * (*seq_start)(struct seq_file___78 *, loff_t *);
	void * (*seq_next)(struct seq_file___78 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___78 *, void *);
	ssize_t (*read)(struct kernfs_open_file___81 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___81 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___81 *, struct vm_area_struct___84 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___81 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___81 {
	int (*remount_fs)(struct kernfs_root___81 *, int *, char *);
	int (*show_options)(struct seq_file___78 *, struct kernfs_root___81 *);
	int (*mkdir)(struct kernfs_node___81 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___81 *);
	int (*rename)(struct kernfs_node___81 *, struct kernfs_node___81 *, const char *);
	int (*show_path)(struct seq_file___78 *, struct kernfs_node___81 *, struct kernfs_root___81 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___81 {
	struct kernfs_node___81 *kn;
	struct file___84 *file;
	struct seq_file___78 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___82 *vm_ops;
};

struct cgroup_namespace___67 {
	refcount_t count;
	struct ns_common___5 ns;
	struct user_namespace___69 *user_ns;
	struct ucounts___69 *ucounts;
	struct css_set___67 *root_cset;
};

struct ucounts___69 {
	struct hlist_node node;
	struct user_namespace___69 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___67;

struct bpf_map_ops___67 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___67 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___67 *, struct file___84 *);
	void (*map_free)(struct bpf_map___67 *);
	int (*map_get_next_key)(struct bpf_map___67 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___67 *);
	void * (*map_lookup_elem)(struct bpf_map___67 *, void *);
	int (*map_update_elem)(struct bpf_map___67 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___67 *, void *);
	int (*map_push_elem)(struct bpf_map___67 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___67 *, void *);
	int (*map_peek_elem)(struct bpf_map___67 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___67 *, struct file___84 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___67 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___67 *, void *, struct seq_file___78 *);
	int (*map_check_btf)(const struct bpf_map___67 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___67 {
	const struct bpf_map_ops___67 *ops;
	struct bpf_map___67 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___80 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___67;

typedef void (*kthread_work_func_t___67)(struct kthread_work___67 *);

struct kthread_worker___67;

struct kthread_work___67 {
	struct list_head node;
	kthread_work_func_t___67 func;
	struct kthread_worker___67 *worker;
	int canceling;
};

struct kthread_worker___67 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___84 *task;
	struct kthread_work___67 *current_work;
};

struct kthread_delayed_work___67 {
	struct kthread_work___67 work;
	struct timer_list timer;
};

struct psi_group___67 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___67 *poll_kworker;
	struct kthread_delayed_work___67 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___67 {
	struct kernfs_node___81 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___67;

struct cgroup_subsys_state___67 {
	struct cgroup___67 *cgroup;
	struct cgroup_subsys___67 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___67 *parent;
};

struct cgroup_root___67;

struct cgroup_rstat_cpu___67;

struct cgroup___67 {
	struct cgroup_subsys_state___67 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___81 *kn;
	struct cgroup_file___67 procs_file;
	struct cgroup_file___67 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___67 *subsys[13];
	struct cgroup_root___67 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___67 *dom_cgrp;
	struct cgroup_rstat_cpu___67 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___6 bpf;
	atomic_t congestion_count;
	struct cgroup___67 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___67 psi;
	int ancestor_ids[0];
};

struct cftype___67;

struct cgroup_subsys___67 {
	struct cgroup_subsys_state___67 * (*css_alloc)(struct cgroup_subsys_state___67 *);
	int (*css_online)(struct cgroup_subsys_state___67 *);
	void (*css_offline)(struct cgroup_subsys_state___67 *);
	void (*css_released)(struct cgroup_subsys_state___67 *);
	void (*css_free)(struct cgroup_subsys_state___67 *);
	void (*css_reset)(struct cgroup_subsys_state___67 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___67 *, int);
	int (*css_extra_stat_show)(struct seq_file___78 *, struct cgroup_subsys_state___67 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___84 *);
	void (*cancel_fork)(struct task_struct___84 *);
	void (*fork)(struct task_struct___84 *);
	void (*exit)(struct task_struct___84 *);
	void (*free)(struct task_struct___84 *);
	void (*bind)(struct cgroup_subsys_state___67 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___67 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___67 *dfl_cftypes;
	struct cftype___67 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___67 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___67 *updated_children;
	struct cgroup___67 *updated_next;
};

struct cgroup_root___67 {
	struct kernfs_root___81 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___67 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___67 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___67 *ss;
	struct list_head node;
	struct kernfs_ops___81 *kf_ops;
	int (*open)(struct kernfs_open_file___81 *);
	void (*release)(struct kernfs_open_file___81 *);
	u64 (*read_u64)(struct cgroup_subsys_state___67 *, struct cftype___67 *);
	s64 (*read_s64)(struct cgroup_subsys_state___67 *, struct cftype___67 *);
	int (*seq_show)(struct seq_file___78 *, void *);
	void * (*seq_start)(struct seq_file___78 *, loff_t *);
	void * (*seq_next)(struct seq_file___78 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___78 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___67 *, struct cftype___67 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___67 *, struct cftype___67 *, s64);
	ssize_t (*write)(struct kernfs_open_file___81 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___81 *, struct poll_table_struct___6 *);
};

struct cgroup_taskset {
	struct list_head src_csets;
	struct list_head dst_csets;
	int nr_tasks;
	int ssid;
	struct list_head *csets;
	struct css_set___67 *cur_cset;
	struct task_struct___84 *cur_task;
};

struct css_task_iter___2 {
	struct cgroup_subsys___67 *ss;
	unsigned int flags;
	struct list_head *cset_pos;
	struct list_head *cset_head;
	struct list_head *tcset_pos;
	struct list_head *tcset_head;
	struct list_head *task_pos;
	struct list_head *tasks_head;
	struct list_head *mg_tasks_head;
	struct css_set___67 *cur_cset;
	struct css_set___67 *cur_dcset;
	struct task_struct___84 *cur_task;
	struct list_head iters_node;
};

struct cgrp_cset_link___2 {
	struct cgroup___67 *cgrp;
	struct css_set___67 *cset;
	struct list_head cset_link;
	struct list_head cgrp_link;
};

struct cgroup_mgctx___2 {
	struct list_head preloaded_src_csets;
	struct list_head preloaded_dst_csets;
	struct cgroup_taskset tset;
	u16 ss_mask;
};

typedef void compound_page_dtor___82(struct page___84 *);

enum cgroup_filetype {
	CGROUP_FILE_PROCS = 0,
	CGROUP_FILE_TASKS = 1,
};

struct cgroup_pidlist {
	struct {
		enum cgroup_filetype type;
		struct pid_namespace___70 *ns;
	} key;
	pid_t *list;
	int length;
	struct list_head links;
	struct cgroup___67 *owner;
	struct delayed_work destroy_dwork;
};

struct css_task_iter___3 {
	struct cgroup_subsys___66 *ss;
	unsigned int flags;
	struct list_head *cset_pos;
	struct list_head *cset_head;
	struct list_head *tcset_pos;
	struct list_head *tcset_head;
	struct list_head *task_pos;
	struct list_head *tasks_head;
	struct list_head *mg_tasks_head;
	struct css_set___66 *cur_cset;
	struct css_set___66 *cur_dcset;
	struct task_struct___83 *cur_task;
	struct list_head iters_node;
};

enum freezer_state_flags {
	CGROUP_FREEZER_ONLINE = 1,
	CGROUP_FREEZING_SELF = 2,
	CGROUP_FREEZING_PARENT = 4,
	CGROUP_FROZEN = 8,
	CGROUP_FREEZING = 6,
};

struct freezer {
	struct cgroup_subsys_state___67 css;
	unsigned int state;
};

struct pids_cgroup {
	struct cgroup_subsys_state___67 css;
	atomic64_t counter;
	int64_t limit;
	struct cgroup_file___67 events_file;
	atomic64_t events_limit;
};

typedef struct {
	char *from;
	char *to;
} substring_t;

enum rdmacg_resource_type {
	RDMACG_RESOURCE_HCA_HANDLE = 0,
	RDMACG_RESOURCE_HCA_OBJECT = 1,
	RDMACG_RESOURCE_MAX = 2,
};

struct rdma_cgroup {
	struct cgroup_subsys_state___67 css;
	struct list_head rpools;
};

struct rdmacg_device {
	struct list_head dev_node;
	struct list_head rpools;
	char *name;
};

enum rdmacg_file_type {
	RDMACG_RESOURCE_TYPE_MAX = 0,
	RDMACG_RESOURCE_TYPE_STAT = 1,
};

struct rdmacg_resource {
	int max;
	int usage;
};

struct rdmacg_resource_pool {
	struct rdmacg_device *device;
	struct rdmacg_resource resources[2];
	struct list_head cg_node;
	struct list_head dev_node;
	u64 usage_sum;
	int num_max_cnt;
};

struct file___85;

struct kiocb___85;

struct vm_area_struct___85;

struct inode___86;

struct file_lock___85;

struct page___85;

struct seq_file___79;

struct file_operations___85 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___85 *, loff_t, int);
	ssize_t (*read)(struct file___85 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___85 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___85 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___85 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___85 *, bool);
	int (*iterate)(struct file___85 *, struct dir_context *);
	int (*iterate_shared)(struct file___85 *, struct dir_context *);
	__poll_t (*poll)(struct file___85 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___85 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___85 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___85 *, struct vm_area_struct___85 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___86 *, struct file___85 *);
	int (*flush)(struct file___85 *, fl_owner_t);
	int (*release)(struct inode___86 *, struct file___85 *);
	int (*fsync)(struct file___85 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___85 *, int);
	int (*lock)(struct file___85 *, int, struct file_lock___85 *);
	ssize_t (*sendpage)(struct file___85 *, struct page___85 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___85 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___85 *, int, struct file_lock___85 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___85 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___85 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___85 *, long int, struct file_lock___85 **, void **);
	long int (*fallocate)(struct file___85 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___79 *, struct file___85 *);
	ssize_t (*copy_file_range)(struct file___85 *, loff_t, struct file___85 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___85 *, loff_t, struct file___85 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___85 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___84 {
	u64 seqnum;
	struct vm_area_struct___85 *vmas[4];
};

struct page_frag___84 {
	struct page___85 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___84;

struct cred___81;

struct nsproxy___79;

struct signal_struct___75;

struct bio_list___34;

struct backing_dev_info___34;

struct io_context___15;

struct css_set___68;

struct request_queue___16;

struct vm_struct___61;

struct task_struct___85 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___85 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___84 *mm;
	struct mm_struct___84 *active_mm;
	struct vmacache___84 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___85 *real_parent;
	struct task_struct___85 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___85 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___70 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___70 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___70 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___81 *ptracer_cred;
	const struct cred___81 *real_cred;
	const struct cred___81 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___79 *nsproxy;
	struct signal_struct___75 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___85 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___34 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___34 *backing_dev_info;
	struct io_context___15 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___68 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___84 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___16 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___85 *oom_reaper_list;
	struct vm_struct___61 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___53 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___85 *pgtable_t___84;

struct address_space___84;

struct dev_pagemap___83;

struct page___85 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___84 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___85 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___84 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___84 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___83 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___84;

struct lruvec___84 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___84 *pgdat;
};

struct zone___84 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___84 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___84 {
	struct zone___84 *zone;
	int zone_idx;
};

struct zonelist___84 {
	struct zoneref___84 _zonerefs[25];
};

struct pglist_data___84 {
	struct zone___84 node_zones[3];
	struct zonelist___84 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___85 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___85 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___84 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___85 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___85 *owner;
};

struct secondary_data___85 {
	void *stack;
	struct task_struct___85 *task;
	long int status;
};

struct blocking_notifier_head___84 {
	struct rw_semaphore___85 rwsem;
	struct notifier_block *head;
};

struct key___82;

struct ucounts___70;

struct user_namespace___70 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___70 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___5 ns;
	long unsigned int flags;
	struct key___82 *persistent_keyring_register;
	struct rw_semaphore___85 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___70 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_root___82;

struct kernfs_elem_dir___82 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___82 *root;
};

struct kernfs_node___82;

struct kernfs_syscall_ops___82;

struct kernfs_root___82 {
	struct kernfs_node___82 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___82 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___82 {
	struct kernfs_node___82 *target_kn;
};

struct kernfs_ops___82;

struct kernfs_elem_attr___82 {
	const struct kernfs_ops___82 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___82 *notify_next;
};

struct kernfs_node___82 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___82 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___82 dir;
		struct kernfs_elem_symlink___82 symlink;
		struct kernfs_elem_attr___82 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___82;

struct kernfs_ops___82 {
	int (*open)(struct kernfs_open_file___82 *);
	void (*release)(struct kernfs_open_file___82 *);
	int (*seq_show)(struct seq_file___79 *, void *);
	void * (*seq_start)(struct seq_file___79 *, loff_t *);
	void * (*seq_next)(struct seq_file___79 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___79 *, void *);
	ssize_t (*read)(struct kernfs_open_file___82 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___82 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___82 *, struct vm_area_struct___85 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___82 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___82 {
	int (*remount_fs)(struct kernfs_root___82 *, int *, char *);
	int (*show_options)(struct seq_file___79 *, struct kernfs_root___82 *);
	int (*mkdir)(struct kernfs_node___82 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___82 *);
	int (*rename)(struct kernfs_node___82 *, struct kernfs_node___82 *, const char *);
	int (*show_path)(struct seq_file___79 *, struct kernfs_node___82 *, struct kernfs_root___82 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___76;

struct seq_file___79 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___76 *op;
	int poll_event;
	const struct file___85 *file;
	void *private;
};

struct vm_operations_struct___83;

struct kernfs_open_file___82 {
	struct kernfs_node___82 *kn;
	struct file___85 *file;
	struct seq_file___79 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___83 *vm_ops;
};

struct vfsmount___13;

struct dentry___85;

struct path___84 {
	struct vfsmount___13 *mnt;
	struct dentry___85 *dentry;
};

struct file___85 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___84 f_path;
	struct inode___86 *f_inode;
	const struct file_operations___85 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___70 f_owner;
	const struct cred___81 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___84 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___83;

struct vm_operations_struct___83 {
	void (*open)(struct vm_area_struct___85 *);
	void (*close)(struct vm_area_struct___85 *);
	int (*split)(struct vm_area_struct___85 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___85 *);
	vm_fault_t (*fault)(struct vm_fault___83 *);
	vm_fault_t (*huge_fault)(struct vm_fault___83 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___83 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___85 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___83 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___83 *);
	int (*access)(struct vm_area_struct___85 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___85 *);
	int (*set_policy)(struct vm_area_struct___85 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___85 *, long unsigned int);
	struct page___85 * (*find_special_page)(struct vm_area_struct___85 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_area_struct___85 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___85 *vm_next;
	struct vm_area_struct___85 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___84 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___83 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___85 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___80;

struct bin_attribute___77;

struct attribute_group___77 {
	const char *name;
	umode_t (*is_visible)(struct kobject___80 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___80 *, struct bin_attribute___77 *, int);
	struct attribute **attrs;
	struct bin_attribute___77 **bin_attrs;
};

struct kset___79;

struct kobj_type___79;

struct kobject___80 {
	const char *name;
	struct list_head entry;
	struct kobject___80 *parent;
	struct kset___79 *kset;
	struct kobj_type___79 *ktype;
	struct kernfs_node___82 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___77 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___85 *, struct kobject___80 *, struct bin_attribute___77 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___85 *, struct kobject___80 *, struct bin_attribute___77 *, char *, loff_t, size_t);
	int (*mmap)(struct file___85 *, struct kobject___80 *, struct bin_attribute___77 *, struct vm_area_struct___85 *);
};

struct sysfs_ops___79 {
	ssize_t (*show)(struct kobject___80 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___80 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___79;

struct kset___79 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___80 kobj;
	const struct kset_uevent_ops___79 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___79 {
	void (*release)(struct kobject___80 *);
	const struct sysfs_ops___79 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___3 * (*child_ns_type)(struct kobject___80 *);
	const void * (*namespace)(struct kobject___80 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___79 {
	int (* const filter)(struct kset___79 *, struct kobject___80 *);
	const char * (* const name)(struct kset___79 *, struct kobject___80 *);
	int (* const uevent)(struct kset___79 *, struct kobject___80 *, struct kobj_uevent_env *);
};

struct kobj_attribute___80 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___80 *, struct kobj_attribute___80 *, char *);
	ssize_t (*store)(struct kobject___80 *, struct kobj_attribute___80 *, const char *, size_t);
};

struct device___78;

struct dev_pm_ops___78 {
	int (*prepare)(struct device___78 *);
	void (*complete)(struct device___78 *);
	int (*suspend)(struct device___78 *);
	int (*resume)(struct device___78 *);
	int (*freeze)(struct device___78 *);
	int (*thaw)(struct device___78 *);
	int (*poweroff)(struct device___78 *);
	int (*restore)(struct device___78 *);
	int (*suspend_late)(struct device___78 *);
	int (*resume_early)(struct device___78 *);
	int (*freeze_late)(struct device___78 *);
	int (*thaw_early)(struct device___78 *);
	int (*poweroff_late)(struct device___78 *);
	int (*restore_early)(struct device___78 *);
	int (*suspend_noirq)(struct device___78 *);
	int (*resume_noirq)(struct device___78 *);
	int (*freeze_noirq)(struct device___78 *);
	int (*thaw_noirq)(struct device___78 *);
	int (*poweroff_noirq)(struct device___78 *);
	int (*restore_noirq)(struct device___78 *);
	int (*runtime_suspend)(struct device___78 *);
	int (*runtime_resume)(struct device___78 *);
	int (*runtime_idle)(struct device___78 *);
};

struct dev_pm_info___78 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___78 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___78;

struct bus_type___78;

struct device_driver___78;

struct dev_pm_domain___78;

struct device_node___27;

struct fwnode_handle___57;

struct class___78;

struct device___78 {
	struct device___78 *parent;
	struct device_private *p;
	struct kobject___80 kobj;
	const char *init_name;
	const struct device_type___78 *type;
	struct mutex mutex;
	struct bus_type___78 *bus;
	struct device_driver___78 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___78 power;
	struct dev_pm_domain___78 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___27 *of_node;
	struct fwnode_handle___57 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___78 *class;
	const struct attribute_group___77 **groups;
	void (*release)(struct device___78 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___78 {
	struct dev_pm_ops___78 ops;
	void (*detach)(struct device___78 *, bool);
	int (*activate)(struct device___78 *);
	void (*sync)(struct device___78 *);
	void (*dismiss)(struct device___78 *);
};

struct user_struct___81 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___82 *uid_keyring;
	struct key___82 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___84;

struct mm_struct___84 {
	struct {
		struct vm_area_struct___85 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___85 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___85 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___84 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___85 *owner;
		struct user_namespace___70 *user_ns;
		struct file___85 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___84 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___81 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___82 *session_keyring;
	struct key___82 *process_keyring;
	struct key___82 *thread_keyring;
	struct key___82 *request_key_auth;
	void *security;
	struct user_struct___81 *user;
	struct user_namespace___70 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___68;

struct nsproxy___79 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___68 *cgroup_ns;
};

struct signal_struct___75 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___85 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___85 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___70 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___70 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___84 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___70 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide42;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___34;

struct bio_list___34 {
	struct bio___34 *head;
	struct bio___34 *tail;
};

struct bdi_writeback_congested___34;

struct cgroup_subsys_state___68;

struct bdi_writeback___34 {
	struct backing_dev_info___34 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___34 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___68 *memcg_css;
	struct cgroup_subsys_state___68 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___34 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___34 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___78 *dev;
	struct device___78 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___85 *debug_dir;
	struct dentry___85 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___15;

struct io_context___15 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___15 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___68;

struct css_set___68 {
	struct cgroup_subsys_state___68 *subsys[13];
	refcount_t refcount;
	struct css_set___68 *dom_cset;
	struct cgroup___68 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___68 *mg_src_cgrp;
	struct cgroup___68 *mg_dst_cgrp;
	struct css_set___68 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

typedef blk_qc_t make_request_fn___15(struct request_queue___16 *, struct bio___34 *);

struct request___16;

typedef int dma_drain_needed_fn___15(struct request___16 *);

struct bsg_ops___15;

struct bsg_class_device___15 {
	struct device___78 *class_dev;
	int minor;
	struct request_queue___16 *queue;
	const struct bsg_ops___15 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___34 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___34 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___15;

struct blkcg_gq___8;

struct request_queue___16 {
	struct list_head queue_head;
	struct request___16 *last_merge;
	struct elevator_queue___15 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___15 *make_request_fn;
	dma_drain_needed_fn___15 *dma_drain_needed;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___34 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___80 kobj;
	struct kobject___80 *mq_kobj;
	struct blk_integrity integrity;
	struct device___78 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___8 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	struct bsg_class_device___15 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___34 bio_split;
	struct dentry___85 *debugfs_dir;
	struct dentry___85 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___61 {
	struct vm_struct___61 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___85 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___75 {
	struct task_struct___85 task;
	long unsigned int stack[8192];
};

struct bus_type___78 {
	const char *name;
	const char *dev_name;
	struct device___78 *dev_root;
	const struct attribute_group___77 **bus_groups;
	const struct attribute_group___77 **dev_groups;
	const struct attribute_group___77 **drv_groups;
	int (*match)(struct device___78 *, struct device_driver___78 *);
	int (*uevent)(struct device___78 *, struct kobj_uevent_env *);
	int (*probe)(struct device___78 *);
	int (*remove)(struct device___78 *);
	void (*shutdown)(struct device___78 *);
	int (*online)(struct device___78 *);
	int (*offline)(struct device___78 *);
	int (*suspend)(struct device___78 *, pm_message_t);
	int (*resume)(struct device___78 *);
	int (*num_vf)(struct device___78 *);
	int (*dma_configure)(struct device___78 *);
	const struct dev_pm_ops___78 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___78 {
	const char *name;
	struct bus_type___78 *bus;
	struct module___11 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___78 *);
	int (*remove)(struct device___78 *);
	void (*shutdown)(struct device___78 *);
	int (*suspend)(struct device___78 *, pm_message_t);
	int (*resume)(struct device___78 *);
	const struct attribute_group___77 **groups;
	const struct dev_pm_ops___78 *pm;
	void (*coredump)(struct device___78 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___78 {
	const char *name;
	const struct attribute_group___77 **groups;
	int (*uevent)(struct device___78 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___78 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___78 *);
	const struct dev_pm_ops___78 *pm;
};

struct class___78 {
	const char *name;
	struct module___11 *owner;
	const struct attribute_group___77 **class_groups;
	const struct attribute_group___77 **dev_groups;
	struct kobject___80 *dev_kobj;
	int (*dev_uevent)(struct device___78 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___78 *, umode_t *);
	void (*class_release)(struct class___78 *);
	void (*dev_release)(struct device___78 *);
	int (*shutdown_pre)(struct device___78 *);
	const struct kobj_ns_type_operations___3 *ns_type;
	const void * (*namespace)(struct device___78 *);
	const struct dev_pm_ops___78 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct fwnode_operations___57;

struct fwnode_handle___57 {
	struct fwnode_handle___57 *secondary;
	const struct fwnode_operations___57 *ops;
};

struct property___26;

struct device_node___27 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___57 fwnode;
	struct property___26 *properties;
	struct property___26 *deadprops;
	struct device_node___27 *parent;
	struct device_node___27 *child;
	struct device_node___27 *sibling;
	struct kobject___80 kobj;
	long unsigned int _flags;
	void *data;
};

struct node___68 {
	struct device___78 dev;
};

struct address_space_operations___84;

struct address_space___84 {
	struct inode___86 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___85 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___84 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___83)(struct vm_area_struct___85 *, long unsigned int, const struct page___85 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___83)(struct page___85 *, void *);

struct dev_pagemap___83 {
	dev_page_fault_t___83 page_fault;
	dev_page_free_t___83 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___78 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___84 {
	struct task_struct___85 *task;
	struct core_thread___84 *next;
};

struct core_state___84 {
	atomic_t nr_threads;
	struct core_thread___84 dumper;
	struct completion startup;
};

struct vm_fault___83 {
	struct vm_area_struct___85 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___85 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___85 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___84 prealloc_pte;
};

struct dentry_operations___84;

struct super_block___85;

struct dentry___85 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___85 *d_parent;
	struct qstr d_name;
	struct inode___86 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___84 *d_op;
	struct super_block___85 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___84;

struct block_device___85;

struct inode___86 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___84 *i_op;
	struct super_block___85 *i_sb;
	struct address_space___84 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___85 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___34 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___85 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___84 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___85 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___84 {
	int (*d_revalidate)(struct dentry___85 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___85 *, unsigned int);
	int (*d_hash)(const struct dentry___85 *, struct qstr *);
	int (*d_compare)(const struct dentry___85 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___85 *);
	int (*d_init)(struct dentry___85 *);
	void (*d_release)(struct dentry___85 *);
	void (*d_prune)(struct dentry___85 *);
	void (*d_iput)(struct dentry___85 *, struct inode___86 *);
	char * (*d_dname)(struct dentry___85 *, char *, int);
	struct vfsmount___13 * (*d_automount)(struct path___84 *);
	int (*d_manage)(const struct path___84 *, bool);
	struct dentry___85 * (*d_real)(struct dentry___85 *, const struct inode___86 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___84;

struct mem_dqinfo___84 {
	struct quota_format_type___84 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___84;

struct quota_info___84 {
	unsigned int flags;
	struct rw_semaphore___85 dqio_sem;
	struct inode___86 *files[3];
	struct mem_dqinfo___84 info[3];
	const struct quota_format_ops___84 *ops[3];
};

struct rcuwait___84 {
	struct task_struct___85 *task;
};

struct percpu_rw_semaphore___84 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___85 rw_sem;
	struct rcuwait___84 writer;
	int readers_block;
};

struct sb_writers___84 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___84 rw_sem[3];
};

struct file_system_type___84;

struct super_operations___84;

struct dquot_operations___84;

struct quotactl_ops___84;

struct super_block___85 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___84 *s_type;
	const struct super_operations___84 *s_op;
	const struct dquot_operations___84 *dq_op;
	const struct quotactl_ops___84 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___85 *s_root;
	struct rw_semaphore___85 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___85 *s_bdev;
	struct backing_dev_info___34 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___84 s_dquot;
	struct sb_writers___84 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___84 *s_d_op;
	int cleancache_poolid;
	struct shrinker___31 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___70 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___13 {
	struct dentry___85 *mnt_root;
	struct super_block___85 *mnt_sb;
	int mnt_flags;
};

struct io_cq___15 {
	struct request_queue___16 *q;
	struct io_context___15 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___85 {
	struct file___85 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___85 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___85 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___85 *ia_file;
};

struct dquot___84 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___85 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___84 {
	int qf_fmt_id;
	const struct quota_format_ops___84 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___84 *qf_next;
};

struct quota_format_ops___84 {
	int (*check_quota_file)(struct super_block___85 *, int);
	int (*read_file_info)(struct super_block___85 *, int);
	int (*write_file_info)(struct super_block___85 *, int);
	int (*free_file_info)(struct super_block___85 *, int);
	int (*read_dqblk)(struct dquot___84 *);
	int (*commit_dqblk)(struct dquot___84 *);
	int (*release_dqblk)(struct dquot___84 *);
	int (*get_next_id)(struct super_block___85 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___84 {
	int (*write_dquot)(struct dquot___84 *);
	struct dquot___84 * (*alloc_dquot)(struct super_block___85 *, int);
	void (*destroy_dquot)(struct dquot___84 *);
	int (*acquire_dquot)(struct dquot___84 *);
	int (*release_dquot)(struct dquot___84 *);
	int (*mark_dirty)(struct dquot___84 *);
	int (*write_info)(struct super_block___85 *, int);
	qsize_t * (*get_reserved_space)(struct inode___86 *);
	int (*get_projid)(struct inode___86 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___86 *, qsize_t *);
	int (*get_next_id)(struct super_block___85 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___84 {
	int (*quota_on)(struct super_block___85 *, int, int, const struct path___84 *);
	int (*quota_off)(struct super_block___85 *, int);
	int (*quota_enable)(struct super_block___85 *, unsigned int);
	int (*quota_disable)(struct super_block___85 *, unsigned int);
	int (*quota_sync)(struct super_block___85 *, int);
	int (*set_info)(struct super_block___85 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___85 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___85 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___85 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___85 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___85 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___32;

struct address_space_operations___84 {
	int (*writepage)(struct page___85 *, struct writeback_control___32 *);
	int (*readpage)(struct file___85 *, struct page___85 *);
	int (*writepages)(struct address_space___84 *, struct writeback_control___32 *);
	int (*set_page_dirty)(struct page___85 *);
	int (*readpages)(struct file___85 *, struct address_space___84 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___85 *, struct address_space___84 *, loff_t, unsigned int, unsigned int, struct page___85 **, void **);
	int (*write_end)(struct file___85 *, struct address_space___84 *, loff_t, unsigned int, unsigned int, struct page___85 *, void *);
	sector_t (*bmap)(struct address_space___84 *, sector_t);
	void (*invalidatepage)(struct page___85 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___85 *, gfp_t);
	void (*freepage)(struct page___85 *);
	ssize_t (*direct_IO)(struct kiocb___85 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___84 *, struct page___85 *, struct page___85 *, enum migrate_mode);
	bool (*isolate_page)(struct page___85 *, isolate_mode_t);
	void (*putback_page)(struct page___85 *);
	int (*launder_page)(struct page___85 *);
	int (*is_partially_uptodate)(struct page___85 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___85 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___84 *, struct page___85 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___85 *, sector_t *);
	void (*swap_deactivate)(struct file___85 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___32 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___34 *wb;
	struct inode___86 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct hd_struct___16;

struct gendisk___16;

struct block_device___85 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___86 *bd_inode;
	struct super_block___85 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___85 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___16 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___16 *bd_disk;
	struct request_queue___16 *bd_queue;
	struct backing_dev_info___34 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct hd_struct___16 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___78 __dev;
	struct kobject___80 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___16;

struct block_device_operations___16;

struct gendisk___16 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___16 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___16 *part_tbl;
	struct hd_struct___16 part0;
	const struct block_device_operations___16 *fops;
	struct request_queue___16 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___85 lookup_sem;
	struct kobject___80 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___80 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___84 {
	struct dentry___85 * (*lookup)(struct inode___86 *, struct dentry___85 *, unsigned int);
	const char * (*get_link)(struct dentry___85 *, struct inode___86 *, struct delayed_call *);
	int (*permission)(struct inode___86 *, int);
	struct posix_acl * (*get_acl)(struct inode___86 *, int);
	int (*readlink)(struct dentry___85 *, char *, int);
	int (*create)(struct inode___86 *, struct dentry___85 *, umode_t, bool);
	int (*link)(struct dentry___85 *, struct inode___86 *, struct dentry___85 *);
	int (*unlink)(struct inode___86 *, struct dentry___85 *);
	int (*symlink)(struct inode___86 *, struct dentry___85 *, const char *);
	int (*mkdir)(struct inode___86 *, struct dentry___85 *, umode_t);
	int (*rmdir)(struct inode___86 *, struct dentry___85 *);
	int (*mknod)(struct inode___86 *, struct dentry___85 *, umode_t, dev_t);
	int (*rename)(struct inode___86 *, struct dentry___85 *, struct inode___86 *, struct dentry___85 *, unsigned int);
	int (*setattr)(struct dentry___85 *, struct iattr___85 *);
	int (*getattr)(const struct path___84 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___85 *, char *, size_t);
	int (*fiemap)(struct inode___86 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___86 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___86 *, struct dentry___85 *, struct file___85 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___86 *, struct dentry___85 *, umode_t);
	int (*set_acl)(struct inode___86 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___84 {
	void (*fl_copy_lock)(struct file_lock___85 *, struct file_lock___85 *);
	void (*fl_release_private)(struct file_lock___85 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___84;

struct lock_manager_operations___84;

struct file_lock___85 {
	struct file_lock___85 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___85 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___84 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___84 *fl_ops;
	const struct lock_manager_operations___84 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___84 {
	int (*lm_compare_owner)(struct file_lock___85 *, struct file_lock___85 *);
	long unsigned int (*lm_owner_key)(struct file_lock___85 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___85 *);
	int (*lm_grant)(struct file_lock___85 *, int);
	bool (*lm_break)(struct file_lock___85 *);
	int (*lm_change)(struct file_lock___85 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___85 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___84 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___84 *fa_next;
	struct file___85 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___84 {
	const char *name;
	int fs_flags;
	struct dentry___85 * (*mount)(struct file_system_type___84 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___85 *);
	struct module___11 *owner;
	struct file_system_type___84 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___84 {
	struct inode___86 * (*alloc_inode)(struct super_block___85 *);
	void (*destroy_inode)(struct inode___86 *);
	void (*dirty_inode)(struct inode___86 *, int);
	int (*write_inode)(struct inode___86 *, struct writeback_control___32 *);
	int (*drop_inode)(struct inode___86 *);
	void (*evict_inode)(struct inode___86 *);
	void (*put_super)(struct super_block___85 *);
	int (*sync_fs)(struct super_block___85 *, int);
	int (*freeze_super)(struct super_block___85 *);
	int (*freeze_fs)(struct super_block___85 *);
	int (*thaw_super)(struct super_block___85 *);
	int (*unfreeze_fs)(struct super_block___85 *);
	int (*statfs)(struct dentry___85 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___85 *, int *, char *);
	void (*umount_begin)(struct super_block___85 *);
	int (*show_options)(struct seq_file___79 *, struct dentry___85 *);
	int (*show_devname)(struct seq_file___79 *, struct dentry___85 *);
	int (*show_path)(struct seq_file___79 *, struct dentry___85 *);
	int (*show_stats)(struct seq_file___79 *, struct dentry___85 *);
	ssize_t (*quota_read)(struct super_block___85 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___85 *, int, const char *, size_t, loff_t);
	struct dquot___84 ** (*get_dquots)(struct inode___86 *);
	int (*bdev_try_to_free_page)(struct super_block___85 *, struct page___85 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___85 *, struct shrink_control___31 *);
	long int (*free_cached_objects)(struct super_block___85 *, struct shrink_control___31 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___34(struct bio___34 *);

struct bio_vec___34 {
	struct page___85 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___34;

struct bio___34 {
	struct bio___34 *bi_next;
	struct gendisk___16 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___34 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___8 *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___34 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___34 *bi_io_vec;
	struct bio_set___34 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___34 bi_inline_vecs[0];
};

typedef void compound_page_dtor___83(struct page___85 *);

typedef int (*key_restrict_link_func_t___81)(struct key___82 *, const struct key_type *, const union key_payload *, struct key___82 *);

struct key_restriction___82;

struct key___82 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___85 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___82 *restrict_link;
};

struct key_restriction___82 {
	key_restrict_link_func_t___81 check;
	struct key___82 *key;
	struct key_type *keytype;
};

struct seq_operations___76 {
	void * (*start)(struct seq_file___79 *, loff_t *);
	void (*stop)(struct seq_file___79 *, void *);
	void * (*next)(struct seq_file___79 *, void *, loff_t *);
	int (*show)(struct seq_file___79 *, void *);
};

struct bio_integrity_payload___34 {
	struct bio___34 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___34 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___34 bip_inline_vecs[0];
};

struct blkcg___8;

struct blkg_policy_data___8;

struct blkcg_gq___8 {
	struct request_queue___16 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___8 *blkcg;
	struct bdi_writeback_congested___34 *wb_congested;
	struct blkcg_gq___8 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_rwstat stat_bytes;
	struct blkg_rwstat stat_ios;
	struct blkg_policy_data___8 *pd[5];
	struct callback_head callback_head;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
};

struct disk_part_tbl___16 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___16 *last_lookup;
	struct hd_struct___16 *part[0];
};

struct block_device_operations___16 {
	int (*open)(struct block_device___85 *, fmode_t);
	void (*release)(struct gendisk___16 *, fmode_t);
	int (*rw_page)(struct block_device___85 *, sector_t, struct page___85 *, unsigned int);
	int (*ioctl)(struct block_device___85 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___85 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___16 *, unsigned int);
	int (*media_changed)(struct gendisk___16 *);
	void (*unlock_native_capacity)(struct gendisk___16 *);
	int (*revalidate_disk)(struct gendisk___16 *);
	int (*getgeo)(struct block_device___85 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___85 *, long unsigned int);
	int (*report_zones)(struct gendisk___16 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___11 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bdi_writeback_congested___34 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___34 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct cgroup_subsys___68;

struct cgroup_subsys_state___68 {
	struct cgroup___68 *cgroup;
	struct cgroup_subsys___68 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___68 *parent;
};

struct bsg_ops___15 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___16 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___16 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___16 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___15(struct request___16 *, blk_status_t);

struct request___16 {
	struct request_queue___16 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___34 *bio;
	struct bio___34 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___34 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___15 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___15 *saved_end_io;
		} flush;
	};
	struct gendisk___16 *rq_disk;
	struct hd_struct___16 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___15 *end_io;
	void *end_io_data;
	struct request___16 *next_rq;
};

struct fwnode_reference_args___57;

struct fwnode_endpoint___57;

struct fwnode_operations___57 {
	struct fwnode_handle___57 * (*get)(struct fwnode_handle___57 *);
	void (*put)(struct fwnode_handle___57 *);
	bool (*device_is_available)(const struct fwnode_handle___57 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___57 *, const struct device___78 *);
	bool (*property_present)(const struct fwnode_handle___57 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___57 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___57 *, const char *, const char **, size_t);
	struct fwnode_handle___57 * (*get_parent)(const struct fwnode_handle___57 *);
	struct fwnode_handle___57 * (*get_next_child_node)(const struct fwnode_handle___57 *, struct fwnode_handle___57 *);
	struct fwnode_handle___57 * (*get_named_child_node)(const struct fwnode_handle___57 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___57 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___57 *);
	struct fwnode_handle___57 * (*graph_get_next_endpoint)(const struct fwnode_handle___57 *, struct fwnode_handle___57 *);
	struct fwnode_handle___57 * (*graph_get_remote_endpoint)(const struct fwnode_handle___57 *);
	struct fwnode_handle___57 * (*graph_get_port_parent)(struct fwnode_handle___57 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___57 *, struct fwnode_endpoint___57 *);
};

struct fwnode_endpoint___57 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___57 *local_fwnode;
};

struct fwnode_reference_args___57 {
	struct fwnode_handle___57 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct elevator_type___15;

struct elevator_mq_ops___15 {
	int (*init_sched)(struct request_queue___16 *, struct elevator_type___15 *);
	void (*exit_sched)(struct elevator_queue___15 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	bool (*allow_merge)(struct request_queue___16 *, struct request___16 *, struct bio___34 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx *, struct bio___34 *);
	int (*request_merge)(struct request_queue___16 *, struct request___16 **, struct bio___34 *);
	void (*request_merged)(struct request_queue___16 *, struct request___16 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___16 *, struct request___16 *, struct request___16 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___16 *, struct bio___34 *);
	void (*finish_request)(struct request___16 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___16 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___16 *, u64);
	void (*started_request)(struct request___16 *);
	void (*requeue_request)(struct request___16 *);
	struct request___16 * (*former_request)(struct request_queue___16 *, struct request___16 *);
	struct request___16 * (*next_request)(struct request_queue___16 *, struct request___16 *);
	void (*init_icq)(struct io_cq___15 *);
	void (*exit_icq)(struct io_cq___15 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___15;

struct elevator_type___15 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___15 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___15 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___11 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___15 {
	struct elevator_type___15 *type;
	void *elevator_data;
	struct kobject___80 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___15 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___15 *, char *);
	ssize_t (*store)(struct elevator_queue___15 *, const char *, size_t);
};

struct cgroup_namespace___68 {
	refcount_t count;
	struct ns_common___5 ns;
	struct user_namespace___70 *user_ns;
	struct ucounts___70 *ucounts;
	struct css_set___68 *root_cset;
};

struct ucounts___70 {
	struct hlist_node node;
	struct user_namespace___70 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___68;

struct bpf_map_ops___68 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___68 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___68 *, struct file___85 *);
	void (*map_free)(struct bpf_map___68 *);
	int (*map_get_next_key)(struct bpf_map___68 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___68 *);
	void * (*map_lookup_elem)(struct bpf_map___68 *, void *);
	int (*map_update_elem)(struct bpf_map___68 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___68 *, void *);
	int (*map_push_elem)(struct bpf_map___68 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___68 *, void *);
	int (*map_peek_elem)(struct bpf_map___68 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___68 *, struct file___85 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___68 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___68 *, void *, struct seq_file___79 *);
	int (*map_check_btf)(const struct bpf_map___68 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___68 {
	const struct bpf_map_ops___68 *ops;
	struct bpf_map___68 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___81 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___68;

typedef void (*kthread_work_func_t___68)(struct kthread_work___68 *);

struct kthread_worker___68;

struct kthread_work___68 {
	struct list_head node;
	kthread_work_func_t___68 func;
	struct kthread_worker___68 *worker;
	int canceling;
};

struct kthread_worker___68 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___85 *task;
	struct kthread_work___68 *current_work;
};

struct kthread_delayed_work___68 {
	struct kthread_work___68 work;
	struct timer_list timer;
};

struct psi_group___68 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___68 *poll_kworker;
	struct kthread_delayed_work___68 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___68 {
	struct kernfs_node___82 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_root___68;

struct cgroup_rstat_cpu___68;

struct cgroup___68 {
	struct cgroup_subsys_state___68 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___82 *kn;
	struct cgroup_file___68 procs_file;
	struct cgroup_file___68 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___68 *subsys[13];
	struct cgroup_root___68 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___68 *dom_cgrp;
	struct cgroup_rstat_cpu___68 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___6 bpf;
	atomic_t congestion_count;
	struct cgroup___68 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___68 psi;
	int ancestor_ids[0];
};

struct cftype___68;

struct cgroup_subsys___68 {
	struct cgroup_subsys_state___68 * (*css_alloc)(struct cgroup_subsys_state___68 *);
	int (*css_online)(struct cgroup_subsys_state___68 *);
	void (*css_offline)(struct cgroup_subsys_state___68 *);
	void (*css_released)(struct cgroup_subsys_state___68 *);
	void (*css_free)(struct cgroup_subsys_state___68 *);
	void (*css_reset)(struct cgroup_subsys_state___68 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___68 *, int);
	int (*css_extra_stat_show)(struct seq_file___79 *, struct cgroup_subsys_state___68 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___85 *);
	void (*cancel_fork)(struct task_struct___85 *);
	void (*fork)(struct task_struct___85 *);
	void (*exit)(struct task_struct___85 *);
	void (*free)(struct task_struct___85 *);
	void (*bind)(struct cgroup_subsys_state___68 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___68 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___68 *dfl_cftypes;
	struct cftype___68 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___68 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___68 *updated_children;
	struct cgroup___68 *updated_next;
};

struct cgroup_root___68 {
	struct kernfs_root___82 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___68 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___68 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___68 *ss;
	struct list_head node;
	struct kernfs_ops___82 *kf_ops;
	int (*open)(struct kernfs_open_file___82 *);
	void (*release)(struct kernfs_open_file___82 *);
	u64 (*read_u64)(struct cgroup_subsys_state___68 *, struct cftype___68 *);
	s64 (*read_s64)(struct cgroup_subsys_state___68 *, struct cftype___68 *);
	int (*seq_show)(struct seq_file___79 *, void *);
	void * (*seq_start)(struct seq_file___79 *, loff_t *);
	void * (*seq_next)(struct seq_file___79 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___79 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___68 *, struct cftype___68 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___68 *, struct cftype___68 *, s64);
	ssize_t (*write)(struct kernfs_open_file___82 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___82 *, struct poll_table_struct___6 *);
};

struct css_task_iter___4 {
	struct cgroup_subsys___68 *ss;
	unsigned int flags;
	struct list_head *cset_pos;
	struct list_head *cset_head;
	struct list_head *tcset_pos;
	struct list_head *tcset_head;
	struct list_head *task_pos;
	struct list_head *tasks_head;
	struct list_head *mg_tasks_head;
	struct css_set___68 *cur_cset;
	struct css_set___68 *cur_dcset;
	struct task_struct___85 *cur_task;
	struct list_head iters_node;
};

struct blkcg_policy_data___8;

struct blkcg___8 {
	struct cgroup_subsys_state___68 css;
	spinlock_t lock;
	struct xarray blkg_tree;
	struct blkcg_gq___8 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___8 *cpd[5];
	struct list_head all_blkcgs_node;
	struct list_head cgwb_list;
	refcount_t cgwb_refcnt;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct blkcg_policy_data___8 {
	struct blkcg___8 *blkcg;
	int plid;
};

struct blkg_policy_data___8 {
	struct blkcg_gq___8 *blkg;
	int plid;
};

struct property___26 {
	char *name;
	int length;
	void *value;
	struct property___26 *next;
	long unsigned int _flags;
	struct bin_attribute___77 attr;
};

struct fmeter {
	int cnt;
	int val;
	time64_t time;
	spinlock_t lock;
};

struct cpuset {
	struct cgroup_subsys_state___68 css;
	long unsigned int flags;
	cpumask_var_t cpus_allowed;
	nodemask_t mems_allowed;
	cpumask_var_t effective_cpus;
	nodemask_t effective_mems;
	cpumask_var_t subparts_cpus;
	nodemask_t old_mems_allowed;
	struct fmeter fmeter;
	int attach_in_progress;
	int pn;
	int relax_domain_level;
	int nr_subparts_cpus;
	int partition_root_state;
	int use_parent_ecpus;
	int child_ecpus_count;
};

struct tmpmasks {
	cpumask_var_t addmask;
	cpumask_var_t delmask;
	cpumask_var_t new_cpus;
};

typedef enum {
	CS_ONLINE = 0,
	CS_CPU_EXCLUSIVE = 1,
	CS_MEM_EXCLUSIVE = 2,
	CS_MEM_HARDWALL = 3,
	CS_MEMORY_MIGRATE = 4,
	CS_SCHED_LOAD_BALANCE = 5,
	CS_SPREAD_PAGE = 6,
	CS_SPREAD_SLAB = 7,
} cpuset_flagbits_t;

enum subparts_cmd {
	partcmd_enable = 0,
	partcmd_disable = 1,
	partcmd_update = 2,
};

struct cpuset_migrate_mm_work {
	struct work_struct work;
	struct mm_struct___84 *mm;
	nodemask_t from;
	nodemask_t to;
};

typedef enum {
	FILE_MEMORY_MIGRATE = 0,
	FILE_CPULIST = 1,
	FILE_MEMLIST = 2,
	FILE_EFFECTIVE_CPULIST = 3,
	FILE_EFFECTIVE_MEMLIST = 4,
	FILE_SUBPARTS_CPULIST = 5,
	FILE_CPU_EXCLUSIVE = 6,
	FILE_MEM_EXCLUSIVE = 7,
	FILE_MEM_HARDWALL = 8,
	FILE_SCHED_LOAD_BALANCE = 9,
	FILE_PARTITION_ROOT = 10,
	FILE_SCHED_RELAX_DOMAIN_LEVEL = 11,
	FILE_MEMORY_PRESSURE_ENABLED = 12,
	FILE_MEMORY_PRESSURE = 13,
	FILE_SPREAD_PAGE = 14,
	FILE_SPREAD_SLAB = 15,
} cpuset_filetype_t;

struct file___86;

struct kiocb___86;

struct vm_area_struct___86;

struct inode___87;

struct file_lock___86;

struct page___86;

struct file_operations___86 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___86 *, loff_t, int);
	ssize_t (*read)(struct file___86 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___86 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___86 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___86 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___86 *, bool);
	int (*iterate)(struct file___86 *, struct dir_context *);
	int (*iterate_shared)(struct file___86 *, struct dir_context *);
	__poll_t (*poll)(struct file___86 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___86 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___86 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___86 *, struct vm_area_struct___86 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___87 *, struct file___86 *);
	int (*flush)(struct file___86 *, fl_owner_t);
	int (*release)(struct inode___87 *, struct file___86 *);
	int (*fsync)(struct file___86 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___86 *, int);
	int (*lock)(struct file___86 *, int, struct file_lock___86 *);
	ssize_t (*sendpage)(struct file___86 *, struct page___86 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___86 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___86 *, int, struct file_lock___86 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___86 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___86 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___86 *, long int, struct file_lock___86 **, void **);
	long int (*fallocate)(struct file___86 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___2 *, struct file___86 *);
	ssize_t (*copy_file_range)(struct file___86 *, loff_t, struct file___86 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___86 *, loff_t, struct file___86 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___86 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___85 {
	u64 seqnum;
	struct vm_area_struct___86 *vmas[4];
};

struct page_frag___85 {
	struct page___86 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___85;

struct cred___82;

struct fs_struct___5;

struct signal_struct___76;

struct task_struct___86 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___86 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___85 *mm;
	struct mm_struct___85 *active_mm;
	struct vmacache___85 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___86 *real_parent;
	struct task_struct___86 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___86 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___70 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___70 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___70 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___82 *ptracer_cred;
	const struct cred___82 *real_cred;
	const struct cred___82 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct___5 *fs;
	struct files_struct *files;
	struct nsproxy___79 *nsproxy;
	struct signal_struct___76 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___86 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___15 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___85 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___86 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___53 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct proc_ns_operations___6;

struct ns_common___6 {
	atomic_long_t stashed;
	const struct proc_ns_operations___6 *ops;
	unsigned int inum;
};

struct rw_semaphore___86 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___86 *owner;
};

struct ucounts___71;

struct user_namespace___71 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___71 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___6 ns;
	long unsigned int flags;
	struct key___2 *persistent_keyring_register;
	struct rw_semaphore___86 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___71 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct secondary_data___86 {
	void *stack;
	struct task_struct___86 *task;
	long int status;
};

typedef struct page___86 *pgtable_t___85;

struct address_space___85;

struct page___86 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___85 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___86 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___85 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___85 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___83 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct user_struct___82 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___2 *uid_keyring;
	struct key___2 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_area_struct___86 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___86 *vm_next;
	struct vm_area_struct___86 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___85 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___13 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___86 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___85;

struct mm_struct___85 {
	struct {
		struct vm_area_struct___86 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___86 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___86 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___85 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___86 *owner;
		struct user_namespace___71 *user_ns;
		struct file___86 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___85 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___82 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___2 *session_keyring;
	struct key___2 *process_keyring;
	struct key___2 *thread_keyring;
	struct key___2 *request_key_auth;
	void *security;
	struct user_struct___82 *user;
	struct user_namespace___71 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct dentry___86;

struct path___85 {
	struct vfsmount *mnt;
	struct dentry___86 *dentry;
};

struct fs_struct___5 {
	int users;
	spinlock_t lock;
	seqcount_t seq;
	int umask;
	int in_exec;
	struct path___85 root;
	struct path___85 pwd;
};

struct signal_struct___76 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___86 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___86 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___70 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___70 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___85 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___70 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

union thread_union___76 {
	struct task_struct___86 task;
	long unsigned int stack[8192];
};

struct pglist_data___85;

struct lruvec___85 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___85 *pgdat;
};

struct zone___85 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___85 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___85 {
	struct zone___85 *zone;
	int zone_idx;
};

struct zonelist___85 {
	struct zoneref___85 _zonerefs[25];
};

struct pglist_data___85 {
	struct zone___85 node_zones[3];
	struct zonelist___85 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___86 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___86 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___85 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___85 {
	struct rw_semaphore___86 rwsem;
	struct notifier_block *head;
};

typedef int (*key_restrict_link_func_t___82)(struct key___2 *, const struct key_type *, const union key_payload *, struct key___2 *);

struct key___2 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___86 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction *restrict_link;
};

struct key_restriction {
	key_restrict_link_func_t___82 check;
	struct key___2 *key;
	struct key_type *keytype;
};

struct proc_ns_operations___6 {
	const char *name;
	const char *real_ns_name;
	int type;
	struct ns_common___6 * (*get)(struct task_struct___86 *);
	void (*put)(struct ns_common___6 *);
	int (*install)(struct nsproxy___79 *, struct ns_common___6 *);
	struct user_namespace___71 * (*owner)(struct ns_common___6 *);
	struct ns_common___6 * (*get_parent)(struct ns_common___6 *);
};

struct ucounts___71 {
	struct hlist_node node;
	struct user_namespace___71 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct seq_operations___77 {
	void * (*start)(struct seq_file___2 *, loff_t *);
	void (*stop)(struct seq_file___2 *, void *);
	void * (*next)(struct seq_file___2 *, void *, loff_t *);
	int (*show)(struct seq_file___2 *, void *);
};

struct key_construction {
	struct key___2 *key;
	struct key___2 *authkey;
};

struct key_preparsed_payload {
	char *description;
	union key_payload payload;
	const void *data;
	size_t datalen;
	size_t quotalen;
	time64_t expiry;
};

struct key_match_data {
	bool (*cmp)(const struct key___2 *, const struct key_match_data *);
	const void *raw_data;
	void *preparsed;
	unsigned int lookup_type;
};

struct seq_file___2 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___77 *op;
	int poll_event;
	const struct file___86 *file;
	void *private;
};

struct dentry_operations___85;

struct super_block___86;

struct dentry___86 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___86 *d_parent;
	struct qstr d_name;
	struct inode___87 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___85 *d_op;
	struct super_block___86 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___85;

struct address_space___85 {
	struct inode___87 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___86 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___85 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___85;

struct block_device___86;

struct inode___87 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___85 *i_op;
	struct super_block___86 *i_sb;
	struct address_space___85 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___86 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___86 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___85 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___86 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___85 {
	int (*d_revalidate)(struct dentry___86 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___86 *, unsigned int);
	int (*d_hash)(const struct dentry___86 *, struct qstr *);
	int (*d_compare)(const struct dentry___86 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___86 *);
	int (*d_init)(struct dentry___86 *);
	void (*d_release)(struct dentry___86 *);
	void (*d_prune)(struct dentry___86 *);
	void (*d_iput)(struct dentry___86 *, struct inode___87 *);
	char * (*d_dname)(struct dentry___86 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___85 *);
	int (*d_manage)(const struct path___85 *, bool);
	struct dentry___86 * (*d_real)(struct dentry___86 *, const struct inode___87 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___85;

struct mem_dqinfo___85 {
	struct quota_format_type___85 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___85;

struct quota_info___85 {
	unsigned int flags;
	struct rw_semaphore___86 dqio_sem;
	struct inode___87 *files[3];
	struct mem_dqinfo___85 info[3];
	const struct quota_format_ops___85 *ops[3];
};

struct rcuwait___85 {
	struct task_struct___86 *task;
};

struct percpu_rw_semaphore___85 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___86 rw_sem;
	struct rcuwait___85 writer;
	int readers_block;
};

struct sb_writers___85 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___85 rw_sem[3];
};

struct file_system_type___85;

struct super_operations___85;

struct dquot_operations___85;

struct quotactl_ops___85;

struct super_block___86 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___85 *s_type;
	const struct super_operations___85 *s_op;
	const struct dquot_operations___85 *dq_op;
	const struct quotactl_ops___85 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___86 *s_root;
	struct rw_semaphore___86 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___86 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___85 s_dquot;
	struct sb_writers___85 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___85 *s_d_op;
	int cleancache_poolid;
	struct shrinker___31 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___71 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct file___86 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___85 f_path;
	struct inode___87 *f_inode;
	const struct file_operations___86 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___70 f_owner;
	const struct cred___82 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___85 *f_mapping;
	errseq_t f_wb_err;
};

struct core_thread___85 {
	struct task_struct___86 *task;
	struct core_thread___85 *next;
};

struct core_state___85 {
	atomic_t nr_threads;
	struct core_thread___85 dumper;
	struct completion startup;
};

struct kiocb___86 {
	struct file___86 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___86 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___86 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___86 *ia_file;
};

struct dquot___85 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___86 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___85 {
	int qf_fmt_id;
	const struct quota_format_ops___85 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___85 *qf_next;
};

struct quota_format_ops___85 {
	int (*check_quota_file)(struct super_block___86 *, int);
	int (*read_file_info)(struct super_block___86 *, int);
	int (*write_file_info)(struct super_block___86 *, int);
	int (*free_file_info)(struct super_block___86 *, int);
	int (*read_dqblk)(struct dquot___85 *);
	int (*commit_dqblk)(struct dquot___85 *);
	int (*release_dqblk)(struct dquot___85 *);
	int (*get_next_id)(struct super_block___86 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___85 {
	int (*write_dquot)(struct dquot___85 *);
	struct dquot___85 * (*alloc_dquot)(struct super_block___86 *, int);
	void (*destroy_dquot)(struct dquot___85 *);
	int (*acquire_dquot)(struct dquot___85 *);
	int (*release_dquot)(struct dquot___85 *);
	int (*mark_dirty)(struct dquot___85 *);
	int (*write_info)(struct super_block___86 *, int);
	qsize_t * (*get_reserved_space)(struct inode___87 *);
	int (*get_projid)(struct inode___87 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___87 *, qsize_t *);
	int (*get_next_id)(struct super_block___86 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___85 {
	int (*quota_on)(struct super_block___86 *, int, int, const struct path___85 *);
	int (*quota_off)(struct super_block___86 *, int);
	int (*quota_enable)(struct super_block___86 *, unsigned int);
	int (*quota_disable)(struct super_block___86 *, unsigned int);
	int (*quota_sync)(struct super_block___86 *, int);
	int (*set_info)(struct super_block___86 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___86 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___86 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___86 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___86 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___86 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___85 {
	int (*writepage)(struct page___86 *, struct writeback_control___3 *);
	int (*readpage)(struct file___86 *, struct page___86 *);
	int (*writepages)(struct address_space___85 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___86 *);
	int (*readpages)(struct file___86 *, struct address_space___85 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___86 *, struct address_space___85 *, loff_t, unsigned int, unsigned int, struct page___86 **, void **);
	int (*write_end)(struct file___86 *, struct address_space___85 *, loff_t, unsigned int, unsigned int, struct page___86 *, void *);
	sector_t (*bmap)(struct address_space___85 *, sector_t);
	void (*invalidatepage)(struct page___86 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___86 *, gfp_t);
	void (*freepage)(struct page___86 *);
	ssize_t (*direct_IO)(struct kiocb___86 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___85 *, struct page___86 *, struct page___86 *, enum migrate_mode);
	bool (*isolate_page)(struct page___86 *, isolate_mode_t);
	void (*putback_page)(struct page___86 *);
	int (*launder_page)(struct page___86 *);
	int (*is_partially_uptodate)(struct page___86 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___86 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___85 *, struct page___86 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___86 *, sector_t *);
	void (*swap_deactivate)(struct file___86 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___86 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___87 *bd_inode;
	struct super_block___86 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___86 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___85 {
	struct dentry___86 * (*lookup)(struct inode___87 *, struct dentry___86 *, unsigned int);
	const char * (*get_link)(struct dentry___86 *, struct inode___87 *, struct delayed_call *);
	int (*permission)(struct inode___87 *, int);
	struct posix_acl * (*get_acl)(struct inode___87 *, int);
	int (*readlink)(struct dentry___86 *, char *, int);
	int (*create)(struct inode___87 *, struct dentry___86 *, umode_t, bool);
	int (*link)(struct dentry___86 *, struct inode___87 *, struct dentry___86 *);
	int (*unlink)(struct inode___87 *, struct dentry___86 *);
	int (*symlink)(struct inode___87 *, struct dentry___86 *, const char *);
	int (*mkdir)(struct inode___87 *, struct dentry___86 *, umode_t);
	int (*rmdir)(struct inode___87 *, struct dentry___86 *);
	int (*mknod)(struct inode___87 *, struct dentry___86 *, umode_t, dev_t);
	int (*rename)(struct inode___87 *, struct dentry___86 *, struct inode___87 *, struct dentry___86 *, unsigned int);
	int (*setattr)(struct dentry___86 *, struct iattr___86 *);
	int (*getattr)(const struct path___85 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___86 *, char *, size_t);
	int (*fiemap)(struct inode___87 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___87 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___87 *, struct dentry___86 *, struct file___86 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___87 *, struct dentry___86 *, umode_t);
	int (*set_acl)(struct inode___87 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___85 {
	void (*fl_copy_lock)(struct file_lock___86 *, struct file_lock___86 *);
	void (*fl_release_private)(struct file_lock___86 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___85;

struct lock_manager_operations___85;

struct file_lock___86 {
	struct file_lock___86 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___86 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___85 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___85 *fl_ops;
	const struct lock_manager_operations___85 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___85 {
	int (*lm_compare_owner)(struct file_lock___86 *, struct file_lock___86 *);
	long unsigned int (*lm_owner_key)(struct file_lock___86 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___86 *);
	int (*lm_grant)(struct file_lock___86 *, int);
	bool (*lm_break)(struct file_lock___86 *);
	int (*lm_change)(struct file_lock___86 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___86 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___85 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___85 *fa_next;
	struct file___86 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___85 {
	const char *name;
	int fs_flags;
	struct dentry___86 * (*mount)(struct file_system_type___85 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___86 *);
	struct module___11 *owner;
	struct file_system_type___85 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___85 {
	struct inode___87 * (*alloc_inode)(struct super_block___86 *);
	void (*destroy_inode)(struct inode___87 *);
	void (*dirty_inode)(struct inode___87 *, int);
	int (*write_inode)(struct inode___87 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___87 *);
	void (*evict_inode)(struct inode___87 *);
	void (*put_super)(struct super_block___86 *);
	int (*sync_fs)(struct super_block___86 *, int);
	int (*freeze_super)(struct super_block___86 *);
	int (*freeze_fs)(struct super_block___86 *);
	int (*thaw_super)(struct super_block___86 *);
	int (*unfreeze_fs)(struct super_block___86 *);
	int (*statfs)(struct dentry___86 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___86 *, int *, char *);
	void (*umount_begin)(struct super_block___86 *);
	int (*show_options)(struct seq_file___2 *, struct dentry___86 *);
	int (*show_devname)(struct seq_file___2 *, struct dentry___86 *);
	int (*show_path)(struct seq_file___2 *, struct dentry___86 *);
	int (*show_stats)(struct seq_file___2 *, struct dentry___86 *);
	ssize_t (*quota_read)(struct super_block___86 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___86 *, int, const char *, size_t, loff_t);
	struct dquot___85 ** (*get_dquots)(struct inode___87 *);
	int (*bdev_try_to_free_page)(struct super_block___86 *, struct page___86 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___86 *, struct shrink_control___31 *);
	long int (*free_cached_objects)(struct super_block___86 *, struct shrink_control___31 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct idmap_key {
	bool map_up;
	u32 id;
	u32 count;
};

struct module___75;

struct file___87;

struct kiocb___87;

struct poll_table_struct___57;

struct vm_area_struct___87;

struct inode___88;

struct file_lock___87;

struct page___87;

struct seq_file___80;

struct file_operations___87 {
	struct module___75 *owner;
	loff_t (*llseek)(struct file___87 *, loff_t, int);
	ssize_t (*read)(struct file___87 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___87 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___87 *, struct iov_iter___33 *);
	ssize_t (*write_iter)(struct kiocb___87 *, struct iov_iter___33 *);
	int (*iopoll)(struct kiocb___87 *, bool);
	int (*iterate)(struct file___87 *, struct dir_context *);
	int (*iterate_shared)(struct file___87 *, struct dir_context *);
	__poll_t (*poll)(struct file___87 *, struct poll_table_struct___57 *);
	long int (*unlocked_ioctl)(struct file___87 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___87 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___87 *, struct vm_area_struct___87 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___88 *, struct file___87 *);
	int (*flush)(struct file___87 *, fl_owner_t);
	int (*release)(struct inode___88 *, struct file___87 *);
	int (*fsync)(struct file___87 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___87 *, int);
	int (*lock)(struct file___87 *, int, struct file_lock___87 *);
	ssize_t (*sendpage)(struct file___87 *, struct page___87 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___87 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___87 *, int, struct file_lock___87 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___87 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___87 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___87 *, long int, struct file_lock___87 **, void **);
	long int (*fallocate)(struct file___87 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___80 *, struct file___87 *);
	ssize_t (*copy_file_range)(struct file___87 *, loff_t, struct file___87 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___87 *, loff_t, struct file___87 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___87 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___86 {
	u64 seqnum;
	struct vm_area_struct___87 *vmas[4];
};

struct page_frag___86 {
	struct page___87 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___54;

struct debug_info___54 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___54 *hbp_break[16];
	struct perf_event___54 *hbp_watch[16];
};

struct thread_struct___54 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___54 debug;
	long: 64;
};

struct mm_struct___86;

struct pid___71;

struct cred___83;

struct nsproxy___80;

struct signal_struct___77;

struct css_set___69;

struct perf_event_context___54;

struct task_struct___87 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___87 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___86 *mm;
	struct mm_struct___86 *active_mm;
	struct vmacache___86 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___87 *real_parent;
	struct task_struct___87 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___87 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___71 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___71 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___71 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___83 *ptracer_cred;
	const struct cred___83 *real_cred;
	const struct cred___83 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___80 *nsproxy;
	struct signal_struct___77 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___87 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___15 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___69 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___54 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___86 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___87 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___54 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___54 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___87 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___54)(struct perf_event___54 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___54;

struct fasync_struct___86;

struct pid_namespace___71;

struct trace_event_call___49;

struct perf_cgroup___54;

struct perf_event___54 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___54 *group_leader;
	struct pmu___54 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___54 hw;
	struct perf_event_context___54 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___54 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___87 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___86 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___54 *);
	struct callback_head callback_head;
	struct pid_namespace___71 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___54 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___54 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___49 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___54 *cgrp;
	struct list_head sb_list;
};

struct upid___71 {
	int nr;
	struct pid_namespace___71 *ns;
};

struct proc_ns_operations___7;

struct ns_common___7 {
	atomic_long_t stashed;
	const struct proc_ns_operations___7 *ops;
	unsigned int inum;
};

struct dentry___87;

struct user_namespace___72;

struct ucounts___72;

struct pid_namespace___71 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___87 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___71 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___87 *proc_self;
	struct dentry___87 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___72 *user_ns;
	struct ucounts___72 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___7 ns;
};

struct pid___71 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___71 numbers[1];
};

struct rw_semaphore___87 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___87 *owner;
};

struct key___83;

struct user_namespace___72 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___72 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___7 ns;
	long unsigned int flags;
	struct key___83 *persistent_keyring_register;
	struct rw_semaphore___87 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___72 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct secondary_data___87 {
	void *stack;
	struct task_struct___87 *task;
	long int status;
};

typedef struct page___87 *pgtable_t___86;

struct address_space___86;

struct dev_pagemap___84;

struct page___87 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___86 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___87 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___86 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___86 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___84 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct user_struct___83 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___83 *uid_keyring;
	struct key___83 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___84;

struct vm_area_struct___87 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___87 *vm_next;
	struct vm_area_struct___87 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___86 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___84 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___87 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___86;

struct mm_struct___86 {
	struct {
		struct vm_area_struct___87 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___87 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___87 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___86 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___87 *owner;
		struct user_namespace___72 *user_ns;
		struct file___87 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___86 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___83 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___83 *session_keyring;
	struct key___83 *process_keyring;
	struct key___83 *thread_keyring;
	struct key___83 *request_key_auth;
	void *security;
	struct user_struct___83 *user;
	struct user_namespace___72 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___69;

struct nsproxy___80 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___71 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___69 *cgroup_ns;
};

struct signal_struct___77 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___87 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___87 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___71 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___71 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___86 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___71 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___69;

struct cgroup___69;

struct css_set___69 {
	struct cgroup_subsys_state___69 *subsys[13];
	refcount_t refcount;
	struct css_set___69 *dom_cset;
	struct cgroup___69 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___69 *mg_src_cgrp;
	struct cgroup___69 *mg_dst_cgrp;
	struct css_set___69 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___54 {
	struct pmu___54 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___87 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___54 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

union thread_union___77 {
	struct task_struct___87 task;
	long unsigned int stack[8192];
};

struct pglist_data___86;

struct lruvec___86 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___86 *pgdat;
};

struct zone___86 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___86 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___86 {
	struct zone___86 *zone;
	int zone_idx;
};

struct zonelist___86 {
	struct zoneref___86 _zonerefs[25];
};

struct pglist_data___86 {
	struct zone___86 node_zones[3];
	struct zonelist___86 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___87 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___87 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___86 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___86 {
	struct rw_semaphore___87 rwsem;
	struct notifier_block *head;
};

struct address_space_operations___86;

struct address_space___86 {
	struct inode___88 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___87 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___86 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___84)(struct vm_area_struct___87 *, long unsigned int, const struct page___87 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___84)(struct page___87 *, void *);

struct device___79;

struct dev_pagemap___84 {
	dev_page_fault_t___84 page_fault;
	dev_page_free_t___84 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___79 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___86 {
	struct vfsmount *mnt;
	struct dentry___87 *dentry;
};

struct fown_struct___71 {
	rwlock_t lock;
	struct pid___71 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___87 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___86 f_path;
	struct inode___88 *f_inode;
	const struct file_operations___87 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___71 f_owner;
	const struct cred___83 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___86 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___84;

struct vm_operations_struct___84 {
	void (*open)(struct vm_area_struct___87 *);
	void (*close)(struct vm_area_struct___87 *);
	int (*split)(struct vm_area_struct___87 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___87 *);
	vm_fault_t (*fault)(struct vm_fault___84 *);
	vm_fault_t (*huge_fault)(struct vm_fault___84 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___84 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___87 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___84 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___84 *);
	int (*access)(struct vm_area_struct___87 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___87 *);
	int (*set_policy)(struct vm_area_struct___87 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___87 *, long unsigned int);
	struct page___87 * (*find_special_page)(struct vm_area_struct___87 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___86 {
	struct task_struct___87 *task;
	struct core_thread___86 *next;
};

struct core_state___86 {
	atomic_t nr_threads;
	struct core_thread___86 dumper;
	struct completion startup;
};

struct vm_fault___84 {
	struct vm_area_struct___87 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___87 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___87 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___86 prealloc_pte;
};

struct kset___80;

struct kobj_type___80;

struct kernfs_node___83;

struct kobject___81 {
	const char *name;
	struct list_head entry;
	struct kobject___81 *parent;
	struct kset___80 *kset;
	struct kobj_type___80 *ktype;
	struct kernfs_node___83 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___79 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___79 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___79;

struct bus_type___79;

struct device_driver___79;

struct dev_pm_domain___79;

struct class___79;

struct attribute_group___78;

struct device___79 {
	struct device___79 *parent;
	struct device_private *p;
	struct kobject___81 kobj;
	const char *init_name;
	const struct device_type___79 *type;
	struct mutex mutex;
	struct bus_type___79 *bus;
	struct device_driver___79 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___79 power;
	struct dev_pm_domain___79 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___79 *class;
	const struct attribute_group___78 **groups;
	void (*release)(struct device___79 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___86;

struct super_block___87;

struct dentry___87 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___87 *d_parent;
	struct qstr d_name;
	struct inode___88 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___86 *d_op;
	struct super_block___87 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___86;

struct block_device___87;

struct inode___88 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___86 *i_op;
	struct super_block___87 *i_sb;
	struct address_space___86 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___87 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___87 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___86 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___87 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___86 {
	int (*d_revalidate)(struct dentry___87 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___87 *, unsigned int);
	int (*d_hash)(const struct dentry___87 *, struct qstr *);
	int (*d_compare)(const struct dentry___87 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___87 *);
	int (*d_init)(struct dentry___87 *);
	void (*d_release)(struct dentry___87 *);
	void (*d_prune)(struct dentry___87 *);
	void (*d_iput)(struct dentry___87 *, struct inode___88 *);
	char * (*d_dname)(struct dentry___87 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___86 *);
	int (*d_manage)(const struct path___86 *, bool);
	struct dentry___87 * (*d_real)(struct dentry___87 *, const struct inode___88 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___86;

struct mem_dqinfo___86 {
	struct quota_format_type___86 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___86;

struct quota_info___86 {
	unsigned int flags;
	struct rw_semaphore___87 dqio_sem;
	struct inode___88 *files[3];
	struct mem_dqinfo___86 info[3];
	const struct quota_format_ops___86 *ops[3];
};

struct rcuwait___86 {
	struct task_struct___87 *task;
};

struct percpu_rw_semaphore___86 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___87 rw_sem;
	struct rcuwait___86 writer;
	int readers_block;
};

struct sb_writers___86 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___86 rw_sem[3];
};

struct file_system_type___86;

struct super_operations___86;

struct dquot_operations___86;

struct quotactl_ops___86;

struct super_block___87 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___86 *s_type;
	const struct super_operations___86 *s_op;
	const struct dquot_operations___86 *dq_op;
	const struct quotactl_ops___86 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___87 *s_root;
	struct rw_semaphore___87 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___87 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___86 s_dquot;
	struct sb_writers___86 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___86 *s_d_op;
	int cleancache_poolid;
	struct shrinker___31 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___72 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___87 {
	struct file___87 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___87 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___87 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___87 *ia_file;
};

struct dquot___86 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___87 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___86 {
	int qf_fmt_id;
	const struct quota_format_ops___86 *qf_ops;
	struct module___75 *qf_owner;
	struct quota_format_type___86 *qf_next;
};

struct quota_format_ops___86 {
	int (*check_quota_file)(struct super_block___87 *, int);
	int (*read_file_info)(struct super_block___87 *, int);
	int (*write_file_info)(struct super_block___87 *, int);
	int (*free_file_info)(struct super_block___87 *, int);
	int (*read_dqblk)(struct dquot___86 *);
	int (*commit_dqblk)(struct dquot___86 *);
	int (*release_dqblk)(struct dquot___86 *);
	int (*get_next_id)(struct super_block___87 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___86 {
	int (*write_dquot)(struct dquot___86 *);
	struct dquot___86 * (*alloc_dquot)(struct super_block___87 *, int);
	void (*destroy_dquot)(struct dquot___86 *);
	int (*acquire_dquot)(struct dquot___86 *);
	int (*release_dquot)(struct dquot___86 *);
	int (*mark_dirty)(struct dquot___86 *);
	int (*write_info)(struct super_block___87 *, int);
	qsize_t * (*get_reserved_space)(struct inode___88 *);
	int (*get_projid)(struct inode___88 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___88 *, qsize_t *);
	int (*get_next_id)(struct super_block___87 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___86 {
	int (*quota_on)(struct super_block___87 *, int, int, const struct path___86 *);
	int (*quota_off)(struct super_block___87 *, int);
	int (*quota_enable)(struct super_block___87 *, unsigned int);
	int (*quota_disable)(struct super_block___87 *, unsigned int);
	int (*quota_sync)(struct super_block___87 *, int);
	int (*set_info)(struct super_block___87 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___87 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___87 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___87 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___87 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___87 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___72 {
	struct kobject___81 kobj;
	struct module___75 *mod;
	struct kobject___81 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___72 {
	struct module___75 *mod;
	struct latch_tree_node node;
};

struct module_layout___72 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___72 mtn;
};

struct module_attribute___72;

struct kernel_param___72;

struct module___75 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___72 mkobj;
	struct module_attribute___72 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___81 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___72 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___72 core_layout;
	struct module_layout___72 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___49 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___86 {
	int (*writepage)(struct page___87 *, struct writeback_control___3 *);
	int (*readpage)(struct file___87 *, struct page___87 *);
	int (*writepages)(struct address_space___86 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___87 *);
	int (*readpages)(struct file___87 *, struct address_space___86 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___87 *, struct address_space___86 *, loff_t, unsigned int, unsigned int, struct page___87 **, void **);
	int (*write_end)(struct file___87 *, struct address_space___86 *, loff_t, unsigned int, unsigned int, struct page___87 *, void *);
	sector_t (*bmap)(struct address_space___86 *, sector_t);
	void (*invalidatepage)(struct page___87 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___87 *, gfp_t);
	void (*freepage)(struct page___87 *);
	ssize_t (*direct_IO)(struct kiocb___87 *, struct iov_iter___33 *);
	int (*migratepage)(struct address_space___86 *, struct page___87 *, struct page___87 *, enum migrate_mode);
	bool (*isolate_page)(struct page___87 *, isolate_mode_t);
	void (*putback_page)(struct page___87 *);
	int (*launder_page)(struct page___87 *);
	int (*is_partially_uptodate)(struct page___87 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___87 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___86 *, struct page___87 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___87 *, sector_t *);
	void (*swap_deactivate)(struct file___87 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___87 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___88 *bd_inode;
	struct super_block___87 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___87 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___86 {
	struct dentry___87 * (*lookup)(struct inode___88 *, struct dentry___87 *, unsigned int);
	const char * (*get_link)(struct dentry___87 *, struct inode___88 *, struct delayed_call *);
	int (*permission)(struct inode___88 *, int);
	struct posix_acl * (*get_acl)(struct inode___88 *, int);
	int (*readlink)(struct dentry___87 *, char *, int);
	int (*create)(struct inode___88 *, struct dentry___87 *, umode_t, bool);
	int (*link)(struct dentry___87 *, struct inode___88 *, struct dentry___87 *);
	int (*unlink)(struct inode___88 *, struct dentry___87 *);
	int (*symlink)(struct inode___88 *, struct dentry___87 *, const char *);
	int (*mkdir)(struct inode___88 *, struct dentry___87 *, umode_t);
	int (*rmdir)(struct inode___88 *, struct dentry___87 *);
	int (*mknod)(struct inode___88 *, struct dentry___87 *, umode_t, dev_t);
	int (*rename)(struct inode___88 *, struct dentry___87 *, struct inode___88 *, struct dentry___87 *, unsigned int);
	int (*setattr)(struct dentry___87 *, struct iattr___87 *);
	int (*getattr)(const struct path___86 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___87 *, char *, size_t);
	int (*fiemap)(struct inode___88 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___88 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___88 *, struct dentry___87 *, struct file___87 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___88 *, struct dentry___87 *, umode_t);
	int (*set_acl)(struct inode___88 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___86 {
	void (*fl_copy_lock)(struct file_lock___87 *, struct file_lock___87 *);
	void (*fl_release_private)(struct file_lock___87 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___86;

struct file_lock___87 {
	struct file_lock___87 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___87 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___86 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___86 *fl_ops;
	const struct lock_manager_operations___86 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___86 {
	int (*lm_compare_owner)(struct file_lock___87 *, struct file_lock___87 *);
	long unsigned int (*lm_owner_key)(struct file_lock___87 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___87 *);
	int (*lm_grant)(struct file_lock___87 *, int);
	bool (*lm_break)(struct file_lock___87 *);
	int (*lm_change)(struct file_lock___87 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___87 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___86 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___86 *fa_next;
	struct file___87 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___86 {
	const char *name;
	int fs_flags;
	struct dentry___87 * (*mount)(struct file_system_type___86 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___87 *);
	struct module___75 *owner;
	struct file_system_type___86 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___86 {
	struct inode___88 * (*alloc_inode)(struct super_block___87 *);
	void (*destroy_inode)(struct inode___88 *);
	void (*dirty_inode)(struct inode___88 *, int);
	int (*write_inode)(struct inode___88 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___88 *);
	void (*evict_inode)(struct inode___88 *);
	void (*put_super)(struct super_block___87 *);
	int (*sync_fs)(struct super_block___87 *, int);
	int (*freeze_super)(struct super_block___87 *);
	int (*freeze_fs)(struct super_block___87 *);
	int (*thaw_super)(struct super_block___87 *);
	int (*unfreeze_fs)(struct super_block___87 *);
	int (*statfs)(struct dentry___87 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___87 *, int *, char *);
	void (*umount_begin)(struct super_block___87 *);
	int (*show_options)(struct seq_file___80 *, struct dentry___87 *);
	int (*show_devname)(struct seq_file___80 *, struct dentry___87 *);
	int (*show_path)(struct seq_file___80 *, struct dentry___87 *);
	int (*show_stats)(struct seq_file___80 *, struct dentry___87 *);
	ssize_t (*quota_read)(struct super_block___87 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___87 *, int, const char *, size_t, loff_t);
	struct dquot___86 ** (*get_dquots)(struct inode___88 *);
	int (*bdev_try_to_free_page)(struct super_block___87 *, struct page___87 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___87 *, struct shrink_control___31 *);
	long int (*free_cached_objects)(struct super_block___87 *, struct shrink_control___31 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___56)(struct file___87 *, wait_queue_head_t *, struct poll_table_struct___57 *);

struct poll_table_struct___57 {
	poll_queue_proc___56 _qproc;
	__poll_t _key;
};

struct seq_operations___78;

struct seq_file___80 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___78 *op;
	int poll_event;
	const struct file___87 *file;
	void *private;
};

struct kobj_attribute___81 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___81 *, struct kobj_attribute___81 *, char *);
	ssize_t (*store)(struct kobject___81 *, struct kobj_attribute___81 *, const char *, size_t);
};

typedef void compound_page_dtor___84(struct page___87 *);

struct cgroup_namespace___69 {
	refcount_t count;
	struct ns_common___7 ns;
	struct user_namespace___72 *user_ns;
	struct ucounts___72 *ucounts;
	struct css_set___69 *root_cset;
};

struct proc_ns_operations___7 {
	const char *name;
	const char *real_ns_name;
	int type;
	struct ns_common___7 * (*get)(struct task_struct___87 *);
	void (*put)(struct ns_common___7 *);
	int (*install)(struct nsproxy___80 *, struct ns_common___7 *);
	struct user_namespace___72 * (*owner)(struct ns_common___7 *);
	struct ns_common___7 * (*get_parent)(struct ns_common___7 *);
};

struct ucounts___72 {
	struct hlist_node node;
	struct user_namespace___72 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct ctl_path {
	const char *procname;
};

struct key_restriction___83;

struct key___83 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___87 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___83 *restrict_link;
};

struct seq_operations___78 {
	void * (*start)(struct seq_file___80 *, loff_t *);
	void (*stop)(struct seq_file___80 *, void *);
	void * (*next)(struct seq_file___80 *, void *, loff_t *);
	int (*show)(struct seq_file___80 *, void *);
};

typedef int (*key_restrict_link_func_t___83)(struct key___83 *, const struct key_type *, const union key_payload *, struct key___83 *);

struct key_restriction___83 {
	key_restrict_link_func_t___83 check;
	struct key___83 *key;
	struct key_type *keytype;
};

struct kernfs_root___83;

struct kernfs_elem_dir___83 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___83 *root;
};

struct kernfs_syscall_ops___83;

struct kernfs_root___83 {
	struct kernfs_node___83 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___83 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___83 {
	struct kernfs_node___83 *target_kn;
};

struct kernfs_ops___83;

struct kernfs_elem_attr___83 {
	const struct kernfs_ops___83 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___83 *notify_next;
};

struct kernfs_node___83 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___83 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___83 dir;
		struct kernfs_elem_symlink___83 symlink;
		struct kernfs_elem_attr___83 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___83;

struct kernfs_ops___83 {
	int (*open)(struct kernfs_open_file___83 *);
	void (*release)(struct kernfs_open_file___83 *);
	int (*seq_show)(struct seq_file___80 *, void *);
	void * (*seq_start)(struct seq_file___80 *, loff_t *);
	void * (*seq_next)(struct seq_file___80 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___80 *, void *);
	ssize_t (*read)(struct kernfs_open_file___83 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___83 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___83 *, struct vm_area_struct___87 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___83 *, struct poll_table_struct___57 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___83 {
	int (*remount_fs)(struct kernfs_root___83 *, int *, char *);
	int (*show_options)(struct seq_file___80 *, struct kernfs_root___83 *);
	int (*mkdir)(struct kernfs_node___83 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___83 *);
	int (*rename)(struct kernfs_node___83 *, struct kernfs_node___83 *, const char *);
	int (*show_path)(struct seq_file___80 *, struct kernfs_node___83 *, struct kernfs_root___83 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___83 {
	struct kernfs_node___83 *kn;
	struct file___87 *file;
	struct seq_file___80 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___84 *vm_ops;
};

struct bin_attribute___78;

struct attribute_group___78 {
	const char *name;
	umode_t (*is_visible)(struct kobject___81 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___81 *, struct bin_attribute___78 *, int);
	struct attribute **attrs;
	struct bin_attribute___78 **bin_attrs;
};

struct bin_attribute___78 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___87 *, struct kobject___81 *, struct bin_attribute___78 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___87 *, struct kobject___81 *, struct bin_attribute___78 *, char *, loff_t, size_t);
	int (*mmap)(struct file___87 *, struct kobject___81 *, struct bin_attribute___78 *, struct vm_area_struct___87 *);
};

struct sysfs_ops___80 {
	ssize_t (*show)(struct kobject___81 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___81 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___80;

struct kset___80 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___81 kobj;
	const struct kset_uevent_ops___80 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___80 {
	void (*release)(struct kobject___81 *);
	const struct sysfs_ops___80 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___3 * (*child_ns_type)(struct kobject___81 *);
	const void * (*namespace)(struct kobject___81 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___80 {
	int (* const filter)(struct kset___80 *, struct kobject___81 *);
	const char * (* const name)(struct kset___80 *, struct kobject___81 *);
	int (* const uevent)(struct kset___80 *, struct kobject___81 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___72 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___72 *);
	int (*get)(char *, const struct kernel_param___72 *);
	void (*free)(void *);
};

struct kparam_array___72;

struct kernel_param___72 {
	const char *name;
	struct module___75 *mod;
	const struct kernel_param_ops___72 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___72 *arr;
	};
};

struct kparam_array___72 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___72 *ops;
	void *elem;
};

struct module_attribute___72 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___72 *, struct module_kobject___72 *, char *);
	ssize_t (*store)(struct module_attribute___72 *, struct module_kobject___72 *, const char *, size_t);
	void (*setup)(struct module___75 *, const char *);
	int (*test)(struct module___75 *);
	void (*free)(struct module___75 *);
};

struct trace_event_class___49;

struct trace_event_call___49 {
	struct list_head list;
	struct trace_event_class___49 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___6 *prog_array;
	int (*perf_perm)(struct trace_event_call___49 *, struct perf_event___54 *);
};

struct dev_pm_ops___79 {
	int (*prepare)(struct device___79 *);
	void (*complete)(struct device___79 *);
	int (*suspend)(struct device___79 *);
	int (*resume)(struct device___79 *);
	int (*freeze)(struct device___79 *);
	int (*thaw)(struct device___79 *);
	int (*poweroff)(struct device___79 *);
	int (*restore)(struct device___79 *);
	int (*suspend_late)(struct device___79 *);
	int (*resume_early)(struct device___79 *);
	int (*freeze_late)(struct device___79 *);
	int (*thaw_early)(struct device___79 *);
	int (*poweroff_late)(struct device___79 *);
	int (*restore_early)(struct device___79 *);
	int (*suspend_noirq)(struct device___79 *);
	int (*resume_noirq)(struct device___79 *);
	int (*freeze_noirq)(struct device___79 *);
	int (*thaw_noirq)(struct device___79 *);
	int (*poweroff_noirq)(struct device___79 *);
	int (*restore_noirq)(struct device___79 *);
	int (*runtime_suspend)(struct device___79 *);
	int (*runtime_resume)(struct device___79 *);
	int (*runtime_idle)(struct device___79 *);
};

struct dev_pm_domain___79 {
	struct dev_pm_ops___79 ops;
	void (*detach)(struct device___79 *, bool);
	int (*activate)(struct device___79 *);
	void (*sync)(struct device___79 *);
	void (*dismiss)(struct device___79 *);
};

struct bus_type___79 {
	const char *name;
	const char *dev_name;
	struct device___79 *dev_root;
	const struct attribute_group___78 **bus_groups;
	const struct attribute_group___78 **dev_groups;
	const struct attribute_group___78 **drv_groups;
	int (*match)(struct device___79 *, struct device_driver___79 *);
	int (*uevent)(struct device___79 *, struct kobj_uevent_env *);
	int (*probe)(struct device___79 *);
	int (*remove)(struct device___79 *);
	void (*shutdown)(struct device___79 *);
	int (*online)(struct device___79 *);
	int (*offline)(struct device___79 *);
	int (*suspend)(struct device___79 *, pm_message_t);
	int (*resume)(struct device___79 *);
	int (*num_vf)(struct device___79 *);
	int (*dma_configure)(struct device___79 *);
	const struct dev_pm_ops___79 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___79 {
	const char *name;
	struct bus_type___79 *bus;
	struct module___75 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___79 *);
	int (*remove)(struct device___79 *);
	void (*shutdown)(struct device___79 *);
	int (*suspend)(struct device___79 *, pm_message_t);
	int (*resume)(struct device___79 *);
	const struct attribute_group___78 **groups;
	const struct dev_pm_ops___79 *pm;
	void (*coredump)(struct device___79 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___79 {
	const char *name;
	const struct attribute_group___78 **groups;
	int (*uevent)(struct device___79 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___79 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___79 *);
	const struct dev_pm_ops___79 *pm;
};

struct class___79 {
	const char *name;
	struct module___75 *owner;
	const struct attribute_group___78 **class_groups;
	const struct attribute_group___78 **dev_groups;
	struct kobject___81 *dev_kobj;
	int (*dev_uevent)(struct device___79 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___79 *, umode_t *);
	void (*class_release)(struct class___79 *);
	void (*dev_release)(struct device___79 *);
	int (*shutdown_pre)(struct device___79 *);
	const struct kobj_ns_type_operations___3 *ns_type;
	const void * (*namespace)(struct device___79 *);
	const struct dev_pm_ops___79 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___69 {
	struct device___79 dev;
};

struct bpf_map___69;

struct bpf_map_ops___69 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___69 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___69 *, struct file___87 *);
	void (*map_free)(struct bpf_map___69 *);
	int (*map_get_next_key)(struct bpf_map___69 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___69 *);
	void * (*map_lookup_elem)(struct bpf_map___69 *, void *);
	int (*map_update_elem)(struct bpf_map___69 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___69 *, void *);
	int (*map_push_elem)(struct bpf_map___69 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___69 *, void *);
	int (*map_peek_elem)(struct bpf_map___69 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___69 *, struct file___87 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___69 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___69 *, void *, struct seq_file___80 *);
	int (*map_check_btf)(const struct bpf_map___69 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___69 {
	const struct bpf_map_ops___69 *ops;
	struct bpf_map___69 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___83 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___69;

typedef void (*kthread_work_func_t___69)(struct kthread_work___69 *);

struct kthread_worker___69;

struct kthread_work___69 {
	struct list_head node;
	kthread_work_func_t___69 func;
	struct kthread_worker___69 *worker;
	int canceling;
};

struct kthread_worker___69 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___87 *task;
	struct kthread_work___69 *current_work;
};

struct kthread_delayed_work___69 {
	struct kthread_work___69 work;
	struct timer_list timer;
};

struct psi_group___69 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___69 *poll_kworker;
	struct kthread_delayed_work___69 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___69 {
	struct kernfs_node___83 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___69;

struct cgroup_subsys_state___69 {
	struct cgroup___69 *cgroup;
	struct cgroup_subsys___69 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___69 *parent;
};

struct cgroup_root___69;

struct cgroup_rstat_cpu___69;

struct cgroup___69 {
	struct cgroup_subsys_state___69 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___83 *kn;
	struct cgroup_file___69 procs_file;
	struct cgroup_file___69 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___69 *subsys[13];
	struct cgroup_root___69 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___69 *dom_cgrp;
	struct cgroup_rstat_cpu___69 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___6 bpf;
	atomic_t congestion_count;
	struct cgroup___69 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___69 psi;
	int ancestor_ids[0];
};

struct cftype___69;

struct cgroup_subsys___69 {
	struct cgroup_subsys_state___69 * (*css_alloc)(struct cgroup_subsys_state___69 *);
	int (*css_online)(struct cgroup_subsys_state___69 *);
	void (*css_offline)(struct cgroup_subsys_state___69 *);
	void (*css_released)(struct cgroup_subsys_state___69 *);
	void (*css_free)(struct cgroup_subsys_state___69 *);
	void (*css_reset)(struct cgroup_subsys_state___69 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___69 *, int);
	int (*css_extra_stat_show)(struct seq_file___80 *, struct cgroup_subsys_state___69 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___87 *);
	void (*cancel_fork)(struct task_struct___87 *);
	void (*fork)(struct task_struct___87 *);
	void (*exit)(struct task_struct___87 *);
	void (*free)(struct task_struct___87 *);
	void (*bind)(struct cgroup_subsys_state___69 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___69 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___69 *dfl_cftypes;
	struct cftype___69 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___69 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___69 *updated_children;
	struct cgroup___69 *updated_next;
};

struct cgroup_root___69 {
	struct kernfs_root___83 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___69 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___69 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___69 *ss;
	struct list_head node;
	struct kernfs_ops___83 *kf_ops;
	int (*open)(struct kernfs_open_file___83 *);
	void (*release)(struct kernfs_open_file___83 *);
	u64 (*read_u64)(struct cgroup_subsys_state___69 *, struct cftype___69 *);
	s64 (*read_s64)(struct cgroup_subsys_state___69 *, struct cftype___69 *);
	int (*seq_show)(struct seq_file___80 *, void *);
	void * (*seq_start)(struct seq_file___80 *, loff_t *);
	void * (*seq_next)(struct seq_file___80 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___80 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___69 *, struct cftype___69 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___69 *, struct cftype___69 *, s64);
	ssize_t (*write)(struct kernfs_open_file___83 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___83 *, struct poll_table_struct___57 *);
};

struct perf_cpu_context___54;

struct pmu___54 {
	struct list_head entry;
	struct module___75 *module;
	struct device___79 *dev;
	const struct attribute_group___78 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___54 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___54 *);
	void (*pmu_disable)(struct pmu___54 *);
	int (*event_init)(struct perf_event___54 *);
	void (*event_mapped)(struct perf_event___54 *, struct mm_struct___86 *);
	void (*event_unmapped)(struct perf_event___54 *, struct mm_struct___86 *);
	int (*add)(struct perf_event___54 *, int);
	void (*del)(struct perf_event___54 *, int);
	void (*start)(struct perf_event___54 *, int);
	void (*stop)(struct perf_event___54 *, int);
	void (*read)(struct perf_event___54 *);
	void (*start_txn)(struct pmu___54 *, unsigned int);
	int (*commit_txn)(struct pmu___54 *);
	void (*cancel_txn)(struct pmu___54 *);
	int (*event_idx)(struct perf_event___54 *);
	void (*sched_task)(struct perf_event_context___54 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___54 *);
	int (*filter_match)(struct perf_event___54 *);
	int (*check_period)(struct perf_event___54 *, u64);
};

struct perf_cpu_context___54 {
	struct perf_event_context___54 ctx;
	struct perf_event_context___54 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___54 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___54 {
	struct cgroup_subsys_state___69 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___49 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___49 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___49 *);
	struct list_head * (*get_fields)(struct trace_event_call___49 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___49 *);
};

struct cpu_stop_done {
	atomic_t nr_todo;
	int ret;
	struct completion completion;
};

struct smp_hotplug_thread___4 {
	struct task_struct___70 **store;
	struct list_head list;
	int (*thread_should_run)(unsigned int);
	void (*thread_fn)(unsigned int);
	void (*create)(unsigned int);
	void (*setup)(unsigned int);
	void (*cleanup)(unsigned int, bool);
	void (*park)(unsigned int);
	void (*unpark)(unsigned int);
	cpumask_var_t cpumask;
	bool selfparking;
	const char *thread_comm;
};

struct cpu_stopper {
	struct task_struct___70 *thread;
	raw_spinlock_t lock;
	bool enabled;
	struct list_head works;
	struct cpu_stop_work stop_work;
};

enum multi_stop_state {
	MULTI_STOP_NONE = 0,
	MULTI_STOP_PREPARE = 1,
	MULTI_STOP_DISABLE_IRQ = 2,
	MULTI_STOP_RUN = 3,
	MULTI_STOP_EXIT = 4,
};

struct multi_stop_data {
	cpu_stop_fn_t fn;
	void *data;
	unsigned int num_threads;
	const struct cpumask *active_cpus;
	enum multi_stop_state state;
	atomic_t thread_ack;
};

struct dentry___88;

struct path___87 {
	struct vfsmount *mnt;
	struct dentry___88 *dentry;
};

struct pid___72;

struct fown_struct___72 {
	rwlock_t lock;
	struct pid___72 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct inode___89;

struct file_operations___88;

struct cred___84;

struct address_space___87;

struct file___88 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___87 f_path;
	struct inode___89 *f_inode;
	const struct file_operations___88 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___72 f_owner;
	const struct cred___84 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___87 *f_mapping;
	errseq_t f_wb_err;
};

struct module___76;

struct kiocb___88;

struct iov_iter___34;

struct poll_table_struct___58;

struct vm_area_struct___88;

struct file_lock___88;

struct page___88;

struct pipe_inode_info___16;

struct seq_file___81;

struct file_operations___88 {
	struct module___76 *owner;
	loff_t (*llseek)(struct file___88 *, loff_t, int);
	ssize_t (*read)(struct file___88 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___88 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___88 *, struct iov_iter___34 *);
	ssize_t (*write_iter)(struct kiocb___88 *, struct iov_iter___34 *);
	int (*iopoll)(struct kiocb___88 *, bool);
	int (*iterate)(struct file___88 *, struct dir_context *);
	int (*iterate_shared)(struct file___88 *, struct dir_context *);
	__poll_t (*poll)(struct file___88 *, struct poll_table_struct___58 *);
	long int (*unlocked_ioctl)(struct file___88 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___88 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___88 *, struct vm_area_struct___88 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___89 *, struct file___88 *);
	int (*flush)(struct file___88 *, fl_owner_t);
	int (*release)(struct inode___89 *, struct file___88 *);
	int (*fsync)(struct file___88 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___88 *, int);
	int (*lock)(struct file___88 *, int, struct file_lock___88 *);
	ssize_t (*sendpage)(struct file___88 *, struct page___88 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___88 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___88 *, int, struct file_lock___88 *);
	ssize_t (*splice_write)(struct pipe_inode_info___16 *, struct file___88 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___88 *, loff_t *, struct pipe_inode_info___16 *, size_t, unsigned int);
	int (*setlease)(struct file___88 *, long int, struct file_lock___88 **, void **);
	long int (*fallocate)(struct file___88 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___81 *, struct file___88 *);
	ssize_t (*copy_file_range)(struct file___88 *, loff_t, struct file___88 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___88 *, loff_t, struct file___88 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___88 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___87 {
	u64 seqnum;
	struct vm_area_struct___88 *vmas[4];
};

struct page_frag___87 {
	struct page___88 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___55;

struct debug_info___55 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___55 *hbp_break[16];
	struct perf_event___55 *hbp_watch[16];
};

struct thread_struct___55 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___55 debug;
	long: 64;
};

struct mm_struct___87;

struct mem_cgroup___32;

struct nsproxy___81;

struct signal_struct___78;

struct audit_context___2;

struct bio_list___35;

struct backing_dev_info___35;

struct css_set___70;

struct perf_event_context___55;

struct vm_struct___62;

struct task_struct___88 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___88 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___87 *mm;
	struct mm_struct___87 *active_mm;
	struct vmacache___87 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___88 *real_parent;
	struct task_struct___88 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___88 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___32 *active_memcg;
	long int rh_reserved2;
	struct pid___72 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___72 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___72 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___84 *ptracer_cred;
	const struct cred___84 *real_cred;
	const struct cred___84 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___81 *nsproxy;
	struct signal_struct___78 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context___2 *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___88 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___35 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___35 *backing_dev_info;
	struct io_context___15 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___70 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___55 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___16 *splice_pipe;
	struct page_frag___87 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___32 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___88 *oom_reaper_list;
	struct vm_struct___62 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___55 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___55 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___88 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___55)(struct perf_event___55 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___55;

struct fasync_struct___87;

struct pid_namespace___72;

struct bpf_prog___7;

struct trace_event_call___50;

struct perf_cgroup___55;

struct perf_event___55 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___55 *group_leader;
	struct pmu___55 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___55 hw;
	struct perf_event_context___55 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___55 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___88 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___87 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___55 *);
	struct callback_head callback_head;
	struct pid_namespace___72 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___55 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___55 orig_overflow_handler;
	struct bpf_prog___7 *prog;
	struct trace_event_call___50 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___55 *cgrp;
	struct list_head sb_list;
};

typedef struct page___88 *pgtable_t___87;

struct dev_pagemap___85;

struct page___88 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___87 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___88 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___87 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___87 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___85 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___32 *mem_cgroup;
};

struct pglist_data___87;

struct lruvec___87 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___87 *pgdat;
};

struct zone___87 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___87 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___87 {
	struct zone___87 *zone;
	int zone_idx;
};

struct zonelist___87 {
	struct zoneref___87 _zonerefs[25];
};

struct pglist_data___87 {
	struct zone___87 node_zones[3];
	struct zonelist___87 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___88 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___88 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___87 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___88 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___88 *owner;
};

struct secondary_data___88 {
	void *stack;
	struct task_struct___88 *task;
	long int status;
};

struct blocking_notifier_head___87 {
	struct rw_semaphore___88 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___85;

struct vm_area_struct___88 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___88 *vm_next;
	struct vm_area_struct___88 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___87 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___85 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___88 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___87;

struct user_namespace___73;

struct mm_struct___87 {
	struct {
		struct vm_area_struct___88 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___88 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___88 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___87 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___88 *owner;
		struct user_namespace___73 *user_ns;
		struct file___88 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___87 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___87;

struct address_space___87 {
	struct inode___89 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___88 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___87 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___85)(struct vm_area_struct___88 *, long unsigned int, const struct page___88 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___85)(struct page___88 *, void *);

struct device___80;

struct dev_pagemap___85 {
	dev_page_fault_t___85 page_fault;
	dev_page_free_t___85 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___80 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct cgroup___70;

struct cgroup_subsys___70;

struct cgroup_subsys_state___70 {
	struct cgroup___70 *cgroup;
	struct cgroup_subsys___70 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___70 *parent;
};

struct mem_cgroup_id___14 {
	int id;
	union {
		refcount_t ref;
		struct {
			atomic_t ref;
		} __UNIQUE_ID_rh_kabi_hide56;
		union {		};
	};
};

struct kernfs_node___84;

struct cgroup_file___70 {
	struct kernfs_node___84 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___32;

struct mem_cgroup___32 {
	struct cgroup_subsys_state___70 css;
	struct mem_cgroup_id___14 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___70 events_file;
	struct cgroup_file___70 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___88 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___32 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct vm_fault___85;

struct vm_operations_struct___85 {
	void (*open)(struct vm_area_struct___88 *);
	void (*close)(struct vm_area_struct___88 *);
	int (*split)(struct vm_area_struct___88 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___88 *);
	vm_fault_t (*fault)(struct vm_fault___85 *);
	vm_fault_t (*huge_fault)(struct vm_fault___85 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___85 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___88 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___85 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___85 *);
	int (*access)(struct vm_area_struct___88 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___88 *);
	int (*set_policy)(struct vm_area_struct___88 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___88 *, long unsigned int);
	struct page___88 * (*find_special_page)(struct vm_area_struct___88 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___87 {
	struct task_struct___88 *task;
	struct core_thread___87 *next;
};

struct core_state___87 {
	atomic_t nr_threads;
	struct core_thread___87 dumper;
	struct completion startup;
};

struct key___84;

struct ucounts___73;

struct user_namespace___73 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___73 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___7 ns;
	long unsigned int flags;
	struct key___84 *persistent_keyring_register;
	struct rw_semaphore___88 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___73 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___85 {
	struct vm_area_struct___88 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___88 *cow_page;
	struct mem_cgroup___32 *memcg;
	struct page___88 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___87 prealloc_pte;
};

struct shrink_control___32 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___32 *memcg;
};

struct shrinker___32 {
	long unsigned int (*count_objects)(struct shrinker___32 *, struct shrink_control___32 *);
	long unsigned int (*scan_objects)(struct shrinker___32 *, struct shrink_control___32 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct upid___72 {
	int nr;
	struct pid_namespace___72 *ns;
};

struct pid_namespace___72 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___88 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___72 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___88 *proc_self;
	struct dentry___88 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___73 *user_ns;
	struct ucounts___73 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___7 ns;
};

struct pid___72 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___72 numbers[1];
};

struct user_struct___84 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___84 *uid_keyring;
	struct key___84 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___84 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___84 *session_keyring;
	struct key___84 *process_keyring;
	struct key___84 *thread_keyring;
	struct key___84 *request_key_auth;
	void *security;
	struct user_struct___84 *user;
	struct user_namespace___73 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___17;

struct cgroup_namespace___70;

struct nsproxy___81 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___72 *pid_ns_for_children;
	struct net___17 *net_ns;
	struct cgroup_namespace___70 *cgroup_ns;
};

struct tty_struct___10;

struct signal_struct___78 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___88 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___88 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___72 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___72 *tty_old_pgrp;
	int leader;
	struct tty_struct___10 *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___87 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___72 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct audit_context___2 {
	int dummy;
	int in_syscall;
	enum audit_state state;
	enum audit_state current_state;
	unsigned int serial;
	int major;
	struct timespec64 ctime;
	long unsigned int argv[4];
	long int return_code;
	u64 prio;
	int return_valid;
	struct audit_names preallocated_names[5];
	int name_count;
	struct list_head names_list;
	char *filterkey;
	struct path___87 pwd;
	struct audit_aux_data *aux;
	struct audit_aux_data *aux_pids;
	struct __kernel_sockaddr_storage *sockaddr;
	size_t sockaddr_len;
	pid_t pid;
	pid_t ppid;
	kuid_t uid;
	kuid_t euid;
	kuid_t suid;
	kuid_t fsuid;
	kgid_t gid;
	kgid_t egid;
	kgid_t sgid;
	kgid_t fsgid;
	long unsigned int personality;
	int arch;
	pid_t target_pid;
	kuid_t target_auid;
	kuid_t target_uid;
	unsigned int target_sessionid;
	u32 target_sid;
	char target_comm[16];
	struct audit_tree_refs *trees;
	struct audit_tree_refs *first_trees;
	struct list_head killed_trees;
	int tree_count;
	int type;
	union {
		struct {
			int nargs;
			long int args[6];
		} socketcall;
		struct {
			kuid_t uid;
			kgid_t gid;
			umode_t mode;
			u32 osid;
			int has_perm;
			uid_t perm_uid;
			gid_t perm_gid;
			umode_t perm_mode;
			long unsigned int qbytes;
		} ipc;
		struct {
			mqd_t mqdes;
			struct mq_attr mqstat;
		} mq_getsetattr;
		struct {
			mqd_t mqdes;
			int sigev_signo;
		} mq_notify;
		struct {
			mqd_t mqdes;
			size_t msg_len;
			unsigned int msg_prio;
			struct timespec64 abs_timeout;
		} mq_sendrecv;
		struct {
			int oflag;
			umode_t mode;
			struct mq_attr attr;
		} mq_open;
		struct {
			pid_t pid;
			struct audit_cap_data cap;
		} capset;
		struct {
			int fd;
			int flags;
		} mmap;
		struct {
			int argc;
		} execve;
		struct {
			char *name;
		} module;
	};
	int fds[2];
	struct audit_proctitle proctitle;
};

struct bio___35;

struct bio_list___35 {
	struct bio___35 *head;
	struct bio___35 *tail;
};

struct bdi_writeback_congested___35;

struct bdi_writeback___35 {
	struct backing_dev_info___35 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___35 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___70 *memcg_css;
	struct cgroup_subsys_state___70 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___35 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___35 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___80 *dev;
	struct device___80 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___88 *debug_dir;
	struct dentry___88 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___70 {
	struct cgroup_subsys_state___70 *subsys[13];
	refcount_t refcount;
	struct css_set___70 *dom_cset;
	struct cgroup___70 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___70 *mg_src_cgrp;
	struct cgroup___70 *mg_dst_cgrp;
	struct css_set___70 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___55 {
	struct pmu___55 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___88 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___55 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___16;

struct pipe_inode_info___16 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___88 *tmp_page;
	struct fasync_struct___87 *fasync_readers;
	struct fasync_struct___87 *fasync_writers;
	struct pipe_buffer___16 *bufs;
	struct user_struct___84 *user;
};

struct vm_struct___62 {
	struct vm_struct___62 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___88 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___78 {
	struct task_struct___88 task;
	long unsigned int stack[8192];
};

struct kset___81;

struct kobj_type___81;

struct kobject___82 {
	const char *name;
	struct list_head entry;
	struct kobject___82 *parent;
	struct kset___81 *kset;
	struct kobj_type___81 *ktype;
	struct kernfs_node___84 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___80 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___80 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___80;

struct bus_type___80;

struct device_driver___80;

struct dev_pm_domain___80;

struct dma_map_ops___21;

struct fwnode_handle___58;

struct class___80;

struct attribute_group___79;

struct device___80 {
	struct device___80 *parent;
	struct device_private *p;
	struct kobject___82 kobj;
	const char *init_name;
	const struct device_type___80 *type;
	struct mutex mutex;
	struct bus_type___80 *bus;
	struct device_driver___80 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___80 power;
	struct dev_pm_domain___80 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___21 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___58 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___80 *class;
	const struct attribute_group___79 **groups;
	void (*release)(struct device___80 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___87;

struct super_block___88;

struct dentry___88 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___88 *d_parent;
	struct qstr d_name;
	struct inode___89 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___87 *d_op;
	struct super_block___88 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___87;

struct block_device___88;

struct cdev___24;

struct inode___89 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___87 *i_op;
	struct super_block___88 *i_sb;
	struct address_space___87 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___88 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___35 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___88 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___87 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___16 *i_pipe;
		struct block_device___88 *i_bdev;
		struct cdev___24 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___87 {
	int (*d_revalidate)(struct dentry___88 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___88 *, unsigned int);
	int (*d_hash)(const struct dentry___88 *, struct qstr *);
	int (*d_compare)(const struct dentry___88 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___88 *);
	int (*d_init)(struct dentry___88 *);
	void (*d_release)(struct dentry___88 *);
	void (*d_prune)(struct dentry___88 *);
	void (*d_iput)(struct dentry___88 *, struct inode___89 *);
	char * (*d_dname)(struct dentry___88 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___87 *);
	int (*d_manage)(const struct path___87 *, bool);
	struct dentry___88 * (*d_real)(struct dentry___88 *, const struct inode___89 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___87;

struct mem_dqinfo___87 {
	struct quota_format_type___87 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___87;

struct quota_info___87 {
	unsigned int flags;
	struct rw_semaphore___88 dqio_sem;
	struct inode___89 *files[3];
	struct mem_dqinfo___87 info[3];
	const struct quota_format_ops___87 *ops[3];
};

struct rcuwait___87 {
	struct task_struct___88 *task;
};

struct percpu_rw_semaphore___87 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___88 rw_sem;
	struct rcuwait___87 writer;
	int readers_block;
};

struct sb_writers___87 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___87 rw_sem[3];
};

struct file_system_type___87;

struct super_operations___87;

struct dquot_operations___87;

struct quotactl_ops___87;

struct super_block___88 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___87 *s_type;
	const struct super_operations___87 *s_op;
	const struct dquot_operations___87 *dq_op;
	const struct quotactl_ops___87 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___88 *s_root;
	struct rw_semaphore___88 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___88 *s_bdev;
	struct backing_dev_info___35 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___87 s_dquot;
	struct sb_writers___87 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___87 *s_d_op;
	int cleancache_poolid;
	struct shrinker___32 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___73 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct cpu_vfs_cap_data {
	__u32 magic_etc;
	kernel_cap_t permitted;
	kernel_cap_t inheritable;
};

struct kiocb___88 {
	struct file___88 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___88 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___88 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___88 *ia_file;
};

struct dquot___87 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___88 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___87 {
	int qf_fmt_id;
	const struct quota_format_ops___87 *qf_ops;
	struct module___76 *qf_owner;
	struct quota_format_type___87 *qf_next;
};

struct quota_format_ops___87 {
	int (*check_quota_file)(struct super_block___88 *, int);
	int (*read_file_info)(struct super_block___88 *, int);
	int (*write_file_info)(struct super_block___88 *, int);
	int (*free_file_info)(struct super_block___88 *, int);
	int (*read_dqblk)(struct dquot___87 *);
	int (*commit_dqblk)(struct dquot___87 *);
	int (*release_dqblk)(struct dquot___87 *);
	int (*get_next_id)(struct super_block___88 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___87 {
	int (*write_dquot)(struct dquot___87 *);
	struct dquot___87 * (*alloc_dquot)(struct super_block___88 *, int);
	void (*destroy_dquot)(struct dquot___87 *);
	int (*acquire_dquot)(struct dquot___87 *);
	int (*release_dquot)(struct dquot___87 *);
	int (*mark_dirty)(struct dquot___87 *);
	int (*write_info)(struct super_block___88 *, int);
	qsize_t * (*get_reserved_space)(struct inode___89 *);
	int (*get_projid)(struct inode___89 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___89 *, qsize_t *);
	int (*get_next_id)(struct super_block___88 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___87 {
	int (*quota_on)(struct super_block___88 *, int, int, const struct path___87 *);
	int (*quota_off)(struct super_block___88 *, int);
	int (*quota_enable)(struct super_block___88 *, unsigned int);
	int (*quota_disable)(struct super_block___88 *, unsigned int);
	int (*quota_sync)(struct super_block___88 *, int);
	int (*set_info)(struct super_block___88 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___88 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___88 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___88 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___88 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___88 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___73 {
	struct kobject___82 kobj;
	struct module___76 *mod;
	struct kobject___82 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___73 {
	struct module___76 *mod;
	struct latch_tree_node node;
};

struct module_layout___73 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___73 mtn;
};

struct module_attribute___73;

struct kernel_param___73;

struct module___76 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___73 mkobj;
	struct module_attribute___73 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___82 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___73 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___73 core_layout;
	struct module_layout___73 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___50 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___33;

struct address_space_operations___87 {
	int (*writepage)(struct page___88 *, struct writeback_control___33 *);
	int (*readpage)(struct file___88 *, struct page___88 *);
	int (*writepages)(struct address_space___87 *, struct writeback_control___33 *);
	int (*set_page_dirty)(struct page___88 *);
	int (*readpages)(struct file___88 *, struct address_space___87 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___88 *, struct address_space___87 *, loff_t, unsigned int, unsigned int, struct page___88 **, void **);
	int (*write_end)(struct file___88 *, struct address_space___87 *, loff_t, unsigned int, unsigned int, struct page___88 *, void *);
	sector_t (*bmap)(struct address_space___87 *, sector_t);
	void (*invalidatepage)(struct page___88 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___88 *, gfp_t);
	void (*freepage)(struct page___88 *);
	ssize_t (*direct_IO)(struct kiocb___88 *, struct iov_iter___34 *);
	int (*migratepage)(struct address_space___87 *, struct page___88 *, struct page___88 *, enum migrate_mode);
	bool (*isolate_page)(struct page___88 *, isolate_mode_t);
	void (*putback_page)(struct page___88 *);
	int (*launder_page)(struct page___88 *);
	int (*is_partially_uptodate)(struct page___88 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___88 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___87 *, struct page___88 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___88 *, sector_t *);
	void (*swap_deactivate)(struct file___88 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___33 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___35 *wb;
	struct inode___89 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___35;

struct iov_iter___34 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___35 *bvec;
		struct pipe_inode_info___16 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___88 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___89 *bd_inode;
	struct super_block___88 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___88 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___35 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___24 {
	struct kobject___82 kobj;
	struct module___76 *owner;
	const struct file_operations___88 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___87 {
	struct dentry___88 * (*lookup)(struct inode___89 *, struct dentry___88 *, unsigned int);
	const char * (*get_link)(struct dentry___88 *, struct inode___89 *, struct delayed_call *);
	int (*permission)(struct inode___89 *, int);
	struct posix_acl * (*get_acl)(struct inode___89 *, int);
	int (*readlink)(struct dentry___88 *, char *, int);
	int (*create)(struct inode___89 *, struct dentry___88 *, umode_t, bool);
	int (*link)(struct dentry___88 *, struct inode___89 *, struct dentry___88 *);
	int (*unlink)(struct inode___89 *, struct dentry___88 *);
	int (*symlink)(struct inode___89 *, struct dentry___88 *, const char *);
	int (*mkdir)(struct inode___89 *, struct dentry___88 *, umode_t);
	int (*rmdir)(struct inode___89 *, struct dentry___88 *);
	int (*mknod)(struct inode___89 *, struct dentry___88 *, umode_t, dev_t);
	int (*rename)(struct inode___89 *, struct dentry___88 *, struct inode___89 *, struct dentry___88 *, unsigned int);
	int (*setattr)(struct dentry___88 *, struct iattr___88 *);
	int (*getattr)(const struct path___87 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___88 *, char *, size_t);
	int (*fiemap)(struct inode___89 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___89 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___89 *, struct dentry___88 *, struct file___88 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___89 *, struct dentry___88 *, umode_t);
	int (*set_acl)(struct inode___89 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___87 {
	void (*fl_copy_lock)(struct file_lock___88 *, struct file_lock___88 *);
	void (*fl_release_private)(struct file_lock___88 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___87;

struct file_lock___88 {
	struct file_lock___88 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___88 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___87 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___87 *fl_ops;
	const struct lock_manager_operations___87 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___87 {
	int (*lm_compare_owner)(struct file_lock___88 *, struct file_lock___88 *);
	long unsigned int (*lm_owner_key)(struct file_lock___88 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___88 *);
	int (*lm_grant)(struct file_lock___88 *, int);
	bool (*lm_break)(struct file_lock___88 *);
	int (*lm_change)(struct file_lock___88 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___88 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___87 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___87 *fa_next;
	struct file___88 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___87 {
	const char *name;
	int fs_flags;
	struct dentry___88 * (*mount)(struct file_system_type___87 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___88 *);
	struct module___76 *owner;
	struct file_system_type___87 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___87 {
	struct inode___89 * (*alloc_inode)(struct super_block___88 *);
	void (*destroy_inode)(struct inode___89 *);
	void (*dirty_inode)(struct inode___89 *, int);
	int (*write_inode)(struct inode___89 *, struct writeback_control___33 *);
	int (*drop_inode)(struct inode___89 *);
	void (*evict_inode)(struct inode___89 *);
	void (*put_super)(struct super_block___88 *);
	int (*sync_fs)(struct super_block___88 *, int);
	int (*freeze_super)(struct super_block___88 *);
	int (*freeze_fs)(struct super_block___88 *);
	int (*thaw_super)(struct super_block___88 *);
	int (*unfreeze_fs)(struct super_block___88 *);
	int (*statfs)(struct dentry___88 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___88 *, int *, char *);
	void (*umount_begin)(struct super_block___88 *);
	int (*show_options)(struct seq_file___81 *, struct dentry___88 *);
	int (*show_devname)(struct seq_file___81 *, struct dentry___88 *);
	int (*show_path)(struct seq_file___81 *, struct dentry___88 *);
	int (*show_stats)(struct seq_file___81 *, struct dentry___88 *);
	ssize_t (*quota_read)(struct super_block___88 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___88 *, int, const char *, size_t, loff_t);
	struct dquot___87 ** (*get_dquots)(struct inode___89 *);
	int (*bdev_try_to_free_page)(struct super_block___88 *, struct page___88 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___88 *, struct shrink_control___32 *);
	long int (*free_cached_objects)(struct super_block___88 *, struct shrink_control___32 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___57)(struct file___88 *, wait_queue_head_t *, struct poll_table_struct___58 *);

struct poll_table_struct___58 {
	poll_queue_proc___57 _qproc;
	__poll_t _key;
};

struct seq_operations___79;

struct seq_file___81 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___79 *op;
	int poll_event;
	const struct file___88 *file;
	void *private;
};

typedef void bio_end_io_t___35(struct bio___35 *);

struct bio_vec___35 {
	struct page___88 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___35;

struct bio_set___35;

struct bio___35 {
	struct bio___35 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___35 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___35 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___35 *bi_io_vec;
	struct bio_set___35 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___35 bi_inline_vecs[0];
};

struct kobj_attribute___82 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___82 *, struct kobj_attribute___82 *, char *);
	ssize_t (*store)(struct kobject___82 *, struct kobj_attribute___82 *, const char *, size_t);
};

typedef void compound_page_dtor___85(struct page___88 *);

struct kthread_work___70;

typedef void (*kthread_work_func_t___70)(struct kthread_work___70 *);

struct kthread_worker___70;

struct kthread_work___70 {
	struct list_head node;
	kthread_work_func_t___70 func;
	struct kthread_worker___70 *worker;
	int canceling;
};

struct kthread_worker___70 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___88 *task;
	struct kthread_work___70 *current_work;
};

struct kthread_delayed_work___70 {
	struct kthread_work___70 work;
	struct timer_list timer;
};

typedef int (*key_restrict_link_func_t___84)(struct key___84 *, const struct key_type *, const union key_payload *, struct key___84 *);

struct key_restriction___84;

struct key___84 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___88 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___84 *restrict_link;
};

struct key_restriction___84 {
	key_restrict_link_func_t___84 check;
	struct key___84 *key;
	struct key_type *keytype;
};

struct seq_operations___79 {
	void * (*start)(struct seq_file___81 *, loff_t *);
	void (*stop)(struct seq_file___81 *, void *);
	void * (*next)(struct seq_file___81 *, void *, loff_t *);
	int (*show)(struct seq_file___81 *, void *);
};

struct inet_frags___8;

struct netns_frags___8 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___8 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_rules_ops___4;

struct sock___7;

struct fib_notifier_ops___4;

struct netns_ipv4___8 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___4 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___7 *fibnl;
	struct sock___7 **icmp_sk;
	struct sock___7 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___7 **tcp_sk;
	struct netns_frags___8 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___4 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___4 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___4 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct dst_entry___6;

struct net_device___13;

struct sk_buff___12;

struct neighbour___6;

struct dst_ops___15 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___15 *);
	struct dst_entry___6 * (*check)(struct dst_entry___6 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___6 *);
	unsigned int (*mtu)(const struct dst_entry___6 *);
	u32 * (*cow_metrics)(struct dst_entry___6 *, long unsigned int);
	void (*destroy)(struct dst_entry___6 *);
	void (*ifdown)(struct dst_entry___6 *, struct net_device___13 *, int);
	struct dst_entry___6 * (*negative_advice)(struct dst_entry___6 *);
	void (*link_failure)(struct sk_buff___12 *);
	void (*update_pmtu)(struct dst_entry___6 *, struct sock___7 *, struct sk_buff___12 *, u32);
	void (*redirect)(struct dst_entry___6 *, struct sock___7 *, struct sk_buff___12 *);
	int (*local_out)(struct net___17 *, struct sock___7 *, struct sk_buff___12 *);
	struct neighbour___6 * (*neigh_lookup)(const struct dst_entry___6 *, struct sk_buff___12 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___6 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___14 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___8 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___15 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___4 *fib6_rules_ops;
	struct sock___7 **icmp_sk;
	struct sock___7 *ndisc_sk;
	struct sock___7 *tcp_sk;
	struct sock___7 *igmp_sk;
	struct sock___7 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___4 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___4 *notifier_ops;
	struct fib_notifier_ops___4 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___4 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___7 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___8 {
	struct netns_frags___8 frags;
};

struct netns_xfrm___14 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___7 *nlsk;
	struct sock___7 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___15 xfrm4_dst_ops;
	struct dst_ops___15 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct net___17 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___73 *user_ns;
	struct ucounts___73 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___7 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___7 *rtnl;
	struct sock___7 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___13 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___8 ipv4;
	struct netns_ipv6___14 ipv6;
	struct netns_sctp___4 sctp;
	struct netns_nf nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___8 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___7 *nfnl;
	struct sock___7 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___14 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___7 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___7 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cgroup_namespace___70 {
	refcount_t count;
	struct ns_common___7 ns;
	struct user_namespace___73 *user_ns;
	struct ucounts___73 *ucounts;
	struct css_set___70 *root_cset;
};

struct ucounts___73 {
	struct hlist_node node;
	struct user_namespace___73 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct kernfs_root___84;

struct kernfs_elem_dir___84 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___84 *root;
};

struct kernfs_syscall_ops___84;

struct kernfs_root___84 {
	struct kernfs_node___84 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___84 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___84 {
	struct kernfs_node___84 *target_kn;
};

struct kernfs_ops___84;

struct kernfs_elem_attr___84 {
	const struct kernfs_ops___84 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___84 *notify_next;
};

struct kernfs_node___84 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___84 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___84 dir;
		struct kernfs_elem_symlink___84 symlink;
		struct kernfs_elem_attr___84 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___84;

struct kernfs_ops___84 {
	int (*open)(struct kernfs_open_file___84 *);
	void (*release)(struct kernfs_open_file___84 *);
	int (*seq_show)(struct seq_file___81 *, void *);
	void * (*seq_start)(struct seq_file___81 *, loff_t *);
	void * (*seq_next)(struct seq_file___81 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___81 *, void *);
	ssize_t (*read)(struct kernfs_open_file___84 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___84 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___84 *, struct vm_area_struct___88 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___84 *, struct poll_table_struct___58 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___84 {
	int (*remount_fs)(struct kernfs_root___84 *, int *, char *);
	int (*show_options)(struct seq_file___81 *, struct kernfs_root___84 *);
	int (*mkdir)(struct kernfs_node___84 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___84 *);
	int (*rename)(struct kernfs_node___84 *, struct kernfs_node___84 *, const char *);
	int (*show_path)(struct seq_file___81 *, struct kernfs_node___84 *, struct kernfs_root___84 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___84 {
	struct kernfs_node___84 *kn;
	struct file___88 *file;
	struct seq_file___81 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___85 *vm_ops;
};

struct kobj_ns_type_operations___4 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___7 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___17 *net;
} possible_net_t___8;

struct proto___4;

struct sock_common___4 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___4 *skc_prot;
	possible_net_t___8 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___7 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff_head___9 {
	struct sk_buff___12 *next;
	struct sk_buff___12 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___4;

struct socket_wq___4;

struct socket___4;

struct sock___7 {
	struct sock_common___4 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___9 sk_error_queue;
	struct sk_buff_head___9 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___12 *head;
		struct sk_buff___12 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___4 *sk_filter;
	union {
		struct socket_wq___4 *sk_wq;
		struct socket_wq___4 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___6 *sk_rx_dst;
	struct dst_entry___6 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___12 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___9 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___87 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___4 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___72 *sk_peer_pid;
	const struct cred___84 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___4 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___32 *sk_memcg;
	void (*sk_state_change)(struct sock___7 *);
	void (*sk_data_ready)(struct sock___7 *);
	void (*sk_write_space)(struct sock___7 *);
	void (*sk_error_report)(struct sock___7 *);
	int (*sk_backlog_rcv)(struct sock___7 *, struct sk_buff___12 *);
	struct sk_buff___12 * (*sk_validate_xmit_skb)(struct sock___7 *, struct net_device___13 *, struct sk_buff___12 *);
	void (*sk_destruct)(struct sock___7 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct bin_attribute___79;

struct attribute_group___79 {
	const char *name;
	umode_t (*is_visible)(struct kobject___82 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___82 *, struct bin_attribute___79 *, int);
	struct attribute **attrs;
	struct bin_attribute___79 **bin_attrs;
};

struct bin_attribute___79 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___88 *, struct kobject___82 *, struct bin_attribute___79 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___88 *, struct kobject___82 *, struct bin_attribute___79 *, char *, loff_t, size_t);
	int (*mmap)(struct file___88 *, struct kobject___82 *, struct bin_attribute___79 *, struct vm_area_struct___88 *);
};

struct sysfs_ops___81 {
	ssize_t (*show)(struct kobject___82 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___82 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___81;

struct kset___81 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___82 kobj;
	const struct kset_uevent_ops___81 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___81 {
	void (*release)(struct kobject___82 *);
	const struct sysfs_ops___81 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___4 * (*child_ns_type)(struct kobject___82 *);
	const void * (*namespace)(struct kobject___82 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___81 {
	int (* const filter)(struct kset___81 *, struct kobject___82 *);
	const char * (* const name)(struct kset___81 *, struct kobject___82 *);
	int (* const uevent)(struct kset___81 *, struct kobject___82 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___73 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___73 *);
	int (*get)(char *, const struct kernel_param___73 *);
	void (*free)(void *);
};

struct kparam_array___73;

struct kernel_param___73 {
	const char *name;
	struct module___76 *mod;
	const struct kernel_param_ops___73 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___73 *arr;
	};
};

struct kparam_array___73 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___73 *ops;
	void *elem;
};

struct module_attribute___73 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___73 *, struct module_kobject___73 *, char *);
	ssize_t (*store)(struct module_attribute___73 *, struct module_kobject___73 *, const char *, size_t);
	void (*setup)(struct module___76 *, const char *);
	int (*test)(struct module___76 *);
	void (*free)(struct module___76 *);
};

struct trace_event_class___50;

struct bpf_prog_array___7;

struct trace_event_call___50 {
	struct list_head list;
	struct trace_event_class___50 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___7 *prog_array;
	int (*perf_perm)(struct trace_event_call___50 *, struct perf_event___55 *);
};

struct tty_driver___10;

struct tty_operations___10;

struct tty_ldisc___10;

struct tty_port___10;

struct tty_struct___10 {
	int magic;
	struct kref kref;
	struct device___80 *dev;
	struct tty_driver___10 *driver;
	const struct tty_operations___10 *ops;
	int index;
	struct ld_semaphore ldisc_sem;
	struct tty_ldisc___10 *ldisc;
	struct mutex atomic_write_lock;
	struct mutex legacy_mutex;
	struct mutex throttle_mutex;
	struct rw_semaphore___88 termios_rwsem;
	struct mutex winsize_mutex;
	spinlock_t ctrl_lock;
	spinlock_t flow_lock;
	struct ktermios termios;
	struct ktermios termios_locked;
	struct termiox *termiox;
	char name[64];
	struct pid___72 *pgrp;
	struct pid___72 *session;
	long unsigned int flags;
	int count;
	struct winsize winsize;
	long unsigned int stopped: 1;
	long unsigned int flow_stopped: 1;
	int: 30;
	long unsigned int unused: 62;
	int hw_stopped;
	long unsigned int ctrl_status: 8;
	long unsigned int packet: 1;
	int: 23;
	long unsigned int unused_ctrl: 55;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___10 *link;
	struct fasync_struct___87 *fasync;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	spinlock_t files_lock;
	struct list_head tty_files;
	int closing;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___10 *port;
};

struct msghdr___4 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___34 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___88 *msg_iocb;
};

struct dev_pm_ops___80 {
	int (*prepare)(struct device___80 *);
	void (*complete)(struct device___80 *);
	int (*suspend)(struct device___80 *);
	int (*resume)(struct device___80 *);
	int (*freeze)(struct device___80 *);
	int (*thaw)(struct device___80 *);
	int (*poweroff)(struct device___80 *);
	int (*restore)(struct device___80 *);
	int (*suspend_late)(struct device___80 *);
	int (*resume_early)(struct device___80 *);
	int (*freeze_late)(struct device___80 *);
	int (*thaw_early)(struct device___80 *);
	int (*poweroff_late)(struct device___80 *);
	int (*restore_early)(struct device___80 *);
	int (*suspend_noirq)(struct device___80 *);
	int (*resume_noirq)(struct device___80 *);
	int (*freeze_noirq)(struct device___80 *);
	int (*thaw_noirq)(struct device___80 *);
	int (*poweroff_noirq)(struct device___80 *);
	int (*restore_noirq)(struct device___80 *);
	int (*runtime_suspend)(struct device___80 *);
	int (*runtime_resume)(struct device___80 *);
	int (*runtime_idle)(struct device___80 *);
};

struct dev_pm_domain___80 {
	struct dev_pm_ops___80 ops;
	void (*detach)(struct device___80 *, bool);
	int (*activate)(struct device___80 *);
	void (*sync)(struct device___80 *);
	void (*dismiss)(struct device___80 *);
};

struct bus_type___80 {
	const char *name;
	const char *dev_name;
	struct device___80 *dev_root;
	const struct attribute_group___79 **bus_groups;
	const struct attribute_group___79 **dev_groups;
	const struct attribute_group___79 **drv_groups;
	int (*match)(struct device___80 *, struct device_driver___80 *);
	int (*uevent)(struct device___80 *, struct kobj_uevent_env *);
	int (*probe)(struct device___80 *);
	int (*remove)(struct device___80 *);
	void (*shutdown)(struct device___80 *);
	int (*online)(struct device___80 *);
	int (*offline)(struct device___80 *);
	int (*suspend)(struct device___80 *, pm_message_t);
	int (*resume)(struct device___80 *);
	int (*num_vf)(struct device___80 *);
	int (*dma_configure)(struct device___80 *);
	const struct dev_pm_ops___80 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___80 {
	const char *name;
	struct bus_type___80 *bus;
	struct module___76 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___80 *);
	int (*remove)(struct device___80 *);
	void (*shutdown)(struct device___80 *);
	int (*suspend)(struct device___80 *, pm_message_t);
	int (*resume)(struct device___80 *);
	const struct attribute_group___79 **groups;
	const struct dev_pm_ops___80 *pm;
	void (*coredump)(struct device___80 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___80 {
	const char *name;
	const struct attribute_group___79 **groups;
	int (*uevent)(struct device___80 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___80 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___80 *);
	const struct dev_pm_ops___80 *pm;
};

struct class___80 {
	const char *name;
	struct module___76 *owner;
	const struct attribute_group___79 **class_groups;
	const struct attribute_group___79 **dev_groups;
	struct kobject___82 *dev_kobj;
	int (*dev_uevent)(struct device___80 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___80 *, umode_t *);
	void (*class_release)(struct class___80 *);
	void (*dev_release)(struct device___80 *);
	int (*shutdown_pre)(struct device___80 *);
	const struct kobj_ns_type_operations___4 *ns_type;
	const void * (*namespace)(struct device___80 *);
	const struct dev_pm_ops___80 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___21 {
	void * (*alloc)(struct device___80 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___80 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___80 *, struct vm_area_struct___88 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___80 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___80 *, struct page___88 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___80 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___80 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___80 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___80 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___80 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___80 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide21;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___80 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___80 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___80 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___80 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___80 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___80 *, u64);
	u64 (*get_required_mask)(struct device___80 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___58;

struct fwnode_handle___58 {
	struct fwnode_handle___58 *secondary;
	const struct fwnode_operations___58 *ops;
};

struct node___70 {
	struct device___80 dev;
};

struct bpf_map___70;

struct bpf_map_ops___70 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___70 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___70 *, struct file___88 *);
	void (*map_free)(struct bpf_map___70 *);
	int (*map_get_next_key)(struct bpf_map___70 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___70 *);
	void * (*map_lookup_elem)(struct bpf_map___70 *, void *);
	int (*map_update_elem)(struct bpf_map___70 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___70 *, void *);
	int (*map_push_elem)(struct bpf_map___70 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___70 *, void *);
	int (*map_peek_elem)(struct bpf_map___70 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___70 *, struct file___88 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___70 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___70 *, void *, struct seq_file___81 *);
	int (*map_check_btf)(const struct bpf_map___70 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___70 {
	const struct bpf_map_ops___70 *ops;
	struct bpf_map___70 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___84 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___8;

struct bpf_map_dev_ops___8 {
	int (*map_get_next_key)(struct bpf_offloaded_map___8 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___8 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___8 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___8 *, void *);
};

struct bpf_offloaded_map___8 {
	struct bpf_map___70 map;
	struct net_device___13 *netdev;
	const struct bpf_map_dev_ops___8 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

typedef rx_handler_result_t rx_handler_func_t___8(struct sk_buff___12 **);

struct net_device_ops___8;

struct ethtool_ops___8;

struct l3mdev_ops___5;

struct xfrmdev_ops___8;

struct tlsdev_ops___8;

struct header_ops___8;

struct netdev_rx_queue___8;

struct mini_Qdisc___7;

struct netdev_queue___8;

struct Qdisc___7;

struct rtnl_link_ops___7;

struct dcbnl_rtnl_ops___8;

struct net_device___13 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___8 *netdev_ops;
	const struct ethtool_ops___8 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___5 *l3mdev_ops;
	const struct ndisc_ops___2 *ndisc_ops;
	const struct xfrmdev_ops___8 *xfrmdev_ops;
	const struct tlsdev_ops___8 *tlsdev_ops;
	const struct header_ops___8 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___81 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___2 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___8 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___7 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___8 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___7 *miniq_ingress;
	struct netdev_queue___8 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___8 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___7 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___7 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___8 = 0,
		NETREG_REGISTERED___8 = 1,
		NETREG_UNREGISTERING___8 = 2,
		NETREG_UNREGISTERED___8 = 3,
		NETREG_RELEASED___8 = 4,
		NETREG_DUMMY___8 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___8 = 0,
		RTNL_LINK_INITIALIZING___8 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___13 *);
	struct netpoll_info *npinfo;
	possible_net_t___8 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___80 dev;
	const struct attribute_group___79 *sysfs_groups[4];
	const struct attribute_group___79 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___7 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___8 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide37;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct bpf_prog_ops___7 {
	int (*test_run)(struct bpf_prog___7 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_aux___7;

struct bpf_prog___7 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___7 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

struct bpf_verifier_ops___7 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___7 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___7 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___7 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___7 *, u32 *);
};

struct bpf_prog_offload_ops___7 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___7 *);
	int (*translate)(struct bpf_prog___7 *);
	void (*destroy)(struct bpf_prog___7 *);
};

struct bpf_prog_offload___7 {
	struct bpf_prog___7 *prog;
	struct net_device___13 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___7 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___7 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___7 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___7 *ops;
	struct bpf_map___70 **used_maps;
	struct bpf_prog___7 *prog;
	struct user_struct___84 *user;
	u64 load_time;
	struct bpf_map___70 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___7 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___7 {
	struct bpf_prog___7 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___7 {
	struct callback_head rcu;
	struct bpf_prog_array_item___7 items[0];
};

struct cgroup_bpf___7 {
	struct bpf_prog_array___7 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___7 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct psi_group___70 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___70 *poll_kworker;
	struct kthread_delayed_work___70 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___70;

struct cgroup_rstat_cpu___70;

struct cgroup___70 {
	struct cgroup_subsys_state___70 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___84 *kn;
	struct cgroup_file___70 procs_file;
	struct cgroup_file___70 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___70 *subsys[13];
	struct cgroup_root___70 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___70 *dom_cgrp;
	struct cgroup_rstat_cpu___70 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___7 bpf;
	atomic_t congestion_count;
	struct cgroup___70 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___70 psi;
	int ancestor_ids[0];
};

struct cftype___70;

struct cgroup_subsys___70 {
	struct cgroup_subsys_state___70 * (*css_alloc)(struct cgroup_subsys_state___70 *);
	int (*css_online)(struct cgroup_subsys_state___70 *);
	void (*css_offline)(struct cgroup_subsys_state___70 *);
	void (*css_released)(struct cgroup_subsys_state___70 *);
	void (*css_free)(struct cgroup_subsys_state___70 *);
	void (*css_reset)(struct cgroup_subsys_state___70 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___70 *, int);
	int (*css_extra_stat_show)(struct seq_file___81 *, struct cgroup_subsys_state___70 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___88 *);
	void (*cancel_fork)(struct task_struct___88 *);
	void (*fork)(struct task_struct___88 *);
	void (*exit)(struct task_struct___88 *);
	void (*free)(struct task_struct___88 *);
	void (*bind)(struct cgroup_subsys_state___70 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___70 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___70 *dfl_cftypes;
	struct cftype___70 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___70 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___70 *updated_children;
	struct cgroup___70 *updated_next;
};

struct cgroup_root___70 {
	struct kernfs_root___84 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___70 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___70 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___70 *ss;
	struct list_head node;
	struct kernfs_ops___84 *kf_ops;
	int (*open)(struct kernfs_open_file___84 *);
	void (*release)(struct kernfs_open_file___84 *);
	u64 (*read_u64)(struct cgroup_subsys_state___70 *, struct cftype___70 *);
	s64 (*read_s64)(struct cgroup_subsys_state___70 *, struct cftype___70 *);
	int (*seq_show)(struct seq_file___81 *, void *);
	void * (*seq_start)(struct seq_file___81 *, loff_t *);
	void * (*seq_next)(struct seq_file___81 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___81 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___70 *, struct cftype___70 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___70 *, struct cftype___70 *, s64);
	ssize_t (*write)(struct kernfs_open_file___84 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___84 *, struct poll_table_struct___58 *);
};

struct perf_cpu_context___55;

struct pmu___55 {
	struct list_head entry;
	struct module___76 *module;
	struct device___80 *dev;
	const struct attribute_group___79 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___55 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___55 *);
	void (*pmu_disable)(struct pmu___55 *);
	int (*event_init)(struct perf_event___55 *);
	void (*event_mapped)(struct perf_event___55 *, struct mm_struct___87 *);
	void (*event_unmapped)(struct perf_event___55 *, struct mm_struct___87 *);
	int (*add)(struct perf_event___55 *, int);
	void (*del)(struct perf_event___55 *, int);
	void (*start)(struct perf_event___55 *, int);
	void (*stop)(struct perf_event___55 *, int);
	void (*read)(struct perf_event___55 *);
	void (*start_txn)(struct pmu___55 *, unsigned int);
	int (*commit_txn)(struct pmu___55 *);
	void (*cancel_txn)(struct pmu___55 *);
	int (*event_idx)(struct perf_event___55 *);
	void (*sched_task)(struct perf_event_context___55 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___55 *);
	int (*filter_match)(struct perf_event___55 *);
	int (*check_period)(struct perf_event___55 *, u64);
};

struct perf_cpu_context___55 {
	struct perf_event_context___55 ctx;
	struct perf_event_context___55 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___55 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___55 {
	struct cgroup_subsys_state___70 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___50 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___50 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___50 *);
	struct list_head * (*get_fields)(struct trace_event_call___50 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___50 *);
};

enum audit_nlgrps {
	AUDIT_NLGRP_NONE = 0,
	AUDIT_NLGRP_READLOG = 1,
	__AUDIT_NLGRP_MAX = 2,
};

struct audit_status {
	__u32 mask;
	__u32 enabled;
	__u32 failure;
	__u32 pid;
	__u32 rate_limit;
	__u32 backlog_limit;
	__u32 lost;
	__u32 backlog;
	union {
		__u32 version;
		__u32 feature_bitmap;
	};
	__u32 backlog_wait_time;
};

struct audit_features {
	__u32 vers;
	__u32 mask;
	__u32 features;
	__u32 lock;
};

struct audit_tty_status {
	__u32 enabled;
	__u32 log_passwd;
};

struct audit_sig_info {
	uid_t uid;
	pid_t pid;
	char ctx[0];
};

struct socket_wq___4 {
	wait_queue_head_t wait;
	struct fasync_struct___87 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___4;

struct socket___4 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___4 *wq;
	struct file___88 *file;
	struct sock___7 *sk;
	const struct proto_ops___4 *ops;
};

typedef int (*sk_read_actor_t___4)(read_descriptor_t *, struct sk_buff___12 *, unsigned int, size_t);

struct proto_ops___4 {
	int family;
	struct module___76 *owner;
	int (*release)(struct socket___4 *);
	int (*bind)(struct socket___4 *, struct sockaddr *, int);
	int (*connect)(struct socket___4 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___4 *, struct socket___4 *);
	int (*accept)(struct socket___4 *, struct socket___4 *, int, bool);
	int (*getname)(struct socket___4 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___88 *, struct socket___4 *, struct poll_table_struct___58 *);
	int (*ioctl)(struct socket___4 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___4 *, int);
	int (*shutdown)(struct socket___4 *, int);
	int (*setsockopt)(struct socket___4 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___4 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___4 *, struct msghdr___4 *, size_t);
	int (*recvmsg)(struct socket___4 *, struct msghdr___4 *, size_t, int);
	int (*mmap)(struct file___88 *, struct socket___4 *, struct vm_area_struct___88 *);
	ssize_t (*sendpage)(struct socket___4 *, struct page___88 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___4 *, loff_t *, struct pipe_inode_info___16 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___7 *, int);
	int (*peek_len)(struct socket___4 *);
	int (*read_sock)(struct sock___7 *, read_descriptor_t *, sk_read_actor_t___4);
	int (*sendpage_locked)(struct sock___7 *, struct page___88 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___7 *, struct msghdr___4 *, size_t);
	int (*set_rcvlowat)(struct sock___7 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct nf_bridge_info___8;

struct sk_buff___12 {
	union {
		struct {
			struct sk_buff___12 *next;
			struct sk_buff___12 *prev;
			union {
				struct net_device___13 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___7 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___12 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___8 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct fwnode_reference_args___58;

struct fwnode_endpoint___58;

struct fwnode_operations___58 {
	struct fwnode_handle___58 * (*get)(struct fwnode_handle___58 *);
	void (*put)(struct fwnode_handle___58 *);
	bool (*device_is_available)(const struct fwnode_handle___58 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___58 *, const struct device___80 *);
	bool (*property_present)(const struct fwnode_handle___58 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___58 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___58 *, const char *, const char **, size_t);
	struct fwnode_handle___58 * (*get_parent)(const struct fwnode_handle___58 *);
	struct fwnode_handle___58 * (*get_next_child_node)(const struct fwnode_handle___58 *, struct fwnode_handle___58 *);
	struct fwnode_handle___58 * (*get_named_child_node)(const struct fwnode_handle___58 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___58 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___58 *);
	struct fwnode_handle___58 * (*graph_get_next_endpoint)(const struct fwnode_handle___58 *, struct fwnode_handle___58 *);
	struct fwnode_handle___58 * (*graph_get_remote_endpoint)(const struct fwnode_handle___58 *);
	struct fwnode_handle___58 * (*graph_get_port_parent)(struct fwnode_handle___58 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___58 *, struct fwnode_endpoint___58 *);
};

struct fwnode_endpoint___58 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___58 *local_fwnode;
};

struct fwnode_reference_args___58 {
	struct fwnode_handle___58 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___16;

struct pipe_buffer___16 {
	struct page___88 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___16 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___16 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___16 *, struct pipe_buffer___16 *);
	void (*release)(struct pipe_inode_info___16 *, struct pipe_buffer___16 *);
	int (*steal)(struct pipe_inode_info___16 *, struct pipe_buffer___16 *);
	union {
		bool (*get)(struct pipe_inode_info___16 *, struct pipe_buffer___16 *);
		struct {
			void (*get)(struct pipe_inode_info___16 *, struct pipe_buffer___16 *);
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
};

struct nf_bridge_info___8 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___8 = 0,
		BRNF_PROTO_8021Q___8 = 1,
		BRNF_PROTO_PPPOE___8 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___13 *physindev;
	struct net_device___13 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

struct ethtool_ops___8 {
	int (*get_settings)(struct net_device___13 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___13 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___13 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___13 *);
	void (*get_regs)(struct net_device___13 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___13 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___13 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___13 *);
	void (*set_msglevel)(struct net_device___13 *, u32);
	int (*nway_reset)(struct net_device___13 *);
	u32 (*get_link)(struct net_device___13 *);
	int (*get_eeprom_len)(struct net_device___13 *);
	int (*get_eeprom)(struct net_device___13 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___13 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___13 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___13 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___13 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___13 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___13 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___13 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___13 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___13 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___13 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___13 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___13 *);
	void (*complete)(struct net_device___13 *);
	u32 (*get_priv_flags)(struct net_device___13 *);
	int (*set_priv_flags)(struct net_device___13 *, u32);
	int (*get_sset_count)(struct net_device___13 *, int);
	int (*get_rxnfc)(struct net_device___13 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___13 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___13 *, struct ethtool_flash *);
	int (*reset)(struct net_device___13 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___13 *);
	u32 (*get_rxfh_indir_size)(struct net_device___13 *);
	int (*get_rxfh)(struct net_device___13 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___13 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___13 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___13 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___13 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___13 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___13 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___13 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___13 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___13 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___13 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___13 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___13 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___13 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___13 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___13 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___13 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___13 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___13 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___13 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___13 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___13 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	int (*get_fecparam)(struct net_device___13 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___13 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___13 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___13 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___13 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___8;

struct inet_frags___8 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___8 *, const void *);
	void (*destructor)(struct inet_frag_queue___8 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___8 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___12 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___12 *fragments_tail;
	struct sk_buff___12 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___8 *net;
	struct callback_head rcu;
};

struct fib_rule___4;

struct fib_lookup_arg___4;

struct fib_rules_ops___4 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___4 *, struct flowi *, int, struct fib_lookup_arg___4 *);
	bool (*suppress)(struct fib_rule___4 *, struct fib_lookup_arg___4 *);
	int (*match)(struct fib_rule___4 *, struct flowi *, int);
	int (*configure)(struct fib_rule___4 *, struct sk_buff___12 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___4 *);
	int (*compare)(struct fib_rule___4 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___4 *, struct sk_buff___12 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___4 *);
	void (*flush_cache)(struct fib_rules_ops___4 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___76 *owner;
	struct net___17 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___4 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___17 *);
	int (*fib_dump)(struct net___17 *, struct notifier_block *);
	struct module___76 *owner;
	struct callback_head rcu;
};

struct dst_entry___6 {
	struct net_device___13 *dev;
	struct dst_ops___15 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___12 *);
	int (*output)(struct net___17 *, struct sock___7 *, struct sk_buff___12 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___5;

struct neigh_parms___6;

struct neigh_ops___5;

struct neighbour___6 {
	struct neighbour___6 *next;
	struct neigh_table___5 *tbl;
	struct neigh_parms___6 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___9 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___6 *, struct sk_buff___12 *);
	const struct neigh_ops___5 *ops;
	struct callback_head rcu;
	struct net_device___13 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct net_generic {
	union {
		struct {
			unsigned int len;
			struct callback_head rcu;
		} s;
		void *ptr[0];
	};
};

struct pernet_operations___8 {
	struct list_head list;
	int (*init)(struct net___17 *);
	void (*exit)(struct net___17 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___8 {
	int (*ieee_getets)(struct net_device___13 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___13 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___13 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___13 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___13 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___13 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___13 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___13 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___13 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___13 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___13 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___13 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___13 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___13 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___13 *);
	u8 (*setstate)(struct net_device___13 *, u8);
	void (*getpermhwaddr)(struct net_device___13 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___13 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___13 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___13 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___13 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___13 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___13 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___13 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___13 *, int, u8 *);
	void (*setpfccfg)(struct net_device___13 *, int, u8);
	void (*getpfccfg)(struct net_device___13 *, int, u8 *);
	u8 (*setall)(struct net_device___13 *);
	u8 (*getcap)(struct net_device___13 *, int, u8 *);
	int (*getnumtcs)(struct net_device___13 *, int, u8 *);
	int (*setnumtcs)(struct net_device___13 *, int, u8);
	u8 (*getpfcstate)(struct net_device___13 *);
	void (*setpfcstate)(struct net_device___13 *, u8);
	void (*getbcncfg)(struct net_device___13 *, int, u32 *);
	void (*setbcncfg)(struct net_device___13 *, int, u32);
	void (*getbcnrp)(struct net_device___13 *, int, u8 *);
	void (*setbcnrp)(struct net_device___13 *, int, u8);
	int (*setapp)(struct net_device___13 *, u8, u16, u8);
	int (*getapp)(struct net_device___13 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___13 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___13 *, int, u8);
	u8 (*getdcbx)(struct net_device___13 *);
	u8 (*setdcbx)(struct net_device___13 *, u8);
	int (*peer_getappinfo)(struct net_device___13 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___13 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___13 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___13 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___13 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___13 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct xdp_rxq_info___8 {
	struct net_device___13 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___8 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___13 *dev_rx;
};

struct scm_creds {
	u32 pid;
	kuid_t uid;
	kgid_t gid;
};

struct netlink_skb_parms {
	struct scm_creds creds;
	__u32 portid;
	__u32 dst_group;
	__u32 flags;
	struct sock___7 *sk;
	bool nsid_is_set;
	int nsid;
};

struct netlink_kernel_cfg {
	unsigned int groups;
	unsigned int flags;
	void (*input)(struct sk_buff___12 *);
	struct mutex *cb_mutex;
	int (*bind)(struct net___17 *, int);
	void (*unbind)(struct net___17 *, int);
	bool (*compare)(struct net___17 *, struct sock___7 *);
};

struct netlink_callback___8 {
	struct sk_buff___12 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___8 *);
	int (*dump)(struct sk_buff___12 *, struct netlink_callback___8 *);
	int (*done)(struct netlink_callback___8 *);
	void *data;
	struct module___76 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___8 {
	int (*create)(struct sk_buff___12 *, struct net_device___13 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___12 *, unsigned char *);
	int (*cache)(const struct neighbour___6 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___13 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___8 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___8 *, int);
	int poll_owner;
	struct net_device___13 *dev;
	struct sk_buff___12 *gro_list;
	struct sk_buff___12 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___8 {
	struct net_device___13 *dev;
	struct Qdisc___7 *qdisc;
	struct Qdisc___7 *qdisc_sleeping;
	struct kobject___82 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___13 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___7 {
	struct sk_buff___12 *head;
	struct sk_buff___12 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___7;

struct Qdisc___7 {
	int (*enqueue)(struct sk_buff___12 *, struct Qdisc___7 *, struct sk_buff___12 **);
	struct sk_buff___12 * (*dequeue)(struct Qdisc___7 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___7 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___8 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___9 gso_skb;
	struct qdisc_skb_head___7 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___7 *next_sched;
	struct sk_buff_head___9 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___8 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___82 kobj;
	struct net_device___13 *dev;
	long: 64;
	struct xdp_rxq_info___8 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___8)(struct net_device___13 *, struct sk_buff___12 *, struct net_device___13 *);

struct netdev_bpf___8 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___7 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___7 *prog;
			const struct bpf_prog_offload_ops___7 *ops;
		} verifier;
		struct {
			struct bpf_prog___7 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___8 *offmap;
		};
		struct {
			struct xdp_umem *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___8 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___12 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___8 {
	int (*tls_dev_add)(struct net_device___13 *, struct sock___7 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___13 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___13 *, struct sock___7 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___8 {
	int (*ndo_init)(struct net_device___13 *);
	void (*ndo_uninit)(struct net_device___13 *);
	int (*ndo_open)(struct net_device___13 *);
	int (*ndo_stop)(struct net_device___13 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___12 *, struct net_device___13 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___12 *, struct net_device___13 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___13 *, struct sk_buff___12 *, struct net_device___13 *, select_queue_fallback_t___8);
	void (*ndo_change_rx_flags)(struct net_device___13 *, int);
	void (*ndo_set_rx_mode)(struct net_device___13 *);
	int (*ndo_set_mac_address)(struct net_device___13 *, void *);
	int (*ndo_validate_addr)(struct net_device___13 *);
	int (*ndo_do_ioctl)(struct net_device___13 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___13 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___13 *, int);
	int (*ndo_neigh_setup)(struct net_device___13 *, struct neigh_parms___6 *);
	void (*ndo_tx_timeout)(struct net_device___13 *);
	void (*ndo_get_stats64)(struct net_device___13 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___13 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___13 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___13 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___13 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___13 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___13 *);
	int (*ndo_netpoll_setup)(struct net_device___13 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___13 *);
	int (*ndo_set_vf_mac)(struct net_device___13 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___13 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___13 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___13 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___13 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___13 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___13 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___13 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___13 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___13 *, int, struct sk_buff___12 *);
	int (*ndo_set_vf_guid)(struct net_device___13 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___13 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___13 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___13 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___13 *, const struct sk_buff___12 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___13 *, struct net_device___13 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___13 *, struct net_device___13 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___13 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___13 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___13 *, struct neighbour___6 *);
	void (*ndo_neigh_destroy)(struct net_device___13 *, struct neighbour___6 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___13 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___13 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___13 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___12 *, struct netlink_callback___8 *, struct net_device___13 *, struct net_device___13 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___13 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___13 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide35;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___12 *, u32, u32, struct net_device___13 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___13 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___13 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___13 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___13 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___13 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___13 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___13 *, struct net_device___13 *);
	void (*ndo_dfwd_del_station)(struct net_device___13 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___13 *);
	int (*ndo_set_tx_maxrate)(struct net_device___13 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___13 *);
	int (*ndo_change_proto_down)(struct net_device___13 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___13 *, struct sk_buff___12 *);
	void (*ndo_set_rx_headroom)(struct net_device___13 *, int);
	int (*ndo_bpf)(struct net_device___13 *, struct netdev_bpf___8 *);
	int (*ndo_xdp_xmit)(struct net_device___13 *, int, struct xdp_frame___8 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___13 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___13 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide36;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___6 {
	possible_net_t___8 net;
	struct net_device___13 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___6 *);
	void (*neigh_cleanup)(struct neighbour___6 *);
	struct neigh_table___5 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___5 {
	u32 (*l3mdev_fib_table)(const struct net_device___13 *);
	struct sk_buff___12 * (*l3mdev_l3_rcv)(struct net_device___13 *, struct sk_buff___12 *, u16);
	struct sk_buff___12 * (*l3mdev_l3_out)(struct net_device___13 *, struct sock___7 *, struct sk_buff___12 *, u16);
	struct dst_entry___6 * (*l3mdev_link_scope_lookup)(const struct net_device___13 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct tcf_proto___7;

struct mini_Qdisc___7 {
	struct tcf_proto___7 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___7 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___13 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___17 *, struct net_device___13 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___13 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___13 *, struct list_head *);
	size_t (*get_size)(const struct net_device___13 *);
	int (*fill_info)(struct sk_buff___12 *, const struct net_device___13 *);
	size_t (*get_xstats_size)(const struct net_device___13 *);
	int (*fill_xstats)(struct sk_buff___12 *, const struct net_device___13 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___13 *, struct net_device___13 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___13 *, const struct net_device___13 *);
	int (*fill_slave_info)(struct sk_buff___12 *, const struct net_device___13 *, const struct net_device___13 *);
	struct net___17 * (*get_link_net)(const struct net_device___13 *);
	size_t (*get_linkxstats_size)(const struct net_device___13 *, int);
	int (*fill_linkxstats)(struct sk_buff___12 *, const struct net_device___13 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___8 {
	struct list_head poll_list;
	struct sk_buff_head___9 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___8 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___7 *output_queue;
	struct Qdisc___7 **output_queue_tailp;
	struct sk_buff___12 *completion_queue;
	struct sk_buff_head___9 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___8 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___9 input_pkt_queue;
	struct napi_struct___8 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bdi_writeback_congested___35 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___35 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___35 {
	struct bio___35 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___35 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___35 bip_inline_vecs[0];
};

struct bio_set___35 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___35 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___32 {
	struct mem_cgroup___32 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___32 {
	struct lruvec___87 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___32 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___32 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct gnet_dump___7 {
	spinlock_t *lock;
	struct sk_buff___12 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___7;

struct Qdisc_ops___7 {
	struct Qdisc_ops___7 *next;
	const struct Qdisc_class_ops___7 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___12 *, struct Qdisc___7 *, struct sk_buff___12 **);
	struct sk_buff___12 * (*dequeue)(struct Qdisc___7 *);
	struct sk_buff___12 * (*peek)(struct Qdisc___7 *);
	int (*init)(struct Qdisc___7 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___7 *);
	void (*destroy)(struct Qdisc___7 *);
	int (*change)(struct Qdisc___7 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___7 *);
	int (*change_tx_queue_len)(struct Qdisc___7 *, unsigned int);
	int (*dump)(struct Qdisc___7 *, struct sk_buff___12 *);
	int (*dump_stats)(struct Qdisc___7 *, struct gnet_dump___7 *);
	void (*ingress_block_set)(struct Qdisc___7 *, u32);
	void (*egress_block_set)(struct Qdisc___7 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___7 *);
	u32 (*egress_block_get)(struct Qdisc___7 *);
	struct module___76 *owner;
};

struct tcf_block___7;

struct Qdisc_class_ops___7 {
	unsigned int flags;
	struct netdev_queue___8 * (*select_queue)(struct Qdisc___7 *, struct tcmsg *);
	int (*graft)(struct Qdisc___7 *, long unsigned int, struct Qdisc___7 *, struct Qdisc___7 **, struct netlink_ext_ack *);
	struct Qdisc___7 * (*leaf)(struct Qdisc___7 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___7 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___7 *, u32);
	int (*change)(struct Qdisc___7 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___7 *, long unsigned int);
	void (*walk)(struct Qdisc___7 *, struct qdisc_walker *);
	struct tcf_block___7 * (*tcf_block)(struct Qdisc___7 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___7 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___7 *, long unsigned int);
	int (*dump)(struct Qdisc___7 *, long unsigned int, struct sk_buff___12 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___7 *, long unsigned int, struct gnet_dump___7 *);
};

struct tcf_chain___7;

struct tcf_block___7 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___17 *net;
	struct Qdisc___7 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___7 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___7;

struct tcf_proto_ops___7;

struct tcf_proto___7 {
	struct tcf_proto___7 *next;
	void *root;
	int (*classify)(struct sk_buff___12 *, const struct tcf_proto___7 *, struct tcf_result___7 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___7 *ops;
	struct tcf_chain___7 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___7 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___7 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___7 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___12 *, const struct tcf_proto___7 *, struct tcf_result___7 *);
	int (*init)(struct tcf_proto___7 *);
	void (*destroy)(struct tcf_proto___7 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___7 *, u32);
	void (*put)(struct tcf_proto___7 *, void *);
	int (*change)(struct net___17 *, struct sk_buff___12 *, struct tcf_proto___7 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___7 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___7 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___7 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___17 *, struct tcf_chain___7 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___17 *, struct tcf_proto___7 *, void *, struct sk_buff___12 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___12 *, struct net___17 *, void *);
	struct module___76 *owner;
	int flags;
};

struct tcf_chain___7 {
	struct mutex filter_chain_lock;
	struct tcf_proto___7 *filter_chain;
	struct list_head list;
	struct tcf_block___7 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___7 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___4 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___7 *prog;
};

struct bpf_redirect_info___7 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___70 *map;
	struct bpf_map___70 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___4;

struct neigh_hash_table___4;

struct neigh_table___5 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___13 *, __u32 *);
	bool (*key_eq)(const struct neighbour___6 *, const void *);
	int (*constructor)(struct neighbour___6 *);
	int (*pconstructor)(struct pneigh_entry___4 *);
	void (*pdestructor)(struct pneigh_entry___4 *);
	void (*proxy_redo)(struct sk_buff___12 *);
	char *id;
	struct neigh_parms___6 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___9 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___4 *nht;
	struct pneigh_entry___4 **phash_buckets;
};

struct neigh_ops___5 {
	int family;
	void (*solicit)(struct neighbour___6 *, struct sk_buff___12 *);
	void (*error_report)(struct neighbour___6 *, struct sk_buff___12 *);
	int (*output)(struct neighbour___6 *, struct sk_buff___12 *);
	int (*connected_output)(struct neighbour___6 *, struct sk_buff___12 *);
};

struct pneigh_entry___4 {
	struct pneigh_entry___4 *next;
	possible_net_t___8 net;
	struct net_device___13 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___4 {
	struct neighbour___6 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___4 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___4 *ctarget;
	struct net___17 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___4 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___4 *rule;
	u32 table;
	int flags;
};

struct proto___4 {
	void (*close)(struct sock___7 *, long int);
	int (*pre_connect)(struct sock___7 *, struct sockaddr *, int);
	int (*connect)(struct sock___7 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___7 *, int);
	struct sock___7 * (*accept)(struct sock___7 *, int, int *, bool);
	int (*ioctl)(struct sock___7 *, int, long unsigned int);
	int (*init)(struct sock___7 *);
	void (*destroy)(struct sock___7 *);
	void (*shutdown)(struct sock___7 *, int);
	int (*setsockopt)(struct sock___7 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___7 *, int, int, char *, int *);
	void (*keepalive)(struct sock___7 *, int);
	int (*sendmsg)(struct sock___7 *, struct msghdr___4 *, size_t);
	int (*recvmsg)(struct sock___7 *, struct msghdr___4 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___7 *, struct page___88 *, int, size_t, int);
	int (*bind)(struct sock___7 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___7 *, struct sk_buff___12 *);
	void (*release_cb)(struct sock___7 *);
	int (*hash)(struct sock___7 *);
	void (*unhash)(struct sock___7 *);
	void (*rehash)(struct sock___7 *);
	int (*get_port)(struct sock___7 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___7 *);
	bool (*stream_memory_read)(const struct sock___7 *);
	void (*enter_memory_pressure)(struct sock___7 *);
	void (*leave_memory_pressure)(struct sock___7 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___3 *rsk_prot;
	struct timewait_sock_ops___3 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___76 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___7 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct tty_operations___10 {
	struct tty_struct___10 * (*lookup)(struct tty_driver___10 *, struct file___88 *, int);
	int (*install)(struct tty_driver___10 *, struct tty_struct___10 *);
	void (*remove)(struct tty_driver___10 *, struct tty_struct___10 *);
	int (*open)(struct tty_struct___10 *, struct file___88 *);
	void (*close)(struct tty_struct___10 *, struct file___88 *);
	void (*shutdown)(struct tty_struct___10 *);
	void (*cleanup)(struct tty_struct___10 *);
	int (*write)(struct tty_struct___10 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___10 *, unsigned char);
	void (*flush_chars)(struct tty_struct___10 *);
	int (*write_room)(struct tty_struct___10 *);
	int (*chars_in_buffer)(struct tty_struct___10 *);
	int (*ioctl)(struct tty_struct___10 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___10 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___10 *, struct ktermios *);
	void (*throttle)(struct tty_struct___10 *);
	void (*unthrottle)(struct tty_struct___10 *);
	void (*stop)(struct tty_struct___10 *);
	void (*start)(struct tty_struct___10 *);
	void (*hangup)(struct tty_struct___10 *);
	int (*break_ctl)(struct tty_struct___10 *, int);
	void (*flush_buffer)(struct tty_struct___10 *);
	void (*set_ldisc)(struct tty_struct___10 *);
	void (*wait_until_sent)(struct tty_struct___10 *, int);
	void (*send_xchar)(struct tty_struct___10 *, char);
	int (*tiocmget)(struct tty_struct___10 *);
	int (*tiocmset)(struct tty_struct___10 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___10 *, struct winsize *);
	int (*set_termiox)(struct tty_struct___10 *, struct termiox *);
	int (*get_icount)(struct tty_struct___10 *, struct serial_icounter_struct *);
	void (*show_fdinfo)(struct tty_struct___10 *, struct seq_file___81 *);
	int (*poll_init)(struct tty_driver___10 *, int, char *);
	int (*poll_get_char)(struct tty_driver___10 *, int);
	void (*poll_put_char)(struct tty_driver___10 *, int, char);
	int (*proc_show)(struct seq_file___81 *, void *);
};

struct tty_driver___10 {
	int magic;
	struct kref kref;
	struct cdev___24 **cdevs;
	struct module___76 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___10 *other;
	struct tty_struct___10 **ttys;
	struct tty_port___10 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___10 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___10;

struct tty_port_client_operations___10;

struct tty_port___10 {
	struct tty_bufhead buf;
	struct tty_struct___10 *tty;
	struct tty_struct___10 *itty;
	const struct tty_port_operations___10 *ops;
	const struct tty_port_client_operations___10 *client_ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	unsigned char low_latency: 1;
	struct mutex mutex;
	struct mutex buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
	void *client_data;
};

struct tty_ldisc_ops___10 {
	int magic;
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___10 *);
	void (*close)(struct tty_struct___10 *);
	void (*flush_buffer)(struct tty_struct___10 *);
	ssize_t (*read)(struct tty_struct___10 *, struct file___88 *, unsigned char *, size_t);
	ssize_t (*write)(struct tty_struct___10 *, struct file___88 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___10 *, struct file___88 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___10 *, struct file___88 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___10 *, struct ktermios *);
	__poll_t (*poll)(struct tty_struct___10 *, struct file___88 *, struct poll_table_struct___58 *);
	int (*hangup)(struct tty_struct___10 *);
	void (*receive_buf)(struct tty_struct___10 *, const unsigned char *, char *, int);
	void (*write_wakeup)(struct tty_struct___10 *);
	void (*dcd_change)(struct tty_struct___10 *, unsigned int);
	int (*receive_buf2)(struct tty_struct___10 *, const unsigned char *, char *, int);
	struct module___76 *owner;
	int refcount;
};

struct tty_ldisc___10 {
	struct tty_ldisc_ops___10 *ops;
	struct tty_struct___10 *tty;
};

struct tty_port_operations___10 {
	int (*carrier_raised)(struct tty_port___10 *);
	void (*dtr_rts)(struct tty_port___10 *, int);
	void (*shutdown)(struct tty_port___10 *);
	int (*activate)(struct tty_port___10 *, struct tty_struct___10 *);
	void (*destruct)(struct tty_port___10 *);
};

struct tty_port_client_operations___10 {
	int (*receive_buf)(struct tty_port___10 *, const unsigned char *, const unsigned char *, size_t);
	void (*write_wakeup)(struct tty_port___10 *);
};

struct audit_netlink_list {
	__u32 portid;
	struct net___17 *net;
	struct sk_buff_head___9 q;
};

struct audit_net {
	struct sock___7 *sk;
};

struct auditd_connection {
	struct pid___72 *pid;
	u32 portid;
	struct net___17 *net;
	struct callback_head rcu;
};

struct audit_ctl_mutex {
	struct mutex lock;
	void *owner;
};

struct audit_buffer {
	struct sk_buff___12 *skb;
	struct audit_context___2 *ctx;
	gfp_t gfp_mask;
};

struct audit_reply {
	__u32 portid;
	struct net___17 *net;
	struct sk_buff___12 *skb;
};

struct module___77;

struct file___89;

struct kiocb___89;

struct iov_iter___35;

struct poll_table_struct___59;

struct vm_area_struct___89;

struct inode___90;

struct file_lock___89;

struct page___89;

struct pipe_inode_info___17;

struct seq_file___82;

struct file_operations___89 {
	struct module___77 *owner;
	loff_t (*llseek)(struct file___89 *, loff_t, int);
	ssize_t (*read)(struct file___89 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___89 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___89 *, struct iov_iter___35 *);
	ssize_t (*write_iter)(struct kiocb___89 *, struct iov_iter___35 *);
	int (*iopoll)(struct kiocb___89 *, bool);
	int (*iterate)(struct file___89 *, struct dir_context *);
	int (*iterate_shared)(struct file___89 *, struct dir_context *);
	__poll_t (*poll)(struct file___89 *, struct poll_table_struct___59 *);
	long int (*unlocked_ioctl)(struct file___89 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___89 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___89 *, struct vm_area_struct___89 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___90 *, struct file___89 *);
	int (*flush)(struct file___89 *, fl_owner_t);
	int (*release)(struct inode___90 *, struct file___89 *);
	int (*fsync)(struct file___89 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___89 *, int);
	int (*lock)(struct file___89 *, int, struct file_lock___89 *);
	ssize_t (*sendpage)(struct file___89 *, struct page___89 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___89 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___89 *, int, struct file_lock___89 *);
	ssize_t (*splice_write)(struct pipe_inode_info___17 *, struct file___89 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___89 *, loff_t *, struct pipe_inode_info___17 *, size_t, unsigned int);
	int (*setlease)(struct file___89 *, long int, struct file_lock___89 **, void **);
	long int (*fallocate)(struct file___89 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___82 *, struct file___89 *);
	ssize_t (*copy_file_range)(struct file___89 *, loff_t, struct file___89 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___89 *, loff_t, struct file___89 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___89 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___88 {
	u64 seqnum;
	struct vm_area_struct___89 *vmas[4];
};

struct page_frag___88 {
	struct page___89 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___88;

struct mem_cgroup___33;

struct pid___73;

struct cred___85;

struct nsproxy___82;

struct signal_struct___79;

struct audit_context___3;

struct bio_list___36;

struct backing_dev_info___36;

struct css_set___71;

struct vm_struct___63;

struct task_struct___89 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___89 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___88 *mm;
	struct mm_struct___88 *active_mm;
	struct vmacache___88 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___89 *real_parent;
	struct task_struct___89 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___89 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___33 *active_memcg;
	long int rh_reserved2;
	struct pid___73 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___73 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___73 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___85 *ptracer_cred;
	const struct cred___85 *real_cred;
	const struct cred___85 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___82 *nsproxy;
	struct signal_struct___79 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context___3 *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___89 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___36 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___36 *backing_dev_info;
	struct io_context___15 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___71 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___17 *splice_pipe;
	struct page_frag___88 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___33 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___89 *oom_reaper_list;
	struct vm_struct___63 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___55 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___73;

struct upid___73 {
	int nr;
	struct pid_namespace___73 *ns;
};

struct dentry___89;

struct user_namespace___74;

struct ucounts___74;

struct pid_namespace___73 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___89 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___73 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___89 *proc_self;
	struct dentry___89 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___74 *user_ns;
	struct ucounts___74 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___7 ns;
};

struct pid___73 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___73 numbers[1];
};

struct rw_semaphore___89 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___89 *owner;
};

struct key___85;

struct user_namespace___74 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___74 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___7 ns;
	long unsigned int flags;
	struct key___85 *persistent_keyring_register;
	struct rw_semaphore___89 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___74 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct secondary_data___89 {
	void *stack;
	struct task_struct___89 *task;
	long int status;
};

typedef struct page___89 *pgtable_t___88;

struct address_space___88;

struct dev_pagemap___86;

struct page___89 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___88 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___89 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___88 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___88 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___86 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___33 *mem_cgroup;
};

struct user_struct___85 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___85 *uid_keyring;
	struct key___85 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___86;

struct vm_area_struct___89 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___89 *vm_next;
	struct vm_area_struct___89 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___88 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___86 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___89 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___88;

struct mm_struct___88 {
	struct {
		struct vm_area_struct___89 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___89 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___89 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___88 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___89 *owner;
		struct user_namespace___74 *user_ns;
		struct file___89 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___88 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup___71;

struct cgroup_subsys___71;

struct cgroup_subsys_state___71 {
	struct cgroup___71 *cgroup;
	struct cgroup_subsys___71 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___71 *parent;
};

struct kernfs_node___85;

struct cgroup_file___71 {
	struct kernfs_node___85 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___33;

struct mem_cgroup___33 {
	struct cgroup_subsys_state___71 css;
	struct mem_cgroup_id___13 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___71 events_file;
	struct cgroup_file___71 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___89 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___33 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cred___85 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___85 *session_keyring;
	struct key___85 *process_keyring;
	struct key___85 *thread_keyring;
	struct key___85 *request_key_auth;
	void *security;
	struct user_struct___85 *user;
	struct user_namespace___74 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___18;

struct cgroup_namespace___71;

struct nsproxy___82 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___73 *pid_ns_for_children;
	struct net___18 *net_ns;
	struct cgroup_namespace___71 *cgroup_ns;
};

struct tty_struct___11;

struct signal_struct___79 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___89 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___89 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___73 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___73 *tty_old_pgrp;
	int leader;
	struct tty_struct___11 *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___88 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___73 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct path___88 {
	struct vfsmount *mnt;
	struct dentry___89 *dentry;
};

struct audit_context___3 {
	int dummy;
	int in_syscall;
	enum audit_state state;
	enum audit_state current_state;
	unsigned int serial;
	int major;
	struct timespec64 ctime;
	long unsigned int argv[4];
	long int return_code;
	u64 prio;
	int return_valid;
	struct audit_names preallocated_names[5];
	int name_count;
	struct list_head names_list;
	char *filterkey;
	struct path___88 pwd;
	struct audit_aux_data *aux;
	struct audit_aux_data *aux_pids;
	struct __kernel_sockaddr_storage *sockaddr;
	size_t sockaddr_len;
	pid_t pid;
	pid_t ppid;
	kuid_t uid;
	kuid_t euid;
	kuid_t suid;
	kuid_t fsuid;
	kgid_t gid;
	kgid_t egid;
	kgid_t sgid;
	kgid_t fsgid;
	long unsigned int personality;
	int arch;
	pid_t target_pid;
	kuid_t target_auid;
	kuid_t target_uid;
	unsigned int target_sessionid;
	u32 target_sid;
	char target_comm[16];
	struct audit_tree_refs *trees;
	struct audit_tree_refs *first_trees;
	struct list_head killed_trees;
	int tree_count;
	int type;
	union {
		struct {
			int nargs;
			long int args[6];
		} socketcall;
		struct {
			kuid_t uid;
			kgid_t gid;
			umode_t mode;
			u32 osid;
			int has_perm;
			uid_t perm_uid;
			gid_t perm_gid;
			umode_t perm_mode;
			long unsigned int qbytes;
		} ipc;
		struct {
			mqd_t mqdes;
			struct mq_attr mqstat;
		} mq_getsetattr;
		struct {
			mqd_t mqdes;
			int sigev_signo;
		} mq_notify;
		struct {
			mqd_t mqdes;
			size_t msg_len;
			unsigned int msg_prio;
			struct timespec64 abs_timeout;
		} mq_sendrecv;
		struct {
			int oflag;
			umode_t mode;
			struct mq_attr attr;
		} mq_open;
		struct {
			pid_t pid;
			struct audit_cap_data cap;
		} capset;
		struct {
			int fd;
			int flags;
		} mmap;
		struct {
			int argc;
		} execve;
		struct {
			char *name;
		} module;
	};
	int fds[2];
	struct audit_proctitle proctitle;
};

struct bio___36;

struct bio_list___36 {
	struct bio___36 *head;
	struct bio___36 *tail;
};

struct bdi_writeback_congested___36;

struct bdi_writeback___36 {
	struct backing_dev_info___36 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___36 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___71 *memcg_css;
	struct cgroup_subsys_state___71 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___81;

struct backing_dev_info___36 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___36 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___81 *dev;
	struct device___81 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___89 *debug_dir;
	struct dentry___89 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___71 {
	struct cgroup_subsys_state___71 *subsys[13];
	refcount_t refcount;
	struct css_set___71 *dom_cset;
	struct cgroup___71 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___71 *mg_src_cgrp;
	struct cgroup___71 *mg_dst_cgrp;
	struct css_set___71 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___88;

struct pipe_buffer___17;

struct pipe_inode_info___17 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___89 *tmp_page;
	struct fasync_struct___88 *fasync_readers;
	struct fasync_struct___88 *fasync_writers;
	struct pipe_buffer___17 *bufs;
	struct user_struct___85 *user;
};

struct vm_struct___63 {
	struct vm_struct___63 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___89 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___79 {
	struct task_struct___89 task;
	long unsigned int stack[8192];
};

typedef int (*key_restrict_link_func_t___85)(struct key___85 *, const struct key_type *, const union key_payload *, struct key___85 *);

struct key_restriction___85;

struct key___85 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___89 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___85 *restrict_link;
};

struct key_restriction___85 {
	key_restrict_link_func_t___85 check;
	struct key___85 *key;
	struct key_type *keytype;
};

struct tty_driver___11;

struct tty_operations___11;

struct tty_ldisc___11;

struct tty_port___11;

struct tty_struct___11 {
	int magic;
	struct kref kref;
	struct device___81 *dev;
	struct tty_driver___11 *driver;
	const struct tty_operations___11 *ops;
	int index;
	struct ld_semaphore ldisc_sem;
	struct tty_ldisc___11 *ldisc;
	struct mutex atomic_write_lock;
	struct mutex legacy_mutex;
	struct mutex throttle_mutex;
	struct rw_semaphore___89 termios_rwsem;
	struct mutex winsize_mutex;
	spinlock_t ctrl_lock;
	spinlock_t flow_lock;
	struct ktermios termios;
	struct ktermios termios_locked;
	struct termiox *termiox;
	char name[64];
	struct pid___73 *pgrp;
	struct pid___73 *session;
	long unsigned int flags;
	int count;
	struct winsize winsize;
	long unsigned int stopped: 1;
	long unsigned int flow_stopped: 1;
	int: 30;
	long unsigned int unused: 62;
	int hw_stopped;
	long unsigned int ctrl_status: 8;
	long unsigned int packet: 1;
	int: 23;
	long unsigned int unused_ctrl: 55;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___11 *link;
	struct fasync_struct___88 *fasync;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	spinlock_t files_lock;
	struct list_head tty_files;
	int closing;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___11 *port;
};

struct pglist_data___88;

struct lruvec___88 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___88 *pgdat;
};

struct zone___88 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___88 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___88 {
	struct zone___88 *zone;
	int zone_idx;
};

struct zonelist___88 {
	struct zoneref___88 _zonerefs[25];
};

struct pglist_data___88 {
	struct zone___88 node_zones[3];
	struct zonelist___88 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___89 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___89 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___88 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___88 {
	struct rw_semaphore___89 rwsem;
	struct notifier_block *head;
};

struct address_space_operations___88;

struct address_space___88 {
	struct inode___90 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___89 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___88 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___86)(struct vm_area_struct___89 *, long unsigned int, const struct page___89 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___86)(struct page___89 *, void *);

struct dev_pagemap___86 {
	dev_page_fault_t___86 page_fault;
	dev_page_free_t___86 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___81 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct fown_struct___73 {
	rwlock_t lock;
	struct pid___73 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___89 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___88 f_path;
	struct inode___90 *f_inode;
	const struct file_operations___89 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___73 f_owner;
	const struct cred___85 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___88 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___86;

struct vm_operations_struct___86 {
	void (*open)(struct vm_area_struct___89 *);
	void (*close)(struct vm_area_struct___89 *);
	int (*split)(struct vm_area_struct___89 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___89 *);
	vm_fault_t (*fault)(struct vm_fault___86 *);
	vm_fault_t (*huge_fault)(struct vm_fault___86 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___86 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___89 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___86 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___86 *);
	int (*access)(struct vm_area_struct___89 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___89 *);
	int (*set_policy)(struct vm_area_struct___89 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___89 *, long unsigned int);
	struct page___89 * (*find_special_page)(struct vm_area_struct___89 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___88 {
	struct task_struct___89 *task;
	struct core_thread___88 *next;
};

struct core_state___88 {
	atomic_t nr_threads;
	struct core_thread___88 dumper;
	struct completion startup;
};

struct vm_fault___86 {
	struct vm_area_struct___89 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___89 *cow_page;
	struct mem_cgroup___33 *memcg;
	struct page___89 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___88 prealloc_pte;
};

struct shrink_control___33 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___33 *memcg;
};

struct shrinker___33 {
	long unsigned int (*count_objects)(struct shrinker___33 *, struct shrink_control___33 *);
	long unsigned int (*scan_objects)(struct shrinker___33 *, struct shrink_control___33 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct kset___82;

struct kobj_type___82;

struct kobject___83 {
	const char *name;
	struct list_head entry;
	struct kobject___83 *parent;
	struct kset___82 *kset;
	struct kobj_type___82 *ktype;
	struct kernfs_node___85 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___81 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___81 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___81;

struct bus_type___81;

struct device_driver___81;

struct dev_pm_domain___81;

struct dma_map_ops___22;

struct fwnode_handle___59;

struct class___81;

struct attribute_group___80;

struct device___81 {
	struct device___81 *parent;
	struct device_private *p;
	struct kobject___83 kobj;
	const char *init_name;
	const struct device_type___81 *type;
	struct mutex mutex;
	struct bus_type___81 *bus;
	struct device_driver___81 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___81 power;
	struct dev_pm_domain___81 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___22 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___59 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___81 *class;
	const struct attribute_group___80 **groups;
	void (*release)(struct device___81 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___88;

struct super_block___89;

struct dentry___89 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___89 *d_parent;
	struct qstr d_name;
	struct inode___90 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___88 *d_op;
	struct super_block___89 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___88;

struct block_device___89;

struct cdev___25;

struct inode___90 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___88 *i_op;
	struct super_block___89 *i_sb;
	struct address_space___88 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___89 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___36 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___89 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___88 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___17 *i_pipe;
		struct block_device___89 *i_bdev;
		struct cdev___25 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___88 {
	int (*d_revalidate)(struct dentry___89 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___89 *, unsigned int);
	int (*d_hash)(const struct dentry___89 *, struct qstr *);
	int (*d_compare)(const struct dentry___89 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___89 *);
	int (*d_init)(struct dentry___89 *);
	void (*d_release)(struct dentry___89 *);
	void (*d_prune)(struct dentry___89 *);
	void (*d_iput)(struct dentry___89 *, struct inode___90 *);
	char * (*d_dname)(struct dentry___89 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___88 *);
	int (*d_manage)(const struct path___88 *, bool);
	struct dentry___89 * (*d_real)(struct dentry___89 *, const struct inode___90 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___88;

struct mem_dqinfo___88 {
	struct quota_format_type___88 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___88;

struct quota_info___88 {
	unsigned int flags;
	struct rw_semaphore___89 dqio_sem;
	struct inode___90 *files[3];
	struct mem_dqinfo___88 info[3];
	const struct quota_format_ops___88 *ops[3];
};

struct rcuwait___88 {
	struct task_struct___89 *task;
};

struct percpu_rw_semaphore___88 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___89 rw_sem;
	struct rcuwait___88 writer;
	int readers_block;
};

struct sb_writers___88 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___88 rw_sem[3];
};

struct file_system_type___88;

struct super_operations___88;

struct dquot_operations___88;

struct quotactl_ops___88;

struct super_block___89 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___88 *s_type;
	const struct super_operations___88 *s_op;
	const struct dquot_operations___88 *dq_op;
	const struct quotactl_ops___88 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___89 *s_root;
	struct rw_semaphore___89 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___89 *s_bdev;
	struct backing_dev_info___36 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___88 s_dquot;
	struct sb_writers___88 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___88 *s_d_op;
	int cleancache_poolid;
	struct shrinker___33 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___74 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___89 {
	struct file___89 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___89 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___89 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___89 *ia_file;
};

struct dquot___88 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___89 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___88 {
	int qf_fmt_id;
	const struct quota_format_ops___88 *qf_ops;
	struct module___77 *qf_owner;
	struct quota_format_type___88 *qf_next;
};

struct quota_format_ops___88 {
	int (*check_quota_file)(struct super_block___89 *, int);
	int (*read_file_info)(struct super_block___89 *, int);
	int (*write_file_info)(struct super_block___89 *, int);
	int (*free_file_info)(struct super_block___89 *, int);
	int (*read_dqblk)(struct dquot___88 *);
	int (*commit_dqblk)(struct dquot___88 *);
	int (*release_dqblk)(struct dquot___88 *);
	int (*get_next_id)(struct super_block___89 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___88 {
	int (*write_dquot)(struct dquot___88 *);
	struct dquot___88 * (*alloc_dquot)(struct super_block___89 *, int);
	void (*destroy_dquot)(struct dquot___88 *);
	int (*acquire_dquot)(struct dquot___88 *);
	int (*release_dquot)(struct dquot___88 *);
	int (*mark_dirty)(struct dquot___88 *);
	int (*write_info)(struct super_block___89 *, int);
	qsize_t * (*get_reserved_space)(struct inode___90 *);
	int (*get_projid)(struct inode___90 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___90 *, qsize_t *);
	int (*get_next_id)(struct super_block___89 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___88 {
	int (*quota_on)(struct super_block___89 *, int, int, const struct path___88 *);
	int (*quota_off)(struct super_block___89 *, int);
	int (*quota_enable)(struct super_block___89 *, unsigned int);
	int (*quota_disable)(struct super_block___89 *, unsigned int);
	int (*quota_sync)(struct super_block___89 *, int);
	int (*set_info)(struct super_block___89 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___89 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___89 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___89 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___89 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___89 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___74 {
	struct kobject___83 kobj;
	struct module___77 *mod;
	struct kobject___83 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___74 {
	struct module___77 *mod;
	struct latch_tree_node node;
};

struct module_layout___74 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___74 mtn;
};

struct module_attribute___74;

struct kernel_param___74;

struct module___77 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___74 mkobj;
	struct module_attribute___74 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___83 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___74 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___74 core_layout;
	struct module_layout___74 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide55;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide56;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___34;

struct address_space_operations___88 {
	int (*writepage)(struct page___89 *, struct writeback_control___34 *);
	int (*readpage)(struct file___89 *, struct page___89 *);
	int (*writepages)(struct address_space___88 *, struct writeback_control___34 *);
	int (*set_page_dirty)(struct page___89 *);
	int (*readpages)(struct file___89 *, struct address_space___88 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___89 *, struct address_space___88 *, loff_t, unsigned int, unsigned int, struct page___89 **, void **);
	int (*write_end)(struct file___89 *, struct address_space___88 *, loff_t, unsigned int, unsigned int, struct page___89 *, void *);
	sector_t (*bmap)(struct address_space___88 *, sector_t);
	void (*invalidatepage)(struct page___89 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___89 *, gfp_t);
	void (*freepage)(struct page___89 *);
	ssize_t (*direct_IO)(struct kiocb___89 *, struct iov_iter___35 *);
	int (*migratepage)(struct address_space___88 *, struct page___89 *, struct page___89 *, enum migrate_mode);
	bool (*isolate_page)(struct page___89 *, isolate_mode_t);
	void (*putback_page)(struct page___89 *);
	int (*launder_page)(struct page___89 *);
	int (*is_partially_uptodate)(struct page___89 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___89 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___88 *, struct page___89 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___89 *, sector_t *);
	void (*swap_deactivate)(struct file___89 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___34 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___36 *wb;
	struct inode___90 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___36;

struct iov_iter___35 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___36 *bvec;
		struct pipe_inode_info___17 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___89 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___90 *bd_inode;
	struct super_block___89 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___89 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___36 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___25 {
	struct kobject___83 kobj;
	struct module___77 *owner;
	const struct file_operations___89 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___88 {
	struct dentry___89 * (*lookup)(struct inode___90 *, struct dentry___89 *, unsigned int);
	const char * (*get_link)(struct dentry___89 *, struct inode___90 *, struct delayed_call *);
	int (*permission)(struct inode___90 *, int);
	struct posix_acl * (*get_acl)(struct inode___90 *, int);
	int (*readlink)(struct dentry___89 *, char *, int);
	int (*create)(struct inode___90 *, struct dentry___89 *, umode_t, bool);
	int (*link)(struct dentry___89 *, struct inode___90 *, struct dentry___89 *);
	int (*unlink)(struct inode___90 *, struct dentry___89 *);
	int (*symlink)(struct inode___90 *, struct dentry___89 *, const char *);
	int (*mkdir)(struct inode___90 *, struct dentry___89 *, umode_t);
	int (*rmdir)(struct inode___90 *, struct dentry___89 *);
	int (*mknod)(struct inode___90 *, struct dentry___89 *, umode_t, dev_t);
	int (*rename)(struct inode___90 *, struct dentry___89 *, struct inode___90 *, struct dentry___89 *, unsigned int);
	int (*setattr)(struct dentry___89 *, struct iattr___89 *);
	int (*getattr)(const struct path___88 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___89 *, char *, size_t);
	int (*fiemap)(struct inode___90 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___90 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___90 *, struct dentry___89 *, struct file___89 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___90 *, struct dentry___89 *, umode_t);
	int (*set_acl)(struct inode___90 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___88 {
	void (*fl_copy_lock)(struct file_lock___89 *, struct file_lock___89 *);
	void (*fl_release_private)(struct file_lock___89 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___88;

struct file_lock___89 {
	struct file_lock___89 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___89 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___88 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___88 *fl_ops;
	const struct lock_manager_operations___88 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___88 {
	int (*lm_compare_owner)(struct file_lock___89 *, struct file_lock___89 *);
	long unsigned int (*lm_owner_key)(struct file_lock___89 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___89 *);
	int (*lm_grant)(struct file_lock___89 *, int);
	bool (*lm_break)(struct file_lock___89 *);
	int (*lm_change)(struct file_lock___89 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___89 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___88 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___88 *fa_next;
	struct file___89 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___88 {
	const char *name;
	int fs_flags;
	struct dentry___89 * (*mount)(struct file_system_type___88 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___89 *);
	struct module___77 *owner;
	struct file_system_type___88 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___88 {
	struct inode___90 * (*alloc_inode)(struct super_block___89 *);
	void (*destroy_inode)(struct inode___90 *);
	void (*dirty_inode)(struct inode___90 *, int);
	int (*write_inode)(struct inode___90 *, struct writeback_control___34 *);
	int (*drop_inode)(struct inode___90 *);
	void (*evict_inode)(struct inode___90 *);
	void (*put_super)(struct super_block___89 *);
	int (*sync_fs)(struct super_block___89 *, int);
	int (*freeze_super)(struct super_block___89 *);
	int (*freeze_fs)(struct super_block___89 *);
	int (*thaw_super)(struct super_block___89 *);
	int (*unfreeze_fs)(struct super_block___89 *);
	int (*statfs)(struct dentry___89 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___89 *, int *, char *);
	void (*umount_begin)(struct super_block___89 *);
	int (*show_options)(struct seq_file___82 *, struct dentry___89 *);
	int (*show_devname)(struct seq_file___82 *, struct dentry___89 *);
	int (*show_path)(struct seq_file___82 *, struct dentry___89 *);
	int (*show_stats)(struct seq_file___82 *, struct dentry___89 *);
	ssize_t (*quota_read)(struct super_block___89 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___89 *, int, const char *, size_t, loff_t);
	struct dquot___88 ** (*get_dquots)(struct inode___90 *);
	int (*bdev_try_to_free_page)(struct super_block___89 *, struct page___89 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___89 *, struct shrink_control___33 *);
	long int (*free_cached_objects)(struct super_block___89 *, struct shrink_control___33 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___58)(struct file___89 *, wait_queue_head_t *, struct poll_table_struct___59 *);

struct poll_table_struct___59 {
	poll_queue_proc___58 _qproc;
	__poll_t _key;
};

struct seq_operations___80;

struct seq_file___82 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___80 *op;
	int poll_event;
	const struct file___89 *file;
	void *private;
};

typedef void bio_end_io_t___36(struct bio___36 *);

struct bio_vec___36 {
	struct page___89 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___36;

struct bio_set___36;

struct bio___36 {
	struct bio___36 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___36 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___36 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___36 *bi_io_vec;
	struct bio_set___36 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___36 bi_inline_vecs[0];
};

struct kobj_attribute___83 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___83 *, struct kobj_attribute___83 *, char *);
	ssize_t (*store)(struct kobject___83 *, struct kobj_attribute___83 *, const char *, size_t);
};

typedef void compound_page_dtor___86(struct page___89 *);

struct inet_frags___9;

struct netns_frags___9 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___9 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_rules_ops___5;

struct sock___8;

struct fib_notifier_ops___5;

struct netns_ipv4___9 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___5 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___8 *fibnl;
	struct sock___8 **icmp_sk;
	struct sock___8 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___8 **tcp_sk;
	struct netns_frags___9 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___5 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___5 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___5 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct dst_entry___7;

struct net_device___14;

struct sk_buff___13;

struct neighbour___7;

struct dst_ops___16 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___16 *);
	struct dst_entry___7 * (*check)(struct dst_entry___7 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___7 *);
	unsigned int (*mtu)(const struct dst_entry___7 *);
	u32 * (*cow_metrics)(struct dst_entry___7 *, long unsigned int);
	void (*destroy)(struct dst_entry___7 *);
	void (*ifdown)(struct dst_entry___7 *, struct net_device___14 *, int);
	struct dst_entry___7 * (*negative_advice)(struct dst_entry___7 *);
	void (*link_failure)(struct sk_buff___13 *);
	void (*update_pmtu)(struct dst_entry___7 *, struct sock___8 *, struct sk_buff___13 *, u32);
	void (*redirect)(struct dst_entry___7 *, struct sock___8 *, struct sk_buff___13 *);
	int (*local_out)(struct net___18 *, struct sock___8 *, struct sk_buff___13 *);
	struct neighbour___7 * (*neigh_lookup)(const struct dst_entry___7 *, struct sk_buff___13 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___7 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___15 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___9 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___16 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___5 *fib6_rules_ops;
	struct sock___8 **icmp_sk;
	struct sock___8 *ndisc_sk;
	struct sock___8 *tcp_sk;
	struct sock___8 *igmp_sk;
	struct sock___8 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___5 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___5 *notifier_ops;
	struct fib_notifier_ops___5 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___5 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___8 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___9 {
	struct netns_frags___9 frags;
};

struct netns_xfrm___15 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___8 *nlsk;
	struct sock___8 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___16 xfrm4_dst_ops;
	struct dst_ops___16 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___8;

struct net___18 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___74 *user_ns;
	struct ucounts___74 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___7 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___8 *rtnl;
	struct sock___8 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___14 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___9 ipv4;
	struct netns_ipv6___15 ipv6;
	struct netns_sctp___5 sctp;
	struct netns_nf nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___9 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___8 *nfnl;
	struct sock___8 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___15 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___8 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___8 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cgroup_namespace___71 {
	refcount_t count;
	struct ns_common___7 ns;
	struct user_namespace___74 *user_ns;
	struct ucounts___74 *ucounts;
	struct css_set___71 *root_cset;
};

struct ucounts___74 {
	struct hlist_node node;
	struct user_namespace___74 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

enum {
	Audit_equal = 0,
	Audit_not_equal = 1,
	Audit_bitmask = 2,
	Audit_bittest = 3,
	Audit_lt = 4,
	Audit_gt = 5,
	Audit_le = 6,
	Audit_ge = 7,
	Audit_bad = 8,
};

struct audit_rule_data {
	__u32 flags;
	__u32 action;
	__u32 field_count;
	__u32 mask[64];
	__u32 fields[64];
	__u32 values[64];
	__u32 fieldflags[64];
	__u32 buflen;
	char buf[0];
};

struct audit_field;

struct audit_watch;

struct audit_tree;

struct audit_fsnotify_mark;

struct audit_krule {
	u32 pflags;
	u32 flags;
	u32 listnr;
	u32 action;
	u32 mask[64];
	u32 buflen;
	u32 field_count;
	char *filterkey;
	struct audit_field *fields;
	struct audit_field *arch_f;
	struct audit_field *inode_f;
	struct audit_watch *watch;
	struct audit_tree *tree;
	struct audit_fsnotify_mark *exe;
	struct list_head rlist;
	struct list_head list;
	u64 prio;
};

struct audit_field {
	u32 type;
	union {
		u32 val;
		kuid_t uid;
		kgid_t gid;
		struct {
			char *lsm_str;
			void *lsm_rule;
		};
	};
	u32 op;
};

struct msghdr___5 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___35 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___89 *msg_iocb;
};

struct kthread_work___71;

typedef void (*kthread_work_func_t___71)(struct kthread_work___71 *);

struct kthread_worker___71;

struct kthread_work___71 {
	struct list_head node;
	kthread_work_func_t___71 func;
	struct kthread_worker___71 *worker;
	int canceling;
};

struct kthread_worker___71 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___89 *task;
	struct kthread_work___71 *current_work;
};

struct kthread_delayed_work___71 {
	struct kthread_work___71 work;
	struct timer_list timer;
};

struct socket_wq___5 {
	wait_queue_head_t wait;
	struct fasync_struct___88 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___5;

struct socket___5 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___5 *wq;
	struct file___89 *file;
	struct sock___8 *sk;
	const struct proto_ops___5 *ops;
};

typedef struct {
	struct net___18 *net;
} possible_net_t___9;

struct proto___5;

struct sock_common___5 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___5 *skc_prot;
	possible_net_t___9 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___8 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff_head___10 {
	struct sk_buff___13 *next;
	struct sk_buff___13 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___5;

struct sock___8 {
	struct sock_common___5 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___10 sk_error_queue;
	struct sk_buff_head___10 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___13 *head;
		struct sk_buff___13 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___5 *sk_filter;
	union {
		struct socket_wq___5 *sk_wq;
		struct socket_wq___5 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___7 *sk_rx_dst;
	struct dst_entry___7 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___13 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___10 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___88 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___5 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___73 *sk_peer_pid;
	const struct cred___85 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___5 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___33 *sk_memcg;
	void (*sk_state_change)(struct sock___8 *);
	void (*sk_data_ready)(struct sock___8 *);
	void (*sk_write_space)(struct sock___8 *);
	void (*sk_error_report)(struct sock___8 *);
	int (*sk_backlog_rcv)(struct sock___8 *, struct sk_buff___13 *);
	struct sk_buff___13 * (*sk_validate_xmit_skb)(struct sock___8 *, struct net_device___14 *, struct sk_buff___13 *);
	void (*sk_destruct)(struct sock___8 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

typedef int (*sk_read_actor_t___5)(read_descriptor_t *, struct sk_buff___13 *, unsigned int, size_t);

struct proto_ops___5 {
	int family;
	struct module___77 *owner;
	int (*release)(struct socket___5 *);
	int (*bind)(struct socket___5 *, struct sockaddr *, int);
	int (*connect)(struct socket___5 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___5 *, struct socket___5 *);
	int (*accept)(struct socket___5 *, struct socket___5 *, int, bool);
	int (*getname)(struct socket___5 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___89 *, struct socket___5 *, struct poll_table_struct___59 *);
	int (*ioctl)(struct socket___5 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___5 *, int);
	int (*shutdown)(struct socket___5 *, int);
	int (*setsockopt)(struct socket___5 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___5 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___5 *, struct msghdr___5 *, size_t);
	int (*recvmsg)(struct socket___5 *, struct msghdr___5 *, size_t, int);
	int (*mmap)(struct file___89 *, struct socket___5 *, struct vm_area_struct___89 *);
	ssize_t (*sendpage)(struct socket___5 *, struct page___89 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___5 *, loff_t *, struct pipe_inode_info___17 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___8 *, int);
	int (*peek_len)(struct socket___5 *);
	int (*read_sock)(struct sock___8 *, read_descriptor_t *, sk_read_actor_t___5);
	int (*sendpage_locked)(struct sock___8 *, struct page___89 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___8 *, struct msghdr___5 *, size_t);
	int (*set_rcvlowat)(struct sock___8 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct nf_bridge_info___9;

struct sk_buff___13 {
	union {
		struct {
			struct sk_buff___13 *next;
			struct sk_buff___13 *prev;
			union {
				struct net_device___14 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___8 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___13 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___9 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct kernfs_root___85;

struct kernfs_elem_dir___85 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___85 *root;
};

struct kernfs_syscall_ops___85;

struct kernfs_root___85 {
	struct kernfs_node___85 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___85 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___85 {
	struct kernfs_node___85 *target_kn;
};

struct kernfs_ops___85;

struct kernfs_elem_attr___85 {
	const struct kernfs_ops___85 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___85 *notify_next;
};

struct kernfs_node___85 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___85 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___85 dir;
		struct kernfs_elem_symlink___85 symlink;
		struct kernfs_elem_attr___85 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___85;

struct kernfs_ops___85 {
	int (*open)(struct kernfs_open_file___85 *);
	void (*release)(struct kernfs_open_file___85 *);
	int (*seq_show)(struct seq_file___82 *, void *);
	void * (*seq_start)(struct seq_file___82 *, loff_t *);
	void * (*seq_next)(struct seq_file___82 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___82 *, void *);
	ssize_t (*read)(struct kernfs_open_file___85 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___85 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___85 *, struct vm_area_struct___89 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___85 *, struct poll_table_struct___59 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___85 {
	int (*remount_fs)(struct kernfs_root___85 *, int *, char *);
	int (*show_options)(struct seq_file___82 *, struct kernfs_root___85 *);
	int (*mkdir)(struct kernfs_node___85 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___85 *);
	int (*rename)(struct kernfs_node___85 *, struct kernfs_node___85 *, const char *);
	int (*show_path)(struct seq_file___82 *, struct kernfs_node___85 *, struct kernfs_root___85 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___85 {
	struct kernfs_node___85 *kn;
	struct file___89 *file;
	struct seq_file___82 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___86 *vm_ops;
};

struct kobj_ns_type_operations___5 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___8 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___80;

struct attribute_group___80 {
	const char *name;
	umode_t (*is_visible)(struct kobject___83 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___83 *, struct bin_attribute___80 *, int);
	struct attribute **attrs;
	struct bin_attribute___80 **bin_attrs;
};

struct bin_attribute___80 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___89 *, struct kobject___83 *, struct bin_attribute___80 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___89 *, struct kobject___83 *, struct bin_attribute___80 *, char *, loff_t, size_t);
	int (*mmap)(struct file___89 *, struct kobject___83 *, struct bin_attribute___80 *, struct vm_area_struct___89 *);
};

struct sysfs_ops___82 {
	ssize_t (*show)(struct kobject___83 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___83 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___82;

struct kset___82 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___83 kobj;
	const struct kset_uevent_ops___82 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___82 {
	void (*release)(struct kobject___83 *);
	const struct sysfs_ops___82 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___5 * (*child_ns_type)(struct kobject___83 *);
	const void * (*namespace)(struct kobject___83 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___82 {
	int (* const filter)(struct kset___82 *, struct kobject___83 *);
	const char * (* const name)(struct kset___82 *, struct kobject___83 *);
	int (* const uevent)(struct kset___82 *, struct kobject___83 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___81 {
	int (*prepare)(struct device___81 *);
	void (*complete)(struct device___81 *);
	int (*suspend)(struct device___81 *);
	int (*resume)(struct device___81 *);
	int (*freeze)(struct device___81 *);
	int (*thaw)(struct device___81 *);
	int (*poweroff)(struct device___81 *);
	int (*restore)(struct device___81 *);
	int (*suspend_late)(struct device___81 *);
	int (*resume_early)(struct device___81 *);
	int (*freeze_late)(struct device___81 *);
	int (*thaw_early)(struct device___81 *);
	int (*poweroff_late)(struct device___81 *);
	int (*restore_early)(struct device___81 *);
	int (*suspend_noirq)(struct device___81 *);
	int (*resume_noirq)(struct device___81 *);
	int (*freeze_noirq)(struct device___81 *);
	int (*thaw_noirq)(struct device___81 *);
	int (*poweroff_noirq)(struct device___81 *);
	int (*restore_noirq)(struct device___81 *);
	int (*runtime_suspend)(struct device___81 *);
	int (*runtime_resume)(struct device___81 *);
	int (*runtime_idle)(struct device___81 *);
};

struct dev_pm_domain___81 {
	struct dev_pm_ops___81 ops;
	void (*detach)(struct device___81 *, bool);
	int (*activate)(struct device___81 *);
	void (*sync)(struct device___81 *);
	void (*dismiss)(struct device___81 *);
};

struct bus_type___81 {
	const char *name;
	const char *dev_name;
	struct device___81 *dev_root;
	const struct attribute_group___80 **bus_groups;
	const struct attribute_group___80 **dev_groups;
	const struct attribute_group___80 **drv_groups;
	int (*match)(struct device___81 *, struct device_driver___81 *);
	int (*uevent)(struct device___81 *, struct kobj_uevent_env *);
	int (*probe)(struct device___81 *);
	int (*remove)(struct device___81 *);
	void (*shutdown)(struct device___81 *);
	int (*online)(struct device___81 *);
	int (*offline)(struct device___81 *);
	int (*suspend)(struct device___81 *, pm_message_t);
	int (*resume)(struct device___81 *);
	int (*num_vf)(struct device___81 *);
	int (*dma_configure)(struct device___81 *);
	const struct dev_pm_ops___81 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___81 {
	const char *name;
	struct bus_type___81 *bus;
	struct module___77 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___81 *);
	int (*remove)(struct device___81 *);
	void (*shutdown)(struct device___81 *);
	int (*suspend)(struct device___81 *, pm_message_t);
	int (*resume)(struct device___81 *);
	const struct attribute_group___80 **groups;
	const struct dev_pm_ops___81 *pm;
	void (*coredump)(struct device___81 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___81 {
	const char *name;
	const struct attribute_group___80 **groups;
	int (*uevent)(struct device___81 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___81 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___81 *);
	const struct dev_pm_ops___81 *pm;
};

struct class___81 {
	const char *name;
	struct module___77 *owner;
	const struct attribute_group___80 **class_groups;
	const struct attribute_group___80 **dev_groups;
	struct kobject___83 *dev_kobj;
	int (*dev_uevent)(struct device___81 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___81 *, umode_t *);
	void (*class_release)(struct class___81 *);
	void (*dev_release)(struct device___81 *);
	int (*shutdown_pre)(struct device___81 *);
	const struct kobj_ns_type_operations___5 *ns_type;
	const void * (*namespace)(struct device___81 *);
	const struct dev_pm_ops___81 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___22 {
	void * (*alloc)(struct device___81 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___81 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___81 *, struct vm_area_struct___89 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___81 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___81 *, struct page___89 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___81 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___81 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___81 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___81 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___81 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___81 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___81 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___81 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___81 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___81 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___81 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___81 *, u64);
	u64 (*get_required_mask)(struct device___81 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___59;

struct fwnode_handle___59 {
	struct fwnode_handle___59 *secondary;
	const struct fwnode_operations___59 *ops;
};

struct fwnode_reference_args___59;

struct fwnode_endpoint___59;

struct fwnode_operations___59 {
	struct fwnode_handle___59 * (*get)(struct fwnode_handle___59 *);
	void (*put)(struct fwnode_handle___59 *);
	bool (*device_is_available)(const struct fwnode_handle___59 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___59 *, const struct device___81 *);
	bool (*property_present)(const struct fwnode_handle___59 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___59 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___59 *, const char *, const char **, size_t);
	struct fwnode_handle___59 * (*get_parent)(const struct fwnode_handle___59 *);
	struct fwnode_handle___59 * (*get_next_child_node)(const struct fwnode_handle___59 *, struct fwnode_handle___59 *);
	struct fwnode_handle___59 * (*get_named_child_node)(const struct fwnode_handle___59 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___59 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___59 *);
	struct fwnode_handle___59 * (*graph_get_next_endpoint)(const struct fwnode_handle___59 *, struct fwnode_handle___59 *);
	struct fwnode_handle___59 * (*graph_get_remote_endpoint)(const struct fwnode_handle___59 *);
	struct fwnode_handle___59 * (*graph_get_port_parent)(struct fwnode_handle___59 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___59 *, struct fwnode_endpoint___59 *);
};

struct fwnode_endpoint___59 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___59 *local_fwnode;
};

struct fwnode_reference_args___59 {
	struct fwnode_handle___59 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___17;

struct pipe_buffer___17 {
	struct page___89 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___17 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___17 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___17 *, struct pipe_buffer___17 *);
	void (*release)(struct pipe_inode_info___17 *, struct pipe_buffer___17 *);
	int (*steal)(struct pipe_inode_info___17 *, struct pipe_buffer___17 *);
	union {
		bool (*get)(struct pipe_inode_info___17 *, struct pipe_buffer___17 *);
		struct {
			void (*get)(struct pipe_inode_info___17 *, struct pipe_buffer___17 *);
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
};

struct nf_bridge_info___9 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___9 = 0,
		BRNF_PROTO_8021Q___9 = 1,
		BRNF_PROTO_PPPOE___9 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___14 *physindev;
	struct net_device___14 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___9(struct sk_buff___13 **);

struct net_device_ops___9;

struct ethtool_ops___9;

struct l3mdev_ops___6;

struct xfrmdev_ops___9;

struct tlsdev_ops___9;

struct header_ops___9;

struct netdev_rx_queue___9;

struct mini_Qdisc___8;

struct netdev_queue___9;

struct Qdisc___8;

struct rtnl_link_ops___8;

struct dcbnl_rtnl_ops___9;

struct net_device___14 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___9 *netdev_ops;
	const struct ethtool_ops___9 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___6 *l3mdev_ops;
	const struct ndisc_ops___2 *ndisc_ops;
	const struct xfrmdev_ops___9 *xfrmdev_ops;
	const struct tlsdev_ops___9 *tlsdev_ops;
	const struct header_ops___9 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___82 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___2 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___9 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___8 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___9 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___8 *miniq_ingress;
	struct netdev_queue___9 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___9 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___8 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___8 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___9 = 0,
		NETREG_REGISTERED___9 = 1,
		NETREG_UNREGISTERING___9 = 2,
		NETREG_UNREGISTERED___9 = 3,
		NETREG_RELEASED___9 = 4,
		NETREG_DUMMY___9 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___9 = 0,
		RTNL_LINK_INITIALIZING___9 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___14 *);
	struct netpoll_info *npinfo;
	possible_net_t___9 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___81 dev;
	const struct attribute_group___80 *sysfs_groups[4];
	const struct attribute_group___80 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___8 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___9 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide35;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct netlink_skb_parms___2 {
	struct scm_creds creds;
	__u32 portid;
	__u32 dst_group;
	__u32 flags;
	struct sock___8 *sk;
	bool nsid_is_set;
	int nsid;
};

struct netlink_callback___9 {
	struct sk_buff___13 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___9 *);
	int (*dump)(struct sk_buff___13 *, struct netlink_callback___9 *);
	int (*done)(struct netlink_callback___9 *);
	void *data;
	struct module___77 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct inet_frag_queue___9;

struct inet_frags___9 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___9 *, const void *);
	void (*destructor)(struct inet_frag_queue___9 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___9 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___13 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___13 *fragments_tail;
	struct sk_buff___13 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___9 *net;
	struct callback_head rcu;
};

struct fib_rule___5;

struct fib_lookup_arg___5;

struct fib_rules_ops___5 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___5 *, struct flowi *, int, struct fib_lookup_arg___5 *);
	bool (*suppress)(struct fib_rule___5 *, struct fib_lookup_arg___5 *);
	int (*match)(struct fib_rule___5 *, struct flowi *, int);
	int (*configure)(struct fib_rule___5 *, struct sk_buff___13 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___5 *);
	int (*compare)(struct fib_rule___5 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___5 *, struct sk_buff___13 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___5 *);
	void (*flush_cache)(struct fib_rules_ops___5 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___77 *owner;
	struct net___18 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___5 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___18 *);
	int (*fib_dump)(struct net___18 *, struct notifier_block *);
	struct module___77 *owner;
	struct callback_head rcu;
};

struct dst_entry___7 {
	struct net_device___14 *dev;
	struct dst_ops___16 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___13 *);
	int (*output)(struct net___18 *, struct sock___8 *, struct sk_buff___13 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___6;

struct neigh_parms___7;

struct neigh_ops___6;

struct neighbour___7 {
	struct neighbour___7 *next;
	struct neigh_table___6 *tbl;
	struct neigh_parms___7 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___10 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___7 *, struct sk_buff___13 *);
	const struct neigh_ops___6 *ops;
	struct callback_head rcu;
	struct net_device___14 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct bpf_prog_aux___8;

struct bpf_prog___8 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___8 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

struct seq_operations___80 {
	void * (*start)(struct seq_file___82 *, loff_t *);
	void (*stop)(struct seq_file___82 *, void *);
	void * (*next)(struct seq_file___82 *, void *, loff_t *);
	int (*show)(struct seq_file___82 *, void *);
};

struct pernet_operations___9 {
	struct list_head list;
	int (*init)(struct net___18 *);
	void (*exit)(struct net___18 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct ethtool_ops___9 {
	int (*get_settings)(struct net_device___14 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___14 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___14 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___14 *);
	void (*get_regs)(struct net_device___14 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___14 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___14 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___14 *);
	void (*set_msglevel)(struct net_device___14 *, u32);
	int (*nway_reset)(struct net_device___14 *);
	u32 (*get_link)(struct net_device___14 *);
	int (*get_eeprom_len)(struct net_device___14 *);
	int (*get_eeprom)(struct net_device___14 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___14 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___14 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___14 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___14 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___14 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___14 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___14 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___14 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___14 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___14 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___14 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___14 *);
	void (*complete)(struct net_device___14 *);
	u32 (*get_priv_flags)(struct net_device___14 *);
	int (*set_priv_flags)(struct net_device___14 *, u32);
	int (*get_sset_count)(struct net_device___14 *, int);
	int (*get_rxnfc)(struct net_device___14 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___14 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___14 *, struct ethtool_flash *);
	int (*reset)(struct net_device___14 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___14 *);
	u32 (*get_rxfh_indir_size)(struct net_device___14 *);
	int (*get_rxfh)(struct net_device___14 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___14 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___14 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___14 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___14 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___14 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___14 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___14 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___14 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___14 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___14 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___14 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___14 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___14 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___14 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___14 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___14 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___14 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___14 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___14 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___14 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___14 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	int (*get_fecparam)(struct net_device___14 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___14 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___14 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___14 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___14 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct dcbnl_rtnl_ops___9 {
	int (*ieee_getets)(struct net_device___14 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___14 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___14 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___14 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___14 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___14 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___14 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___14 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___14 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___14 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___14 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___14 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___14 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___14 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___14 *);
	u8 (*setstate)(struct net_device___14 *, u8);
	void (*getpermhwaddr)(struct net_device___14 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___14 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___14 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___14 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___14 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___14 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___14 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___14 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___14 *, int, u8 *);
	void (*setpfccfg)(struct net_device___14 *, int, u8);
	void (*getpfccfg)(struct net_device___14 *, int, u8 *);
	u8 (*setall)(struct net_device___14 *);
	u8 (*getcap)(struct net_device___14 *, int, u8 *);
	int (*getnumtcs)(struct net_device___14 *, int, u8 *);
	int (*setnumtcs)(struct net_device___14 *, int, u8);
	u8 (*getpfcstate)(struct net_device___14 *);
	void (*setpfcstate)(struct net_device___14 *, u8);
	void (*getbcncfg)(struct net_device___14 *, int, u32 *);
	void (*setbcncfg)(struct net_device___14 *, int, u32);
	void (*getbcnrp)(struct net_device___14 *, int, u8 *);
	void (*setbcnrp)(struct net_device___14 *, int, u8);
	int (*setapp)(struct net_device___14 *, u8, u16, u8);
	int (*getapp)(struct net_device___14 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___14 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___14 *, int, u8);
	u8 (*getdcbx)(struct net_device___14 *);
	u8 (*setdcbx)(struct net_device___14 *, u8);
	int (*peer_getappinfo)(struct net_device___14 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___14 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___14 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___14 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___14 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___14 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct bpf_map___71;

struct bpf_map_ops___71 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___71 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___71 *, struct file___89 *);
	void (*map_free)(struct bpf_map___71 *);
	int (*map_get_next_key)(struct bpf_map___71 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___71 *);
	void * (*map_lookup_elem)(struct bpf_map___71 *, void *);
	int (*map_update_elem)(struct bpf_map___71 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___71 *, void *);
	int (*map_push_elem)(struct bpf_map___71 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___71 *, void *);
	int (*map_peek_elem)(struct bpf_map___71 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___71 *, struct file___89 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___71 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___71 *, void *, struct seq_file___82 *);
	int (*map_check_btf)(const struct bpf_map___71 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___71 {
	const struct bpf_map_ops___71 *ops;
	struct bpf_map___71 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___85 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___9;

struct bpf_map_dev_ops___9 {
	int (*map_get_next_key)(struct bpf_offloaded_map___9 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___9 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___9 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___9 *, void *);
};

struct bpf_offloaded_map___9 {
	struct bpf_map___71 map;
	struct net_device___14 *netdev;
	const struct bpf_map_dev_ops___9 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___8 {
	int (*test_run)(struct bpf_prog___8 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___8 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___8 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___8 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___8 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___8 *, u32 *);
};

struct bpf_prog_offload_ops___8 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___8 *);
	int (*translate)(struct bpf_prog___8 *);
	void (*destroy)(struct bpf_prog___8 *);
};

struct bpf_prog_offload___8 {
	struct bpf_prog___8 *prog;
	struct net_device___14 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___8 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___8 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___8 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___8 *ops;
	struct bpf_map___71 **used_maps;
	struct bpf_prog___8 *prog;
	struct user_struct___85 *user;
	u64 load_time;
	struct bpf_map___71 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___8 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___8 {
	struct bpf_prog___8 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___8 {
	struct callback_head rcu;
	struct bpf_prog_array_item___8 items[0];
};

struct cgroup_bpf___8 {
	struct bpf_prog_array___8 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___8 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct psi_group___71 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___71 *poll_kworker;
	struct kthread_delayed_work___71 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___71;

struct cgroup_rstat_cpu___71;

struct cgroup___71 {
	struct cgroup_subsys_state___71 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___85 *kn;
	struct cgroup_file___71 procs_file;
	struct cgroup_file___71 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___71 *subsys[13];
	struct cgroup_root___71 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___71 *dom_cgrp;
	struct cgroup_rstat_cpu___71 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___8 bpf;
	atomic_t congestion_count;
	struct cgroup___71 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___71 psi;
	int ancestor_ids[0];
};

struct cftype___71;

struct cgroup_subsys___71 {
	struct cgroup_subsys_state___71 * (*css_alloc)(struct cgroup_subsys_state___71 *);
	int (*css_online)(struct cgroup_subsys_state___71 *);
	void (*css_offline)(struct cgroup_subsys_state___71 *);
	void (*css_released)(struct cgroup_subsys_state___71 *);
	void (*css_free)(struct cgroup_subsys_state___71 *);
	void (*css_reset)(struct cgroup_subsys_state___71 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___71 *, int);
	int (*css_extra_stat_show)(struct seq_file___82 *, struct cgroup_subsys_state___71 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___89 *);
	void (*cancel_fork)(struct task_struct___89 *);
	void (*fork)(struct task_struct___89 *);
	void (*exit)(struct task_struct___89 *);
	void (*free)(struct task_struct___89 *);
	void (*bind)(struct cgroup_subsys_state___71 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___71 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___71 *dfl_cftypes;
	struct cftype___71 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___71 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___71 *updated_children;
	struct cgroup___71 *updated_next;
};

struct cgroup_root___71 {
	struct kernfs_root___85 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___71 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___71 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___71 *ss;
	struct list_head node;
	struct kernfs_ops___85 *kf_ops;
	int (*open)(struct kernfs_open_file___85 *);
	void (*release)(struct kernfs_open_file___85 *);
	u64 (*read_u64)(struct cgroup_subsys_state___71 *, struct cftype___71 *);
	s64 (*read_s64)(struct cgroup_subsys_state___71 *, struct cftype___71 *);
	int (*seq_show)(struct seq_file___82 *, void *);
	void * (*seq_start)(struct seq_file___82 *, loff_t *);
	void * (*seq_next)(struct seq_file___82 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___82 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___71 *, struct cftype___71 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___71 *, struct cftype___71 *, s64);
	ssize_t (*write)(struct kernfs_open_file___85 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___85 *, struct poll_table_struct___59 *);
};

struct xdp_rxq_info___9 {
	struct net_device___14 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___9 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___14 *dev_rx;
};

struct header_ops___9 {
	int (*create)(struct sk_buff___13 *, struct net_device___14 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___13 *, unsigned char *);
	int (*cache)(const struct neighbour___7 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___14 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___9 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___9 *, int);
	int poll_owner;
	struct net_device___14 *dev;
	struct sk_buff___13 *gro_list;
	struct sk_buff___13 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___9 {
	struct net_device___14 *dev;
	struct Qdisc___8 *qdisc;
	struct Qdisc___8 *qdisc_sleeping;
	struct kobject___83 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___14 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___8 {
	struct sk_buff___13 *head;
	struct sk_buff___13 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___8;

struct Qdisc___8 {
	int (*enqueue)(struct sk_buff___13 *, struct Qdisc___8 *, struct sk_buff___13 **);
	struct sk_buff___13 * (*dequeue)(struct Qdisc___8 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___8 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___9 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___10 gso_skb;
	struct qdisc_skb_head___8 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___8 *next_sched;
	struct sk_buff_head___10 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___9 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___83 kobj;
	struct net_device___14 *dev;
	long: 64;
	struct xdp_rxq_info___9 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___9)(struct net_device___14 *, struct sk_buff___13 *, struct net_device___14 *);

struct netdev_bpf___9 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___8 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___8 *prog;
			const struct bpf_prog_offload_ops___8 *ops;
		} verifier;
		struct {
			struct bpf_prog___8 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___9 *offmap;
		};
		struct {
			struct xdp_umem *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___9 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___13 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___9 {
	int (*tls_dev_add)(struct net_device___14 *, struct sock___8 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___14 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___14 *, struct sock___8 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___9 {
	int (*ndo_init)(struct net_device___14 *);
	void (*ndo_uninit)(struct net_device___14 *);
	int (*ndo_open)(struct net_device___14 *);
	int (*ndo_stop)(struct net_device___14 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___13 *, struct net_device___14 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___13 *, struct net_device___14 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___14 *, struct sk_buff___13 *, struct net_device___14 *, select_queue_fallback_t___9);
	void (*ndo_change_rx_flags)(struct net_device___14 *, int);
	void (*ndo_set_rx_mode)(struct net_device___14 *);
	int (*ndo_set_mac_address)(struct net_device___14 *, void *);
	int (*ndo_validate_addr)(struct net_device___14 *);
	int (*ndo_do_ioctl)(struct net_device___14 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___14 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___14 *, int);
	int (*ndo_neigh_setup)(struct net_device___14 *, struct neigh_parms___7 *);
	void (*ndo_tx_timeout)(struct net_device___14 *);
	void (*ndo_get_stats64)(struct net_device___14 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___14 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___14 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___14 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___14 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___14 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___14 *);
	int (*ndo_netpoll_setup)(struct net_device___14 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___14 *);
	int (*ndo_set_vf_mac)(struct net_device___14 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___14 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___14 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___14 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___14 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___14 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___14 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___14 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___14 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___14 *, int, struct sk_buff___13 *);
	int (*ndo_set_vf_guid)(struct net_device___14 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___14 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___14 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___14 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___14 *, const struct sk_buff___13 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___14 *, struct net_device___14 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___14 *, struct net_device___14 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___14 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___14 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___14 *, struct neighbour___7 *);
	void (*ndo_neigh_destroy)(struct net_device___14 *, struct neighbour___7 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___14 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___14 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___14 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___13 *, struct netlink_callback___9 *, struct net_device___14 *, struct net_device___14 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___14 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___14 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___13 *, u32, u32, struct net_device___14 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___14 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___14 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___14 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___14 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___14 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___14 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___14 *, struct net_device___14 *);
	void (*ndo_dfwd_del_station)(struct net_device___14 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___14 *);
	int (*ndo_set_tx_maxrate)(struct net_device___14 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___14 *);
	int (*ndo_change_proto_down)(struct net_device___14 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___14 *, struct sk_buff___13 *);
	void (*ndo_set_rx_headroom)(struct net_device___14 *, int);
	int (*ndo_bpf)(struct net_device___14 *, struct netdev_bpf___9 *);
	int (*ndo_xdp_xmit)(struct net_device___14 *, int, struct xdp_frame___9 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___14 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___14 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___7 {
	possible_net_t___9 net;
	struct net_device___14 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___7 *);
	void (*neigh_cleanup)(struct neighbour___7 *);
	struct neigh_table___6 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___6 {
	u32 (*l3mdev_fib_table)(const struct net_device___14 *);
	struct sk_buff___13 * (*l3mdev_l3_rcv)(struct net_device___14 *, struct sk_buff___13 *, u16);
	struct sk_buff___13 * (*l3mdev_l3_out)(struct net_device___14 *, struct sock___8 *, struct sk_buff___13 *, u16);
	struct dst_entry___7 * (*l3mdev_link_scope_lookup)(const struct net_device___14 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct tcf_proto___8;

struct mini_Qdisc___8 {
	struct tcf_proto___8 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___8 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___14 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___18 *, struct net_device___14 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___14 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___14 *, struct list_head *);
	size_t (*get_size)(const struct net_device___14 *);
	int (*fill_info)(struct sk_buff___13 *, const struct net_device___14 *);
	size_t (*get_xstats_size)(const struct net_device___14 *);
	int (*fill_xstats)(struct sk_buff___13 *, const struct net_device___14 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___14 *, struct net_device___14 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___14 *, const struct net_device___14 *);
	int (*fill_slave_info)(struct sk_buff___13 *, const struct net_device___14 *, const struct net_device___14 *);
	struct net___18 * (*get_link_net)(const struct net_device___14 *);
	size_t (*get_linkxstats_size)(const struct net_device___14 *, int);
	int (*fill_linkxstats)(struct sk_buff___13 *, const struct net_device___14 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___9 {
	struct list_head poll_list;
	struct sk_buff_head___10 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___9 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___8 *output_queue;
	struct Qdisc___8 **output_queue_tailp;
	struct sk_buff___13 *completion_queue;
	struct sk_buff_head___10 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___9 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___10 input_pkt_queue;
	struct napi_struct___9 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bdi_writeback_congested___36 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___36 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___36 {
	struct bio___36 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___36 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___36 bip_inline_vecs[0];
};

struct bio_set___36 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___36 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___33 {
	struct mem_cgroup___33 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___33 {
	struct lruvec___88 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___33 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___33 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct kernel_param_ops___74 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___74 *);
	int (*get)(char *, const struct kernel_param___74 *);
	void (*free)(void *);
};

struct kparam_array___74;

struct kernel_param___74 {
	const char *name;
	struct module___77 *mod;
	const struct kernel_param_ops___74 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___74 *arr;
	};
};

struct kparam_array___74 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___74 *ops;
	void *elem;
};

struct module_attribute___74 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___74 *, struct module_kobject___74 *, char *);
	ssize_t (*store)(struct module_attribute___74 *, struct module_kobject___74 *, const char *, size_t);
	void (*setup)(struct module___77 *, const char *);
	int (*test)(struct module___77 *);
	void (*free)(struct module___77 *);
};

struct gnet_dump___8 {
	spinlock_t *lock;
	struct sk_buff___13 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___8;

struct Qdisc_ops___8 {
	struct Qdisc_ops___8 *next;
	const struct Qdisc_class_ops___8 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___13 *, struct Qdisc___8 *, struct sk_buff___13 **);
	struct sk_buff___13 * (*dequeue)(struct Qdisc___8 *);
	struct sk_buff___13 * (*peek)(struct Qdisc___8 *);
	int (*init)(struct Qdisc___8 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___8 *);
	void (*destroy)(struct Qdisc___8 *);
	int (*change)(struct Qdisc___8 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___8 *);
	int (*change_tx_queue_len)(struct Qdisc___8 *, unsigned int);
	int (*dump)(struct Qdisc___8 *, struct sk_buff___13 *);
	int (*dump_stats)(struct Qdisc___8 *, struct gnet_dump___8 *);
	void (*ingress_block_set)(struct Qdisc___8 *, u32);
	void (*egress_block_set)(struct Qdisc___8 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___8 *);
	u32 (*egress_block_get)(struct Qdisc___8 *);
	struct module___77 *owner;
};

struct tcf_block___8;

struct Qdisc_class_ops___8 {
	unsigned int flags;
	struct netdev_queue___9 * (*select_queue)(struct Qdisc___8 *, struct tcmsg *);
	int (*graft)(struct Qdisc___8 *, long unsigned int, struct Qdisc___8 *, struct Qdisc___8 **, struct netlink_ext_ack *);
	struct Qdisc___8 * (*leaf)(struct Qdisc___8 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___8 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___8 *, u32);
	int (*change)(struct Qdisc___8 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___8 *, long unsigned int);
	void (*walk)(struct Qdisc___8 *, struct qdisc_walker *);
	struct tcf_block___8 * (*tcf_block)(struct Qdisc___8 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___8 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___8 *, long unsigned int);
	int (*dump)(struct Qdisc___8 *, long unsigned int, struct sk_buff___13 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___8 *, long unsigned int, struct gnet_dump___8 *);
};

struct tcf_chain___8;

struct tcf_block___8 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___18 *net;
	struct Qdisc___8 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___8 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___8;

struct tcf_proto_ops___8;

struct tcf_proto___8 {
	struct tcf_proto___8 *next;
	void *root;
	int (*classify)(struct sk_buff___13 *, const struct tcf_proto___8 *, struct tcf_result___8 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___8 *ops;
	struct tcf_chain___8 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___8 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___8 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___8 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___13 *, const struct tcf_proto___8 *, struct tcf_result___8 *);
	int (*init)(struct tcf_proto___8 *);
	void (*destroy)(struct tcf_proto___8 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___8 *, u32);
	void (*put)(struct tcf_proto___8 *, void *);
	int (*change)(struct net___18 *, struct sk_buff___13 *, struct tcf_proto___8 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___8 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___8 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___8 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___18 *, struct tcf_chain___8 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___18 *, struct tcf_proto___8 *, void *, struct sk_buff___13 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___13 *, struct net___18 *, void *);
	struct module___77 *owner;
	int flags;
};

struct tcf_chain___8 {
	struct mutex filter_chain_lock;
	struct tcf_proto___8 *filter_chain;
	struct list_head list;
	struct tcf_block___8 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___8 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___5 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___8 *prog;
};

struct bpf_redirect_info___8 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___71 *map;
	struct bpf_map___71 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___5;

struct neigh_hash_table___5;

struct neigh_table___6 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___14 *, __u32 *);
	bool (*key_eq)(const struct neighbour___7 *, const void *);
	int (*constructor)(struct neighbour___7 *);
	int (*pconstructor)(struct pneigh_entry___5 *);
	void (*pdestructor)(struct pneigh_entry___5 *);
	void (*proxy_redo)(struct sk_buff___13 *);
	char *id;
	struct neigh_parms___7 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___10 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___5 *nht;
	struct pneigh_entry___5 **phash_buckets;
};

struct neigh_ops___6 {
	int family;
	void (*solicit)(struct neighbour___7 *, struct sk_buff___13 *);
	void (*error_report)(struct neighbour___7 *, struct sk_buff___13 *);
	int (*output)(struct neighbour___7 *, struct sk_buff___13 *);
	int (*connected_output)(struct neighbour___7 *, struct sk_buff___13 *);
};

struct pneigh_entry___5 {
	struct pneigh_entry___5 *next;
	possible_net_t___9 net;
	struct net_device___14 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___5 {
	struct neighbour___7 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___5 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___5 *ctarget;
	struct net___18 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___5 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___5 *rule;
	u32 table;
	int flags;
};

struct proto___5 {
	void (*close)(struct sock___8 *, long int);
	int (*pre_connect)(struct sock___8 *, struct sockaddr *, int);
	int (*connect)(struct sock___8 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___8 *, int);
	struct sock___8 * (*accept)(struct sock___8 *, int, int *, bool);
	int (*ioctl)(struct sock___8 *, int, long unsigned int);
	int (*init)(struct sock___8 *);
	void (*destroy)(struct sock___8 *);
	void (*shutdown)(struct sock___8 *, int);
	int (*setsockopt)(struct sock___8 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___8 *, int, int, char *, int *);
	void (*keepalive)(struct sock___8 *, int);
	int (*sendmsg)(struct sock___8 *, struct msghdr___5 *, size_t);
	int (*recvmsg)(struct sock___8 *, struct msghdr___5 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___8 *, struct page___89 *, int, size_t, int);
	int (*bind)(struct sock___8 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___8 *, struct sk_buff___13 *);
	void (*release_cb)(struct sock___8 *);
	int (*hash)(struct sock___8 *);
	void (*unhash)(struct sock___8 *);
	void (*rehash)(struct sock___8 *);
	int (*get_port)(struct sock___8 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___8 *);
	bool (*stream_memory_read)(const struct sock___8 *);
	void (*enter_memory_pressure)(struct sock___8 *);
	void (*leave_memory_pressure)(struct sock___8 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___3 *rsk_prot;
	struct timewait_sock_ops___3 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___77 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___8 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct tty_operations___11 {
	struct tty_struct___11 * (*lookup)(struct tty_driver___11 *, struct file___89 *, int);
	int (*install)(struct tty_driver___11 *, struct tty_struct___11 *);
	void (*remove)(struct tty_driver___11 *, struct tty_struct___11 *);
	int (*open)(struct tty_struct___11 *, struct file___89 *);
	void (*close)(struct tty_struct___11 *, struct file___89 *);
	void (*shutdown)(struct tty_struct___11 *);
	void (*cleanup)(struct tty_struct___11 *);
	int (*write)(struct tty_struct___11 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___11 *, unsigned char);
	void (*flush_chars)(struct tty_struct___11 *);
	int (*write_room)(struct tty_struct___11 *);
	int (*chars_in_buffer)(struct tty_struct___11 *);
	int (*ioctl)(struct tty_struct___11 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___11 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___11 *, struct ktermios *);
	void (*throttle)(struct tty_struct___11 *);
	void (*unthrottle)(struct tty_struct___11 *);
	void (*stop)(struct tty_struct___11 *);
	void (*start)(struct tty_struct___11 *);
	void (*hangup)(struct tty_struct___11 *);
	int (*break_ctl)(struct tty_struct___11 *, int);
	void (*flush_buffer)(struct tty_struct___11 *);
	void (*set_ldisc)(struct tty_struct___11 *);
	void (*wait_until_sent)(struct tty_struct___11 *, int);
	void (*send_xchar)(struct tty_struct___11 *, char);
	int (*tiocmget)(struct tty_struct___11 *);
	int (*tiocmset)(struct tty_struct___11 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___11 *, struct winsize *);
	int (*set_termiox)(struct tty_struct___11 *, struct termiox *);
	int (*get_icount)(struct tty_struct___11 *, struct serial_icounter_struct *);
	void (*show_fdinfo)(struct tty_struct___11 *, struct seq_file___82 *);
	int (*poll_init)(struct tty_driver___11 *, int, char *);
	int (*poll_get_char)(struct tty_driver___11 *, int);
	void (*poll_put_char)(struct tty_driver___11 *, int, char);
	int (*proc_show)(struct seq_file___82 *, void *);
};

struct tty_driver___11 {
	int magic;
	struct kref kref;
	struct cdev___25 **cdevs;
	struct module___77 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___11 *other;
	struct tty_struct___11 **ttys;
	struct tty_port___11 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___11 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___11;

struct tty_port_client_operations___11;

struct tty_port___11 {
	struct tty_bufhead buf;
	struct tty_struct___11 *tty;
	struct tty_struct___11 *itty;
	const struct tty_port_operations___11 *ops;
	const struct tty_port_client_operations___11 *client_ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	unsigned char low_latency: 1;
	struct mutex mutex;
	struct mutex buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
	void *client_data;
};

struct tty_ldisc_ops___11 {
	int magic;
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___11 *);
	void (*close)(struct tty_struct___11 *);
	void (*flush_buffer)(struct tty_struct___11 *);
	ssize_t (*read)(struct tty_struct___11 *, struct file___89 *, unsigned char *, size_t);
	ssize_t (*write)(struct tty_struct___11 *, struct file___89 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___11 *, struct file___89 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___11 *, struct file___89 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___11 *, struct ktermios *);
	__poll_t (*poll)(struct tty_struct___11 *, struct file___89 *, struct poll_table_struct___59 *);
	int (*hangup)(struct tty_struct___11 *);
	void (*receive_buf)(struct tty_struct___11 *, const unsigned char *, char *, int);
	void (*write_wakeup)(struct tty_struct___11 *);
	void (*dcd_change)(struct tty_struct___11 *, unsigned int);
	int (*receive_buf2)(struct tty_struct___11 *, const unsigned char *, char *, int);
	struct module___77 *owner;
	int refcount;
};

struct tty_ldisc___11 {
	struct tty_ldisc_ops___11 *ops;
	struct tty_struct___11 *tty;
};

struct tty_port_operations___11 {
	int (*carrier_raised)(struct tty_port___11 *);
	void (*dtr_rts)(struct tty_port___11 *, int);
	void (*shutdown)(struct tty_port___11 *);
	int (*activate)(struct tty_port___11 *, struct tty_struct___11 *);
	void (*destruct)(struct tty_port___11 *);
};

struct tty_port_client_operations___11 {
	int (*receive_buf)(struct tty_port___11 *, const unsigned char *, const unsigned char *, size_t);
	void (*write_wakeup)(struct tty_port___11 *);
};

struct audit_entry {
	struct list_head list;
	struct callback_head rcu;
	struct audit_krule rule;
};

struct audit_netlink_list___2 {
	__u32 portid;
	struct net___18 *net;
	struct sk_buff_head___10 q;
};

struct audit_buffer___2;

typedef int __kernel_key_t;

typedef __kernel_key_t key_t;

struct module___78;

struct file___90;

struct kiocb___90;

struct iov_iter___36;

struct poll_table_struct___60;

struct vm_area_struct___90;

struct inode___91;

struct file_lock___90;

struct page___90;

struct pipe_inode_info___18;

struct seq_file___83;

struct file_operations___90 {
	struct module___78 *owner;
	loff_t (*llseek)(struct file___90 *, loff_t, int);
	ssize_t (*read)(struct file___90 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___90 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___90 *, struct iov_iter___36 *);
	ssize_t (*write_iter)(struct kiocb___90 *, struct iov_iter___36 *);
	int (*iopoll)(struct kiocb___90 *, bool);
	int (*iterate)(struct file___90 *, struct dir_context *);
	int (*iterate_shared)(struct file___90 *, struct dir_context *);
	__poll_t (*poll)(struct file___90 *, struct poll_table_struct___60 *);
	long int (*unlocked_ioctl)(struct file___90 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___90 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___90 *, struct vm_area_struct___90 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___91 *, struct file___90 *);
	int (*flush)(struct file___90 *, fl_owner_t);
	int (*release)(struct inode___91 *, struct file___90 *);
	int (*fsync)(struct file___90 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___90 *, int);
	int (*lock)(struct file___90 *, int, struct file_lock___90 *);
	ssize_t (*sendpage)(struct file___90 *, struct page___90 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___90 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___90 *, int, struct file_lock___90 *);
	ssize_t (*splice_write)(struct pipe_inode_info___18 *, struct file___90 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___90 *, loff_t *, struct pipe_inode_info___18 *, size_t, unsigned int);
	int (*setlease)(struct file___90 *, long int, struct file_lock___90 **, void **);
	long int (*fallocate)(struct file___90 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___83 *, struct file___90 *);
	ssize_t (*copy_file_range)(struct file___90 *, loff_t, struct file___90 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___90 *, loff_t, struct file___90 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___90 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___89 {
	u64 seqnum;
	struct vm_area_struct___90 *vmas[4];
};

struct page_frag___89 {
	struct page___90 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___56;

struct debug_info___56 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___56 *hbp_break[16];
	struct perf_event___56 *hbp_watch[16];
};

struct thread_struct___56 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___56 debug;
	long: 64;
};

struct mm_struct___89;

struct pid___74;

struct cred___86;

struct fs_struct___6;

struct nsproxy___83;

struct signal_struct___80;

struct audit_context___4;

struct css_set___72;

struct perf_event_context___56;

struct vm_struct___64;

struct task_struct___90 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___90 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___89 *mm;
	struct mm_struct___89 *active_mm;
	struct vmacache___89 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___90 *real_parent;
	struct task_struct___90 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___90 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___74 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___74 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___74 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___86 *ptracer_cred;
	const struct cred___86 *real_cred;
	const struct cred___86 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct___6 *fs;
	struct files_struct *files;
	struct nsproxy___83 *nsproxy;
	struct signal_struct___80 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context___4 *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___90 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___15 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___72 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___56 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___18 *splice_pipe;
	struct page_frag___89 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___90 *oom_reaper_list;
	struct vm_struct___64 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___56 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___56 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___90 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___56)(struct perf_event___56 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___56;

struct fasync_struct___89;

struct pid_namespace___74;

struct trace_event_call___51;

struct perf_cgroup___56;

struct perf_event___56 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___56 *group_leader;
	struct pmu___56 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___56 hw;
	struct perf_event_context___56 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___56 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___90 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___89 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___56 *);
	struct callback_head callback_head;
	struct pid_namespace___74 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___56 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___56 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___51 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___56 *cgrp;
	struct list_head sb_list;
};

struct dentry_operations___89;

struct super_block___90;

struct dentry___90 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___90 *d_parent;
	struct qstr d_name;
	struct inode___91 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___89 *d_op;
	struct super_block___90 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct rw_semaphore___90 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___90 *owner;
};

struct address_space_operations___89;

struct address_space___89 {
	struct inode___91 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___90 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___89 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___89;

struct block_device___90;

struct cdev___26;

struct inode___91 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___89 *i_op;
	struct super_block___90 *i_sb;
	struct address_space___89 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___90 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___90 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___89 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___18 *i_pipe;
		struct block_device___90 *i_bdev;
		struct cdev___26 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vfsmount___14;

struct path___89;

struct dentry_operations___89 {
	int (*d_revalidate)(struct dentry___90 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___90 *, unsigned int);
	int (*d_hash)(const struct dentry___90 *, struct qstr *);
	int (*d_compare)(const struct dentry___90 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___90 *);
	int (*d_init)(struct dentry___90 *);
	void (*d_release)(struct dentry___90 *);
	void (*d_prune)(struct dentry___90 *);
	void (*d_iput)(struct dentry___90 *, struct inode___91 *);
	char * (*d_dname)(struct dentry___90 *, char *, int);
	struct vfsmount___14 * (*d_automount)(struct path___89 *);
	int (*d_manage)(const struct path___89 *, bool);
	struct dentry___90 * (*d_real)(struct dentry___90 *, const struct inode___91 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___89;

struct mem_dqinfo___89 {
	struct quota_format_type___89 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___89;

struct quota_info___89 {
	unsigned int flags;
	struct rw_semaphore___90 dqio_sem;
	struct inode___91 *files[3];
	struct mem_dqinfo___89 info[3];
	const struct quota_format_ops___89 *ops[3];
};

struct rcuwait___89 {
	struct task_struct___90 *task;
};

struct percpu_rw_semaphore___89 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___90 rw_sem;
	struct rcuwait___89 writer;
	int readers_block;
};

struct sb_writers___89 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___89 rw_sem[3];
};

struct file_system_type___89;

struct super_operations___89;

struct dquot_operations___89;

struct quotactl_ops___89;

struct user_namespace___75;

struct super_block___90 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___89 *s_type;
	const struct super_operations___89 *s_op;
	const struct dquot_operations___89 *dq_op;
	const struct quotactl_ops___89 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___90 *s_root;
	struct rw_semaphore___90 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___90 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___89 s_dquot;
	struct sb_writers___89 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___89 *s_d_op;
	int cleancache_poolid;
	struct shrinker___33 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___75 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___14 {
	struct dentry___90 *mnt_root;
	struct super_block___90 *mnt_sb;
	int mnt_flags;
};

struct path___89 {
	struct vfsmount___14 *mnt;
	struct dentry___90 *dentry;
};

struct key___86;

struct ucounts___75;

struct user_namespace___75 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___75 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___7 ns;
	long unsigned int flags;
	struct key___86 *persistent_keyring_register;
	struct rw_semaphore___90 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___75 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___90 *pgtable_t___89;

struct dev_pagemap___87;

struct page___90 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___89 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___90 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___89 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___89 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___87 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___89;

struct lruvec___89 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___89 *pgdat;
};

struct zone___89 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___89 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___89 {
	struct zone___89 *zone;
	int zone_idx;
};

struct zonelist___89 {
	struct zoneref___89 _zonerefs[25];
};

struct pglist_data___89 {
	struct zone___89 node_zones[3];
	struct zonelist___89 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___90 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___90 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___89 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___90 {
	void *stack;
	struct task_struct___90 *task;
	long int status;
};

struct blocking_notifier_head___89 {
	struct rw_semaphore___90 rwsem;
	struct notifier_block *head;
};

struct upid___74 {
	int nr;
	struct pid_namespace___74 *ns;
};

struct pid_namespace___74 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___90 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___74 *parent;
	struct vfsmount___14 *proc_mnt;
	struct dentry___90 *proc_self;
	struct dentry___90 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___75 *user_ns;
	struct ucounts___75 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___7 ns;
};

struct pid___74 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___74 numbers[1];
};

struct vm_operations_struct___87;

struct vm_area_struct___90 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___90 *vm_next;
	struct vm_area_struct___90 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___89 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___87 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___90 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct linux_binfmt___12;

struct core_state___89;

struct mm_struct___89 {
	struct {
		struct vm_area_struct___90 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___90 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___90 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___12 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___89 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___90 *owner;
		struct user_namespace___75 *user_ns;
		struct file___90 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___89 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___87)(struct vm_area_struct___90 *, long unsigned int, const struct page___90 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___87)(struct page___90 *, void *);

struct device___82;

struct dev_pagemap___87 {
	dev_page_fault_t___87 page_fault;
	dev_page_free_t___87 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___82 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct fown_struct___74 {
	rwlock_t lock;
	struct pid___74 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___90 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___89 f_path;
	struct inode___91 *f_inode;
	const struct file_operations___90 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___74 f_owner;
	const struct cred___86 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___89 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___87;

struct vm_operations_struct___87 {
	void (*open)(struct vm_area_struct___90 *);
	void (*close)(struct vm_area_struct___90 *);
	int (*split)(struct vm_area_struct___90 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___90 *);
	vm_fault_t (*fault)(struct vm_fault___87 *);
	vm_fault_t (*huge_fault)(struct vm_fault___87 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___87 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___90 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___87 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___87 *);
	int (*access)(struct vm_area_struct___90 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___90 *);
	int (*set_policy)(struct vm_area_struct___90 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___90 *, long unsigned int);
	struct page___90 * (*find_special_page)(struct vm_area_struct___90 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___89 {
	struct task_struct___90 *task;
	struct core_thread___89 *next;
};

struct core_state___89 {
	atomic_t nr_threads;
	struct core_thread___89 dumper;
	struct completion startup;
};

struct linux_binprm___13;

struct coredump_params___12;

struct linux_binfmt___12 {
	struct list_head lh;
	struct module___78 *module;
	int (*load_binary)(struct linux_binprm___13 *);
	int (*load_shlib)(struct file___90 *);
	int (*core_dump)(struct coredump_params___12 *);
	long unsigned int min_coredump;
};

struct vm_fault___87 {
	struct vm_area_struct___90 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___90 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___90 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___89 prealloc_pte;
};

struct kern_ipc_perm {
	spinlock_t lock;
	bool deleted;
	int id;
	key_t key;
	kuid_t uid;
	kgid_t gid;
	kuid_t cuid;
	kgid_t cgid;
	umode_t mode;
	long unsigned int seq;
	void *security;
	struct rhash_head khtnode;
	struct callback_head rcu;
	refcount_t refcount;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct user_struct___86 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___86 *uid_keyring;
	struct key___86 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___86 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___86 *session_keyring;
	struct key___86 *process_keyring;
	struct key___86 *thread_keyring;
	struct key___86 *request_key_auth;
	void *security;
	struct user_struct___86 *user;
	struct user_namespace___75 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct fs_struct___6 {
	int users;
	spinlock_t lock;
	seqcount_t seq;
	int umask;
	int in_exec;
	struct path___89 root;
	struct path___89 pwd;
};

struct cgroup_namespace___72;

struct nsproxy___83 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___74 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___72 *cgroup_ns;
};

struct tty_struct___12;

struct signal_struct___80 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___90 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___90 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___74 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___74 *tty_old_pgrp;
	int leader;
	struct tty_struct___12 *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___89 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___74 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct audit_aux_data___2;

struct audit_tree_refs___2;

struct audit_context___4 {
	int dummy;
	int in_syscall;
	enum audit_state state;
	enum audit_state current_state;
	unsigned int serial;
	int major;
	struct timespec64 ctime;
	long unsigned int argv[4];
	long int return_code;
	u64 prio;
	int return_valid;
	struct audit_names preallocated_names[5];
	int name_count;
	struct list_head names_list;
	char *filterkey;
	struct path___89 pwd;
	struct audit_aux_data___2 *aux;
	struct audit_aux_data___2 *aux_pids;
	struct __kernel_sockaddr_storage *sockaddr;
	size_t sockaddr_len;
	pid_t pid;
	pid_t ppid;
	kuid_t uid;
	kuid_t euid;
	kuid_t suid;
	kuid_t fsuid;
	kgid_t gid;
	kgid_t egid;
	kgid_t sgid;
	kgid_t fsgid;
	long unsigned int personality;
	int arch;
	pid_t target_pid;
	kuid_t target_auid;
	kuid_t target_uid;
	unsigned int target_sessionid;
	u32 target_sid;
	char target_comm[16];
	struct audit_tree_refs___2 *trees;
	struct audit_tree_refs___2 *first_trees;
	struct list_head killed_trees;
	int tree_count;
	int type;
	union {
		struct {
			int nargs;
			long int args[6];
		} socketcall;
		struct {
			kuid_t uid;
			kgid_t gid;
			umode_t mode;
			u32 osid;
			int has_perm;
			uid_t perm_uid;
			gid_t perm_gid;
			umode_t perm_mode;
			long unsigned int qbytes;
		} ipc;
		struct {
			mqd_t mqdes;
			struct mq_attr mqstat;
		} mq_getsetattr;
		struct {
			mqd_t mqdes;
			int sigev_signo;
		} mq_notify;
		struct {
			mqd_t mqdes;
			size_t msg_len;
			unsigned int msg_prio;
			struct timespec64 abs_timeout;
		} mq_sendrecv;
		struct {
			int oflag;
			umode_t mode;
			struct mq_attr attr;
		} mq_open;
		struct {
			pid_t pid;
			struct audit_cap_data cap;
		} capset;
		struct {
			int fd;
			int flags;
		} mmap;
		struct {
			int argc;
		} execve;
		struct {
			char *name;
		} module;
	};
	int fds[2];
	struct audit_proctitle proctitle;
};

struct cgroup_subsys_state___72;

struct cgroup___72;

struct css_set___72 {
	struct cgroup_subsys_state___72 *subsys[13];
	refcount_t refcount;
	struct css_set___72 *dom_cset;
	struct cgroup___72 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___72 *mg_src_cgrp;
	struct cgroup___72 *mg_dst_cgrp;
	struct css_set___72 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___56 {
	struct pmu___56 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___90 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___56 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___18;

struct pipe_inode_info___18 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___90 *tmp_page;
	struct fasync_struct___89 *fasync_readers;
	struct fasync_struct___89 *fasync_writers;
	struct pipe_buffer___18 *bufs;
	struct user_struct___86 *user;
};

struct vm_struct___64 {
	struct vm_struct___64 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___90 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___80 {
	struct task_struct___90 task;
	long unsigned int stack[8192];
};

struct kiocb___90 {
	struct file___90 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___90 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___90 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___90 *ia_file;
};

struct dquot___89 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___90 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___89 {
	int qf_fmt_id;
	const struct quota_format_ops___89 *qf_ops;
	struct module___78 *qf_owner;
	struct quota_format_type___89 *qf_next;
};

struct quota_format_ops___89 {
	int (*check_quota_file)(struct super_block___90 *, int);
	int (*read_file_info)(struct super_block___90 *, int);
	int (*write_file_info)(struct super_block___90 *, int);
	int (*free_file_info)(struct super_block___90 *, int);
	int (*read_dqblk)(struct dquot___89 *);
	int (*commit_dqblk)(struct dquot___89 *);
	int (*release_dqblk)(struct dquot___89 *);
	int (*get_next_id)(struct super_block___90 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___89 {
	int (*write_dquot)(struct dquot___89 *);
	struct dquot___89 * (*alloc_dquot)(struct super_block___90 *, int);
	void (*destroy_dquot)(struct dquot___89 *);
	int (*acquire_dquot)(struct dquot___89 *);
	int (*release_dquot)(struct dquot___89 *);
	int (*mark_dirty)(struct dquot___89 *);
	int (*write_info)(struct super_block___90 *, int);
	qsize_t * (*get_reserved_space)(struct inode___91 *);
	int (*get_projid)(struct inode___91 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___91 *, qsize_t *);
	int (*get_next_id)(struct super_block___90 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___89 {
	int (*quota_on)(struct super_block___90 *, int, int, const struct path___89 *);
	int (*quota_off)(struct super_block___90 *, int);
	int (*quota_enable)(struct super_block___90 *, unsigned int);
	int (*quota_disable)(struct super_block___90 *, unsigned int);
	int (*quota_sync)(struct super_block___90 *, int);
	int (*set_info)(struct super_block___90 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___90 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___90 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___90 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___90 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___90 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___83;

struct kobj_type___83;

struct kernfs_node___86;

struct kobject___84 {
	const char *name;
	struct list_head entry;
	struct kobject___84 *parent;
	struct kset___83 *kset;
	struct kobj_type___83 *ktype;
	struct kernfs_node___86 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___75 {
	struct kobject___84 kobj;
	struct module___78 *mod;
	struct kobject___84 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___75 {
	struct module___78 *mod;
	struct latch_tree_node node;
};

struct module_layout___75 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___75 mtn;
};

struct module_attribute___75;

struct kernel_param___75;

struct module___78 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___75 mkobj;
	struct module_attribute___75 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___84 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___75 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___75 core_layout;
	struct module_layout___75 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___51 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___89 {
	int (*writepage)(struct page___90 *, struct writeback_control___3 *);
	int (*readpage)(struct file___90 *, struct page___90 *);
	int (*writepages)(struct address_space___89 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___90 *);
	int (*readpages)(struct file___90 *, struct address_space___89 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___90 *, struct address_space___89 *, loff_t, unsigned int, unsigned int, struct page___90 **, void **);
	int (*write_end)(struct file___90 *, struct address_space___89 *, loff_t, unsigned int, unsigned int, struct page___90 *, void *);
	sector_t (*bmap)(struct address_space___89 *, sector_t);
	void (*invalidatepage)(struct page___90 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___90 *, gfp_t);
	void (*freepage)(struct page___90 *);
	ssize_t (*direct_IO)(struct kiocb___90 *, struct iov_iter___36 *);
	int (*migratepage)(struct address_space___89 *, struct page___90 *, struct page___90 *, enum migrate_mode);
	bool (*isolate_page)(struct page___90 *, isolate_mode_t);
	void (*putback_page)(struct page___90 *);
	int (*launder_page)(struct page___90 *);
	int (*is_partially_uptodate)(struct page___90 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___90 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___89 *, struct page___90 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___90 *, sector_t *);
	void (*swap_deactivate)(struct file___90 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct iov_iter___36 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___3 *bvec;
		struct pipe_inode_info___18 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___90 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___91 *bd_inode;
	struct super_block___90 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___90 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___26 {
	struct kobject___84 kobj;
	struct module___78 *owner;
	const struct file_operations___90 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___89 {
	struct dentry___90 * (*lookup)(struct inode___91 *, struct dentry___90 *, unsigned int);
	const char * (*get_link)(struct dentry___90 *, struct inode___91 *, struct delayed_call *);
	int (*permission)(struct inode___91 *, int);
	struct posix_acl * (*get_acl)(struct inode___91 *, int);
	int (*readlink)(struct dentry___90 *, char *, int);
	int (*create)(struct inode___91 *, struct dentry___90 *, umode_t, bool);
	int (*link)(struct dentry___90 *, struct inode___91 *, struct dentry___90 *);
	int (*unlink)(struct inode___91 *, struct dentry___90 *);
	int (*symlink)(struct inode___91 *, struct dentry___90 *, const char *);
	int (*mkdir)(struct inode___91 *, struct dentry___90 *, umode_t);
	int (*rmdir)(struct inode___91 *, struct dentry___90 *);
	int (*mknod)(struct inode___91 *, struct dentry___90 *, umode_t, dev_t);
	int (*rename)(struct inode___91 *, struct dentry___90 *, struct inode___91 *, struct dentry___90 *, unsigned int);
	int (*setattr)(struct dentry___90 *, struct iattr___90 *);
	int (*getattr)(const struct path___89 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___90 *, char *, size_t);
	int (*fiemap)(struct inode___91 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___91 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___91 *, struct dentry___90 *, struct file___90 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___91 *, struct dentry___90 *, umode_t);
	int (*set_acl)(struct inode___91 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct fsnotify_mark_connector *fsnotify_connp_t;

struct fsnotify_mark_connector {
	spinlock_t lock;
	unsigned int type;
	union {
		fsnotify_connp_t *obj;
		struct fsnotify_mark_connector *destroy_next;
	};
	struct hlist_head list;
};

struct file_lock_operations___89 {
	void (*fl_copy_lock)(struct file_lock___90 *, struct file_lock___90 *);
	void (*fl_release_private)(struct file_lock___90 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___89;

struct file_lock___90 {
	struct file_lock___90 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___90 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___89 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___89 *fl_ops;
	const struct lock_manager_operations___89 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___89 {
	int (*lm_compare_owner)(struct file_lock___90 *, struct file_lock___90 *);
	long unsigned int (*lm_owner_key)(struct file_lock___90 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___90 *);
	int (*lm_grant)(struct file_lock___90 *, int);
	bool (*lm_break)(struct file_lock___90 *);
	int (*lm_change)(struct file_lock___90 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___90 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___89 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___89 *fa_next;
	struct file___90 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___89 {
	const char *name;
	int fs_flags;
	struct dentry___90 * (*mount)(struct file_system_type___89 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___90 *);
	struct module___78 *owner;
	struct file_system_type___89 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___89 {
	struct inode___91 * (*alloc_inode)(struct super_block___90 *);
	void (*destroy_inode)(struct inode___91 *);
	void (*dirty_inode)(struct inode___91 *, int);
	int (*write_inode)(struct inode___91 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___91 *);
	void (*evict_inode)(struct inode___91 *);
	void (*put_super)(struct super_block___90 *);
	int (*sync_fs)(struct super_block___90 *, int);
	int (*freeze_super)(struct super_block___90 *);
	int (*freeze_fs)(struct super_block___90 *);
	int (*thaw_super)(struct super_block___90 *);
	int (*unfreeze_fs)(struct super_block___90 *);
	int (*statfs)(struct dentry___90 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___90 *, int *, char *);
	void (*umount_begin)(struct super_block___90 *);
	int (*show_options)(struct seq_file___83 *, struct dentry___90 *);
	int (*show_devname)(struct seq_file___83 *, struct dentry___90 *);
	int (*show_path)(struct seq_file___83 *, struct dentry___90 *);
	int (*show_stats)(struct seq_file___83 *, struct dentry___90 *);
	ssize_t (*quota_read)(struct super_block___90 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___90 *, int, const char *, size_t, loff_t);
	struct dquot___89 ** (*get_dquots)(struct inode___91 *);
	int (*bdev_try_to_free_page)(struct super_block___90 *, struct page___90 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___90 *, struct shrink_control___33 *);
	long int (*free_cached_objects)(struct super_block___90 *, struct shrink_control___33 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___59)(struct file___90 *, wait_queue_head_t *, struct poll_table_struct___60 *);

struct poll_table_struct___60 {
	poll_queue_proc___59 _qproc;
	__poll_t _key;
};

struct seq_operations___81;

struct seq_file___83 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___81 *op;
	int poll_event;
	const struct file___90 *file;
	void *private;
};

struct dev_pm_info___82 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___82 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___82;

struct bus_type___82;

struct device_driver___82;

struct dev_pm_domain___82;

struct dma_map_ops___23;

struct fwnode_handle___60;

struct class___82;

struct attribute_group___81;

struct device___82 {
	struct device___82 *parent;
	struct device_private *p;
	struct kobject___84 kobj;
	const char *init_name;
	const struct device_type___82 *type;
	struct mutex mutex;
	struct bus_type___82 *bus;
	struct device_driver___82 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___82 power;
	struct dev_pm_domain___82 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___23 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___60 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___82 *class;
	const struct attribute_group___81 **groups;
	void (*release)(struct device___82 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct kobj_attribute___84 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___84 *, struct kobj_attribute___84 *, char *);
	ssize_t (*store)(struct kobject___84 *, struct kobj_attribute___84 *, const char *, size_t);
};

typedef void compound_page_dtor___87(struct page___90 *);

typedef int (*key_restrict_link_func_t___86)(struct key___86 *, const struct key_type *, const union key_payload *, struct key___86 *);

struct key_restriction___86;

struct key___86 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___90 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___86 *restrict_link;
};

struct key_restriction___86 {
	key_restrict_link_func_t___86 check;
	struct key___86 *key;
	struct key_type *keytype;
};

struct tty_driver___12;

struct tty_operations___12;

struct tty_ldisc___12;

struct tty_port___12;

struct tty_struct___12 {
	int magic;
	struct kref kref;
	struct device___82 *dev;
	struct tty_driver___12 *driver;
	const struct tty_operations___12 *ops;
	int index;
	struct ld_semaphore ldisc_sem;
	struct tty_ldisc___12 *ldisc;
	struct mutex atomic_write_lock;
	struct mutex legacy_mutex;
	struct mutex throttle_mutex;
	struct rw_semaphore___90 termios_rwsem;
	struct mutex winsize_mutex;
	spinlock_t ctrl_lock;
	spinlock_t flow_lock;
	struct ktermios termios;
	struct ktermios termios_locked;
	struct termiox *termiox;
	char name[64];
	struct pid___74 *pgrp;
	struct pid___74 *session;
	long unsigned int flags;
	int count;
	struct winsize winsize;
	long unsigned int stopped: 1;
	long unsigned int flow_stopped: 1;
	int: 30;
	long unsigned int unused: 62;
	int hw_stopped;
	long unsigned int ctrl_status: 8;
	long unsigned int packet: 1;
	int: 23;
	long unsigned int unused_ctrl: 55;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___12 *link;
	struct fasync_struct___89 *fasync;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	spinlock_t files_lock;
	struct list_head tty_files;
	int closing;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___12 *port;
};

struct cgroup_namespace___72 {
	refcount_t count;
	struct ns_common___7 ns;
	struct user_namespace___75 *user_ns;
	struct ucounts___75 *ucounts;
	struct css_set___72 *root_cset;
};

struct ucounts___75 {
	struct hlist_node node;
	struct user_namespace___75 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct kernfs_root___86;

struct kernfs_elem_dir___86 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___86 *root;
};

struct kernfs_syscall_ops___86;

struct kernfs_root___86 {
	struct kernfs_node___86 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___86 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___86 {
	struct kernfs_node___86 *target_kn;
};

struct kernfs_ops___86;

struct kernfs_elem_attr___86 {
	const struct kernfs_ops___86 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___86 *notify_next;
};

struct kernfs_node___86 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___86 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___86 dir;
		struct kernfs_elem_symlink___86 symlink;
		struct kernfs_elem_attr___86 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___86;

struct kernfs_ops___86 {
	int (*open)(struct kernfs_open_file___86 *);
	void (*release)(struct kernfs_open_file___86 *);
	int (*seq_show)(struct seq_file___83 *, void *);
	void * (*seq_start)(struct seq_file___83 *, loff_t *);
	void * (*seq_next)(struct seq_file___83 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___83 *, void *);
	ssize_t (*read)(struct kernfs_open_file___86 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___86 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___86 *, struct vm_area_struct___90 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___86 *, struct poll_table_struct___60 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___86 {
	int (*remount_fs)(struct kernfs_root___86 *, int *, char *);
	int (*show_options)(struct seq_file___83 *, struct kernfs_root___86 *);
	int (*mkdir)(struct kernfs_node___86 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___86 *);
	int (*rename)(struct kernfs_node___86 *, struct kernfs_node___86 *, const char *);
	int (*show_path)(struct seq_file___83 *, struct kernfs_node___86 *, struct kernfs_root___86 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___86 {
	struct kernfs_node___86 *kn;
	struct file___90 *file;
	struct seq_file___83 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___87 *vm_ops;
};

struct bin_attribute___81;

struct attribute_group___81 {
	const char *name;
	umode_t (*is_visible)(struct kobject___84 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___84 *, struct bin_attribute___81 *, int);
	struct attribute **attrs;
	struct bin_attribute___81 **bin_attrs;
};

struct bin_attribute___81 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___90 *, struct kobject___84 *, struct bin_attribute___81 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___90 *, struct kobject___84 *, struct bin_attribute___81 *, char *, loff_t, size_t);
	int (*mmap)(struct file___90 *, struct kobject___84 *, struct bin_attribute___81 *, struct vm_area_struct___90 *);
};

struct sysfs_ops___83 {
	ssize_t (*show)(struct kobject___84 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___84 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___83;

struct kset___83 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___84 kobj;
	const struct kset_uevent_ops___83 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___83 {
	void (*release)(struct kobject___84 *);
	const struct sysfs_ops___83 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___5 * (*child_ns_type)(struct kobject___84 *);
	const void * (*namespace)(struct kobject___84 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___83 {
	int (* const filter)(struct kset___83 *, struct kobject___84 *);
	const char * (* const name)(struct kset___83 *, struct kobject___84 *);
	int (* const uevent)(struct kset___83 *, struct kobject___84 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___82 {
	int (*prepare)(struct device___82 *);
	void (*complete)(struct device___82 *);
	int (*suspend)(struct device___82 *);
	int (*resume)(struct device___82 *);
	int (*freeze)(struct device___82 *);
	int (*thaw)(struct device___82 *);
	int (*poweroff)(struct device___82 *);
	int (*restore)(struct device___82 *);
	int (*suspend_late)(struct device___82 *);
	int (*resume_early)(struct device___82 *);
	int (*freeze_late)(struct device___82 *);
	int (*thaw_early)(struct device___82 *);
	int (*poweroff_late)(struct device___82 *);
	int (*restore_early)(struct device___82 *);
	int (*suspend_noirq)(struct device___82 *);
	int (*resume_noirq)(struct device___82 *);
	int (*freeze_noirq)(struct device___82 *);
	int (*thaw_noirq)(struct device___82 *);
	int (*poweroff_noirq)(struct device___82 *);
	int (*restore_noirq)(struct device___82 *);
	int (*runtime_suspend)(struct device___82 *);
	int (*runtime_resume)(struct device___82 *);
	int (*runtime_idle)(struct device___82 *);
};

struct dev_pm_domain___82 {
	struct dev_pm_ops___82 ops;
	void (*detach)(struct device___82 *, bool);
	int (*activate)(struct device___82 *);
	void (*sync)(struct device___82 *);
	void (*dismiss)(struct device___82 *);
};

struct bus_type___82 {
	const char *name;
	const char *dev_name;
	struct device___82 *dev_root;
	const struct attribute_group___81 **bus_groups;
	const struct attribute_group___81 **dev_groups;
	const struct attribute_group___81 **drv_groups;
	int (*match)(struct device___82 *, struct device_driver___82 *);
	int (*uevent)(struct device___82 *, struct kobj_uevent_env *);
	int (*probe)(struct device___82 *);
	int (*remove)(struct device___82 *);
	void (*shutdown)(struct device___82 *);
	int (*online)(struct device___82 *);
	int (*offline)(struct device___82 *);
	int (*suspend)(struct device___82 *, pm_message_t);
	int (*resume)(struct device___82 *);
	int (*num_vf)(struct device___82 *);
	int (*dma_configure)(struct device___82 *);
	const struct dev_pm_ops___82 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___82 {
	const char *name;
	struct bus_type___82 *bus;
	struct module___78 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___82 *);
	int (*remove)(struct device___82 *);
	void (*shutdown)(struct device___82 *);
	int (*suspend)(struct device___82 *, pm_message_t);
	int (*resume)(struct device___82 *);
	const struct attribute_group___81 **groups;
	const struct dev_pm_ops___82 *pm;
	void (*coredump)(struct device___82 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___82 {
	const char *name;
	const struct attribute_group___81 **groups;
	int (*uevent)(struct device___82 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___82 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___82 *);
	const struct dev_pm_ops___82 *pm;
};

struct class___82 {
	const char *name;
	struct module___78 *owner;
	const struct attribute_group___81 **class_groups;
	const struct attribute_group___81 **dev_groups;
	struct kobject___84 *dev_kobj;
	int (*dev_uevent)(struct device___82 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___82 *, umode_t *);
	void (*class_release)(struct class___82 *);
	void (*dev_release)(struct device___82 *);
	int (*shutdown_pre)(struct device___82 *);
	const struct kobj_ns_type_operations___5 *ns_type;
	const void * (*namespace)(struct device___82 *);
	const struct dev_pm_ops___82 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___23 {
	void * (*alloc)(struct device___82 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___82 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___82 *, struct vm_area_struct___90 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___82 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___82 *, struct page___90 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___82 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___82 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___82 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___82 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___82 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___82 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___82 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___82 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___82 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___82 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___82 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___82 *, u64);
	u64 (*get_required_mask)(struct device___82 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___60;

struct fwnode_handle___60 {
	struct fwnode_handle___60 *secondary;
	const struct fwnode_operations___60 *ops;
};

struct fwnode_reference_args___60;

struct fwnode_endpoint___60;

struct fwnode_operations___60 {
	struct fwnode_handle___60 * (*get)(struct fwnode_handle___60 *);
	void (*put)(struct fwnode_handle___60 *);
	bool (*device_is_available)(const struct fwnode_handle___60 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___60 *, const struct device___82 *);
	bool (*property_present)(const struct fwnode_handle___60 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___60 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___60 *, const char *, const char **, size_t);
	struct fwnode_handle___60 * (*get_parent)(const struct fwnode_handle___60 *);
	struct fwnode_handle___60 * (*get_next_child_node)(const struct fwnode_handle___60 *, struct fwnode_handle___60 *);
	struct fwnode_handle___60 * (*get_named_child_node)(const struct fwnode_handle___60 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___60 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___60 *);
	struct fwnode_handle___60 * (*graph_get_next_endpoint)(const struct fwnode_handle___60 *, struct fwnode_handle___60 *);
	struct fwnode_handle___60 * (*graph_get_remote_endpoint)(const struct fwnode_handle___60 *);
	struct fwnode_handle___60 * (*graph_get_port_parent)(struct fwnode_handle___60 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___60 *, struct fwnode_endpoint___60 *);
};

struct fwnode_endpoint___60 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___60 *local_fwnode;
};

struct fwnode_reference_args___60 {
	struct fwnode_handle___60 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___18;

struct pipe_buffer___18 {
	struct page___90 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___18 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___18 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___18 *, struct pipe_buffer___18 *);
	void (*release)(struct pipe_inode_info___18 *, struct pipe_buffer___18 *);
	int (*steal)(struct pipe_inode_info___18 *, struct pipe_buffer___18 *);
	union {
		bool (*get)(struct pipe_inode_info___18 *, struct pipe_buffer___18 *);
		struct {
			void (*get)(struct pipe_inode_info___18 *, struct pipe_buffer___18 *);
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
};

struct linux_binprm___13 {
	char buf[256];
	struct vm_area_struct___90 *vma;
	long unsigned int vma_pages;
	struct mm_struct___89 *mm;
	long unsigned int p;
	unsigned int called_set_creds: 1;
	unsigned int cap_elevated: 1;
	unsigned int secureexec: 1;
	unsigned int recursion_depth;
	struct file___90 *file;
	struct cred___86 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
};

struct coredump_params___12 {
	union {
		const kernel_siginfo_t *siginfo;
		struct {
			const siginfo_t *siginfo;
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	struct pt_regs *regs;
	struct file___90 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
};

struct seq_operations___81 {
	void * (*start)(struct seq_file___83 *, loff_t *);
	void (*stop)(struct seq_file___83 *, void *);
	void * (*next)(struct seq_file___83 *, void *, loff_t *);
	int (*show)(struct seq_file___83 *, void *);
};

struct kernel_param_ops___75 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___75 *);
	int (*get)(char *, const struct kernel_param___75 *);
	void (*free)(void *);
};

struct kparam_array___75;

struct kernel_param___75 {
	const char *name;
	struct module___78 *mod;
	const struct kernel_param_ops___75 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___75 *arr;
	};
};

struct kparam_array___75 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___75 *ops;
	void *elem;
};

struct module_attribute___75 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___75 *, struct module_kobject___75 *, char *);
	ssize_t (*store)(struct module_attribute___75 *, struct module_kobject___75 *, const char *, size_t);
	void (*setup)(struct module___78 *, const char *);
	int (*test)(struct module___78 *);
	void (*free)(struct module___78 *);
};

struct trace_event_class___51;

struct trace_event_call___51 {
	struct list_head list;
	struct trace_event_class___51 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___8 *prog_array;
	int (*perf_perm)(struct trace_event_call___51 *, struct perf_event___56 *);
};

struct node___71 {
	struct device___82 dev;
};

struct bpf_map___72;

struct bpf_map_ops___72 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___72 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___72 *, struct file___90 *);
	void (*map_free)(struct bpf_map___72 *);
	int (*map_get_next_key)(struct bpf_map___72 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___72 *);
	void * (*map_lookup_elem)(struct bpf_map___72 *, void *);
	int (*map_update_elem)(struct bpf_map___72 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___72 *, void *);
	int (*map_push_elem)(struct bpf_map___72 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___72 *, void *);
	int (*map_peek_elem)(struct bpf_map___72 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___72 *, struct file___90 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___72 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___72 *, void *, struct seq_file___83 *);
	int (*map_check_btf)(const struct bpf_map___72 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___72 {
	const struct bpf_map_ops___72 *ops;
	struct bpf_map___72 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___86 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___72;

typedef void (*kthread_work_func_t___72)(struct kthread_work___72 *);

struct kthread_worker___72;

struct kthread_work___72 {
	struct list_head node;
	kthread_work_func_t___72 func;
	struct kthread_worker___72 *worker;
	int canceling;
};

struct kthread_worker___72 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___90 *task;
	struct kthread_work___72 *current_work;
};

struct kthread_delayed_work___72 {
	struct kthread_work___72 work;
	struct timer_list timer;
};

struct psi_group___72 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___72 *poll_kworker;
	struct kthread_delayed_work___72 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___72 {
	struct kernfs_node___86 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___72;

struct cgroup_subsys_state___72 {
	struct cgroup___72 *cgroup;
	struct cgroup_subsys___72 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___72 *parent;
};

struct cgroup_root___72;

struct cgroup_rstat_cpu___72;

struct cgroup___72 {
	struct cgroup_subsys_state___72 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___86 *kn;
	struct cgroup_file___72 procs_file;
	struct cgroup_file___72 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___72 *subsys[13];
	struct cgroup_root___72 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___72 *dom_cgrp;
	struct cgroup_rstat_cpu___72 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___8 bpf;
	atomic_t congestion_count;
	struct cgroup___72 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___72 psi;
	int ancestor_ids[0];
};

struct cftype___72;

struct cgroup_subsys___72 {
	struct cgroup_subsys_state___72 * (*css_alloc)(struct cgroup_subsys_state___72 *);
	int (*css_online)(struct cgroup_subsys_state___72 *);
	void (*css_offline)(struct cgroup_subsys_state___72 *);
	void (*css_released)(struct cgroup_subsys_state___72 *);
	void (*css_free)(struct cgroup_subsys_state___72 *);
	void (*css_reset)(struct cgroup_subsys_state___72 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___72 *, int);
	int (*css_extra_stat_show)(struct seq_file___83 *, struct cgroup_subsys_state___72 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___90 *);
	void (*cancel_fork)(struct task_struct___90 *);
	void (*fork)(struct task_struct___90 *);
	void (*exit)(struct task_struct___90 *);
	void (*free)(struct task_struct___90 *);
	void (*bind)(struct cgroup_subsys_state___72 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___72 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___72 *dfl_cftypes;
	struct cftype___72 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___72 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___72 *updated_children;
	struct cgroup___72 *updated_next;
};

struct cgroup_root___72 {
	struct kernfs_root___86 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___72 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___72 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___72 *ss;
	struct list_head node;
	struct kernfs_ops___86 *kf_ops;
	int (*open)(struct kernfs_open_file___86 *);
	void (*release)(struct kernfs_open_file___86 *);
	u64 (*read_u64)(struct cgroup_subsys_state___72 *, struct cftype___72 *);
	s64 (*read_s64)(struct cgroup_subsys_state___72 *, struct cftype___72 *);
	int (*seq_show)(struct seq_file___83 *, void *);
	void * (*seq_start)(struct seq_file___83 *, loff_t *);
	void * (*seq_next)(struct seq_file___83 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___83 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___72 *, struct cftype___72 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___72 *, struct cftype___72 *, s64);
	ssize_t (*write)(struct kernfs_open_file___86 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___86 *, struct poll_table_struct___60 *);
};

struct perf_cpu_context___56;

struct pmu___56 {
	struct list_head entry;
	struct module___78 *module;
	struct device___82 *dev;
	const struct attribute_group___81 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___56 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___56 *);
	void (*pmu_disable)(struct pmu___56 *);
	int (*event_init)(struct perf_event___56 *);
	void (*event_mapped)(struct perf_event___56 *, struct mm_struct___89 *);
	void (*event_unmapped)(struct perf_event___56 *, struct mm_struct___89 *);
	int (*add)(struct perf_event___56 *, int);
	void (*del)(struct perf_event___56 *, int);
	void (*start)(struct perf_event___56 *, int);
	void (*stop)(struct perf_event___56 *, int);
	void (*read)(struct perf_event___56 *);
	void (*start_txn)(struct pmu___56 *, unsigned int);
	int (*commit_txn)(struct pmu___56 *);
	void (*cancel_txn)(struct pmu___56 *);
	int (*event_idx)(struct perf_event___56 *);
	void (*sched_task)(struct perf_event_context___56 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___56 *);
	int (*filter_match)(struct perf_event___56 *);
	int (*check_period)(struct perf_event___56 *, u64);
};

struct perf_cpu_context___56 {
	struct perf_event_context___56 ctx;
	struct perf_event_context___56 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___56 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___56 {
	struct cgroup_subsys_state___72 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___51 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___51 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___51 *);
	struct list_head * (*get_fields)(struct trace_event_call___51 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___51 *);
};

enum fsnotify_obj_type {
	FSNOTIFY_OBJ_TYPE_INODE = 0,
	FSNOTIFY_OBJ_TYPE_VFSMOUNT = 1,
	FSNOTIFY_OBJ_TYPE_COUNT = 2,
	FSNOTIFY_OBJ_TYPE_DETACHED = 2,
};

struct tty_operations___12 {
	struct tty_struct___12 * (*lookup)(struct tty_driver___12 *, struct file___90 *, int);
	int (*install)(struct tty_driver___12 *, struct tty_struct___12 *);
	void (*remove)(struct tty_driver___12 *, struct tty_struct___12 *);
	int (*open)(struct tty_struct___12 *, struct file___90 *);
	void (*close)(struct tty_struct___12 *, struct file___90 *);
	void (*shutdown)(struct tty_struct___12 *);
	void (*cleanup)(struct tty_struct___12 *);
	int (*write)(struct tty_struct___12 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___12 *, unsigned char);
	void (*flush_chars)(struct tty_struct___12 *);
	int (*write_room)(struct tty_struct___12 *);
	int (*chars_in_buffer)(struct tty_struct___12 *);
	int (*ioctl)(struct tty_struct___12 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___12 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___12 *, struct ktermios *);
	void (*throttle)(struct tty_struct___12 *);
	void (*unthrottle)(struct tty_struct___12 *);
	void (*stop)(struct tty_struct___12 *);
	void (*start)(struct tty_struct___12 *);
	void (*hangup)(struct tty_struct___12 *);
	int (*break_ctl)(struct tty_struct___12 *, int);
	void (*flush_buffer)(struct tty_struct___12 *);
	void (*set_ldisc)(struct tty_struct___12 *);
	void (*wait_until_sent)(struct tty_struct___12 *, int);
	void (*send_xchar)(struct tty_struct___12 *, char);
	int (*tiocmget)(struct tty_struct___12 *);
	int (*tiocmset)(struct tty_struct___12 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___12 *, struct winsize *);
	int (*set_termiox)(struct tty_struct___12 *, struct termiox *);
	int (*get_icount)(struct tty_struct___12 *, struct serial_icounter_struct *);
	void (*show_fdinfo)(struct tty_struct___12 *, struct seq_file___83 *);
	int (*poll_init)(struct tty_driver___12 *, int, char *);
	int (*poll_get_char)(struct tty_driver___12 *, int);
	void (*poll_put_char)(struct tty_driver___12 *, int, char);
	int (*proc_show)(struct seq_file___83 *, void *);
};

struct tty_driver___12 {
	int magic;
	struct kref kref;
	struct cdev___26 **cdevs;
	struct module___78 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___12 *other;
	struct tty_struct___12 **ttys;
	struct tty_port___12 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___12 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___12;

struct tty_port_client_operations___12;

struct tty_port___12 {
	struct tty_bufhead buf;
	struct tty_struct___12 *tty;
	struct tty_struct___12 *itty;
	const struct tty_port_operations___12 *ops;
	const struct tty_port_client_operations___12 *client_ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	unsigned char low_latency: 1;
	struct mutex mutex;
	struct mutex buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
	void *client_data;
};

struct tty_ldisc_ops___12 {
	int magic;
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___12 *);
	void (*close)(struct tty_struct___12 *);
	void (*flush_buffer)(struct tty_struct___12 *);
	ssize_t (*read)(struct tty_struct___12 *, struct file___90 *, unsigned char *, size_t);
	ssize_t (*write)(struct tty_struct___12 *, struct file___90 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___12 *, struct file___90 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___12 *, struct file___90 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___12 *, struct ktermios *);
	__poll_t (*poll)(struct tty_struct___12 *, struct file___90 *, struct poll_table_struct___60 *);
	int (*hangup)(struct tty_struct___12 *);
	void (*receive_buf)(struct tty_struct___12 *, const unsigned char *, char *, int);
	void (*write_wakeup)(struct tty_struct___12 *);
	void (*dcd_change)(struct tty_struct___12 *, unsigned int);
	int (*receive_buf2)(struct tty_struct___12 *, const unsigned char *, char *, int);
	struct module___78 *owner;
	int refcount;
};

struct tty_ldisc___12 {
	struct tty_ldisc_ops___12 *ops;
	struct tty_struct___12 *tty;
};

struct tty_port_operations___12 {
	int (*carrier_raised)(struct tty_port___12 *);
	void (*dtr_rts)(struct tty_port___12 *, int);
	void (*shutdown)(struct tty_port___12 *);
	int (*activate)(struct tty_port___12 *, struct tty_struct___12 *);
	void (*destruct)(struct tty_port___12 *);
};

struct tty_port_client_operations___12 {
	int (*receive_buf)(struct tty_port___12 *, const unsigned char *, const unsigned char *, size_t);
	void (*write_wakeup)(struct tty_port___12 *);
};

struct audit_aux_data___2 {
	struct audit_aux_data___2 *next;
	int type;
};

struct audit_chunk;

struct audit_tree_refs___2 {
	struct audit_tree_refs___2 *next;
	struct audit_chunk *c[31];
};

struct audit_aux_data_pids {
	struct audit_aux_data___2 d;
	pid_t target_pid[16];
	kuid_t target_auid[16];
	kuid_t target_uid[16];
	unsigned int target_sessionid[16];
	u32 target_sid[16];
	char target_comm[256];
	int pid_count;
};

struct audit_aux_data_bprm_fcaps {
	struct audit_aux_data___2 d;
	struct audit_cap_data fcap;
	unsigned int fcap_ver;
	struct audit_cap_data old_pcap;
	struct audit_cap_data new_pcap;
};

struct audit_parent;

struct audit_watch {
	refcount_t count;
	dev_t dev;
	char *path;
	long unsigned int ino;
	struct audit_parent *parent;
	struct list_head wlist;
	struct list_head rules;
};

struct fsnotify_group;

struct fsnotify_iter_info;

struct fsnotify_mark;

struct fsnotify_event;

struct fsnotify_ops {
	int (*handle_event)(struct fsnotify_group *, struct inode___90 *, u32, const void *, int, const unsigned char *, u32, struct fsnotify_iter_info *);
	void (*free_group_priv)(struct fsnotify_group *);
	void (*freeing_mark)(struct fsnotify_mark *, struct fsnotify_group *);
	void (*free_event)(struct fsnotify_event *);
	void (*free_mark)(struct fsnotify_mark *);
};

struct inotify_group_private_data {
	spinlock_t idr_lock;
	struct idr idr;
	struct ucounts___74 *ucounts;
};

struct fanotify_group_private_data {
	struct list_head access_list;
	wait_queue_head_t access_waitq;
	int flags;
	int f_flags;
	unsigned int max_marks;
	struct user_struct___85 *user;
};

struct fsnotify_group {
	const struct fsnotify_ops *ops;
	refcount_t refcnt;
	spinlock_t notification_lock;
	struct list_head notification_list;
	wait_queue_head_t notification_waitq;
	unsigned int q_len;
	unsigned int max_events;
	unsigned int priority;
	bool shutdown;
	struct mutex mark_mutex;
	atomic_t num_marks;
	atomic_t user_waits;
	struct list_head marks_list;
	struct fasync_struct___88 *fsn_fa;
	struct fsnotify_event *overflow_event;
	struct mem_cgroup___2 *memcg;
	union {
		void *private;
		struct inotify_group_private_data inotify_data;
		struct fanotify_group_private_data fanotify_data;
	};
};

struct fsnotify_iter_info {
	struct fsnotify_mark *marks[2];
	unsigned int report_mask;
	int srcu_idx;
};

struct fsnotify_mark {
	__u32 mask;
	refcount_t refcnt;
	struct fsnotify_group *group;
	struct list_head g_list;
	spinlock_t lock;
	struct hlist_node obj_list;
	struct fsnotify_mark_connector *connector;
	__u32 ignored_mask;
	unsigned int flags;
};

struct fsnotify_event {
	struct list_head list;
	struct inode___90 *inode;
	u32 mask;
};

struct audit_parent {
	struct list_head watches;
	struct fsnotify_mark mark;
};

struct audit_fsnotify_mark {
	dev_t dev;
	long unsigned int ino;
	char *path;
	struct fsnotify_mark mark;
	struct audit_krule *rule;
};

struct file___91;

struct kiocb___91;

struct iov_iter___37;

struct vm_area_struct___91;

struct inode___92;

struct file_lock___91;

struct page___91;

struct pipe_inode_info___19;

struct seq_file___84;

struct file_operations___91 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___91 *, loff_t, int);
	ssize_t (*read)(struct file___91 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___91 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___91 *, struct iov_iter___37 *);
	ssize_t (*write_iter)(struct kiocb___91 *, struct iov_iter___37 *);
	int (*iopoll)(struct kiocb___91 *, bool);
	int (*iterate)(struct file___91 *, struct dir_context *);
	int (*iterate_shared)(struct file___91 *, struct dir_context *);
	__poll_t (*poll)(struct file___91 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___91 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___91 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___91 *, struct vm_area_struct___91 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___92 *, struct file___91 *);
	int (*flush)(struct file___91 *, fl_owner_t);
	int (*release)(struct inode___92 *, struct file___91 *);
	int (*fsync)(struct file___91 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___91 *, int);
	int (*lock)(struct file___91 *, int, struct file_lock___91 *);
	ssize_t (*sendpage)(struct file___91 *, struct page___91 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___91 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___91 *, int, struct file_lock___91 *);
	ssize_t (*splice_write)(struct pipe_inode_info___19 *, struct file___91 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___91 *, loff_t *, struct pipe_inode_info___19 *, size_t, unsigned int);
	int (*setlease)(struct file___91 *, long int, struct file_lock___91 **, void **);
	long int (*fallocate)(struct file___91 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___84 *, struct file___91 *);
	ssize_t (*copy_file_range)(struct file___91 *, loff_t, struct file___91 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___91 *, loff_t, struct file___91 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___91 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___90 {
	u64 seqnum;
	struct vm_area_struct___91 *vmas[4];
};

struct page_frag___90 {
	struct page___91 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___90;

struct pid___75;

struct cred___87;

struct nsproxy___84;

struct signal_struct___81;

struct audit_context___5;

struct vm_struct___65;

struct task_struct___91 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___91 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___90 *mm;
	struct mm_struct___90 *active_mm;
	struct vmacache___90 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___91 *real_parent;
	struct task_struct___91 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___91 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___75 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___75 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___75 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___87 *ptracer_cred;
	const struct cred___87 *real_cred;
	const struct cred___87 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___84 *nsproxy;
	struct signal_struct___81 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context___5 *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___91 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___15 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___19 *splice_pipe;
	struct page_frag___90 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___91 *oom_reaper_list;
	struct vm_struct___65 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___56 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___90;

struct super_block___91;

struct dentry___91 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___91 *d_parent;
	struct qstr d_name;
	struct inode___92 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___90 *d_op;
	struct super_block___91 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct rw_semaphore___91 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___91 *owner;
};

struct address_space_operations___90;

struct address_space___90 {
	struct inode___92 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___91 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___90 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___90;

struct block_device___91;

struct cdev___27;

struct inode___92 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___90 *i_op;
	struct super_block___91 *i_sb;
	struct address_space___90 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___91 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___91 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___90 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___19 *i_pipe;
		struct block_device___91 *i_bdev;
		struct cdev___27 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vfsmount___15;

struct path___90;

struct dentry_operations___90 {
	int (*d_revalidate)(struct dentry___91 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___91 *, unsigned int);
	int (*d_hash)(const struct dentry___91 *, struct qstr *);
	int (*d_compare)(const struct dentry___91 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___91 *);
	int (*d_init)(struct dentry___91 *);
	void (*d_release)(struct dentry___91 *);
	void (*d_prune)(struct dentry___91 *);
	void (*d_iput)(struct dentry___91 *, struct inode___92 *);
	char * (*d_dname)(struct dentry___91 *, char *, int);
	struct vfsmount___15 * (*d_automount)(struct path___90 *);
	int (*d_manage)(const struct path___90 *, bool);
	struct dentry___91 * (*d_real)(struct dentry___91 *, const struct inode___92 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___90;

struct mem_dqinfo___90 {
	struct quota_format_type___90 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___90;

struct quota_info___90 {
	unsigned int flags;
	struct rw_semaphore___91 dqio_sem;
	struct inode___92 *files[3];
	struct mem_dqinfo___90 info[3];
	const struct quota_format_ops___90 *ops[3];
};

struct rcuwait___90 {
	struct task_struct___91 *task;
};

struct percpu_rw_semaphore___90 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___91 rw_sem;
	struct rcuwait___90 writer;
	int readers_block;
};

struct sb_writers___90 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___90 rw_sem[3];
};

struct file_system_type___90;

struct super_operations___90;

struct dquot_operations___90;

struct quotactl_ops___90;

struct user_namespace___76;

struct super_block___91 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___90 *s_type;
	const struct super_operations___90 *s_op;
	const struct dquot_operations___90 *dq_op;
	const struct quotactl_ops___90 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___91 *s_root;
	struct rw_semaphore___91 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___91 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___90 s_dquot;
	struct sb_writers___90 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___90 *s_d_op;
	int cleancache_poolid;
	struct shrinker___33 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___76 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___15 {
	struct dentry___91 *mnt_root;
	struct super_block___91 *mnt_sb;
	int mnt_flags;
};

struct path___90 {
	struct vfsmount___15 *mnt;
	struct dentry___91 *dentry;
};

struct key___87;

struct ucounts___76;

struct user_namespace___76 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___76 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___7 ns;
	long unsigned int flags;
	struct key___87 *persistent_keyring_register;
	struct rw_semaphore___91 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___76 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___91 *pgtable_t___90;

struct dev_pagemap___88;

struct page___91 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___90 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___91 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___90 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___90 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___88 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___90;

struct lruvec___90 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___90 *pgdat;
};

struct zone___90 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___90 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___90 {
	struct zone___90 *zone;
	int zone_idx;
};

struct zonelist___90 {
	struct zoneref___90 _zonerefs[25];
};

struct pglist_data___90 {
	struct zone___90 node_zones[3];
	struct zonelist___90 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___91 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___91 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___90 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___91 {
	void *stack;
	struct task_struct___91 *task;
	long int status;
};

struct blocking_notifier_head___90 {
	struct rw_semaphore___91 rwsem;
	struct notifier_block *head;
};

struct pid_namespace___75;

struct upid___75 {
	int nr;
	struct pid_namespace___75 *ns;
};

struct pid_namespace___75 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___91 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___75 *parent;
	struct vfsmount___15 *proc_mnt;
	struct dentry___91 *proc_self;
	struct dentry___91 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___76 *user_ns;
	struct ucounts___76 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___7 ns;
};

struct pid___75 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___75 numbers[1];
};

struct vm_operations_struct___88;

struct vm_area_struct___91 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___91 *vm_next;
	struct vm_area_struct___91 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___90 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___88 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___91 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___90;

struct mm_struct___90 {
	struct {
		struct vm_area_struct___91 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___91 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___91 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___90 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___91 *owner;
		struct user_namespace___76 *user_ns;
		struct file___91 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___90 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___88)(struct vm_area_struct___91 *, long unsigned int, const struct page___91 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___88)(struct page___91 *, void *);

struct device___83;

struct dev_pagemap___88 {
	dev_page_fault_t___88 page_fault;
	dev_page_free_t___88 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___83 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct fown_struct___75 {
	rwlock_t lock;
	struct pid___75 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___91 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___90 f_path;
	struct inode___92 *f_inode;
	const struct file_operations___91 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___75 f_owner;
	const struct cred___87 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___90 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___88;

struct vm_operations_struct___88 {
	void (*open)(struct vm_area_struct___91 *);
	void (*close)(struct vm_area_struct___91 *);
	int (*split)(struct vm_area_struct___91 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___91 *);
	vm_fault_t (*fault)(struct vm_fault___88 *);
	vm_fault_t (*huge_fault)(struct vm_fault___88 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___88 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___91 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___88 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___88 *);
	int (*access)(struct vm_area_struct___91 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___91 *);
	int (*set_policy)(struct vm_area_struct___91 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___91 *, long unsigned int);
	struct page___91 * (*find_special_page)(struct vm_area_struct___91 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___90 {
	struct task_struct___91 *task;
	struct core_thread___90 *next;
};

struct core_state___90 {
	atomic_t nr_threads;
	struct core_thread___90 dumper;
	struct completion startup;
};

struct vm_fault___88 {
	struct vm_area_struct___91 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___91 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___91 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___90 prealloc_pte;
};

struct user_struct___87 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___87 *uid_keyring;
	struct key___87 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___87 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___87 *session_keyring;
	struct key___87 *process_keyring;
	struct key___87 *thread_keyring;
	struct key___87 *request_key_auth;
	void *security;
	struct user_struct___87 *user;
	struct user_namespace___76 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct nsproxy___84 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___75 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct tty_struct___13;

struct signal_struct___81 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___91 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___91 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___75 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___75 *tty_old_pgrp;
	int leader;
	struct tty_struct___13 *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___90 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___75 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct audit_context___5 {
	int dummy;
	int in_syscall;
	enum audit_state state;
	enum audit_state current_state;
	unsigned int serial;
	int major;
	struct timespec64 ctime;
	long unsigned int argv[4];
	long int return_code;
	u64 prio;
	int return_valid;
	struct audit_names preallocated_names[5];
	int name_count;
	struct list_head names_list;
	char *filterkey;
	struct path___90 pwd;
	struct audit_aux_data *aux;
	struct audit_aux_data *aux_pids;
	struct __kernel_sockaddr_storage *sockaddr;
	size_t sockaddr_len;
	pid_t pid;
	pid_t ppid;
	kuid_t uid;
	kuid_t euid;
	kuid_t suid;
	kuid_t fsuid;
	kgid_t gid;
	kgid_t egid;
	kgid_t sgid;
	kgid_t fsgid;
	long unsigned int personality;
	int arch;
	pid_t target_pid;
	kuid_t target_auid;
	kuid_t target_uid;
	unsigned int target_sessionid;
	u32 target_sid;
	char target_comm[16];
	struct audit_tree_refs *trees;
	struct audit_tree_refs *first_trees;
	struct list_head killed_trees;
	int tree_count;
	int type;
	union {
		struct {
			int nargs;
			long int args[6];
		} socketcall;
		struct {
			kuid_t uid;
			kgid_t gid;
			umode_t mode;
			u32 osid;
			int has_perm;
			uid_t perm_uid;
			gid_t perm_gid;
			umode_t perm_mode;
			long unsigned int qbytes;
		} ipc;
		struct {
			mqd_t mqdes;
			struct mq_attr mqstat;
		} mq_getsetattr;
		struct {
			mqd_t mqdes;
			int sigev_signo;
		} mq_notify;
		struct {
			mqd_t mqdes;
			size_t msg_len;
			unsigned int msg_prio;
			struct timespec64 abs_timeout;
		} mq_sendrecv;
		struct {
			int oflag;
			umode_t mode;
			struct mq_attr attr;
		} mq_open;
		struct {
			pid_t pid;
			struct audit_cap_data cap;
		} capset;
		struct {
			int fd;
			int flags;
		} mmap;
		struct {
			int argc;
		} execve;
		struct {
			char *name;
		} module;
	};
	int fds[2];
	struct audit_proctitle proctitle;
};

struct fasync_struct___90;

struct pipe_buffer___19;

struct pipe_inode_info___19 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___91 *tmp_page;
	struct fasync_struct___90 *fasync_readers;
	struct fasync_struct___90 *fasync_writers;
	struct pipe_buffer___19 *bufs;
	struct user_struct___87 *user;
};

struct vm_struct___65 {
	struct vm_struct___65 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___91 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___81 {
	struct task_struct___91 task;
	long unsigned int stack[8192];
};

struct kiocb___91 {
	struct file___91 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___91 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___91 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___91 *ia_file;
};

struct dquot___90 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___91 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___90 {
	int qf_fmt_id;
	const struct quota_format_ops___90 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___90 *qf_next;
};

struct quota_format_ops___90 {
	int (*check_quota_file)(struct super_block___91 *, int);
	int (*read_file_info)(struct super_block___91 *, int);
	int (*write_file_info)(struct super_block___91 *, int);
	int (*free_file_info)(struct super_block___91 *, int);
	int (*read_dqblk)(struct dquot___90 *);
	int (*commit_dqblk)(struct dquot___90 *);
	int (*release_dqblk)(struct dquot___90 *);
	int (*get_next_id)(struct super_block___91 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___90 {
	int (*write_dquot)(struct dquot___90 *);
	struct dquot___90 * (*alloc_dquot)(struct super_block___91 *, int);
	void (*destroy_dquot)(struct dquot___90 *);
	int (*acquire_dquot)(struct dquot___90 *);
	int (*release_dquot)(struct dquot___90 *);
	int (*mark_dirty)(struct dquot___90 *);
	int (*write_info)(struct super_block___91 *, int);
	qsize_t * (*get_reserved_space)(struct inode___92 *);
	int (*get_projid)(struct inode___92 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___92 *, qsize_t *);
	int (*get_next_id)(struct super_block___91 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___90 {
	int (*quota_on)(struct super_block___91 *, int, int, const struct path___90 *);
	int (*quota_off)(struct super_block___91 *, int);
	int (*quota_enable)(struct super_block___91 *, unsigned int);
	int (*quota_disable)(struct super_block___91 *, unsigned int);
	int (*quota_sync)(struct super_block___91 *, int);
	int (*set_info)(struct super_block___91 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___91 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___91 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___91 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___91 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___91 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___90 {
	int (*writepage)(struct page___91 *, struct writeback_control___3 *);
	int (*readpage)(struct file___91 *, struct page___91 *);
	int (*writepages)(struct address_space___90 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___91 *);
	int (*readpages)(struct file___91 *, struct address_space___90 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___91 *, struct address_space___90 *, loff_t, unsigned int, unsigned int, struct page___91 **, void **);
	int (*write_end)(struct file___91 *, struct address_space___90 *, loff_t, unsigned int, unsigned int, struct page___91 *, void *);
	sector_t (*bmap)(struct address_space___90 *, sector_t);
	void (*invalidatepage)(struct page___91 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___91 *, gfp_t);
	void (*freepage)(struct page___91 *);
	ssize_t (*direct_IO)(struct kiocb___91 *, struct iov_iter___37 *);
	int (*migratepage)(struct address_space___90 *, struct page___91 *, struct page___91 *, enum migrate_mode);
	bool (*isolate_page)(struct page___91 *, isolate_mode_t);
	void (*putback_page)(struct page___91 *);
	int (*launder_page)(struct page___91 *);
	int (*is_partially_uptodate)(struct page___91 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___91 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___90 *, struct page___91 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___91 *, sector_t *);
	void (*swap_deactivate)(struct file___91 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct iov_iter___37 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___3 *bvec;
		struct pipe_inode_info___19 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___91 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___92 *bd_inode;
	struct super_block___91 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___91 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___84;

struct kobj_type___84;

struct kernfs_node___87;

struct kobject___85 {
	const char *name;
	struct list_head entry;
	struct kobject___85 *parent;
	struct kset___84 *kset;
	struct kobj_type___84 *ktype;
	struct kernfs_node___87 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___27 {
	struct kobject___85 kobj;
	struct module___11 *owner;
	const struct file_operations___91 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___90 {
	struct dentry___91 * (*lookup)(struct inode___92 *, struct dentry___91 *, unsigned int);
	const char * (*get_link)(struct dentry___91 *, struct inode___92 *, struct delayed_call *);
	int (*permission)(struct inode___92 *, int);
	struct posix_acl * (*get_acl)(struct inode___92 *, int);
	int (*readlink)(struct dentry___91 *, char *, int);
	int (*create)(struct inode___92 *, struct dentry___91 *, umode_t, bool);
	int (*link)(struct dentry___91 *, struct inode___92 *, struct dentry___91 *);
	int (*unlink)(struct inode___92 *, struct dentry___91 *);
	int (*symlink)(struct inode___92 *, struct dentry___91 *, const char *);
	int (*mkdir)(struct inode___92 *, struct dentry___91 *, umode_t);
	int (*rmdir)(struct inode___92 *, struct dentry___91 *);
	int (*mknod)(struct inode___92 *, struct dentry___91 *, umode_t, dev_t);
	int (*rename)(struct inode___92 *, struct dentry___91 *, struct inode___92 *, struct dentry___91 *, unsigned int);
	int (*setattr)(struct dentry___91 *, struct iattr___91 *);
	int (*getattr)(const struct path___90 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___91 *, char *, size_t);
	int (*fiemap)(struct inode___92 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___92 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___92 *, struct dentry___91 *, struct file___91 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___92 *, struct dentry___91 *, umode_t);
	int (*set_acl)(struct inode___92 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___90 {
	void (*fl_copy_lock)(struct file_lock___91 *, struct file_lock___91 *);
	void (*fl_release_private)(struct file_lock___91 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___90;

struct file_lock___91 {
	struct file_lock___91 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___91 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___90 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___90 *fl_ops;
	const struct lock_manager_operations___90 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___90 {
	int (*lm_compare_owner)(struct file_lock___91 *, struct file_lock___91 *);
	long unsigned int (*lm_owner_key)(struct file_lock___91 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___91 *);
	int (*lm_grant)(struct file_lock___91 *, int);
	bool (*lm_break)(struct file_lock___91 *);
	int (*lm_change)(struct file_lock___91 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___91 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___90 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___90 *fa_next;
	struct file___91 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___90 {
	const char *name;
	int fs_flags;
	struct dentry___91 * (*mount)(struct file_system_type___90 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___91 *);
	struct module___11 *owner;
	struct file_system_type___90 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___90 {
	struct inode___92 * (*alloc_inode)(struct super_block___91 *);
	void (*destroy_inode)(struct inode___92 *);
	void (*dirty_inode)(struct inode___92 *, int);
	int (*write_inode)(struct inode___92 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___92 *);
	void (*evict_inode)(struct inode___92 *);
	void (*put_super)(struct super_block___91 *);
	int (*sync_fs)(struct super_block___91 *, int);
	int (*freeze_super)(struct super_block___91 *);
	int (*freeze_fs)(struct super_block___91 *);
	int (*thaw_super)(struct super_block___91 *);
	int (*unfreeze_fs)(struct super_block___91 *);
	int (*statfs)(struct dentry___91 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___91 *, int *, char *);
	void (*umount_begin)(struct super_block___91 *);
	int (*show_options)(struct seq_file___84 *, struct dentry___91 *);
	int (*show_devname)(struct seq_file___84 *, struct dentry___91 *);
	int (*show_path)(struct seq_file___84 *, struct dentry___91 *);
	int (*show_stats)(struct seq_file___84 *, struct dentry___91 *);
	ssize_t (*quota_read)(struct super_block___91 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___91 *, int, const char *, size_t, loff_t);
	struct dquot___90 ** (*get_dquots)(struct inode___92 *);
	int (*bdev_try_to_free_page)(struct super_block___91 *, struct page___91 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___91 *, struct shrink_control___33 *);
	long int (*free_cached_objects)(struct super_block___91 *, struct shrink_control___33 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___82;

struct seq_file___84 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___82 *op;
	int poll_event;
	const struct file___91 *file;
	void *private;
};

typedef int (*key_restrict_link_func_t___87)(struct key___87 *, const struct key_type *, const union key_payload *, struct key___87 *);

struct key_restriction___87;

struct key___87 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___91 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___87 *restrict_link;
};

struct key_restriction___87 {
	key_restrict_link_func_t___87 check;
	struct key___87 *key;
	struct key_type *keytype;
};

struct tty_driver___13;

struct tty_operations___13;

struct tty_ldisc___13;

struct tty_port___13;

struct tty_struct___13 {
	int magic;
	struct kref kref;
	struct device___83 *dev;
	struct tty_driver___13 *driver;
	const struct tty_operations___13 *ops;
	int index;
	struct ld_semaphore ldisc_sem;
	struct tty_ldisc___13 *ldisc;
	struct mutex atomic_write_lock;
	struct mutex legacy_mutex;
	struct mutex throttle_mutex;
	struct rw_semaphore___91 termios_rwsem;
	struct mutex winsize_mutex;
	spinlock_t ctrl_lock;
	spinlock_t flow_lock;
	struct ktermios termios;
	struct ktermios termios_locked;
	struct termiox *termiox;
	char name[64];
	struct pid___75 *pgrp;
	struct pid___75 *session;
	long unsigned int flags;
	int count;
	struct winsize winsize;
	long unsigned int stopped: 1;
	long unsigned int flow_stopped: 1;
	int: 30;
	long unsigned int unused: 62;
	int hw_stopped;
	long unsigned int ctrl_status: 8;
	long unsigned int packet: 1;
	int: 23;
	long unsigned int unused_ctrl: 55;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___13 *link;
	struct fasync_struct___90 *fasync;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	spinlock_t files_lock;
	struct list_head tty_files;
	int closing;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___13 *port;
};

struct dev_pm_info___83 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___83 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___83;

struct bus_type___83;

struct device_driver___83;

struct dev_pm_domain___83;

struct dma_map_ops___24;

struct fwnode_handle___61;

struct class___83;

struct attribute_group___82;

struct device___83 {
	struct device___83 *parent;
	struct device_private *p;
	struct kobject___85 kobj;
	const char *init_name;
	const struct device_type___83 *type;
	struct mutex mutex;
	struct bus_type___83 *bus;
	struct device_driver___83 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___83 power;
	struct dev_pm_domain___83 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___24 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___61 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___83 *class;
	const struct attribute_group___82 **groups;
	void (*release)(struct device___83 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct kobj_attribute___85 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___85 *, struct kobj_attribute___85 *, char *);
	ssize_t (*store)(struct kobject___85 *, struct kobj_attribute___85 *, const char *, size_t);
};

typedef void compound_page_dtor___88(struct page___91 *);

struct ucounts___76 {
	struct hlist_node node;
	struct user_namespace___76 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct audit_chunk___2;

struct audit_tree {
	refcount_t count;
	int goner;
	struct audit_chunk___2 *root;
	struct list_head chunks;
	struct list_head rules;
	struct list_head list;
	struct list_head same_root;
	struct callback_head head;
	char pathname[0];
};

struct kernfs_root___87;

struct kernfs_elem_dir___87 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___87 *root;
};

struct kernfs_syscall_ops___87;

struct kernfs_root___87 {
	struct kernfs_node___87 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___87 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___87 {
	struct kernfs_node___87 *target_kn;
};

struct kernfs_ops___87;

struct kernfs_elem_attr___87 {
	const struct kernfs_ops___87 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___87 *notify_next;
};

struct kernfs_node___87 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___87 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___87 dir;
		struct kernfs_elem_symlink___87 symlink;
		struct kernfs_elem_attr___87 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___87;

struct kernfs_ops___87 {
	int (*open)(struct kernfs_open_file___87 *);
	void (*release)(struct kernfs_open_file___87 *);
	int (*seq_show)(struct seq_file___84 *, void *);
	void * (*seq_start)(struct seq_file___84 *, loff_t *);
	void * (*seq_next)(struct seq_file___84 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___84 *, void *);
	ssize_t (*read)(struct kernfs_open_file___87 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___87 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___87 *, struct vm_area_struct___91 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___87 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___87 {
	int (*remount_fs)(struct kernfs_root___87 *, int *, char *);
	int (*show_options)(struct seq_file___84 *, struct kernfs_root___87 *);
	int (*mkdir)(struct kernfs_node___87 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___87 *);
	int (*rename)(struct kernfs_node___87 *, struct kernfs_node___87 *, const char *);
	int (*show_path)(struct seq_file___84 *, struct kernfs_node___87 *, struct kernfs_root___87 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___87 {
	struct kernfs_node___87 *kn;
	struct file___91 *file;
	struct seq_file___84 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___88 *vm_ops;
};

struct bin_attribute___82;

struct attribute_group___82 {
	const char *name;
	umode_t (*is_visible)(struct kobject___85 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___85 *, struct bin_attribute___82 *, int);
	struct attribute **attrs;
	struct bin_attribute___82 **bin_attrs;
};

struct bin_attribute___82 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___91 *, struct kobject___85 *, struct bin_attribute___82 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___91 *, struct kobject___85 *, struct bin_attribute___82 *, char *, loff_t, size_t);
	int (*mmap)(struct file___91 *, struct kobject___85 *, struct bin_attribute___82 *, struct vm_area_struct___91 *);
};

struct sysfs_ops___84 {
	ssize_t (*show)(struct kobject___85 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___85 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___84;

struct kset___84 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___85 kobj;
	const struct kset_uevent_ops___84 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___84 {
	void (*release)(struct kobject___85 *);
	const struct sysfs_ops___84 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___5 * (*child_ns_type)(struct kobject___85 *);
	const void * (*namespace)(struct kobject___85 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___84 {
	int (* const filter)(struct kset___84 *, struct kobject___85 *);
	const char * (* const name)(struct kset___84 *, struct kobject___85 *);
	int (* const uevent)(struct kset___84 *, struct kobject___85 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___83 {
	int (*prepare)(struct device___83 *);
	void (*complete)(struct device___83 *);
	int (*suspend)(struct device___83 *);
	int (*resume)(struct device___83 *);
	int (*freeze)(struct device___83 *);
	int (*thaw)(struct device___83 *);
	int (*poweroff)(struct device___83 *);
	int (*restore)(struct device___83 *);
	int (*suspend_late)(struct device___83 *);
	int (*resume_early)(struct device___83 *);
	int (*freeze_late)(struct device___83 *);
	int (*thaw_early)(struct device___83 *);
	int (*poweroff_late)(struct device___83 *);
	int (*restore_early)(struct device___83 *);
	int (*suspend_noirq)(struct device___83 *);
	int (*resume_noirq)(struct device___83 *);
	int (*freeze_noirq)(struct device___83 *);
	int (*thaw_noirq)(struct device___83 *);
	int (*poweroff_noirq)(struct device___83 *);
	int (*restore_noirq)(struct device___83 *);
	int (*runtime_suspend)(struct device___83 *);
	int (*runtime_resume)(struct device___83 *);
	int (*runtime_idle)(struct device___83 *);
};

struct dev_pm_domain___83 {
	struct dev_pm_ops___83 ops;
	void (*detach)(struct device___83 *, bool);
	int (*activate)(struct device___83 *);
	void (*sync)(struct device___83 *);
	void (*dismiss)(struct device___83 *);
};

struct bus_type___83 {
	const char *name;
	const char *dev_name;
	struct device___83 *dev_root;
	const struct attribute_group___82 **bus_groups;
	const struct attribute_group___82 **dev_groups;
	const struct attribute_group___82 **drv_groups;
	int (*match)(struct device___83 *, struct device_driver___83 *);
	int (*uevent)(struct device___83 *, struct kobj_uevent_env *);
	int (*probe)(struct device___83 *);
	int (*remove)(struct device___83 *);
	void (*shutdown)(struct device___83 *);
	int (*online)(struct device___83 *);
	int (*offline)(struct device___83 *);
	int (*suspend)(struct device___83 *, pm_message_t);
	int (*resume)(struct device___83 *);
	int (*num_vf)(struct device___83 *);
	int (*dma_configure)(struct device___83 *);
	const struct dev_pm_ops___83 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___83 {
	const char *name;
	struct bus_type___83 *bus;
	struct module___11 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___83 *);
	int (*remove)(struct device___83 *);
	void (*shutdown)(struct device___83 *);
	int (*suspend)(struct device___83 *, pm_message_t);
	int (*resume)(struct device___83 *);
	const struct attribute_group___82 **groups;
	const struct dev_pm_ops___83 *pm;
	void (*coredump)(struct device___83 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___83 {
	const char *name;
	const struct attribute_group___82 **groups;
	int (*uevent)(struct device___83 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___83 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___83 *);
	const struct dev_pm_ops___83 *pm;
};

struct class___83 {
	const char *name;
	struct module___11 *owner;
	const struct attribute_group___82 **class_groups;
	const struct attribute_group___82 **dev_groups;
	struct kobject___85 *dev_kobj;
	int (*dev_uevent)(struct device___83 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___83 *, umode_t *);
	void (*class_release)(struct class___83 *);
	void (*dev_release)(struct device___83 *);
	int (*shutdown_pre)(struct device___83 *);
	const struct kobj_ns_type_operations___5 *ns_type;
	const void * (*namespace)(struct device___83 *);
	const struct dev_pm_ops___83 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___24 {
	void * (*alloc)(struct device___83 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___83 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___83 *, struct vm_area_struct___91 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___83 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___83 *, struct page___91 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___83 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___83 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___83 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___83 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___83 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___83 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___83 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___83 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___83 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___83 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___83 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___83 *, u64);
	u64 (*get_required_mask)(struct device___83 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___61;

struct fwnode_handle___61 {
	struct fwnode_handle___61 *secondary;
	const struct fwnode_operations___61 *ops;
};

struct fwnode_reference_args___61;

struct fwnode_endpoint___61;

struct fwnode_operations___61 {
	struct fwnode_handle___61 * (*get)(struct fwnode_handle___61 *);
	void (*put)(struct fwnode_handle___61 *);
	bool (*device_is_available)(const struct fwnode_handle___61 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___61 *, const struct device___83 *);
	bool (*property_present)(const struct fwnode_handle___61 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___61 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___61 *, const char *, const char **, size_t);
	struct fwnode_handle___61 * (*get_parent)(const struct fwnode_handle___61 *);
	struct fwnode_handle___61 * (*get_next_child_node)(const struct fwnode_handle___61 *, struct fwnode_handle___61 *);
	struct fwnode_handle___61 * (*get_named_child_node)(const struct fwnode_handle___61 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___61 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___61 *);
	struct fwnode_handle___61 * (*graph_get_next_endpoint)(const struct fwnode_handle___61 *, struct fwnode_handle___61 *);
	struct fwnode_handle___61 * (*graph_get_remote_endpoint)(const struct fwnode_handle___61 *);
	struct fwnode_handle___61 * (*graph_get_port_parent)(struct fwnode_handle___61 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___61 *, struct fwnode_endpoint___61 *);
};

struct fwnode_endpoint___61 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___61 *local_fwnode;
};

struct fwnode_reference_args___61 {
	struct fwnode_handle___61 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___19;

struct pipe_buffer___19 {
	struct page___91 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___19 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___19 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___19 *, struct pipe_buffer___19 *);
	void (*release)(struct pipe_inode_info___19 *, struct pipe_buffer___19 *);
	int (*steal)(struct pipe_inode_info___19 *, struct pipe_buffer___19 *);
	union {
		bool (*get)(struct pipe_inode_info___19 *, struct pipe_buffer___19 *);
		struct {
			void (*get)(struct pipe_inode_info___19 *, struct pipe_buffer___19 *);
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
};

struct seq_operations___82 {
	void * (*start)(struct seq_file___84 *, loff_t *);
	void (*stop)(struct seq_file___84 *, void *);
	void * (*next)(struct seq_file___84 *, void *, loff_t *);
	int (*show)(struct seq_file___84 *, void *);
};

struct tty_operations___13 {
	struct tty_struct___13 * (*lookup)(struct tty_driver___13 *, struct file___91 *, int);
	int (*install)(struct tty_driver___13 *, struct tty_struct___13 *);
	void (*remove)(struct tty_driver___13 *, struct tty_struct___13 *);
	int (*open)(struct tty_struct___13 *, struct file___91 *);
	void (*close)(struct tty_struct___13 *, struct file___91 *);
	void (*shutdown)(struct tty_struct___13 *);
	void (*cleanup)(struct tty_struct___13 *);
	int (*write)(struct tty_struct___13 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___13 *, unsigned char);
	void (*flush_chars)(struct tty_struct___13 *);
	int (*write_room)(struct tty_struct___13 *);
	int (*chars_in_buffer)(struct tty_struct___13 *);
	int (*ioctl)(struct tty_struct___13 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___13 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___13 *, struct ktermios *);
	void (*throttle)(struct tty_struct___13 *);
	void (*unthrottle)(struct tty_struct___13 *);
	void (*stop)(struct tty_struct___13 *);
	void (*start)(struct tty_struct___13 *);
	void (*hangup)(struct tty_struct___13 *);
	int (*break_ctl)(struct tty_struct___13 *, int);
	void (*flush_buffer)(struct tty_struct___13 *);
	void (*set_ldisc)(struct tty_struct___13 *);
	void (*wait_until_sent)(struct tty_struct___13 *, int);
	void (*send_xchar)(struct tty_struct___13 *, char);
	int (*tiocmget)(struct tty_struct___13 *);
	int (*tiocmset)(struct tty_struct___13 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___13 *, struct winsize *);
	int (*set_termiox)(struct tty_struct___13 *, struct termiox *);
	int (*get_icount)(struct tty_struct___13 *, struct serial_icounter_struct *);
	void (*show_fdinfo)(struct tty_struct___13 *, struct seq_file___84 *);
	int (*poll_init)(struct tty_driver___13 *, int, char *);
	int (*poll_get_char)(struct tty_driver___13 *, int);
	void (*poll_put_char)(struct tty_driver___13 *, int, char);
	int (*proc_show)(struct seq_file___84 *, void *);
};

struct tty_driver___13 {
	int magic;
	struct kref kref;
	struct cdev___27 **cdevs;
	struct module___11 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___13 *other;
	struct tty_struct___13 **ttys;
	struct tty_port___13 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___13 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___13;

struct tty_port_client_operations___13;

struct tty_port___13 {
	struct tty_bufhead buf;
	struct tty_struct___13 *tty;
	struct tty_struct___13 *itty;
	const struct tty_port_operations___13 *ops;
	const struct tty_port_client_operations___13 *client_ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	unsigned char low_latency: 1;
	struct mutex mutex;
	struct mutex buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
	void *client_data;
};

struct tty_ldisc_ops___13 {
	int magic;
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___13 *);
	void (*close)(struct tty_struct___13 *);
	void (*flush_buffer)(struct tty_struct___13 *);
	ssize_t (*read)(struct tty_struct___13 *, struct file___91 *, unsigned char *, size_t);
	ssize_t (*write)(struct tty_struct___13 *, struct file___91 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___13 *, struct file___91 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___13 *, struct file___91 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___13 *, struct ktermios *);
	__poll_t (*poll)(struct tty_struct___13 *, struct file___91 *, struct poll_table_struct___6 *);
	int (*hangup)(struct tty_struct___13 *);
	void (*receive_buf)(struct tty_struct___13 *, const unsigned char *, char *, int);
	void (*write_wakeup)(struct tty_struct___13 *);
	void (*dcd_change)(struct tty_struct___13 *, unsigned int);
	int (*receive_buf2)(struct tty_struct___13 *, const unsigned char *, char *, int);
	struct module___11 *owner;
	int refcount;
};

struct tty_ldisc___13 {
	struct tty_ldisc_ops___13 *ops;
	struct tty_struct___13 *tty;
};

struct tty_port_operations___13 {
	int (*carrier_raised)(struct tty_port___13 *);
	void (*dtr_rts)(struct tty_port___13 *, int);
	void (*shutdown)(struct tty_port___13 *);
	int (*activate)(struct tty_port___13 *, struct tty_struct___13 *);
	void (*destruct)(struct tty_port___13 *);
};

struct tty_port_client_operations___13 {
	int (*receive_buf)(struct tty_port___13 *, const unsigned char *, const unsigned char *, size_t);
	void (*write_wakeup)(struct tty_port___13 *);
};

struct fsnotify_group___2;

struct fsnotify_iter_info___2;

struct fsnotify_mark___2;

struct fsnotify_event___2;

struct fsnotify_ops___2 {
	int (*handle_event)(struct fsnotify_group___2 *, struct inode___92 *, u32, const void *, int, const unsigned char *, u32, struct fsnotify_iter_info___2 *);
	void (*free_group_priv)(struct fsnotify_group___2 *);
	void (*freeing_mark)(struct fsnotify_mark___2 *, struct fsnotify_group___2 *);
	void (*free_event)(struct fsnotify_event___2 *);
	void (*free_mark)(struct fsnotify_mark___2 *);
};

struct inotify_group_private_data___2 {
	spinlock_t idr_lock;
	struct idr idr;
	struct ucounts___76 *ucounts;
};

struct fanotify_group_private_data___2 {
	struct list_head access_list;
	wait_queue_head_t access_waitq;
	int flags;
	int f_flags;
	unsigned int max_marks;
	struct user_struct___87 *user;
};

struct fsnotify_group___2 {
	const struct fsnotify_ops___2 *ops;
	refcount_t refcnt;
	spinlock_t notification_lock;
	struct list_head notification_list;
	wait_queue_head_t notification_waitq;
	unsigned int q_len;
	unsigned int max_events;
	unsigned int priority;
	bool shutdown;
	struct mutex mark_mutex;
	atomic_t num_marks;
	atomic_t user_waits;
	struct list_head marks_list;
	struct fasync_struct___90 *fsn_fa;
	struct fsnotify_event___2 *overflow_event;
	struct mem_cgroup___2 *memcg;
	union {
		void *private;
		struct inotify_group_private_data___2 inotify_data;
		struct fanotify_group_private_data___2 fanotify_data;
	};
};

struct fsnotify_iter_info___2 {
	struct fsnotify_mark___2 *marks[2];
	unsigned int report_mask;
	int srcu_idx;
};

struct fsnotify_mark___2 {
	__u32 mask;
	refcount_t refcnt;
	struct fsnotify_group___2 *group;
	struct list_head g_list;
	spinlock_t lock;
	struct hlist_node obj_list;
	struct fsnotify_mark_connector *connector;
	__u32 ignored_mask;
	unsigned int flags;
};

struct fsnotify_event___2 {
	struct list_head list;
	struct inode___92 *inode;
	u32 mask;
};

struct node___72 {
	struct list_head list;
	struct audit_tree *owner;
	unsigned int index;
};

struct audit_chunk___2 {
	struct list_head hash;
	struct fsnotify_mark___2 mark;
	struct list_head trees;
	int dead;
	int count;
	atomic_long_t refs;
	struct callback_head head;
	struct node___72 owners[0];
};

enum {
	HASH_SIZE = 128,
};

struct kprobe_blacklist_entry {
	struct list_head list;
	long unsigned int start_addr;
	long unsigned int end_addr;
};

struct kprobe_insn_page {
	struct list_head list;
	kprobe_opcode_t *insns;
	struct kprobe_insn_cache *cache;
	int nused;
	int ngarbage;
	char slot_used[0];
};

enum kprobe_slot_state {
	SLOT_CLEAN = 0,
	SLOT_DIRTY = 1,
	SLOT_USED = 2,
};

struct module___79;

struct file___92;

struct kiocb___92;

struct vm_area_struct___92;

struct inode___93;

struct file_lock___92;

struct page___92;

struct seq_file___85;

struct file_operations___92 {
	struct module___79 *owner;
	loff_t (*llseek)(struct file___92 *, loff_t, int);
	ssize_t (*read)(struct file___92 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___92 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___92 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___92 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___92 *, bool);
	int (*iterate)(struct file___92 *, struct dir_context *);
	int (*iterate_shared)(struct file___92 *, struct dir_context *);
	__poll_t (*poll)(struct file___92 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___92 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___92 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___92 *, struct vm_area_struct___92 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___93 *, struct file___92 *);
	int (*flush)(struct file___92 *, fl_owner_t);
	int (*release)(struct inode___93 *, struct file___92 *);
	int (*fsync)(struct file___92 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___92 *, int);
	int (*lock)(struct file___92 *, int, struct file_lock___92 *);
	ssize_t (*sendpage)(struct file___92 *, struct page___92 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___92 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___92 *, int, struct file_lock___92 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___92 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___92 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___92 *, long int, struct file_lock___92 **, void **);
	long int (*fallocate)(struct file___92 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___85 *, struct file___92 *);
	ssize_t (*copy_file_range)(struct file___92 *, loff_t, struct file___92 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___92 *, loff_t, struct file___92 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___92 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___91 {
	u64 seqnum;
	struct vm_area_struct___92 *vmas[4];
};

struct page_frag___91 {
	struct page___92 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___91;

struct pid___76;

struct cred___88;

struct nsproxy___85;

struct signal_struct___82;

struct vm_struct___66;

struct task_struct___92 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___92 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___91 *mm;
	struct mm_struct___91 *active_mm;
	struct vmacache___91 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___92 *real_parent;
	struct task_struct___92 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___92 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___76 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___76 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___76 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___88 *ptracer_cred;
	const struct cred___88 *real_cred;
	const struct cred___88 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___85 *nsproxy;
	struct signal_struct___82 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___92 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___15 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___91 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___92 *oom_reaper_list;
	struct vm_struct___66 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___56 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___76;

struct upid___76 {
	int nr;
	struct pid_namespace___76 *ns;
};

struct dentry___92;

struct pid_namespace___76 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___92 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___76 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___92 *proc_self;
	struct dentry___92 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___3 *user_ns;
	struct ucounts___2 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___7 ns;
};

struct pid___76 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___76 numbers[1];
};

struct secondary_data___92 {
	void *stack;
	struct task_struct___92 *task;
	long int status;
};

typedef struct page___92 *pgtable_t___91;

struct address_space___91;

struct dev_pagemap___89;

struct page___92 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___91 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___92 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___91 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___91 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___89 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct key___88;

struct user_struct___88 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___88 *uid_keyring;
	struct key___88 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___89;

struct vm_area_struct___92 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___92 *vm_next;
	struct vm_area_struct___92 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___91 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___89 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___92 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct rw_semaphore___92 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___92 *owner;
};

struct core_state___91;

struct mm_struct___91 {
	struct {
		struct vm_area_struct___92 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___92 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___92 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___91 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___92 *owner;
		struct user_namespace___3 *user_ns;
		struct file___92 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___91 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___88 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___88 *session_keyring;
	struct key___88 *process_keyring;
	struct key___88 *thread_keyring;
	struct key___88 *request_key_auth;
	void *security;
	struct user_struct___88 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct nsproxy___85 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___76 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct tty_struct___14;

struct signal_struct___82 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___92 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___92 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___76 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___76 *tty_old_pgrp;
	int leader;
	struct tty_struct___14 *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___91 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___76 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_struct___66 {
	struct vm_struct___66 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___92 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___82 {
	struct task_struct___92 task;
	long unsigned int stack[8192];
};

struct pglist_data___91;

struct lruvec___91 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___91 *pgdat;
};

struct zone___91 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___91 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___91 {
	struct zone___91 *zone;
	int zone_idx;
};

struct zonelist___91 {
	struct zoneref___91 _zonerefs[25];
};

struct pglist_data___91 {
	struct zone___91 node_zones[3];
	struct zonelist___91 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___92 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___92 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___91 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___91 {
	struct rw_semaphore___92 rwsem;
	struct notifier_block *head;
};

struct address_space_operations___91;

struct address_space___91 {
	struct inode___93 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___92 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___91 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___89)(struct vm_area_struct___92 *, long unsigned int, const struct page___92 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___89)(struct page___92 *, void *);

struct device___84;

struct dev_pagemap___89 {
	dev_page_fault_t___89 page_fault;
	dev_page_free_t___89 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___84 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___91 {
	struct vfsmount *mnt;
	struct dentry___92 *dentry;
};

struct fown_struct___76 {
	rwlock_t lock;
	struct pid___76 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___92 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___91 f_path;
	struct inode___93 *f_inode;
	const struct file_operations___92 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___76 f_owner;
	const struct cred___88 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___91 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___89;

struct vm_operations_struct___89 {
	void (*open)(struct vm_area_struct___92 *);
	void (*close)(struct vm_area_struct___92 *);
	int (*split)(struct vm_area_struct___92 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___92 *);
	vm_fault_t (*fault)(struct vm_fault___89 *);
	vm_fault_t (*huge_fault)(struct vm_fault___89 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___89 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___92 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___89 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___89 *);
	int (*access)(struct vm_area_struct___92 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___92 *);
	int (*set_policy)(struct vm_area_struct___92 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___92 *, long unsigned int);
	struct page___92 * (*find_special_page)(struct vm_area_struct___92 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___91 {
	struct task_struct___92 *task;
	struct core_thread___91 *next;
};

struct core_state___91 {
	atomic_t nr_threads;
	struct core_thread___91 dumper;
	struct completion startup;
};

struct vm_fault___89 {
	struct vm_area_struct___92 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___92 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___92 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___91 prealloc_pte;
};

struct kset___85;

struct kobj_type___85;

struct kernfs_node___88;

struct kobject___86 {
	const char *name;
	struct list_head entry;
	struct kobject___86 *parent;
	struct kset___85 *kset;
	struct kobj_type___85 *ktype;
	struct kernfs_node___88 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___84 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___84 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___84;

struct bus_type___84;

struct device_driver___84;

struct dev_pm_domain___84;

struct device_node___28;

struct fwnode_handle___62;

struct class___84;

struct attribute_group___83;

struct device___84 {
	struct device___84 *parent;
	struct device_private *p;
	struct kobject___86 kobj;
	const char *init_name;
	const struct device_type___84 *type;
	struct mutex mutex;
	struct bus_type___84 *bus;
	struct device_driver___84 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___84 power;
	struct dev_pm_domain___84 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___28 *of_node;
	struct fwnode_handle___62 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___84 *class;
	const struct attribute_group___83 **groups;
	void (*release)(struct device___84 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___91;

struct super_block___92;

struct dentry___92 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___92 *d_parent;
	struct qstr d_name;
	struct inode___93 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___91 *d_op;
	struct super_block___92 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___91;

struct block_device___92;

struct cdev___28;

struct inode___93 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___91 *i_op;
	struct super_block___92 *i_sb;
	struct address_space___91 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___92 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___92 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___91 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___92 *i_bdev;
		struct cdev___28 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___91 {
	int (*d_revalidate)(struct dentry___92 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___92 *, unsigned int);
	int (*d_hash)(const struct dentry___92 *, struct qstr *);
	int (*d_compare)(const struct dentry___92 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___92 *);
	int (*d_init)(struct dentry___92 *);
	void (*d_release)(struct dentry___92 *);
	void (*d_prune)(struct dentry___92 *);
	void (*d_iput)(struct dentry___92 *, struct inode___93 *);
	char * (*d_dname)(struct dentry___92 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___91 *);
	int (*d_manage)(const struct path___91 *, bool);
	struct dentry___92 * (*d_real)(struct dentry___92 *, const struct inode___93 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___91;

struct mem_dqinfo___91 {
	struct quota_format_type___91 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___91;

struct quota_info___91 {
	unsigned int flags;
	struct rw_semaphore___92 dqio_sem;
	struct inode___93 *files[3];
	struct mem_dqinfo___91 info[3];
	const struct quota_format_ops___91 *ops[3];
};

struct rcuwait___91 {
	struct task_struct___92 *task;
};

struct percpu_rw_semaphore___91 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___92 rw_sem;
	struct rcuwait___91 writer;
	int readers_block;
};

struct sb_writers___91 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___91 rw_sem[3];
};

struct file_system_type___91;

struct super_operations___91;

struct dquot_operations___91;

struct quotactl_ops___91;

struct super_block___92 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___91 *s_type;
	const struct super_operations___91 *s_op;
	const struct dquot_operations___91 *dq_op;
	const struct quotactl_ops___91 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___92 *s_root;
	struct rw_semaphore___92 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___92 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___91 s_dquot;
	struct sb_writers___91 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___91 *s_d_op;
	int cleancache_poolid;
	struct shrinker___33 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___92 {
	struct file___92 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___92 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___92 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___92 *ia_file;
};

struct dquot___91 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___92 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___91 {
	int qf_fmt_id;
	const struct quota_format_ops___91 *qf_ops;
	struct module___79 *qf_owner;
	struct quota_format_type___91 *qf_next;
};

struct quota_format_ops___91 {
	int (*check_quota_file)(struct super_block___92 *, int);
	int (*read_file_info)(struct super_block___92 *, int);
	int (*write_file_info)(struct super_block___92 *, int);
	int (*free_file_info)(struct super_block___92 *, int);
	int (*read_dqblk)(struct dquot___91 *);
	int (*commit_dqblk)(struct dquot___91 *);
	int (*release_dqblk)(struct dquot___91 *);
	int (*get_next_id)(struct super_block___92 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___91 {
	int (*write_dquot)(struct dquot___91 *);
	struct dquot___91 * (*alloc_dquot)(struct super_block___92 *, int);
	void (*destroy_dquot)(struct dquot___91 *);
	int (*acquire_dquot)(struct dquot___91 *);
	int (*release_dquot)(struct dquot___91 *);
	int (*mark_dirty)(struct dquot___91 *);
	int (*write_info)(struct super_block___92 *, int);
	qsize_t * (*get_reserved_space)(struct inode___93 *);
	int (*get_projid)(struct inode___93 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___93 *, qsize_t *);
	int (*get_next_id)(struct super_block___92 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___91 {
	int (*quota_on)(struct super_block___92 *, int, int, const struct path___91 *);
	int (*quota_off)(struct super_block___92 *, int);
	int (*quota_enable)(struct super_block___92 *, unsigned int);
	int (*quota_disable)(struct super_block___92 *, unsigned int);
	int (*quota_sync)(struct super_block___92 *, int);
	int (*set_info)(struct super_block___92 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___92 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___92 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___92 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___92 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___92 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___76 {
	struct kobject___86 kobj;
	struct module___79 *mod;
	struct kobject___86 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___76 {
	struct module___79 *mod;
	struct latch_tree_node node;
};

struct module_layout___76 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___76 mtn;
};

struct module_attribute___76;

struct kernel_param___76;

struct module___79 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___76 mkobj;
	struct module_attribute___76 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___86 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___76 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___76 core_layout;
	struct module_layout___76 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___91 {
	int (*writepage)(struct page___92 *, struct writeback_control___3 *);
	int (*readpage)(struct file___92 *, struct page___92 *);
	int (*writepages)(struct address_space___91 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___92 *);
	int (*readpages)(struct file___92 *, struct address_space___91 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___92 *, struct address_space___91 *, loff_t, unsigned int, unsigned int, struct page___92 **, void **);
	int (*write_end)(struct file___92 *, struct address_space___91 *, loff_t, unsigned int, unsigned int, struct page___92 *, void *);
	sector_t (*bmap)(struct address_space___91 *, sector_t);
	void (*invalidatepage)(struct page___92 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___92 *, gfp_t);
	void (*freepage)(struct page___92 *);
	ssize_t (*direct_IO)(struct kiocb___92 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___91 *, struct page___92 *, struct page___92 *, enum migrate_mode);
	bool (*isolate_page)(struct page___92 *, isolate_mode_t);
	void (*putback_page)(struct page___92 *);
	int (*launder_page)(struct page___92 *);
	int (*is_partially_uptodate)(struct page___92 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___92 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___91 *, struct page___92 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___92 *, sector_t *);
	void (*swap_deactivate)(struct file___92 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___92 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___93 *bd_inode;
	struct super_block___92 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___92 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___28 {
	struct kobject___86 kobj;
	struct module___79 *owner;
	const struct file_operations___92 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___91 {
	struct dentry___92 * (*lookup)(struct inode___93 *, struct dentry___92 *, unsigned int);
	const char * (*get_link)(struct dentry___92 *, struct inode___93 *, struct delayed_call *);
	int (*permission)(struct inode___93 *, int);
	struct posix_acl * (*get_acl)(struct inode___93 *, int);
	int (*readlink)(struct dentry___92 *, char *, int);
	int (*create)(struct inode___93 *, struct dentry___92 *, umode_t, bool);
	int (*link)(struct dentry___92 *, struct inode___93 *, struct dentry___92 *);
	int (*unlink)(struct inode___93 *, struct dentry___92 *);
	int (*symlink)(struct inode___93 *, struct dentry___92 *, const char *);
	int (*mkdir)(struct inode___93 *, struct dentry___92 *, umode_t);
	int (*rmdir)(struct inode___93 *, struct dentry___92 *);
	int (*mknod)(struct inode___93 *, struct dentry___92 *, umode_t, dev_t);
	int (*rename)(struct inode___93 *, struct dentry___92 *, struct inode___93 *, struct dentry___92 *, unsigned int);
	int (*setattr)(struct dentry___92 *, struct iattr___92 *);
	int (*getattr)(const struct path___91 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___92 *, char *, size_t);
	int (*fiemap)(struct inode___93 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___93 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___93 *, struct dentry___92 *, struct file___92 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___93 *, struct dentry___92 *, umode_t);
	int (*set_acl)(struct inode___93 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___91 {
	void (*fl_copy_lock)(struct file_lock___92 *, struct file_lock___92 *);
	void (*fl_release_private)(struct file_lock___92 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___91;

struct lock_manager_operations___91;

struct file_lock___92 {
	struct file_lock___92 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___92 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___91 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___91 *fl_ops;
	const struct lock_manager_operations___91 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___91 {
	int (*lm_compare_owner)(struct file_lock___92 *, struct file_lock___92 *);
	long unsigned int (*lm_owner_key)(struct file_lock___92 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___92 *);
	int (*lm_grant)(struct file_lock___92 *, int);
	bool (*lm_break)(struct file_lock___92 *);
	int (*lm_change)(struct file_lock___92 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___92 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___91 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___91 *fa_next;
	struct file___92 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___91 {
	const char *name;
	int fs_flags;
	struct dentry___92 * (*mount)(struct file_system_type___91 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___92 *);
	struct module___79 *owner;
	struct file_system_type___91 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___91 {
	struct inode___93 * (*alloc_inode)(struct super_block___92 *);
	void (*destroy_inode)(struct inode___93 *);
	void (*dirty_inode)(struct inode___93 *, int);
	int (*write_inode)(struct inode___93 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___93 *);
	void (*evict_inode)(struct inode___93 *);
	void (*put_super)(struct super_block___92 *);
	int (*sync_fs)(struct super_block___92 *, int);
	int (*freeze_super)(struct super_block___92 *);
	int (*freeze_fs)(struct super_block___92 *);
	int (*thaw_super)(struct super_block___92 *);
	int (*unfreeze_fs)(struct super_block___92 *);
	int (*statfs)(struct dentry___92 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___92 *, int *, char *);
	void (*umount_begin)(struct super_block___92 *);
	int (*show_options)(struct seq_file___85 *, struct dentry___92 *);
	int (*show_devname)(struct seq_file___85 *, struct dentry___92 *);
	int (*show_path)(struct seq_file___85 *, struct dentry___92 *);
	int (*show_stats)(struct seq_file___85 *, struct dentry___92 *);
	ssize_t (*quota_read)(struct super_block___92 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___92 *, int, const char *, size_t, loff_t);
	struct dquot___91 ** (*get_dquots)(struct inode___93 *);
	int (*bdev_try_to_free_page)(struct super_block___92 *, struct page___92 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___92 *, struct shrink_control___33 *);
	long int (*free_cached_objects)(struct super_block___92 *, struct shrink_control___33 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___83;

struct seq_file___85 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___83 *op;
	int poll_event;
	const struct file___92 *file;
	void *private;
};

struct kobj_attribute___86 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___86 *, struct kobj_attribute___86 *, char *);
	ssize_t (*store)(struct kobject___86 *, struct kobj_attribute___86 *, const char *, size_t);
};

typedef void compound_page_dtor___89(struct page___92 *);

struct kernfs_root___88;

struct kernfs_elem_dir___88 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___88 *root;
};

struct kernfs_syscall_ops___88;

struct kernfs_root___88 {
	struct kernfs_node___88 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___88 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___88 {
	struct kernfs_node___88 *target_kn;
};

struct kernfs_ops___88;

struct kernfs_elem_attr___88 {
	const struct kernfs_ops___88 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___88 *notify_next;
};

struct kernfs_node___88 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___88 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___88 dir;
		struct kernfs_elem_symlink___88 symlink;
		struct kernfs_elem_attr___88 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___88;

struct kernfs_ops___88 {
	int (*open)(struct kernfs_open_file___88 *);
	void (*release)(struct kernfs_open_file___88 *);
	int (*seq_show)(struct seq_file___85 *, void *);
	void * (*seq_start)(struct seq_file___85 *, loff_t *);
	void * (*seq_next)(struct seq_file___85 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___85 *, void *);
	ssize_t (*read)(struct kernfs_open_file___88 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___88 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___88 *, struct vm_area_struct___92 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___88 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___88 {
	int (*remount_fs)(struct kernfs_root___88 *, int *, char *);
	int (*show_options)(struct seq_file___85 *, struct kernfs_root___88 *);
	int (*mkdir)(struct kernfs_node___88 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___88 *);
	int (*rename)(struct kernfs_node___88 *, struct kernfs_node___88 *, const char *);
	int (*show_path)(struct seq_file___85 *, struct kernfs_node___88 *, struct kernfs_root___88 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___88 {
	struct kernfs_node___88 *kn;
	struct file___92 *file;
	struct seq_file___85 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___89 *vm_ops;
};

struct bin_attribute___83;

struct attribute_group___83 {
	const char *name;
	umode_t (*is_visible)(struct kobject___86 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___86 *, struct bin_attribute___83 *, int);
	struct attribute **attrs;
	struct bin_attribute___83 **bin_attrs;
};

struct bin_attribute___83 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___92 *, struct kobject___86 *, struct bin_attribute___83 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___92 *, struct kobject___86 *, struct bin_attribute___83 *, char *, loff_t, size_t);
	int (*mmap)(struct file___92 *, struct kobject___86 *, struct bin_attribute___83 *, struct vm_area_struct___92 *);
};

struct sysfs_ops___85 {
	ssize_t (*show)(struct kobject___86 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___86 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___85;

struct kset___85 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___86 kobj;
	const struct kset_uevent_ops___85 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___85 {
	void (*release)(struct kobject___86 *);
	const struct sysfs_ops___85 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___5 * (*child_ns_type)(struct kobject___86 *);
	const void * (*namespace)(struct kobject___86 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___85 {
	int (* const filter)(struct kset___85 *, struct kobject___86 *);
	const char * (* const name)(struct kset___85 *, struct kobject___86 *);
	int (* const uevent)(struct kset___85 *, struct kobject___86 *, struct kobj_uevent_env *);
};

struct fwnode_operations___62;

struct fwnode_handle___62 {
	struct fwnode_handle___62 *secondary;
	const struct fwnode_operations___62 *ops;
};

struct fwnode_reference_args___62;

struct fwnode_endpoint___62;

struct fwnode_operations___62 {
	struct fwnode_handle___62 * (*get)(struct fwnode_handle___62 *);
	void (*put)(struct fwnode_handle___62 *);
	bool (*device_is_available)(const struct fwnode_handle___62 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___62 *, const struct device___84 *);
	bool (*property_present)(const struct fwnode_handle___62 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___62 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___62 *, const char *, const char **, size_t);
	struct fwnode_handle___62 * (*get_parent)(const struct fwnode_handle___62 *);
	struct fwnode_handle___62 * (*get_next_child_node)(const struct fwnode_handle___62 *, struct fwnode_handle___62 *);
	struct fwnode_handle___62 * (*get_named_child_node)(const struct fwnode_handle___62 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___62 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___62 *);
	struct fwnode_handle___62 * (*graph_get_next_endpoint)(const struct fwnode_handle___62 *, struct fwnode_handle___62 *);
	struct fwnode_handle___62 * (*graph_get_remote_endpoint)(const struct fwnode_handle___62 *);
	struct fwnode_handle___62 * (*graph_get_port_parent)(struct fwnode_handle___62 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___62 *, struct fwnode_endpoint___62 *);
};

struct fwnode_endpoint___62 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___62 *local_fwnode;
};

struct fwnode_reference_args___62 {
	struct fwnode_handle___62 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct property___27 {
	char *name;
	int length;
	void *value;
	struct property___27 *next;
	long unsigned int _flags;
	struct bin_attribute___83 attr;
};

struct device_node___28 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___62 fwnode;
	struct property___27 *properties;
	struct property___27 *deadprops;
	struct device_node___28 *parent;
	struct device_node___28 *child;
	struct device_node___28 *sibling;
	struct kobject___86 kobj;
	long unsigned int _flags;
	void *data;
};

struct dev_pm_ops___84 {
	int (*prepare)(struct device___84 *);
	void (*complete)(struct device___84 *);
	int (*suspend)(struct device___84 *);
	int (*resume)(struct device___84 *);
	int (*freeze)(struct device___84 *);
	int (*thaw)(struct device___84 *);
	int (*poweroff)(struct device___84 *);
	int (*restore)(struct device___84 *);
	int (*suspend_late)(struct device___84 *);
	int (*resume_early)(struct device___84 *);
	int (*freeze_late)(struct device___84 *);
	int (*thaw_early)(struct device___84 *);
	int (*poweroff_late)(struct device___84 *);
	int (*restore_early)(struct device___84 *);
	int (*suspend_noirq)(struct device___84 *);
	int (*resume_noirq)(struct device___84 *);
	int (*freeze_noirq)(struct device___84 *);
	int (*thaw_noirq)(struct device___84 *);
	int (*poweroff_noirq)(struct device___84 *);
	int (*restore_noirq)(struct device___84 *);
	int (*runtime_suspend)(struct device___84 *);
	int (*runtime_resume)(struct device___84 *);
	int (*runtime_idle)(struct device___84 *);
};

struct dev_pm_domain___84 {
	struct dev_pm_ops___84 ops;
	void (*detach)(struct device___84 *, bool);
	int (*activate)(struct device___84 *);
	void (*sync)(struct device___84 *);
	void (*dismiss)(struct device___84 *);
};

struct bus_type___84 {
	const char *name;
	const char *dev_name;
	struct device___84 *dev_root;
	const struct attribute_group___83 **bus_groups;
	const struct attribute_group___83 **dev_groups;
	const struct attribute_group___83 **drv_groups;
	int (*match)(struct device___84 *, struct device_driver___84 *);
	int (*uevent)(struct device___84 *, struct kobj_uevent_env *);
	int (*probe)(struct device___84 *);
	int (*remove)(struct device___84 *);
	void (*shutdown)(struct device___84 *);
	int (*online)(struct device___84 *);
	int (*offline)(struct device___84 *);
	int (*suspend)(struct device___84 *, pm_message_t);
	int (*resume)(struct device___84 *);
	int (*num_vf)(struct device___84 *);
	int (*dma_configure)(struct device___84 *);
	const struct dev_pm_ops___84 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___84 {
	const char *name;
	struct bus_type___84 *bus;
	struct module___79 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___84 *);
	int (*remove)(struct device___84 *);
	void (*shutdown)(struct device___84 *);
	int (*suspend)(struct device___84 *, pm_message_t);
	int (*resume)(struct device___84 *);
	const struct attribute_group___83 **groups;
	const struct dev_pm_ops___84 *pm;
	void (*coredump)(struct device___84 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___84 {
	const char *name;
	const struct attribute_group___83 **groups;
	int (*uevent)(struct device___84 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___84 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___84 *);
	const struct dev_pm_ops___84 *pm;
};

struct class___84 {
	const char *name;
	struct module___79 *owner;
	const struct attribute_group___83 **class_groups;
	const struct attribute_group___83 **dev_groups;
	struct kobject___86 *dev_kobj;
	int (*dev_uevent)(struct device___84 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___84 *, umode_t *);
	void (*class_release)(struct class___84 *);
	void (*dev_release)(struct device___84 *);
	int (*shutdown_pre)(struct device___84 *);
	const struct kobj_ns_type_operations___5 *ns_type;
	const void * (*namespace)(struct device___84 *);
	const struct dev_pm_ops___84 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

typedef int (*key_restrict_link_func_t___88)(struct key___88 *, const struct key_type *, const union key_payload *, struct key___88 *);

struct key_restriction___88;

struct key___88 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___92 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___88 *restrict_link;
};

struct key_restriction___88 {
	key_restrict_link_func_t___88 check;
	struct key___88 *key;
	struct key_type *keytype;
};

struct seq_operations___83 {
	void * (*start)(struct seq_file___85 *, loff_t *);
	void (*stop)(struct seq_file___85 *, void *);
	void * (*next)(struct seq_file___85 *, void *, loff_t *);
	int (*show)(struct seq_file___85 *, void *);
};

struct tty_driver___14;

struct tty_operations___14 {
	struct tty_struct___14 * (*lookup)(struct tty_driver___14 *, struct file___92 *, int);
	int (*install)(struct tty_driver___14 *, struct tty_struct___14 *);
	void (*remove)(struct tty_driver___14 *, struct tty_struct___14 *);
	int (*open)(struct tty_struct___14 *, struct file___92 *);
	void (*close)(struct tty_struct___14 *, struct file___92 *);
	void (*shutdown)(struct tty_struct___14 *);
	void (*cleanup)(struct tty_struct___14 *);
	int (*write)(struct tty_struct___14 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___14 *, unsigned char);
	void (*flush_chars)(struct tty_struct___14 *);
	int (*write_room)(struct tty_struct___14 *);
	int (*chars_in_buffer)(struct tty_struct___14 *);
	int (*ioctl)(struct tty_struct___14 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___14 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___14 *, struct ktermios *);
	void (*throttle)(struct tty_struct___14 *);
	void (*unthrottle)(struct tty_struct___14 *);
	void (*stop)(struct tty_struct___14 *);
	void (*start)(struct tty_struct___14 *);
	void (*hangup)(struct tty_struct___14 *);
	int (*break_ctl)(struct tty_struct___14 *, int);
	void (*flush_buffer)(struct tty_struct___14 *);
	void (*set_ldisc)(struct tty_struct___14 *);
	void (*wait_until_sent)(struct tty_struct___14 *, int);
	void (*send_xchar)(struct tty_struct___14 *, char);
	int (*tiocmget)(struct tty_struct___14 *);
	int (*tiocmset)(struct tty_struct___14 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___14 *, struct winsize *);
	int (*set_termiox)(struct tty_struct___14 *, struct termiox *);
	int (*get_icount)(struct tty_struct___14 *, struct serial_icounter_struct *);
	void (*show_fdinfo)(struct tty_struct___14 *, struct seq_file___85 *);
	int (*poll_init)(struct tty_driver___14 *, int, char *);
	int (*poll_get_char)(struct tty_driver___14 *, int);
	void (*poll_put_char)(struct tty_driver___14 *, int, char);
	int (*proc_show)(struct seq_file___85 *, void *);
};

struct tty_ldisc___14;

struct tty_port___14;

struct tty_struct___14 {
	int magic;
	struct kref kref;
	struct device___84 *dev;
	struct tty_driver___14 *driver;
	const struct tty_operations___14 *ops;
	int index;
	struct ld_semaphore ldisc_sem;
	struct tty_ldisc___14 *ldisc;
	struct mutex atomic_write_lock;
	struct mutex legacy_mutex;
	struct mutex throttle_mutex;
	struct rw_semaphore___92 termios_rwsem;
	struct mutex winsize_mutex;
	spinlock_t ctrl_lock;
	spinlock_t flow_lock;
	struct ktermios termios;
	struct ktermios termios_locked;
	struct termiox *termiox;
	char name[64];
	struct pid___76 *pgrp;
	struct pid___76 *session;
	long unsigned int flags;
	int count;
	struct winsize winsize;
	long unsigned int stopped: 1;
	long unsigned int flow_stopped: 1;
	int: 30;
	long unsigned int unused: 62;
	int hw_stopped;
	long unsigned int ctrl_status: 8;
	long unsigned int packet: 1;
	int: 23;
	long unsigned int unused_ctrl: 55;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___14 *link;
	struct fasync_struct___91 *fasync;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	spinlock_t files_lock;
	struct list_head tty_files;
	int closing;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___14 *port;
};

struct tty_driver___14 {
	int magic;
	struct kref kref;
	struct cdev___28 **cdevs;
	struct module___79 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___14 *other;
	struct tty_struct___14 **ttys;
	struct tty_port___14 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___14 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___14;

struct tty_port_client_operations___14;

struct tty_port___14 {
	struct tty_bufhead buf;
	struct tty_struct___14 *tty;
	struct tty_struct___14 *itty;
	const struct tty_port_operations___14 *ops;
	const struct tty_port_client_operations___14 *client_ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	unsigned char low_latency: 1;
	struct mutex mutex;
	struct mutex buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
	void *client_data;
};

struct tty_ldisc_ops___14 {
	int magic;
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___14 *);
	void (*close)(struct tty_struct___14 *);
	void (*flush_buffer)(struct tty_struct___14 *);
	ssize_t (*read)(struct tty_struct___14 *, struct file___92 *, unsigned char *, size_t);
	ssize_t (*write)(struct tty_struct___14 *, struct file___92 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___14 *, struct file___92 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___14 *, struct file___92 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___14 *, struct ktermios *);
	__poll_t (*poll)(struct tty_struct___14 *, struct file___92 *, struct poll_table_struct___6 *);
	int (*hangup)(struct tty_struct___14 *);
	void (*receive_buf)(struct tty_struct___14 *, const unsigned char *, char *, int);
	void (*write_wakeup)(struct tty_struct___14 *);
	void (*dcd_change)(struct tty_struct___14 *, unsigned int);
	int (*receive_buf2)(struct tty_struct___14 *, const unsigned char *, char *, int);
	struct module___79 *owner;
	int refcount;
};

struct tty_ldisc___14 {
	struct tty_ldisc_ops___14 *ops;
	struct tty_struct___14 *tty;
};

struct tty_port_operations___14 {
	int (*carrier_raised)(struct tty_port___14 *);
	void (*dtr_rts)(struct tty_port___14 *, int);
	void (*shutdown)(struct tty_port___14 *);
	int (*activate)(struct tty_port___14 *, struct tty_struct___14 *);
	void (*destruct)(struct tty_port___14 *);
};

struct tty_port_client_operations___14 {
	int (*receive_buf)(struct tty_port___14 *, const unsigned char *, const unsigned char *, size_t);
	void (*write_wakeup)(struct tty_port___14 *);
};

struct uart_port___2;

struct uart_ops___2 {
	unsigned int (*tx_empty)(struct uart_port___2 *);
	void (*set_mctrl)(struct uart_port___2 *, unsigned int);
	unsigned int (*get_mctrl)(struct uart_port___2 *);
	void (*stop_tx)(struct uart_port___2 *);
	void (*start_tx)(struct uart_port___2 *);
	void (*throttle)(struct uart_port___2 *);
	void (*unthrottle)(struct uart_port___2 *);
	void (*send_xchar)(struct uart_port___2 *, char);
	void (*stop_rx)(struct uart_port___2 *);
	void (*enable_ms)(struct uart_port___2 *);
	void (*break_ctl)(struct uart_port___2 *, int);
	int (*startup)(struct uart_port___2 *);
	void (*shutdown)(struct uart_port___2 *);
	void (*flush_buffer)(struct uart_port___2 *);
	void (*set_termios)(struct uart_port___2 *, struct ktermios *, struct ktermios *);
	void (*set_ldisc)(struct uart_port___2 *, struct ktermios *);
	void (*pm)(struct uart_port___2 *, unsigned int, unsigned int);
	const char * (*type)(struct uart_port___2 *);
	void (*release_port)(struct uart_port___2 *);
	int (*request_port)(struct uart_port___2 *);
	void (*config_port)(struct uart_port___2 *, int);
	int (*verify_port)(struct uart_port___2 *, struct serial_struct *);
	int (*ioctl)(struct uart_port___2 *, unsigned int, long unsigned int);
	int (*poll_init)(struct uart_port___2 *);
	void (*poll_put_char)(struct uart_port___2 *, unsigned char);
	int (*poll_get_char)(struct uart_port___2 *);
};

struct uart_state___2;

struct console___4;

struct uart_port___2 {
	spinlock_t lock;
	long unsigned int iobase;
	unsigned char *membase;
	unsigned int (*serial_in)(struct uart_port___2 *, int);
	void (*serial_out)(struct uart_port___2 *, int, int);
	void (*set_termios)(struct uart_port___2 *, struct ktermios *, struct ktermios *);
	void (*set_ldisc)(struct uart_port___2 *, struct ktermios *);
	unsigned int (*get_mctrl)(struct uart_port___2 *);
	void (*set_mctrl)(struct uart_port___2 *, unsigned int);
	int (*startup)(struct uart_port___2 *);
	void (*shutdown)(struct uart_port___2 *);
	void (*throttle)(struct uart_port___2 *);
	void (*unthrottle)(struct uart_port___2 *);
	int (*handle_irq)(struct uart_port___2 *);
	void (*pm)(struct uart_port___2 *, unsigned int, unsigned int);
	void (*handle_break)(struct uart_port___2 *);
	int (*rs485_config)(struct uart_port___2 *, struct serial_rs485 *);
	unsigned int irq;
	long unsigned int irqflags;
	unsigned int uartclk;
	unsigned int fifosize;
	unsigned char x_char;
	unsigned char regshift;
	unsigned char iotype;
	unsigned char quirks;
	unsigned int read_status_mask;
	unsigned int ignore_status_mask;
	struct uart_state___2 *state;
	struct uart_icount icount;
	struct console___4 *cons;
	long unsigned int sysrq;
	upf_t flags;
	upstat_t status;
	int hw_stopped;
	unsigned int mctrl;
	unsigned int timeout;
	unsigned int type;
	const struct uart_ops___2 *ops;
	unsigned int custom_divisor;
	unsigned int line;
	unsigned int minor;
	resource_size_t mapbase;
	resource_size_t mapsize;
	struct device___84 *dev;
	unsigned char hub6;
	unsigned char suspended;
	unsigned char unused[2];
	const char *name;
	struct attribute_group___83 *attr_group;
	const struct attribute_group___83 **tty_groups;
	struct serial_rs485 rs485;
	void *private_data;
};

struct uart_state___2 {
	struct tty_port___14 port;
	enum uart_pm_state pm_state;
	struct circ_buf xmit;
	atomic_t refcount;
	wait_queue_head_t remove_wait;
	struct uart_port___2 *uart_port;
};

struct console___4 {
	char name[16];
	void (*write)(struct console___4 *, const char *, unsigned int);
	int (*read)(struct console___4 *, char *, unsigned int);
	struct tty_driver___14 * (*device)(struct console___4 *, int *);
	void (*unblank)();
	int (*setup)(struct console___4 *, char *);
	int (*match)(struct console___4 *, char *, int, char *);
	short int flags;
	short int index;
	int cflag;
	void *data;
	struct console___4 *next;
};

struct earlycon_device___2 {
	struct console___4 *con;
	struct uart_port___2 port;
	char options[16];
	unsigned int baud;
};

struct earlycon_id___2 {
	char name[15];
	char name_term;
	char compatible[128];
	int (*setup)(struct earlycon_device___2 *, const char *);
};

struct consw___10 {
	struct module___79 *owner;
	const char * (*con_startup)();
	void (*con_init)(struct vc_data *, int);
	void (*con_deinit)(struct vc_data *);
	void (*con_clear)(struct vc_data *, int, int, int, int);
	void (*con_putc)(struct vc_data *, int, int, int);
	void (*con_putcs)(struct vc_data *, const short unsigned int *, int, int, int);
	void (*con_cursor)(struct vc_data *, int);
	bool (*con_scroll)(struct vc_data *, unsigned int, unsigned int, enum con_scroll, unsigned int);
	int (*con_switch)(struct vc_data *);
	int (*con_blank)(struct vc_data *, int, int);
	int (*con_font_set)(struct vc_data *, struct console_font *, unsigned int);
	int (*con_font_get)(struct vc_data *, struct console_font *);
	int (*con_font_default)(struct vc_data *, struct console_font *, char *);
	int (*con_font_copy)(struct vc_data *, int);
	int (*con_resize)(struct vc_data *, unsigned int, unsigned int, unsigned int);
	void (*con_set_palette)(struct vc_data *, const unsigned char *);
	void (*con_scrolldelta)(struct vc_data *, int);
	int (*con_set_origin)(struct vc_data *);
	void (*con_save_screen)(struct vc_data *);
	u8 (*con_build_attr)(struct vc_data *, u8, u8, u8, u8, u8, u8);
	void (*con_invert_region)(struct vc_data *, u16 *, int);
	u16 * (*con_screen_pos)(struct vc_data *, int);
	long unsigned int (*con_getxy)(struct vc_data *, long unsigned int, int *, int *);
	void (*con_flush_scrollback)(struct vc_data *);
	int (*con_debug_enter)(struct vc_data *);
	int (*con_debug_leave)(struct vc_data *);
};

struct kernel_param_ops___76 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___76 *);
	int (*get)(char *, const struct kernel_param___76 *);
	void (*free)(void *);
};

struct kparam_array___76;

struct kernel_param___76 {
	const char *name;
	struct module___79 *mod;
	const struct kernel_param_ops___76 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___76 *arr;
	};
};

struct kparam_array___76 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___76 *ops;
	void *elem;
};

struct module_attribute___76 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___76 *, struct module_kobject___76 *, char *);
	ssize_t (*store)(struct module_attribute___76 *, struct module_kobject___76 *, const char *, size_t);
	void (*setup)(struct module___79 *, const char *);
	int (*test)(struct module___79 *);
	void (*free)(struct module___79 *);
};

enum {
	KDB_NOT_INITIALIZED = 0,
	KDB_INIT_EARLY = 1,
	KDB_INIT_FULL = 2,
};

struct kgdb_state {
	int ex_vector;
	int signo;
	int err_code;
	int cpu;
	int pass_exception;
	long unsigned int thr_query;
	long unsigned int threadid;
	long int kgdb_usethreadid;
	struct pt_regs *linux_regs;
	atomic_t *send_ready;
};

struct debuggerinfo_struct {
	void *debuggerinfo;
	struct task_struct___92 *task;
	int exception_state;
	int ret_state;
	int irq_depth;
	int enter_kgdb;
};

struct file___93;

struct kiocb___93;

struct vm_area_struct___93;

struct inode___94;

struct file_lock___93;

struct page___93;

struct seq_file___86;

struct file_operations___93 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___93 *, loff_t, int);
	ssize_t (*read)(struct file___93 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___93 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___93 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___93 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___93 *, bool);
	int (*iterate)(struct file___93 *, struct dir_context *);
	int (*iterate_shared)(struct file___93 *, struct dir_context *);
	__poll_t (*poll)(struct file___93 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___93 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___93 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___93 *, struct vm_area_struct___93 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___94 *, struct file___93 *);
	int (*flush)(struct file___93 *, fl_owner_t);
	int (*release)(struct inode___94 *, struct file___93 *);
	int (*fsync)(struct file___93 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___93 *, int);
	int (*lock)(struct file___93 *, int, struct file_lock___93 *);
	ssize_t (*sendpage)(struct file___93 *, struct page___93 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___93 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___93 *, int, struct file_lock___93 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___93 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___93 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___93 *, long int, struct file_lock___93 **, void **);
	long int (*fallocate)(struct file___93 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___86 *, struct file___93 *);
	ssize_t (*copy_file_range)(struct file___93 *, loff_t, struct file___93 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___93 *, loff_t, struct file___93 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___93 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___92 {
	u64 seqnum;
	struct vm_area_struct___93 *vmas[4];
};

struct page_frag___92 {
	struct page___93 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___92;

struct pid___77;

struct cred___89;

struct nsproxy___86;

struct signal_struct___83;

struct task_struct___93 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___93 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___92 *mm;
	struct mm_struct___92 *active_mm;
	struct vmacache___92 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___93 *real_parent;
	struct task_struct___93 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___93 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___77 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___77 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___77 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___89 *ptracer_cred;
	const struct cred___89 *real_cred;
	const struct cred___89 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___86 *nsproxy;
	struct signal_struct___83 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___93 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___15 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___92 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___93 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___56 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct key___89;

struct user_struct___89 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___89 *uid_keyring;
	struct key___89 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct pid_namespace___77;

struct upid___77 {
	int nr;
	struct pid_namespace___77 *ns;
};

struct dentry___93;

struct pid_namespace___77 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___93 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___77 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___93 *proc_self;
	struct dentry___93 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___3 *user_ns;
	struct ucounts___2 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___7 ns;
};

struct pid___77 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___77 numbers[1];
};

struct secondary_data___93 {
	void *stack;
	struct task_struct___93 *task;
	long int status;
};

typedef struct page___93 *pgtable_t___92;

struct address_space___92;

struct dev_pagemap___90;

struct page___93 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___92 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___93 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___92 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___92 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___90 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct vm_operations_struct___90;

struct vm_area_struct___93 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___93 *vm_next;
	struct vm_area_struct___93 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___92 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___90 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___93 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct rw_semaphore___93 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___93 *owner;
};

struct core_state___92;

struct mm_struct___92 {
	struct {
		struct vm_area_struct___93 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___93 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___93 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___92 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___93 *owner;
		struct user_namespace___3 *user_ns;
		struct file___93 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___92 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___89 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___89 *session_keyring;
	struct key___89 *process_keyring;
	struct key___89 *thread_keyring;
	struct key___89 *request_key_auth;
	void *security;
	struct user_struct___89 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct nsproxy___86 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___77 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct tty_struct___15;

struct signal_struct___83 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___93 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___93 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___77 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___77 *tty_old_pgrp;
	int leader;
	struct tty_struct___15 *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___92 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___77 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

union thread_union___83 {
	struct task_struct___93 task;
	long unsigned int stack[8192];
};

typedef int (*key_restrict_link_func_t___89)(struct key___89 *, const struct key_type *, const union key_payload *, struct key___89 *);

struct key_restriction___89;

struct key___89 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___93 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___89 *restrict_link;
};

struct key_restriction___89 {
	key_restrict_link_func_t___89 check;
	struct key___89 *key;
	struct key_type *keytype;
};

struct device___85;

struct tty_driver___15;

struct tty_operations___15;

struct tty_ldisc___15;

struct fasync_struct___92;

struct tty_port___15;

struct tty_struct___15 {
	int magic;
	struct kref kref;
	struct device___85 *dev;
	struct tty_driver___15 *driver;
	const struct tty_operations___15 *ops;
	int index;
	struct ld_semaphore ldisc_sem;
	struct tty_ldisc___15 *ldisc;
	struct mutex atomic_write_lock;
	struct mutex legacy_mutex;
	struct mutex throttle_mutex;
	struct rw_semaphore___93 termios_rwsem;
	struct mutex winsize_mutex;
	spinlock_t ctrl_lock;
	spinlock_t flow_lock;
	struct ktermios termios;
	struct ktermios termios_locked;
	struct termiox *termiox;
	char name[64];
	struct pid___77 *pgrp;
	struct pid___77 *session;
	long unsigned int flags;
	int count;
	struct winsize winsize;
	long unsigned int stopped: 1;
	long unsigned int flow_stopped: 1;
	int: 30;
	long unsigned int unused: 62;
	int hw_stopped;
	long unsigned int ctrl_status: 8;
	long unsigned int packet: 1;
	int: 23;
	long unsigned int unused_ctrl: 55;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___15 *link;
	struct fasync_struct___92 *fasync;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	spinlock_t files_lock;
	struct list_head tty_files;
	int closing;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___15 *port;
};

struct pglist_data___92;

struct lruvec___92 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___92 *pgdat;
};

struct zone___92 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___92 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___92 {
	struct zone___92 *zone;
	int zone_idx;
};

struct zonelist___92 {
	struct zoneref___92 _zonerefs[25];
};

struct pglist_data___92 {
	struct zone___92 node_zones[3];
	struct zonelist___92 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___93 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___93 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___92 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___92 {
	struct rw_semaphore___93 rwsem;
	struct notifier_block *head;
};

struct address_space_operations___92;

struct address_space___92 {
	struct inode___94 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___93 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___92 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___90)(struct vm_area_struct___93 *, long unsigned int, const struct page___93 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___90)(struct page___93 *, void *);

struct dev_pagemap___90 {
	dev_page_fault_t___90 page_fault;
	dev_page_free_t___90 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___85 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___92 {
	struct vfsmount *mnt;
	struct dentry___93 *dentry;
};

struct fown_struct___77 {
	rwlock_t lock;
	struct pid___77 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___93 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___92 f_path;
	struct inode___94 *f_inode;
	const struct file_operations___93 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___77 f_owner;
	const struct cred___89 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___92 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___90;

struct vm_operations_struct___90 {
	void (*open)(struct vm_area_struct___93 *);
	void (*close)(struct vm_area_struct___93 *);
	int (*split)(struct vm_area_struct___93 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___93 *);
	vm_fault_t (*fault)(struct vm_fault___90 *);
	vm_fault_t (*huge_fault)(struct vm_fault___90 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___90 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___93 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___90 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___90 *);
	int (*access)(struct vm_area_struct___93 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___93 *);
	int (*set_policy)(struct vm_area_struct___93 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___93 *, long unsigned int);
	struct page___93 * (*find_special_page)(struct vm_area_struct___93 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___92 {
	struct task_struct___93 *task;
	struct core_thread___92 *next;
};

struct core_state___92 {
	atomic_t nr_threads;
	struct core_thread___92 dumper;
	struct completion startup;
};

struct vm_fault___90 {
	struct vm_area_struct___93 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___93 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___93 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___92 prealloc_pte;
};

struct kset___86;

struct kobj_type___86;

struct kernfs_node___89;

struct kobject___87 {
	const char *name;
	struct list_head entry;
	struct kobject___87 *parent;
	struct kset___86 *kset;
	struct kobj_type___86 *ktype;
	struct kernfs_node___89 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___85 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___85 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___85;

struct bus_type___85;

struct device_driver___85;

struct dev_pm_domain___85;

struct class___85;

struct attribute_group___84;

struct device___85 {
	struct device___85 *parent;
	struct device_private *p;
	struct kobject___87 kobj;
	const char *init_name;
	const struct device_type___85 *type;
	struct mutex mutex;
	struct bus_type___85 *bus;
	struct device_driver___85 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___85 power;
	struct dev_pm_domain___85 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___85 *class;
	const struct attribute_group___84 **groups;
	void (*release)(struct device___85 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___92;

struct super_block___93;

struct dentry___93 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___93 *d_parent;
	struct qstr d_name;
	struct inode___94 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___92 *d_op;
	struct super_block___93 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___92;

struct block_device___93;

struct cdev___29;

struct inode___94 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___92 *i_op;
	struct super_block___93 *i_sb;
	struct address_space___92 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___93 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___93 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___92 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___93 *i_bdev;
		struct cdev___29 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___92 {
	int (*d_revalidate)(struct dentry___93 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___93 *, unsigned int);
	int (*d_hash)(const struct dentry___93 *, struct qstr *);
	int (*d_compare)(const struct dentry___93 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___93 *);
	int (*d_init)(struct dentry___93 *);
	void (*d_release)(struct dentry___93 *);
	void (*d_prune)(struct dentry___93 *);
	void (*d_iput)(struct dentry___93 *, struct inode___94 *);
	char * (*d_dname)(struct dentry___93 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___92 *);
	int (*d_manage)(const struct path___92 *, bool);
	struct dentry___93 * (*d_real)(struct dentry___93 *, const struct inode___94 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___92;

struct mem_dqinfo___92 {
	struct quota_format_type___92 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___92;

struct quota_info___92 {
	unsigned int flags;
	struct rw_semaphore___93 dqio_sem;
	struct inode___94 *files[3];
	struct mem_dqinfo___92 info[3];
	const struct quota_format_ops___92 *ops[3];
};

struct rcuwait___92 {
	struct task_struct___93 *task;
};

struct percpu_rw_semaphore___92 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___93 rw_sem;
	struct rcuwait___92 writer;
	int readers_block;
};

struct sb_writers___92 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___92 rw_sem[3];
};

struct file_system_type___92;

struct super_operations___92;

struct dquot_operations___92;

struct quotactl_ops___92;

struct super_block___93 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___92 *s_type;
	const struct super_operations___92 *s_op;
	const struct dquot_operations___92 *dq_op;
	const struct quotactl_ops___92 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___93 *s_root;
	struct rw_semaphore___93 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___93 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___92 s_dquot;
	struct sb_writers___92 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___92 *s_d_op;
	int cleancache_poolid;
	struct shrinker___33 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___93 {
	struct file___93 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___93 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___93 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___93 *ia_file;
};

struct dquot___92 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___93 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___92 {
	int qf_fmt_id;
	const struct quota_format_ops___92 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___92 *qf_next;
};

struct quota_format_ops___92 {
	int (*check_quota_file)(struct super_block___93 *, int);
	int (*read_file_info)(struct super_block___93 *, int);
	int (*write_file_info)(struct super_block___93 *, int);
	int (*free_file_info)(struct super_block___93 *, int);
	int (*read_dqblk)(struct dquot___92 *);
	int (*commit_dqblk)(struct dquot___92 *);
	int (*release_dqblk)(struct dquot___92 *);
	int (*get_next_id)(struct super_block___93 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___92 {
	int (*write_dquot)(struct dquot___92 *);
	struct dquot___92 * (*alloc_dquot)(struct super_block___93 *, int);
	void (*destroy_dquot)(struct dquot___92 *);
	int (*acquire_dquot)(struct dquot___92 *);
	int (*release_dquot)(struct dquot___92 *);
	int (*mark_dirty)(struct dquot___92 *);
	int (*write_info)(struct super_block___93 *, int);
	qsize_t * (*get_reserved_space)(struct inode___94 *);
	int (*get_projid)(struct inode___94 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___94 *, qsize_t *);
	int (*get_next_id)(struct super_block___93 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___92 {
	int (*quota_on)(struct super_block___93 *, int, int, const struct path___92 *);
	int (*quota_off)(struct super_block___93 *, int);
	int (*quota_enable)(struct super_block___93 *, unsigned int);
	int (*quota_disable)(struct super_block___93 *, unsigned int);
	int (*quota_sync)(struct super_block___93 *, int);
	int (*set_info)(struct super_block___93 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___93 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___93 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___93 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___93 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___93 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___92 {
	int (*writepage)(struct page___93 *, struct writeback_control___3 *);
	int (*readpage)(struct file___93 *, struct page___93 *);
	int (*writepages)(struct address_space___92 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___93 *);
	int (*readpages)(struct file___93 *, struct address_space___92 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___93 *, struct address_space___92 *, loff_t, unsigned int, unsigned int, struct page___93 **, void **);
	int (*write_end)(struct file___93 *, struct address_space___92 *, loff_t, unsigned int, unsigned int, struct page___93 *, void *);
	sector_t (*bmap)(struct address_space___92 *, sector_t);
	void (*invalidatepage)(struct page___93 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___93 *, gfp_t);
	void (*freepage)(struct page___93 *);
	ssize_t (*direct_IO)(struct kiocb___93 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___92 *, struct page___93 *, struct page___93 *, enum migrate_mode);
	bool (*isolate_page)(struct page___93 *, isolate_mode_t);
	void (*putback_page)(struct page___93 *);
	int (*launder_page)(struct page___93 *);
	int (*is_partially_uptodate)(struct page___93 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___93 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___92 *, struct page___93 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___93 *, sector_t *);
	void (*swap_deactivate)(struct file___93 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___93 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___94 *bd_inode;
	struct super_block___93 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___93 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___29 {
	struct kobject___87 kobj;
	struct module___11 *owner;
	const struct file_operations___93 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___92 {
	struct dentry___93 * (*lookup)(struct inode___94 *, struct dentry___93 *, unsigned int);
	const char * (*get_link)(struct dentry___93 *, struct inode___94 *, struct delayed_call *);
	int (*permission)(struct inode___94 *, int);
	struct posix_acl * (*get_acl)(struct inode___94 *, int);
	int (*readlink)(struct dentry___93 *, char *, int);
	int (*create)(struct inode___94 *, struct dentry___93 *, umode_t, bool);
	int (*link)(struct dentry___93 *, struct inode___94 *, struct dentry___93 *);
	int (*unlink)(struct inode___94 *, struct dentry___93 *);
	int (*symlink)(struct inode___94 *, struct dentry___93 *, const char *);
	int (*mkdir)(struct inode___94 *, struct dentry___93 *, umode_t);
	int (*rmdir)(struct inode___94 *, struct dentry___93 *);
	int (*mknod)(struct inode___94 *, struct dentry___93 *, umode_t, dev_t);
	int (*rename)(struct inode___94 *, struct dentry___93 *, struct inode___94 *, struct dentry___93 *, unsigned int);
	int (*setattr)(struct dentry___93 *, struct iattr___93 *);
	int (*getattr)(const struct path___92 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___93 *, char *, size_t);
	int (*fiemap)(struct inode___94 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___94 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___94 *, struct dentry___93 *, struct file___93 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___94 *, struct dentry___93 *, umode_t);
	int (*set_acl)(struct inode___94 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___92 {
	void (*fl_copy_lock)(struct file_lock___93 *, struct file_lock___93 *);
	void (*fl_release_private)(struct file_lock___93 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___92;

struct file_lock___93 {
	struct file_lock___93 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___93 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___92 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___92 *fl_ops;
	const struct lock_manager_operations___92 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___92 {
	int (*lm_compare_owner)(struct file_lock___93 *, struct file_lock___93 *);
	long unsigned int (*lm_owner_key)(struct file_lock___93 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___93 *);
	int (*lm_grant)(struct file_lock___93 *, int);
	bool (*lm_break)(struct file_lock___93 *);
	int (*lm_change)(struct file_lock___93 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___93 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___92 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___92 *fa_next;
	struct file___93 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___92 {
	const char *name;
	int fs_flags;
	struct dentry___93 * (*mount)(struct file_system_type___92 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___93 *);
	struct module___11 *owner;
	struct file_system_type___92 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___92 {
	struct inode___94 * (*alloc_inode)(struct super_block___93 *);
	void (*destroy_inode)(struct inode___94 *);
	void (*dirty_inode)(struct inode___94 *, int);
	int (*write_inode)(struct inode___94 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___94 *);
	void (*evict_inode)(struct inode___94 *);
	void (*put_super)(struct super_block___93 *);
	int (*sync_fs)(struct super_block___93 *, int);
	int (*freeze_super)(struct super_block___93 *);
	int (*freeze_fs)(struct super_block___93 *);
	int (*thaw_super)(struct super_block___93 *);
	int (*unfreeze_fs)(struct super_block___93 *);
	int (*statfs)(struct dentry___93 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___93 *, int *, char *);
	void (*umount_begin)(struct super_block___93 *);
	int (*show_options)(struct seq_file___86 *, struct dentry___93 *);
	int (*show_devname)(struct seq_file___86 *, struct dentry___93 *);
	int (*show_path)(struct seq_file___86 *, struct dentry___93 *);
	int (*show_stats)(struct seq_file___86 *, struct dentry___93 *);
	ssize_t (*quota_read)(struct super_block___93 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___93 *, int, const char *, size_t, loff_t);
	struct dquot___92 ** (*get_dquots)(struct inode___94 *);
	int (*bdev_try_to_free_page)(struct super_block___93 *, struct page___93 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___93 *, struct shrink_control___33 *);
	long int (*free_cached_objects)(struct super_block___93 *, struct shrink_control___33 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___84;

struct seq_file___86 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___84 *op;
	int poll_event;
	const struct file___93 *file;
	void *private;
};

struct kobj_attribute___87 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___87 *, struct kobj_attribute___87 *, char *);
	ssize_t (*store)(struct kobject___87 *, struct kobj_attribute___87 *, const char *, size_t);
};

typedef void compound_page_dtor___90(struct page___93 *);

struct kernfs_root___89;

struct kernfs_elem_dir___89 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___89 *root;
};

struct kernfs_syscall_ops___89;

struct kernfs_root___89 {
	struct kernfs_node___89 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___89 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___89 {
	struct kernfs_node___89 *target_kn;
};

struct kernfs_ops___89;

struct kernfs_elem_attr___89 {
	const struct kernfs_ops___89 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___89 *notify_next;
};

struct kernfs_node___89 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___89 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___89 dir;
		struct kernfs_elem_symlink___89 symlink;
		struct kernfs_elem_attr___89 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___89;

struct kernfs_ops___89 {
	int (*open)(struct kernfs_open_file___89 *);
	void (*release)(struct kernfs_open_file___89 *);
	int (*seq_show)(struct seq_file___86 *, void *);
	void * (*seq_start)(struct seq_file___86 *, loff_t *);
	void * (*seq_next)(struct seq_file___86 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___86 *, void *);
	ssize_t (*read)(struct kernfs_open_file___89 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___89 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___89 *, struct vm_area_struct___93 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___89 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___89 {
	int (*remount_fs)(struct kernfs_root___89 *, int *, char *);
	int (*show_options)(struct seq_file___86 *, struct kernfs_root___89 *);
	int (*mkdir)(struct kernfs_node___89 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___89 *);
	int (*rename)(struct kernfs_node___89 *, struct kernfs_node___89 *, const char *);
	int (*show_path)(struct seq_file___86 *, struct kernfs_node___89 *, struct kernfs_root___89 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___89 {
	struct kernfs_node___89 *kn;
	struct file___93 *file;
	struct seq_file___86 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___90 *vm_ops;
};

struct bin_attribute___84;

struct attribute_group___84 {
	const char *name;
	umode_t (*is_visible)(struct kobject___87 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___87 *, struct bin_attribute___84 *, int);
	struct attribute **attrs;
	struct bin_attribute___84 **bin_attrs;
};

struct bin_attribute___84 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___93 *, struct kobject___87 *, struct bin_attribute___84 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___93 *, struct kobject___87 *, struct bin_attribute___84 *, char *, loff_t, size_t);
	int (*mmap)(struct file___93 *, struct kobject___87 *, struct bin_attribute___84 *, struct vm_area_struct___93 *);
};

struct sysfs_ops___86 {
	ssize_t (*show)(struct kobject___87 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___87 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___86;

struct kset___86 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___87 kobj;
	const struct kset_uevent_ops___86 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___86 {
	void (*release)(struct kobject___87 *);
	const struct sysfs_ops___86 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___5 * (*child_ns_type)(struct kobject___87 *);
	const void * (*namespace)(struct kobject___87 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___86 {
	int (* const filter)(struct kset___86 *, struct kobject___87 *);
	const char * (* const name)(struct kset___86 *, struct kobject___87 *);
	int (* const uevent)(struct kset___86 *, struct kobject___87 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___85 {
	int (*prepare)(struct device___85 *);
	void (*complete)(struct device___85 *);
	int (*suspend)(struct device___85 *);
	int (*resume)(struct device___85 *);
	int (*freeze)(struct device___85 *);
	int (*thaw)(struct device___85 *);
	int (*poweroff)(struct device___85 *);
	int (*restore)(struct device___85 *);
	int (*suspend_late)(struct device___85 *);
	int (*resume_early)(struct device___85 *);
	int (*freeze_late)(struct device___85 *);
	int (*thaw_early)(struct device___85 *);
	int (*poweroff_late)(struct device___85 *);
	int (*restore_early)(struct device___85 *);
	int (*suspend_noirq)(struct device___85 *);
	int (*resume_noirq)(struct device___85 *);
	int (*freeze_noirq)(struct device___85 *);
	int (*thaw_noirq)(struct device___85 *);
	int (*poweroff_noirq)(struct device___85 *);
	int (*restore_noirq)(struct device___85 *);
	int (*runtime_suspend)(struct device___85 *);
	int (*runtime_resume)(struct device___85 *);
	int (*runtime_idle)(struct device___85 *);
};

struct dev_pm_domain___85 {
	struct dev_pm_ops___85 ops;
	void (*detach)(struct device___85 *, bool);
	int (*activate)(struct device___85 *);
	void (*sync)(struct device___85 *);
	void (*dismiss)(struct device___85 *);
};

struct bus_type___85 {
	const char *name;
	const char *dev_name;
	struct device___85 *dev_root;
	const struct attribute_group___84 **bus_groups;
	const struct attribute_group___84 **dev_groups;
	const struct attribute_group___84 **drv_groups;
	int (*match)(struct device___85 *, struct device_driver___85 *);
	int (*uevent)(struct device___85 *, struct kobj_uevent_env *);
	int (*probe)(struct device___85 *);
	int (*remove)(struct device___85 *);
	void (*shutdown)(struct device___85 *);
	int (*online)(struct device___85 *);
	int (*offline)(struct device___85 *);
	int (*suspend)(struct device___85 *, pm_message_t);
	int (*resume)(struct device___85 *);
	int (*num_vf)(struct device___85 *);
	int (*dma_configure)(struct device___85 *);
	const struct dev_pm_ops___85 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___85 {
	const char *name;
	struct bus_type___85 *bus;
	struct module___11 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___85 *);
	int (*remove)(struct device___85 *);
	void (*shutdown)(struct device___85 *);
	int (*suspend)(struct device___85 *, pm_message_t);
	int (*resume)(struct device___85 *);
	const struct attribute_group___84 **groups;
	const struct dev_pm_ops___85 *pm;
	void (*coredump)(struct device___85 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___85 {
	const char *name;
	const struct attribute_group___84 **groups;
	int (*uevent)(struct device___85 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___85 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___85 *);
	const struct dev_pm_ops___85 *pm;
};

struct class___85 {
	const char *name;
	struct module___11 *owner;
	const struct attribute_group___84 **class_groups;
	const struct attribute_group___84 **dev_groups;
	struct kobject___87 *dev_kobj;
	int (*dev_uevent)(struct device___85 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___85 *, umode_t *);
	void (*class_release)(struct class___85 *);
	void (*dev_release)(struct device___85 *);
	int (*shutdown_pre)(struct device___85 *);
	const struct kobj_ns_type_operations___5 *ns_type;
	const void * (*namespace)(struct device___85 *);
	const struct dev_pm_ops___85 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct seq_operations___84 {
	void * (*start)(struct seq_file___86 *, loff_t *);
	void (*stop)(struct seq_file___86 *, void *);
	void * (*next)(struct seq_file___86 *, void *, loff_t *);
	int (*show)(struct seq_file___86 *, void *);
};

struct tty_operations___15 {
	struct tty_struct___15 * (*lookup)(struct tty_driver___15 *, struct file___93 *, int);
	int (*install)(struct tty_driver___15 *, struct tty_struct___15 *);
	void (*remove)(struct tty_driver___15 *, struct tty_struct___15 *);
	int (*open)(struct tty_struct___15 *, struct file___93 *);
	void (*close)(struct tty_struct___15 *, struct file___93 *);
	void (*shutdown)(struct tty_struct___15 *);
	void (*cleanup)(struct tty_struct___15 *);
	int (*write)(struct tty_struct___15 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___15 *, unsigned char);
	void (*flush_chars)(struct tty_struct___15 *);
	int (*write_room)(struct tty_struct___15 *);
	int (*chars_in_buffer)(struct tty_struct___15 *);
	int (*ioctl)(struct tty_struct___15 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___15 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___15 *, struct ktermios *);
	void (*throttle)(struct tty_struct___15 *);
	void (*unthrottle)(struct tty_struct___15 *);
	void (*stop)(struct tty_struct___15 *);
	void (*start)(struct tty_struct___15 *);
	void (*hangup)(struct tty_struct___15 *);
	int (*break_ctl)(struct tty_struct___15 *, int);
	void (*flush_buffer)(struct tty_struct___15 *);
	void (*set_ldisc)(struct tty_struct___15 *);
	void (*wait_until_sent)(struct tty_struct___15 *, int);
	void (*send_xchar)(struct tty_struct___15 *, char);
	int (*tiocmget)(struct tty_struct___15 *);
	int (*tiocmset)(struct tty_struct___15 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___15 *, struct winsize *);
	int (*set_termiox)(struct tty_struct___15 *, struct termiox *);
	int (*get_icount)(struct tty_struct___15 *, struct serial_icounter_struct *);
	void (*show_fdinfo)(struct tty_struct___15 *, struct seq_file___86 *);
	int (*poll_init)(struct tty_driver___15 *, int, char *);
	int (*poll_get_char)(struct tty_driver___15 *, int);
	void (*poll_put_char)(struct tty_driver___15 *, int, char);
	int (*proc_show)(struct seq_file___86 *, void *);
};

struct tty_driver___15 {
	int magic;
	struct kref kref;
	struct cdev___29 **cdevs;
	struct module___11 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___15 *other;
	struct tty_struct___15 **ttys;
	struct tty_port___15 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___15 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___15;

struct tty_port_client_operations___15;

struct tty_port___15 {
	struct tty_bufhead buf;
	struct tty_struct___15 *tty;
	struct tty_struct___15 *itty;
	const struct tty_port_operations___15 *ops;
	const struct tty_port_client_operations___15 *client_ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	unsigned char low_latency: 1;
	struct mutex mutex;
	struct mutex buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
	void *client_data;
};

struct tty_ldisc_ops___15 {
	int magic;
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___15 *);
	void (*close)(struct tty_struct___15 *);
	void (*flush_buffer)(struct tty_struct___15 *);
	ssize_t (*read)(struct tty_struct___15 *, struct file___93 *, unsigned char *, size_t);
	ssize_t (*write)(struct tty_struct___15 *, struct file___93 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___15 *, struct file___93 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___15 *, struct file___93 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___15 *, struct ktermios *);
	__poll_t (*poll)(struct tty_struct___15 *, struct file___93 *, struct poll_table_struct___6 *);
	int (*hangup)(struct tty_struct___15 *);
	void (*receive_buf)(struct tty_struct___15 *, const unsigned char *, char *, int);
	void (*write_wakeup)(struct tty_struct___15 *);
	void (*dcd_change)(struct tty_struct___15 *, unsigned int);
	int (*receive_buf2)(struct tty_struct___15 *, const unsigned char *, char *, int);
	struct module___11 *owner;
	int refcount;
};

struct tty_ldisc___15 {
	struct tty_ldisc_ops___15 *ops;
	struct tty_struct___15 *tty;
};

struct tty_port_operations___15 {
	int (*carrier_raised)(struct tty_port___15 *);
	void (*dtr_rts)(struct tty_port___15 *, int);
	void (*shutdown)(struct tty_port___15 *);
	int (*activate)(struct tty_port___15 *, struct tty_struct___15 *);
	void (*destruct)(struct tty_port___15 *);
};

struct tty_port_client_operations___15 {
	int (*receive_buf)(struct tty_port___15 *, const unsigned char *, const unsigned char *, size_t);
	void (*write_wakeup)(struct tty_port___15 *);
};

struct uart_port___3;

struct uart_ops___3 {
	unsigned int (*tx_empty)(struct uart_port___3 *);
	void (*set_mctrl)(struct uart_port___3 *, unsigned int);
	unsigned int (*get_mctrl)(struct uart_port___3 *);
	void (*stop_tx)(struct uart_port___3 *);
	void (*start_tx)(struct uart_port___3 *);
	void (*throttle)(struct uart_port___3 *);
	void (*unthrottle)(struct uart_port___3 *);
	void (*send_xchar)(struct uart_port___3 *, char);
	void (*stop_rx)(struct uart_port___3 *);
	void (*enable_ms)(struct uart_port___3 *);
	void (*break_ctl)(struct uart_port___3 *, int);
	int (*startup)(struct uart_port___3 *);
	void (*shutdown)(struct uart_port___3 *);
	void (*flush_buffer)(struct uart_port___3 *);
	void (*set_termios)(struct uart_port___3 *, struct ktermios *, struct ktermios *);
	void (*set_ldisc)(struct uart_port___3 *, struct ktermios *);
	void (*pm)(struct uart_port___3 *, unsigned int, unsigned int);
	const char * (*type)(struct uart_port___3 *);
	void (*release_port)(struct uart_port___3 *);
	int (*request_port)(struct uart_port___3 *);
	void (*config_port)(struct uart_port___3 *, int);
	int (*verify_port)(struct uart_port___3 *, struct serial_struct *);
	int (*ioctl)(struct uart_port___3 *, unsigned int, long unsigned int);
	int (*poll_init)(struct uart_port___3 *);
	void (*poll_put_char)(struct uart_port___3 *, unsigned char);
	int (*poll_get_char)(struct uart_port___3 *);
};

struct uart_state___3;

struct uart_port___3 {
	spinlock_t lock;
	long unsigned int iobase;
	unsigned char *membase;
	unsigned int (*serial_in)(struct uart_port___3 *, int);
	void (*serial_out)(struct uart_port___3 *, int, int);
	void (*set_termios)(struct uart_port___3 *, struct ktermios *, struct ktermios *);
	void (*set_ldisc)(struct uart_port___3 *, struct ktermios *);
	unsigned int (*get_mctrl)(struct uart_port___3 *);
	void (*set_mctrl)(struct uart_port___3 *, unsigned int);
	int (*startup)(struct uart_port___3 *);
	void (*shutdown)(struct uart_port___3 *);
	void (*throttle)(struct uart_port___3 *);
	void (*unthrottle)(struct uart_port___3 *);
	int (*handle_irq)(struct uart_port___3 *);
	void (*pm)(struct uart_port___3 *, unsigned int, unsigned int);
	void (*handle_break)(struct uart_port___3 *);
	int (*rs485_config)(struct uart_port___3 *, struct serial_rs485 *);
	unsigned int irq;
	long unsigned int irqflags;
	unsigned int uartclk;
	unsigned int fifosize;
	unsigned char x_char;
	unsigned char regshift;
	unsigned char iotype;
	unsigned char quirks;
	unsigned int read_status_mask;
	unsigned int ignore_status_mask;
	struct uart_state___3 *state;
	struct uart_icount icount;
	struct console___2 *cons;
	long unsigned int sysrq;
	upf_t flags;
	upstat_t status;
	int hw_stopped;
	unsigned int mctrl;
	unsigned int timeout;
	unsigned int type;
	const struct uart_ops___3 *ops;
	unsigned int custom_divisor;
	unsigned int line;
	unsigned int minor;
	resource_size_t mapbase;
	resource_size_t mapsize;
	struct device___85 *dev;
	unsigned char hub6;
	unsigned char suspended;
	unsigned char unused[2];
	const char *name;
	struct attribute_group___84 *attr_group;
	const struct attribute_group___84 **tty_groups;
	struct serial_rs485 rs485;
	void *private_data;
};

struct uart_state___3 {
	struct tty_port___15 port;
	enum uart_pm_state pm_state;
	struct circ_buf xmit;
	atomic_t refcount;
	wait_queue_head_t remove_wait;
	struct uart_port___3 *uart_port;
};

struct earlycon_device___3 {
	struct console___2 *con;
	struct uart_port___3 port;
	char options[16];
	unsigned int baud;
};

struct earlycon_id___3 {
	char name[15];
	char name_term;
	char compatible[128];
	int (*setup)(struct earlycon_device___3 *, const char *);
};

struct debuggerinfo_struct___2 {
	void *debuggerinfo;
	struct task_struct___93 *task;
	int exception_state;
	int ret_state;
	int irq_depth;
	int enter_kgdb;
};

struct module___80;

struct file___94;

struct kiocb___94;

struct vm_area_struct___94;

struct inode___95;

struct file_lock___94;

struct page___94;

struct file_operations___94 {
	struct module___80 *owner;
	loff_t (*llseek)(struct file___94 *, loff_t, int);
	ssize_t (*read)(struct file___94 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___94 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___94 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___94 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___94 *, bool);
	int (*iterate)(struct file___94 *, struct dir_context *);
	int (*iterate_shared)(struct file___94 *, struct dir_context *);
	__poll_t (*poll)(struct file___94 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___94 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___94 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___94 *, struct vm_area_struct___94 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___95 *, struct file___94 *);
	int (*flush)(struct file___94 *, fl_owner_t);
	int (*release)(struct inode___95 *, struct file___94 *);
	int (*fsync)(struct file___94 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___94 *, int);
	int (*lock)(struct file___94 *, int, struct file_lock___94 *);
	ssize_t (*sendpage)(struct file___94 *, struct page___94 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___94 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___94 *, int, struct file_lock___94 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___94 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___94 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___94 *, long int, struct file_lock___94 **, void **);
	long int (*fallocate)(struct file___94 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___94 *);
	ssize_t (*copy_file_range)(struct file___94 *, loff_t, struct file___94 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___94 *, loff_t, struct file___94 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___94 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___93 {
	u64 seqnum;
	struct vm_area_struct___94 *vmas[4];
};

struct page_frag___93 {
	struct page___94 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___93;

struct pid___78;

struct cred___90;

struct nsproxy___87;

struct signal_struct___84;

struct task_struct___94 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___94 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___93 *mm;
	struct mm_struct___93 *active_mm;
	struct vmacache___93 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___94 *real_parent;
	struct task_struct___94 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___94 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___78 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___78 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___78 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___90 *ptracer_cred;
	const struct cred___90 *real_cred;
	const struct cred___90 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___87 *nsproxy;
	struct signal_struct___84 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___94 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___15 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___93 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___94 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___56 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___94 *pgtable_t___93;

struct address_space___93;

struct dev_pagemap___91;

struct page___94 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___93 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___94 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___93 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___93 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___91 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___93;

struct lruvec___93 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___93 *pgdat;
};

struct zone___93 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___93 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___93 {
	struct zone___93 *zone;
	int zone_idx;
};

struct zonelist___93 {
	struct zoneref___93 _zonerefs[25];
};

struct pglist_data___93 {
	struct zone___93 node_zones[3];
	struct zonelist___93 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___94 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___94 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___93 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___94 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___94 *owner;
};

struct secondary_data___94 {
	void *stack;
	struct task_struct___94 *task;
	long int status;
};

struct blocking_notifier_head___93 {
	struct rw_semaphore___94 rwsem;
	struct notifier_block *head;
};

struct dentry___94;

struct path___93 {
	struct vfsmount *mnt;
	struct dentry___94 *dentry;
};

struct fown_struct___78 {
	rwlock_t lock;
	struct pid___78 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___94 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___93 f_path;
	struct inode___95 *f_inode;
	const struct file_operations___94 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___78 f_owner;
	const struct cred___90 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___93 *f_mapping;
	errseq_t f_wb_err;
};

struct key___90;

struct user_struct___90;

struct cred___90 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___90 *session_keyring;
	struct key___90 *process_keyring;
	struct key___90 *thread_keyring;
	struct key___90 *request_key_auth;
	void *security;
	struct user_struct___90 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___90;

struct kernfs_elem_dir___90 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___90 *root;
};

struct kernfs_node___90;

struct kernfs_syscall_ops___90;

struct kernfs_root___90 {
	struct kernfs_node___90 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___90 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___90 {
	struct kernfs_node___90 *target_kn;
};

struct kernfs_ops___90;

struct kernfs_elem_attr___90 {
	const struct kernfs_ops___90 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___90 *notify_next;
};

struct kernfs_node___90 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___90 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___90 dir;
		struct kernfs_elem_symlink___90 symlink;
		struct kernfs_elem_attr___90 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___90;

struct kernfs_ops___90 {
	int (*open)(struct kernfs_open_file___90 *);
	void (*release)(struct kernfs_open_file___90 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___90 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___90 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___90 *, struct vm_area_struct___94 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___90 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___90 {
	int (*remount_fs)(struct kernfs_root___90 *, int *, char *);
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___90 *);
	int (*mkdir)(struct kernfs_node___90 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___90 *);
	int (*rename)(struct kernfs_node___90 *, struct kernfs_node___90 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___90 *, struct kernfs_root___90 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_operations_struct___91;

struct kernfs_open_file___90 {
	struct kernfs_node___90 *kn;
	struct file___94 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___91 *vm_ops;
};

struct vm_fault___91;

struct vm_operations_struct___91 {
	void (*open)(struct vm_area_struct___94 *);
	void (*close)(struct vm_area_struct___94 *);
	int (*split)(struct vm_area_struct___94 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___94 *);
	vm_fault_t (*fault)(struct vm_fault___91 *);
	vm_fault_t (*huge_fault)(struct vm_fault___91 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___91 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___94 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___91 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___91 *);
	int (*access)(struct vm_area_struct___94 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___94 *);
	int (*set_policy)(struct vm_area_struct___94 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___94 *, long unsigned int);
	struct page___94 * (*find_special_page)(struct vm_area_struct___94 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_area_struct___94 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___94 *vm_next;
	struct vm_area_struct___94 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___93 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___91 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___94 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___87;

struct kobj_type___87;

struct kobject___88 {
	const char *name;
	struct list_head entry;
	struct kobject___88 *parent;
	struct kset___87 *kset;
	struct kobj_type___87 *ktype;
	struct kernfs_node___90 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sysfs_ops___87 {
	ssize_t (*show)(struct kobject___88 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___88 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___87;

struct kset___87 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___88 kobj;
	const struct kset_uevent_ops___87 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___87 {
	void (*release)(struct kobject___88 *);
	const struct sysfs_ops___87 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___5 * (*child_ns_type)(struct kobject___88 *);
	const void * (*namespace)(struct kobject___88 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___87 {
	int (* const filter)(struct kset___87 *, struct kobject___88 *);
	const char * (* const name)(struct kset___87 *, struct kobject___88 *);
	int (* const uevent)(struct kset___87 *, struct kobject___88 *, struct kobj_uevent_env *);
};

struct kobj_attribute___88 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___88 *, struct kobj_attribute___88 *, char *);
	ssize_t (*store)(struct kobject___88 *, struct kobj_attribute___88 *, const char *, size_t);
};

struct kernel_param___77;

struct kernel_param_ops___77 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___77 *);
	int (*get)(char *, const struct kernel_param___77 *);
	void (*free)(void *);
};

struct kparam_array___77;

struct kernel_param___77 {
	const char *name;
	struct module___80 *mod;
	const struct kernel_param_ops___77 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___77 *arr;
	};
};

struct kparam_array___77 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___77 *ops;
	void *elem;
};

struct module_kobject___77 {
	struct kobject___88 kobj;
	struct module___80 *mod;
	struct kobject___88 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___77 {
	struct module___80 *mod;
	struct latch_tree_node node;
};

struct module_layout___77 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___77 mtn;
};

struct module_attribute___77;

struct module___80 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___77 mkobj;
	struct module_attribute___77 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___88 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___77 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___77 core_layout;
	struct module_layout___77 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___77 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___77 *, struct module_kobject___77 *, char *);
	ssize_t (*store)(struct module_attribute___77 *, struct module_kobject___77 *, const char *, size_t);
	void (*setup)(struct module___80 *, const char *);
	int (*test)(struct module___80 *);
	void (*free)(struct module___80 *);
};

struct consw___11 {
	struct module___80 *owner;
	const char * (*con_startup)();
	void (*con_init)(struct vc_data *, int);
	void (*con_deinit)(struct vc_data *);
	void (*con_clear)(struct vc_data *, int, int, int, int);
	void (*con_putc)(struct vc_data *, int, int, int);
	void (*con_putcs)(struct vc_data *, const short unsigned int *, int, int, int);
	void (*con_cursor)(struct vc_data *, int);
	bool (*con_scroll)(struct vc_data *, unsigned int, unsigned int, enum con_scroll, unsigned int);
	int (*con_switch)(struct vc_data *);
	int (*con_blank)(struct vc_data *, int, int);
	int (*con_font_set)(struct vc_data *, struct console_font *, unsigned int);
	int (*con_font_get)(struct vc_data *, struct console_font *);
	int (*con_font_default)(struct vc_data *, struct console_font *, char *);
	int (*con_font_copy)(struct vc_data *, int);
	int (*con_resize)(struct vc_data *, unsigned int, unsigned int, unsigned int);
	void (*con_set_palette)(struct vc_data *, const unsigned char *);
	void (*con_scrolldelta)(struct vc_data *, int);
	int (*con_set_origin)(struct vc_data *);
	void (*con_save_screen)(struct vc_data *);
	u8 (*con_build_attr)(struct vc_data *, u8, u8, u8, u8, u8, u8);
	void (*con_invert_region)(struct vc_data *, u16 *, int);
	u16 * (*con_screen_pos)(struct vc_data *, int);
	long unsigned int (*con_getxy)(struct vc_data *, long unsigned int, int *, int *);
	void (*con_flush_scrollback)(struct vc_data *);
	int (*con_debug_enter)(struct vc_data *);
	int (*con_debug_leave)(struct vc_data *);
};

struct pid_namespace___78;

struct upid___78 {
	int nr;
	struct pid_namespace___78 *ns;
};

struct pid_namespace___78 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___94 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___78 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___94 *proc_self;
	struct dentry___94 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___3 *user_ns;
	struct ucounts___2 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___7 ns;
};

struct pid___78 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___78 numbers[1];
};

struct user_struct___90 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___90 *uid_keyring;
	struct key___90 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___93;

struct mm_struct___93 {
	struct {
		struct vm_area_struct___94 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___94 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___94 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___93 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___94 *owner;
		struct user_namespace___3 *user_ns;
		struct file___94 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___93 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct nsproxy___87 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___78 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct signal_struct___84 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___94 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___94 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___78 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___78 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___93 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___78 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

union thread_union___84 {
	struct task_struct___94 task;
	long unsigned int stack[8192];
};

typedef int (*key_restrict_link_func_t___90)(struct key___90 *, const struct key_type *, const union key_payload *, struct key___90 *);

struct key_restriction___90;

struct key___90 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___94 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___90 *restrict_link;
};

struct key_restriction___90 {
	key_restrict_link_func_t___90 check;
	struct key___90 *key;
	struct key_type *keytype;
};

struct address_space_operations___93;

struct address_space___93 {
	struct inode___95 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___94 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___93 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___91)(struct vm_area_struct___94 *, long unsigned int, const struct page___94 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___91)(struct page___94 *, void *);

struct dev_pagemap___91 {
	dev_page_fault_t___91 page_fault;
	dev_page_free_t___91 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___6 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___93 {
	struct task_struct___94 *task;
	struct core_thread___93 *next;
};

struct core_state___93 {
	atomic_t nr_threads;
	struct core_thread___93 dumper;
	struct completion startup;
};

struct vm_fault___91 {
	struct vm_area_struct___94 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___94 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___94 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___93 prealloc_pte;
};

struct dentry_operations___93;

struct super_block___94;

struct dentry___94 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___94 *d_parent;
	struct qstr d_name;
	struct inode___95 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___93 *d_op;
	struct super_block___94 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___93;

struct block_device___94;

struct inode___95 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___93 *i_op;
	struct super_block___94 *i_sb;
	struct address_space___93 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___94 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___94 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___93 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___94 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___93 {
	int (*d_revalidate)(struct dentry___94 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___94 *, unsigned int);
	int (*d_hash)(const struct dentry___94 *, struct qstr *);
	int (*d_compare)(const struct dentry___94 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___94 *);
	int (*d_init)(struct dentry___94 *);
	void (*d_release)(struct dentry___94 *);
	void (*d_prune)(struct dentry___94 *);
	void (*d_iput)(struct dentry___94 *, struct inode___95 *);
	char * (*d_dname)(struct dentry___94 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___93 *);
	int (*d_manage)(const struct path___93 *, bool);
	struct dentry___94 * (*d_real)(struct dentry___94 *, const struct inode___95 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___93;

struct mem_dqinfo___93 {
	struct quota_format_type___93 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___93;

struct quota_info___93 {
	unsigned int flags;
	struct rw_semaphore___94 dqio_sem;
	struct inode___95 *files[3];
	struct mem_dqinfo___93 info[3];
	const struct quota_format_ops___93 *ops[3];
};

struct rcuwait___93 {
	struct task_struct___94 *task;
};

struct percpu_rw_semaphore___93 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___94 rw_sem;
	struct rcuwait___93 writer;
	int readers_block;
};

struct sb_writers___93 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___93 rw_sem[3];
};

struct file_system_type___93;

struct super_operations___93;

struct dquot_operations___93;

struct quotactl_ops___93;

struct super_block___94 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___93 *s_type;
	const struct super_operations___93 *s_op;
	const struct dquot_operations___93 *dq_op;
	const struct quotactl_ops___93 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___94 *s_root;
	struct rw_semaphore___94 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___94 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___93 s_dquot;
	struct sb_writers___93 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___93 *s_d_op;
	int cleancache_poolid;
	struct shrinker___33 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___94 {
	struct file___94 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___94 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___94 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___94 *ia_file;
};

struct dquot___93 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___94 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___93 {
	int qf_fmt_id;
	const struct quota_format_ops___93 *qf_ops;
	struct module___80 *qf_owner;
	struct quota_format_type___93 *qf_next;
};

struct quota_format_ops___93 {
	int (*check_quota_file)(struct super_block___94 *, int);
	int (*read_file_info)(struct super_block___94 *, int);
	int (*write_file_info)(struct super_block___94 *, int);
	int (*free_file_info)(struct super_block___94 *, int);
	int (*read_dqblk)(struct dquot___93 *);
	int (*commit_dqblk)(struct dquot___93 *);
	int (*release_dqblk)(struct dquot___93 *);
	int (*get_next_id)(struct super_block___94 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___93 {
	int (*write_dquot)(struct dquot___93 *);
	struct dquot___93 * (*alloc_dquot)(struct super_block___94 *, int);
	void (*destroy_dquot)(struct dquot___93 *);
	int (*acquire_dquot)(struct dquot___93 *);
	int (*release_dquot)(struct dquot___93 *);
	int (*mark_dirty)(struct dquot___93 *);
	int (*write_info)(struct super_block___94 *, int);
	qsize_t * (*get_reserved_space)(struct inode___95 *);
	int (*get_projid)(struct inode___95 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___95 *, qsize_t *);
	int (*get_next_id)(struct super_block___94 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___93 {
	int (*quota_on)(struct super_block___94 *, int, int, const struct path___93 *);
	int (*quota_off)(struct super_block___94 *, int);
	int (*quota_enable)(struct super_block___94 *, unsigned int);
	int (*quota_disable)(struct super_block___94 *, unsigned int);
	int (*quota_sync)(struct super_block___94 *, int);
	int (*set_info)(struct super_block___94 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___94 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___94 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___94 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___94 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___94 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___93 {
	int (*writepage)(struct page___94 *, struct writeback_control___3 *);
	int (*readpage)(struct file___94 *, struct page___94 *);
	int (*writepages)(struct address_space___93 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___94 *);
	int (*readpages)(struct file___94 *, struct address_space___93 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___94 *, struct address_space___93 *, loff_t, unsigned int, unsigned int, struct page___94 **, void **);
	int (*write_end)(struct file___94 *, struct address_space___93 *, loff_t, unsigned int, unsigned int, struct page___94 *, void *);
	sector_t (*bmap)(struct address_space___93 *, sector_t);
	void (*invalidatepage)(struct page___94 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___94 *, gfp_t);
	void (*freepage)(struct page___94 *);
	ssize_t (*direct_IO)(struct kiocb___94 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___93 *, struct page___94 *, struct page___94 *, enum migrate_mode);
	bool (*isolate_page)(struct page___94 *, isolate_mode_t);
	void (*putback_page)(struct page___94 *);
	int (*launder_page)(struct page___94 *);
	int (*is_partially_uptodate)(struct page___94 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___94 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___93 *, struct page___94 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___94 *, sector_t *);
	void (*swap_deactivate)(struct file___94 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___94 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___95 *bd_inode;
	struct super_block___94 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___94 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___93 {
	struct dentry___94 * (*lookup)(struct inode___95 *, struct dentry___94 *, unsigned int);
	const char * (*get_link)(struct dentry___94 *, struct inode___95 *, struct delayed_call *);
	int (*permission)(struct inode___95 *, int);
	struct posix_acl * (*get_acl)(struct inode___95 *, int);
	int (*readlink)(struct dentry___94 *, char *, int);
	int (*create)(struct inode___95 *, struct dentry___94 *, umode_t, bool);
	int (*link)(struct dentry___94 *, struct inode___95 *, struct dentry___94 *);
	int (*unlink)(struct inode___95 *, struct dentry___94 *);
	int (*symlink)(struct inode___95 *, struct dentry___94 *, const char *);
	int (*mkdir)(struct inode___95 *, struct dentry___94 *, umode_t);
	int (*rmdir)(struct inode___95 *, struct dentry___94 *);
	int (*mknod)(struct inode___95 *, struct dentry___94 *, umode_t, dev_t);
	int (*rename)(struct inode___95 *, struct dentry___94 *, struct inode___95 *, struct dentry___94 *, unsigned int);
	int (*setattr)(struct dentry___94 *, struct iattr___94 *);
	int (*getattr)(const struct path___93 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___94 *, char *, size_t);
	int (*fiemap)(struct inode___95 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___95 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___95 *, struct dentry___94 *, struct file___94 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___95 *, struct dentry___94 *, umode_t);
	int (*set_acl)(struct inode___95 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___93 {
	void (*fl_copy_lock)(struct file_lock___94 *, struct file_lock___94 *);
	void (*fl_release_private)(struct file_lock___94 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___93;

struct lock_manager_operations___93;

struct file_lock___94 {
	struct file_lock___94 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___94 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___93 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___93 *fl_ops;
	const struct lock_manager_operations___93 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___93 {
	int (*lm_compare_owner)(struct file_lock___94 *, struct file_lock___94 *);
	long unsigned int (*lm_owner_key)(struct file_lock___94 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___94 *);
	int (*lm_grant)(struct file_lock___94 *, int);
	bool (*lm_break)(struct file_lock___94 *);
	int (*lm_change)(struct file_lock___94 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___94 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___93 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___93 *fa_next;
	struct file___94 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___93 {
	const char *name;
	int fs_flags;
	struct dentry___94 * (*mount)(struct file_system_type___93 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___94 *);
	struct module___80 *owner;
	struct file_system_type___93 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___93 {
	struct inode___95 * (*alloc_inode)(struct super_block___94 *);
	void (*destroy_inode)(struct inode___95 *);
	void (*dirty_inode)(struct inode___95 *, int);
	int (*write_inode)(struct inode___95 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___95 *);
	void (*evict_inode)(struct inode___95 *);
	void (*put_super)(struct super_block___94 *);
	int (*sync_fs)(struct super_block___94 *, int);
	int (*freeze_super)(struct super_block___94 *);
	int (*freeze_fs)(struct super_block___94 *);
	int (*thaw_super)(struct super_block___94 *);
	int (*unfreeze_fs)(struct super_block___94 *);
	int (*statfs)(struct dentry___94 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___94 *, int *, char *);
	void (*umount_begin)(struct super_block___94 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___94 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___94 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___94 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___94 *);
	ssize_t (*quota_read)(struct super_block___94 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___94 *, int, const char *, size_t, loff_t);
	struct dquot___93 ** (*get_dquots)(struct inode___95 *);
	int (*bdev_try_to_free_page)(struct super_block___94 *, struct page___94 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___94 *, struct shrink_control___33 *);
	long int (*free_cached_objects)(struct super_block___94 *, struct shrink_control___33 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___91(struct page___94 *);

struct debuggerinfo_struct___3 {
	void *debuggerinfo;
	struct task_struct___94 *task;
	int exception_state;
	int ret_state;
	int irq_depth;
	int enter_kgdb;
};

struct _kdb_bp {
	long unsigned int bp_addr;
	unsigned int bp_free: 1;
	unsigned int bp_enabled: 1;
	unsigned int bp_type: 4;
	unsigned int bp_installed: 1;
	unsigned int bp_delay: 1;
	unsigned int bp_delayed: 1;
	unsigned int bph_length;
};

typedef struct _kdb_bp kdb_bp_t;

struct module___81;

struct file___95;

struct kiocb___95;

struct vm_area_struct___95;

struct inode___96;

struct file_lock___95;

struct page___95;

struct file_operations___95 {
	struct module___81 *owner;
	loff_t (*llseek)(struct file___95 *, loff_t, int);
	ssize_t (*read)(struct file___95 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___95 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___95 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___95 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___95 *, bool);
	int (*iterate)(struct file___95 *, struct dir_context *);
	int (*iterate_shared)(struct file___95 *, struct dir_context *);
	__poll_t (*poll)(struct file___95 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___95 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___95 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___95 *, struct vm_area_struct___95 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___96 *, struct file___95 *);
	int (*flush)(struct file___95 *, fl_owner_t);
	int (*release)(struct inode___96 *, struct file___95 *);
	int (*fsync)(struct file___95 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___95 *, int);
	int (*lock)(struct file___95 *, int, struct file_lock___95 *);
	ssize_t (*sendpage)(struct file___95 *, struct page___95 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___95 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___95 *, int, struct file_lock___95 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___95 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___95 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___95 *, long int, struct file_lock___95 **, void **);
	long int (*fallocate)(struct file___95 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___95 *);
	ssize_t (*copy_file_range)(struct file___95 *, loff_t, struct file___95 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___95 *, loff_t, struct file___95 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___95 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___94 {
	u64 seqnum;
	struct vm_area_struct___95 *vmas[4];
};

struct page_frag___94 {
	struct page___95 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___94;

struct pid___79;

struct cred___91;

struct nsproxy___88;

struct signal_struct___85;

struct vm_struct___67;

struct task_struct___95 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___95 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___94 *mm;
	struct mm_struct___94 *active_mm;
	struct vmacache___94 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___95 *real_parent;
	struct task_struct___95 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___95 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___79 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___79 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___79 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___91 *ptracer_cred;
	const struct cred___91 *real_cred;
	const struct cred___91 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___88 *nsproxy;
	struct signal_struct___85 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___95 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___15 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___94 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___95 *oom_reaper_list;
	struct vm_struct___67 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___56 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rw_semaphore___95 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___95 *owner;
};

struct secondary_data___95 {
	void *stack;
	struct task_struct___95 *task;
	long int status;
};

struct blocking_notifier_head___94 {
	struct rw_semaphore___95 rwsem;
	struct notifier_block *head;
};

struct pid_namespace___79;

struct upid___79 {
	int nr;
	struct pid_namespace___79 *ns;
};

struct dentry___95;

struct pid_namespace___79 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___95 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___79 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___95 *proc_self;
	struct dentry___95 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___3 *user_ns;
	struct ucounts___2 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___5 ns;
};

struct pid___79 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___79 numbers[1];
};

typedef struct page___95 *pgtable_t___94;

struct address_space___94;

struct dev_pagemap___92;

struct page___95 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___94 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___95 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___94 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___94 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___92 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct key___91;

struct user_struct___91 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___91 *uid_keyring;
	struct key___91 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___92;

struct vm_area_struct___95 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___95 *vm_next;
	struct vm_area_struct___95 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___94 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___92 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___95 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___94;

struct mm_struct___94 {
	struct {
		struct vm_area_struct___95 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___95 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___95 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___94 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___95 *owner;
		struct user_namespace___3 *user_ns;
		struct file___95 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___94 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___91 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___91 *session_keyring;
	struct key___91 *process_keyring;
	struct key___91 *thread_keyring;
	struct key___91 *request_key_auth;
	void *security;
	struct user_struct___91 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct nsproxy___88 {
	atomic_t count;
	struct uts_namespace___19 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___79 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct signal_struct___85 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___95 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___95 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___79 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___79 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___94 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___79 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_struct___67 {
	struct vm_struct___67 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___95 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___85 {
	struct task_struct___95 task;
	long unsigned int stack[8192];
};

struct pglist_data___94;

struct lruvec___94 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___94 *pgdat;
};

struct zone___94 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___94 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___94 {
	struct zone___94 *zone;
	int zone_idx;
};

struct zonelist___94 {
	struct zoneref___94 _zonerefs[25];
};

struct pglist_data___94 {
	struct zone___94 node_zones[3];
	struct zonelist___94 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___95 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___95 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___94 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct path___94 {
	struct vfsmount *mnt;
	struct dentry___95 *dentry;
};

struct fown_struct___79 {
	rwlock_t lock;
	struct pid___79 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___95 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___94 f_path;
	struct inode___96 *f_inode;
	const struct file_operations___95 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___79 f_owner;
	const struct cred___91 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___94 *f_mapping;
	errseq_t f_wb_err;
};

struct kernfs_root___91;

struct kernfs_elem_dir___91 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___91 *root;
};

struct kernfs_node___91;

struct kernfs_syscall_ops___91;

struct kernfs_root___91 {
	struct kernfs_node___91 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___91 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___91 {
	struct kernfs_node___91 *target_kn;
};

struct kernfs_ops___91;

struct kernfs_elem_attr___91 {
	const struct kernfs_ops___91 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___91 *notify_next;
};

struct kernfs_node___91 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___91 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___91 dir;
		struct kernfs_elem_symlink___91 symlink;
		struct kernfs_elem_attr___91 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___91;

struct kernfs_ops___91 {
	int (*open)(struct kernfs_open_file___91 *);
	void (*release)(struct kernfs_open_file___91 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___91 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___91 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___91 *, struct vm_area_struct___95 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___91 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___91 {
	int (*remount_fs)(struct kernfs_root___91 *, int *, char *);
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___91 *);
	int (*mkdir)(struct kernfs_node___91 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___91 *);
	int (*rename)(struct kernfs_node___91 *, struct kernfs_node___91 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___91 *, struct kernfs_root___91 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___91 {
	struct kernfs_node___91 *kn;
	struct file___95 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___92 *vm_ops;
};

struct vm_fault___92;

struct vm_operations_struct___92 {
	void (*open)(struct vm_area_struct___95 *);
	void (*close)(struct vm_area_struct___95 *);
	int (*split)(struct vm_area_struct___95 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___95 *);
	vm_fault_t (*fault)(struct vm_fault___92 *);
	vm_fault_t (*huge_fault)(struct vm_fault___92 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___92 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___95 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___92 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___92 *);
	int (*access)(struct vm_area_struct___95 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___95 *);
	int (*set_policy)(struct vm_area_struct___95 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___95 *, long unsigned int);
	struct page___95 * (*find_special_page)(struct vm_area_struct___95 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___89;

struct bin_attribute___85;

struct attribute_group___85 {
	const char *name;
	umode_t (*is_visible)(struct kobject___89 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___89 *, struct bin_attribute___85 *, int);
	struct attribute **attrs;
	struct bin_attribute___85 **bin_attrs;
};

struct kset___88;

struct kobj_type___88;

struct kobject___89 {
	const char *name;
	struct list_head entry;
	struct kobject___89 *parent;
	struct kset___88 *kset;
	struct kobj_type___88 *ktype;
	struct kernfs_node___91 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___85 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___95 *, struct kobject___89 *, struct bin_attribute___85 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___95 *, struct kobject___89 *, struct bin_attribute___85 *, char *, loff_t, size_t);
	int (*mmap)(struct file___95 *, struct kobject___89 *, struct bin_attribute___85 *, struct vm_area_struct___95 *);
};

struct sysfs_ops___88 {
	ssize_t (*show)(struct kobject___89 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___89 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___88;

struct kset___88 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___89 kobj;
	const struct kset_uevent_ops___88 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___88 {
	void (*release)(struct kobject___89 *);
	const struct sysfs_ops___88 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___5 * (*child_ns_type)(struct kobject___89 *);
	const void * (*namespace)(struct kobject___89 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___88 {
	int (* const filter)(struct kset___88 *, struct kobject___89 *);
	const char * (* const name)(struct kset___88 *, struct kobject___89 *);
	int (* const uevent)(struct kset___88 *, struct kobject___89 *, struct kobj_uevent_env *);
};

struct kobj_attribute___89 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___89 *, struct kobj_attribute___89 *, char *);
	ssize_t (*store)(struct kobject___89 *, struct kobj_attribute___89 *, const char *, size_t);
};

struct kernel_param___78;

struct kernel_param_ops___78 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___78 *);
	int (*get)(char *, const struct kernel_param___78 *);
	void (*free)(void *);
};

struct kparam_array___78;

struct kernel_param___78 {
	const char *name;
	struct module___81 *mod;
	const struct kernel_param_ops___78 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___78 *arr;
	};
};

struct kparam_array___78 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___78 *ops;
	void *elem;
};

struct module_kobject___78 {
	struct kobject___89 kobj;
	struct module___81 *mod;
	struct kobject___89 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___78 {
	struct module___81 *mod;
	struct latch_tree_node node;
};

struct module_layout___78 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___78 mtn;
};

struct module_attribute___78;

struct module___81 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___78 mkobj;
	struct module_attribute___78 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___89 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___78 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___78 core_layout;
	struct module_layout___78 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___78 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___78 *, struct module_kobject___78 *, char *);
	ssize_t (*store)(struct module_attribute___78 *, struct module_kobject___78 *, const char *, size_t);
	void (*setup)(struct module___81 *, const char *);
	int (*test)(struct module___81 *);
	void (*free)(struct module___81 *);
};

struct module_use___2 {
	struct list_head source_list;
	struct list_head target_list;
	struct module___81 *source;
	struct module___81 *target;
};

struct address_space_operations___94;

struct address_space___94 {
	struct inode___96 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___95 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___94 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___92)(struct vm_area_struct___95 *, long unsigned int, const struct page___95 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___92)(struct page___95 *, void *);

struct device___86;

struct dev_pagemap___92 {
	dev_page_fault_t___92 page_fault;
	dev_page_free_t___92 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___86 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___94 {
	struct task_struct___95 *task;
	struct core_thread___94 *next;
};

struct core_state___94 {
	atomic_t nr_threads;
	struct core_thread___94 dumper;
	struct completion startup;
};

struct vm_fault___92 {
	struct vm_area_struct___95 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___95 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___95 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___94 prealloc_pte;
};

struct dev_pm_info___86 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___86 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___86;

struct bus_type___86;

struct device_driver___86;

struct dev_pm_domain___86;

struct class___86;

struct device___86 {
	struct device___86 *parent;
	struct device_private *p;
	struct kobject___89 kobj;
	const char *init_name;
	const struct device_type___86 *type;
	struct mutex mutex;
	struct bus_type___86 *bus;
	struct device_driver___86 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___86 power;
	struct dev_pm_domain___86 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___86 *class;
	const struct attribute_group___85 **groups;
	void (*release)(struct device___86 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___94;

struct super_block___95;

struct dentry___95 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___95 *d_parent;
	struct qstr d_name;
	struct inode___96 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___94 *d_op;
	struct super_block___95 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___94;

struct block_device___95;

struct inode___96 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___94 *i_op;
	struct super_block___95 *i_sb;
	struct address_space___94 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___95 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___95 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___94 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___95 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___94 {
	int (*d_revalidate)(struct dentry___95 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___95 *, unsigned int);
	int (*d_hash)(const struct dentry___95 *, struct qstr *);
	int (*d_compare)(const struct dentry___95 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___95 *);
	int (*d_init)(struct dentry___95 *);
	void (*d_release)(struct dentry___95 *);
	void (*d_prune)(struct dentry___95 *);
	void (*d_iput)(struct dentry___95 *, struct inode___96 *);
	char * (*d_dname)(struct dentry___95 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___94 *);
	int (*d_manage)(const struct path___94 *, bool);
	struct dentry___95 * (*d_real)(struct dentry___95 *, const struct inode___96 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___94;

struct mem_dqinfo___94 {
	struct quota_format_type___94 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___94;

struct quota_info___94 {
	unsigned int flags;
	struct rw_semaphore___95 dqio_sem;
	struct inode___96 *files[3];
	struct mem_dqinfo___94 info[3];
	const struct quota_format_ops___94 *ops[3];
};

struct rcuwait___94 {
	struct task_struct___95 *task;
};

struct percpu_rw_semaphore___94 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___95 rw_sem;
	struct rcuwait___94 writer;
	int readers_block;
};

struct sb_writers___94 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___94 rw_sem[3];
};

struct file_system_type___94;

struct super_operations___94;

struct dquot_operations___94;

struct quotactl_ops___94;

struct super_block___95 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___94 *s_type;
	const struct super_operations___94 *s_op;
	const struct dquot_operations___94 *dq_op;
	const struct quotactl_ops___94 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___95 *s_root;
	struct rw_semaphore___95 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___95 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___94 s_dquot;
	struct sb_writers___94 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___94 *s_d_op;
	int cleancache_poolid;
	struct shrinker___33 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___95 {
	struct file___95 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___95 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___95 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___95 *ia_file;
};

struct dquot___94 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___95 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___94 {
	int qf_fmt_id;
	const struct quota_format_ops___94 *qf_ops;
	struct module___81 *qf_owner;
	struct quota_format_type___94 *qf_next;
};

struct quota_format_ops___94 {
	int (*check_quota_file)(struct super_block___95 *, int);
	int (*read_file_info)(struct super_block___95 *, int);
	int (*write_file_info)(struct super_block___95 *, int);
	int (*free_file_info)(struct super_block___95 *, int);
	int (*read_dqblk)(struct dquot___94 *);
	int (*commit_dqblk)(struct dquot___94 *);
	int (*release_dqblk)(struct dquot___94 *);
	int (*get_next_id)(struct super_block___95 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___94 {
	int (*write_dquot)(struct dquot___94 *);
	struct dquot___94 * (*alloc_dquot)(struct super_block___95 *, int);
	void (*destroy_dquot)(struct dquot___94 *);
	int (*acquire_dquot)(struct dquot___94 *);
	int (*release_dquot)(struct dquot___94 *);
	int (*mark_dirty)(struct dquot___94 *);
	int (*write_info)(struct super_block___95 *, int);
	qsize_t * (*get_reserved_space)(struct inode___96 *);
	int (*get_projid)(struct inode___96 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___96 *, qsize_t *);
	int (*get_next_id)(struct super_block___95 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___94 {
	int (*quota_on)(struct super_block___95 *, int, int, const struct path___94 *);
	int (*quota_off)(struct super_block___95 *, int);
	int (*quota_enable)(struct super_block___95 *, unsigned int);
	int (*quota_disable)(struct super_block___95 *, unsigned int);
	int (*quota_sync)(struct super_block___95 *, int);
	int (*set_info)(struct super_block___95 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___95 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___95 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___95 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___95 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___95 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___94 {
	int (*writepage)(struct page___95 *, struct writeback_control___3 *);
	int (*readpage)(struct file___95 *, struct page___95 *);
	int (*writepages)(struct address_space___94 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___95 *);
	int (*readpages)(struct file___95 *, struct address_space___94 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___95 *, struct address_space___94 *, loff_t, unsigned int, unsigned int, struct page___95 **, void **);
	int (*write_end)(struct file___95 *, struct address_space___94 *, loff_t, unsigned int, unsigned int, struct page___95 *, void *);
	sector_t (*bmap)(struct address_space___94 *, sector_t);
	void (*invalidatepage)(struct page___95 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___95 *, gfp_t);
	void (*freepage)(struct page___95 *);
	ssize_t (*direct_IO)(struct kiocb___95 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___94 *, struct page___95 *, struct page___95 *, enum migrate_mode);
	bool (*isolate_page)(struct page___95 *, isolate_mode_t);
	void (*putback_page)(struct page___95 *);
	int (*launder_page)(struct page___95 *);
	int (*is_partially_uptodate)(struct page___95 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___95 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___94 *, struct page___95 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___95 *, sector_t *);
	void (*swap_deactivate)(struct file___95 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___95 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___96 *bd_inode;
	struct super_block___95 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___95 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___94 {
	struct dentry___95 * (*lookup)(struct inode___96 *, struct dentry___95 *, unsigned int);
	const char * (*get_link)(struct dentry___95 *, struct inode___96 *, struct delayed_call *);
	int (*permission)(struct inode___96 *, int);
	struct posix_acl * (*get_acl)(struct inode___96 *, int);
	int (*readlink)(struct dentry___95 *, char *, int);
	int (*create)(struct inode___96 *, struct dentry___95 *, umode_t, bool);
	int (*link)(struct dentry___95 *, struct inode___96 *, struct dentry___95 *);
	int (*unlink)(struct inode___96 *, struct dentry___95 *);
	int (*symlink)(struct inode___96 *, struct dentry___95 *, const char *);
	int (*mkdir)(struct inode___96 *, struct dentry___95 *, umode_t);
	int (*rmdir)(struct inode___96 *, struct dentry___95 *);
	int (*mknod)(struct inode___96 *, struct dentry___95 *, umode_t, dev_t);
	int (*rename)(struct inode___96 *, struct dentry___95 *, struct inode___96 *, struct dentry___95 *, unsigned int);
	int (*setattr)(struct dentry___95 *, struct iattr___95 *);
	int (*getattr)(const struct path___94 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___95 *, char *, size_t);
	int (*fiemap)(struct inode___96 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___96 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___96 *, struct dentry___95 *, struct file___95 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___96 *, struct dentry___95 *, umode_t);
	int (*set_acl)(struct inode___96 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___94 {
	void (*fl_copy_lock)(struct file_lock___95 *, struct file_lock___95 *);
	void (*fl_release_private)(struct file_lock___95 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___94;

struct lock_manager_operations___94;

struct file_lock___95 {
	struct file_lock___95 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___95 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___94 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___94 *fl_ops;
	const struct lock_manager_operations___94 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___94 {
	int (*lm_compare_owner)(struct file_lock___95 *, struct file_lock___95 *);
	long unsigned int (*lm_owner_key)(struct file_lock___95 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___95 *);
	int (*lm_grant)(struct file_lock___95 *, int);
	bool (*lm_break)(struct file_lock___95 *);
	int (*lm_change)(struct file_lock___95 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___95 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___94 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___94 *fa_next;
	struct file___95 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___94 {
	const char *name;
	int fs_flags;
	struct dentry___95 * (*mount)(struct file_system_type___94 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___95 *);
	struct module___81 *owner;
	struct file_system_type___94 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___94 {
	struct inode___96 * (*alloc_inode)(struct super_block___95 *);
	void (*destroy_inode)(struct inode___96 *);
	void (*dirty_inode)(struct inode___96 *, int);
	int (*write_inode)(struct inode___96 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___96 *);
	void (*evict_inode)(struct inode___96 *);
	void (*put_super)(struct super_block___95 *);
	int (*sync_fs)(struct super_block___95 *, int);
	int (*freeze_super)(struct super_block___95 *);
	int (*freeze_fs)(struct super_block___95 *);
	int (*thaw_super)(struct super_block___95 *);
	int (*unfreeze_fs)(struct super_block___95 *);
	int (*statfs)(struct dentry___95 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___95 *, int *, char *);
	void (*umount_begin)(struct super_block___95 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___95 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___95 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___95 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___95 *);
	ssize_t (*quota_read)(struct super_block___95 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___95 *, int, const char *, size_t, loff_t);
	struct dquot___94 ** (*get_dquots)(struct inode___96 *);
	int (*bdev_try_to_free_page)(struct super_block___95 *, struct page___95 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___95 *, struct shrink_control___33 *);
	long int (*free_cached_objects)(struct super_block___95 *, struct shrink_control___33 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___92(struct page___95 *);

typedef int (*key_restrict_link_func_t___91)(struct key___91 *, const struct key_type *, const union key_payload *, struct key___91 *);

struct key_restriction___91;

struct key___91 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___95 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___91 *restrict_link;
};

struct key_restriction___91 {
	key_restrict_link_func_t___91 check;
	struct key___91 *key;
	struct key_type *keytype;
};

typedef enum {
	KDB_ENABLE_ALL = 1,
	KDB_ENABLE_MEM_READ = 2,
	KDB_ENABLE_MEM_WRITE = 4,
	KDB_ENABLE_REG_READ = 8,
	KDB_ENABLE_REG_WRITE = 16,
	KDB_ENABLE_INSPECT = 32,
	KDB_ENABLE_FLOW_CTRL = 64,
	KDB_ENABLE_SIGNAL = 128,
	KDB_ENABLE_REBOOT = 256,
	KDB_ENABLE_ALWAYS_SAFE = 512,
	KDB_ENABLE_MASK = 1023,
	KDB_ENABLE_ALL_NO_ARGS = 1024,
	KDB_ENABLE_MEM_READ_NO_ARGS = 2048,
	KDB_ENABLE_MEM_WRITE_NO_ARGS = 4096,
	KDB_ENABLE_REG_READ_NO_ARGS = 8192,
	KDB_ENABLE_REG_WRITE_NO_ARGS = 16384,
	KDB_ENABLE_INSPECT_NO_ARGS = 32768,
	KDB_ENABLE_FLOW_CTRL_NO_ARGS = 65536,
	KDB_ENABLE_SIGNAL_NO_ARGS = 131072,
	KDB_ENABLE_REBOOT_NO_ARGS = 262144,
	KDB_ENABLE_ALWAYS_SAFE_NO_ARGS = 524288,
	KDB_ENABLE_MASK_NO_ARGS = 1047552,
	KDB_REPEAT_NO_ARGS = 1073741824,
	KDB_REPEAT_WITH_ARGS = 2147483648,
} kdb_cmdflags_t;

typedef int (*kdb_func_t)(int, const char **);

typedef enum {
	KDB_REASON_ENTER = 1,
	KDB_REASON_ENTER_SLAVE = 2,
	KDB_REASON_BREAK = 3,
	KDB_REASON_DEBUG = 4,
	KDB_REASON_OOPS = 5,
	KDB_REASON_SWITCH = 6,
	KDB_REASON_KEYBOARD = 7,
	KDB_REASON_NMI = 8,
	KDB_REASON_RECURSE = 9,
	KDB_REASON_SSTEP = 10,
	KDB_REASON_SYSTEM_NMI = 11,
} kdb_reason_t;

struct dev_pm_ops___86 {
	int (*prepare)(struct device___86 *);
	void (*complete)(struct device___86 *);
	int (*suspend)(struct device___86 *);
	int (*resume)(struct device___86 *);
	int (*freeze)(struct device___86 *);
	int (*thaw)(struct device___86 *);
	int (*poweroff)(struct device___86 *);
	int (*restore)(struct device___86 *);
	int (*suspend_late)(struct device___86 *);
	int (*resume_early)(struct device___86 *);
	int (*freeze_late)(struct device___86 *);
	int (*thaw_early)(struct device___86 *);
	int (*poweroff_late)(struct device___86 *);
	int (*restore_early)(struct device___86 *);
	int (*suspend_noirq)(struct device___86 *);
	int (*resume_noirq)(struct device___86 *);
	int (*freeze_noirq)(struct device___86 *);
	int (*thaw_noirq)(struct device___86 *);
	int (*poweroff_noirq)(struct device___86 *);
	int (*restore_noirq)(struct device___86 *);
	int (*runtime_suspend)(struct device___86 *);
	int (*runtime_resume)(struct device___86 *);
	int (*runtime_idle)(struct device___86 *);
};

struct dev_pm_domain___86 {
	struct dev_pm_ops___86 ops;
	void (*detach)(struct device___86 *, bool);
	int (*activate)(struct device___86 *);
	void (*sync)(struct device___86 *);
	void (*dismiss)(struct device___86 *);
};

struct bus_type___86 {
	const char *name;
	const char *dev_name;
	struct device___86 *dev_root;
	const struct attribute_group___85 **bus_groups;
	const struct attribute_group___85 **dev_groups;
	const struct attribute_group___85 **drv_groups;
	int (*match)(struct device___86 *, struct device_driver___86 *);
	int (*uevent)(struct device___86 *, struct kobj_uevent_env *);
	int (*probe)(struct device___86 *);
	int (*remove)(struct device___86 *);
	void (*shutdown)(struct device___86 *);
	int (*online)(struct device___86 *);
	int (*offline)(struct device___86 *);
	int (*suspend)(struct device___86 *, pm_message_t);
	int (*resume)(struct device___86 *);
	int (*num_vf)(struct device___86 *);
	int (*dma_configure)(struct device___86 *);
	const struct dev_pm_ops___86 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___86 {
	const char *name;
	struct bus_type___86 *bus;
	struct module___81 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___86 *);
	int (*remove)(struct device___86 *);
	void (*shutdown)(struct device___86 *);
	int (*suspend)(struct device___86 *, pm_message_t);
	int (*resume)(struct device___86 *);
	const struct attribute_group___85 **groups;
	const struct dev_pm_ops___86 *pm;
	void (*coredump)(struct device___86 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___86 {
	const char *name;
	const struct attribute_group___85 **groups;
	int (*uevent)(struct device___86 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___86 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___86 *);
	const struct dev_pm_ops___86 *pm;
};

struct class___86 {
	const char *name;
	struct module___81 *owner;
	const struct attribute_group___85 **class_groups;
	const struct attribute_group___85 **dev_groups;
	struct kobject___89 *dev_kobj;
	int (*dev_uevent)(struct device___86 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___86 *, umode_t *);
	void (*class_release)(struct class___86 *);
	void (*dev_release)(struct device___86 *);
	int (*shutdown_pre)(struct device___86 *);
	const struct kobj_ns_type_operations___5 *ns_type;
	const void * (*namespace)(struct device___86 *);
	const struct dev_pm_ops___86 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___73 {
	struct device___86 dev;
};

struct debuggerinfo_struct___4 {
	void *debuggerinfo;
	struct task_struct___95 *task;
	int exception_state;
	int ret_state;
	int irq_depth;
	int enter_kgdb;
};

struct __ksymtab {
	long unsigned int value;
	const char *mod_name;
	long unsigned int mod_start;
	long unsigned int mod_end;
	const char *sec_name;
	long unsigned int sec_start;
	long unsigned int sec_end;
	const char *sym_name;
	long unsigned int sym_start;
	long unsigned int sym_end;
};

typedef struct __ksymtab kdb_symtab_t;

struct _kdbtab {
	char *cmd_name;
	kdb_func_t cmd_func;
	char *cmd_usage;
	char *cmd_help;
	short int cmd_minlen;
	kdb_cmdflags_t cmd_flags;
};

typedef struct _kdbtab kdbtab_t;

typedef enum {
	KDB_DB_BPT = 0,
	KDB_DB_SS = 1,
	KDB_DB_SSBPT = 2,
	KDB_DB_NOBPT = 3,
} kdb_dbtrap_t;

struct _kdbmsg {
	int km_diag;
	char *km_msg;
};

typedef struct _kdbmsg kdbmsg_t;

struct defcmd_set {
	int count;
	int usable;
	char *name;
	char *usage;
	char *help;
	char **command;
};

struct debug_alloc_header {
	u32 next;
	u32 size;
	void *caller;
};

typedef short unsigned int u_short;

struct file___96;

struct kiocb___96;

struct vm_area_struct___96;

struct inode___97;

struct file_lock___96;

struct page___96;

struct seq_file___87;

struct file_operations___96 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___96 *, loff_t, int);
	ssize_t (*read)(struct file___96 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___96 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___96 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___96 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___96 *, bool);
	int (*iterate)(struct file___96 *, struct dir_context *);
	int (*iterate_shared)(struct file___96 *, struct dir_context *);
	__poll_t (*poll)(struct file___96 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___96 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___96 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___96 *, struct vm_area_struct___96 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___97 *, struct file___96 *);
	int (*flush)(struct file___96 *, fl_owner_t);
	int (*release)(struct inode___97 *, struct file___96 *);
	int (*fsync)(struct file___96 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___96 *, int);
	int (*lock)(struct file___96 *, int, struct file_lock___96 *);
	ssize_t (*sendpage)(struct file___96 *, struct page___96 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___96 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___96 *, int, struct file_lock___96 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___96 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___96 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___96 *, long int, struct file_lock___96 **, void **);
	long int (*fallocate)(struct file___96 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___87 *, struct file___96 *);
	ssize_t (*copy_file_range)(struct file___96 *, loff_t, struct file___96 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___96 *, loff_t, struct file___96 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___96 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___95 {
	u64 seqnum;
	struct vm_area_struct___96 *vmas[4];
};

struct page_frag___95 {
	struct page___96 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___95;

struct mem_cgroup___34;

struct cred___92;

struct nsproxy___89;

struct signal_struct___86;

struct bio_list___37;

struct backing_dev_info___37;

struct css_set___73;

struct task_struct___96 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___96 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___95 *mm;
	struct mm_struct___95 *active_mm;
	struct vmacache___95 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___96 *real_parent;
	struct task_struct___96 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___96 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___34 *active_memcg;
	long int rh_reserved2;
	struct pid___79 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___79 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___79 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___92 *ptracer_cred;
	const struct cred___92 *real_cred;
	const struct cred___92 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___89 *nsproxy;
	struct signal_struct___86 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___96 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___37 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___37 *backing_dev_info;
	struct io_context___15 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___73 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___95 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___34 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___96 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___56 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___96 *pgtable_t___95;

struct address_space___95;

struct dev_pagemap___93;

struct page___96 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___95 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___96 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___95 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___95 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___93 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___34 *mem_cgroup;
};

struct pglist_data___95;

struct lruvec___95 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___95 *pgdat;
};

struct zone___95 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___95 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___95 {
	struct zone___95 *zone;
	int zone_idx;
};

struct zonelist___95 {
	struct zoneref___95 _zonerefs[25];
};

struct pglist_data___95 {
	struct zone___95 node_zones[3];
	struct zonelist___95 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___96 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___96 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___95 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___96 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___96 *owner;
};

struct secondary_data___96 {
	void *stack;
	struct task_struct___96 *task;
	long int status;
};

struct blocking_notifier_head___95 {
	struct rw_semaphore___96 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___93;

struct vm_area_struct___96 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___96 *vm_next;
	struct vm_area_struct___96 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___95 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___93 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___96 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct linux_binfmt___13;

struct core_state___95;

struct user_namespace___77;

struct mm_struct___95 {
	struct {
		struct vm_area_struct___96 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___96 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___96 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___13 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___95 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___96 *owner;
		struct user_namespace___77 *user_ns;
		struct file___96 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___95 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___95;

struct address_space___95 {
	struct inode___97 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___96 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___95 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___93)(struct vm_area_struct___96 *, long unsigned int, const struct page___96 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___93)(struct page___96 *, void *);

struct device___87;

struct dev_pagemap___93 {
	dev_page_fault_t___93 page_fault;
	dev_page_free_t___93 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___87 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct cgroup___73;

struct cgroup_subsys___73;

struct cgroup_subsys_state___73 {
	struct cgroup___73 *cgroup;
	struct cgroup_subsys___73 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___73 *parent;
};

struct kernfs_node___92;

struct cgroup_file___73 {
	struct kernfs_node___92 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___34;

struct mem_cgroup___34 {
	struct cgroup_subsys_state___73 css;
	struct mem_cgroup_id___6 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___73 events_file;
	struct cgroup_file___73 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___96 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___34 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry___96;

struct path___95 {
	struct vfsmount *mnt;
	struct dentry___96 *dentry;
};

struct file___96 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___95 f_path;
	struct inode___97 *f_inode;
	const struct file_operations___96 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___79 f_owner;
	const struct cred___92 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___95 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___93;

struct vm_operations_struct___93 {
	void (*open)(struct vm_area_struct___96 *);
	void (*close)(struct vm_area_struct___96 *);
	int (*split)(struct vm_area_struct___96 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___96 *);
	vm_fault_t (*fault)(struct vm_fault___93 *);
	vm_fault_t (*huge_fault)(struct vm_fault___93 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___93 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___96 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___93 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___93 *);
	int (*access)(struct vm_area_struct___96 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___96 *);
	int (*set_policy)(struct vm_area_struct___96 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___96 *, long unsigned int);
	struct page___96 * (*find_special_page)(struct vm_area_struct___96 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___95 {
	struct task_struct___96 *task;
	struct core_thread___95 *next;
};

struct core_state___95 {
	atomic_t nr_threads;
	struct core_thread___95 dumper;
	struct completion startup;
};

struct linux_binprm___14;

struct coredump_params___13;

struct linux_binfmt___13 {
	struct list_head lh;
	struct module___11 *module;
	int (*load_binary)(struct linux_binprm___14 *);
	int (*load_shlib)(struct file___96 *);
	int (*core_dump)(struct coredump_params___13 *);
	long unsigned int min_coredump;
};

struct key___92;

struct ucounts___77;

struct user_namespace___77 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___77 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___7 ns;
	long unsigned int flags;
	struct key___92 *persistent_keyring_register;
	struct rw_semaphore___96 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___77 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___93 {
	struct vm_area_struct___96 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___96 *cow_page;
	struct mem_cgroup___34 *memcg;
	struct page___96 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___95 prealloc_pte;
};

struct shrink_control___34 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___34 *memcg;
};

struct shrinker___34 {
	long unsigned int (*count_objects)(struct shrinker___34 *, struct shrink_control___34 *);
	long unsigned int (*scan_objects)(struct shrinker___34 *, struct shrink_control___34 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct user_struct___92 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___92 *uid_keyring;
	struct key___92 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___92 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___92 *session_keyring;
	struct key___92 *process_keyring;
	struct key___92 *thread_keyring;
	struct key___92 *request_key_auth;
	void *security;
	struct user_struct___92 *user;
	struct user_namespace___77 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct uts_namespace___20;

struct cgroup_namespace___73;

struct nsproxy___89 {
	atomic_t count;
	struct uts_namespace___20 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___73 *cgroup_ns;
};

struct signal_struct___86 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___96 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___96 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___79 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___79 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___95 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___79 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___37;

struct bio_list___37 {
	struct bio___37 *head;
	struct bio___37 *tail;
};

struct bdi_writeback_congested___37;

struct bdi_writeback___37 {
	struct backing_dev_info___37 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___37 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___73 *memcg_css;
	struct cgroup_subsys_state___73 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___37 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___37 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___87 *dev;
	struct device___87 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___96 *debug_dir;
	struct dentry___96 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___73 {
	struct cgroup_subsys_state___73 *subsys[13];
	refcount_t refcount;
	struct css_set___73 *dom_cset;
	struct cgroup___73 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___73 *mg_src_cgrp;
	struct cgroup___73 *mg_dst_cgrp;
	struct css_set___73 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

union thread_union___86 {
	struct task_struct___96 task;
	long unsigned int stack[8192];
};

struct kset___89;

struct kobj_type___89;

struct kobject___90 {
	const char *name;
	struct list_head entry;
	struct kobject___90 *parent;
	struct kset___89 *kset;
	struct kobj_type___89 *ktype;
	struct kernfs_node___92 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___87 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___87 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___87;

struct bus_type___87;

struct device_driver___87;

struct dev_pm_domain___87;

struct class___87;

struct attribute_group___86;

struct device___87 {
	struct device___87 *parent;
	struct device_private *p;
	struct kobject___90 kobj;
	const char *init_name;
	const struct device_type___87 *type;
	struct mutex mutex;
	struct bus_type___87 *bus;
	struct device_driver___87 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___87 power;
	struct dev_pm_domain___87 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___87 *class;
	const struct attribute_group___86 **groups;
	void (*release)(struct device___87 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___95;

struct super_block___96;

struct dentry___96 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___96 *d_parent;
	struct qstr d_name;
	struct inode___97 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___95 *d_op;
	struct super_block___96 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___95;

struct block_device___96;

struct inode___97 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___95 *i_op;
	struct super_block___96 *i_sb;
	struct address_space___95 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___96 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___37 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___96 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___95 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___96 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___95 {
	int (*d_revalidate)(struct dentry___96 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___96 *, unsigned int);
	int (*d_hash)(const struct dentry___96 *, struct qstr *);
	int (*d_compare)(const struct dentry___96 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___96 *);
	int (*d_init)(struct dentry___96 *);
	void (*d_release)(struct dentry___96 *);
	void (*d_prune)(struct dentry___96 *);
	void (*d_iput)(struct dentry___96 *, struct inode___97 *);
	char * (*d_dname)(struct dentry___96 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___95 *);
	int (*d_manage)(const struct path___95 *, bool);
	struct dentry___96 * (*d_real)(struct dentry___96 *, const struct inode___97 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___95;

struct mem_dqinfo___95 {
	struct quota_format_type___95 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___95;

struct quota_info___95 {
	unsigned int flags;
	struct rw_semaphore___96 dqio_sem;
	struct inode___97 *files[3];
	struct mem_dqinfo___95 info[3];
	const struct quota_format_ops___95 *ops[3];
};

struct rcuwait___95 {
	struct task_struct___96 *task;
};

struct percpu_rw_semaphore___95 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___96 rw_sem;
	struct rcuwait___95 writer;
	int readers_block;
};

struct sb_writers___95 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___95 rw_sem[3];
};

struct file_system_type___95;

struct super_operations___95;

struct dquot_operations___95;

struct quotactl_ops___95;

struct super_block___96 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___95 *s_type;
	const struct super_operations___95 *s_op;
	const struct dquot_operations___95 *dq_op;
	const struct quotactl_ops___95 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___96 *s_root;
	struct rw_semaphore___96 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___96 *s_bdev;
	struct backing_dev_info___37 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___95 s_dquot;
	struct sb_writers___95 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___95 *s_d_op;
	int cleancache_poolid;
	struct shrinker___34 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___77 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___96 {
	struct file___96 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___96 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___96 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___96 *ia_file;
};

struct dquot___95 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___96 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___95 {
	int qf_fmt_id;
	const struct quota_format_ops___95 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___95 *qf_next;
};

struct quota_format_ops___95 {
	int (*check_quota_file)(struct super_block___96 *, int);
	int (*read_file_info)(struct super_block___96 *, int);
	int (*write_file_info)(struct super_block___96 *, int);
	int (*free_file_info)(struct super_block___96 *, int);
	int (*read_dqblk)(struct dquot___95 *);
	int (*commit_dqblk)(struct dquot___95 *);
	int (*release_dqblk)(struct dquot___95 *);
	int (*get_next_id)(struct super_block___96 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___95 {
	int (*write_dquot)(struct dquot___95 *);
	struct dquot___95 * (*alloc_dquot)(struct super_block___96 *, int);
	void (*destroy_dquot)(struct dquot___95 *);
	int (*acquire_dquot)(struct dquot___95 *);
	int (*release_dquot)(struct dquot___95 *);
	int (*mark_dirty)(struct dquot___95 *);
	int (*write_info)(struct super_block___96 *, int);
	qsize_t * (*get_reserved_space)(struct inode___97 *);
	int (*get_projid)(struct inode___97 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___97 *, qsize_t *);
	int (*get_next_id)(struct super_block___96 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___95 {
	int (*quota_on)(struct super_block___96 *, int, int, const struct path___95 *);
	int (*quota_off)(struct super_block___96 *, int);
	int (*quota_enable)(struct super_block___96 *, unsigned int);
	int (*quota_disable)(struct super_block___96 *, unsigned int);
	int (*quota_sync)(struct super_block___96 *, int);
	int (*set_info)(struct super_block___96 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___96 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___96 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___96 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___96 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___96 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___35;

struct swap_info_struct___26;

struct address_space_operations___95 {
	int (*writepage)(struct page___96 *, struct writeback_control___35 *);
	int (*readpage)(struct file___96 *, struct page___96 *);
	int (*writepages)(struct address_space___95 *, struct writeback_control___35 *);
	int (*set_page_dirty)(struct page___96 *);
	int (*readpages)(struct file___96 *, struct address_space___95 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___96 *, struct address_space___95 *, loff_t, unsigned int, unsigned int, struct page___96 **, void **);
	int (*write_end)(struct file___96 *, struct address_space___95 *, loff_t, unsigned int, unsigned int, struct page___96 *, void *);
	sector_t (*bmap)(struct address_space___95 *, sector_t);
	void (*invalidatepage)(struct page___96 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___96 *, gfp_t);
	void (*freepage)(struct page___96 *);
	ssize_t (*direct_IO)(struct kiocb___96 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___95 *, struct page___96 *, struct page___96 *, enum migrate_mode);
	bool (*isolate_page)(struct page___96 *, isolate_mode_t);
	void (*putback_page)(struct page___96 *);
	int (*launder_page)(struct page___96 *);
	int (*is_partially_uptodate)(struct page___96 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___96 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___95 *, struct page___96 *);
	int (*swap_activate)(struct swap_info_struct___26 *, struct file___96 *, sector_t *);
	void (*swap_deactivate)(struct file___96 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___35 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___37 *wb;
	struct inode___97 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct swap_info_struct___26 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___96 *bdev;
	struct file___96 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___96 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___97 *bd_inode;
	struct super_block___96 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___96 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___37 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___95 {
	struct dentry___96 * (*lookup)(struct inode___97 *, struct dentry___96 *, unsigned int);
	const char * (*get_link)(struct dentry___96 *, struct inode___97 *, struct delayed_call *);
	int (*permission)(struct inode___97 *, int);
	struct posix_acl * (*get_acl)(struct inode___97 *, int);
	int (*readlink)(struct dentry___96 *, char *, int);
	int (*create)(struct inode___97 *, struct dentry___96 *, umode_t, bool);
	int (*link)(struct dentry___96 *, struct inode___97 *, struct dentry___96 *);
	int (*unlink)(struct inode___97 *, struct dentry___96 *);
	int (*symlink)(struct inode___97 *, struct dentry___96 *, const char *);
	int (*mkdir)(struct inode___97 *, struct dentry___96 *, umode_t);
	int (*rmdir)(struct inode___97 *, struct dentry___96 *);
	int (*mknod)(struct inode___97 *, struct dentry___96 *, umode_t, dev_t);
	int (*rename)(struct inode___97 *, struct dentry___96 *, struct inode___97 *, struct dentry___96 *, unsigned int);
	int (*setattr)(struct dentry___96 *, struct iattr___96 *);
	int (*getattr)(const struct path___95 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___96 *, char *, size_t);
	int (*fiemap)(struct inode___97 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___97 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___97 *, struct dentry___96 *, struct file___96 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___97 *, struct dentry___96 *, umode_t);
	int (*set_acl)(struct inode___97 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___95 {
	void (*fl_copy_lock)(struct file_lock___96 *, struct file_lock___96 *);
	void (*fl_release_private)(struct file_lock___96 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___95;

struct lock_manager_operations___95;

struct file_lock___96 {
	struct file_lock___96 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___96 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___95 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___95 *fl_ops;
	const struct lock_manager_operations___95 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___95 {
	int (*lm_compare_owner)(struct file_lock___96 *, struct file_lock___96 *);
	long unsigned int (*lm_owner_key)(struct file_lock___96 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___96 *);
	int (*lm_grant)(struct file_lock___96 *, int);
	bool (*lm_break)(struct file_lock___96 *);
	int (*lm_change)(struct file_lock___96 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___96 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___95 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___95 *fa_next;
	struct file___96 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___95 {
	const char *name;
	int fs_flags;
	struct dentry___96 * (*mount)(struct file_system_type___95 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___96 *);
	struct module___11 *owner;
	struct file_system_type___95 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___95 {
	struct inode___97 * (*alloc_inode)(struct super_block___96 *);
	void (*destroy_inode)(struct inode___97 *);
	void (*dirty_inode)(struct inode___97 *, int);
	int (*write_inode)(struct inode___97 *, struct writeback_control___35 *);
	int (*drop_inode)(struct inode___97 *);
	void (*evict_inode)(struct inode___97 *);
	void (*put_super)(struct super_block___96 *);
	int (*sync_fs)(struct super_block___96 *, int);
	int (*freeze_super)(struct super_block___96 *);
	int (*freeze_fs)(struct super_block___96 *);
	int (*thaw_super)(struct super_block___96 *);
	int (*unfreeze_fs)(struct super_block___96 *);
	int (*statfs)(struct dentry___96 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___96 *, int *, char *);
	void (*umount_begin)(struct super_block___96 *);
	int (*show_options)(struct seq_file___87 *, struct dentry___96 *);
	int (*show_devname)(struct seq_file___87 *, struct dentry___96 *);
	int (*show_path)(struct seq_file___87 *, struct dentry___96 *);
	int (*show_stats)(struct seq_file___87 *, struct dentry___96 *);
	ssize_t (*quota_read)(struct super_block___96 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___96 *, int, const char *, size_t, loff_t);
	struct dquot___95 ** (*get_dquots)(struct inode___97 *);
	int (*bdev_try_to_free_page)(struct super_block___96 *, struct page___96 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___96 *, struct shrink_control___34 *);
	long int (*free_cached_objects)(struct super_block___96 *, struct shrink_control___34 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___85;

struct seq_file___87 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___85 *op;
	int poll_event;
	const struct file___96 *file;
	void *private;
};

typedef void bio_end_io_t___37(struct bio___37 *);

struct bio_vec___37 {
	struct page___96 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___37;

struct bio_set___37;

struct bio___37 {
	struct bio___37 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___37 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___37 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___37 *bi_io_vec;
	struct bio_set___37 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___37 bi_inline_vecs[0];
};

struct kobj_attribute___90 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___90 *, struct kobj_attribute___90 *, char *);
	ssize_t (*store)(struct kobject___90 *, struct kobj_attribute___90 *, const char *, size_t);
};

typedef void compound_page_dtor___93(struct page___96 *);

struct kernfs_root___92;

struct kernfs_elem_dir___92 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___92 *root;
};

struct kernfs_syscall_ops___92;

struct kernfs_root___92 {
	struct kernfs_node___92 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___92 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___92 {
	struct kernfs_node___92 *target_kn;
};

struct kernfs_ops___92;

struct kernfs_elem_attr___92 {
	const struct kernfs_ops___92 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___92 *notify_next;
};

struct kernfs_node___92 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___92 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___92 dir;
		struct kernfs_elem_symlink___92 symlink;
		struct kernfs_elem_attr___92 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___92;

struct kernfs_ops___92 {
	int (*open)(struct kernfs_open_file___92 *);
	void (*release)(struct kernfs_open_file___92 *);
	int (*seq_show)(struct seq_file___87 *, void *);
	void * (*seq_start)(struct seq_file___87 *, loff_t *);
	void * (*seq_next)(struct seq_file___87 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___87 *, void *);
	ssize_t (*read)(struct kernfs_open_file___92 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___92 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___92 *, struct vm_area_struct___96 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___92 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___92 {
	int (*remount_fs)(struct kernfs_root___92 *, int *, char *);
	int (*show_options)(struct seq_file___87 *, struct kernfs_root___92 *);
	int (*mkdir)(struct kernfs_node___92 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___92 *);
	int (*rename)(struct kernfs_node___92 *, struct kernfs_node___92 *, const char *);
	int (*show_path)(struct seq_file___87 *, struct kernfs_node___92 *, struct kernfs_root___92 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___92 {
	struct kernfs_node___92 *kn;
	struct file___96 *file;
	struct seq_file___87 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___93 *vm_ops;
};

struct bin_attribute___86;

struct attribute_group___86 {
	const char *name;
	umode_t (*is_visible)(struct kobject___90 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___90 *, struct bin_attribute___86 *, int);
	struct attribute **attrs;
	struct bin_attribute___86 **bin_attrs;
};

struct bin_attribute___86 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___96 *, struct kobject___90 *, struct bin_attribute___86 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___96 *, struct kobject___90 *, struct bin_attribute___86 *, char *, loff_t, size_t);
	int (*mmap)(struct file___96 *, struct kobject___90 *, struct bin_attribute___86 *, struct vm_area_struct___96 *);
};

struct sysfs_ops___89 {
	ssize_t (*show)(struct kobject___90 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___90 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___89;

struct kset___89 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___90 kobj;
	const struct kset_uevent_ops___89 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___89 {
	void (*release)(struct kobject___90 *);
	const struct sysfs_ops___89 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___5 * (*child_ns_type)(struct kobject___90 *);
	const void * (*namespace)(struct kobject___90 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___89 {
	int (* const filter)(struct kset___89 *, struct kobject___90 *);
	const char * (* const name)(struct kset___89 *, struct kobject___90 *);
	int (* const uevent)(struct kset___89 *, struct kobject___90 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___87 {
	int (*prepare)(struct device___87 *);
	void (*complete)(struct device___87 *);
	int (*suspend)(struct device___87 *);
	int (*resume)(struct device___87 *);
	int (*freeze)(struct device___87 *);
	int (*thaw)(struct device___87 *);
	int (*poweroff)(struct device___87 *);
	int (*restore)(struct device___87 *);
	int (*suspend_late)(struct device___87 *);
	int (*resume_early)(struct device___87 *);
	int (*freeze_late)(struct device___87 *);
	int (*thaw_early)(struct device___87 *);
	int (*poweroff_late)(struct device___87 *);
	int (*restore_early)(struct device___87 *);
	int (*suspend_noirq)(struct device___87 *);
	int (*resume_noirq)(struct device___87 *);
	int (*freeze_noirq)(struct device___87 *);
	int (*thaw_noirq)(struct device___87 *);
	int (*poweroff_noirq)(struct device___87 *);
	int (*restore_noirq)(struct device___87 *);
	int (*runtime_suspend)(struct device___87 *);
	int (*runtime_resume)(struct device___87 *);
	int (*runtime_idle)(struct device___87 *);
};

struct dev_pm_domain___87 {
	struct dev_pm_ops___87 ops;
	void (*detach)(struct device___87 *, bool);
	int (*activate)(struct device___87 *);
	void (*sync)(struct device___87 *);
	void (*dismiss)(struct device___87 *);
};

struct bus_type___87 {
	const char *name;
	const char *dev_name;
	struct device___87 *dev_root;
	const struct attribute_group___86 **bus_groups;
	const struct attribute_group___86 **dev_groups;
	const struct attribute_group___86 **drv_groups;
	int (*match)(struct device___87 *, struct device_driver___87 *);
	int (*uevent)(struct device___87 *, struct kobj_uevent_env *);
	int (*probe)(struct device___87 *);
	int (*remove)(struct device___87 *);
	void (*shutdown)(struct device___87 *);
	int (*online)(struct device___87 *);
	int (*offline)(struct device___87 *);
	int (*suspend)(struct device___87 *, pm_message_t);
	int (*resume)(struct device___87 *);
	int (*num_vf)(struct device___87 *);
	int (*dma_configure)(struct device___87 *);
	const struct dev_pm_ops___87 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___87 {
	const char *name;
	struct bus_type___87 *bus;
	struct module___11 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___87 *);
	int (*remove)(struct device___87 *);
	void (*shutdown)(struct device___87 *);
	int (*suspend)(struct device___87 *, pm_message_t);
	int (*resume)(struct device___87 *);
	const struct attribute_group___86 **groups;
	const struct dev_pm_ops___87 *pm;
	void (*coredump)(struct device___87 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___87 {
	const char *name;
	const struct attribute_group___86 **groups;
	int (*uevent)(struct device___87 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___87 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___87 *);
	const struct dev_pm_ops___87 *pm;
};

struct class___87 {
	const char *name;
	struct module___11 *owner;
	const struct attribute_group___86 **class_groups;
	const struct attribute_group___86 **dev_groups;
	struct kobject___90 *dev_kobj;
	int (*dev_uevent)(struct device___87 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___87 *, umode_t *);
	void (*class_release)(struct class___87 *);
	void (*dev_release)(struct device___87 *);
	int (*shutdown_pre)(struct device___87 *);
	const struct kobj_ns_type_operations___5 *ns_type;
	const void * (*namespace)(struct device___87 *);
	const struct dev_pm_ops___87 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___74 {
	struct device___87 dev;
};

struct kthread_work___73;

typedef void (*kthread_work_func_t___73)(struct kthread_work___73 *);

struct kthread_worker___73;

struct kthread_work___73 {
	struct list_head node;
	kthread_work_func_t___73 func;
	struct kthread_worker___73 *worker;
	int canceling;
};

struct kthread_worker___73 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___96 *task;
	struct kthread_work___73 *current_work;
};

struct kthread_delayed_work___73 {
	struct kthread_work___73 work;
	struct timer_list timer;
};

typedef int (*key_restrict_link_func_t___92)(struct key___92 *, const struct key_type *, const union key_payload *, struct key___92 *);

struct key_restriction___92;

struct key___92 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___96 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___92 *restrict_link;
};

struct key_restriction___92 {
	key_restrict_link_func_t___92 check;
	struct key___92 *key;
	struct key_type *keytype;
};

struct seq_operations___85 {
	void * (*start)(struct seq_file___87 *, loff_t *);
	void (*stop)(struct seq_file___87 *, void *);
	void * (*next)(struct seq_file___87 *, void *, loff_t *);
	int (*show)(struct seq_file___87 *, void *);
};

struct uts_namespace___20 {
	struct kref kref;
	struct new_utsname name;
	struct user_namespace___77 *user_ns;
	struct ucounts___77 *ucounts;
	struct ns_common___7 ns;
};

struct cgroup_namespace___73 {
	refcount_t count;
	struct ns_common___7 ns;
	struct user_namespace___77 *user_ns;
	struct ucounts___77 *ucounts;
	struct css_set___73 *root_cset;
};

struct ucounts___77 {
	struct hlist_node node;
	struct user_namespace___77 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___73;

struct bpf_map_ops___73 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___73 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___73 *, struct file___96 *);
	void (*map_free)(struct bpf_map___73 *);
	int (*map_get_next_key)(struct bpf_map___73 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___73 *);
	void * (*map_lookup_elem)(struct bpf_map___73 *, void *);
	int (*map_update_elem)(struct bpf_map___73 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___73 *, void *);
	int (*map_push_elem)(struct bpf_map___73 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___73 *, void *);
	int (*map_peek_elem)(struct bpf_map___73 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___73 *, struct file___96 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___73 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___73 *, void *, struct seq_file___87 *);
	int (*map_check_btf)(const struct bpf_map___73 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___73 {
	const struct bpf_map_ops___73 *ops;
	struct bpf_map___73 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___92 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct psi_group___73 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___73 *poll_kworker;
	struct kthread_delayed_work___73 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___73;

struct cgroup_rstat_cpu___73;

struct cgroup___73 {
	struct cgroup_subsys_state___73 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___92 *kn;
	struct cgroup_file___73 procs_file;
	struct cgroup_file___73 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___73 *subsys[13];
	struct cgroup_root___73 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___73 *dom_cgrp;
	struct cgroup_rstat_cpu___73 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___8 bpf;
	atomic_t congestion_count;
	struct cgroup___73 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___73 psi;
	int ancestor_ids[0];
};

struct cftype___73;

struct cgroup_subsys___73 {
	struct cgroup_subsys_state___73 * (*css_alloc)(struct cgroup_subsys_state___73 *);
	int (*css_online)(struct cgroup_subsys_state___73 *);
	void (*css_offline)(struct cgroup_subsys_state___73 *);
	void (*css_released)(struct cgroup_subsys_state___73 *);
	void (*css_free)(struct cgroup_subsys_state___73 *);
	void (*css_reset)(struct cgroup_subsys_state___73 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___73 *, int);
	int (*css_extra_stat_show)(struct seq_file___87 *, struct cgroup_subsys_state___73 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___96 *);
	void (*cancel_fork)(struct task_struct___96 *);
	void (*fork)(struct task_struct___96 *);
	void (*exit)(struct task_struct___96 *);
	void (*free)(struct task_struct___96 *);
	void (*bind)(struct cgroup_subsys_state___73 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___73 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___73 *dfl_cftypes;
	struct cftype___73 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___73 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___73 *updated_children;
	struct cgroup___73 *updated_next;
};

struct cgroup_root___73 {
	struct kernfs_root___92 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___73 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___73 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___73 *ss;
	struct list_head node;
	struct kernfs_ops___92 *kf_ops;
	int (*open)(struct kernfs_open_file___92 *);
	void (*release)(struct kernfs_open_file___92 *);
	u64 (*read_u64)(struct cgroup_subsys_state___73 *, struct cftype___73 *);
	s64 (*read_s64)(struct cgroup_subsys_state___73 *, struct cftype___73 *);
	int (*seq_show)(struct seq_file___87 *, void *);
	void * (*seq_start)(struct seq_file___87 *, loff_t *);
	void * (*seq_next)(struct seq_file___87 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___87 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___73 *, struct cftype___73 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___73 *, struct cftype___73 *, s64);
	ssize_t (*write)(struct kernfs_open_file___92 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___92 *, struct poll_table_struct___6 *);
};

struct bdi_writeback_congested___37 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___37 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___37 {
	struct bio___37 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___37 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___37 bip_inline_vecs[0];
};

struct bio_set___37 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___37 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___34 {
	struct mem_cgroup___34 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___34 {
	struct lruvec___95 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___34 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___34 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct linux_binprm___14 {
	char buf[256];
	struct vm_area_struct___96 *vma;
	long unsigned int vma_pages;
	struct mm_struct___95 *mm;
	long unsigned int p;
	unsigned int called_set_creds: 1;
	unsigned int cap_elevated: 1;
	unsigned int secureexec: 1;
	unsigned int recursion_depth;
	struct file___96 *file;
	struct cred___92 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
};

struct coredump_params___13 {
	union {
		const kernel_siginfo_t *siginfo;
		struct {
			const siginfo_t *siginfo;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	struct pt_regs *regs;
	struct file___96 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
};

struct module___82;

struct file___97;

struct kiocb___97;

struct iov_iter___38;

struct poll_table_struct___61;

struct vm_area_struct___97;

struct inode___98;

struct file_lock___97;

struct page___97;

struct pipe_inode_info___20;

struct seq_file___88;

struct file_operations___97 {
	struct module___82 *owner;
	loff_t (*llseek)(struct file___97 *, loff_t, int);
	ssize_t (*read)(struct file___97 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___97 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___97 *, struct iov_iter___38 *);
	ssize_t (*write_iter)(struct kiocb___97 *, struct iov_iter___38 *);
	int (*iopoll)(struct kiocb___97 *, bool);
	int (*iterate)(struct file___97 *, struct dir_context *);
	int (*iterate_shared)(struct file___97 *, struct dir_context *);
	__poll_t (*poll)(struct file___97 *, struct poll_table_struct___61 *);
	long int (*unlocked_ioctl)(struct file___97 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___97 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___97 *, struct vm_area_struct___97 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___98 *, struct file___97 *);
	int (*flush)(struct file___97 *, fl_owner_t);
	int (*release)(struct inode___98 *, struct file___97 *);
	int (*fsync)(struct file___97 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___97 *, int);
	int (*lock)(struct file___97 *, int, struct file_lock___97 *);
	ssize_t (*sendpage)(struct file___97 *, struct page___97 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___97 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___97 *, int, struct file_lock___97 *);
	ssize_t (*splice_write)(struct pipe_inode_info___20 *, struct file___97 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___97 *, loff_t *, struct pipe_inode_info___20 *, size_t, unsigned int);
	int (*setlease)(struct file___97 *, long int, struct file_lock___97 **, void **);
	long int (*fallocate)(struct file___97 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___88 *, struct file___97 *);
	ssize_t (*copy_file_range)(struct file___97 *, loff_t, struct file___97 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___97 *, loff_t, struct file___97 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___97 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___96 {
	u64 seqnum;
	struct vm_area_struct___97 *vmas[4];
};

struct page_frag___96 {
	struct page___97 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___57;

struct debug_info___57 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___57 *hbp_break[16];
	struct perf_event___57 *hbp_watch[16];
};

struct thread_struct___57 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___57 debug;
	long: 64;
};

struct mm_struct___96;

struct mem_cgroup___35;

struct pid___80;

struct cred___93;

struct nsproxy___90;

struct signal_struct___87;

struct bio_list___38;

struct backing_dev_info___38;

struct io_context___16;

struct css_set___74;

struct perf_event_context___57;

struct request_queue___17;

struct vm_struct___68;

struct task_struct___97 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___97 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___96 *mm;
	struct mm_struct___96 *active_mm;
	struct vmacache___96 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___97 *real_parent;
	struct task_struct___97 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___97 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___35 *active_memcg;
	long int rh_reserved2;
	struct pid___80 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___80 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___80 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___93 *ptracer_cred;
	const struct cred___93 *real_cred;
	const struct cred___93 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___90 *nsproxy;
	struct signal_struct___87 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___97 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___38 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___38 *backing_dev_info;
	struct io_context___16 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___74 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___57 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___20 *splice_pipe;
	struct page_frag___96 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___35 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___17 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___97 *oom_reaper_list;
	struct vm_struct___68 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___57 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___57 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___97 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___57)(struct perf_event___57 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___57;

struct fasync_struct___96;

struct pid_namespace___80;

struct bpf_prog___9;

struct trace_event_call___52;

struct perf_cgroup___57;

struct perf_event___57 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___57 *group_leader;
	struct pmu___57 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___57 hw;
	struct perf_event_context___57 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___57 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___97 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___96 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___57 *);
	struct callback_head callback_head;
	struct pid_namespace___80 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___57 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___57 orig_overflow_handler;
	struct bpf_prog___9 *prog;
	struct trace_event_call___52 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___57 *cgrp;
	struct list_head sb_list;
};

struct upid___80 {
	int nr;
	struct pid_namespace___80 *ns;
};

struct dentry___97;

struct user_namespace___78;

struct ucounts___78;

struct pid_namespace___80 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___97 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___80 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___97 *proc_self;
	struct dentry___97 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___78 *user_ns;
	struct ucounts___78 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___7 ns;
};

struct pid___80 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___80 numbers[1];
};

struct rw_semaphore___97 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___97 *owner;
};

struct key___93;

struct user_namespace___78 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___78 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___7 ns;
	long unsigned int flags;
	struct key___93 *persistent_keyring_register;
	struct rw_semaphore___97 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___78 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct secondary_data___97 {
	void *stack;
	struct task_struct___97 *task;
	long int status;
};

typedef struct page___97 *pgtable_t___96;

struct address_space___96;

struct dev_pagemap___94;

struct page___97 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___96 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___97 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___96 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___96 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___94 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___35 *mem_cgroup;
};

struct seccomp_filter {
	refcount_t usage;
	bool log;
	struct seccomp_filter *prev;
	struct bpf_prog___9 *prog;
};

struct user_struct___93 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___93 *uid_keyring;
	struct key___93 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___94;

struct vm_area_struct___97 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___97 *vm_next;
	struct vm_area_struct___97 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___96 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___94 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___97 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___96;

struct mm_struct___96 {
	struct {
		struct vm_area_struct___97 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___97 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___97 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___96 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___97 *owner;
		struct user_namespace___78 *user_ns;
		struct file___97 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___96 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup___74;

struct cgroup_subsys___74;

struct cgroup_subsys_state___74 {
	struct cgroup___74 *cgroup;
	struct cgroup_subsys___74 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___74 *parent;
};

struct mem_cgroup_id___15 {
	int id;
	union {
		refcount_t ref;
		struct {
			atomic_t ref;
		} __UNIQUE_ID_rh_kabi_hide60;
		union {		};
	};
};

struct kernfs_node___93;

struct cgroup_file___74 {
	struct kernfs_node___93 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___35;

struct mem_cgroup___35 {
	struct cgroup_subsys_state___74 css;
	struct mem_cgroup_id___15 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___74 events_file;
	struct cgroup_file___74 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___97 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___35 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cred___93 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___93 *session_keyring;
	struct key___93 *process_keyring;
	struct key___93 *thread_keyring;
	struct key___93 *request_key_auth;
	void *security;
	struct user_struct___93 *user;
	struct user_namespace___78 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___19;

struct cgroup_namespace___74;

struct nsproxy___90 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___80 *pid_ns_for_children;
	struct net___19 *net_ns;
	struct cgroup_namespace___74 *cgroup_ns;
};

struct signal_struct___87 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___97 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___97 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___80 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___80 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___96 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___80 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___38;

struct bio_list___38 {
	struct bio___38 *head;
	struct bio___38 *tail;
};

struct bdi_writeback_congested___38;

struct bdi_writeback___38 {
	struct backing_dev_info___38 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___38 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___74 *memcg_css;
	struct cgroup_subsys_state___74 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___88;

struct backing_dev_info___38 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___38 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___88 *dev;
	struct device___88 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___97 *debug_dir;
	struct dentry___97 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___16;

struct io_context___16 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___16 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___74 {
	struct cgroup_subsys_state___74 *subsys[13];
	refcount_t refcount;
	struct css_set___74 *dom_cset;
	struct cgroup___74 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___74 *mg_src_cgrp;
	struct cgroup___74 *mg_dst_cgrp;
	struct css_set___74 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___57 {
	struct pmu___57 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___97 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___57 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___20;

struct pipe_inode_info___20 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___97 *tmp_page;
	struct fasync_struct___96 *fasync_readers;
	struct fasync_struct___96 *fasync_writers;
	struct pipe_buffer___20 *bufs;
	struct user_struct___93 *user;
};

typedef blk_qc_t make_request_fn___16(struct request_queue___17 *, struct bio___38 *);

struct request___17;

typedef int dma_drain_needed_fn___16(struct request___17 *);

struct kset___90;

struct kobj_type___90;

struct kobject___91 {
	const char *name;
	struct list_head entry;
	struct kobject___91 *parent;
	struct kset___90 *kset;
	struct kobj_type___90 *ktype;
	struct kernfs_node___93 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___16;

struct bsg_class_device___16 {
	struct device___88 *class_dev;
	int minor;
	struct request_queue___17 *queue;
	const struct bsg_ops___16 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___38 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___38 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___16;

struct blkcg_gq___9;

struct request_queue___17 {
	struct list_head queue_head;
	struct request___17 *last_merge;
	struct elevator_queue___16 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___16 *make_request_fn;
	dma_drain_needed_fn___16 *dma_drain_needed;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___38 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___91 kobj;
	struct kobject___91 *mq_kobj;
	struct blk_integrity integrity;
	struct device___88 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___9 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide62;
		union {		};
	};
	struct bsg_class_device___16 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___38 bio_split;
	struct dentry___97 *debugfs_dir;
	struct dentry___97 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___68 {
	struct vm_struct___68 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___97 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___87 {
	struct task_struct___97 task;
	long unsigned int stack[8192];
};

typedef int (*key_restrict_link_func_t___93)(struct key___93 *, const struct key_type *, const union key_payload *, struct key___93 *);

struct key_restriction___93;

struct key___93 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___97 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___93 *restrict_link;
};

struct key_restriction___93 {
	key_restrict_link_func_t___93 check;
	struct key___93 *key;
	struct key_type *keytype;
};

struct pglist_data___96;

struct lruvec___96 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___96 *pgdat;
};

struct zone___96 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___96 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___96 {
	struct zone___96 *zone;
	int zone_idx;
};

struct zonelist___96 {
	struct zoneref___96 _zonerefs[25];
};

struct pglist_data___96 {
	struct zone___96 node_zones[3];
	struct zonelist___96 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___97 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___97 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___96 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___96 {
	struct rw_semaphore___97 rwsem;
	struct notifier_block *head;
};

struct address_space_operations___96;

struct address_space___96 {
	struct inode___98 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___97 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___96 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___94)(struct vm_area_struct___97 *, long unsigned int, const struct page___97 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___94)(struct page___97 *, void *);

struct dev_pagemap___94 {
	dev_page_fault_t___94 page_fault;
	dev_page_free_t___94 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___88 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___96 {
	struct vfsmount *mnt;
	struct dentry___97 *dentry;
};

struct fown_struct___80 {
	rwlock_t lock;
	struct pid___80 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___97 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___96 f_path;
	struct inode___98 *f_inode;
	const struct file_operations___97 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___80 f_owner;
	const struct cred___93 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___96 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___94;

struct vm_operations_struct___94 {
	void (*open)(struct vm_area_struct___97 *);
	void (*close)(struct vm_area_struct___97 *);
	int (*split)(struct vm_area_struct___97 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___97 *);
	vm_fault_t (*fault)(struct vm_fault___94 *);
	vm_fault_t (*huge_fault)(struct vm_fault___94 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___94 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___97 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___94 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___94 *);
	int (*access)(struct vm_area_struct___97 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___97 *);
	int (*set_policy)(struct vm_area_struct___97 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___97 *, long unsigned int);
	struct page___97 * (*find_special_page)(struct vm_area_struct___97 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___96 {
	struct task_struct___97 *task;
	struct core_thread___96 *next;
};

struct core_state___96 {
	atomic_t nr_threads;
	struct core_thread___96 dumper;
	struct completion startup;
};

struct vm_fault___94 {
	struct vm_area_struct___97 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___97 *cow_page;
	struct mem_cgroup___35 *memcg;
	struct page___97 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___96 prealloc_pte;
};

struct shrink_control___35 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___35 *memcg;
};

struct shrinker___35 {
	long unsigned int (*count_objects)(struct shrinker___35 *, struct shrink_control___35 *);
	long unsigned int (*scan_objects)(struct shrinker___35 *, struct shrink_control___35 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct dev_pm_info___88 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___88 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___88;

struct bus_type___88;

struct device_driver___88;

struct dev_pm_domain___88;

struct dma_map_ops___25;

struct fwnode_handle___63;

struct class___88;

struct attribute_group___87;

struct device___88 {
	struct device___88 *parent;
	struct device_private *p;
	struct kobject___91 kobj;
	const char *init_name;
	const struct device_type___88 *type;
	struct mutex mutex;
	struct bus_type___88 *bus;
	struct device_driver___88 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___88 power;
	struct dev_pm_domain___88 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___25 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___63 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___88 *class;
	const struct attribute_group___87 **groups;
	void (*release)(struct device___88 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___96;

struct super_block___97;

struct dentry___97 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___97 *d_parent;
	struct qstr d_name;
	struct inode___98 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___96 *d_op;
	struct super_block___97 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___96;

struct block_device___97;

struct inode___98 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___96 *i_op;
	struct super_block___97 *i_sb;
	struct address_space___96 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___97 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___38 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___97 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___96 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___20 *i_pipe;
		struct block_device___97 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___96 {
	int (*d_revalidate)(struct dentry___97 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___97 *, unsigned int);
	int (*d_hash)(const struct dentry___97 *, struct qstr *);
	int (*d_compare)(const struct dentry___97 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___97 *);
	int (*d_init)(struct dentry___97 *);
	void (*d_release)(struct dentry___97 *);
	void (*d_prune)(struct dentry___97 *);
	void (*d_iput)(struct dentry___97 *, struct inode___98 *);
	char * (*d_dname)(struct dentry___97 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___96 *);
	int (*d_manage)(const struct path___96 *, bool);
	struct dentry___97 * (*d_real)(struct dentry___97 *, const struct inode___98 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___96;

struct mem_dqinfo___96 {
	struct quota_format_type___96 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___96;

struct quota_info___96 {
	unsigned int flags;
	struct rw_semaphore___97 dqio_sem;
	struct inode___98 *files[3];
	struct mem_dqinfo___96 info[3];
	const struct quota_format_ops___96 *ops[3];
};

struct rcuwait___96 {
	struct task_struct___97 *task;
};

struct percpu_rw_semaphore___96 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___97 rw_sem;
	struct rcuwait___96 writer;
	int readers_block;
};

struct sb_writers___96 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___96 rw_sem[3];
};

struct file_system_type___96;

struct super_operations___96;

struct dquot_operations___96;

struct quotactl_ops___96;

struct super_block___97 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___96 *s_type;
	const struct super_operations___96 *s_op;
	const struct dquot_operations___96 *dq_op;
	const struct quotactl_ops___96 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___97 *s_root;
	struct rw_semaphore___97 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___97 *s_bdev;
	struct backing_dev_info___38 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___96 s_dquot;
	struct sb_writers___96 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___96 *s_d_op;
	int cleancache_poolid;
	struct shrinker___35 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___78 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct io_cq___16 {
	struct request_queue___17 *q;
	struct io_context___16 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___97 {
	struct file___97 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___97 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___97 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___97 *ia_file;
};

struct dquot___96 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___97 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___96 {
	int qf_fmt_id;
	const struct quota_format_ops___96 *qf_ops;
	struct module___82 *qf_owner;
	struct quota_format_type___96 *qf_next;
};

struct quota_format_ops___96 {
	int (*check_quota_file)(struct super_block___97 *, int);
	int (*read_file_info)(struct super_block___97 *, int);
	int (*write_file_info)(struct super_block___97 *, int);
	int (*free_file_info)(struct super_block___97 *, int);
	int (*read_dqblk)(struct dquot___96 *);
	int (*commit_dqblk)(struct dquot___96 *);
	int (*release_dqblk)(struct dquot___96 *);
	int (*get_next_id)(struct super_block___97 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___96 {
	int (*write_dquot)(struct dquot___96 *);
	struct dquot___96 * (*alloc_dquot)(struct super_block___97 *, int);
	void (*destroy_dquot)(struct dquot___96 *);
	int (*acquire_dquot)(struct dquot___96 *);
	int (*release_dquot)(struct dquot___96 *);
	int (*mark_dirty)(struct dquot___96 *);
	int (*write_info)(struct super_block___97 *, int);
	qsize_t * (*get_reserved_space)(struct inode___98 *);
	int (*get_projid)(struct inode___98 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___98 *, qsize_t *);
	int (*get_next_id)(struct super_block___97 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___96 {
	int (*quota_on)(struct super_block___97 *, int, int, const struct path___96 *);
	int (*quota_off)(struct super_block___97 *, int);
	int (*quota_enable)(struct super_block___97 *, unsigned int);
	int (*quota_disable)(struct super_block___97 *, unsigned int);
	int (*quota_sync)(struct super_block___97 *, int);
	int (*set_info)(struct super_block___97 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___97 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___97 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___97 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___97 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___97 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___79 {
	struct kobject___91 kobj;
	struct module___82 *mod;
	struct kobject___91 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___79 {
	struct module___82 *mod;
	struct latch_tree_node node;
};

struct module_layout___79 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___79 mtn;
};

struct module_attribute___79;

struct kernel_param___79;

struct module___82 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___79 mkobj;
	struct module_attribute___79 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___91 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___79 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___79 core_layout;
	struct module_layout___79 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___52 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___36;

struct address_space_operations___96 {
	int (*writepage)(struct page___97 *, struct writeback_control___36 *);
	int (*readpage)(struct file___97 *, struct page___97 *);
	int (*writepages)(struct address_space___96 *, struct writeback_control___36 *);
	int (*set_page_dirty)(struct page___97 *);
	int (*readpages)(struct file___97 *, struct address_space___96 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___97 *, struct address_space___96 *, loff_t, unsigned int, unsigned int, struct page___97 **, void **);
	int (*write_end)(struct file___97 *, struct address_space___96 *, loff_t, unsigned int, unsigned int, struct page___97 *, void *);
	sector_t (*bmap)(struct address_space___96 *, sector_t);
	void (*invalidatepage)(struct page___97 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___97 *, gfp_t);
	void (*freepage)(struct page___97 *);
	ssize_t (*direct_IO)(struct kiocb___97 *, struct iov_iter___38 *);
	int (*migratepage)(struct address_space___96 *, struct page___97 *, struct page___97 *, enum migrate_mode);
	bool (*isolate_page)(struct page___97 *, isolate_mode_t);
	void (*putback_page)(struct page___97 *);
	int (*launder_page)(struct page___97 *);
	int (*is_partially_uptodate)(struct page___97 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___97 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___96 *, struct page___97 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___97 *, sector_t *);
	void (*swap_deactivate)(struct file___97 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___36 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___38 *wb;
	struct inode___98 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___38;

struct iov_iter___38 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___38 *bvec;
		struct pipe_inode_info___20 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct hd_struct___17;

struct gendisk___17;

struct block_device___97 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___98 *bd_inode;
	struct super_block___97 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___97 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___17 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___17 *bd_disk;
	struct request_queue___17 *bd_queue;
	struct backing_dev_info___38 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct hd_struct___17 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___88 __dev;
	struct kobject___91 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___17;

struct block_device_operations___17;

struct gendisk___17 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___17 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___17 *part_tbl;
	struct hd_struct___17 part0;
	const struct block_device_operations___17 *fops;
	struct request_queue___17 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___97 lookup_sem;
	struct kobject___91 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___91 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___96 {
	struct dentry___97 * (*lookup)(struct inode___98 *, struct dentry___97 *, unsigned int);
	const char * (*get_link)(struct dentry___97 *, struct inode___98 *, struct delayed_call *);
	int (*permission)(struct inode___98 *, int);
	struct posix_acl * (*get_acl)(struct inode___98 *, int);
	int (*readlink)(struct dentry___97 *, char *, int);
	int (*create)(struct inode___98 *, struct dentry___97 *, umode_t, bool);
	int (*link)(struct dentry___97 *, struct inode___98 *, struct dentry___97 *);
	int (*unlink)(struct inode___98 *, struct dentry___97 *);
	int (*symlink)(struct inode___98 *, struct dentry___97 *, const char *);
	int (*mkdir)(struct inode___98 *, struct dentry___97 *, umode_t);
	int (*rmdir)(struct inode___98 *, struct dentry___97 *);
	int (*mknod)(struct inode___98 *, struct dentry___97 *, umode_t, dev_t);
	int (*rename)(struct inode___98 *, struct dentry___97 *, struct inode___98 *, struct dentry___97 *, unsigned int);
	int (*setattr)(struct dentry___97 *, struct iattr___97 *);
	int (*getattr)(const struct path___96 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___97 *, char *, size_t);
	int (*fiemap)(struct inode___98 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___98 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___98 *, struct dentry___97 *, struct file___97 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___98 *, struct dentry___97 *, umode_t);
	int (*set_acl)(struct inode___98 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___96 {
	void (*fl_copy_lock)(struct file_lock___97 *, struct file_lock___97 *);
	void (*fl_release_private)(struct file_lock___97 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___96;

struct file_lock___97 {
	struct file_lock___97 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___97 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___96 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___96 *fl_ops;
	const struct lock_manager_operations___96 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___96 {
	int (*lm_compare_owner)(struct file_lock___97 *, struct file_lock___97 *);
	long unsigned int (*lm_owner_key)(struct file_lock___97 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___97 *);
	int (*lm_grant)(struct file_lock___97 *, int);
	bool (*lm_break)(struct file_lock___97 *);
	int (*lm_change)(struct file_lock___97 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___97 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___96 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___96 *fa_next;
	struct file___97 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___96 {
	const char *name;
	int fs_flags;
	struct dentry___97 * (*mount)(struct file_system_type___96 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___97 *);
	struct module___82 *owner;
	struct file_system_type___96 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___96 {
	struct inode___98 * (*alloc_inode)(struct super_block___97 *);
	void (*destroy_inode)(struct inode___98 *);
	void (*dirty_inode)(struct inode___98 *, int);
	int (*write_inode)(struct inode___98 *, struct writeback_control___36 *);
	int (*drop_inode)(struct inode___98 *);
	void (*evict_inode)(struct inode___98 *);
	void (*put_super)(struct super_block___97 *);
	int (*sync_fs)(struct super_block___97 *, int);
	int (*freeze_super)(struct super_block___97 *);
	int (*freeze_fs)(struct super_block___97 *);
	int (*thaw_super)(struct super_block___97 *);
	int (*unfreeze_fs)(struct super_block___97 *);
	int (*statfs)(struct dentry___97 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___97 *, int *, char *);
	void (*umount_begin)(struct super_block___97 *);
	int (*show_options)(struct seq_file___88 *, struct dentry___97 *);
	int (*show_devname)(struct seq_file___88 *, struct dentry___97 *);
	int (*show_path)(struct seq_file___88 *, struct dentry___97 *);
	int (*show_stats)(struct seq_file___88 *, struct dentry___97 *);
	ssize_t (*quota_read)(struct super_block___97 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___97 *, int, const char *, size_t, loff_t);
	struct dquot___96 ** (*get_dquots)(struct inode___98 *);
	int (*bdev_try_to_free_page)(struct super_block___97 *, struct page___97 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___97 *, struct shrink_control___35 *);
	long int (*free_cached_objects)(struct super_block___97 *, struct shrink_control___35 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___60)(struct file___97 *, wait_queue_head_t *, struct poll_table_struct___61 *);

struct poll_table_struct___61 {
	poll_queue_proc___60 _qproc;
	__poll_t _key;
};

struct seq_operations___86;

struct seq_file___88 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___86 *op;
	int poll_event;
	const struct file___97 *file;
	void *private;
};

typedef void bio_end_io_t___38(struct bio___38 *);

struct bio_vec___38 {
	struct page___97 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___38;

struct bio___38 {
	struct bio___38 *bi_next;
	struct gendisk___17 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___38 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___9 *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___38 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___38 *bi_io_vec;
	struct bio_set___38 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___38 bi_inline_vecs[0];
};

struct kobj_attribute___91 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___91 *, struct kobj_attribute___91 *, char *);
	ssize_t (*store)(struct kobject___91 *, struct kobj_attribute___91 *, const char *, size_t);
};

typedef void compound_page_dtor___94(struct page___97 *);

struct inet_frags___10;

struct netns_frags___10 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___10 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv4___10 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct sock *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock **tcp_sk;
	struct netns_frags___10 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct net_device___15;

struct sk_buff___14;

struct dst_ops___17 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___17 *);
	struct dst_entry___2 * (*check)(struct dst_entry___2 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___2 *);
	unsigned int (*mtu)(const struct dst_entry___2 *);
	u32 * (*cow_metrics)(struct dst_entry___2 *, long unsigned int);
	void (*destroy)(struct dst_entry___2 *);
	void (*ifdown)(struct dst_entry___2 *, struct net_device___15 *, int);
	struct dst_entry___2 * (*negative_advice)(struct dst_entry___2 *);
	void (*link_failure)(struct sk_buff___14 *);
	void (*update_pmtu)(struct dst_entry___2 *, struct sock *, struct sk_buff___14 *, u32);
	void (*redirect)(struct dst_entry___2 *, struct sock *, struct sk_buff___14 *);
	int (*local_out)(struct net___19 *, struct sock *, struct sk_buff___14 *);
	struct neighbour___2 * (*neigh_lookup)(const struct dst_entry___2 *, struct sk_buff___14 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___2 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___16 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___10 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___17 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct sock *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops *notifier_ops;
	struct fib_notifier_ops *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_nf_frag___10 {
	struct netns_frags___10 frags;
};

struct netns_xfrm___16 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___17 xfrm4_dst_ops;
	struct dst_ops___17 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct net___19 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___78 *user_ns;
	struct ucounts___78 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___7 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___15 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___10 ipv4;
	struct netns_ipv6___16 ipv6;
	struct netns_sctp___5 sctp;
	struct netns_nf nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___10 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock *nfnl;
	struct sock *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___16 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___9 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cgroup_namespace___74 {
	refcount_t count;
	struct ns_common___7 ns;
	struct user_namespace___78 *user_ns;
	struct ucounts___78 *ucounts;
	struct css_set___74 *root_cset;
};

struct ucounts___78 {
	struct hlist_node node;
	struct user_namespace___78 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct seccomp_metadata {
	__u64 filter_off;
	__u64 flags;
};

struct seq_operations___86 {
	void * (*start)(struct seq_file___88 *, loff_t *);
	void (*stop)(struct seq_file___88 *, void *);
	void * (*next)(struct seq_file___88 *, void *, loff_t *);
	int (*show)(struct seq_file___88 *, void *);
};

struct kernfs_root___93;

struct kernfs_elem_dir___93 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___93 *root;
};

struct kernfs_syscall_ops___93;

struct kernfs_root___93 {
	struct kernfs_node___93 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___93 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___93 {
	struct kernfs_node___93 *target_kn;
};

struct kernfs_ops___93;

struct kernfs_elem_attr___93 {
	const struct kernfs_ops___93 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___93 *notify_next;
};

struct kernfs_node___93 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___93 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___93 dir;
		struct kernfs_elem_symlink___93 symlink;
		struct kernfs_elem_attr___93 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___93;

struct kernfs_ops___93 {
	int (*open)(struct kernfs_open_file___93 *);
	void (*release)(struct kernfs_open_file___93 *);
	int (*seq_show)(struct seq_file___88 *, void *);
	void * (*seq_start)(struct seq_file___88 *, loff_t *);
	void * (*seq_next)(struct seq_file___88 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___88 *, void *);
	ssize_t (*read)(struct kernfs_open_file___93 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___93 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___93 *, struct vm_area_struct___97 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___93 *, struct poll_table_struct___61 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___93 {
	int (*remount_fs)(struct kernfs_root___93 *, int *, char *);
	int (*show_options)(struct seq_file___88 *, struct kernfs_root___93 *);
	int (*mkdir)(struct kernfs_node___93 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___93 *);
	int (*rename)(struct kernfs_node___93 *, struct kernfs_node___93 *, const char *);
	int (*show_path)(struct seq_file___88 *, struct kernfs_node___93 *, struct kernfs_root___93 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___93 {
	struct kernfs_node___93 *kn;
	struct file___97 *file;
	struct seq_file___88 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___94 *vm_ops;
};

struct bin_attribute___87;

struct attribute_group___87 {
	const char *name;
	umode_t (*is_visible)(struct kobject___91 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___91 *, struct bin_attribute___87 *, int);
	struct attribute **attrs;
	struct bin_attribute___87 **bin_attrs;
};

struct bin_attribute___87 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___97 *, struct kobject___91 *, struct bin_attribute___87 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___97 *, struct kobject___91 *, struct bin_attribute___87 *, char *, loff_t, size_t);
	int (*mmap)(struct file___97 *, struct kobject___91 *, struct bin_attribute___87 *, struct vm_area_struct___97 *);
};

struct sysfs_ops___90 {
	ssize_t (*show)(struct kobject___91 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___91 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___90;

struct kset___90 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___91 kobj;
	const struct kset_uevent_ops___90 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___90 {
	void (*release)(struct kobject___91 *);
	const struct sysfs_ops___90 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___5 * (*child_ns_type)(struct kobject___91 *);
	const void * (*namespace)(struct kobject___91 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___90 {
	int (* const filter)(struct kset___90 *, struct kobject___91 *);
	const char * (* const name)(struct kset___90 *, struct kobject___91 *);
	int (* const uevent)(struct kset___90 *, struct kobject___91 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___79 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___79 *);
	int (*get)(char *, const struct kernel_param___79 *);
	void (*free)(void *);
};

struct kparam_array___79;

struct kernel_param___79 {
	const char *name;
	struct module___82 *mod;
	const struct kernel_param_ops___79 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___79 *arr;
	};
};

struct kparam_array___79 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___79 *ops;
	void *elem;
};

struct module_attribute___79 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___79 *, struct module_kobject___79 *, char *);
	ssize_t (*store)(struct module_attribute___79 *, struct module_kobject___79 *, const char *, size_t);
	void (*setup)(struct module___82 *, const char *);
	int (*test)(struct module___82 *);
	void (*free)(struct module___82 *);
};

struct trace_event_class___52;

struct bpf_prog_array___9;

struct trace_event_call___52 {
	struct list_head list;
	struct trace_event_class___52 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___9 *prog_array;
	int (*perf_perm)(struct trace_event_call___52 *, struct perf_event___57 *);
};

struct dev_pm_ops___88 {
	int (*prepare)(struct device___88 *);
	void (*complete)(struct device___88 *);
	int (*suspend)(struct device___88 *);
	int (*resume)(struct device___88 *);
	int (*freeze)(struct device___88 *);
	int (*thaw)(struct device___88 *);
	int (*poweroff)(struct device___88 *);
	int (*restore)(struct device___88 *);
	int (*suspend_late)(struct device___88 *);
	int (*resume_early)(struct device___88 *);
	int (*freeze_late)(struct device___88 *);
	int (*thaw_early)(struct device___88 *);
	int (*poweroff_late)(struct device___88 *);
	int (*restore_early)(struct device___88 *);
	int (*suspend_noirq)(struct device___88 *);
	int (*resume_noirq)(struct device___88 *);
	int (*freeze_noirq)(struct device___88 *);
	int (*thaw_noirq)(struct device___88 *);
	int (*poweroff_noirq)(struct device___88 *);
	int (*restore_noirq)(struct device___88 *);
	int (*runtime_suspend)(struct device___88 *);
	int (*runtime_resume)(struct device___88 *);
	int (*runtime_idle)(struct device___88 *);
};

struct dev_pm_domain___88 {
	struct dev_pm_ops___88 ops;
	void (*detach)(struct device___88 *, bool);
	int (*activate)(struct device___88 *);
	void (*sync)(struct device___88 *);
	void (*dismiss)(struct device___88 *);
};

struct bus_type___88 {
	const char *name;
	const char *dev_name;
	struct device___88 *dev_root;
	const struct attribute_group___87 **bus_groups;
	const struct attribute_group___87 **dev_groups;
	const struct attribute_group___87 **drv_groups;
	int (*match)(struct device___88 *, struct device_driver___88 *);
	int (*uevent)(struct device___88 *, struct kobj_uevent_env *);
	int (*probe)(struct device___88 *);
	int (*remove)(struct device___88 *);
	void (*shutdown)(struct device___88 *);
	int (*online)(struct device___88 *);
	int (*offline)(struct device___88 *);
	int (*suspend)(struct device___88 *, pm_message_t);
	int (*resume)(struct device___88 *);
	int (*num_vf)(struct device___88 *);
	int (*dma_configure)(struct device___88 *);
	const struct dev_pm_ops___88 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___88 {
	const char *name;
	struct bus_type___88 *bus;
	struct module___82 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___88 *);
	int (*remove)(struct device___88 *);
	void (*shutdown)(struct device___88 *);
	int (*suspend)(struct device___88 *, pm_message_t);
	int (*resume)(struct device___88 *);
	const struct attribute_group___87 **groups;
	const struct dev_pm_ops___88 *pm;
	void (*coredump)(struct device___88 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___88 {
	const char *name;
	const struct attribute_group___87 **groups;
	int (*uevent)(struct device___88 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___88 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___88 *);
	const struct dev_pm_ops___88 *pm;
};

struct class___88 {
	const char *name;
	struct module___82 *owner;
	const struct attribute_group___87 **class_groups;
	const struct attribute_group___87 **dev_groups;
	struct kobject___91 *dev_kobj;
	int (*dev_uevent)(struct device___88 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___88 *, umode_t *);
	void (*class_release)(struct class___88 *);
	void (*dev_release)(struct device___88 *);
	int (*shutdown_pre)(struct device___88 *);
	const struct kobj_ns_type_operations___5 *ns_type;
	const void * (*namespace)(struct device___88 *);
	const struct dev_pm_ops___88 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___25 {
	void * (*alloc)(struct device___88 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___88 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___88 *, struct vm_area_struct___97 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___88 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___88 *, struct page___97 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___88 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___88 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___88 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___88 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___88 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___88 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide21;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___88 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___88 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___88 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___88 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___88 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___88 *, u64);
	u64 (*get_required_mask)(struct device___88 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___63;

struct fwnode_handle___63 {
	struct fwnode_handle___63 *secondary;
	const struct fwnode_operations___63 *ops;
};

struct node___75 {
	struct device___88 dev;
};

struct bpf_map___74;

struct bpf_map_ops___74 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___74 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___74 *, struct file___97 *);
	void (*map_free)(struct bpf_map___74 *);
	int (*map_get_next_key)(struct bpf_map___74 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___74 *);
	void * (*map_lookup_elem)(struct bpf_map___74 *, void *);
	int (*map_update_elem)(struct bpf_map___74 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___74 *, void *);
	int (*map_push_elem)(struct bpf_map___74 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___74 *, void *);
	int (*map_peek_elem)(struct bpf_map___74 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___74 *, struct file___97 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___74 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___74 *, void *, struct seq_file___88 *);
	int (*map_check_btf)(const struct bpf_map___74 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___74 {
	const struct bpf_map_ops___74 *ops;
	struct bpf_map___74 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___93 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___10;

struct bpf_map_dev_ops___10 {
	int (*map_get_next_key)(struct bpf_offloaded_map___10 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___10 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___10 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___10 *, void *);
};

struct bpf_offloaded_map___10 {
	struct bpf_map___74 map;
	struct net_device___15 *netdev;
	const struct bpf_map_dev_ops___10 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

typedef rx_handler_result_t rx_handler_func_t___10(struct sk_buff___14 **);

typedef struct {
	struct net___19 *net;
} possible_net_t___10;

struct net_device_ops___10;

struct ethtool_ops___10;

struct xfrmdev_ops___10;

struct tlsdev_ops___10;

struct header_ops___10;

struct netdev_rx_queue___10;

struct mini_Qdisc___9;

struct netdev_queue___10;

struct Qdisc___9;

struct rtnl_link_ops___9;

struct dcbnl_rtnl_ops___10;

struct net_device___15 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___10 *netdev_ops;
	const struct ethtool_ops___10 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___2 *l3mdev_ops;
	const struct ndisc_ops___2 *ndisc_ops;
	const struct xfrmdev_ops___10 *xfrmdev_ops;
	const struct tlsdev_ops___10 *tlsdev_ops;
	const struct header_ops___10 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___90 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___2 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___10 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___9 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___10 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___9 *miniq_ingress;
	struct netdev_queue___10 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___10 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___9 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___9 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___10 = 0,
		NETREG_REGISTERED___10 = 1,
		NETREG_UNREGISTERING___10 = 2,
		NETREG_UNREGISTERED___10 = 3,
		NETREG_RELEASED___10 = 4,
		NETREG_DUMMY___10 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___10 = 0,
		RTNL_LINK_INITIALIZING___10 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___15 *);
	struct netpoll_info *npinfo;
	possible_net_t___10 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___88 dev;
	const struct attribute_group___87 *sysfs_groups[4];
	const struct attribute_group___87 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___9 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___10 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide37;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct bpf_prog_ops___9 {
	int (*test_run)(struct bpf_prog___9 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_aux___9;

struct bpf_prog___9 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___9 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

struct bpf_verifier_ops___9 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___9 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___9 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___9 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___9 *, u32 *);
};

struct bpf_prog_offload_ops___9 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___9 *);
	int (*translate)(struct bpf_prog___9 *);
	void (*destroy)(struct bpf_prog___9 *);
};

struct bpf_prog_offload___9 {
	struct bpf_prog___9 *prog;
	struct net_device___15 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___9 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___9 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___9 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___9 *ops;
	struct bpf_map___74 **used_maps;
	struct bpf_prog___9 *prog;
	struct user_struct___93 *user;
	u64 load_time;
	struct bpf_map___74 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___9 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___9 {
	struct bpf_prog___9 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___9 {
	struct callback_head rcu;
	struct bpf_prog_array_item___9 items[0];
};

struct cgroup_bpf___9 {
	struct bpf_prog_array___9 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___9 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___74;

typedef void (*kthread_work_func_t___74)(struct kthread_work___74 *);

struct kthread_worker___74;

struct kthread_work___74 {
	struct list_head node;
	kthread_work_func_t___74 func;
	struct kthread_worker___74 *worker;
	int canceling;
};

struct kthread_worker___74 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___97 *task;
	struct kthread_work___74 *current_work;
};

struct kthread_delayed_work___74 {
	struct kthread_work___74 work;
	struct timer_list timer;
};

struct psi_group___74 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___74 *poll_kworker;
	struct kthread_delayed_work___74 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___74;

struct cgroup_rstat_cpu___74;

struct cgroup___74 {
	struct cgroup_subsys_state___74 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___93 *kn;
	struct cgroup_file___74 procs_file;
	struct cgroup_file___74 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___74 *subsys[13];
	struct cgroup_root___74 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___74 *dom_cgrp;
	struct cgroup_rstat_cpu___74 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___9 bpf;
	atomic_t congestion_count;
	struct cgroup___74 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___74 psi;
	int ancestor_ids[0];
};

struct cftype___74;

struct cgroup_subsys___74 {
	struct cgroup_subsys_state___74 * (*css_alloc)(struct cgroup_subsys_state___74 *);
	int (*css_online)(struct cgroup_subsys_state___74 *);
	void (*css_offline)(struct cgroup_subsys_state___74 *);
	void (*css_released)(struct cgroup_subsys_state___74 *);
	void (*css_free)(struct cgroup_subsys_state___74 *);
	void (*css_reset)(struct cgroup_subsys_state___74 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___74 *, int);
	int (*css_extra_stat_show)(struct seq_file___88 *, struct cgroup_subsys_state___74 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___97 *);
	void (*cancel_fork)(struct task_struct___97 *);
	void (*fork)(struct task_struct___97 *);
	void (*exit)(struct task_struct___97 *);
	void (*free)(struct task_struct___97 *);
	void (*bind)(struct cgroup_subsys_state___74 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___74 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___74 *dfl_cftypes;
	struct cftype___74 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___74 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___74 *updated_children;
	struct cgroup___74 *updated_next;
};

struct cgroup_root___74 {
	struct kernfs_root___93 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___74 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___74 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___74 *ss;
	struct list_head node;
	struct kernfs_ops___93 *kf_ops;
	int (*open)(struct kernfs_open_file___93 *);
	void (*release)(struct kernfs_open_file___93 *);
	u64 (*read_u64)(struct cgroup_subsys_state___74 *, struct cftype___74 *);
	s64 (*read_s64)(struct cgroup_subsys_state___74 *, struct cftype___74 *);
	int (*seq_show)(struct seq_file___88 *, void *);
	void * (*seq_start)(struct seq_file___88 *, loff_t *);
	void * (*seq_next)(struct seq_file___88 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___88 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___74 *, struct cftype___74 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___74 *, struct cftype___74 *, s64);
	ssize_t (*write)(struct kernfs_open_file___93 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___93 *, struct poll_table_struct___61 *);
};

struct perf_cpu_context___57;

struct pmu___57 {
	struct list_head entry;
	struct module___82 *module;
	struct device___88 *dev;
	const struct attribute_group___87 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___57 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___57 *);
	void (*pmu_disable)(struct pmu___57 *);
	int (*event_init)(struct perf_event___57 *);
	void (*event_mapped)(struct perf_event___57 *, struct mm_struct___96 *);
	void (*event_unmapped)(struct perf_event___57 *, struct mm_struct___96 *);
	int (*add)(struct perf_event___57 *, int);
	void (*del)(struct perf_event___57 *, int);
	void (*start)(struct perf_event___57 *, int);
	void (*stop)(struct perf_event___57 *, int);
	void (*read)(struct perf_event___57 *);
	void (*start_txn)(struct pmu___57 *, unsigned int);
	int (*commit_txn)(struct pmu___57 *);
	void (*cancel_txn)(struct pmu___57 *);
	int (*event_idx)(struct perf_event___57 *);
	void (*sched_task)(struct perf_event_context___57 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___57 *);
	int (*filter_match)(struct perf_event___57 *);
	int (*check_period)(struct perf_event___57 *, u64);
};

struct perf_cpu_context___57 {
	struct perf_event_context___57 ctx;
	struct perf_event_context___57 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___57 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___57 {
	struct cgroup_subsys_state___74 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___52 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___52 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___52 *);
	struct list_head * (*get_fields)(struct trace_event_call___52 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___52 *);
};

struct syscall_metadata___23 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___52 *enter_event;
	struct trace_event_call___52 *exit_event;
};

struct nf_bridge_info___10;

struct sk_buff___14 {
	union {
		struct {
			struct sk_buff___14 *next;
			struct sk_buff___14 *prev;
			union {
				struct net_device___15 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___8 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___14 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___10 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct fwnode_reference_args___63;

struct fwnode_endpoint___63;

struct fwnode_operations___63 {
	struct fwnode_handle___63 * (*get)(struct fwnode_handle___63 *);
	void (*put)(struct fwnode_handle___63 *);
	bool (*device_is_available)(const struct fwnode_handle___63 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___63 *, const struct device___88 *);
	bool (*property_present)(const struct fwnode_handle___63 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___63 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___63 *, const char *, const char **, size_t);
	struct fwnode_handle___63 * (*get_parent)(const struct fwnode_handle___63 *);
	struct fwnode_handle___63 * (*get_next_child_node)(const struct fwnode_handle___63 *, struct fwnode_handle___63 *);
	struct fwnode_handle___63 * (*get_named_child_node)(const struct fwnode_handle___63 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___63 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___63 *);
	struct fwnode_handle___63 * (*graph_get_next_endpoint)(const struct fwnode_handle___63 *, struct fwnode_handle___63 *);
	struct fwnode_handle___63 * (*graph_get_remote_endpoint)(const struct fwnode_handle___63 *);
	struct fwnode_handle___63 * (*graph_get_port_parent)(struct fwnode_handle___63 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___63 *, struct fwnode_endpoint___63 *);
};

struct fwnode_endpoint___63 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___63 *local_fwnode;
};

struct fwnode_reference_args___63 {
	struct fwnode_handle___63 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___20;

struct pipe_buffer___20 {
	struct page___97 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___20 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___20 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___20 *, struct pipe_buffer___20 *);
	void (*release)(struct pipe_inode_info___20 *, struct pipe_buffer___20 *);
	int (*steal)(struct pipe_inode_info___20 *, struct pipe_buffer___20 *);
	union {
		bool (*get)(struct pipe_inode_info___20 *, struct pipe_buffer___20 *);
		struct {
			void (*get)(struct pipe_inode_info___20 *, struct pipe_buffer___20 *);
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
};

struct nf_bridge_info___10 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___10 = 0,
		BRNF_PROTO_8021Q___10 = 1,
		BRNF_PROTO_PPPOE___10 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___15 *physindev;
	struct net_device___15 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

struct sk_buff_head___11 {
	struct sk_buff___14 *next;
	struct sk_buff___14 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct ethtool_ops___10 {
	int (*get_settings)(struct net_device___15 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___15 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___15 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___15 *);
	void (*get_regs)(struct net_device___15 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___15 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___15 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___15 *);
	void (*set_msglevel)(struct net_device___15 *, u32);
	int (*nway_reset)(struct net_device___15 *);
	u32 (*get_link)(struct net_device___15 *);
	int (*get_eeprom_len)(struct net_device___15 *);
	int (*get_eeprom)(struct net_device___15 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___15 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___15 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___15 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___15 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___15 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___15 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___15 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___15 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___15 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___15 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___15 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___15 *);
	void (*complete)(struct net_device___15 *);
	u32 (*get_priv_flags)(struct net_device___15 *);
	int (*set_priv_flags)(struct net_device___15 *, u32);
	int (*get_sset_count)(struct net_device___15 *, int);
	int (*get_rxnfc)(struct net_device___15 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___15 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___15 *, struct ethtool_flash *);
	int (*reset)(struct net_device___15 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___15 *);
	u32 (*get_rxfh_indir_size)(struct net_device___15 *);
	int (*get_rxfh)(struct net_device___15 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___15 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___15 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___15 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___15 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___15 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___15 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___15 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___15 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___15 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___15 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___15 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___15 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___15 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___15 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___15 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___15 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___15 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___15 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___15 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___15 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___15 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	int (*get_fecparam)(struct net_device___15 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___15 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___15 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___15 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___15 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___10;

struct inet_frags___10 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___10 *, const void *);
	void (*destructor)(struct inet_frag_queue___10 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___10 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___14 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___14 *fragments_tail;
	struct sk_buff___14 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___10 *net;
	struct callback_head rcu;
};

struct pernet_operations___10 {
	struct list_head list;
	int (*init)(struct net___19 *);
	void (*exit)(struct net___19 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___10 {
	int (*ieee_getets)(struct net_device___15 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___15 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___15 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___15 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___15 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___15 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___15 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___15 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___15 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___15 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___15 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___15 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___15 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___15 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___15 *);
	u8 (*setstate)(struct net_device___15 *, u8);
	void (*getpermhwaddr)(struct net_device___15 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___15 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___15 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___15 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___15 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___15 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___15 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___15 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___15 *, int, u8 *);
	void (*setpfccfg)(struct net_device___15 *, int, u8);
	void (*getpfccfg)(struct net_device___15 *, int, u8 *);
	u8 (*setall)(struct net_device___15 *);
	u8 (*getcap)(struct net_device___15 *, int, u8 *);
	int (*getnumtcs)(struct net_device___15 *, int, u8 *);
	int (*setnumtcs)(struct net_device___15 *, int, u8);
	u8 (*getpfcstate)(struct net_device___15 *);
	void (*setpfcstate)(struct net_device___15 *, u8);
	void (*getbcncfg)(struct net_device___15 *, int, u32 *);
	void (*setbcncfg)(struct net_device___15 *, int, u32);
	void (*getbcnrp)(struct net_device___15 *, int, u8 *);
	void (*setbcnrp)(struct net_device___15 *, int, u8);
	int (*setapp)(struct net_device___15 *, u8, u16, u8);
	int (*getapp)(struct net_device___15 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___15 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___15 *, int, u8);
	u8 (*getdcbx)(struct net_device___15 *);
	u8 (*setdcbx)(struct net_device___15 *, u8);
	int (*peer_getappinfo)(struct net_device___15 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___15 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___15 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___15 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___15 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___15 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct xdp_rxq_info___10 {
	struct net_device___15 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___10 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___15 *dev_rx;
};

struct netlink_callback___10 {
	struct sk_buff___14 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___10 *);
	int (*dump)(struct sk_buff___14 *, struct netlink_callback___10 *);
	int (*done)(struct netlink_callback___10 *);
	void *data;
	struct module___82 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___10 {
	int (*create)(struct sk_buff___14 *, struct net_device___15 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___14 *, unsigned char *);
	int (*cache)(const struct neighbour___2 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___15 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___10 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___10 *, int);
	int poll_owner;
	struct net_device___15 *dev;
	struct sk_buff___14 *gro_list;
	struct sk_buff___14 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___10 {
	struct net_device___15 *dev;
	struct Qdisc___9 *qdisc;
	struct Qdisc___9 *qdisc_sleeping;
	struct kobject___91 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___15 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___9 {
	struct sk_buff___14 *head;
	struct sk_buff___14 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___9;

struct Qdisc___9 {
	int (*enqueue)(struct sk_buff___14 *, struct Qdisc___9 *, struct sk_buff___14 **);
	struct sk_buff___14 * (*dequeue)(struct Qdisc___9 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___9 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___10 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___11 gso_skb;
	struct qdisc_skb_head___9 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___9 *next_sched;
	struct sk_buff_head___11 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___10 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___91 kobj;
	struct net_device___15 *dev;
	long: 64;
	struct xdp_rxq_info___10 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___10)(struct net_device___15 *, struct sk_buff___14 *, struct net_device___15 *);

struct netdev_bpf___10 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___9 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___9 *prog;
			const struct bpf_prog_offload_ops___9 *ops;
		} verifier;
		struct {
			struct bpf_prog___9 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___10 *offmap;
		};
		struct {
			struct xdp_umem *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___10 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___14 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___10 {
	int (*tls_dev_add)(struct net_device___15 *, struct sock *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___15 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___15 *, struct sock *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___10 {
	int (*ndo_init)(struct net_device___15 *);
	void (*ndo_uninit)(struct net_device___15 *);
	int (*ndo_open)(struct net_device___15 *);
	int (*ndo_stop)(struct net_device___15 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___14 *, struct net_device___15 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___14 *, struct net_device___15 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___15 *, struct sk_buff___14 *, struct net_device___15 *, select_queue_fallback_t___10);
	void (*ndo_change_rx_flags)(struct net_device___15 *, int);
	void (*ndo_set_rx_mode)(struct net_device___15 *);
	int (*ndo_set_mac_address)(struct net_device___15 *, void *);
	int (*ndo_validate_addr)(struct net_device___15 *);
	int (*ndo_do_ioctl)(struct net_device___15 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___15 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___15 *, int);
	int (*ndo_neigh_setup)(struct net_device___15 *, struct neigh_parms___3 *);
	void (*ndo_tx_timeout)(struct net_device___15 *);
	void (*ndo_get_stats64)(struct net_device___15 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___15 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___15 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___15 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___15 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___15 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___15 *);
	int (*ndo_netpoll_setup)(struct net_device___15 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___15 *);
	int (*ndo_set_vf_mac)(struct net_device___15 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___15 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___15 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___15 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___15 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___15 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___15 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___15 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___15 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___15 *, int, struct sk_buff___14 *);
	int (*ndo_set_vf_guid)(struct net_device___15 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___15 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___15 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___15 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___15 *, const struct sk_buff___14 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___15 *, struct net_device___15 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___15 *, struct net_device___15 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___15 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___15 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___15 *, struct neighbour___2 *);
	void (*ndo_neigh_destroy)(struct net_device___15 *, struct neighbour___2 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___15 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___15 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___15 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___14 *, struct netlink_callback___10 *, struct net_device___15 *, struct net_device___15 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___15 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___15 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide35;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___14 *, u32, u32, struct net_device___15 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___15 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___15 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___15 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___15 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___15 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___15 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___15 *, struct net_device___15 *);
	void (*ndo_dfwd_del_station)(struct net_device___15 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___15 *);
	int (*ndo_set_tx_maxrate)(struct net_device___15 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___15 *);
	int (*ndo_change_proto_down)(struct net_device___15 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___15 *, struct sk_buff___14 *);
	void (*ndo_set_rx_headroom)(struct net_device___15 *, int);
	int (*ndo_bpf)(struct net_device___15 *, struct netdev_bpf___10 *);
	int (*ndo_xdp_xmit)(struct net_device___15 *, int, struct xdp_frame___10 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___15 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___15 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide36;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct tcf_proto___9;

struct mini_Qdisc___9 {
	struct tcf_proto___9 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___9 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___15 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___19 *, struct net_device___15 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___15 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___15 *, struct list_head *);
	size_t (*get_size)(const struct net_device___15 *);
	int (*fill_info)(struct sk_buff___14 *, const struct net_device___15 *);
	size_t (*get_xstats_size)(const struct net_device___15 *);
	int (*fill_xstats)(struct sk_buff___14 *, const struct net_device___15 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___15 *, struct net_device___15 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___15 *, const struct net_device___15 *);
	int (*fill_slave_info)(struct sk_buff___14 *, const struct net_device___15 *, const struct net_device___15 *);
	struct net___19 * (*get_link_net)(const struct net_device___15 *);
	size_t (*get_linkxstats_size)(const struct net_device___15 *, int);
	int (*fill_linkxstats)(struct sk_buff___14 *, const struct net_device___15 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___10 {
	struct list_head poll_list;
	struct sk_buff_head___11 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___10 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___9 *output_queue;
	struct Qdisc___9 **output_queue_tailp;
	struct sk_buff___14 *completion_queue;
	struct sk_buff_head___11 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___10 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___11 input_pkt_queue;
	struct napi_struct___10 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct gnet_dump___9 {
	spinlock_t *lock;
	struct sk_buff___14 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___9;

struct Qdisc_ops___9 {
	struct Qdisc_ops___9 *next;
	const struct Qdisc_class_ops___9 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___14 *, struct Qdisc___9 *, struct sk_buff___14 **);
	struct sk_buff___14 * (*dequeue)(struct Qdisc___9 *);
	struct sk_buff___14 * (*peek)(struct Qdisc___9 *);
	int (*init)(struct Qdisc___9 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___9 *);
	void (*destroy)(struct Qdisc___9 *);
	int (*change)(struct Qdisc___9 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___9 *);
	int (*change_tx_queue_len)(struct Qdisc___9 *, unsigned int);
	int (*dump)(struct Qdisc___9 *, struct sk_buff___14 *);
	int (*dump_stats)(struct Qdisc___9 *, struct gnet_dump___9 *);
	void (*ingress_block_set)(struct Qdisc___9 *, u32);
	void (*egress_block_set)(struct Qdisc___9 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___9 *);
	u32 (*egress_block_get)(struct Qdisc___9 *);
	struct module___82 *owner;
};

struct tcf_block___9;

struct Qdisc_class_ops___9 {
	unsigned int flags;
	struct netdev_queue___10 * (*select_queue)(struct Qdisc___9 *, struct tcmsg *);
	int (*graft)(struct Qdisc___9 *, long unsigned int, struct Qdisc___9 *, struct Qdisc___9 **, struct netlink_ext_ack *);
	struct Qdisc___9 * (*leaf)(struct Qdisc___9 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___9 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___9 *, u32);
	int (*change)(struct Qdisc___9 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___9 *, long unsigned int);
	void (*walk)(struct Qdisc___9 *, struct qdisc_walker *);
	struct tcf_block___9 * (*tcf_block)(struct Qdisc___9 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___9 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___9 *, long unsigned int);
	int (*dump)(struct Qdisc___9 *, long unsigned int, struct sk_buff___14 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___9 *, long unsigned int, struct gnet_dump___9 *);
};

struct tcf_chain___9;

struct tcf_block___9 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___19 *net;
	struct Qdisc___9 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___9 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___9;

struct tcf_proto_ops___9;

struct tcf_proto___9 {
	struct tcf_proto___9 *next;
	void *root;
	int (*classify)(struct sk_buff___14 *, const struct tcf_proto___9 *, struct tcf_result___9 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___9 *ops;
	struct tcf_chain___9 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___9 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___9 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___9 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___14 *, const struct tcf_proto___9 *, struct tcf_result___9 *);
	int (*init)(struct tcf_proto___9 *);
	void (*destroy)(struct tcf_proto___9 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___9 *, u32);
	void (*put)(struct tcf_proto___9 *, void *);
	int (*change)(struct net___19 *, struct sk_buff___14 *, struct tcf_proto___9 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___9 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___9 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___9 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___19 *, struct tcf_chain___9 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___19 *, struct tcf_proto___9 *, void *, struct sk_buff___14 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___14 *, struct net___19 *, void *);
	struct module___82 *owner;
	int flags;
};

struct tcf_chain___9 {
	struct mutex filter_chain_lock;
	struct tcf_proto___9 *filter_chain;
	struct list_head list;
	struct tcf_block___9 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___9 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sock_fprog {
	short unsigned int len;
	struct sock_filter *filter;
};

struct bpf_redirect_info___9 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___74 *map;
	struct bpf_map___74 *map_to_flush;
	u32 kern_flags;
};

struct bdi_writeback_congested___38 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___38 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___38 {
	struct bio___38 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___38 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___38 bip_inline_vecs[0];
};

struct blkcg___9;

struct blkg_policy_data___9;

struct blkcg_gq___9 {
	struct request_queue___17 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___9 *blkcg;
	struct bdi_writeback_congested___38 *wb_congested;
	struct blkcg_gq___9 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_rwstat stat_bytes;
	struct blkg_rwstat stat_ios;
	struct blkg_policy_data___9 *pd[5];
	struct callback_head callback_head;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
};

struct mem_cgroup_reclaim_iter___35 {
	struct mem_cgroup___35 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___35 {
	struct lruvec___96 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___35 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___35 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct disk_part_tbl___17 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___17 *last_lookup;
	struct hd_struct___17 *part[0];
};

struct block_device_operations___17 {
	int (*open)(struct block_device___97 *, fmode_t);
	void (*release)(struct gendisk___17 *, fmode_t);
	int (*rw_page)(struct block_device___97 *, sector_t, struct page___97 *, unsigned int);
	int (*ioctl)(struct block_device___97 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___97 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___17 *, unsigned int);
	int (*media_changed)(struct gendisk___17 *);
	void (*unlock_native_capacity)(struct gendisk___17 *);
	int (*revalidate_disk)(struct gendisk___17 *);
	int (*getgeo)(struct block_device___97 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___97 *, long unsigned int);
	int (*report_zones)(struct gendisk___17 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___82 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___16 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___17 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___17 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___17 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___16(struct request___17 *, blk_status_t);

struct request___17 {
	struct request_queue___17 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___38 *bio;
	struct bio___38 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___38 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___16 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___16 *saved_end_io;
		} flush;
	};
	struct gendisk___17 *rq_disk;
	struct hd_struct___17 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___16 *end_io;
	void *end_io_data;
	struct request___17 *next_rq;
};

struct elevator_type___16;

struct elevator_mq_ops___16 {
	int (*init_sched)(struct request_queue___17 *, struct elevator_type___16 *);
	void (*exit_sched)(struct elevator_queue___16 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	bool (*allow_merge)(struct request_queue___17 *, struct request___17 *, struct bio___38 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx *, struct bio___38 *);
	int (*request_merge)(struct request_queue___17 *, struct request___17 **, struct bio___38 *);
	void (*request_merged)(struct request_queue___17 *, struct request___17 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___17 *, struct request___17 *, struct request___17 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___17 *, struct bio___38 *);
	void (*finish_request)(struct request___17 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___17 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___17 *, u64);
	void (*started_request)(struct request___17 *);
	void (*requeue_request)(struct request___17 *);
	struct request___17 * (*former_request)(struct request_queue___17 *, struct request___17 *);
	struct request___17 * (*next_request)(struct request_queue___17 *, struct request___17 *);
	void (*init_icq)(struct io_cq___16 *);
	void (*exit_icq)(struct io_cq___16 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide61;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___16;

struct elevator_type___16 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___16 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___16 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___82 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___16 {
	struct elevator_type___16 *type;
	void *elevator_data;
	struct kobject___91 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___16 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___16 *, char *);
	ssize_t (*store)(struct elevator_queue___16 *, const char *, size_t);
};

struct blkcg_policy_data___9;

struct blkcg___9 {
	struct cgroup_subsys_state___74 css;
	spinlock_t lock;
	struct xarray blkg_tree;
	struct blkcg_gq___9 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___9 *cpd[5];
	struct list_head all_blkcgs_node;
	struct list_head cgwb_list;
	refcount_t cgwb_refcnt;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct blkcg_policy_data___9 {
	struct blkcg___9 *blkcg;
	int plid;
};

struct blkg_policy_data___9 {
	struct blkcg_gq___9 *blkg;
	int plid;
};

struct seccomp_log_name {
	u32 log;
	const char *name;
};

struct file___98;

struct kiocb___98;

struct poll_table_struct___62;

struct vm_area_struct___98;

struct inode___99;

struct file_lock___98;

struct page___98;

struct pipe_inode_info___21;

struct file_operations___98 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___98 *, loff_t, int);
	ssize_t (*read)(struct file___98 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___98 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___98 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___98 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___98 *, bool);
	int (*iterate)(struct file___98 *, struct dir_context *);
	int (*iterate_shared)(struct file___98 *, struct dir_context *);
	__poll_t (*poll)(struct file___98 *, struct poll_table_struct___62 *);
	long int (*unlocked_ioctl)(struct file___98 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___98 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___98 *, struct vm_area_struct___98 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___99 *, struct file___98 *);
	int (*flush)(struct file___98 *, fl_owner_t);
	int (*release)(struct inode___99 *, struct file___98 *);
	int (*fsync)(struct file___98 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___98 *, int);
	int (*lock)(struct file___98 *, int, struct file_lock___98 *);
	ssize_t (*sendpage)(struct file___98 *, struct page___98 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___98 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___98 *, int, struct file_lock___98 *);
	ssize_t (*splice_write)(struct pipe_inode_info___21 *, struct file___98 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___98 *, loff_t *, struct pipe_inode_info___21 *, size_t, unsigned int);
	int (*setlease)(struct file___98 *, long int, struct file_lock___98 **, void **);
	long int (*fallocate)(struct file___98 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___98 *);
	ssize_t (*copy_file_range)(struct file___98 *, loff_t, struct file___98 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___98 *, loff_t, struct file___98 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___98 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___97 {
	u64 seqnum;
	struct vm_area_struct___98 *vmas[4];
};

struct page_frag___97 {
	struct page___98 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___97;

struct vm_struct___69;

struct task_struct___98 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___98 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___97 *mm;
	struct mm_struct___97 *active_mm;
	struct vmacache___97 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___98 *real_parent;
	struct task_struct___98 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___98 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___80 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___80 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___80 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___2 *ptracer_cred;
	const struct cred___2 *real_cred;
	const struct cred___2 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___98 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___16 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___21 *splice_pipe;
	struct page_frag___97 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___98 *oom_reaper_list;
	struct vm_struct___69 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___57 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___98 *pgtable_t___97;

struct address_space___97;

struct dev_pagemap___95;

struct page___98 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___97 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___98 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___97 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___97 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___95 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___97;

struct lruvec___97 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___97 *pgdat;
};

struct zone___97 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___97 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___97 {
	struct zone___97 *zone;
	int zone_idx;
};

struct zonelist___97 {
	struct zoneref___97 _zonerefs[25];
};

struct pglist_data___97 {
	struct zone___97 node_zones[3];
	struct zonelist___97 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___98 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___98 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___97 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___98 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___98 *owner;
};

struct secondary_data___98 {
	void *stack;
	struct task_struct___98 *task;
	long int status;
};

struct blocking_notifier_head___97 {
	struct rw_semaphore___98 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___95;

struct vm_area_struct___98 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___98 *vm_next;
	struct vm_area_struct___98 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___97 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___95 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___98 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___97;

struct mm_struct___97 {
	struct {
		struct vm_area_struct___98 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___98 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___98 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___97 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___98 *owner;
		struct user_namespace___3 *user_ns;
		struct file___98 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___97 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct fasync_struct___97;

struct pipe_buffer___21;

struct pipe_inode_info___21 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___98 *tmp_page;
	struct fasync_struct___97 *fasync_readers;
	struct fasync_struct___97 *fasync_writers;
	struct pipe_buffer___21 *bufs;
	struct user_struct___25 *user;
};

struct vm_struct___69 {
	struct vm_struct___69 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___98 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dentry_operations___97;

struct super_block___98;

struct dentry___98 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___98 *d_parent;
	struct qstr d_name;
	struct inode___99 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___97 *d_op;
	struct super_block___98 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___97;

struct address_space___97 {
	struct inode___99 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___98 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___97 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___97;

struct block_device___98;

struct inode___99 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___97 *i_op;
	struct super_block___98 *i_sb;
	struct address_space___97 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___98 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___98 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___97 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___21 *i_pipe;
		struct block_device___98 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___97;

struct dentry_operations___97 {
	int (*d_revalidate)(struct dentry___98 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___98 *, unsigned int);
	int (*d_hash)(const struct dentry___98 *, struct qstr *);
	int (*d_compare)(const struct dentry___98 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___98 *);
	int (*d_init)(struct dentry___98 *);
	void (*d_release)(struct dentry___98 *);
	void (*d_prune)(struct dentry___98 *);
	void (*d_iput)(struct dentry___98 *, struct inode___99 *);
	char * (*d_dname)(struct dentry___98 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___97 *);
	int (*d_manage)(const struct path___97 *, bool);
	struct dentry___98 * (*d_real)(struct dentry___98 *, const struct inode___99 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___97;

struct mem_dqinfo___97 {
	struct quota_format_type___97 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___97;

struct quota_info___97 {
	unsigned int flags;
	struct rw_semaphore___98 dqio_sem;
	struct inode___99 *files[3];
	struct mem_dqinfo___97 info[3];
	const struct quota_format_ops___97 *ops[3];
};

struct rcuwait___97 {
	struct task_struct___98 *task;
};

struct percpu_rw_semaphore___97 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___98 rw_sem;
	struct rcuwait___97 writer;
	int readers_block;
};

struct sb_writers___97 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___97 rw_sem[3];
};

struct file_system_type___97;

struct super_operations___97;

struct dquot_operations___97;

struct quotactl_ops___97;

struct super_block___98 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___97 *s_type;
	const struct super_operations___97 *s_op;
	const struct dquot_operations___97 *dq_op;
	const struct quotactl_ops___97 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___98 *s_root;
	struct rw_semaphore___98 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___98 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___97 s_dquot;
	struct sb_writers___97 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___97 *s_d_op;
	int cleancache_poolid;
	struct shrinker___35 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct path___97 {
	struct vfsmount *mnt;
	struct dentry___98 *dentry;
};

typedef int (*dev_page_fault_t___95)(struct vm_area_struct___98 *, long unsigned int, const struct page___98 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___95)(struct page___98 *, void *);

struct device___89;

struct dev_pagemap___95 {
	dev_page_fault_t___95 page_fault;
	dev_page_free_t___95 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___89 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct file___98 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___97 f_path;
	struct inode___99 *f_inode;
	const struct file_operations___98 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___80 f_owner;
	const struct cred___2 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___97 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___95;

struct vm_operations_struct___95 {
	void (*open)(struct vm_area_struct___98 *);
	void (*close)(struct vm_area_struct___98 *);
	int (*split)(struct vm_area_struct___98 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___98 *);
	vm_fault_t (*fault)(struct vm_fault___95 *);
	vm_fault_t (*huge_fault)(struct vm_fault___95 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___95 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___98 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___95 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___95 *);
	int (*access)(struct vm_area_struct___98 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___98 *);
	int (*set_policy)(struct vm_area_struct___98 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___98 *, long unsigned int);
	struct page___98 * (*find_special_page)(struct vm_area_struct___98 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___97 {
	struct task_struct___98 *task;
	struct core_thread___97 *next;
};

struct core_state___97 {
	atomic_t nr_threads;
	struct core_thread___97 dumper;
	struct completion startup;
};

struct vm_fault___95 {
	struct vm_area_struct___98 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___98 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___98 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___97 prealloc_pte;
};

struct kiocb___98 {
	struct file___98 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___98 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___98 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___98 *ia_file;
};

struct dquot___97 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___98 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___97 {
	int qf_fmt_id;
	const struct quota_format_ops___97 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___97 *qf_next;
};

struct quota_format_ops___97 {
	int (*check_quota_file)(struct super_block___98 *, int);
	int (*read_file_info)(struct super_block___98 *, int);
	int (*write_file_info)(struct super_block___98 *, int);
	int (*free_file_info)(struct super_block___98 *, int);
	int (*read_dqblk)(struct dquot___97 *);
	int (*commit_dqblk)(struct dquot___97 *);
	int (*release_dqblk)(struct dquot___97 *);
	int (*get_next_id)(struct super_block___98 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___97 {
	int (*write_dquot)(struct dquot___97 *);
	struct dquot___97 * (*alloc_dquot)(struct super_block___98 *, int);
	void (*destroy_dquot)(struct dquot___97 *);
	int (*acquire_dquot)(struct dquot___97 *);
	int (*release_dquot)(struct dquot___97 *);
	int (*mark_dirty)(struct dquot___97 *);
	int (*write_info)(struct super_block___98 *, int);
	qsize_t * (*get_reserved_space)(struct inode___99 *);
	int (*get_projid)(struct inode___99 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___99 *, qsize_t *);
	int (*get_next_id)(struct super_block___98 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___97 {
	int (*quota_on)(struct super_block___98 *, int, int, const struct path___97 *);
	int (*quota_off)(struct super_block___98 *, int);
	int (*quota_enable)(struct super_block___98 *, unsigned int);
	int (*quota_disable)(struct super_block___98 *, unsigned int);
	int (*quota_sync)(struct super_block___98 *, int);
	int (*set_info)(struct super_block___98 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___98 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___98 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___98 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___98 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___98 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___97 {
	int (*writepage)(struct page___98 *, struct writeback_control___3 *);
	int (*readpage)(struct file___98 *, struct page___98 *);
	int (*writepages)(struct address_space___97 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___98 *);
	int (*readpages)(struct file___98 *, struct address_space___97 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___98 *, struct address_space___97 *, loff_t, unsigned int, unsigned int, struct page___98 **, void **);
	int (*write_end)(struct file___98 *, struct address_space___97 *, loff_t, unsigned int, unsigned int, struct page___98 *, void *);
	sector_t (*bmap)(struct address_space___97 *, sector_t);
	void (*invalidatepage)(struct page___98 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___98 *, gfp_t);
	void (*freepage)(struct page___98 *);
	ssize_t (*direct_IO)(struct kiocb___98 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___97 *, struct page___98 *, struct page___98 *, enum migrate_mode);
	bool (*isolate_page)(struct page___98 *, isolate_mode_t);
	void (*putback_page)(struct page___98 *);
	int (*launder_page)(struct page___98 *);
	int (*is_partially_uptodate)(struct page___98 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___98 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___97 *, struct page___98 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___98 *, sector_t *);
	void (*swap_deactivate)(struct file___98 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___98 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___99 *bd_inode;
	struct super_block___98 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___98 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___97 {
	struct dentry___98 * (*lookup)(struct inode___99 *, struct dentry___98 *, unsigned int);
	const char * (*get_link)(struct dentry___98 *, struct inode___99 *, struct delayed_call *);
	int (*permission)(struct inode___99 *, int);
	struct posix_acl * (*get_acl)(struct inode___99 *, int);
	int (*readlink)(struct dentry___98 *, char *, int);
	int (*create)(struct inode___99 *, struct dentry___98 *, umode_t, bool);
	int (*link)(struct dentry___98 *, struct inode___99 *, struct dentry___98 *);
	int (*unlink)(struct inode___99 *, struct dentry___98 *);
	int (*symlink)(struct inode___99 *, struct dentry___98 *, const char *);
	int (*mkdir)(struct inode___99 *, struct dentry___98 *, umode_t);
	int (*rmdir)(struct inode___99 *, struct dentry___98 *);
	int (*mknod)(struct inode___99 *, struct dentry___98 *, umode_t, dev_t);
	int (*rename)(struct inode___99 *, struct dentry___98 *, struct inode___99 *, struct dentry___98 *, unsigned int);
	int (*setattr)(struct dentry___98 *, struct iattr___98 *);
	int (*getattr)(const struct path___97 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___98 *, char *, size_t);
	int (*fiemap)(struct inode___99 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___99 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___99 *, struct dentry___98 *, struct file___98 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___99 *, struct dentry___98 *, umode_t);
	int (*set_acl)(struct inode___99 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___97 {
	void (*fl_copy_lock)(struct file_lock___98 *, struct file_lock___98 *);
	void (*fl_release_private)(struct file_lock___98 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___97;

struct file_lock___98 {
	struct file_lock___98 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___98 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___97 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___97 *fl_ops;
	const struct lock_manager_operations___97 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___97 {
	int (*lm_compare_owner)(struct file_lock___98 *, struct file_lock___98 *);
	long unsigned int (*lm_owner_key)(struct file_lock___98 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___98 *);
	int (*lm_grant)(struct file_lock___98 *, int);
	bool (*lm_break)(struct file_lock___98 *);
	int (*lm_change)(struct file_lock___98 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___98 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___97 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___97 *fa_next;
	struct file___98 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___97 {
	const char *name;
	int fs_flags;
	struct dentry___98 * (*mount)(struct file_system_type___97 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___98 *);
	struct module___11 *owner;
	struct file_system_type___97 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___97 {
	struct inode___99 * (*alloc_inode)(struct super_block___98 *);
	void (*destroy_inode)(struct inode___99 *);
	void (*dirty_inode)(struct inode___99 *, int);
	int (*write_inode)(struct inode___99 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___99 *);
	void (*evict_inode)(struct inode___99 *);
	void (*put_super)(struct super_block___98 *);
	int (*sync_fs)(struct super_block___98 *, int);
	int (*freeze_super)(struct super_block___98 *);
	int (*freeze_fs)(struct super_block___98 *);
	int (*thaw_super)(struct super_block___98 *);
	int (*unfreeze_fs)(struct super_block___98 *);
	int (*statfs)(struct dentry___98 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___98 *, int *, char *);
	void (*umount_begin)(struct super_block___98 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___98 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___98 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___98 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___98 *);
	ssize_t (*quota_read)(struct super_block___98 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___98 *, int, const char *, size_t, loff_t);
	struct dquot___97 ** (*get_dquots)(struct inode___99 *);
	int (*bdev_try_to_free_page)(struct super_block___98 *, struct page___98 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___98 *, struct shrink_control___35 *);
	long int (*free_cached_objects)(struct super_block___98 *, struct shrink_control___35 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___61)(struct file___98 *, wait_queue_head_t *, struct poll_table_struct___62 *);

struct poll_table_struct___62 {
	poll_queue_proc___61 _qproc;
	__poll_t _key;
};

struct kset___91;

struct kobj_type___91;

struct kernfs_node___94;

struct kobject___92 {
	const char *name;
	struct list_head entry;
	struct kobject___92 *parent;
	struct kset___91 *kset;
	struct kobj_type___91 *ktype;
	struct kernfs_node___94 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct poll_table_struct___62 poll_table___6;

struct rchan;

struct rchan_buf {
	void *start;
	void *data;
	size_t offset;
	size_t subbufs_produced;
	size_t subbufs_consumed;
	struct rchan *chan;
	wait_queue_head_t read_wait;
	struct irq_work wakeup_work;
	struct dentry___98 *dentry;
	struct kref kref;
	struct page___98 **page_array;
	unsigned int page_count;
	unsigned int finalized;
	size_t *padding;
	size_t prev_padding;
	size_t bytes_consumed;
	size_t early_bytes;
	unsigned int cpu;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
};

struct rchan_callbacks;

struct rchan {
	u32 version;
	size_t subbuf_size;
	size_t n_subbufs;
	size_t alloc_size;
	struct rchan_callbacks *cb;
	struct kref kref;
	void *private_data;
	size_t last_toobig;
	struct rchan_buf **buf;
	int is_global;
	struct list_head list;
	struct dentry___98 *parent;
	int has_base_filename;
	char base_filename[255];
};

struct rchan_callbacks {
	int (*subbuf_start)(struct rchan_buf *, void *, void *, size_t);
	void (*buf_mapped)(struct rchan_buf *, struct file___98 *);
	void (*buf_unmapped)(struct rchan_buf *, struct file___98 *);
	struct dentry___98 * (*create_buf_file)(const char *, struct dentry___98 *, umode_t, struct rchan_buf *, int *);
	int (*remove_buf_file)(struct dentry___98 *);
};

struct dev_pm_info___89 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___89 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___89;

struct bus_type___89;

struct device_driver___89;

struct dev_pm_domain___89;

struct class___89;

struct attribute_group___88;

struct device___89 {
	struct device___89 *parent;
	struct device_private *p;
	struct kobject___92 kobj;
	const char *init_name;
	const struct device_type___89 *type;
	struct mutex mutex;
	struct bus_type___89 *bus;
	struct device_driver___89 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___89 power;
	struct dev_pm_domain___89 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___89 *class;
	const struct attribute_group___88 **groups;
	void (*release)(struct device___89 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct kobj_attribute___92 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___92 *, struct kobj_attribute___92 *, char *);
	ssize_t (*store)(struct kobject___92 *, struct kobj_attribute___92 *, const char *, size_t);
};

typedef void compound_page_dtor___95(struct page___98 *);

struct kernfs_root___94;

struct kernfs_elem_dir___94 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___94 *root;
};

struct kernfs_syscall_ops___94;

struct kernfs_root___94 {
	struct kernfs_node___94 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___94 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___94 {
	struct kernfs_node___94 *target_kn;
};

struct kernfs_ops___94;

struct kernfs_elem_attr___94 {
	const struct kernfs_ops___94 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___94 *notify_next;
};

struct kernfs_node___94 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___94 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___94 dir;
		struct kernfs_elem_symlink___94 symlink;
		struct kernfs_elem_attr___94 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___94;

struct kernfs_ops___94 {
	int (*open)(struct kernfs_open_file___94 *);
	void (*release)(struct kernfs_open_file___94 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___94 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___94 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___94 *, struct vm_area_struct___98 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___94 *, struct poll_table_struct___62 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___94 {
	int (*remount_fs)(struct kernfs_root___94 *, int *, char *);
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___94 *);
	int (*mkdir)(struct kernfs_node___94 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___94 *);
	int (*rename)(struct kernfs_node___94 *, struct kernfs_node___94 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___94 *, struct kernfs_root___94 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___94 {
	struct kernfs_node___94 *kn;
	struct file___98 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___95 *vm_ops;
};

struct bin_attribute___88;

struct attribute_group___88 {
	const char *name;
	umode_t (*is_visible)(struct kobject___92 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___92 *, struct bin_attribute___88 *, int);
	struct attribute **attrs;
	struct bin_attribute___88 **bin_attrs;
};

struct bin_attribute___88 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___98 *, struct kobject___92 *, struct bin_attribute___88 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___98 *, struct kobject___92 *, struct bin_attribute___88 *, char *, loff_t, size_t);
	int (*mmap)(struct file___98 *, struct kobject___92 *, struct bin_attribute___88 *, struct vm_area_struct___98 *);
};

struct sysfs_ops___91 {
	ssize_t (*show)(struct kobject___92 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___92 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___91;

struct kset___91 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___92 kobj;
	const struct kset_uevent_ops___91 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___91 {
	void (*release)(struct kobject___92 *);
	const struct sysfs_ops___91 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___5 * (*child_ns_type)(struct kobject___92 *);
	const void * (*namespace)(struct kobject___92 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___91 {
	int (* const filter)(struct kset___91 *, struct kobject___92 *);
	const char * (* const name)(struct kset___91 *, struct kobject___92 *);
	int (* const uevent)(struct kset___91 *, struct kobject___92 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___89 {
	int (*prepare)(struct device___89 *);
	void (*complete)(struct device___89 *);
	int (*suspend)(struct device___89 *);
	int (*resume)(struct device___89 *);
	int (*freeze)(struct device___89 *);
	int (*thaw)(struct device___89 *);
	int (*poweroff)(struct device___89 *);
	int (*restore)(struct device___89 *);
	int (*suspend_late)(struct device___89 *);
	int (*resume_early)(struct device___89 *);
	int (*freeze_late)(struct device___89 *);
	int (*thaw_early)(struct device___89 *);
	int (*poweroff_late)(struct device___89 *);
	int (*restore_early)(struct device___89 *);
	int (*suspend_noirq)(struct device___89 *);
	int (*resume_noirq)(struct device___89 *);
	int (*freeze_noirq)(struct device___89 *);
	int (*thaw_noirq)(struct device___89 *);
	int (*poweroff_noirq)(struct device___89 *);
	int (*restore_noirq)(struct device___89 *);
	int (*runtime_suspend)(struct device___89 *);
	int (*runtime_resume)(struct device___89 *);
	int (*runtime_idle)(struct device___89 *);
};

struct dev_pm_domain___89 {
	struct dev_pm_ops___89 ops;
	void (*detach)(struct device___89 *, bool);
	int (*activate)(struct device___89 *);
	void (*sync)(struct device___89 *);
	void (*dismiss)(struct device___89 *);
};

struct bus_type___89 {
	const char *name;
	const char *dev_name;
	struct device___89 *dev_root;
	const struct attribute_group___88 **bus_groups;
	const struct attribute_group___88 **dev_groups;
	const struct attribute_group___88 **drv_groups;
	int (*match)(struct device___89 *, struct device_driver___89 *);
	int (*uevent)(struct device___89 *, struct kobj_uevent_env *);
	int (*probe)(struct device___89 *);
	int (*remove)(struct device___89 *);
	void (*shutdown)(struct device___89 *);
	int (*online)(struct device___89 *);
	int (*offline)(struct device___89 *);
	int (*suspend)(struct device___89 *, pm_message_t);
	int (*resume)(struct device___89 *);
	int (*num_vf)(struct device___89 *);
	int (*dma_configure)(struct device___89 *);
	const struct dev_pm_ops___89 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___89 {
	const char *name;
	struct bus_type___89 *bus;
	struct module___11 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___89 *);
	int (*remove)(struct device___89 *);
	void (*shutdown)(struct device___89 *);
	int (*suspend)(struct device___89 *, pm_message_t);
	int (*resume)(struct device___89 *);
	const struct attribute_group___88 **groups;
	const struct dev_pm_ops___89 *pm;
	void (*coredump)(struct device___89 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___89 {
	const char *name;
	const struct attribute_group___88 **groups;
	int (*uevent)(struct device___89 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___89 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___89 *);
	const struct dev_pm_ops___89 *pm;
};

struct class___89 {
	const char *name;
	struct module___11 *owner;
	const struct attribute_group___88 **class_groups;
	const struct attribute_group___88 **dev_groups;
	struct kobject___92 *dev_kobj;
	int (*dev_uevent)(struct device___89 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___89 *, umode_t *);
	void (*class_release)(struct class___89 *);
	void (*dev_release)(struct device___89 *);
	int (*shutdown_pre)(struct device___89 *);
	const struct kobj_ns_type_operations___5 *ns_type;
	const void * (*namespace)(struct device___89 *);
	const struct dev_pm_ops___89 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___76 {
	struct device___89 dev;
};

struct pipe_buf_operations___21;

struct pipe_buffer___21 {
	struct page___98 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___21 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___21 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___21 *, struct pipe_buffer___21 *);
	void (*release)(struct pipe_inode_info___21 *, struct pipe_buffer___21 *);
	int (*steal)(struct pipe_inode_info___21 *, struct pipe_buffer___21 *);
	union {
		bool (*get)(struct pipe_inode_info___21 *, struct pipe_buffer___21 *);
		struct {
			void (*get)(struct pipe_inode_info___21 *, struct pipe_buffer___21 *);
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
};

struct partial_page {
	unsigned int offset;
	unsigned int len;
	long unsigned int private;
};

struct splice_pipe_desc {
	struct page___98 **pages;
	struct partial_page *partial;
	int nr_pages;
	unsigned int nr_pages_max;
	const struct pipe_buf_operations___21 *ops;
	void (*spd_release)(struct splice_pipe_desc *, unsigned int);
};

struct rchan_percpu_buf_dispatcher {
	struct rchan_buf *buf;
	struct dentry___98 *dentry;
};

struct file___99;

struct kiocb___99;

struct iov_iter___39;

struct vm_area_struct___99;

struct inode___100;

struct file_lock___99;

struct page___99;

struct pipe_inode_info___22;

struct seq_file___89;

struct file_operations___99 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___99 *, loff_t, int);
	ssize_t (*read)(struct file___99 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___99 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___99 *, struct iov_iter___39 *);
	ssize_t (*write_iter)(struct kiocb___99 *, struct iov_iter___39 *);
	int (*iopoll)(struct kiocb___99 *, bool);
	int (*iterate)(struct file___99 *, struct dir_context *);
	int (*iterate_shared)(struct file___99 *, struct dir_context *);
	__poll_t (*poll)(struct file___99 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___99 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___99 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___99 *, struct vm_area_struct___99 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___100 *, struct file___99 *);
	int (*flush)(struct file___99 *, fl_owner_t);
	int (*release)(struct inode___100 *, struct file___99 *);
	int (*fsync)(struct file___99 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___99 *, int);
	int (*lock)(struct file___99 *, int, struct file_lock___99 *);
	ssize_t (*sendpage)(struct file___99 *, struct page___99 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___99 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___99 *, int, struct file_lock___99 *);
	ssize_t (*splice_write)(struct pipe_inode_info___22 *, struct file___99 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___99 *, loff_t *, struct pipe_inode_info___22 *, size_t, unsigned int);
	int (*setlease)(struct file___99 *, long int, struct file_lock___99 **, void **);
	long int (*fallocate)(struct file___99 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___89 *, struct file___99 *);
	ssize_t (*copy_file_range)(struct file___99 *, loff_t, struct file___99 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___99 *, loff_t, struct file___99 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___99 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

enum {
	TASKSTATS_TYPE_UNSPEC = 0,
	TASKSTATS_TYPE_PID = 1,
	TASKSTATS_TYPE_TGID = 2,
	TASKSTATS_TYPE_STATS = 3,
	TASKSTATS_TYPE_AGGR_PID = 4,
	TASKSTATS_TYPE_AGGR_TGID = 5,
	TASKSTATS_TYPE_NULL = 6,
	__TASKSTATS_TYPE_MAX = 7,
};

enum {
	TASKSTATS_CMD_ATTR_UNSPEC = 0,
	TASKSTATS_CMD_ATTR_PID = 1,
	TASKSTATS_CMD_ATTR_TGID = 2,
	TASKSTATS_CMD_ATTR_REGISTER_CPUMASK = 3,
	TASKSTATS_CMD_ATTR_DEREGISTER_CPUMASK = 4,
	__TASKSTATS_CMD_ATTR_MAX = 5,
};

struct vmacache___98 {
	u64 seqnum;
	struct vm_area_struct___99 *vmas[4];
};

struct page_frag___98 {
	struct page___99 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___98;

struct pid___81;

struct cred___94;

struct nsproxy___91;

struct signal_struct___88;

struct css_set___75;

struct vm_struct___70;

struct task_struct___99 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___99 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___98 *mm;
	struct mm_struct___98 *active_mm;
	struct vmacache___98 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___99 *real_parent;
	struct task_struct___99 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___99 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___81 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___81 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___81 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___94 *ptracer_cred;
	const struct cred___94 *real_cred;
	const struct cred___94 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___91 *nsproxy;
	struct signal_struct___88 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___99 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___16 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___75 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___22 *splice_pipe;
	struct page_frag___98 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___99 *oom_reaper_list;
	struct vm_struct___70 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___57 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct key___94;

struct user_struct___94 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___94 *uid_keyring;
	struct key___94 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct pid_namespace___81;

struct upid___81 {
	int nr;
	struct pid_namespace___81 *ns;
};

struct dentry___99;

struct user_namespace___79;

struct ucounts___79;

struct pid_namespace___81 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___99 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___81 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___99 *proc_self;
	struct dentry___99 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___79 *user_ns;
	struct ucounts___79 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___7 ns;
};

struct pid___81 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___81 numbers[1];
};

struct rw_semaphore___99 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___99 *owner;
};

struct user_namespace___79 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___79 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___7 ns;
	long unsigned int flags;
	struct key___94 *persistent_keyring_register;
	struct rw_semaphore___99 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___79 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct secondary_data___99 {
	void *stack;
	struct task_struct___99 *task;
	long int status;
};

typedef struct page___99 *pgtable_t___98;

struct address_space___98;

struct dev_pagemap___96;

struct page___99 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___98 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___99 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___98 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___98 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___96 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct vm_operations_struct___96;

struct vm_area_struct___99 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___99 *vm_next;
	struct vm_area_struct___99 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___98 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___96 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___99 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___98;

struct mm_struct___98 {
	struct {
		struct vm_area_struct___99 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___99 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___99 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___98 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___99 *owner;
		struct user_namespace___79 *user_ns;
		struct file___99 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___98 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___94 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___94 *session_keyring;
	struct key___94 *process_keyring;
	struct key___94 *thread_keyring;
	struct key___94 *request_key_auth;
	void *security;
	struct user_struct___94 *user;
	struct user_namespace___79 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___20;

struct cgroup_namespace___75;

struct nsproxy___91 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___81 *pid_ns_for_children;
	struct net___20 *net_ns;
	struct cgroup_namespace___75 *cgroup_ns;
};

struct signal_struct___88 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___99 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___99 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___81 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___81 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___98 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___81 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___75;

struct cgroup___75;

struct css_set___75 {
	struct cgroup_subsys_state___75 *subsys[13];
	refcount_t refcount;
	struct css_set___75 *dom_cset;
	struct cgroup___75 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___75 *mg_src_cgrp;
	struct cgroup___75 *mg_dst_cgrp;
	struct css_set___75 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___98;

struct pipe_buffer___22;

struct pipe_inode_info___22 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___99 *tmp_page;
	struct fasync_struct___98 *fasync_readers;
	struct fasync_struct___98 *fasync_writers;
	struct pipe_buffer___22 *bufs;
	struct user_struct___94 *user;
};

struct vm_struct___70 {
	struct vm_struct___70 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___99 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___88 {
	struct task_struct___99 task;
	long unsigned int stack[8192];
};

typedef int (*key_restrict_link_func_t___94)(struct key___94 *, const struct key_type *, const union key_payload *, struct key___94 *);

struct key_restriction___94;

struct key___94 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___99 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___94 *restrict_link;
};

struct key_restriction___94 {
	key_restrict_link_func_t___94 check;
	struct key___94 *key;
	struct key_type *keytype;
};

struct pglist_data___98;

struct lruvec___98 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___98 *pgdat;
};

struct zone___98 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___98 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___98 {
	struct zone___98 *zone;
	int zone_idx;
};

struct zonelist___98 {
	struct zoneref___98 _zonerefs[25];
};

struct pglist_data___98 {
	struct zone___98 node_zones[3];
	struct zonelist___98 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___99 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___99 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___98 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___98 {
	struct rw_semaphore___99 rwsem;
	struct notifier_block *head;
};

enum {
	CGROUPSTATS_CMD_UNSPEC = 3,
	CGROUPSTATS_CMD_GET = 4,
	CGROUPSTATS_CMD_NEW = 5,
	__CGROUPSTATS_CMD_MAX = 6,
};

enum {
	CGROUPSTATS_TYPE_UNSPEC = 0,
	CGROUPSTATS_TYPE_CGROUP_STATS = 1,
	__CGROUPSTATS_TYPE_MAX = 2,
};

enum {
	CGROUPSTATS_CMD_ATTR_UNSPEC = 0,
	CGROUPSTATS_CMD_ATTR_FD = 1,
	__CGROUPSTATS_CMD_ATTR_MAX = 2,
};

struct dentry_operations___98;

struct super_block___99;

struct dentry___99 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___99 *d_parent;
	struct qstr d_name;
	struct inode___100 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___98 *d_op;
	struct super_block___99 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___98;

struct address_space___98 {
	struct inode___100 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___99 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___98 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___98;

struct block_device___99;

struct inode___100 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___98 *i_op;
	struct super_block___99 *i_sb;
	struct address_space___98 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___99 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___99 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___98 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___22 *i_pipe;
		struct block_device___99 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___98;

struct dentry_operations___98 {
	int (*d_revalidate)(struct dentry___99 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___99 *, unsigned int);
	int (*d_hash)(const struct dentry___99 *, struct qstr *);
	int (*d_compare)(const struct dentry___99 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___99 *);
	int (*d_init)(struct dentry___99 *);
	void (*d_release)(struct dentry___99 *);
	void (*d_prune)(struct dentry___99 *);
	void (*d_iput)(struct dentry___99 *, struct inode___100 *);
	char * (*d_dname)(struct dentry___99 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___98 *);
	int (*d_manage)(const struct path___98 *, bool);
	struct dentry___99 * (*d_real)(struct dentry___99 *, const struct inode___100 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___98;

struct mem_dqinfo___98 {
	struct quota_format_type___98 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___98;

struct quota_info___98 {
	unsigned int flags;
	struct rw_semaphore___99 dqio_sem;
	struct inode___100 *files[3];
	struct mem_dqinfo___98 info[3];
	const struct quota_format_ops___98 *ops[3];
};

struct rcuwait___98 {
	struct task_struct___99 *task;
};

struct percpu_rw_semaphore___98 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___99 rw_sem;
	struct rcuwait___98 writer;
	int readers_block;
};

struct sb_writers___98 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___98 rw_sem[3];
};

struct file_system_type___98;

struct super_operations___98;

struct dquot_operations___98;

struct quotactl_ops___98;

struct super_block___99 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___98 *s_type;
	const struct super_operations___98 *s_op;
	const struct dquot_operations___98 *dq_op;
	const struct quotactl_ops___98 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___99 *s_root;
	struct rw_semaphore___99 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___99 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___98 s_dquot;
	struct sb_writers___98 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___98 *s_d_op;
	int cleancache_poolid;
	struct shrinker___35 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___79 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct path___98 {
	struct vfsmount *mnt;
	struct dentry___99 *dentry;
};

typedef int (*dev_page_fault_t___96)(struct vm_area_struct___99 *, long unsigned int, const struct page___99 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___96)(struct page___99 *, void *);

struct device___90;

struct dev_pagemap___96 {
	dev_page_fault_t___96 page_fault;
	dev_page_free_t___96 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___90 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct fown_struct___81 {
	rwlock_t lock;
	struct pid___81 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___99 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___98 f_path;
	struct inode___100 *f_inode;
	const struct file_operations___99 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___81 f_owner;
	const struct cred___94 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___98 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___96;

struct vm_operations_struct___96 {
	void (*open)(struct vm_area_struct___99 *);
	void (*close)(struct vm_area_struct___99 *);
	int (*split)(struct vm_area_struct___99 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___99 *);
	vm_fault_t (*fault)(struct vm_fault___96 *);
	vm_fault_t (*huge_fault)(struct vm_fault___96 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___96 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___99 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___96 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___96 *);
	int (*access)(struct vm_area_struct___99 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___99 *);
	int (*set_policy)(struct vm_area_struct___99 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___99 *, long unsigned int);
	struct page___99 * (*find_special_page)(struct vm_area_struct___99 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___98 {
	struct task_struct___99 *task;
	struct core_thread___98 *next;
};

struct core_state___98 {
	atomic_t nr_threads;
	struct core_thread___98 dumper;
	struct completion startup;
};

struct vm_fault___96 {
	struct vm_area_struct___99 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___99 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___99 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___98 prealloc_pte;
};

struct kiocb___99 {
	struct file___99 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___99 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___99 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___99 *ia_file;
};

struct dquot___98 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___99 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___98 {
	int qf_fmt_id;
	const struct quota_format_ops___98 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___98 *qf_next;
};

struct quota_format_ops___98 {
	int (*check_quota_file)(struct super_block___99 *, int);
	int (*read_file_info)(struct super_block___99 *, int);
	int (*write_file_info)(struct super_block___99 *, int);
	int (*free_file_info)(struct super_block___99 *, int);
	int (*read_dqblk)(struct dquot___98 *);
	int (*commit_dqblk)(struct dquot___98 *);
	int (*release_dqblk)(struct dquot___98 *);
	int (*get_next_id)(struct super_block___99 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___98 {
	int (*write_dquot)(struct dquot___98 *);
	struct dquot___98 * (*alloc_dquot)(struct super_block___99 *, int);
	void (*destroy_dquot)(struct dquot___98 *);
	int (*acquire_dquot)(struct dquot___98 *);
	int (*release_dquot)(struct dquot___98 *);
	int (*mark_dirty)(struct dquot___98 *);
	int (*write_info)(struct super_block___99 *, int);
	qsize_t * (*get_reserved_space)(struct inode___100 *);
	int (*get_projid)(struct inode___100 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___100 *, qsize_t *);
	int (*get_next_id)(struct super_block___99 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___98 {
	int (*quota_on)(struct super_block___99 *, int, int, const struct path___98 *);
	int (*quota_off)(struct super_block___99 *, int);
	int (*quota_enable)(struct super_block___99 *, unsigned int);
	int (*quota_disable)(struct super_block___99 *, unsigned int);
	int (*quota_sync)(struct super_block___99 *, int);
	int (*set_info)(struct super_block___99 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___99 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___99 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___99 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___99 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___99 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___98 {
	int (*writepage)(struct page___99 *, struct writeback_control___3 *);
	int (*readpage)(struct file___99 *, struct page___99 *);
	int (*writepages)(struct address_space___98 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___99 *);
	int (*readpages)(struct file___99 *, struct address_space___98 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___99 *, struct address_space___98 *, loff_t, unsigned int, unsigned int, struct page___99 **, void **);
	int (*write_end)(struct file___99 *, struct address_space___98 *, loff_t, unsigned int, unsigned int, struct page___99 *, void *);
	sector_t (*bmap)(struct address_space___98 *, sector_t);
	void (*invalidatepage)(struct page___99 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___99 *, gfp_t);
	void (*freepage)(struct page___99 *);
	ssize_t (*direct_IO)(struct kiocb___99 *, struct iov_iter___39 *);
	int (*migratepage)(struct address_space___98 *, struct page___99 *, struct page___99 *, enum migrate_mode);
	bool (*isolate_page)(struct page___99 *, isolate_mode_t);
	void (*putback_page)(struct page___99 *);
	int (*launder_page)(struct page___99 *);
	int (*is_partially_uptodate)(struct page___99 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___99 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___98 *, struct page___99 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___99 *, sector_t *);
	void (*swap_deactivate)(struct file___99 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct iov_iter___39 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___3 *bvec;
		struct pipe_inode_info___22 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___99 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___100 *bd_inode;
	struct super_block___99 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___99 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___98 {
	struct dentry___99 * (*lookup)(struct inode___100 *, struct dentry___99 *, unsigned int);
	const char * (*get_link)(struct dentry___99 *, struct inode___100 *, struct delayed_call *);
	int (*permission)(struct inode___100 *, int);
	struct posix_acl * (*get_acl)(struct inode___100 *, int);
	int (*readlink)(struct dentry___99 *, char *, int);
	int (*create)(struct inode___100 *, struct dentry___99 *, umode_t, bool);
	int (*link)(struct dentry___99 *, struct inode___100 *, struct dentry___99 *);
	int (*unlink)(struct inode___100 *, struct dentry___99 *);
	int (*symlink)(struct inode___100 *, struct dentry___99 *, const char *);
	int (*mkdir)(struct inode___100 *, struct dentry___99 *, umode_t);
	int (*rmdir)(struct inode___100 *, struct dentry___99 *);
	int (*mknod)(struct inode___100 *, struct dentry___99 *, umode_t, dev_t);
	int (*rename)(struct inode___100 *, struct dentry___99 *, struct inode___100 *, struct dentry___99 *, unsigned int);
	int (*setattr)(struct dentry___99 *, struct iattr___99 *);
	int (*getattr)(const struct path___98 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___99 *, char *, size_t);
	int (*fiemap)(struct inode___100 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___100 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___100 *, struct dentry___99 *, struct file___99 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___100 *, struct dentry___99 *, umode_t);
	int (*set_acl)(struct inode___100 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___98 {
	void (*fl_copy_lock)(struct file_lock___99 *, struct file_lock___99 *);
	void (*fl_release_private)(struct file_lock___99 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___98;

struct file_lock___99 {
	struct file_lock___99 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___99 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___98 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___98 *fl_ops;
	const struct lock_manager_operations___98 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___98 {
	int (*lm_compare_owner)(struct file_lock___99 *, struct file_lock___99 *);
	long unsigned int (*lm_owner_key)(struct file_lock___99 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___99 *);
	int (*lm_grant)(struct file_lock___99 *, int);
	bool (*lm_break)(struct file_lock___99 *);
	int (*lm_change)(struct file_lock___99 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___99 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___98 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___98 *fa_next;
	struct file___99 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___98 {
	const char *name;
	int fs_flags;
	struct dentry___99 * (*mount)(struct file_system_type___98 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___99 *);
	struct module___11 *owner;
	struct file_system_type___98 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___98 {
	struct inode___100 * (*alloc_inode)(struct super_block___99 *);
	void (*destroy_inode)(struct inode___100 *);
	void (*dirty_inode)(struct inode___100 *, int);
	int (*write_inode)(struct inode___100 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___100 *);
	void (*evict_inode)(struct inode___100 *);
	void (*put_super)(struct super_block___99 *);
	int (*sync_fs)(struct super_block___99 *, int);
	int (*freeze_super)(struct super_block___99 *);
	int (*freeze_fs)(struct super_block___99 *);
	int (*thaw_super)(struct super_block___99 *);
	int (*unfreeze_fs)(struct super_block___99 *);
	int (*statfs)(struct dentry___99 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___99 *, int *, char *);
	void (*umount_begin)(struct super_block___99 *);
	int (*show_options)(struct seq_file___89 *, struct dentry___99 *);
	int (*show_devname)(struct seq_file___89 *, struct dentry___99 *);
	int (*show_path)(struct seq_file___89 *, struct dentry___99 *);
	int (*show_stats)(struct seq_file___89 *, struct dentry___99 *);
	ssize_t (*quota_read)(struct super_block___99 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___99 *, int, const char *, size_t, loff_t);
	struct dquot___98 ** (*get_dquots)(struct inode___100 *);
	int (*bdev_try_to_free_page)(struct super_block___99 *, struct page___99 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___99 *, struct shrink_control___35 *);
	long int (*free_cached_objects)(struct super_block___99 *, struct shrink_control___35 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___87;

struct seq_file___89 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___87 *op;
	int poll_event;
	const struct file___99 *file;
	void *private;
};

struct kset___92;

struct kobj_type___92;

struct kernfs_node___95;

struct kobject___93 {
	const char *name;
	struct list_head entry;
	struct kobject___93 *parent;
	struct kset___92 *kset;
	struct kobj_type___92 *ktype;
	struct kernfs_node___95 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___87 {
	void * (*start)(struct seq_file___89 *, loff_t *);
	void (*stop)(struct seq_file___89 *, void *);
	void * (*next)(struct seq_file___89 *, void *, loff_t *);
	int (*show)(struct seq_file___89 *, void *);
};

struct kernfs_root___95;

struct kernfs_elem_dir___95 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___95 *root;
};

struct kernfs_syscall_ops___95;

struct kernfs_root___95 {
	struct kernfs_node___95 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___95 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___95 {
	struct kernfs_node___95 *target_kn;
};

struct kernfs_ops___95;

struct kernfs_elem_attr___95 {
	const struct kernfs_ops___95 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___95 *notify_next;
};

struct kernfs_node___95 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___95 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___95 dir;
		struct kernfs_elem_symlink___95 symlink;
		struct kernfs_elem_attr___95 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___95;

struct kernfs_ops___95 {
	int (*open)(struct kernfs_open_file___95 *);
	void (*release)(struct kernfs_open_file___95 *);
	int (*seq_show)(struct seq_file___89 *, void *);
	void * (*seq_start)(struct seq_file___89 *, loff_t *);
	void * (*seq_next)(struct seq_file___89 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___89 *, void *);
	ssize_t (*read)(struct kernfs_open_file___95 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___95 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___95 *, struct vm_area_struct___99 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___95 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___95 {
	int (*remount_fs)(struct kernfs_root___95 *, int *, char *);
	int (*show_options)(struct seq_file___89 *, struct kernfs_root___95 *);
	int (*mkdir)(struct kernfs_node___95 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___95 *);
	int (*rename)(struct kernfs_node___95 *, struct kernfs_node___95 *, const char *);
	int (*show_path)(struct seq_file___89 *, struct kernfs_node___95 *, struct kernfs_root___95 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___95 {
	struct kernfs_node___95 *kn;
	struct file___99 *file;
	struct seq_file___89 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___96 *vm_ops;
};

struct dst_ops___18 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___18 *);
	struct dst_entry___2 * (*check)(struct dst_entry___2 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___2 *);
	unsigned int (*mtu)(const struct dst_entry___2 *);
	u32 * (*cow_metrics)(struct dst_entry___2 *, long unsigned int);
	void (*destroy)(struct dst_entry___2 *);
	void (*ifdown)(struct dst_entry___2 *, struct net_device *, int);
	struct dst_entry___2 * (*negative_advice)(struct dst_entry___2 *);
	void (*link_failure)(struct sk_buff___14 *);
	void (*update_pmtu)(struct dst_entry___2 *, struct sock *, struct sk_buff___14 *, u32);
	void (*redirect)(struct dst_entry___2 *, struct sock *, struct sk_buff___14 *);
	int (*local_out)(struct net___20 *, struct sock *, struct sk_buff___14 *);
	struct neighbour___2 * (*neigh_lookup)(const struct dst_entry___2 *, struct sk_buff___14 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___2 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___17 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___10 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___18 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct sock *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops *notifier_ops;
	struct fib_notifier_ops *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_xfrm___17 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___18 xfrm4_dst_ops;
	struct dst_ops___18 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct net___20 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___79 *user_ns;
	struct ucounts___79 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___7 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___10 ipv4;
	struct netns_ipv6___17 ipv6;
	struct netns_sctp___5 sctp;
	struct netns_nf nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___10 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock *nfnl;
	struct sock *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___17 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cgroup_namespace___75 {
	refcount_t count;
	struct ns_common___7 ns;
	struct user_namespace___79 *user_ns;
	struct ucounts___79 *ucounts;
	struct css_set___75 *root_cset;
};

struct ucounts___79 {
	struct hlist_node node;
	struct user_namespace___79 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct fd___4 {
	struct file___99 *file;
	unsigned int flags;
};

struct bpf_map___75;

struct bpf_map_ops___75 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___75 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___75 *, struct file___99 *);
	void (*map_free)(struct bpf_map___75 *);
	int (*map_get_next_key)(struct bpf_map___75 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___75 *);
	void * (*map_lookup_elem)(struct bpf_map___75 *, void *);
	int (*map_update_elem)(struct bpf_map___75 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___75 *, void *);
	int (*map_push_elem)(struct bpf_map___75 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___75 *, void *);
	int (*map_peek_elem)(struct bpf_map___75 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___75 *, struct file___99 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___75 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___75 *, void *, struct seq_file___89 *);
	int (*map_check_btf)(const struct bpf_map___75 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___75 {
	const struct bpf_map_ops___75 *ops;
	struct bpf_map___75 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___94 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___75;

typedef void (*kthread_work_func_t___75)(struct kthread_work___75 *);

struct kthread_worker___75;

struct kthread_work___75 {
	struct list_head node;
	kthread_work_func_t___75 func;
	struct kthread_worker___75 *worker;
	int canceling;
};

struct kthread_worker___75 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___99 *task;
	struct kthread_work___75 *current_work;
};

struct kthread_delayed_work___75 {
	struct kthread_work___75 work;
	struct timer_list timer;
};

struct psi_group___75 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___75 *poll_kworker;
	struct kthread_delayed_work___75 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___75 {
	struct kernfs_node___95 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___75;

struct cgroup_subsys_state___75 {
	struct cgroup___75 *cgroup;
	struct cgroup_subsys___75 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___75 *parent;
};

struct cgroup_root___75;

struct cgroup_rstat_cpu___75;

struct cgroup___75 {
	struct cgroup_subsys_state___75 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___95 *kn;
	struct cgroup_file___75 procs_file;
	struct cgroup_file___75 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___75 *subsys[13];
	struct cgroup_root___75 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___75 *dom_cgrp;
	struct cgroup_rstat_cpu___75 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___9 bpf;
	atomic_t congestion_count;
	struct cgroup___75 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___75 psi;
	int ancestor_ids[0];
};

struct cftype___75;

struct cgroup_subsys___75 {
	struct cgroup_subsys_state___75 * (*css_alloc)(struct cgroup_subsys_state___75 *);
	int (*css_online)(struct cgroup_subsys_state___75 *);
	void (*css_offline)(struct cgroup_subsys_state___75 *);
	void (*css_released)(struct cgroup_subsys_state___75 *);
	void (*css_free)(struct cgroup_subsys_state___75 *);
	void (*css_reset)(struct cgroup_subsys_state___75 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___75 *, int);
	int (*css_extra_stat_show)(struct seq_file___89 *, struct cgroup_subsys_state___75 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___99 *);
	void (*cancel_fork)(struct task_struct___99 *);
	void (*fork)(struct task_struct___99 *);
	void (*exit)(struct task_struct___99 *);
	void (*free)(struct task_struct___99 *);
	void (*bind)(struct cgroup_subsys_state___75 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___75 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___75 *dfl_cftypes;
	struct cftype___75 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___75 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___75 *updated_children;
	struct cgroup___75 *updated_next;
};

struct cgroup_root___75 {
	struct kernfs_root___95 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___75 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___75 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___75 *ss;
	struct list_head node;
	struct kernfs_ops___95 *kf_ops;
	int (*open)(struct kernfs_open_file___95 *);
	void (*release)(struct kernfs_open_file___95 *);
	u64 (*read_u64)(struct cgroup_subsys_state___75 *, struct cftype___75 *);
	s64 (*read_s64)(struct cgroup_subsys_state___75 *, struct cftype___75 *);
	int (*seq_show)(struct seq_file___89 *, void *);
	void * (*seq_start)(struct seq_file___89 *, loff_t *);
	void * (*seq_next)(struct seq_file___89 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___89 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___75 *, struct cftype___75 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___75 *, struct cftype___75 *, s64);
	ssize_t (*write)(struct kernfs_open_file___95 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___95 *, struct poll_table_struct___6 *);
};

struct dev_pm_info___90 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___90 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___90;

struct bus_type___90;

struct device_driver___90;

struct dev_pm_domain___90;

struct dma_map_ops___26;

struct fwnode_handle___64;

struct class___90;

struct attribute_group___89;

struct device___90 {
	struct device___90 *parent;
	struct device_private *p;
	struct kobject___93 kobj;
	const char *init_name;
	const struct device_type___90 *type;
	struct mutex mutex;
	struct bus_type___90 *bus;
	struct device_driver___90 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___90 power;
	struct dev_pm_domain___90 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___26 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___64 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___90 *class;
	const struct attribute_group___89 **groups;
	void (*release)(struct device___90 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct kobj_attribute___93 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___93 *, struct kobj_attribute___93 *, char *);
	ssize_t (*store)(struct kobject___93 *, struct kobj_attribute___93 *, const char *, size_t);
};

typedef void compound_page_dtor___96(struct page___99 *);

struct bin_attribute___89;

struct attribute_group___89 {
	const char *name;
	umode_t (*is_visible)(struct kobject___93 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___93 *, struct bin_attribute___89 *, int);
	struct attribute **attrs;
	struct bin_attribute___89 **bin_attrs;
};

struct bin_attribute___89 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___99 *, struct kobject___93 *, struct bin_attribute___89 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___99 *, struct kobject___93 *, struct bin_attribute___89 *, char *, loff_t, size_t);
	int (*mmap)(struct file___99 *, struct kobject___93 *, struct bin_attribute___89 *, struct vm_area_struct___99 *);
};

struct sysfs_ops___92 {
	ssize_t (*show)(struct kobject___93 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___93 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___92;

struct kset___92 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___93 kobj;
	const struct kset_uevent_ops___92 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___92 {
	void (*release)(struct kobject___93 *);
	const struct sysfs_ops___92 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___5 * (*child_ns_type)(struct kobject___93 *);
	const void * (*namespace)(struct kobject___93 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___92 {
	int (* const filter)(struct kset___92 *, struct kobject___93 *);
	const char * (* const name)(struct kset___92 *, struct kobject___93 *);
	int (* const uevent)(struct kset___92 *, struct kobject___93 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___90 {
	int (*prepare)(struct device___90 *);
	void (*complete)(struct device___90 *);
	int (*suspend)(struct device___90 *);
	int (*resume)(struct device___90 *);
	int (*freeze)(struct device___90 *);
	int (*thaw)(struct device___90 *);
	int (*poweroff)(struct device___90 *);
	int (*restore)(struct device___90 *);
	int (*suspend_late)(struct device___90 *);
	int (*resume_early)(struct device___90 *);
	int (*freeze_late)(struct device___90 *);
	int (*thaw_early)(struct device___90 *);
	int (*poweroff_late)(struct device___90 *);
	int (*restore_early)(struct device___90 *);
	int (*suspend_noirq)(struct device___90 *);
	int (*resume_noirq)(struct device___90 *);
	int (*freeze_noirq)(struct device___90 *);
	int (*thaw_noirq)(struct device___90 *);
	int (*poweroff_noirq)(struct device___90 *);
	int (*restore_noirq)(struct device___90 *);
	int (*runtime_suspend)(struct device___90 *);
	int (*runtime_resume)(struct device___90 *);
	int (*runtime_idle)(struct device___90 *);
};

struct dev_pm_domain___90 {
	struct dev_pm_ops___90 ops;
	void (*detach)(struct device___90 *, bool);
	int (*activate)(struct device___90 *);
	void (*sync)(struct device___90 *);
	void (*dismiss)(struct device___90 *);
};

struct bus_type___90 {
	const char *name;
	const char *dev_name;
	struct device___90 *dev_root;
	const struct attribute_group___89 **bus_groups;
	const struct attribute_group___89 **dev_groups;
	const struct attribute_group___89 **drv_groups;
	int (*match)(struct device___90 *, struct device_driver___90 *);
	int (*uevent)(struct device___90 *, struct kobj_uevent_env *);
	int (*probe)(struct device___90 *);
	int (*remove)(struct device___90 *);
	void (*shutdown)(struct device___90 *);
	int (*online)(struct device___90 *);
	int (*offline)(struct device___90 *);
	int (*suspend)(struct device___90 *, pm_message_t);
	int (*resume)(struct device___90 *);
	int (*num_vf)(struct device___90 *);
	int (*dma_configure)(struct device___90 *);
	const struct dev_pm_ops___90 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___90 {
	const char *name;
	struct bus_type___90 *bus;
	struct module___11 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___90 *);
	int (*remove)(struct device___90 *);
	void (*shutdown)(struct device___90 *);
	int (*suspend)(struct device___90 *, pm_message_t);
	int (*resume)(struct device___90 *);
	const struct attribute_group___89 **groups;
	const struct dev_pm_ops___90 *pm;
	void (*coredump)(struct device___90 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___90 {
	const char *name;
	const struct attribute_group___89 **groups;
	int (*uevent)(struct device___90 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___90 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___90 *);
	const struct dev_pm_ops___90 *pm;
};

struct class___90 {
	const char *name;
	struct module___11 *owner;
	const struct attribute_group___89 **class_groups;
	const struct attribute_group___89 **dev_groups;
	struct kobject___93 *dev_kobj;
	int (*dev_uevent)(struct device___90 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___90 *, umode_t *);
	void (*class_release)(struct class___90 *);
	void (*dev_release)(struct device___90 *);
	int (*shutdown_pre)(struct device___90 *);
	const struct kobj_ns_type_operations___5 *ns_type;
	const void * (*namespace)(struct device___90 *);
	const struct dev_pm_ops___90 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___26 {
	void * (*alloc)(struct device___90 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___90 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___90 *, struct vm_area_struct___99 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___90 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___90 *, struct page___99 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___90 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___90 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___90 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___90 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___90 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___90 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___90 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___90 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___90 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___90 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___90 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___90 *, u64);
	u64 (*get_required_mask)(struct device___90 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___64;

struct fwnode_handle___64 {
	struct fwnode_handle___64 *secondary;
	const struct fwnode_operations___64 *ops;
};

struct fwnode_reference_args___64;

struct fwnode_endpoint___64;

struct fwnode_operations___64 {
	struct fwnode_handle___64 * (*get)(struct fwnode_handle___64 *);
	void (*put)(struct fwnode_handle___64 *);
	bool (*device_is_available)(const struct fwnode_handle___64 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___64 *, const struct device___90 *);
	bool (*property_present)(const struct fwnode_handle___64 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___64 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___64 *, const char *, const char **, size_t);
	struct fwnode_handle___64 * (*get_parent)(const struct fwnode_handle___64 *);
	struct fwnode_handle___64 * (*get_next_child_node)(const struct fwnode_handle___64 *, struct fwnode_handle___64 *);
	struct fwnode_handle___64 * (*get_named_child_node)(const struct fwnode_handle___64 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___64 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___64 *);
	struct fwnode_handle___64 * (*graph_get_next_endpoint)(const struct fwnode_handle___64 *, struct fwnode_handle___64 *);
	struct fwnode_handle___64 * (*graph_get_remote_endpoint)(const struct fwnode_handle___64 *);
	struct fwnode_handle___64 * (*graph_get_port_parent)(struct fwnode_handle___64 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___64 *, struct fwnode_endpoint___64 *);
};

struct fwnode_endpoint___64 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___64 *local_fwnode;
};

struct fwnode_reference_args___64 {
	struct fwnode_handle___64 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___22;

struct pipe_buffer___22 {
	struct page___99 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___22 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___22 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___22 *, struct pipe_buffer___22 *);
	void (*release)(struct pipe_inode_info___22 *, struct pipe_buffer___22 *);
	int (*steal)(struct pipe_inode_info___22 *, struct pipe_buffer___22 *);
	union {
		bool (*get)(struct pipe_inode_info___22 *, struct pipe_buffer___22 *);
		struct {
			void (*get)(struct pipe_inode_info___22 *, struct pipe_buffer___22 *);
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
};

struct genlmsghdr {
	__u8 cmd;
	__u8 version;
	__u16 reserved;
};

enum {
	NLA_UNSPEC = 0,
	NLA_U8 = 1,
	NLA_U16 = 2,
	NLA_U32 = 3,
	NLA_U64 = 4,
	NLA_STRING = 5,
	NLA_FLAG = 6,
	NLA_MSECS = 7,
	NLA_NESTED = 8,
	NLA_NESTED_ARRAY = 9,
	NLA_NUL_STRING = 10,
	NLA_BINARY = 11,
	NLA_S8 = 12,
	NLA_S16 = 13,
	NLA_S32 = 14,
	NLA_S64 = 15,
	NLA_BITFIELD32 = 16,
	NLA_REJECT = 17,
	NLA_EXACT_LEN = 18,
	NLA_EXACT_LEN_WARN = 19,
	__NLA_TYPE_MAX = 20,
};

typedef struct {
	struct net___20 *net;
} possible_net_t___11;

struct genl_multicast_group {
	char name[16];
};

struct genl_ops;

struct genl_info;

struct genl_family {
	int id;
	unsigned int hdrsize;
	char name[16];
	unsigned int version;
	unsigned int maxattr;
	bool netnsok;
	bool parallel_ops;
	int (*pre_doit)(const struct genl_ops *, struct sk_buff___14 *, struct genl_info *);
	void (*post_doit)(const struct genl_ops *, struct sk_buff___14 *, struct genl_info *);
	int (*mcast_bind)(struct net___20 *, int);
	void (*mcast_unbind)(struct net___20 *, int);
	struct nlattr **attrbuf;
	const struct genl_ops *ops;
	const struct genl_multicast_group *mcgrps;
	unsigned int n_ops;
	unsigned int n_mcgrps;
	unsigned int mcgrp_offset;
	struct module___11 *module;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct genl_ops_extended_rh {};

struct genl_ops {
	const struct nla_policy *policy;
	int (*doit)(struct sk_buff___14 *, struct genl_info *);
	int (*start)(struct netlink_callback___10 *);
	int (*dumpit)(struct sk_buff___14 *, struct netlink_callback___10 *);
	int (*done)(struct netlink_callback___10 *);
	u8 cmd;
	u8 internal_flags;
	u8 flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t genl_ops_extended_size_rh;
	struct genl_ops_extended_rh genl_ops_extended_rh;
};

struct genl_info {
	u32 snd_seq;
	u32 snd_portid;
	struct nlmsghdr *nlhdr;
	struct genlmsghdr *genlhdr;
	void *userhdr;
	struct nlattr **attrs;
	possible_net_t___11 _net;
	void *user_ptr[2];
	struct netlink_ext_ack *extack;
};

struct listener {
	struct list_head list;
	pid_t pid;
	char valid;
};

struct listener_list {
	struct rw_semaphore___99 sem;
	struct list_head list;
};

enum actions {
	REGISTER = 0,
	DEREGISTER = 1,
	CPU_DONT_CARE = 2,
};

struct tp_module {
	struct list_head list;
	struct module___80 *mod;
};

struct tp_probes {
	struct callback_head rcu;
	struct tracepoint_func probes[0];
};

struct module___83;

struct file___100;

struct kiocb___100;

struct iov_iter___40;

struct poll_table_struct___63;

struct vm_area_struct___100;

struct inode___101;

struct file_lock___100;

struct page___100;

struct seq_file___90;

struct file_operations___100 {
	struct module___83 *owner;
	loff_t (*llseek)(struct file___100 *, loff_t, int);
	ssize_t (*read)(struct file___100 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___100 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___100 *, struct iov_iter___40 *);
	ssize_t (*write_iter)(struct kiocb___100 *, struct iov_iter___40 *);
	int (*iopoll)(struct kiocb___100 *, bool);
	int (*iterate)(struct file___100 *, struct dir_context *);
	int (*iterate_shared)(struct file___100 *, struct dir_context *);
	__poll_t (*poll)(struct file___100 *, struct poll_table_struct___63 *);
	long int (*unlocked_ioctl)(struct file___100 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___100 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___100 *, struct vm_area_struct___100 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___101 *, struct file___100 *);
	int (*flush)(struct file___100 *, fl_owner_t);
	int (*release)(struct inode___101 *, struct file___100 *);
	int (*fsync)(struct file___100 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___100 *, int);
	int (*lock)(struct file___100 *, int, struct file_lock___100 *);
	ssize_t (*sendpage)(struct file___100 *, struct page___100 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___100 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___100 *, int, struct file_lock___100 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___100 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___100 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___100 *, long int, struct file_lock___100 **, void **);
	long int (*fallocate)(struct file___100 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___90 *, struct file___100 *);
	ssize_t (*copy_file_range)(struct file___100 *, loff_t, struct file___100 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___100 *, loff_t, struct file___100 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___100 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct perf_event___58;

struct debug_info___58 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___58 *hbp_break[16];
	struct perf_event___58 *hbp_watch[16];
};

struct task_struct___100;

struct hw_perf_event___58 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___100 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___58)(struct perf_event___58 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___58;

struct perf_event_context___58;

struct fasync_struct___99;

struct pid_namespace___82;

struct trace_event_call___53;

struct perf_cgroup___58;

struct perf_event___58 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___58 *group_leader;
	struct pmu___58 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___58 hw;
	struct perf_event_context___58 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___58 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___100 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___99 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___58 *);
	struct callback_head callback_head;
	struct pid_namespace___82 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___58 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___58 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___53 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___58 *cgrp;
	struct list_head sb_list;
};

struct thread_struct___58 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___58 debug;
	long: 64;
};

struct vmacache___99 {
	u64 seqnum;
	struct vm_area_struct___100 *vmas[4];
};

struct page_frag___99 {
	struct page___100 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___99;

struct mem_cgroup___36;

struct pid___82;

struct cred___95;

struct nsproxy___92;

struct signal_struct___89;

struct bio_list___39;

struct backing_dev_info___39;

struct css_set___76;

struct vm_struct___71;

struct task_struct___100 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___100 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___99 *mm;
	struct mm_struct___99 *active_mm;
	struct vmacache___99 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___100 *real_parent;
	struct task_struct___100 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___100 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___36 *active_memcg;
	long int rh_reserved2;
	struct pid___82 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___82 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___82 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___95 *ptracer_cred;
	const struct cred___95 *real_cred;
	const struct cred___95 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___92 *nsproxy;
	struct signal_struct___89 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___100 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___39 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___39 *backing_dev_info;
	struct io_context___16 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___76 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___58 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___99 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___36 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___100 *oom_reaper_list;
	struct vm_struct___71 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___58 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___100 *pgtable_t___99;

struct address_space___99;

struct dev_pagemap___97;

struct page___100 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___99 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___100 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___99 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___99 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___97 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___36 *mem_cgroup;
};

struct pglist_data___99;

struct lruvec___99 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___99 *pgdat;
};

struct zone___99 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___99 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___99 {
	struct zone___99 *zone;
	int zone_idx;
};

struct zonelist___99 {
	struct zoneref___99 _zonerefs[25];
};

struct pglist_data___99 {
	struct zone___99 node_zones[3];
	struct zonelist___99 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___100 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___100 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___99 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___100 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___100 *owner;
};

struct secondary_data___100 {
	void *stack;
	struct task_struct___100 *task;
	long int status;
};

struct blocking_notifier_head___99 {
	struct rw_semaphore___100 rwsem;
	struct notifier_block *head;
};

struct key___95;

struct ucounts___80;

struct user_namespace___80 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___80 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___7 ns;
	long unsigned int flags;
	struct key___95 *persistent_keyring_register;
	struct rw_semaphore___100 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___80 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_root___96;

struct kernfs_elem_dir___96 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___96 *root;
};

struct kernfs_node___96;

struct kernfs_syscall_ops___96;

struct kernfs_root___96 {
	struct kernfs_node___96 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___96 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___96 {
	struct kernfs_node___96 *target_kn;
};

struct kernfs_ops___96;

struct kernfs_elem_attr___96 {
	const struct kernfs_ops___96 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___96 *notify_next;
};

struct kernfs_node___96 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___96 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___96 dir;
		struct kernfs_elem_symlink___96 symlink;
		struct kernfs_elem_attr___96 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___96;

struct kernfs_ops___96 {
	int (*open)(struct kernfs_open_file___96 *);
	void (*release)(struct kernfs_open_file___96 *);
	int (*seq_show)(struct seq_file___90 *, void *);
	void * (*seq_start)(struct seq_file___90 *, loff_t *);
	void * (*seq_next)(struct seq_file___90 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___90 *, void *);
	ssize_t (*read)(struct kernfs_open_file___96 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___96 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___96 *, struct vm_area_struct___100 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___96 *, struct poll_table_struct___63 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___96 {
	int (*remount_fs)(struct kernfs_root___96 *, int *, char *);
	int (*show_options)(struct seq_file___90 *, struct kernfs_root___96 *);
	int (*mkdir)(struct kernfs_node___96 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___96 *);
	int (*rename)(struct kernfs_node___96 *, struct kernfs_node___96 *, const char *);
	int (*show_path)(struct seq_file___90 *, struct kernfs_node___96 *, struct kernfs_root___96 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___88;

struct seq_file___90 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___88 *op;
	int poll_event;
	const struct file___100 *file;
	void *private;
};

struct vm_operations_struct___97;

struct kernfs_open_file___96 {
	struct kernfs_node___96 *kn;
	struct file___100 *file;
	struct seq_file___90 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___97 *vm_ops;
};

struct dentry___100;

struct path___99 {
	struct vfsmount *mnt;
	struct dentry___100 *dentry;
};

struct fown_struct___82 {
	rwlock_t lock;
	struct pid___82 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___100 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___99 f_path;
	struct inode___101 *f_inode;
	const struct file_operations___100 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___82 f_owner;
	const struct cred___95 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___99 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___97;

struct vm_operations_struct___97 {
	void (*open)(struct vm_area_struct___100 *);
	void (*close)(struct vm_area_struct___100 *);
	int (*split)(struct vm_area_struct___100 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___100 *);
	vm_fault_t (*fault)(struct vm_fault___97 *);
	vm_fault_t (*huge_fault)(struct vm_fault___97 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___97 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___100 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___97 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___97 *);
	int (*access)(struct vm_area_struct___100 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___100 *);
	int (*set_policy)(struct vm_area_struct___100 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___100 *, long unsigned int);
	struct page___100 * (*find_special_page)(struct vm_area_struct___100 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___62)(struct file___100 *, wait_queue_head_t *, struct poll_table_struct___63 *);

struct poll_table_struct___63 {
	poll_queue_proc___62 _qproc;
	__poll_t _key;
};

struct vm_area_struct___100 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___100 *vm_next;
	struct vm_area_struct___100 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___99 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___97 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___100 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___94;

struct bin_attribute___90;

struct attribute_group___90 {
	const char *name;
	umode_t (*is_visible)(struct kobject___94 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___94 *, struct bin_attribute___90 *, int);
	struct attribute **attrs;
	struct bin_attribute___90 **bin_attrs;
};

struct kset___93;

struct kobj_type___93;

struct kobject___94 {
	const char *name;
	struct list_head entry;
	struct kobject___94 *parent;
	struct kset___93 *kset;
	struct kobj_type___93 *ktype;
	struct kernfs_node___96 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___90 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___100 *, struct kobject___94 *, struct bin_attribute___90 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___100 *, struct kobject___94 *, struct bin_attribute___90 *, char *, loff_t, size_t);
	int (*mmap)(struct file___100 *, struct kobject___94 *, struct bin_attribute___90 *, struct vm_area_struct___100 *);
};

struct sysfs_ops___93 {
	ssize_t (*show)(struct kobject___94 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___94 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___93;

struct kset___93 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___94 kobj;
	const struct kset_uevent_ops___93 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___93 {
	void (*release)(struct kobject___94 *);
	const struct sysfs_ops___93 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___5 * (*child_ns_type)(struct kobject___94 *);
	const void * (*namespace)(struct kobject___94 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___93 {
	int (* const filter)(struct kset___93 *, struct kobject___94 *);
	const char * (* const name)(struct kset___93 *, struct kobject___94 *);
	int (* const uevent)(struct kset___93 *, struct kobject___94 *, struct kobj_uevent_env *);
};

struct kobj_attribute___94 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___94 *, struct kobj_attribute___94 *, char *);
	ssize_t (*store)(struct kobject___94 *, struct kobj_attribute___94 *, const char *, size_t);
};

struct device___91;

struct dev_pm_ops___91 {
	int (*prepare)(struct device___91 *);
	void (*complete)(struct device___91 *);
	int (*suspend)(struct device___91 *);
	int (*resume)(struct device___91 *);
	int (*freeze)(struct device___91 *);
	int (*thaw)(struct device___91 *);
	int (*poweroff)(struct device___91 *);
	int (*restore)(struct device___91 *);
	int (*suspend_late)(struct device___91 *);
	int (*resume_early)(struct device___91 *);
	int (*freeze_late)(struct device___91 *);
	int (*thaw_early)(struct device___91 *);
	int (*poweroff_late)(struct device___91 *);
	int (*restore_early)(struct device___91 *);
	int (*suspend_noirq)(struct device___91 *);
	int (*resume_noirq)(struct device___91 *);
	int (*freeze_noirq)(struct device___91 *);
	int (*thaw_noirq)(struct device___91 *);
	int (*poweroff_noirq)(struct device___91 *);
	int (*restore_noirq)(struct device___91 *);
	int (*runtime_suspend)(struct device___91 *);
	int (*runtime_resume)(struct device___91 *);
	int (*runtime_idle)(struct device___91 *);
};

struct dev_pm_info___91 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___91 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___91;

struct bus_type___91;

struct device_driver___91;

struct dev_pm_domain___91;

struct device_node___29;

struct fwnode_handle___65;

struct class___91;

struct device___91 {
	struct device___91 *parent;
	struct device_private *p;
	struct kobject___94 kobj;
	const char *init_name;
	const struct device_type___91 *type;
	struct mutex mutex;
	struct bus_type___91 *bus;
	struct device_driver___91 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___91 power;
	struct dev_pm_domain___91 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___29 *of_node;
	struct fwnode_handle___65 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___91 *class;
	const struct attribute_group___90 **groups;
	void (*release)(struct device___91 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___91 {
	struct dev_pm_ops___91 ops;
	void (*detach)(struct device___91 *, bool);
	int (*activate)(struct device___91 *);
	void (*sync)(struct device___91 *);
	void (*dismiss)(struct device___91 *);
};

struct upid___82 {
	int nr;
	struct pid_namespace___82 *ns;
};

struct pid_namespace___82 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___100 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___82 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___100 *proc_self;
	struct dentry___100 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___80 *user_ns;
	struct ucounts___80 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___7 ns;
};

struct pid___82 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___82 numbers[1];
};

struct user_struct___95 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___95 *uid_keyring;
	struct key___95 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct linux_binfmt___14;

struct core_state___99;

struct mm_struct___99 {
	struct {
		struct vm_area_struct___100 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___100 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___100 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___14 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___99 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___100 *owner;
		struct user_namespace___80 *user_ns;
		struct file___100 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___99 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup___76;

struct cgroup_subsys___76;

struct cgroup_subsys_state___76 {
	struct cgroup___76 *cgroup;
	struct cgroup_subsys___76 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___76 *parent;
};

struct cgroup_file___76 {
	struct kernfs_node___96 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___36;

struct mem_cgroup___36 {
	struct cgroup_subsys_state___76 css;
	struct mem_cgroup_id___2 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___76 events_file;
	struct cgroup_file___76 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___100 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___36 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cred___95 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___95 *session_keyring;
	struct key___95 *process_keyring;
	struct key___95 *thread_keyring;
	struct key___95 *request_key_auth;
	void *security;
	struct user_struct___95 *user;
	struct user_namespace___80 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___76;

struct nsproxy___92 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___82 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___76 *cgroup_ns;
};

struct signal_struct___89 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___100 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___100 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___82 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___82 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___99 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___82 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___39;

struct bio_list___39 {
	struct bio___39 *head;
	struct bio___39 *tail;
};

struct bdi_writeback_congested___39;

struct bdi_writeback___39 {
	struct backing_dev_info___39 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___39 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___76 *memcg_css;
	struct cgroup_subsys_state___76 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___39 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___39 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___91 *dev;
	struct device___91 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___100 *debug_dir;
	struct dentry___100 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___76 {
	struct cgroup_subsys_state___76 *subsys[13];
	refcount_t refcount;
	struct css_set___76 *dom_cset;
	struct cgroup___76 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___76 *mg_src_cgrp;
	struct cgroup___76 *mg_dst_cgrp;
	struct css_set___76 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___58 {
	struct pmu___58 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___100 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___58 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___71 {
	struct vm_struct___71 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___100 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___89 {
	struct task_struct___100 task;
	long unsigned int stack[8192];
};

struct bus_type___91 {
	const char *name;
	const char *dev_name;
	struct device___91 *dev_root;
	const struct attribute_group___90 **bus_groups;
	const struct attribute_group___90 **dev_groups;
	const struct attribute_group___90 **drv_groups;
	int (*match)(struct device___91 *, struct device_driver___91 *);
	int (*uevent)(struct device___91 *, struct kobj_uevent_env *);
	int (*probe)(struct device___91 *);
	int (*remove)(struct device___91 *);
	void (*shutdown)(struct device___91 *);
	int (*online)(struct device___91 *);
	int (*offline)(struct device___91 *);
	int (*suspend)(struct device___91 *, pm_message_t);
	int (*resume)(struct device___91 *);
	int (*num_vf)(struct device___91 *);
	int (*dma_configure)(struct device___91 *);
	const struct dev_pm_ops___91 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___91 {
	const char *name;
	struct bus_type___91 *bus;
	struct module___83 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___91 *);
	int (*remove)(struct device___91 *);
	void (*shutdown)(struct device___91 *);
	int (*suspend)(struct device___91 *, pm_message_t);
	int (*resume)(struct device___91 *);
	const struct attribute_group___90 **groups;
	const struct dev_pm_ops___91 *pm;
	void (*coredump)(struct device___91 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___91 {
	const char *name;
	const struct attribute_group___90 **groups;
	int (*uevent)(struct device___91 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___91 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___91 *);
	const struct dev_pm_ops___91 *pm;
};

struct module_kobject___80 {
	struct kobject___94 kobj;
	struct module___83 *mod;
	struct kobject___94 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___80 {
	struct module___83 *mod;
	struct latch_tree_node node;
};

struct module_layout___80 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___80 mtn;
};

struct module_attribute___80;

struct kernel_param___80;

struct module___83 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___80 mkobj;
	struct module_attribute___80 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___94 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___80 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___80 core_layout;
	struct module_layout___80 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___53 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct class___91 {
	const char *name;
	struct module___83 *owner;
	const struct attribute_group___90 **class_groups;
	const struct attribute_group___90 **dev_groups;
	struct kobject___94 *dev_kobj;
	int (*dev_uevent)(struct device___91 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___91 *, umode_t *);
	void (*class_release)(struct class___91 *);
	void (*dev_release)(struct device___91 *);
	int (*shutdown_pre)(struct device___91 *);
	const struct kobj_ns_type_operations___5 *ns_type;
	const void * (*namespace)(struct device___91 *);
	const struct dev_pm_ops___91 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct fwnode_operations___65;

struct fwnode_handle___65 {
	struct fwnode_handle___65 *secondary;
	const struct fwnode_operations___65 *ops;
};

struct property___28;

struct device_node___29 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___65 fwnode;
	struct property___28 *properties;
	struct property___28 *deadprops;
	struct device_node___29 *parent;
	struct device_node___29 *child;
	struct device_node___29 *sibling;
	struct kobject___94 kobj;
	long unsigned int _flags;
	void *data;
};

struct node___77 {
	struct device___91 dev;
};

struct fwnode_reference_args___65;

struct fwnode_endpoint___65;

struct fwnode_operations___65 {
	struct fwnode_handle___65 * (*get)(struct fwnode_handle___65 *);
	void (*put)(struct fwnode_handle___65 *);
	bool (*device_is_available)(const struct fwnode_handle___65 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___65 *, const struct device___91 *);
	bool (*property_present)(const struct fwnode_handle___65 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___65 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___65 *, const char *, const char **, size_t);
	struct fwnode_handle___65 * (*get_parent)(const struct fwnode_handle___65 *);
	struct fwnode_handle___65 * (*get_next_child_node)(const struct fwnode_handle___65 *, struct fwnode_handle___65 *);
	struct fwnode_handle___65 * (*get_named_child_node)(const struct fwnode_handle___65 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___65 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___65 *);
	struct fwnode_handle___65 * (*graph_get_next_endpoint)(const struct fwnode_handle___65 *, struct fwnode_handle___65 *);
	struct fwnode_handle___65 * (*graph_get_remote_endpoint)(const struct fwnode_handle___65 *);
	struct fwnode_handle___65 * (*graph_get_port_parent)(struct fwnode_handle___65 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___65 *, struct fwnode_endpoint___65 *);
};

struct fwnode_endpoint___65 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___65 *local_fwnode;
};

struct fwnode_reference_args___65 {
	struct fwnode_handle___65 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct property___28 {
	char *name;
	int length;
	void *value;
	struct property___28 *next;
	long unsigned int _flags;
	struct bin_attribute___90 attr;
};

struct address_space_operations___99;

struct address_space___99 {
	struct inode___101 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___100 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___99 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___97)(struct vm_area_struct___100 *, long unsigned int, const struct page___100 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___97)(struct page___100 *, void *);

struct dev_pagemap___97 {
	dev_page_fault_t___97 page_fault;
	dev_page_free_t___97 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___91 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___99 {
	struct task_struct___100 *task;
	struct core_thread___99 *next;
};

struct core_state___99 {
	atomic_t nr_threads;
	struct core_thread___99 dumper;
	struct completion startup;
};

struct linux_binprm___15;

struct coredump_params___14;

struct linux_binfmt___14 {
	struct list_head lh;
	struct module___83 *module;
	int (*load_binary)(struct linux_binprm___15 *);
	int (*load_shlib)(struct file___100 *);
	int (*core_dump)(struct coredump_params___14 *);
	long unsigned int min_coredump;
};

struct vm_fault___97 {
	struct vm_area_struct___100 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___100 *cow_page;
	struct mem_cgroup___36 *memcg;
	struct page___100 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___99 prealloc_pte;
};

struct shrink_control___36 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___36 *memcg;
};

struct shrinker___36 {
	long unsigned int (*count_objects)(struct shrinker___36 *, struct shrink_control___36 *);
	long unsigned int (*scan_objects)(struct shrinker___36 *, struct shrink_control___36 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct dentry_operations___99;

struct super_block___100;

struct dentry___100 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___100 *d_parent;
	struct qstr d_name;
	struct inode___101 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___99 *d_op;
	struct super_block___100 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___99;

struct block_device___100;

struct inode___101 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___99 *i_op;
	struct super_block___100 *i_sb;
	struct address_space___99 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___100 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___39 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___100 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___99 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___100 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___99 {
	int (*d_revalidate)(struct dentry___100 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___100 *, unsigned int);
	int (*d_hash)(const struct dentry___100 *, struct qstr *);
	int (*d_compare)(const struct dentry___100 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___100 *);
	int (*d_init)(struct dentry___100 *);
	void (*d_release)(struct dentry___100 *);
	void (*d_prune)(struct dentry___100 *);
	void (*d_iput)(struct dentry___100 *, struct inode___101 *);
	char * (*d_dname)(struct dentry___100 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___99 *);
	int (*d_manage)(const struct path___99 *, bool);
	struct dentry___100 * (*d_real)(struct dentry___100 *, const struct inode___101 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___99;

struct mem_dqinfo___99 {
	struct quota_format_type___99 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___99;

struct quota_info___99 {
	unsigned int flags;
	struct rw_semaphore___100 dqio_sem;
	struct inode___101 *files[3];
	struct mem_dqinfo___99 info[3];
	const struct quota_format_ops___99 *ops[3];
};

struct rcuwait___99 {
	struct task_struct___100 *task;
};

struct percpu_rw_semaphore___99 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___100 rw_sem;
	struct rcuwait___99 writer;
	int readers_block;
};

struct sb_writers___99 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___99 rw_sem[3];
};

struct file_system_type___99;

struct super_operations___99;

struct dquot_operations___99;

struct quotactl_ops___99;

struct super_block___100 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___99 *s_type;
	const struct super_operations___99 *s_op;
	const struct dquot_operations___99 *dq_op;
	const struct quotactl_ops___99 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___100 *s_root;
	struct rw_semaphore___100 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___100 *s_bdev;
	struct backing_dev_info___39 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___99 s_dquot;
	struct sb_writers___99 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___99 *s_d_op;
	int cleancache_poolid;
	struct shrinker___36 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___80 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___100 {
	struct file___100 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___100 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___100 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___100 *ia_file;
};

struct dquot___99 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___100 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___99 {
	int qf_fmt_id;
	const struct quota_format_ops___99 *qf_ops;
	struct module___83 *qf_owner;
	struct quota_format_type___99 *qf_next;
};

struct quota_format_ops___99 {
	int (*check_quota_file)(struct super_block___100 *, int);
	int (*read_file_info)(struct super_block___100 *, int);
	int (*write_file_info)(struct super_block___100 *, int);
	int (*free_file_info)(struct super_block___100 *, int);
	int (*read_dqblk)(struct dquot___99 *);
	int (*commit_dqblk)(struct dquot___99 *);
	int (*release_dqblk)(struct dquot___99 *);
	int (*get_next_id)(struct super_block___100 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___99 {
	int (*write_dquot)(struct dquot___99 *);
	struct dquot___99 * (*alloc_dquot)(struct super_block___100 *, int);
	void (*destroy_dquot)(struct dquot___99 *);
	int (*acquire_dquot)(struct dquot___99 *);
	int (*release_dquot)(struct dquot___99 *);
	int (*mark_dirty)(struct dquot___99 *);
	int (*write_info)(struct super_block___100 *, int);
	qsize_t * (*get_reserved_space)(struct inode___101 *);
	int (*get_projid)(struct inode___101 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___101 *, qsize_t *);
	int (*get_next_id)(struct super_block___100 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___99 {
	int (*quota_on)(struct super_block___100 *, int, int, const struct path___99 *);
	int (*quota_off)(struct super_block___100 *, int);
	int (*quota_enable)(struct super_block___100 *, unsigned int);
	int (*quota_disable)(struct super_block___100 *, unsigned int);
	int (*quota_sync)(struct super_block___100 *, int);
	int (*set_info)(struct super_block___100 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___100 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___100 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___100 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___100 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___100 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___37;

struct swap_info_struct___27;

struct address_space_operations___99 {
	int (*writepage)(struct page___100 *, struct writeback_control___37 *);
	int (*readpage)(struct file___100 *, struct page___100 *);
	int (*writepages)(struct address_space___99 *, struct writeback_control___37 *);
	int (*set_page_dirty)(struct page___100 *);
	int (*readpages)(struct file___100 *, struct address_space___99 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___100 *, struct address_space___99 *, loff_t, unsigned int, unsigned int, struct page___100 **, void **);
	int (*write_end)(struct file___100 *, struct address_space___99 *, loff_t, unsigned int, unsigned int, struct page___100 *, void *);
	sector_t (*bmap)(struct address_space___99 *, sector_t);
	void (*invalidatepage)(struct page___100 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___100 *, gfp_t);
	void (*freepage)(struct page___100 *);
	ssize_t (*direct_IO)(struct kiocb___100 *, struct iov_iter___40 *);
	int (*migratepage)(struct address_space___99 *, struct page___100 *, struct page___100 *, enum migrate_mode);
	bool (*isolate_page)(struct page___100 *, isolate_mode_t);
	void (*putback_page)(struct page___100 *);
	int (*launder_page)(struct page___100 *);
	int (*is_partially_uptodate)(struct page___100 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___100 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___99 *, struct page___100 *);
	int (*swap_activate)(struct swap_info_struct___27 *, struct file___100 *, sector_t *);
	void (*swap_deactivate)(struct file___100 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___37 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___39 *wb;
	struct inode___101 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___39;

struct iov_iter___40 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___39 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct swap_info_struct___27 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___100 *bdev;
	struct file___100 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___100 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___101 *bd_inode;
	struct super_block___100 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___100 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___39 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___99 {
	struct dentry___100 * (*lookup)(struct inode___101 *, struct dentry___100 *, unsigned int);
	const char * (*get_link)(struct dentry___100 *, struct inode___101 *, struct delayed_call *);
	int (*permission)(struct inode___101 *, int);
	struct posix_acl * (*get_acl)(struct inode___101 *, int);
	int (*readlink)(struct dentry___100 *, char *, int);
	int (*create)(struct inode___101 *, struct dentry___100 *, umode_t, bool);
	int (*link)(struct dentry___100 *, struct inode___101 *, struct dentry___100 *);
	int (*unlink)(struct inode___101 *, struct dentry___100 *);
	int (*symlink)(struct inode___101 *, struct dentry___100 *, const char *);
	int (*mkdir)(struct inode___101 *, struct dentry___100 *, umode_t);
	int (*rmdir)(struct inode___101 *, struct dentry___100 *);
	int (*mknod)(struct inode___101 *, struct dentry___100 *, umode_t, dev_t);
	int (*rename)(struct inode___101 *, struct dentry___100 *, struct inode___101 *, struct dentry___100 *, unsigned int);
	int (*setattr)(struct dentry___100 *, struct iattr___100 *);
	int (*getattr)(const struct path___99 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___100 *, char *, size_t);
	int (*fiemap)(struct inode___101 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___101 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___101 *, struct dentry___100 *, struct file___100 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___101 *, struct dentry___100 *, umode_t);
	int (*set_acl)(struct inode___101 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___99 {
	void (*fl_copy_lock)(struct file_lock___100 *, struct file_lock___100 *);
	void (*fl_release_private)(struct file_lock___100 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___99;

struct file_lock___100 {
	struct file_lock___100 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___100 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___99 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___99 *fl_ops;
	const struct lock_manager_operations___99 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___99 {
	int (*lm_compare_owner)(struct file_lock___100 *, struct file_lock___100 *);
	long unsigned int (*lm_owner_key)(struct file_lock___100 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___100 *);
	int (*lm_grant)(struct file_lock___100 *, int);
	bool (*lm_break)(struct file_lock___100 *);
	int (*lm_change)(struct file_lock___100 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___100 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___99 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___99 *fa_next;
	struct file___100 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___99 {
	const char *name;
	int fs_flags;
	struct dentry___100 * (*mount)(struct file_system_type___99 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___100 *);
	struct module___83 *owner;
	struct file_system_type___99 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___99 {
	struct inode___101 * (*alloc_inode)(struct super_block___100 *);
	void (*destroy_inode)(struct inode___101 *);
	void (*dirty_inode)(struct inode___101 *, int);
	int (*write_inode)(struct inode___101 *, struct writeback_control___37 *);
	int (*drop_inode)(struct inode___101 *);
	void (*evict_inode)(struct inode___101 *);
	void (*put_super)(struct super_block___100 *);
	int (*sync_fs)(struct super_block___100 *, int);
	int (*freeze_super)(struct super_block___100 *);
	int (*freeze_fs)(struct super_block___100 *);
	int (*thaw_super)(struct super_block___100 *);
	int (*unfreeze_fs)(struct super_block___100 *);
	int (*statfs)(struct dentry___100 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___100 *, int *, char *);
	void (*umount_begin)(struct super_block___100 *);
	int (*show_options)(struct seq_file___90 *, struct dentry___100 *);
	int (*show_devname)(struct seq_file___90 *, struct dentry___100 *);
	int (*show_path)(struct seq_file___90 *, struct dentry___100 *);
	int (*show_stats)(struct seq_file___90 *, struct dentry___100 *);
	ssize_t (*quota_read)(struct super_block___100 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___100 *, int, const char *, size_t, loff_t);
	struct dquot___99 ** (*get_dquots)(struct inode___101 *);
	int (*bdev_try_to_free_page)(struct super_block___100 *, struct page___100 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___100 *, struct shrink_control___36 *);
	long int (*free_cached_objects)(struct super_block___100 *, struct shrink_control___36 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___39(struct bio___39 *);

struct bio_vec___39 {
	struct page___100 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___39;

struct bio_set___39;

struct bio___39 {
	struct bio___39 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___39 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___39 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___39 *bi_io_vec;
	struct bio_set___39 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___39 bi_inline_vecs[0];
};

typedef void compound_page_dtor___97(struct page___100 *);

struct kernel_param_ops___80 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___80 *);
	int (*get)(char *, const struct kernel_param___80 *);
	void (*free)(void *);
};

struct kparam_array___80;

struct kernel_param___80 {
	const char *name;
	struct module___83 *mod;
	const struct kernel_param_ops___80 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___80 *arr;
	};
};

struct kparam_array___80 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___80 *ops;
	void *elem;
};

struct module_attribute___80 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___80 *, struct module_kobject___80 *, char *);
	ssize_t (*store)(struct module_attribute___80 *, struct module_kobject___80 *, const char *, size_t);
	void (*setup)(struct module___83 *, const char *);
	int (*test)(struct module___83 *);
	void (*free)(struct module___83 *);
};

struct trace_event_class___53;

struct trace_event_call___53 {
	struct list_head list;
	struct trace_event_class___53 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___9 *prog_array;
	int (*perf_perm)(struct trace_event_call___53 *, struct perf_event___58 *);
};

typedef int (*key_restrict_link_func_t___95)(struct key___95 *, const struct key_type *, const union key_payload *, struct key___95 *);

struct key_restriction___95;

struct key___95 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___100 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___95 *restrict_link;
};

struct key_restriction___95 {
	key_restrict_link_func_t___95 check;
	struct key___95 *key;
	struct key_type *keytype;
};

struct seq_operations___88 {
	void * (*start)(struct seq_file___90 *, loff_t *);
	void (*stop)(struct seq_file___90 *, void *);
	void * (*next)(struct seq_file___90 *, void *, loff_t *);
	int (*show)(struct seq_file___90 *, void *);
};

struct cgroup_namespace___76 {
	refcount_t count;
	struct ns_common___7 ns;
	struct user_namespace___80 *user_ns;
	struct ucounts___80 *ucounts;
	struct css_set___76 *root_cset;
};

struct ucounts___80 {
	struct hlist_node node;
	struct user_namespace___80 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___76;

struct bpf_map_ops___76 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___76 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___76 *, struct file___100 *);
	void (*map_free)(struct bpf_map___76 *);
	int (*map_get_next_key)(struct bpf_map___76 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___76 *);
	void * (*map_lookup_elem)(struct bpf_map___76 *, void *);
	int (*map_update_elem)(struct bpf_map___76 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___76 *, void *);
	int (*map_push_elem)(struct bpf_map___76 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___76 *, void *);
	int (*map_peek_elem)(struct bpf_map___76 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___76 *, struct file___100 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___76 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___76 *, void *, struct seq_file___90 *);
	int (*map_check_btf)(const struct bpf_map___76 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___76 {
	const struct bpf_map_ops___76 *ops;
	struct bpf_map___76 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___95 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___76;

typedef void (*kthread_work_func_t___76)(struct kthread_work___76 *);

struct kthread_worker___76;

struct kthread_work___76 {
	struct list_head node;
	kthread_work_func_t___76 func;
	struct kthread_worker___76 *worker;
	int canceling;
};

struct kthread_worker___76 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___100 *task;
	struct kthread_work___76 *current_work;
};

struct kthread_delayed_work___76 {
	struct kthread_work___76 work;
	struct timer_list timer;
};

struct psi_group___76 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___76 *poll_kworker;
	struct kthread_delayed_work___76 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___76;

struct cgroup_rstat_cpu___76;

struct cgroup___76 {
	struct cgroup_subsys_state___76 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___96 *kn;
	struct cgroup_file___76 procs_file;
	struct cgroup_file___76 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___76 *subsys[13];
	struct cgroup_root___76 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___76 *dom_cgrp;
	struct cgroup_rstat_cpu___76 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___9 bpf;
	atomic_t congestion_count;
	struct cgroup___76 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___76 psi;
	int ancestor_ids[0];
};

struct cftype___76;

struct cgroup_subsys___76 {
	struct cgroup_subsys_state___76 * (*css_alloc)(struct cgroup_subsys_state___76 *);
	int (*css_online)(struct cgroup_subsys_state___76 *);
	void (*css_offline)(struct cgroup_subsys_state___76 *);
	void (*css_released)(struct cgroup_subsys_state___76 *);
	void (*css_free)(struct cgroup_subsys_state___76 *);
	void (*css_reset)(struct cgroup_subsys_state___76 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___76 *, int);
	int (*css_extra_stat_show)(struct seq_file___90 *, struct cgroup_subsys_state___76 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___100 *);
	void (*cancel_fork)(struct task_struct___100 *);
	void (*fork)(struct task_struct___100 *);
	void (*exit)(struct task_struct___100 *);
	void (*free)(struct task_struct___100 *);
	void (*bind)(struct cgroup_subsys_state___76 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___76 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___76 *dfl_cftypes;
	struct cftype___76 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___76 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___76 *updated_children;
	struct cgroup___76 *updated_next;
};

struct cgroup_root___76 {
	struct kernfs_root___96 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___76 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___76 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___76 *ss;
	struct list_head node;
	struct kernfs_ops___96 *kf_ops;
	int (*open)(struct kernfs_open_file___96 *);
	void (*release)(struct kernfs_open_file___96 *);
	u64 (*read_u64)(struct cgroup_subsys_state___76 *, struct cftype___76 *);
	s64 (*read_s64)(struct cgroup_subsys_state___76 *, struct cftype___76 *);
	int (*seq_show)(struct seq_file___90 *, void *);
	void * (*seq_start)(struct seq_file___90 *, loff_t *);
	void * (*seq_next)(struct seq_file___90 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___90 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___76 *, struct cftype___76 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___76 *, struct cftype___76 *, s64);
	ssize_t (*write)(struct kernfs_open_file___96 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___96 *, struct poll_table_struct___63 *);
};

struct bdi_writeback_congested___39 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___39 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___39 {
	struct bio___39 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___39 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___39 bip_inline_vecs[0];
};

struct bio_set___39 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___39 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___36 {
	struct mem_cgroup___36 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___36 {
	struct lruvec___99 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___36 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___36 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

enum {
	FTRACE_OPS_FL_ENABLED = 1,
	FTRACE_OPS_FL_DYNAMIC = 2,
	FTRACE_OPS_FL_SAVE_REGS = 4,
	FTRACE_OPS_FL_SAVE_REGS_IF_SUPPORTED = 8,
	FTRACE_OPS_FL_RECURSION_SAFE = 16,
	FTRACE_OPS_FL_STUB = 32,
	FTRACE_OPS_FL_INITIALIZED = 64,
	FTRACE_OPS_FL_DELETED = 128,
	FTRACE_OPS_FL_ADDING = 256,
	FTRACE_OPS_FL_REMOVING = 512,
	FTRACE_OPS_FL_MODIFYING = 1024,
	FTRACE_OPS_FL_ALLOC_TRAMP = 2048,
	FTRACE_OPS_FL_IPMODIFY = 4096,
	FTRACE_OPS_FL_PID = 8192,
	FTRACE_OPS_FL_RCU = 16384,
	FTRACE_OPS_FL_TRACE_ARRAY = 32768,
};

struct ftrace_hash {
	long unsigned int size_bits;
	struct hlist_head *buckets;
	long unsigned int count;
	long unsigned int flags;
	struct callback_head rcu;
};

enum {
	FTRACE_FL_ENABLED = 2147483648,
	FTRACE_FL_REGS = 1073741824,
	FTRACE_FL_REGS_EN = 536870912,
	FTRACE_FL_TRAMP = 268435456,
	FTRACE_FL_TRAMP_EN = 134217728,
	FTRACE_FL_IPMODIFY = 67108864,
	FTRACE_FL_DISABLED = 33554432,
};

enum {
	FTRACE_UPDATE_CALLS = 1,
	FTRACE_DISABLE_CALLS = 2,
	FTRACE_UPDATE_TRACE_FUNC = 4,
	FTRACE_START_FUNC_RET = 8,
	FTRACE_STOP_FUNC_RET = 16,
};

enum {
	FTRACE_UPDATE_IGNORE = 0,
	FTRACE_UPDATE_MAKE_CALL = 1,
	FTRACE_UPDATE_MODIFY_CALL = 2,
	FTRACE_UPDATE_MAKE_NOP = 3,
};

enum {
	FTRACE_ITER_FILTER = 1,
	FTRACE_ITER_NOTRACE = 2,
	FTRACE_ITER_PRINTALL = 4,
	FTRACE_ITER_DO_PROBES = 8,
	FTRACE_ITER_PROBE = 16,
	FTRACE_ITER_MOD = 32,
	FTRACE_ITER_ENABLED = 64,
};

struct linux_binprm___15 {
	char buf[256];
	struct vm_area_struct___100 *vma;
	long unsigned int vma_pages;
	struct mm_struct___99 *mm;
	long unsigned int p;
	unsigned int called_set_creds: 1;
	unsigned int cap_elevated: 1;
	unsigned int secureexec: 1;
	unsigned int recursion_depth;
	struct file___100 *file;
	struct cred___95 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
};

struct coredump_params___14 {
	union {
		const kernel_siginfo_t *siginfo;
		struct {
			const siginfo_t *siginfo;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	struct pt_regs *regs;
	struct file___100 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
};

struct perf_cpu_context___58;

struct pmu___58 {
	struct list_head entry;
	struct module___83 *module;
	struct device___91 *dev;
	const struct attribute_group___90 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___58 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___58 *);
	void (*pmu_disable)(struct pmu___58 *);
	int (*event_init)(struct perf_event___58 *);
	void (*event_mapped)(struct perf_event___58 *, struct mm_struct___99 *);
	void (*event_unmapped)(struct perf_event___58 *, struct mm_struct___99 *);
	int (*add)(struct perf_event___58 *, int);
	void (*del)(struct perf_event___58 *, int);
	void (*start)(struct perf_event___58 *, int);
	void (*stop)(struct perf_event___58 *, int);
	void (*read)(struct perf_event___58 *);
	void (*start_txn)(struct pmu___58 *, unsigned int);
	int (*commit_txn)(struct pmu___58 *);
	void (*cancel_txn)(struct pmu___58 *);
	int (*event_idx)(struct perf_event___58 *);
	void (*sched_task)(struct perf_event_context___58 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___58 *);
	int (*filter_match)(struct perf_event___58 *);
	int (*check_period)(struct perf_event___58 *, u64);
};

struct perf_cpu_context___58 {
	struct perf_event_context___58 ctx;
	struct perf_event_context___58 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___58 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct prog_entry;

struct event_filter {
	struct prog_entry *prog;
	char *filter_string;
};

struct perf_cgroup___58 {
	struct cgroup_subsys_state___76 css;
	struct perf_cgroup_info *info;
};

struct trace_array_cpu;

struct trace_buffer {
	struct trace_array *tr;
	struct ring_buffer *buffer;
	struct trace_array_cpu *data;
	u64 time_start;
	int cpu;
};

struct trace_pid_list;

struct trace_event_file___18;

struct trace_options;

struct trace_array {
	struct list_head list;
	char *name;
	struct trace_buffer trace_buffer;
	struct trace_buffer max_buffer;
	bool allocated_snapshot;
	long unsigned int max_latency;
	struct trace_pid_list *filtered_pids;
	arch_spinlock_t max_lock;
	int buffer_disabled;
	int sys_refcount_enter;
	int sys_refcount_exit;
	struct trace_event_file___18 *enter_syscall_files[295];
	struct trace_event_file___18 *exit_syscall_files[295];
	int stop_count;
	int clock_id;
	int nr_topts;
	bool clear_trace;
	struct tracer *current_trace;
	unsigned int trace_flags;
	unsigned char trace_flags_index[32];
	unsigned int flags;
	raw_spinlock_t start_lock;
	struct dentry___100 *dir;
	struct dentry___100 *options;
	struct dentry___100 *percpu_dir;
	struct dentry___100 *event_dir;
	struct trace_options *topts;
	struct list_head systems;
	struct list_head events;
	struct trace_event_file___18 *trace_marker_file;
	cpumask_var_t tracing_cpumask;
	int ref;
	struct ftrace_ops *ops;
	struct trace_pid_list *function_pids;
	struct list_head func_probes;
	struct list_head mod_trace;
	struct list_head mod_notrace;
	int function_enabled;
	int time_stamp_abs_ref;
	struct list_head hist_vars;
};

struct tracer_flags;

struct tracer {
	const char *name;
	int (*init)(struct trace_array *);
	void (*reset)(struct trace_array *);
	void (*start)(struct trace_array *);
	void (*stop)(struct trace_array *);
	int (*update_thresh)(struct trace_array *);
	void (*open)(struct trace_iterator *);
	void (*pipe_open)(struct trace_iterator *);
	void (*close)(struct trace_iterator *);
	void (*pipe_close)(struct trace_iterator *);
	ssize_t (*read)(struct trace_iterator *, struct file___100 *, char *, size_t, loff_t *);
	ssize_t (*splice_read)(struct trace_iterator *, struct file___100 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	void (*print_header)(struct seq_file___90 *);
	enum print_line_t (*print_line)(struct trace_iterator *);
	int (*set_flag)(struct trace_array *, u32, u32, int);
	int (*flag_changed)(struct trace_array *, u32, int);
	struct tracer *next;
	struct tracer_flags *flags;
	int enabled;
	int ref;
	bool print_max;
	bool allow_instances;
	bool use_max_tr;
	bool noboot;
};

struct trace_event_class___53 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___53 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___53 *);
	struct list_head * (*get_fields)(struct trace_event_call___53 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___53 *);
};

struct trace_subsystem_dir___2;

struct trace_event_file___18 {
	struct list_head list;
	struct trace_event_call___53 *event_call;
	struct event_filter *filter;
	struct dentry___100 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir___2 *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct event_subsystem;

struct trace_subsystem_dir___2 {
	struct list_head list;
	struct event_subsystem *subsystem;
	struct trace_array *tr;
	struct dentry___100 *entry;
	int ref_count;
	int nr_events;
};

struct trace_array_cpu {
	atomic_t disabled;
	void *buffer_page;
	long unsigned int entries;
	long unsigned int saved_latency;
	long unsigned int critical_start;
	long unsigned int critical_end;
	long unsigned int critical_sequence;
	long unsigned int nice;
	long unsigned int policy;
	long unsigned int rt_priority;
	long unsigned int skipped_entries;
	u64 preempt_timestamp;
	pid_t pid;
	kuid_t uid;
	char comm[16];
	bool ignore_pid;
	bool ftrace_ignore_pid;
};

struct trace_option_dentry;

struct trace_options {
	struct tracer *tracer;
	struct trace_option_dentry *topts;
};

struct tracer_opt;

struct trace_option_dentry {
	struct tracer_opt *opt;
	struct tracer_flags *flags;
	struct trace_array *tr;
	struct dentry___100 *entry;
};

struct trace_pid_list {
	int pid_max;
	long unsigned int *pids;
};

enum {
	TRACE_ARRAY_FL_GLOBAL = 1,
};

struct tracer_opt {
	const char *name;
	u32 bit;
};

struct tracer_flags {
	u32 val;
	struct tracer_opt *opts;
	struct tracer *trace;
};

enum {
	TRACE_BUFFER_BIT = 0,
	TRACE_BUFFER_NMI_BIT = 1,
	TRACE_BUFFER_IRQ_BIT = 2,
	TRACE_BUFFER_SIRQ_BIT = 3,
	TRACE_FTRACE_BIT = 4,
	TRACE_FTRACE_NMI_BIT = 5,
	TRACE_FTRACE_IRQ_BIT = 6,
	TRACE_FTRACE_SIRQ_BIT = 7,
	TRACE_INTERNAL_BIT = 8,
	TRACE_INTERNAL_NMI_BIT = 9,
	TRACE_INTERNAL_IRQ_BIT = 10,
	TRACE_INTERNAL_SIRQ_BIT = 11,
	TRACE_BRANCH_BIT = 12,
	TRACE_IRQ_BIT = 13,
};

struct ftrace_mod_load {
	struct list_head list;
	char *func;
	char *module;
	int enable;
};

enum {
	FTRACE_HASH_FL_MOD = 1,
};

struct ftrace_func_command {
	struct list_head list;
	char *name;
	int (*func)(struct trace_array *, struct ftrace_hash *, char *, char *, char *, int);
};

struct ftrace_probe_ops {
	void (*func)(long unsigned int, long unsigned int, struct trace_array *, struct ftrace_probe_ops *, void *);
	int (*init)(struct ftrace_probe_ops *, struct trace_array *, long unsigned int, void *, void **);
	void (*free)(struct ftrace_probe_ops *, struct trace_array *, long unsigned int, void *);
	int (*print)(struct seq_file___90 *, long unsigned int, struct ftrace_probe_ops *, void *);
};

typedef int (*ftrace_mapper_func)(void *);

struct trace_parser {
	bool cont;
	char *buffer;
	unsigned int idx;
	unsigned int size;
};

enum trace_iterator_bits {
	TRACE_ITER_PRINT_PARENT_BIT = 0,
	TRACE_ITER_SYM_OFFSET_BIT = 1,
	TRACE_ITER_SYM_ADDR_BIT = 2,
	TRACE_ITER_VERBOSE_BIT = 3,
	TRACE_ITER_RAW_BIT = 4,
	TRACE_ITER_HEX_BIT = 5,
	TRACE_ITER_BIN_BIT = 6,
	TRACE_ITER_BLOCK_BIT = 7,
	TRACE_ITER_PRINTK_BIT = 8,
	TRACE_ITER_ANNOTATE_BIT = 9,
	TRACE_ITER_USERSTACKTRACE_BIT = 10,
	TRACE_ITER_SYM_USEROBJ_BIT = 11,
	TRACE_ITER_PRINTK_MSGONLY_BIT = 12,
	TRACE_ITER_CONTEXT_INFO_BIT = 13,
	TRACE_ITER_LATENCY_FMT_BIT = 14,
	TRACE_ITER_RECORD_CMD_BIT = 15,
	TRACE_ITER_RECORD_TGID_BIT = 16,
	TRACE_ITER_OVERWRITE_BIT = 17,
	TRACE_ITER_STOP_ON_FREE_BIT = 18,
	TRACE_ITER_IRQ_INFO_BIT = 19,
	TRACE_ITER_MARKERS_BIT = 20,
	TRACE_ITER_EVENT_FORK_BIT = 21,
	TRACE_ITER_FUNCTION_BIT = 22,
	TRACE_ITER_FUNC_FORK_BIT = 23,
	TRACE_ITER_DISPLAY_GRAPH_BIT = 24,
	TRACE_ITER_STACKTRACE_BIT = 25,
	TRACE_ITER_LAST_BIT = 26,
};

struct event_subsystem {
	struct list_head list;
	const char *name;
	struct event_filter *filter;
	int ref_count;
};

enum regex_type {
	MATCH_FULL = 0,
	MATCH_FRONT_ONLY = 1,
	MATCH_MIDDLE_ONLY = 2,
	MATCH_END_ONLY = 3,
	MATCH_GLOB = 4,
};

struct ftrace_func_entry {
	struct hlist_node hlist;
	long unsigned int ip;
};

struct ftrace_func_probe {
	struct ftrace_probe_ops *probe_ops;
	struct ftrace_ops ops;
	struct trace_array *tr;
	struct list_head list;
	void *data;
	int ref;
};

struct ftrace_page {
	struct ftrace_page *next;
	struct dyn_ftrace *records;
	int index;
	int size;
};

struct ftrace_rec_iter {
	struct ftrace_page *pg;
	int index;
};

struct ftrace_iterator {
	loff_t pos;
	loff_t func_pos;
	loff_t mod_pos;
	struct ftrace_page *pg;
	struct dyn_ftrace *func;
	struct ftrace_func_probe *probe;
	struct ftrace_func_entry *probe_entry;
	struct trace_parser parser;
	struct ftrace_hash *hash;
	struct ftrace_ops *ops;
	struct trace_array *tr;
	struct list_head *mod_list;
	int pidx;
	int idx;
	unsigned int flags;
};

struct ftrace_glob {
	char *search;
	unsigned int len;
	int type;
};

struct ftrace_func_map {
	struct ftrace_func_entry entry;
	void *data;
};

struct ftrace_func_mapper {
	struct ftrace_hash hash;
};

enum graph_filter_type {
	GRAPH_FILTER_NOTRACE = 0,
	GRAPH_FILTER_FUNCTION = 1,
};

struct ftrace_graph_data {
	struct ftrace_hash *hash;
	struct ftrace_func_entry *entry;
	int idx;
	enum graph_filter_type type;
	struct ftrace_hash *new_hash;
	const struct seq_operations___88 *seq_ops;
	struct trace_parser parser;
};

struct ftrace_mod_func {
	struct list_head list;
	char *name;
	long unsigned int ip;
	unsigned int size;
};

struct ftrace_mod_map {
	struct callback_head rcu;
	struct list_head list;
	struct module___83 *mod;
	long unsigned int start_addr;
	long unsigned int end_addr;
	struct list_head funcs;
	unsigned int num_funcs;
};

struct ftrace_init_func {
	struct list_head list;
	long unsigned int ip;
};

typedef struct poll_table_struct___58 poll_table___7;

enum ring_buffer_type {
	RINGBUF_TYPE_DATA_TYPE_LEN_MAX = 28,
	RINGBUF_TYPE_PADDING = 29,
	RINGBUF_TYPE_TIME_EXTEND = 30,
	RINGBUF_TYPE_TIME_STAMP = 31,
};

enum ring_buffer_flags {
	RB_FL_OVERWRITE = 1,
};

struct rb_irq_work {
	struct irq_work work;
	wait_queue_head_t waiters;
	wait_queue_head_t full_waiters;
	bool waiters_pending;
	bool full_waiters_pending;
	bool wakeup_full;
};

struct ring_buffer_per_cpu;

struct ring_buffer {
	unsigned int flags;
	int cpus;
	atomic_t record_disabled;
	atomic_t resize_disabled;
	cpumask_var_t cpumask;
	struct lock_class_key *reader_lock_key;
	struct mutex mutex;
	struct ring_buffer_per_cpu **buffers;
	struct hlist_node node;
	u64 (*clock)();
	struct rb_irq_work irq_work;
	bool time_stamp_abs;
};

struct buffer_page;

struct ring_buffer_iter {
	struct ring_buffer_per_cpu *cpu_buffer;
	long unsigned int head;
	struct buffer_page *head_page;
	struct buffer_page *cache_reader_page;
	long unsigned int cache_read;
	u64 read_stamp;
};

enum {
	RB_LEN_TIME_EXTEND = 8,
	RB_LEN_TIME_STAMP = 8,
};

struct buffer_data_page {
	u64 time_stamp;
	local_t commit;
	unsigned char data[0];
};

struct buffer_page {
	struct list_head list;
	local_t write;
	unsigned int read;
	local_t entries;
	long unsigned int real_end;
	struct buffer_data_page *page;
};

struct rb_event_info {
	u64 ts;
	u64 delta;
	long unsigned int length;
	struct buffer_page *tail_page;
	int add_timestamp;
};

enum {
	RB_CTX_NMI = 0,
	RB_CTX_IRQ = 1,
	RB_CTX_SOFTIRQ = 2,
	RB_CTX_NORMAL = 3,
	RB_CTX_MAX = 4,
};

struct ring_buffer_per_cpu {
	int cpu;
	atomic_t record_disabled;
	struct ring_buffer *buffer;
	raw_spinlock_t reader_lock;
	arch_spinlock_t lock;
	struct lock_class_key lock_key;
	struct buffer_data_page *free_page;
	long unsigned int nr_pages;
	unsigned int current_context;
	struct list_head *pages;
	struct buffer_page *head_page;
	struct buffer_page *tail_page;
	struct buffer_page *commit_page;
	struct buffer_page *reader_page;
	long unsigned int lost_events;
	long unsigned int last_overrun;
	long unsigned int nest;
	local_t entries_bytes;
	local_t entries;
	local_t overrun;
	local_t commit_overrun;
	local_t dropped_events;
	local_t committing;
	local_t commits;
	long unsigned int read;
	long unsigned int read_bytes;
	u64 write_stamp;
	u64 read_stamp;
	long int nr_pages_to_update;
	struct list_head new_pages;
	struct work_struct update_pages_work;
	struct completion update_done;
	struct rb_irq_work irq_work;
};

struct module___84;

struct file___101;

struct kiocb___101;

struct iov_iter___41;

struct poll_table_struct___64;

struct vm_area_struct___101;

struct inode___102;

struct file_lock___101;

struct page___101;

struct pipe_inode_info___23;

struct seq_file___91;

struct file_operations___101 {
	struct module___84 *owner;
	loff_t (*llseek)(struct file___101 *, loff_t, int);
	ssize_t (*read)(struct file___101 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___101 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___101 *, struct iov_iter___41 *);
	ssize_t (*write_iter)(struct kiocb___101 *, struct iov_iter___41 *);
	int (*iopoll)(struct kiocb___101 *, bool);
	int (*iterate)(struct file___101 *, struct dir_context *);
	int (*iterate_shared)(struct file___101 *, struct dir_context *);
	__poll_t (*poll)(struct file___101 *, struct poll_table_struct___64 *);
	long int (*unlocked_ioctl)(struct file___101 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___101 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___101 *, struct vm_area_struct___101 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___102 *, struct file___101 *);
	int (*flush)(struct file___101 *, fl_owner_t);
	int (*release)(struct inode___102 *, struct file___101 *);
	int (*fsync)(struct file___101 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___101 *, int);
	int (*lock)(struct file___101 *, int, struct file_lock___101 *);
	ssize_t (*sendpage)(struct file___101 *, struct page___101 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___101 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___101 *, int, struct file_lock___101 *);
	ssize_t (*splice_write)(struct pipe_inode_info___23 *, struct file___101 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___101 *, loff_t *, struct pipe_inode_info___23 *, size_t, unsigned int);
	int (*setlease)(struct file___101 *, long int, struct file_lock___101 **, void **);
	long int (*fallocate)(struct file___101 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___91 *, struct file___101 *);
	ssize_t (*copy_file_range)(struct file___101 *, loff_t, struct file___101 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___101 *, loff_t, struct file___101 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___101 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___100 {
	u64 seqnum;
	struct vm_area_struct___101 *vmas[4];
};

struct page_frag___100 {
	struct page___101 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___59;

struct debug_info___59 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___59 *hbp_break[16];
	struct perf_event___59 *hbp_watch[16];
};

struct thread_struct___59 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___59 debug;
	long: 64;
};

struct mm_struct___100;

struct pid___83;

struct cred___96;

struct nsproxy___93;

struct signal_struct___90;

struct bio_list___40;

struct backing_dev_info___40;

struct css_set___77;

struct perf_event_context___59;

struct vm_struct___72;

struct task_struct___101 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___101 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___100 *mm;
	struct mm_struct___100 *active_mm;
	struct vmacache___100 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___101 *real_parent;
	struct task_struct___101 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___101 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___83 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___83 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___83 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___96 *ptracer_cred;
	const struct cred___96 *real_cred;
	const struct cred___96 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___93 *nsproxy;
	struct signal_struct___90 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___101 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___40 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___40 *backing_dev_info;
	struct io_context___16 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___77 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___59 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___23 *splice_pipe;
	struct page_frag___100 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___101 *oom_reaper_list;
	struct vm_struct___72 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___59 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___59 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___101 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___59)(struct perf_event___59 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___59;

struct fasync_struct___100;

struct pid_namespace___83;

struct trace_event_call___54;

struct perf_cgroup___59;

struct perf_event___59 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___59 *group_leader;
	struct pmu___59 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___59 hw;
	struct perf_event_context___59 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___59 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___101 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___100 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___59 *);
	struct callback_head callback_head;
	struct pid_namespace___83 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___59 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___59 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___54 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___59 *cgrp;
	struct list_head sb_list;
};

typedef struct page___101 *pgtable_t___100;

struct address_space___100;

struct dev_pagemap___98;

struct page___101 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___100 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___101 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___100 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___100 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___98 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___100;

struct lruvec___100 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___100 *pgdat;
};

struct zone___100 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___100 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___100 {
	struct zone___100 *zone;
	int zone_idx;
};

struct zonelist___100 {
	struct zoneref___100 _zonerefs[25];
};

struct pglist_data___100 {
	struct zone___100 node_zones[3];
	struct zonelist___100 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___101 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___101 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___100 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___101 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___101 *owner;
};

struct secondary_data___101 {
	void *stack;
	struct task_struct___101 *task;
	long int status;
};

struct blocking_notifier_head___100 {
	struct rw_semaphore___101 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___98;

struct vm_area_struct___101 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___101 *vm_next;
	struct vm_area_struct___101 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___100 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___98 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___101 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___100;

struct user_namespace___81;

struct mm_struct___100 {
	struct {
		struct vm_area_struct___101 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___101 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___101 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___100 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___101 *owner;
		struct user_namespace___81 *user_ns;
		struct file___101 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___100 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___100;

struct address_space___100 {
	struct inode___102 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___101 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___100 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___98)(struct vm_area_struct___101 *, long unsigned int, const struct page___101 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___98)(struct page___101 *, void *);

struct device___92;

struct dev_pagemap___98 {
	dev_page_fault_t___98 page_fault;
	dev_page_free_t___98 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___92 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct vfsmount___16;

struct dentry___101;

struct path___100 {
	struct vfsmount___16 *mnt;
	struct dentry___101 *dentry;
};

struct fown_struct___83 {
	rwlock_t lock;
	struct pid___83 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___101 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___100 f_path;
	struct inode___102 *f_inode;
	const struct file_operations___101 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___83 f_owner;
	const struct cred___96 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___100 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___98;

struct vm_operations_struct___98 {
	void (*open)(struct vm_area_struct___101 *);
	void (*close)(struct vm_area_struct___101 *);
	int (*split)(struct vm_area_struct___101 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___101 *);
	vm_fault_t (*fault)(struct vm_fault___98 *);
	vm_fault_t (*huge_fault)(struct vm_fault___98 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___98 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___101 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___98 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___98 *);
	int (*access)(struct vm_area_struct___101 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___101 *);
	int (*set_policy)(struct vm_area_struct___101 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___101 *, long unsigned int);
	struct page___101 * (*find_special_page)(struct vm_area_struct___101 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___100 {
	struct task_struct___101 *task;
	struct core_thread___100 *next;
};

struct core_state___100 {
	atomic_t nr_threads;
	struct core_thread___100 dumper;
	struct completion startup;
};

struct key___96;

struct ucounts___81;

struct user_namespace___81 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___81 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___7 ns;
	long unsigned int flags;
	struct key___96 *persistent_keyring_register;
	struct rw_semaphore___101 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___81 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___98 {
	struct vm_area_struct___101 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___101 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___101 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___100 prealloc_pte;
};

struct upid___83 {
	int nr;
	struct pid_namespace___83 *ns;
};

struct pid_namespace___83 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___101 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___83 *parent;
	struct vfsmount___16 *proc_mnt;
	struct dentry___101 *proc_self;
	struct dentry___101 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___81 *user_ns;
	struct ucounts___81 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___7 ns;
};

struct pid___83 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___83 numbers[1];
};

struct user_struct___96 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___96 *uid_keyring;
	struct key___96 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___96 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___96 *session_keyring;
	struct key___96 *process_keyring;
	struct key___96 *thread_keyring;
	struct key___96 *request_key_auth;
	void *security;
	struct user_struct___96 *user;
	struct user_namespace___81 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___77;

struct nsproxy___93 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___83 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___77 *cgroup_ns;
};

struct signal_struct___90 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___101 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___101 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___83 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___83 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___100 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___83 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___40;

struct bio_list___40 {
	struct bio___40 *head;
	struct bio___40 *tail;
};

struct bdi_writeback_congested___40;

struct cgroup_subsys_state___77;

struct bdi_writeback___40 {
	struct backing_dev_info___40 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___40 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___77 *memcg_css;
	struct cgroup_subsys_state___77 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___40 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___40 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___92 *dev;
	struct device___92 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___101 *debug_dir;
	struct dentry___101 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup___77;

struct css_set___77 {
	struct cgroup_subsys_state___77 *subsys[13];
	refcount_t refcount;
	struct css_set___77 *dom_cset;
	struct cgroup___77 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___77 *mg_src_cgrp;
	struct cgroup___77 *mg_dst_cgrp;
	struct css_set___77 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___59 {
	struct pmu___59 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___101 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___59 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___23;

struct pipe_inode_info___23 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___101 *tmp_page;
	struct fasync_struct___100 *fasync_readers;
	struct fasync_struct___100 *fasync_writers;
	struct pipe_buffer___23 *bufs;
	struct user_struct___96 *user;
};

struct vm_struct___72 {
	struct vm_struct___72 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___101 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___90 {
	struct task_struct___101 task;
	long unsigned int stack[8192];
};

struct kset___94;

struct kobj_type___94;

struct kernfs_node___97;

struct kobject___95 {
	const char *name;
	struct list_head entry;
	struct kobject___95 *parent;
	struct kset___94 *kset;
	struct kobj_type___94 *ktype;
	struct kernfs_node___97 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___92 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___92 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___92;

struct bus_type___92;

struct device_driver___92;

struct dev_pm_domain___92;

struct device_node___30;

struct fwnode_handle___66;

struct class___92;

struct attribute_group___91;

struct device___92 {
	struct device___92 *parent;
	struct device_private *p;
	struct kobject___95 kobj;
	const char *init_name;
	const struct device_type___92 *type;
	struct mutex mutex;
	struct bus_type___92 *bus;
	struct device_driver___92 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___92 power;
	struct dev_pm_domain___92 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___30 *of_node;
	struct fwnode_handle___66 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___92 *class;
	const struct attribute_group___91 **groups;
	void (*release)(struct device___92 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___100;

struct super_block___101;

struct dentry___101 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___101 *d_parent;
	struct qstr d_name;
	struct inode___102 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___100 *d_op;
	struct super_block___101 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___100;

struct block_device___101;

struct inode___102 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___100 *i_op;
	struct super_block___101 *i_sb;
	struct address_space___100 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___101 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___40 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___101 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___100 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___23 *i_pipe;
		struct block_device___101 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___100 {
	int (*d_revalidate)(struct dentry___101 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___101 *, unsigned int);
	int (*d_hash)(const struct dentry___101 *, struct qstr *);
	int (*d_compare)(const struct dentry___101 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___101 *);
	int (*d_init)(struct dentry___101 *);
	void (*d_release)(struct dentry___101 *);
	void (*d_prune)(struct dentry___101 *);
	void (*d_iput)(struct dentry___101 *, struct inode___102 *);
	char * (*d_dname)(struct dentry___101 *, char *, int);
	struct vfsmount___16 * (*d_automount)(struct path___100 *);
	int (*d_manage)(const struct path___100 *, bool);
	struct dentry___101 * (*d_real)(struct dentry___101 *, const struct inode___102 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___100;

struct mem_dqinfo___100 {
	struct quota_format_type___100 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___100;

struct quota_info___100 {
	unsigned int flags;
	struct rw_semaphore___101 dqio_sem;
	struct inode___102 *files[3];
	struct mem_dqinfo___100 info[3];
	const struct quota_format_ops___100 *ops[3];
};

struct rcuwait___100 {
	struct task_struct___101 *task;
};

struct percpu_rw_semaphore___100 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___101 rw_sem;
	struct rcuwait___100 writer;
	int readers_block;
};

struct sb_writers___100 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___100 rw_sem[3];
};

struct file_system_type___100;

struct super_operations___100;

struct dquot_operations___100;

struct quotactl_ops___100;

struct super_block___101 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___100 *s_type;
	const struct super_operations___100 *s_op;
	const struct dquot_operations___100 *dq_op;
	const struct quotactl_ops___100 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___101 *s_root;
	struct rw_semaphore___101 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___101 *s_bdev;
	struct backing_dev_info___40 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___100 s_dquot;
	struct sb_writers___100 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___100 *s_d_op;
	int cleancache_poolid;
	struct shrinker___36 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___81 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___16 {
	struct dentry___101 *mnt_root;
	struct super_block___101 *mnt_sb;
	int mnt_flags;
};

struct kiocb___101 {
	struct file___101 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___101 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___101 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___101 *ia_file;
};

struct dquot___100 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___101 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___100 {
	int qf_fmt_id;
	const struct quota_format_ops___100 *qf_ops;
	struct module___84 *qf_owner;
	struct quota_format_type___100 *qf_next;
};

struct quota_format_ops___100 {
	int (*check_quota_file)(struct super_block___101 *, int);
	int (*read_file_info)(struct super_block___101 *, int);
	int (*write_file_info)(struct super_block___101 *, int);
	int (*free_file_info)(struct super_block___101 *, int);
	int (*read_dqblk)(struct dquot___100 *);
	int (*commit_dqblk)(struct dquot___100 *);
	int (*release_dqblk)(struct dquot___100 *);
	int (*get_next_id)(struct super_block___101 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___100 {
	int (*write_dquot)(struct dquot___100 *);
	struct dquot___100 * (*alloc_dquot)(struct super_block___101 *, int);
	void (*destroy_dquot)(struct dquot___100 *);
	int (*acquire_dquot)(struct dquot___100 *);
	int (*release_dquot)(struct dquot___100 *);
	int (*mark_dirty)(struct dquot___100 *);
	int (*write_info)(struct super_block___101 *, int);
	qsize_t * (*get_reserved_space)(struct inode___102 *);
	int (*get_projid)(struct inode___102 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___102 *, qsize_t *);
	int (*get_next_id)(struct super_block___101 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___100 {
	int (*quota_on)(struct super_block___101 *, int, int, const struct path___100 *);
	int (*quota_off)(struct super_block___101 *, int);
	int (*quota_enable)(struct super_block___101 *, unsigned int);
	int (*quota_disable)(struct super_block___101 *, unsigned int);
	int (*quota_sync)(struct super_block___101 *, int);
	int (*set_info)(struct super_block___101 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___101 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___101 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___101 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___101 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___101 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___81 {
	struct kobject___95 kobj;
	struct module___84 *mod;
	struct kobject___95 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___81 {
	struct module___84 *mod;
	struct latch_tree_node node;
};

struct module_layout___81 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___81 mtn;
};

struct module_attribute___81;

struct kernel_param___81;

struct module___84 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___81 mkobj;
	struct module_attribute___81 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___95 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___81 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___81 core_layout;
	struct module_layout___81 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___54 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___38;

struct address_space_operations___100 {
	int (*writepage)(struct page___101 *, struct writeback_control___38 *);
	int (*readpage)(struct file___101 *, struct page___101 *);
	int (*writepages)(struct address_space___100 *, struct writeback_control___38 *);
	int (*set_page_dirty)(struct page___101 *);
	int (*readpages)(struct file___101 *, struct address_space___100 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___101 *, struct address_space___100 *, loff_t, unsigned int, unsigned int, struct page___101 **, void **);
	int (*write_end)(struct file___101 *, struct address_space___100 *, loff_t, unsigned int, unsigned int, struct page___101 *, void *);
	sector_t (*bmap)(struct address_space___100 *, sector_t);
	void (*invalidatepage)(struct page___101 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___101 *, gfp_t);
	void (*freepage)(struct page___101 *);
	ssize_t (*direct_IO)(struct kiocb___101 *, struct iov_iter___41 *);
	int (*migratepage)(struct address_space___100 *, struct page___101 *, struct page___101 *, enum migrate_mode);
	bool (*isolate_page)(struct page___101 *, isolate_mode_t);
	void (*putback_page)(struct page___101 *);
	int (*launder_page)(struct page___101 *);
	int (*is_partially_uptodate)(struct page___101 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___101 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___100 *, struct page___101 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___101 *, sector_t *);
	void (*swap_deactivate)(struct file___101 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___38 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___40 *wb;
	struct inode___102 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___40;

struct iov_iter___41 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___40 *bvec;
		struct pipe_inode_info___23 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___101 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___102 *bd_inode;
	struct super_block___101 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___101 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___40 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___100 {
	struct dentry___101 * (*lookup)(struct inode___102 *, struct dentry___101 *, unsigned int);
	const char * (*get_link)(struct dentry___101 *, struct inode___102 *, struct delayed_call *);
	int (*permission)(struct inode___102 *, int);
	struct posix_acl * (*get_acl)(struct inode___102 *, int);
	int (*readlink)(struct dentry___101 *, char *, int);
	int (*create)(struct inode___102 *, struct dentry___101 *, umode_t, bool);
	int (*link)(struct dentry___101 *, struct inode___102 *, struct dentry___101 *);
	int (*unlink)(struct inode___102 *, struct dentry___101 *);
	int (*symlink)(struct inode___102 *, struct dentry___101 *, const char *);
	int (*mkdir)(struct inode___102 *, struct dentry___101 *, umode_t);
	int (*rmdir)(struct inode___102 *, struct dentry___101 *);
	int (*mknod)(struct inode___102 *, struct dentry___101 *, umode_t, dev_t);
	int (*rename)(struct inode___102 *, struct dentry___101 *, struct inode___102 *, struct dentry___101 *, unsigned int);
	int (*setattr)(struct dentry___101 *, struct iattr___101 *);
	int (*getattr)(const struct path___100 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___101 *, char *, size_t);
	int (*fiemap)(struct inode___102 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___102 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___102 *, struct dentry___101 *, struct file___101 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___102 *, struct dentry___101 *, umode_t);
	int (*set_acl)(struct inode___102 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___100 {
	void (*fl_copy_lock)(struct file_lock___101 *, struct file_lock___101 *);
	void (*fl_release_private)(struct file_lock___101 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___100;

struct file_lock___101 {
	struct file_lock___101 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___101 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___100 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___100 *fl_ops;
	const struct lock_manager_operations___100 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___100 {
	int (*lm_compare_owner)(struct file_lock___101 *, struct file_lock___101 *);
	long unsigned int (*lm_owner_key)(struct file_lock___101 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___101 *);
	int (*lm_grant)(struct file_lock___101 *, int);
	bool (*lm_break)(struct file_lock___101 *);
	int (*lm_change)(struct file_lock___101 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___101 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___100 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___100 *fa_next;
	struct file___101 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___100 {
	const char *name;
	int fs_flags;
	struct dentry___101 * (*mount)(struct file_system_type___100 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___101 *);
	struct module___84 *owner;
	struct file_system_type___100 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___100 {
	struct inode___102 * (*alloc_inode)(struct super_block___101 *);
	void (*destroy_inode)(struct inode___102 *);
	void (*dirty_inode)(struct inode___102 *, int);
	int (*write_inode)(struct inode___102 *, struct writeback_control___38 *);
	int (*drop_inode)(struct inode___102 *);
	void (*evict_inode)(struct inode___102 *);
	void (*put_super)(struct super_block___101 *);
	int (*sync_fs)(struct super_block___101 *, int);
	int (*freeze_super)(struct super_block___101 *);
	int (*freeze_fs)(struct super_block___101 *);
	int (*thaw_super)(struct super_block___101 *);
	int (*unfreeze_fs)(struct super_block___101 *);
	int (*statfs)(struct dentry___101 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___101 *, int *, char *);
	void (*umount_begin)(struct super_block___101 *);
	int (*show_options)(struct seq_file___91 *, struct dentry___101 *);
	int (*show_devname)(struct seq_file___91 *, struct dentry___101 *);
	int (*show_path)(struct seq_file___91 *, struct dentry___101 *);
	int (*show_stats)(struct seq_file___91 *, struct dentry___101 *);
	ssize_t (*quota_read)(struct super_block___101 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___101 *, int, const char *, size_t, loff_t);
	struct dquot___100 ** (*get_dquots)(struct inode___102 *);
	int (*bdev_try_to_free_page)(struct super_block___101 *, struct page___101 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___101 *, struct shrink_control___36 *);
	long int (*free_cached_objects)(struct super_block___101 *, struct shrink_control___36 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___63)(struct file___101 *, wait_queue_head_t *, struct poll_table_struct___64 *);

struct poll_table_struct___64 {
	poll_queue_proc___63 _qproc;
	__poll_t _key;
};

struct seq_operations___89;

struct seq_file___91 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___89 *op;
	int poll_event;
	const struct file___101 *file;
	void *private;
};

typedef void bio_end_io_t___40(struct bio___40 *);

struct bio_vec___40 {
	struct page___101 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___40;

struct bio_set___40;

struct bio___40 {
	struct bio___40 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___40 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___40 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___40 *bi_io_vec;
	struct bio_set___40 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___40 bi_inline_vecs[0];
};

struct kobj_attribute___95 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___95 *, struct kobj_attribute___95 *, char *);
	ssize_t (*store)(struct kobject___95 *, struct kobj_attribute___95 *, const char *, size_t);
};

typedef void compound_page_dtor___98(struct page___101 *);

typedef int (*key_restrict_link_func_t___96)(struct key___96 *, const struct key_type *, const union key_payload *, struct key___96 *);

struct key_restriction___96;

struct key___96 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___101 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___96 *restrict_link;
};

struct key_restriction___96 {
	key_restrict_link_func_t___96 check;
	struct key___96 *key;
	struct key_type *keytype;
};

struct seq_operations___89 {
	void * (*start)(struct seq_file___91 *, loff_t *);
	void (*stop)(struct seq_file___91 *, void *);
	void * (*next)(struct seq_file___91 *, void *, loff_t *);
	int (*show)(struct seq_file___91 *, void *);
};

typedef struct poll_table_struct___64 poll_table___8;

struct bdi_writeback_congested___40 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___40 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct cgroup_subsys___77;

struct cgroup_subsys_state___77 {
	struct cgroup___77 *cgroup;
	struct cgroup_subsys___77 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___77 *parent;
};

struct bio_integrity_payload___40 {
	struct bio___40 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___40 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___40 bip_inline_vecs[0];
};

struct bio_set___40 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___40 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_root___97;

struct kernfs_elem_dir___97 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___97 *root;
};

struct kernfs_syscall_ops___97;

struct kernfs_root___97 {
	struct kernfs_node___97 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___97 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___97 {
	struct kernfs_node___97 *target_kn;
};

struct kernfs_ops___97;

struct kernfs_elem_attr___97 {
	const struct kernfs_ops___97 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___97 *notify_next;
};

struct kernfs_node___97 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___97 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___97 dir;
		struct kernfs_elem_symlink___97 symlink;
		struct kernfs_elem_attr___97 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___97;

struct kernfs_ops___97 {
	int (*open)(struct kernfs_open_file___97 *);
	void (*release)(struct kernfs_open_file___97 *);
	int (*seq_show)(struct seq_file___91 *, void *);
	void * (*seq_start)(struct seq_file___91 *, loff_t *);
	void * (*seq_next)(struct seq_file___91 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___91 *, void *);
	ssize_t (*read)(struct kernfs_open_file___97 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___97 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___97 *, struct vm_area_struct___101 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___97 *, struct poll_table_struct___64 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___97 {
	int (*remount_fs)(struct kernfs_root___97 *, int *, char *);
	int (*show_options)(struct seq_file___91 *, struct kernfs_root___97 *);
	int (*mkdir)(struct kernfs_node___97 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___97 *);
	int (*rename)(struct kernfs_node___97 *, struct kernfs_node___97 *, const char *);
	int (*show_path)(struct seq_file___91 *, struct kernfs_node___97 *, struct kernfs_root___97 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___97 {
	struct kernfs_node___97 *kn;
	struct file___101 *file;
	struct seq_file___91 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___98 *vm_ops;
};

struct cgroup_namespace___77 {
	refcount_t count;
	struct ns_common___7 ns;
	struct user_namespace___81 *user_ns;
	struct ucounts___81 *ucounts;
	struct css_set___77 *root_cset;
};

struct ucounts___81 {
	struct hlist_node node;
	struct user_namespace___81 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___77;

struct bpf_map_ops___77 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___77 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___77 *, struct file___101 *);
	void (*map_free)(struct bpf_map___77 *);
	int (*map_get_next_key)(struct bpf_map___77 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___77 *);
	void * (*map_lookup_elem)(struct bpf_map___77 *, void *);
	int (*map_update_elem)(struct bpf_map___77 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___77 *, void *);
	int (*map_push_elem)(struct bpf_map___77 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___77 *, void *);
	int (*map_peek_elem)(struct bpf_map___77 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___77 *, struct file___101 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___77 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___77 *, void *, struct seq_file___91 *);
	int (*map_check_btf)(const struct bpf_map___77 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___77 {
	const struct bpf_map_ops___77 *ops;
	struct bpf_map___77 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___96 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___77;

typedef void (*kthread_work_func_t___77)(struct kthread_work___77 *);

struct kthread_worker___77;

struct kthread_work___77 {
	struct list_head node;
	kthread_work_func_t___77 func;
	struct kthread_worker___77 *worker;
	int canceling;
};

struct kthread_worker___77 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___101 *task;
	struct kthread_work___77 *current_work;
};

struct kthread_delayed_work___77 {
	struct kthread_work___77 work;
	struct timer_list timer;
};

struct psi_group___77 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___77 *poll_kworker;
	struct kthread_delayed_work___77 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___77 {
	struct kernfs_node___97 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_root___77;

struct cgroup_rstat_cpu___77;

struct cgroup___77 {
	struct cgroup_subsys_state___77 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___97 *kn;
	struct cgroup_file___77 procs_file;
	struct cgroup_file___77 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___77 *subsys[13];
	struct cgroup_root___77 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___77 *dom_cgrp;
	struct cgroup_rstat_cpu___77 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___9 bpf;
	atomic_t congestion_count;
	struct cgroup___77 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___77 psi;
	int ancestor_ids[0];
};

struct cftype___77;

struct cgroup_subsys___77 {
	struct cgroup_subsys_state___77 * (*css_alloc)(struct cgroup_subsys_state___77 *);
	int (*css_online)(struct cgroup_subsys_state___77 *);
	void (*css_offline)(struct cgroup_subsys_state___77 *);
	void (*css_released)(struct cgroup_subsys_state___77 *);
	void (*css_free)(struct cgroup_subsys_state___77 *);
	void (*css_reset)(struct cgroup_subsys_state___77 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___77 *, int);
	int (*css_extra_stat_show)(struct seq_file___91 *, struct cgroup_subsys_state___77 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___101 *);
	void (*cancel_fork)(struct task_struct___101 *);
	void (*fork)(struct task_struct___101 *);
	void (*exit)(struct task_struct___101 *);
	void (*free)(struct task_struct___101 *);
	void (*bind)(struct cgroup_subsys_state___77 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___77 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___77 *dfl_cftypes;
	struct cftype___77 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___77 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___77 *updated_children;
	struct cgroup___77 *updated_next;
};

struct cgroup_root___77 {
	struct kernfs_root___97 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___77 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___77 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___77 *ss;
	struct list_head node;
	struct kernfs_ops___97 *kf_ops;
	int (*open)(struct kernfs_open_file___97 *);
	void (*release)(struct kernfs_open_file___97 *);
	u64 (*read_u64)(struct cgroup_subsys_state___77 *, struct cftype___77 *);
	s64 (*read_s64)(struct cgroup_subsys_state___77 *, struct cftype___77 *);
	int (*seq_show)(struct seq_file___91 *, void *);
	void * (*seq_start)(struct seq_file___91 *, loff_t *);
	void * (*seq_next)(struct seq_file___91 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___91 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___77 *, struct cftype___77 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___77 *, struct cftype___77 *, s64);
	ssize_t (*write)(struct kernfs_open_file___97 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___97 *, struct poll_table_struct___64 *);
};

struct bin_attribute___91;

struct attribute_group___91 {
	const char *name;
	umode_t (*is_visible)(struct kobject___95 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___95 *, struct bin_attribute___91 *, int);
	struct attribute **attrs;
	struct bin_attribute___91 **bin_attrs;
};

struct bin_attribute___91 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___101 *, struct kobject___95 *, struct bin_attribute___91 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___101 *, struct kobject___95 *, struct bin_attribute___91 *, char *, loff_t, size_t);
	int (*mmap)(struct file___101 *, struct kobject___95 *, struct bin_attribute___91 *, struct vm_area_struct___101 *);
};

struct sysfs_ops___94 {
	ssize_t (*show)(struct kobject___95 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___95 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___94;

struct kset___94 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___95 kobj;
	const struct kset_uevent_ops___94 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___94 {
	void (*release)(struct kobject___95 *);
	const struct sysfs_ops___94 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___5 * (*child_ns_type)(struct kobject___95 *);
	const void * (*namespace)(struct kobject___95 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___94 {
	int (* const filter)(struct kset___94 *, struct kobject___95 *);
	const char * (* const name)(struct kset___94 *, struct kobject___95 *);
	int (* const uevent)(struct kset___94 *, struct kobject___95 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___81 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___81 *);
	int (*get)(char *, const struct kernel_param___81 *);
	void (*free)(void *);
};

struct kparam_array___81;

struct kernel_param___81 {
	const char *name;
	struct module___84 *mod;
	const struct kernel_param_ops___81 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___81 *arr;
	};
};

struct kparam_array___81 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___81 *ops;
	void *elem;
};

struct module_attribute___81 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___81 *, struct module_kobject___81 *, char *);
	ssize_t (*store)(struct module_attribute___81 *, struct module_kobject___81 *, const char *, size_t);
	void (*setup)(struct module___84 *, const char *);
	int (*test)(struct module___84 *);
	void (*free)(struct module___84 *);
};

struct trace_event_functions___2;

struct trace_event___2 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___2 *funcs;
};

struct trace_event_class___54;

struct trace_event_call___54 {
	struct list_head list;
	struct trace_event_class___54 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___2 event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___9 *prog_array;
	int (*perf_perm)(struct trace_event_call___54 *, struct perf_event___59 *);
};

struct pipe_buf_operations___23;

struct pipe_buffer___23 {
	struct page___101 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___23 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___23 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___23 *, struct pipe_buffer___23 *);
	void (*release)(struct pipe_inode_info___23 *, struct pipe_buffer___23 *);
	int (*steal)(struct pipe_inode_info___23 *, struct pipe_buffer___23 *);
	union {
		bool (*get)(struct pipe_inode_info___23 *, struct pipe_buffer___23 *);
		struct {
			void (*get)(struct pipe_inode_info___23 *, struct pipe_buffer___23 *);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
};

struct splice_pipe_desc___2 {
	struct page___101 **pages;
	struct partial_page *partial;
	int nr_pages;
	unsigned int nr_pages_max;
	const struct pipe_buf_operations___23 *ops;
	void (*spd_release)(struct splice_pipe_desc___2 *, unsigned int);
};

struct trace_export {
	struct trace_export *next;
	void (*write)(struct trace_export *, const void *, unsigned int);
};

struct fwnode_operations___66;

struct fwnode_handle___66 {
	struct fwnode_handle___66 *secondary;
	const struct fwnode_operations___66 *ops;
};

struct fwnode_reference_args___66;

struct fwnode_endpoint___66;

struct fwnode_operations___66 {
	struct fwnode_handle___66 * (*get)(struct fwnode_handle___66 *);
	void (*put)(struct fwnode_handle___66 *);
	bool (*device_is_available)(const struct fwnode_handle___66 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___66 *, const struct device___92 *);
	bool (*property_present)(const struct fwnode_handle___66 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___66 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___66 *, const char *, const char **, size_t);
	struct fwnode_handle___66 * (*get_parent)(const struct fwnode_handle___66 *);
	struct fwnode_handle___66 * (*get_next_child_node)(const struct fwnode_handle___66 *, struct fwnode_handle___66 *);
	struct fwnode_handle___66 * (*get_named_child_node)(const struct fwnode_handle___66 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___66 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___66 *);
	struct fwnode_handle___66 * (*graph_get_next_endpoint)(const struct fwnode_handle___66 *, struct fwnode_handle___66 *);
	struct fwnode_handle___66 * (*graph_get_remote_endpoint)(const struct fwnode_handle___66 *);
	struct fwnode_handle___66 * (*graph_get_port_parent)(struct fwnode_handle___66 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___66 *, struct fwnode_endpoint___66 *);
};

struct fwnode_endpoint___66 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___66 *local_fwnode;
};

struct fwnode_reference_args___66 {
	struct fwnode_handle___66 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct property___29 {
	char *name;
	int length;
	void *value;
	struct property___29 *next;
	long unsigned int _flags;
	struct bin_attribute___91 attr;
};

struct device_node___30 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___66 fwnode;
	struct property___29 *properties;
	struct property___29 *deadprops;
	struct device_node___30 *parent;
	struct device_node___30 *child;
	struct device_node___30 *sibling;
	struct kobject___95 kobj;
	long unsigned int _flags;
	void *data;
};

struct dev_pm_ops___92 {
	int (*prepare)(struct device___92 *);
	void (*complete)(struct device___92 *);
	int (*suspend)(struct device___92 *);
	int (*resume)(struct device___92 *);
	int (*freeze)(struct device___92 *);
	int (*thaw)(struct device___92 *);
	int (*poweroff)(struct device___92 *);
	int (*restore)(struct device___92 *);
	int (*suspend_late)(struct device___92 *);
	int (*resume_early)(struct device___92 *);
	int (*freeze_late)(struct device___92 *);
	int (*thaw_early)(struct device___92 *);
	int (*poweroff_late)(struct device___92 *);
	int (*restore_early)(struct device___92 *);
	int (*suspend_noirq)(struct device___92 *);
	int (*resume_noirq)(struct device___92 *);
	int (*freeze_noirq)(struct device___92 *);
	int (*thaw_noirq)(struct device___92 *);
	int (*poweroff_noirq)(struct device___92 *);
	int (*restore_noirq)(struct device___92 *);
	int (*runtime_suspend)(struct device___92 *);
	int (*runtime_resume)(struct device___92 *);
	int (*runtime_idle)(struct device___92 *);
};

struct dev_pm_domain___92 {
	struct dev_pm_ops___92 ops;
	void (*detach)(struct device___92 *, bool);
	int (*activate)(struct device___92 *);
	void (*sync)(struct device___92 *);
	void (*dismiss)(struct device___92 *);
};

struct bus_type___92 {
	const char *name;
	const char *dev_name;
	struct device___92 *dev_root;
	const struct attribute_group___91 **bus_groups;
	const struct attribute_group___91 **dev_groups;
	const struct attribute_group___91 **drv_groups;
	int (*match)(struct device___92 *, struct device_driver___92 *);
	int (*uevent)(struct device___92 *, struct kobj_uevent_env *);
	int (*probe)(struct device___92 *);
	int (*remove)(struct device___92 *);
	void (*shutdown)(struct device___92 *);
	int (*online)(struct device___92 *);
	int (*offline)(struct device___92 *);
	int (*suspend)(struct device___92 *, pm_message_t);
	int (*resume)(struct device___92 *);
	int (*num_vf)(struct device___92 *);
	int (*dma_configure)(struct device___92 *);
	const struct dev_pm_ops___92 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___92 {
	const char *name;
	struct bus_type___92 *bus;
	struct module___84 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___92 *);
	int (*remove)(struct device___92 *);
	void (*shutdown)(struct device___92 *);
	int (*suspend)(struct device___92 *, pm_message_t);
	int (*resume)(struct device___92 *);
	const struct attribute_group___91 **groups;
	const struct dev_pm_ops___92 *pm;
	void (*coredump)(struct device___92 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___92 {
	const char *name;
	const struct attribute_group___91 **groups;
	int (*uevent)(struct device___92 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___92 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___92 *);
	const struct dev_pm_ops___92 *pm;
};

struct class___92 {
	const char *name;
	struct module___84 *owner;
	const struct attribute_group___91 **class_groups;
	const struct attribute_group___91 **dev_groups;
	struct kobject___95 *dev_kobj;
	int (*dev_uevent)(struct device___92 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___92 *, umode_t *);
	void (*class_release)(struct class___92 *);
	void (*dev_release)(struct device___92 *);
	int (*shutdown_pre)(struct device___92 *);
	const struct kobj_ns_type_operations___5 *ns_type;
	const void * (*namespace)(struct device___92 *);
	const struct dev_pm_ops___92 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___78 {
	struct device___92 dev;
};

struct perf_cpu_context___59;

struct pmu___59 {
	struct list_head entry;
	struct module___84 *module;
	struct device___92 *dev;
	const struct attribute_group___91 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___59 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___59 *);
	void (*pmu_disable)(struct pmu___59 *);
	int (*event_init)(struct perf_event___59 *);
	void (*event_mapped)(struct perf_event___59 *, struct mm_struct___100 *);
	void (*event_unmapped)(struct perf_event___59 *, struct mm_struct___100 *);
	int (*add)(struct perf_event___59 *, int);
	void (*del)(struct perf_event___59 *, int);
	void (*start)(struct perf_event___59 *, int);
	void (*stop)(struct perf_event___59 *, int);
	void (*read)(struct perf_event___59 *);
	void (*start_txn)(struct pmu___59 *, unsigned int);
	int (*commit_txn)(struct pmu___59 *);
	void (*cancel_txn)(struct pmu___59 *);
	int (*event_idx)(struct perf_event___59 *);
	void (*sched_task)(struct perf_event_context___59 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___59 *);
	int (*filter_match)(struct perf_event___59 *);
	int (*check_period)(struct perf_event___59 *, u64);
};

struct perf_cpu_context___59 {
	struct perf_event_context___59 ctx;
	struct perf_event_context___59 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___59 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___59 {
	struct cgroup_subsys_state___77 css;
	struct perf_cgroup_info *info;
};

struct trace_array___2;

struct tracer___2;

struct trace_buffer___2;

struct trace_iterator___2 {
	struct trace_array___2 *tr;
	struct tracer___2 *trace;
	struct trace_buffer___2 *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

struct trace_buffer___2 {
	struct trace_array___2 *tr;
	struct ring_buffer *buffer;
	struct trace_array_cpu *data;
	u64 time_start;
	int cpu;
};

struct trace_event_file___19;

struct trace_options___2;

struct trace_array___2 {
	struct list_head list;
	char *name;
	struct trace_buffer___2 trace_buffer;
	struct trace_buffer___2 max_buffer;
	bool allocated_snapshot;
	long unsigned int max_latency;
	struct trace_pid_list *filtered_pids;
	arch_spinlock_t max_lock;
	int buffer_disabled;
	int sys_refcount_enter;
	int sys_refcount_exit;
	struct trace_event_file___19 *enter_syscall_files[295];
	struct trace_event_file___19 *exit_syscall_files[295];
	int stop_count;
	int clock_id;
	int nr_topts;
	bool clear_trace;
	struct tracer___2 *current_trace;
	unsigned int trace_flags;
	unsigned char trace_flags_index[32];
	unsigned int flags;
	raw_spinlock_t start_lock;
	struct dentry___101 *dir;
	struct dentry___101 *options;
	struct dentry___101 *percpu_dir;
	struct dentry___101 *event_dir;
	struct trace_options___2 *topts;
	struct list_head systems;
	struct list_head events;
	struct trace_event_file___19 *trace_marker_file;
	cpumask_var_t tracing_cpumask;
	int ref;
	struct ftrace_ops *ops;
	struct trace_pid_list *function_pids;
	struct list_head func_probes;
	struct list_head mod_trace;
	struct list_head mod_notrace;
	int function_enabled;
	int time_stamp_abs_ref;
	struct list_head hist_vars;
};

struct tracer_flags___2;

struct tracer___2 {
	const char *name;
	int (*init)(struct trace_array___2 *);
	void (*reset)(struct trace_array___2 *);
	void (*start)(struct trace_array___2 *);
	void (*stop)(struct trace_array___2 *);
	int (*update_thresh)(struct trace_array___2 *);
	void (*open)(struct trace_iterator___2 *);
	void (*pipe_open)(struct trace_iterator___2 *);
	void (*close)(struct trace_iterator___2 *);
	void (*pipe_close)(struct trace_iterator___2 *);
	ssize_t (*read)(struct trace_iterator___2 *, struct file___101 *, char *, size_t, loff_t *);
	ssize_t (*splice_read)(struct trace_iterator___2 *, struct file___101 *, loff_t *, struct pipe_inode_info___23 *, size_t, unsigned int);
	void (*print_header)(struct seq_file___91 *);
	enum print_line_t (*print_line)(struct trace_iterator___2 *);
	int (*set_flag)(struct trace_array___2 *, u32, u32, int);
	int (*flag_changed)(struct trace_array___2 *, u32, int);
	struct tracer___2 *next;
	struct tracer_flags___2 *flags;
	int enabled;
	int ref;
	bool print_max;
	bool allow_instances;
	bool use_max_tr;
	bool noboot;
};

enum trace_iter_flags {
	TRACE_FILE_LAT_FMT = 1,
	TRACE_FILE_ANNOTATE = 2,
	TRACE_FILE_TIME_IN_NS = 4,
};

typedef enum print_line_t (*trace_print_func___2)(struct trace_iterator___2 *, int, struct trace_event___2 *);

struct trace_event_functions___2 {
	trace_print_func___2 trace;
	trace_print_func___2 raw;
	trace_print_func___2 hex;
	trace_print_func___2 binary;
};

struct trace_event_class___54 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___54 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___54 *);
	struct list_head * (*get_fields)(struct trace_event_call___54 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___54 *);
};

struct trace_event_buffer___18 {
	struct ring_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___19 *trace_file;
	void *entry;
	long unsigned int flags;
	int pc;
};

struct trace_subsystem_dir___3;

struct trace_event_file___19 {
	struct list_head list;
	struct trace_event_call___54 *event_call;
	struct event_filter *filter;
	struct dentry___101 *dir;
	struct trace_array___2 *tr;
	struct trace_subsystem_dir___3 *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_subsystem_dir___3 {
	struct list_head list;
	struct event_subsystem *subsystem;
	struct trace_array___2 *tr;
	struct dentry___101 *entry;
	int ref_count;
	int nr_events;
};

enum event_trigger_type {
	ETT_NONE = 0,
	ETT_TRACE_ONOFF = 1,
	ETT_SNAPSHOT = 2,
	ETT_STACKTRACE = 4,
	ETT_EVENT_ENABLE = 8,
	ETT_EVENT_HIST = 16,
	ETT_HIST_ENABLE = 32,
};

enum trace_type {
	__TRACE_FIRST_TYPE = 0,
	TRACE_FN = 1,
	TRACE_CTX = 2,
	TRACE_WAKE = 3,
	TRACE_STACK = 4,
	TRACE_PRINT = 5,
	TRACE_BPRINT = 6,
	TRACE_MMIO_RW = 7,
	TRACE_MMIO_MAP = 8,
	TRACE_BRANCH = 9,
	TRACE_GRAPH_RET = 10,
	TRACE_GRAPH_ENT = 11,
	TRACE_USER_STACK = 12,
	TRACE_BLK = 13,
	TRACE_BPUTS = 14,
	TRACE_HWLAT = 15,
	TRACE_RAW_DATA = 16,
	__TRACE_LAST_TYPE = 17,
};

struct ftrace_entry {
	struct trace_entry ent;
	long unsigned int ip;
	long unsigned int parent_ip;
};

struct stack_entry {
	struct trace_entry ent;
	int size;
	long unsigned int caller[0];
};

struct userstack_entry {
	struct trace_entry ent;
	unsigned int tgid;
	long unsigned int caller[8];
};

struct bprint_entry {
	struct trace_entry ent;
	long unsigned int ip;
	const char *fmt;
	u32 buf[0];
};

struct print_entry {
	struct trace_entry ent;
	long unsigned int ip;
	char buf[0];
};

struct raw_data_entry {
	struct trace_entry ent;
	unsigned int id;
	char buf[0];
};

struct bputs_entry {
	struct trace_entry ent;
	long unsigned int ip;
	const char *str;
};

enum trace_flag_type {
	TRACE_FLAG_IRQS_OFF = 1,
	TRACE_FLAG_IRQS_NOSUPPORT = 2,
	TRACE_FLAG_NEED_RESCHED = 4,
	TRACE_FLAG_HARDIRQ = 8,
	TRACE_FLAG_SOFTIRQ = 16,
	TRACE_FLAG_PREEMPT_RESCHED = 32,
	TRACE_FLAG_NMI = 64,
};

struct trace_option_dentry___2;

struct trace_options___2 {
	struct tracer___2 *tracer;
	struct trace_option_dentry___2 *topts;
};

struct trace_option_dentry___2 {
	struct tracer_opt *opt;
	struct tracer_flags___2 *flags;
	struct trace_array___2 *tr;
	struct dentry___101 *entry;
};

struct tracer_flags___2 {
	u32 val;
	struct tracer_opt *opts;
	struct tracer___2 *trace;
};

struct ftrace_func_command___2 {
	struct list_head list;
	char *name;
	int (*func)(struct trace_array___2 *, struct ftrace_hash *, char *, char *, char *, int);
};

struct ftrace_probe_ops___2 {
	void (*func)(long unsigned int, long unsigned int, struct trace_array___2 *, struct ftrace_probe_ops___2 *, void *);
	int (*init)(struct ftrace_probe_ops___2 *, struct trace_array___2 *, long unsigned int, void *, void **);
	void (*free)(struct ftrace_probe_ops___2 *, struct trace_array___2 *, long unsigned int, void *);
	int (*print)(struct seq_file___91 *, long unsigned int, struct ftrace_probe_ops___2 *, void *);
};

enum trace_iterator_flags {
	TRACE_ITER_PRINT_PARENT = 1,
	TRACE_ITER_SYM_OFFSET = 2,
	TRACE_ITER_SYM_ADDR = 4,
	TRACE_ITER_VERBOSE = 8,
	TRACE_ITER_RAW = 16,
	TRACE_ITER_HEX = 32,
	TRACE_ITER_BIN = 64,
	TRACE_ITER_BLOCK = 128,
	TRACE_ITER_PRINTK = 256,
	TRACE_ITER_ANNOTATE = 512,
	TRACE_ITER_USERSTACKTRACE = 1024,
	TRACE_ITER_SYM_USEROBJ = 2048,
	TRACE_ITER_PRINTK_MSGONLY = 4096,
	TRACE_ITER_CONTEXT_INFO = 8192,
	TRACE_ITER_LATENCY_FMT = 16384,
	TRACE_ITER_RECORD_CMD = 32768,
	TRACE_ITER_RECORD_TGID = 65536,
	TRACE_ITER_OVERWRITE = 131072,
	TRACE_ITER_STOP_ON_FREE = 262144,
	TRACE_ITER_IRQ_INFO = 524288,
	TRACE_ITER_MARKERS = 1048576,
	TRACE_ITER_EVENT_FORK = 2097152,
	TRACE_ITER_FUNCTION = 4194304,
	TRACE_ITER_FUNC_FORK = 8388608,
	TRACE_ITER_DISPLAY_GRAPH = 16777216,
	TRACE_ITER_STACKTRACE = 33554432,
};

struct saved_cmdlines_buffer {
	unsigned int map_pid_to_cmdline[32769];
	unsigned int *map_cmdline_to_pid;
	unsigned int cmdline_num;
	int cmdline_idx;
	char *saved_cmdlines;
};

struct ftrace_stack {
	long unsigned int calls[8192];
};

struct trace_buffer_struct {
	int nesting;
	char buffer[4096];
};

struct ftrace_buffer_info {
	struct trace_iterator___2 iter;
	void *spare;
	unsigned int spare_cpu;
	unsigned int read;
};

struct buffer_ref {
	struct ring_buffer *buffer;
	void *page;
	int cpu;
	int ref;
};

struct ftrace_func_mapper___2;

struct module___85;

struct file___102;

struct kiocb___102;

struct poll_table_struct___65;

struct vm_area_struct___102;

struct inode___103;

struct file_lock___102;

struct page___102;

struct seq_file___92;

struct file_operations___102 {
	struct module___85 *owner;
	loff_t (*llseek)(struct file___102 *, loff_t, int);
	ssize_t (*read)(struct file___102 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___102 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___102 *, struct iov_iter___41 *);
	ssize_t (*write_iter)(struct kiocb___102 *, struct iov_iter___41 *);
	int (*iopoll)(struct kiocb___102 *, bool);
	int (*iterate)(struct file___102 *, struct dir_context *);
	int (*iterate_shared)(struct file___102 *, struct dir_context *);
	__poll_t (*poll)(struct file___102 *, struct poll_table_struct___65 *);
	long int (*unlocked_ioctl)(struct file___102 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___102 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___102 *, struct vm_area_struct___102 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___103 *, struct file___102 *);
	int (*flush)(struct file___102 *, fl_owner_t);
	int (*release)(struct inode___103 *, struct file___102 *);
	int (*fsync)(struct file___102 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___102 *, int);
	int (*lock)(struct file___102 *, int, struct file_lock___102 *);
	ssize_t (*sendpage)(struct file___102 *, struct page___102 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___102 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___102 *, int, struct file_lock___102 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___102 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___102 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___102 *, long int, struct file_lock___102 **, void **);
	long int (*fallocate)(struct file___102 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___92 *, struct file___102 *);
	ssize_t (*copy_file_range)(struct file___102 *, loff_t, struct file___102 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___102 *, loff_t, struct file___102 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___102 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___101 {
	u64 seqnum;
	struct vm_area_struct___102 *vmas[4];
};

struct page_frag___101 {
	struct page___102 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___60;

struct debug_info___60 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___60 *hbp_break[16];
	struct perf_event___60 *hbp_watch[16];
};

struct thread_struct___60 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___60 debug;
	long: 64;
};

struct mm_struct___101;

struct pid___84;

struct cred___97;

struct nsproxy___94;

struct signal_struct___91;

struct css_set___78;

struct perf_event_context___60;

struct vm_struct___73;

struct task_struct___102 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___102 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___101 *mm;
	struct mm_struct___101 *active_mm;
	struct vmacache___101 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___102 *real_parent;
	struct task_struct___102 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___102 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___84 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___84 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___84 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___97 *ptracer_cred;
	const struct cred___97 *real_cred;
	const struct cred___97 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___94 *nsproxy;
	struct signal_struct___91 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___102 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___16 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___78 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___60 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___101 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___102 *oom_reaper_list;
	struct vm_struct___73 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___60 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___60 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___102 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___60)(struct perf_event___60 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___60;

struct fasync_struct___101;

struct pid_namespace___84;

struct trace_event_call___55;

struct perf_cgroup___60;

struct perf_event___60 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___60 *group_leader;
	struct pmu___60 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___60 hw;
	struct perf_event_context___60 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___60 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___102 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___101 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___60 *);
	struct callback_head callback_head;
	struct pid_namespace___84 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___60 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___60 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___55 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___60 *cgrp;
	struct list_head sb_list;
};

struct rw_semaphore___102 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___102 *owner;
};

struct key___97;

struct ucounts___82;

struct user_namespace___82 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___82 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___7 ns;
	long unsigned int flags;
	struct key___97 *persistent_keyring_register;
	struct rw_semaphore___102 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___82 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___102 *pgtable_t___101;

struct address_space___101;

struct dev_pagemap___99;

struct page___102 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___101 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___102 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___101 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___101 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___99 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___101;

struct lruvec___101 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___101 *pgdat;
};

struct zone___101 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___101 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___101 {
	struct zone___101 *zone;
	int zone_idx;
};

struct zonelist___101 {
	struct zoneref___101 _zonerefs[25];
};

struct pglist_data___101 {
	struct zone___101 node_zones[3];
	struct zonelist___101 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___102 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___102 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___101 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___102 {
	void *stack;
	struct task_struct___102 *task;
	long int status;
};

struct blocking_notifier_head___101 {
	struct rw_semaphore___102 rwsem;
	struct notifier_block *head;
};

struct dentry___102;

struct path___101 {
	struct vfsmount *mnt;
	struct dentry___102 *dentry;
};

struct fown_struct___84 {
	rwlock_t lock;
	struct pid___84 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___102 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___101 f_path;
	struct inode___103 *f_inode;
	const struct file_operations___102 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___84 f_owner;
	const struct cred___97 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___101 *f_mapping;
	errseq_t f_wb_err;
};

struct user_struct___97;

struct cred___97 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___97 *session_keyring;
	struct key___97 *process_keyring;
	struct key___97 *thread_keyring;
	struct key___97 *request_key_auth;
	void *security;
	struct user_struct___97 *user;
	struct user_namespace___82 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___98;

struct kernfs_elem_dir___98 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___98 *root;
};

struct kernfs_node___98;

struct kernfs_syscall_ops___98;

struct kernfs_root___98 {
	struct kernfs_node___98 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___98 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___98 {
	struct kernfs_node___98 *target_kn;
};

struct kernfs_ops___98;

struct kernfs_elem_attr___98 {
	const struct kernfs_ops___98 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___98 *notify_next;
};

struct kernfs_node___98 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___98 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___98 dir;
		struct kernfs_elem_symlink___98 symlink;
		struct kernfs_elem_attr___98 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___98;

struct kernfs_ops___98 {
	int (*open)(struct kernfs_open_file___98 *);
	void (*release)(struct kernfs_open_file___98 *);
	int (*seq_show)(struct seq_file___92 *, void *);
	void * (*seq_start)(struct seq_file___92 *, loff_t *);
	void * (*seq_next)(struct seq_file___92 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___92 *, void *);
	ssize_t (*read)(struct kernfs_open_file___98 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___98 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___98 *, struct vm_area_struct___102 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___98 *, struct poll_table_struct___65 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___98 {
	int (*remount_fs)(struct kernfs_root___98 *, int *, char *);
	int (*show_options)(struct seq_file___92 *, struct kernfs_root___98 *);
	int (*mkdir)(struct kernfs_node___98 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___98 *);
	int (*rename)(struct kernfs_node___98 *, struct kernfs_node___98 *, const char *);
	int (*show_path)(struct seq_file___92 *, struct kernfs_node___98 *, struct kernfs_root___98 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___90;

struct seq_file___92 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___90 *op;
	int poll_event;
	const struct file___102 *file;
	void *private;
};

struct vm_operations_struct___99;

struct kernfs_open_file___98 {
	struct kernfs_node___98 *kn;
	struct file___102 *file;
	struct seq_file___92 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___99 *vm_ops;
};

struct vm_fault___99;

struct vm_operations_struct___99 {
	void (*open)(struct vm_area_struct___102 *);
	void (*close)(struct vm_area_struct___102 *);
	int (*split)(struct vm_area_struct___102 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___102 *);
	vm_fault_t (*fault)(struct vm_fault___99 *);
	vm_fault_t (*huge_fault)(struct vm_fault___99 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___99 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___102 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___99 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___99 *);
	int (*access)(struct vm_area_struct___102 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___102 *);
	int (*set_policy)(struct vm_area_struct___102 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___102 *, long unsigned int);
	struct page___102 * (*find_special_page)(struct vm_area_struct___102 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___64)(struct file___102 *, wait_queue_head_t *, struct poll_table_struct___65 *);

struct poll_table_struct___65 {
	poll_queue_proc___64 _qproc;
	__poll_t _key;
};

struct vm_area_struct___102 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___102 *vm_next;
	struct vm_area_struct___102 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___101 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___99 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___102 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___96;

struct bin_attribute___92;

struct attribute_group___92 {
	const char *name;
	umode_t (*is_visible)(struct kobject___96 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___96 *, struct bin_attribute___92 *, int);
	struct attribute **attrs;
	struct bin_attribute___92 **bin_attrs;
};

struct kset___95;

struct kobj_type___95;

struct kobject___96 {
	const char *name;
	struct list_head entry;
	struct kobject___96 *parent;
	struct kset___95 *kset;
	struct kobj_type___95 *ktype;
	struct kernfs_node___98 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___92 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___102 *, struct kobject___96 *, struct bin_attribute___92 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___102 *, struct kobject___96 *, struct bin_attribute___92 *, char *, loff_t, size_t);
	int (*mmap)(struct file___102 *, struct kobject___96 *, struct bin_attribute___92 *, struct vm_area_struct___102 *);
};

struct sysfs_ops___95 {
	ssize_t (*show)(struct kobject___96 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___96 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___95;

struct kset___95 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___96 kobj;
	const struct kset_uevent_ops___95 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___95 {
	void (*release)(struct kobject___96 *);
	const struct sysfs_ops___95 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___5 * (*child_ns_type)(struct kobject___96 *);
	const void * (*namespace)(struct kobject___96 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___95 {
	int (* const filter)(struct kset___95 *, struct kobject___96 *);
	const char * (* const name)(struct kset___95 *, struct kobject___96 *);
	int (* const uevent)(struct kset___95 *, struct kobject___96 *, struct kobj_uevent_env *);
};

struct kobj_attribute___96 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___96 *, struct kobj_attribute___96 *, char *);
	ssize_t (*store)(struct kobject___96 *, struct kobj_attribute___96 *, const char *, size_t);
};

struct kernel_param___82;

struct kernel_param_ops___82 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___82 *);
	int (*get)(char *, const struct kernel_param___82 *);
	void (*free)(void *);
};

struct kparam_array___82;

struct kernel_param___82 {
	const char *name;
	struct module___85 *mod;
	const struct kernel_param_ops___82 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___82 *arr;
	};
};

struct kparam_array___82 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___82 *ops;
	void *elem;
};

struct module_kobject___82 {
	struct kobject___96 kobj;
	struct module___85 *mod;
	struct kobject___96 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___82 {
	struct module___85 *mod;
	struct latch_tree_node node;
};

struct module_layout___82 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___82 mtn;
};

struct module_attribute___82;

struct module___85 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___82 mkobj;
	struct module_attribute___82 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___96 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___82 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___82 core_layout;
	struct module_layout___82 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___55 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___82 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___82 *, struct module_kobject___82 *, char *);
	ssize_t (*store)(struct module_attribute___82 *, struct module_kobject___82 *, const char *, size_t);
	void (*setup)(struct module___85 *, const char *);
	int (*test)(struct module___85 *);
	void (*free)(struct module___85 *);
};

struct trace_event_functions___3;

struct trace_event___3 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___3 *funcs;
};

struct trace_event_class___55;

struct trace_event_call___55 {
	struct list_head list;
	struct trace_event_class___55 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___3 event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___9 *prog_array;
	int (*perf_perm)(struct trace_event_call___55 *, struct perf_event___60 *);
};

struct core_state___101;

struct mm_struct___101 {
	struct {
		struct vm_area_struct___102 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___102 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___102 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___101 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___102 *owner;
		struct user_namespace___82 *user_ns;
		struct file___102 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___101 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___101;

struct address_space___101 {
	struct inode___103 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___102 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___101 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___99)(struct vm_area_struct___102 *, long unsigned int, const struct page___102 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___99)(struct page___102 *, void *);

struct device___93;

struct dev_pagemap___99 {
	dev_page_fault_t___99 page_fault;
	dev_page_free_t___99 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___93 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___101 {
	struct task_struct___102 *task;
	struct core_thread___101 *next;
};

struct core_state___101 {
	atomic_t nr_threads;
	struct core_thread___101 dumper;
	struct completion startup;
};

struct vm_fault___99 {
	struct vm_area_struct___102 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___102 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___102 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___101 prealloc_pte;
};

struct upid___84 {
	int nr;
	struct pid_namespace___84 *ns;
};

struct pid_namespace___84 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___102 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___84 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___102 *proc_self;
	struct dentry___102 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___82 *user_ns;
	struct ucounts___82 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___7 ns;
};

struct pid___84 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___84 numbers[1];
};

struct user_struct___97 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___97 *uid_keyring;
	struct key___97 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cgroup_namespace___78;

struct nsproxy___94 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___84 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___78 *cgroup_ns;
};

struct signal_struct___91 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___102 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___102 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___84 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___84 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___101 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___84 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___78;

struct cgroup___78;

struct css_set___78 {
	struct cgroup_subsys_state___78 *subsys[13];
	refcount_t refcount;
	struct css_set___78 *dom_cset;
	struct cgroup___78 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___78 *mg_src_cgrp;
	struct cgroup___78 *mg_dst_cgrp;
	struct css_set___78 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___60 {
	struct pmu___60 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___102 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___60 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___73 {
	struct vm_struct___73 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___102 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___91 {
	struct task_struct___102 task;
	long unsigned int stack[8192];
};

struct dev_pm_info___93 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___93 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___93;

struct bus_type___93;

struct device_driver___93;

struct dev_pm_domain___93;

struct device_node___31;

struct fwnode_handle___67;

struct class___93;

struct device___93 {
	struct device___93 *parent;
	struct device_private *p;
	struct kobject___96 kobj;
	const char *init_name;
	const struct device_type___93 *type;
	struct mutex mutex;
	struct bus_type___93 *bus;
	struct device_driver___93 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___93 power;
	struct dev_pm_domain___93 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___31 *of_node;
	struct fwnode_handle___67 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___93 *class;
	const struct attribute_group___92 **groups;
	void (*release)(struct device___93 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___101;

struct super_block___102;

struct dentry___102 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___102 *d_parent;
	struct qstr d_name;
	struct inode___103 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___101 *d_op;
	struct super_block___102 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___101;

struct block_device___102;

struct inode___103 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___101 *i_op;
	struct super_block___102 *i_sb;
	struct address_space___101 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___102 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___102 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___101 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___102 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___101 {
	int (*d_revalidate)(struct dentry___102 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___102 *, unsigned int);
	int (*d_hash)(const struct dentry___102 *, struct qstr *);
	int (*d_compare)(const struct dentry___102 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___102 *);
	int (*d_init)(struct dentry___102 *);
	void (*d_release)(struct dentry___102 *);
	void (*d_prune)(struct dentry___102 *);
	void (*d_iput)(struct dentry___102 *, struct inode___103 *);
	char * (*d_dname)(struct dentry___102 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___101 *);
	int (*d_manage)(const struct path___101 *, bool);
	struct dentry___102 * (*d_real)(struct dentry___102 *, const struct inode___103 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___101;

struct mem_dqinfo___101 {
	struct quota_format_type___101 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___101;

struct quota_info___101 {
	unsigned int flags;
	struct rw_semaphore___102 dqio_sem;
	struct inode___103 *files[3];
	struct mem_dqinfo___101 info[3];
	const struct quota_format_ops___101 *ops[3];
};

struct rcuwait___101 {
	struct task_struct___102 *task;
};

struct percpu_rw_semaphore___101 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___102 rw_sem;
	struct rcuwait___101 writer;
	int readers_block;
};

struct sb_writers___101 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___101 rw_sem[3];
};

struct file_system_type___101;

struct super_operations___101;

struct dquot_operations___101;

struct quotactl_ops___101;

struct super_block___102 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___101 *s_type;
	const struct super_operations___101 *s_op;
	const struct dquot_operations___101 *dq_op;
	const struct quotactl_ops___101 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___102 *s_root;
	struct rw_semaphore___102 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___102 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___101 s_dquot;
	struct sb_writers___101 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___101 *s_d_op;
	int cleancache_poolid;
	struct shrinker___36 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___82 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___102 {
	struct file___102 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___102 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___102 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___102 *ia_file;
};

struct dquot___101 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___102 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___101 {
	int qf_fmt_id;
	const struct quota_format_ops___101 *qf_ops;
	struct module___85 *qf_owner;
	struct quota_format_type___101 *qf_next;
};

struct quota_format_ops___101 {
	int (*check_quota_file)(struct super_block___102 *, int);
	int (*read_file_info)(struct super_block___102 *, int);
	int (*write_file_info)(struct super_block___102 *, int);
	int (*free_file_info)(struct super_block___102 *, int);
	int (*read_dqblk)(struct dquot___101 *);
	int (*commit_dqblk)(struct dquot___101 *);
	int (*release_dqblk)(struct dquot___101 *);
	int (*get_next_id)(struct super_block___102 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___101 {
	int (*write_dquot)(struct dquot___101 *);
	struct dquot___101 * (*alloc_dquot)(struct super_block___102 *, int);
	void (*destroy_dquot)(struct dquot___101 *);
	int (*acquire_dquot)(struct dquot___101 *);
	int (*release_dquot)(struct dquot___101 *);
	int (*mark_dirty)(struct dquot___101 *);
	int (*write_info)(struct super_block___102 *, int);
	qsize_t * (*get_reserved_space)(struct inode___103 *);
	int (*get_projid)(struct inode___103 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___103 *, qsize_t *);
	int (*get_next_id)(struct super_block___102 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___101 {
	int (*quota_on)(struct super_block___102 *, int, int, const struct path___101 *);
	int (*quota_off)(struct super_block___102 *, int);
	int (*quota_enable)(struct super_block___102 *, unsigned int);
	int (*quota_disable)(struct super_block___102 *, unsigned int);
	int (*quota_sync)(struct super_block___102 *, int);
	int (*set_info)(struct super_block___102 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___102 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___102 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___102 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___102 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___102 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___101 {
	int (*writepage)(struct page___102 *, struct writeback_control___3 *);
	int (*readpage)(struct file___102 *, struct page___102 *);
	int (*writepages)(struct address_space___101 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___102 *);
	int (*readpages)(struct file___102 *, struct address_space___101 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___102 *, struct address_space___101 *, loff_t, unsigned int, unsigned int, struct page___102 **, void **);
	int (*write_end)(struct file___102 *, struct address_space___101 *, loff_t, unsigned int, unsigned int, struct page___102 *, void *);
	sector_t (*bmap)(struct address_space___101 *, sector_t);
	void (*invalidatepage)(struct page___102 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___102 *, gfp_t);
	void (*freepage)(struct page___102 *);
	ssize_t (*direct_IO)(struct kiocb___102 *, struct iov_iter___41 *);
	int (*migratepage)(struct address_space___101 *, struct page___102 *, struct page___102 *, enum migrate_mode);
	bool (*isolate_page)(struct page___102 *, isolate_mode_t);
	void (*putback_page)(struct page___102 *);
	int (*launder_page)(struct page___102 *);
	int (*is_partially_uptodate)(struct page___102 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___102 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___101 *, struct page___102 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___102 *, sector_t *);
	void (*swap_deactivate)(struct file___102 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___102 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___103 *bd_inode;
	struct super_block___102 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___102 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___101 {
	struct dentry___102 * (*lookup)(struct inode___103 *, struct dentry___102 *, unsigned int);
	const char * (*get_link)(struct dentry___102 *, struct inode___103 *, struct delayed_call *);
	int (*permission)(struct inode___103 *, int);
	struct posix_acl * (*get_acl)(struct inode___103 *, int);
	int (*readlink)(struct dentry___102 *, char *, int);
	int (*create)(struct inode___103 *, struct dentry___102 *, umode_t, bool);
	int (*link)(struct dentry___102 *, struct inode___103 *, struct dentry___102 *);
	int (*unlink)(struct inode___103 *, struct dentry___102 *);
	int (*symlink)(struct inode___103 *, struct dentry___102 *, const char *);
	int (*mkdir)(struct inode___103 *, struct dentry___102 *, umode_t);
	int (*rmdir)(struct inode___103 *, struct dentry___102 *);
	int (*mknod)(struct inode___103 *, struct dentry___102 *, umode_t, dev_t);
	int (*rename)(struct inode___103 *, struct dentry___102 *, struct inode___103 *, struct dentry___102 *, unsigned int);
	int (*setattr)(struct dentry___102 *, struct iattr___102 *);
	int (*getattr)(const struct path___101 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___102 *, char *, size_t);
	int (*fiemap)(struct inode___103 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___103 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___103 *, struct dentry___102 *, struct file___102 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___103 *, struct dentry___102 *, umode_t);
	int (*set_acl)(struct inode___103 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___101 {
	void (*fl_copy_lock)(struct file_lock___102 *, struct file_lock___102 *);
	void (*fl_release_private)(struct file_lock___102 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___101;

struct file_lock___102 {
	struct file_lock___102 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___102 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___101 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___101 *fl_ops;
	const struct lock_manager_operations___101 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___101 {
	int (*lm_compare_owner)(struct file_lock___102 *, struct file_lock___102 *);
	long unsigned int (*lm_owner_key)(struct file_lock___102 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___102 *);
	int (*lm_grant)(struct file_lock___102 *, int);
	bool (*lm_break)(struct file_lock___102 *);
	int (*lm_change)(struct file_lock___102 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___102 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___101 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___101 *fa_next;
	struct file___102 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___101 {
	const char *name;
	int fs_flags;
	struct dentry___102 * (*mount)(struct file_system_type___101 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___102 *);
	struct module___85 *owner;
	struct file_system_type___101 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___101 {
	struct inode___103 * (*alloc_inode)(struct super_block___102 *);
	void (*destroy_inode)(struct inode___103 *);
	void (*dirty_inode)(struct inode___103 *, int);
	int (*write_inode)(struct inode___103 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___103 *);
	void (*evict_inode)(struct inode___103 *);
	void (*put_super)(struct super_block___102 *);
	int (*sync_fs)(struct super_block___102 *, int);
	int (*freeze_super)(struct super_block___102 *);
	int (*freeze_fs)(struct super_block___102 *);
	int (*thaw_super)(struct super_block___102 *);
	int (*unfreeze_fs)(struct super_block___102 *);
	int (*statfs)(struct dentry___102 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___102 *, int *, char *);
	void (*umount_begin)(struct super_block___102 *);
	int (*show_options)(struct seq_file___92 *, struct dentry___102 *);
	int (*show_devname)(struct seq_file___92 *, struct dentry___102 *);
	int (*show_path)(struct seq_file___92 *, struct dentry___102 *);
	int (*show_stats)(struct seq_file___92 *, struct dentry___102 *);
	ssize_t (*quota_read)(struct super_block___102 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___102 *, int, const char *, size_t, loff_t);
	struct dquot___101 ** (*get_dquots)(struct inode___103 *);
	int (*bdev_try_to_free_page)(struct super_block___102 *, struct page___102 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___102 *, struct shrink_control___36 *);
	long int (*free_cached_objects)(struct super_block___102 *, struct shrink_control___36 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___99(struct page___102 *);

typedef int (*key_restrict_link_func_t___97)(struct key___97 *, const struct key_type *, const union key_payload *, struct key___97 *);

struct key_restriction___97;

struct key___97 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___102 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___97 *restrict_link;
};

struct key_restriction___97 {
	key_restrict_link_func_t___97 check;
	struct key___97 *key;
	struct key_type *keytype;
};

struct cgroup_namespace___78 {
	refcount_t count;
	struct ns_common___7 ns;
	struct user_namespace___82 *user_ns;
	struct ucounts___82 *ucounts;
	struct css_set___78 *root_cset;
};

struct ucounts___82 {
	struct hlist_node node;
	struct user_namespace___82 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct fwnode_operations___67;

struct fwnode_handle___67 {
	struct fwnode_handle___67 *secondary;
	const struct fwnode_operations___67 *ops;
};

struct fwnode_reference_args___67;

struct fwnode_endpoint___67;

struct fwnode_operations___67 {
	struct fwnode_handle___67 * (*get)(struct fwnode_handle___67 *);
	void (*put)(struct fwnode_handle___67 *);
	bool (*device_is_available)(const struct fwnode_handle___67 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___67 *, const struct device___93 *);
	bool (*property_present)(const struct fwnode_handle___67 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___67 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___67 *, const char *, const char **, size_t);
	struct fwnode_handle___67 * (*get_parent)(const struct fwnode_handle___67 *);
	struct fwnode_handle___67 * (*get_next_child_node)(const struct fwnode_handle___67 *, struct fwnode_handle___67 *);
	struct fwnode_handle___67 * (*get_named_child_node)(const struct fwnode_handle___67 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___67 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___67 *);
	struct fwnode_handle___67 * (*graph_get_next_endpoint)(const struct fwnode_handle___67 *, struct fwnode_handle___67 *);
	struct fwnode_handle___67 * (*graph_get_remote_endpoint)(const struct fwnode_handle___67 *);
	struct fwnode_handle___67 * (*graph_get_port_parent)(struct fwnode_handle___67 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___67 *, struct fwnode_endpoint___67 *);
};

struct fwnode_endpoint___67 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___67 *local_fwnode;
};

struct fwnode_reference_args___67 {
	struct fwnode_handle___67 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct property___30 {
	char *name;
	int length;
	void *value;
	struct property___30 *next;
	long unsigned int _flags;
	struct bin_attribute___92 attr;
};

struct device_node___31 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___67 fwnode;
	struct property___30 *properties;
	struct property___30 *deadprops;
	struct device_node___31 *parent;
	struct device_node___31 *child;
	struct device_node___31 *sibling;
	struct kobject___96 kobj;
	long unsigned int _flags;
	void *data;
};

struct seq_operations___90 {
	void * (*start)(struct seq_file___92 *, loff_t *);
	void (*stop)(struct seq_file___92 *, void *);
	void * (*next)(struct seq_file___92 *, void *, loff_t *);
	int (*show)(struct seq_file___92 *, void *);
};

struct dev_pm_ops___93 {
	int (*prepare)(struct device___93 *);
	void (*complete)(struct device___93 *);
	int (*suspend)(struct device___93 *);
	int (*resume)(struct device___93 *);
	int (*freeze)(struct device___93 *);
	int (*thaw)(struct device___93 *);
	int (*poweroff)(struct device___93 *);
	int (*restore)(struct device___93 *);
	int (*suspend_late)(struct device___93 *);
	int (*resume_early)(struct device___93 *);
	int (*freeze_late)(struct device___93 *);
	int (*thaw_early)(struct device___93 *);
	int (*poweroff_late)(struct device___93 *);
	int (*restore_early)(struct device___93 *);
	int (*suspend_noirq)(struct device___93 *);
	int (*resume_noirq)(struct device___93 *);
	int (*freeze_noirq)(struct device___93 *);
	int (*thaw_noirq)(struct device___93 *);
	int (*poweroff_noirq)(struct device___93 *);
	int (*restore_noirq)(struct device___93 *);
	int (*runtime_suspend)(struct device___93 *);
	int (*runtime_resume)(struct device___93 *);
	int (*runtime_idle)(struct device___93 *);
};

struct dev_pm_domain___93 {
	struct dev_pm_ops___93 ops;
	void (*detach)(struct device___93 *, bool);
	int (*activate)(struct device___93 *);
	void (*sync)(struct device___93 *);
	void (*dismiss)(struct device___93 *);
};

struct bus_type___93 {
	const char *name;
	const char *dev_name;
	struct device___93 *dev_root;
	const struct attribute_group___92 **bus_groups;
	const struct attribute_group___92 **dev_groups;
	const struct attribute_group___92 **drv_groups;
	int (*match)(struct device___93 *, struct device_driver___93 *);
	int (*uevent)(struct device___93 *, struct kobj_uevent_env *);
	int (*probe)(struct device___93 *);
	int (*remove)(struct device___93 *);
	void (*shutdown)(struct device___93 *);
	int (*online)(struct device___93 *);
	int (*offline)(struct device___93 *);
	int (*suspend)(struct device___93 *, pm_message_t);
	int (*resume)(struct device___93 *);
	int (*num_vf)(struct device___93 *);
	int (*dma_configure)(struct device___93 *);
	const struct dev_pm_ops___93 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___93 {
	const char *name;
	struct bus_type___93 *bus;
	struct module___85 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___93 *);
	int (*remove)(struct device___93 *);
	void (*shutdown)(struct device___93 *);
	int (*suspend)(struct device___93 *, pm_message_t);
	int (*resume)(struct device___93 *);
	const struct attribute_group___92 **groups;
	const struct dev_pm_ops___93 *pm;
	void (*coredump)(struct device___93 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___93 {
	const char *name;
	const struct attribute_group___92 **groups;
	int (*uevent)(struct device___93 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___93 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___93 *);
	const struct dev_pm_ops___93 *pm;
};

struct class___93 {
	const char *name;
	struct module___85 *owner;
	const struct attribute_group___92 **class_groups;
	const struct attribute_group___92 **dev_groups;
	struct kobject___96 *dev_kobj;
	int (*dev_uevent)(struct device___93 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___93 *, umode_t *);
	void (*class_release)(struct class___93 *);
	void (*dev_release)(struct device___93 *);
	int (*shutdown_pre)(struct device___93 *);
	const struct kobj_ns_type_operations___5 *ns_type;
	const void * (*namespace)(struct device___93 *);
	const struct dev_pm_ops___93 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___79 {
	struct device___93 dev;
};

struct bpf_map___78;

struct bpf_map_ops___78 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___78 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___78 *, struct file___102 *);
	void (*map_free)(struct bpf_map___78 *);
	int (*map_get_next_key)(struct bpf_map___78 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___78 *);
	void * (*map_lookup_elem)(struct bpf_map___78 *, void *);
	int (*map_update_elem)(struct bpf_map___78 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___78 *, void *);
	int (*map_push_elem)(struct bpf_map___78 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___78 *, void *);
	int (*map_peek_elem)(struct bpf_map___78 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___78 *, struct file___102 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___78 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___78 *, void *, struct seq_file___92 *);
	int (*map_check_btf)(const struct bpf_map___78 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___78 {
	const struct bpf_map_ops___78 *ops;
	struct bpf_map___78 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___97 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___78;

typedef void (*kthread_work_func_t___78)(struct kthread_work___78 *);

struct kthread_worker___78;

struct kthread_work___78 {
	struct list_head node;
	kthread_work_func_t___78 func;
	struct kthread_worker___78 *worker;
	int canceling;
};

struct kthread_worker___78 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___102 *task;
	struct kthread_work___78 *current_work;
};

struct kthread_delayed_work___78 {
	struct kthread_work___78 work;
	struct timer_list timer;
};

struct psi_group___78 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___78 *poll_kworker;
	struct kthread_delayed_work___78 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___78 {
	struct kernfs_node___98 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___78;

struct cgroup_subsys_state___78 {
	struct cgroup___78 *cgroup;
	struct cgroup_subsys___78 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___78 *parent;
};

struct cgroup_root___78;

struct cgroup_rstat_cpu___78;

struct cgroup___78 {
	struct cgroup_subsys_state___78 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___98 *kn;
	struct cgroup_file___78 procs_file;
	struct cgroup_file___78 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___78 *subsys[13];
	struct cgroup_root___78 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___78 *dom_cgrp;
	struct cgroup_rstat_cpu___78 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___9 bpf;
	atomic_t congestion_count;
	struct cgroup___78 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___78 psi;
	int ancestor_ids[0];
};

struct cftype___78;

struct cgroup_subsys___78 {
	struct cgroup_subsys_state___78 * (*css_alloc)(struct cgroup_subsys_state___78 *);
	int (*css_online)(struct cgroup_subsys_state___78 *);
	void (*css_offline)(struct cgroup_subsys_state___78 *);
	void (*css_released)(struct cgroup_subsys_state___78 *);
	void (*css_free)(struct cgroup_subsys_state___78 *);
	void (*css_reset)(struct cgroup_subsys_state___78 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___78 *, int);
	int (*css_extra_stat_show)(struct seq_file___92 *, struct cgroup_subsys_state___78 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___102 *);
	void (*cancel_fork)(struct task_struct___102 *);
	void (*fork)(struct task_struct___102 *);
	void (*exit)(struct task_struct___102 *);
	void (*free)(struct task_struct___102 *);
	void (*bind)(struct cgroup_subsys_state___78 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___78 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___78 *dfl_cftypes;
	struct cftype___78 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___78 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___78 *updated_children;
	struct cgroup___78 *updated_next;
};

struct cgroup_root___78 {
	struct kernfs_root___98 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___78 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___78 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___78 *ss;
	struct list_head node;
	struct kernfs_ops___98 *kf_ops;
	int (*open)(struct kernfs_open_file___98 *);
	void (*release)(struct kernfs_open_file___98 *);
	u64 (*read_u64)(struct cgroup_subsys_state___78 *, struct cftype___78 *);
	s64 (*read_s64)(struct cgroup_subsys_state___78 *, struct cftype___78 *);
	int (*seq_show)(struct seq_file___92 *, void *);
	void * (*seq_start)(struct seq_file___92 *, loff_t *);
	void * (*seq_next)(struct seq_file___92 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___92 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___78 *, struct cftype___78 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___78 *, struct cftype___78 *, s64);
	ssize_t (*write)(struct kernfs_open_file___98 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___98 *, struct poll_table_struct___65 *);
};

struct perf_cpu_context___60;

struct pmu___60 {
	struct list_head entry;
	struct module___85 *module;
	struct device___93 *dev;
	const struct attribute_group___92 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___60 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___60 *);
	void (*pmu_disable)(struct pmu___60 *);
	int (*event_init)(struct perf_event___60 *);
	void (*event_mapped)(struct perf_event___60 *, struct mm_struct___101 *);
	void (*event_unmapped)(struct perf_event___60 *, struct mm_struct___101 *);
	int (*add)(struct perf_event___60 *, int);
	void (*del)(struct perf_event___60 *, int);
	void (*start)(struct perf_event___60 *, int);
	void (*stop)(struct perf_event___60 *, int);
	void (*read)(struct perf_event___60 *);
	void (*start_txn)(struct pmu___60 *, unsigned int);
	int (*commit_txn)(struct pmu___60 *);
	void (*cancel_txn)(struct pmu___60 *);
	int (*event_idx)(struct perf_event___60 *);
	void (*sched_task)(struct perf_event_context___60 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___60 *);
	int (*filter_match)(struct perf_event___60 *);
	int (*check_period)(struct perf_event___60 *, u64);
};

struct perf_cpu_context___60 {
	struct perf_event_context___60 ctx;
	struct perf_event_context___60 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___60 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___60 {
	struct cgroup_subsys_state___78 css;
	struct perf_cgroup_info *info;
};

struct trace_array___3;

struct tracer___3;

struct trace_buffer___3;

struct trace_iterator___3 {
	struct trace_array___3 *tr;
	struct tracer___3 *trace;
	struct trace_buffer___3 *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

struct trace_buffer___3 {
	struct trace_array___3 *tr;
	struct ring_buffer *buffer;
	struct trace_array_cpu *data;
	u64 time_start;
	int cpu;
};

struct trace_event_file___20;

struct trace_options___3;

struct trace_array___3 {
	struct list_head list;
	char *name;
	struct trace_buffer___3 trace_buffer;
	struct trace_buffer___3 max_buffer;
	bool allocated_snapshot;
	long unsigned int max_latency;
	struct trace_pid_list *filtered_pids;
	arch_spinlock_t max_lock;
	int buffer_disabled;
	int sys_refcount_enter;
	int sys_refcount_exit;
	struct trace_event_file___20 *enter_syscall_files[295];
	struct trace_event_file___20 *exit_syscall_files[295];
	int stop_count;
	int clock_id;
	int nr_topts;
	bool clear_trace;
	struct tracer___3 *current_trace;
	unsigned int trace_flags;
	unsigned char trace_flags_index[32];
	unsigned int flags;
	raw_spinlock_t start_lock;
	struct dentry___102 *dir;
	struct dentry___102 *options;
	struct dentry___102 *percpu_dir;
	struct dentry___102 *event_dir;
	struct trace_options___3 *topts;
	struct list_head systems;
	struct list_head events;
	struct trace_event_file___20 *trace_marker_file;
	cpumask_var_t tracing_cpumask;
	int ref;
	struct ftrace_ops *ops;
	struct trace_pid_list *function_pids;
	struct list_head func_probes;
	struct list_head mod_trace;
	struct list_head mod_notrace;
	int function_enabled;
	int time_stamp_abs_ref;
	struct list_head hist_vars;
};

struct tracer_flags___3;

struct tracer___3 {
	const char *name;
	int (*init)(struct trace_array___3 *);
	void (*reset)(struct trace_array___3 *);
	void (*start)(struct trace_array___3 *);
	void (*stop)(struct trace_array___3 *);
	int (*update_thresh)(struct trace_array___3 *);
	void (*open)(struct trace_iterator___3 *);
	void (*pipe_open)(struct trace_iterator___3 *);
	void (*close)(struct trace_iterator___3 *);
	void (*pipe_close)(struct trace_iterator___3 *);
	ssize_t (*read)(struct trace_iterator___3 *, struct file___102 *, char *, size_t, loff_t *);
	ssize_t (*splice_read)(struct trace_iterator___3 *, struct file___102 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	void (*print_header)(struct seq_file___92 *);
	enum print_line_t (*print_line)(struct trace_iterator___3 *);
	int (*set_flag)(struct trace_array___3 *, u32, u32, int);
	int (*flag_changed)(struct trace_array___3 *, u32, int);
	struct tracer___3 *next;
	struct tracer_flags___3 *flags;
	int enabled;
	int ref;
	bool print_max;
	bool allow_instances;
	bool use_max_tr;
	bool noboot;
};

typedef enum print_line_t (*trace_print_func___3)(struct trace_iterator___3 *, int, struct trace_event___3 *);

struct trace_event_functions___3 {
	trace_print_func___3 trace;
	trace_print_func___3 raw;
	trace_print_func___3 hex;
	trace_print_func___3 binary;
};

struct trace_event_class___55 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___55 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___55 *);
	struct list_head * (*get_fields)(struct trace_event_call___55 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___55 *);
};

struct trace_subsystem_dir___4;

struct trace_event_file___20 {
	struct list_head list;
	struct trace_event_call___55 *event_call;
	struct event_filter *filter;
	struct dentry___102 *dir;
	struct trace_array___3 *tr;
	struct trace_subsystem_dir___4 *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_subsystem_dir___4 {
	struct list_head list;
	struct event_subsystem *subsystem;
	struct trace_array___3 *tr;
	struct dentry___102 *entry;
	int ref_count;
	int nr_events;
};

struct ctx_switch_entry {
	struct trace_entry ent;
	unsigned int prev_pid;
	unsigned int next_pid;
	unsigned int next_cpu;
	unsigned char prev_prio;
	unsigned char prev_state;
	unsigned char next_prio;
	unsigned char next_state;
};

struct hwlat_entry {
	struct trace_entry ent;
	u64 duration;
	u64 outer_duration;
	u64 nmi_total_ts;
	struct timespec64 timestamp;
	unsigned int nmi_count;
	unsigned int seqnum;
};

struct trace_option_dentry___3;

struct trace_options___3 {
	struct tracer___3 *tracer;
	struct trace_option_dentry___3 *topts;
};

struct trace_option_dentry___3 {
	struct tracer_opt *opt;
	struct tracer_flags___3 *flags;
	struct trace_array___3 *tr;
	struct dentry___102 *entry;
};

struct tracer_flags___3 {
	u32 val;
	struct tracer_opt *opts;
	struct tracer___3 *trace;
};

struct trace_mark {
	long long unsigned int val;
	char sym;
};

struct module___86;

struct file___103;

struct kiocb___103;

struct poll_table_struct___66;

struct vm_area_struct___103;

struct inode___104;

struct file_lock___103;

struct page___103;

struct seq_file___93;

struct file_operations___103 {
	struct module___86 *owner;
	loff_t (*llseek)(struct file___103 *, loff_t, int);
	ssize_t (*read)(struct file___103 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___103 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___103 *, struct iov_iter___41 *);
	ssize_t (*write_iter)(struct kiocb___103 *, struct iov_iter___41 *);
	int (*iopoll)(struct kiocb___103 *, bool);
	int (*iterate)(struct file___103 *, struct dir_context *);
	int (*iterate_shared)(struct file___103 *, struct dir_context *);
	__poll_t (*poll)(struct file___103 *, struct poll_table_struct___66 *);
	long int (*unlocked_ioctl)(struct file___103 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___103 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___103 *, struct vm_area_struct___103 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___104 *, struct file___103 *);
	int (*flush)(struct file___103 *, fl_owner_t);
	int (*release)(struct inode___104 *, struct file___103 *);
	int (*fsync)(struct file___103 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___103 *, int);
	int (*lock)(struct file___103 *, int, struct file_lock___103 *);
	ssize_t (*sendpage)(struct file___103 *, struct page___103 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___103 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___103 *, int, struct file_lock___103 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___103 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___103 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___103 *, long int, struct file_lock___103 **, void **);
	long int (*fallocate)(struct file___103 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___93 *, struct file___103 *);
	ssize_t (*copy_file_range)(struct file___103 *, loff_t, struct file___103 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___103 *, loff_t, struct file___103 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___103 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___102 {
	u64 seqnum;
	struct vm_area_struct___103 *vmas[4];
};

struct page_frag___102 {
	struct page___103 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___61;

struct debug_info___61 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___61 *hbp_break[16];
	struct perf_event___61 *hbp_watch[16];
};

struct thread_struct___61 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___61 debug;
	long: 64;
};

struct mm_struct___102;

struct pid___85;

struct cred___98;

struct nsproxy___95;

struct signal_struct___92;

struct css_set___79;

struct perf_event_context___61;

struct vm_struct___74;

struct task_struct___103 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___103 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___102 *mm;
	struct mm_struct___102 *active_mm;
	struct vmacache___102 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___103 *real_parent;
	struct task_struct___103 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___103 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___85 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___85 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___85 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___98 *ptracer_cred;
	const struct cred___98 *real_cred;
	const struct cred___98 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___95 *nsproxy;
	struct signal_struct___92 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___103 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___16 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___79 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___61 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___102 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___103 *oom_reaper_list;
	struct vm_struct___74 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___61 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___61 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___103 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___61)(struct perf_event___61 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___61;

struct fasync_struct___102;

struct pid_namespace___85;

struct trace_event_call___56;

struct perf_cgroup___61;

struct perf_event___61 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___61 *group_leader;
	struct pmu___61 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___61 hw;
	struct perf_event_context___61 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___61 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___103 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___102 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___61 *);
	struct callback_head callback_head;
	struct pid_namespace___85 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___61 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___61 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___56 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___61 *cgrp;
	struct list_head sb_list;
};

typedef struct page___103 *pgtable_t___102;

struct address_space___102;

struct dev_pagemap___100;

struct page___103 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___102 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___103 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___102 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___102 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___100 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___102;

struct lruvec___102 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___102 *pgdat;
};

struct zone___102 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___102 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___102 {
	struct zone___102 *zone;
	int zone_idx;
};

struct zonelist___102 {
	struct zoneref___102 _zonerefs[25];
};

struct pglist_data___102 {
	struct zone___102 node_zones[3];
	struct zonelist___102 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___103 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___103 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___102 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___103 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___103 *owner;
};

struct secondary_data___103 {
	void *stack;
	struct task_struct___103 *task;
	long int status;
};

struct blocking_notifier_head___102 {
	struct rw_semaphore___103 rwsem;
	struct notifier_block *head;
};

struct dentry_operations___102;

struct super_block___103;

struct dentry___103 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___103 *d_parent;
	struct qstr d_name;
	struct inode___104 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___102 *d_op;
	struct super_block___103 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___102;

struct address_space___102 {
	struct inode___104 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___103 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___102 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___102;

struct block_device___103;

struct inode___104 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___102 *i_op;
	struct super_block___103 *i_sb;
	struct address_space___102 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___103 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___103 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___102 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___103 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___102;

struct dentry_operations___102 {
	int (*d_revalidate)(struct dentry___103 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___103 *, unsigned int);
	int (*d_hash)(const struct dentry___103 *, struct qstr *);
	int (*d_compare)(const struct dentry___103 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___103 *);
	int (*d_init)(struct dentry___103 *);
	void (*d_release)(struct dentry___103 *);
	void (*d_prune)(struct dentry___103 *);
	void (*d_iput)(struct dentry___103 *, struct inode___104 *);
	char * (*d_dname)(struct dentry___103 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___102 *);
	int (*d_manage)(const struct path___102 *, bool);
	struct dentry___103 * (*d_real)(struct dentry___103 *, const struct inode___104 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___102;

struct mem_dqinfo___102 {
	struct quota_format_type___102 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___102;

struct quota_info___102 {
	unsigned int flags;
	struct rw_semaphore___103 dqio_sem;
	struct inode___104 *files[3];
	struct mem_dqinfo___102 info[3];
	const struct quota_format_ops___102 *ops[3];
};

struct rcuwait___102 {
	struct task_struct___103 *task;
};

struct percpu_rw_semaphore___102 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___103 rw_sem;
	struct rcuwait___102 writer;
	int readers_block;
};

struct sb_writers___102 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___102 rw_sem[3];
};

struct file_system_type___102;

struct super_operations___102;

struct dquot_operations___102;

struct quotactl_ops___102;

struct user_namespace___83;

struct super_block___103 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___102 *s_type;
	const struct super_operations___102 *s_op;
	const struct dquot_operations___102 *dq_op;
	const struct quotactl_ops___102 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___103 *s_root;
	struct rw_semaphore___103 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___103 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___102 s_dquot;
	struct sb_writers___102 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___102 *s_d_op;
	int cleancache_poolid;
	struct shrinker___36 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___83 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct path___102 {
	struct vfsmount *mnt;
	struct dentry___103 *dentry;
};

struct key___98;

struct ucounts___83;

struct user_namespace___83 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___83 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___7 ns;
	long unsigned int flags;
	struct key___98 *persistent_keyring_register;
	struct rw_semaphore___103 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___83 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct upid___85 {
	int nr;
	struct pid_namespace___85 *ns;
};

struct pid_namespace___85 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___103 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___85 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___103 *proc_self;
	struct dentry___103 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___83 *user_ns;
	struct ucounts___83 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___7 ns;
};

struct pid___85 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___85 numbers[1];
};

struct vm_operations_struct___100;

struct vm_area_struct___103 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___103 *vm_next;
	struct vm_area_struct___103 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___102 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___100 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___103 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___102;

struct mm_struct___102 {
	struct {
		struct vm_area_struct___103 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___103 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___103 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___102 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___103 *owner;
		struct user_namespace___83 *user_ns;
		struct file___103 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___102 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___100)(struct vm_area_struct___103 *, long unsigned int, const struct page___103 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___100)(struct page___103 *, void *);

struct device___94;

struct dev_pagemap___100 {
	dev_page_fault_t___100 page_fault;
	dev_page_free_t___100 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___94 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct fown_struct___85 {
	rwlock_t lock;
	struct pid___85 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___103 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___102 f_path;
	struct inode___104 *f_inode;
	const struct file_operations___103 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___85 f_owner;
	const struct cred___98 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___102 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___100;

struct vm_operations_struct___100 {
	void (*open)(struct vm_area_struct___103 *);
	void (*close)(struct vm_area_struct___103 *);
	int (*split)(struct vm_area_struct___103 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___103 *);
	vm_fault_t (*fault)(struct vm_fault___100 *);
	vm_fault_t (*huge_fault)(struct vm_fault___100 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___100 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___103 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___100 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___100 *);
	int (*access)(struct vm_area_struct___103 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___103 *);
	int (*set_policy)(struct vm_area_struct___103 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___103 *, long unsigned int);
	struct page___103 * (*find_special_page)(struct vm_area_struct___103 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___102 {
	struct task_struct___103 *task;
	struct core_thread___102 *next;
};

struct core_state___102 {
	atomic_t nr_threads;
	struct core_thread___102 dumper;
	struct completion startup;
};

struct vm_fault___100 {
	struct vm_area_struct___103 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___103 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___103 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___102 prealloc_pte;
};

struct user_struct___98 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___98 *uid_keyring;
	struct key___98 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___98 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___98 *session_keyring;
	struct key___98 *process_keyring;
	struct key___98 *thread_keyring;
	struct key___98 *request_key_auth;
	void *security;
	struct user_struct___98 *user;
	struct user_namespace___83 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___79;

struct nsproxy___95 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___85 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___79 *cgroup_ns;
};

struct signal_struct___92 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___103 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___103 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___85 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___85 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___102 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___85 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___79;

struct cgroup___79;

struct css_set___79 {
	struct cgroup_subsys_state___79 *subsys[13];
	refcount_t refcount;
	struct css_set___79 *dom_cset;
	struct cgroup___79 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___79 *mg_src_cgrp;
	struct cgroup___79 *mg_dst_cgrp;
	struct css_set___79 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___61 {
	struct pmu___61 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___103 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___61 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___74 {
	struct vm_struct___74 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___103 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___92 {
	struct task_struct___103 task;
	long unsigned int stack[8192];
};

struct kiocb___103 {
	struct file___103 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___103 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___103 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___103 *ia_file;
};

struct dquot___102 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___103 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___102 {
	int qf_fmt_id;
	const struct quota_format_ops___102 *qf_ops;
	struct module___86 *qf_owner;
	struct quota_format_type___102 *qf_next;
};

struct quota_format_ops___102 {
	int (*check_quota_file)(struct super_block___103 *, int);
	int (*read_file_info)(struct super_block___103 *, int);
	int (*write_file_info)(struct super_block___103 *, int);
	int (*free_file_info)(struct super_block___103 *, int);
	int (*read_dqblk)(struct dquot___102 *);
	int (*commit_dqblk)(struct dquot___102 *);
	int (*release_dqblk)(struct dquot___102 *);
	int (*get_next_id)(struct super_block___103 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___102 {
	int (*write_dquot)(struct dquot___102 *);
	struct dquot___102 * (*alloc_dquot)(struct super_block___103 *, int);
	void (*destroy_dquot)(struct dquot___102 *);
	int (*acquire_dquot)(struct dquot___102 *);
	int (*release_dquot)(struct dquot___102 *);
	int (*mark_dirty)(struct dquot___102 *);
	int (*write_info)(struct super_block___103 *, int);
	qsize_t * (*get_reserved_space)(struct inode___104 *);
	int (*get_projid)(struct inode___104 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___104 *, qsize_t *);
	int (*get_next_id)(struct super_block___103 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___102 {
	int (*quota_on)(struct super_block___103 *, int, int, const struct path___102 *);
	int (*quota_off)(struct super_block___103 *, int);
	int (*quota_enable)(struct super_block___103 *, unsigned int);
	int (*quota_disable)(struct super_block___103 *, unsigned int);
	int (*quota_sync)(struct super_block___103 *, int);
	int (*set_info)(struct super_block___103 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___103 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___103 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___103 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___103 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___103 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___96;

struct kobj_type___96;

struct kernfs_node___99;

struct kobject___97 {
	const char *name;
	struct list_head entry;
	struct kobject___97 *parent;
	struct kset___96 *kset;
	struct kobj_type___96 *ktype;
	struct kernfs_node___99 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___83 {
	struct kobject___97 kobj;
	struct module___86 *mod;
	struct kobject___97 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___83 {
	struct module___86 *mod;
	struct latch_tree_node node;
};

struct module_layout___83 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___83 mtn;
};

struct module_attribute___83;

struct kernel_param___83;

struct module___86 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___83 mkobj;
	struct module_attribute___83 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___97 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___83 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___83 core_layout;
	struct module_layout___83 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___56 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___102 {
	int (*writepage)(struct page___103 *, struct writeback_control___3 *);
	int (*readpage)(struct file___103 *, struct page___103 *);
	int (*writepages)(struct address_space___102 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___103 *);
	int (*readpages)(struct file___103 *, struct address_space___102 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___103 *, struct address_space___102 *, loff_t, unsigned int, unsigned int, struct page___103 **, void **);
	int (*write_end)(struct file___103 *, struct address_space___102 *, loff_t, unsigned int, unsigned int, struct page___103 *, void *);
	sector_t (*bmap)(struct address_space___102 *, sector_t);
	void (*invalidatepage)(struct page___103 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___103 *, gfp_t);
	void (*freepage)(struct page___103 *);
	ssize_t (*direct_IO)(struct kiocb___103 *, struct iov_iter___41 *);
	int (*migratepage)(struct address_space___102 *, struct page___103 *, struct page___103 *, enum migrate_mode);
	bool (*isolate_page)(struct page___103 *, isolate_mode_t);
	void (*putback_page)(struct page___103 *);
	int (*launder_page)(struct page___103 *);
	int (*is_partially_uptodate)(struct page___103 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___103 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___102 *, struct page___103 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___103 *, sector_t *);
	void (*swap_deactivate)(struct file___103 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___103 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___104 *bd_inode;
	struct super_block___103 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___103 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___102 {
	struct dentry___103 * (*lookup)(struct inode___104 *, struct dentry___103 *, unsigned int);
	const char * (*get_link)(struct dentry___103 *, struct inode___104 *, struct delayed_call *);
	int (*permission)(struct inode___104 *, int);
	struct posix_acl * (*get_acl)(struct inode___104 *, int);
	int (*readlink)(struct dentry___103 *, char *, int);
	int (*create)(struct inode___104 *, struct dentry___103 *, umode_t, bool);
	int (*link)(struct dentry___103 *, struct inode___104 *, struct dentry___103 *);
	int (*unlink)(struct inode___104 *, struct dentry___103 *);
	int (*symlink)(struct inode___104 *, struct dentry___103 *, const char *);
	int (*mkdir)(struct inode___104 *, struct dentry___103 *, umode_t);
	int (*rmdir)(struct inode___104 *, struct dentry___103 *);
	int (*mknod)(struct inode___104 *, struct dentry___103 *, umode_t, dev_t);
	int (*rename)(struct inode___104 *, struct dentry___103 *, struct inode___104 *, struct dentry___103 *, unsigned int);
	int (*setattr)(struct dentry___103 *, struct iattr___103 *);
	int (*getattr)(const struct path___102 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___103 *, char *, size_t);
	int (*fiemap)(struct inode___104 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___104 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___104 *, struct dentry___103 *, struct file___103 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___104 *, struct dentry___103 *, umode_t);
	int (*set_acl)(struct inode___104 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___102 {
	void (*fl_copy_lock)(struct file_lock___103 *, struct file_lock___103 *);
	void (*fl_release_private)(struct file_lock___103 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___102;

struct file_lock___103 {
	struct file_lock___103 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___103 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___102 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___102 *fl_ops;
	const struct lock_manager_operations___102 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___102 {
	int (*lm_compare_owner)(struct file_lock___103 *, struct file_lock___103 *);
	long unsigned int (*lm_owner_key)(struct file_lock___103 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___103 *);
	int (*lm_grant)(struct file_lock___103 *, int);
	bool (*lm_break)(struct file_lock___103 *);
	int (*lm_change)(struct file_lock___103 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___103 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___102 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___102 *fa_next;
	struct file___103 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___102 {
	const char *name;
	int fs_flags;
	struct dentry___103 * (*mount)(struct file_system_type___102 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___103 *);
	struct module___86 *owner;
	struct file_system_type___102 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___102 {
	struct inode___104 * (*alloc_inode)(struct super_block___103 *);
	void (*destroy_inode)(struct inode___104 *);
	void (*dirty_inode)(struct inode___104 *, int);
	int (*write_inode)(struct inode___104 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___104 *);
	void (*evict_inode)(struct inode___104 *);
	void (*put_super)(struct super_block___103 *);
	int (*sync_fs)(struct super_block___103 *, int);
	int (*freeze_super)(struct super_block___103 *);
	int (*freeze_fs)(struct super_block___103 *);
	int (*thaw_super)(struct super_block___103 *);
	int (*unfreeze_fs)(struct super_block___103 *);
	int (*statfs)(struct dentry___103 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___103 *, int *, char *);
	void (*umount_begin)(struct super_block___103 *);
	int (*show_options)(struct seq_file___93 *, struct dentry___103 *);
	int (*show_devname)(struct seq_file___93 *, struct dentry___103 *);
	int (*show_path)(struct seq_file___93 *, struct dentry___103 *);
	int (*show_stats)(struct seq_file___93 *, struct dentry___103 *);
	ssize_t (*quota_read)(struct super_block___103 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___103 *, int, const char *, size_t, loff_t);
	struct dquot___102 ** (*get_dquots)(struct inode___104 *);
	int (*bdev_try_to_free_page)(struct super_block___103 *, struct page___103 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___103 *, struct shrink_control___36 *);
	long int (*free_cached_objects)(struct super_block___103 *, struct shrink_control___36 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___65)(struct file___103 *, wait_queue_head_t *, struct poll_table_struct___66 *);

struct poll_table_struct___66 {
	poll_queue_proc___65 _qproc;
	__poll_t _key;
};

struct seq_operations___91;

struct seq_file___93 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___91 *op;
	int poll_event;
	const struct file___103 *file;
	void *private;
};

typedef int (*key_restrict_link_func_t___98)(struct key___98 *, const struct key_type *, const union key_payload *, struct key___98 *);

struct key_restriction___98;

struct key___98 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___103 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___98 *restrict_link;
};

struct key_restriction___98 {
	key_restrict_link_func_t___98 check;
	struct key___98 *key;
	struct key_type *keytype;
};

struct seq_operations___91 {
	void * (*start)(struct seq_file___93 *, loff_t *);
	void (*stop)(struct seq_file___93 *, void *);
	void * (*next)(struct seq_file___93 *, void *, loff_t *);
	int (*show)(struct seq_file___93 *, void *);
};

struct tracer_stat {
	const char *name;
	void * (*stat_start)(struct tracer_stat *);
	void * (*stat_next)(void *, int);
	int (*stat_cmp)(void *, void *);
	int (*stat_show)(struct seq_file___93 *, void *);
	void (*stat_release)(void *);
	int (*stat_headers)(struct seq_file___93 *);
};

struct kernfs_root___99;

struct kernfs_elem_dir___99 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___99 *root;
};

struct kernfs_syscall_ops___99;

struct kernfs_root___99 {
	struct kernfs_node___99 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___99 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___99 {
	struct kernfs_node___99 *target_kn;
};

struct kernfs_ops___99;

struct kernfs_elem_attr___99 {
	const struct kernfs_ops___99 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___99 *notify_next;
};

struct kernfs_node___99 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___99 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___99 dir;
		struct kernfs_elem_symlink___99 symlink;
		struct kernfs_elem_attr___99 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___99;

struct kernfs_ops___99 {
	int (*open)(struct kernfs_open_file___99 *);
	void (*release)(struct kernfs_open_file___99 *);
	int (*seq_show)(struct seq_file___93 *, void *);
	void * (*seq_start)(struct seq_file___93 *, loff_t *);
	void * (*seq_next)(struct seq_file___93 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___93 *, void *);
	ssize_t (*read)(struct kernfs_open_file___99 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___99 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___99 *, struct vm_area_struct___103 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___99 *, struct poll_table_struct___66 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___99 {
	int (*remount_fs)(struct kernfs_root___99 *, int *, char *);
	int (*show_options)(struct seq_file___93 *, struct kernfs_root___99 *);
	int (*mkdir)(struct kernfs_node___99 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___99 *);
	int (*rename)(struct kernfs_node___99 *, struct kernfs_node___99 *, const char *);
	int (*show_path)(struct seq_file___93 *, struct kernfs_node___99 *, struct kernfs_root___99 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___99 {
	struct kernfs_node___99 *kn;
	struct file___103 *file;
	struct seq_file___93 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___100 *vm_ops;
};

struct bin_attribute___93;

struct attribute_group___93 {
	const char *name;
	umode_t (*is_visible)(struct kobject___97 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___97 *, struct bin_attribute___93 *, int);
	struct attribute **attrs;
	struct bin_attribute___93 **bin_attrs;
};

struct bin_attribute___93 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___103 *, struct kobject___97 *, struct bin_attribute___93 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___103 *, struct kobject___97 *, struct bin_attribute___93 *, char *, loff_t, size_t);
	int (*mmap)(struct file___103 *, struct kobject___97 *, struct bin_attribute___93 *, struct vm_area_struct___103 *);
};

struct sysfs_ops___96 {
	ssize_t (*show)(struct kobject___97 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___97 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___96;

struct kset___96 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___97 kobj;
	const struct kset_uevent_ops___96 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___96 {
	void (*release)(struct kobject___97 *);
	const struct sysfs_ops___96 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___5 * (*child_ns_type)(struct kobject___97 *);
	const void * (*namespace)(struct kobject___97 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___96 {
	int (* const filter)(struct kset___96 *, struct kobject___97 *);
	const char * (* const name)(struct kset___96 *, struct kobject___97 *);
	int (* const uevent)(struct kset___96 *, struct kobject___97 *, struct kobj_uevent_env *);
};

struct kobj_attribute___97 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___97 *, struct kobj_attribute___97 *, char *);
	ssize_t (*store)(struct kobject___97 *, struct kobj_attribute___97 *, const char *, size_t);
};

struct fwnode_operations___68;

struct fwnode_handle___68 {
	struct fwnode_handle___68 *secondary;
	const struct fwnode_operations___68 *ops;
};

struct fwnode_reference_args___68;

struct fwnode_endpoint___68;

struct fwnode_operations___68 {
	struct fwnode_handle___68 * (*get)(struct fwnode_handle___68 *);
	void (*put)(struct fwnode_handle___68 *);
	bool (*device_is_available)(const struct fwnode_handle___68 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___68 *, const struct device___94 *);
	bool (*property_present)(const struct fwnode_handle___68 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___68 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___68 *, const char *, const char **, size_t);
	struct fwnode_handle___68 * (*get_parent)(const struct fwnode_handle___68 *);
	struct fwnode_handle___68 * (*get_next_child_node)(const struct fwnode_handle___68 *, struct fwnode_handle___68 *);
	struct fwnode_handle___68 * (*get_named_child_node)(const struct fwnode_handle___68 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___68 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___68 *);
	struct fwnode_handle___68 * (*graph_get_next_endpoint)(const struct fwnode_handle___68 *, struct fwnode_handle___68 *);
	struct fwnode_handle___68 * (*graph_get_remote_endpoint)(const struct fwnode_handle___68 *);
	struct fwnode_handle___68 * (*graph_get_port_parent)(struct fwnode_handle___68 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___68 *, struct fwnode_endpoint___68 *);
};

struct fwnode_endpoint___68 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___68 *local_fwnode;
};

struct fwnode_reference_args___68 {
	struct fwnode_handle___68 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct dev_pm_info___94 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___94 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___94;

struct bus_type___94;

struct device_driver___94;

struct dev_pm_domain___94;

struct device_node___32;

struct class___94;

struct device___94 {
	struct device___94 *parent;
	struct device_private *p;
	struct kobject___97 kobj;
	const char *init_name;
	const struct device_type___94 *type;
	struct mutex mutex;
	struct bus_type___94 *bus;
	struct device_driver___94 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___94 power;
	struct dev_pm_domain___94 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___32 *of_node;
	struct fwnode_handle___68 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___94 *class;
	const struct attribute_group___93 **groups;
	void (*release)(struct device___94 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct property___31 {
	char *name;
	int length;
	void *value;
	struct property___31 *next;
	long unsigned int _flags;
	struct bin_attribute___93 attr;
};

struct device_node___32 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___68 fwnode;
	struct property___31 *properties;
	struct property___31 *deadprops;
	struct device_node___32 *parent;
	struct device_node___32 *child;
	struct device_node___32 *sibling;
	struct kobject___97 kobj;
	long unsigned int _flags;
	void *data;
};

typedef void compound_page_dtor___100(struct page___103 *);

struct kernel_param_ops___83 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___83 *);
	int (*get)(char *, const struct kernel_param___83 *);
	void (*free)(void *);
};

struct kparam_array___83;

struct kernel_param___83 {
	const char *name;
	struct module___86 *mod;
	const struct kernel_param_ops___83 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___83 *arr;
	};
};

struct kparam_array___83 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___83 *ops;
	void *elem;
};

struct module_attribute___83 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___83 *, struct module_kobject___83 *, char *);
	ssize_t (*store)(struct module_attribute___83 *, struct module_kobject___83 *, const char *, size_t);
	void (*setup)(struct module___86 *, const char *);
	int (*test)(struct module___86 *);
	void (*free)(struct module___86 *);
};

struct trace_event_functions___4;

struct trace_event___4 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___4 *funcs;
};

struct trace_event_class___56;

struct trace_event_call___56 {
	struct list_head list;
	struct trace_event_class___56 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___4 event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___9 *prog_array;
	int (*perf_perm)(struct trace_event_call___56 *, struct perf_event___61 *);
};

struct cgroup_namespace___79 {
	refcount_t count;
	struct ns_common___7 ns;
	struct user_namespace___83 *user_ns;
	struct ucounts___83 *ucounts;
	struct css_set___79 *root_cset;
};

struct ucounts___83 {
	struct hlist_node node;
	struct user_namespace___83 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct dev_pm_ops___94 {
	int (*prepare)(struct device___94 *);
	void (*complete)(struct device___94 *);
	int (*suspend)(struct device___94 *);
	int (*resume)(struct device___94 *);
	int (*freeze)(struct device___94 *);
	int (*thaw)(struct device___94 *);
	int (*poweroff)(struct device___94 *);
	int (*restore)(struct device___94 *);
	int (*suspend_late)(struct device___94 *);
	int (*resume_early)(struct device___94 *);
	int (*freeze_late)(struct device___94 *);
	int (*thaw_early)(struct device___94 *);
	int (*poweroff_late)(struct device___94 *);
	int (*restore_early)(struct device___94 *);
	int (*suspend_noirq)(struct device___94 *);
	int (*resume_noirq)(struct device___94 *);
	int (*freeze_noirq)(struct device___94 *);
	int (*thaw_noirq)(struct device___94 *);
	int (*poweroff_noirq)(struct device___94 *);
	int (*restore_noirq)(struct device___94 *);
	int (*runtime_suspend)(struct device___94 *);
	int (*runtime_resume)(struct device___94 *);
	int (*runtime_idle)(struct device___94 *);
};

struct dev_pm_domain___94 {
	struct dev_pm_ops___94 ops;
	void (*detach)(struct device___94 *, bool);
	int (*activate)(struct device___94 *);
	void (*sync)(struct device___94 *);
	void (*dismiss)(struct device___94 *);
};

struct bus_type___94 {
	const char *name;
	const char *dev_name;
	struct device___94 *dev_root;
	const struct attribute_group___93 **bus_groups;
	const struct attribute_group___93 **dev_groups;
	const struct attribute_group___93 **drv_groups;
	int (*match)(struct device___94 *, struct device_driver___94 *);
	int (*uevent)(struct device___94 *, struct kobj_uevent_env *);
	int (*probe)(struct device___94 *);
	int (*remove)(struct device___94 *);
	void (*shutdown)(struct device___94 *);
	int (*online)(struct device___94 *);
	int (*offline)(struct device___94 *);
	int (*suspend)(struct device___94 *, pm_message_t);
	int (*resume)(struct device___94 *);
	int (*num_vf)(struct device___94 *);
	int (*dma_configure)(struct device___94 *);
	const struct dev_pm_ops___94 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___94 {
	const char *name;
	struct bus_type___94 *bus;
	struct module___86 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___94 *);
	int (*remove)(struct device___94 *);
	void (*shutdown)(struct device___94 *);
	int (*suspend)(struct device___94 *, pm_message_t);
	int (*resume)(struct device___94 *);
	const struct attribute_group___93 **groups;
	const struct dev_pm_ops___94 *pm;
	void (*coredump)(struct device___94 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___94 {
	const char *name;
	const struct attribute_group___93 **groups;
	int (*uevent)(struct device___94 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___94 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___94 *);
	const struct dev_pm_ops___94 *pm;
};

struct class___94 {
	const char *name;
	struct module___86 *owner;
	const struct attribute_group___93 **class_groups;
	const struct attribute_group___93 **dev_groups;
	struct kobject___97 *dev_kobj;
	int (*dev_uevent)(struct device___94 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___94 *, umode_t *);
	void (*class_release)(struct class___94 *);
	void (*dev_release)(struct device___94 *);
	int (*shutdown_pre)(struct device___94 *);
	const struct kobj_ns_type_operations___5 *ns_type;
	const void * (*namespace)(struct device___94 *);
	const struct dev_pm_ops___94 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___80 {
	struct device___94 dev;
};

struct bpf_map___79;

struct bpf_map_ops___79 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___79 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___79 *, struct file___103 *);
	void (*map_free)(struct bpf_map___79 *);
	int (*map_get_next_key)(struct bpf_map___79 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___79 *);
	void * (*map_lookup_elem)(struct bpf_map___79 *, void *);
	int (*map_update_elem)(struct bpf_map___79 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___79 *, void *);
	int (*map_push_elem)(struct bpf_map___79 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___79 *, void *);
	int (*map_peek_elem)(struct bpf_map___79 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___79 *, struct file___103 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___79 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___79 *, void *, struct seq_file___93 *);
	int (*map_check_btf)(const struct bpf_map___79 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___79 {
	const struct bpf_map_ops___79 *ops;
	struct bpf_map___79 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___98 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___79;

typedef void (*kthread_work_func_t___79)(struct kthread_work___79 *);

struct kthread_worker___79;

struct kthread_work___79 {
	struct list_head node;
	kthread_work_func_t___79 func;
	struct kthread_worker___79 *worker;
	int canceling;
};

struct kthread_worker___79 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___103 *task;
	struct kthread_work___79 *current_work;
};

struct kthread_delayed_work___79 {
	struct kthread_work___79 work;
	struct timer_list timer;
};

struct psi_group___79 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___79 *poll_kworker;
	struct kthread_delayed_work___79 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___79 {
	struct kernfs_node___99 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___79;

struct cgroup_subsys_state___79 {
	struct cgroup___79 *cgroup;
	struct cgroup_subsys___79 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___79 *parent;
};

struct cgroup_root___79;

struct cgroup_rstat_cpu___79;

struct cgroup___79 {
	struct cgroup_subsys_state___79 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___99 *kn;
	struct cgroup_file___79 procs_file;
	struct cgroup_file___79 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___79 *subsys[13];
	struct cgroup_root___79 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___79 *dom_cgrp;
	struct cgroup_rstat_cpu___79 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___9 bpf;
	atomic_t congestion_count;
	struct cgroup___79 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___79 psi;
	int ancestor_ids[0];
};

struct cftype___79;

struct cgroup_subsys___79 {
	struct cgroup_subsys_state___79 * (*css_alloc)(struct cgroup_subsys_state___79 *);
	int (*css_online)(struct cgroup_subsys_state___79 *);
	void (*css_offline)(struct cgroup_subsys_state___79 *);
	void (*css_released)(struct cgroup_subsys_state___79 *);
	void (*css_free)(struct cgroup_subsys_state___79 *);
	void (*css_reset)(struct cgroup_subsys_state___79 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___79 *, int);
	int (*css_extra_stat_show)(struct seq_file___93 *, struct cgroup_subsys_state___79 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___103 *);
	void (*cancel_fork)(struct task_struct___103 *);
	void (*fork)(struct task_struct___103 *);
	void (*exit)(struct task_struct___103 *);
	void (*free)(struct task_struct___103 *);
	void (*bind)(struct cgroup_subsys_state___79 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___79 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___79 *dfl_cftypes;
	struct cftype___79 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___79 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___79 *updated_children;
	struct cgroup___79 *updated_next;
};

struct cgroup_root___79 {
	struct kernfs_root___99 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___79 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___79 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___79 *ss;
	struct list_head node;
	struct kernfs_ops___99 *kf_ops;
	int (*open)(struct kernfs_open_file___99 *);
	void (*release)(struct kernfs_open_file___99 *);
	u64 (*read_u64)(struct cgroup_subsys_state___79 *, struct cftype___79 *);
	s64 (*read_s64)(struct cgroup_subsys_state___79 *, struct cftype___79 *);
	int (*seq_show)(struct seq_file___93 *, void *);
	void * (*seq_start)(struct seq_file___93 *, loff_t *);
	void * (*seq_next)(struct seq_file___93 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___93 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___79 *, struct cftype___79 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___79 *, struct cftype___79 *, s64);
	ssize_t (*write)(struct kernfs_open_file___99 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___99 *, struct poll_table_struct___66 *);
};

struct perf_cpu_context___61;

struct pmu___61 {
	struct list_head entry;
	struct module___86 *module;
	struct device___94 *dev;
	const struct attribute_group___93 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___61 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___61 *);
	void (*pmu_disable)(struct pmu___61 *);
	int (*event_init)(struct perf_event___61 *);
	void (*event_mapped)(struct perf_event___61 *, struct mm_struct___102 *);
	void (*event_unmapped)(struct perf_event___61 *, struct mm_struct___102 *);
	int (*add)(struct perf_event___61 *, int);
	void (*del)(struct perf_event___61 *, int);
	void (*start)(struct perf_event___61 *, int);
	void (*stop)(struct perf_event___61 *, int);
	void (*read)(struct perf_event___61 *);
	void (*start_txn)(struct pmu___61 *, unsigned int);
	int (*commit_txn)(struct pmu___61 *);
	void (*cancel_txn)(struct pmu___61 *);
	int (*event_idx)(struct perf_event___61 *);
	void (*sched_task)(struct perf_event_context___61 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___61 *);
	int (*filter_match)(struct perf_event___61 *);
	int (*check_period)(struct perf_event___61 *, u64);
};

struct perf_cpu_context___61 {
	struct perf_event_context___61 ctx;
	struct perf_event_context___61 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___61 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___61 {
	struct cgroup_subsys_state___79 css;
	struct perf_cgroup_info *info;
};

struct trace_array___4;

struct tracer___4;

struct trace_buffer___4;

struct trace_iterator___4 {
	struct trace_array___4 *tr;
	struct tracer___4 *trace;
	struct trace_buffer___4 *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

struct trace_buffer___4 {
	struct trace_array___4 *tr;
	struct ring_buffer *buffer;
	struct trace_array_cpu *data;
	u64 time_start;
	int cpu;
};

struct trace_event_file___21;

struct trace_options___4;

struct trace_array___4 {
	struct list_head list;
	char *name;
	struct trace_buffer___4 trace_buffer;
	struct trace_buffer___4 max_buffer;
	bool allocated_snapshot;
	long unsigned int max_latency;
	struct trace_pid_list *filtered_pids;
	arch_spinlock_t max_lock;
	int buffer_disabled;
	int sys_refcount_enter;
	int sys_refcount_exit;
	struct trace_event_file___21 *enter_syscall_files[295];
	struct trace_event_file___21 *exit_syscall_files[295];
	int stop_count;
	int clock_id;
	int nr_topts;
	bool clear_trace;
	struct tracer___4 *current_trace;
	unsigned int trace_flags;
	unsigned char trace_flags_index[32];
	unsigned int flags;
	raw_spinlock_t start_lock;
	struct dentry___103 *dir;
	struct dentry___103 *options;
	struct dentry___103 *percpu_dir;
	struct dentry___103 *event_dir;
	struct trace_options___4 *topts;
	struct list_head systems;
	struct list_head events;
	struct trace_event_file___21 *trace_marker_file;
	cpumask_var_t tracing_cpumask;
	int ref;
	struct ftrace_ops *ops;
	struct trace_pid_list *function_pids;
	struct list_head func_probes;
	struct list_head mod_trace;
	struct list_head mod_notrace;
	int function_enabled;
	int time_stamp_abs_ref;
	struct list_head hist_vars;
};

struct tracer_flags___4;

struct tracer___4 {
	const char *name;
	int (*init)(struct trace_array___4 *);
	void (*reset)(struct trace_array___4 *);
	void (*start)(struct trace_array___4 *);
	void (*stop)(struct trace_array___4 *);
	int (*update_thresh)(struct trace_array___4 *);
	void (*open)(struct trace_iterator___4 *);
	void (*pipe_open)(struct trace_iterator___4 *);
	void (*close)(struct trace_iterator___4 *);
	void (*pipe_close)(struct trace_iterator___4 *);
	ssize_t (*read)(struct trace_iterator___4 *, struct file___103 *, char *, size_t, loff_t *);
	ssize_t (*splice_read)(struct trace_iterator___4 *, struct file___103 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	void (*print_header)(struct seq_file___93 *);
	enum print_line_t (*print_line)(struct trace_iterator___4 *);
	int (*set_flag)(struct trace_array___4 *, u32, u32, int);
	int (*flag_changed)(struct trace_array___4 *, u32, int);
	struct tracer___4 *next;
	struct tracer_flags___4 *flags;
	int enabled;
	int ref;
	bool print_max;
	bool allow_instances;
	bool use_max_tr;
	bool noboot;
};

typedef enum print_line_t (*trace_print_func___4)(struct trace_iterator___4 *, int, struct trace_event___4 *);

struct trace_event_functions___4 {
	trace_print_func___4 trace;
	trace_print_func___4 raw;
	trace_print_func___4 hex;
	trace_print_func___4 binary;
};

struct trace_event_class___56 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___56 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___56 *);
	struct list_head * (*get_fields)(struct trace_event_call___56 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___56 *);
};

struct trace_subsystem_dir___5;

struct trace_event_file___21 {
	struct list_head list;
	struct trace_event_call___56 *event_call;
	struct event_filter *filter;
	struct dentry___103 *dir;
	struct trace_array___4 *tr;
	struct trace_subsystem_dir___5 *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_subsystem_dir___5 {
	struct list_head list;
	struct event_subsystem *subsystem;
	struct trace_array___4 *tr;
	struct dentry___103 *entry;
	int ref_count;
	int nr_events;
};

struct trace_option_dentry___4;

struct trace_options___4 {
	struct tracer___4 *tracer;
	struct trace_option_dentry___4 *topts;
};

struct trace_option_dentry___4 {
	struct tracer_opt *opt;
	struct tracer_flags___4 *flags;
	struct trace_array___4 *tr;
	struct dentry___103 *entry;
};

struct tracer_flags___4 {
	u32 val;
	struct tracer_opt *opts;
	struct tracer___4 *trace;
};

struct stat_node {
	struct rb_node node;
	void *stat;
};

struct stat_session {
	struct list_head session_list;
	struct tracer_stat *ts;
	struct rb_root stat_root;
	struct mutex stat_mutex;
	struct dentry___103 *file;
};

typedef int (*cmp_stat_t)(void *, void *);

struct module___87;

struct file___104;

struct kiocb___104;

struct poll_table_struct___67;

struct vm_area_struct___104;

struct inode___105;

struct file_lock___104;

struct page___104;

struct seq_file___94;

struct file_operations___104 {
	struct module___87 *owner;
	loff_t (*llseek)(struct file___104 *, loff_t, int);
	ssize_t (*read)(struct file___104 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___104 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___104 *, struct iov_iter___41 *);
	ssize_t (*write_iter)(struct kiocb___104 *, struct iov_iter___41 *);
	int (*iopoll)(struct kiocb___104 *, bool);
	int (*iterate)(struct file___104 *, struct dir_context *);
	int (*iterate_shared)(struct file___104 *, struct dir_context *);
	__poll_t (*poll)(struct file___104 *, struct poll_table_struct___67 *);
	long int (*unlocked_ioctl)(struct file___104 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___104 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___104 *, struct vm_area_struct___104 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___105 *, struct file___104 *);
	int (*flush)(struct file___104 *, fl_owner_t);
	int (*release)(struct inode___105 *, struct file___104 *);
	int (*fsync)(struct file___104 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___104 *, int);
	int (*lock)(struct file___104 *, int, struct file_lock___104 *);
	ssize_t (*sendpage)(struct file___104 *, struct page___104 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___104 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___104 *, int, struct file_lock___104 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___104 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___104 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___104 *, long int, struct file_lock___104 **, void **);
	long int (*fallocate)(struct file___104 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___94 *, struct file___104 *);
	ssize_t (*copy_file_range)(struct file___104 *, loff_t, struct file___104 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___104 *, loff_t, struct file___104 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___104 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct perf_event___62;

struct debug_info___62 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___62 *hbp_break[16];
	struct perf_event___62 *hbp_watch[16];
};

struct task_struct___104;

struct hw_perf_event___62 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___104 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___62)(struct perf_event___62 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___62;

struct perf_event_context___62;

struct fasync_struct___103;

struct pid_namespace___86;

struct trace_event_call___57;

struct perf_cgroup___62;

struct perf_event___62 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___62 *group_leader;
	struct pmu___62 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___62 hw;
	struct perf_event_context___62 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___62 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___104 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___103 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___62 *);
	struct callback_head callback_head;
	struct pid_namespace___86 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___62 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___62 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___57 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___62 *cgrp;
	struct list_head sb_list;
};

struct thread_struct___62 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___62 debug;
	long: 64;
};

struct vmacache___103 {
	u64 seqnum;
	struct vm_area_struct___104 *vmas[4];
};

struct page_frag___103 {
	struct page___104 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___103;

struct pid___86;

struct cred___99;

struct nsproxy___96;

struct signal_struct___93;

struct css_set___80;

struct vm_struct___75;

struct task_struct___104 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___104 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___103 *mm;
	struct mm_struct___103 *active_mm;
	struct vmacache___103 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___104 *real_parent;
	struct task_struct___104 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___104 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___86 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___86 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___86 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___99 *ptracer_cred;
	const struct cred___99 *real_cred;
	const struct cred___99 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___96 *nsproxy;
	struct signal_struct___93 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___104 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___16 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___80 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___62 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___103 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___104 *oom_reaper_list;
	struct vm_struct___75 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___62 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___103;

struct super_block___104;

struct dentry___104 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___104 *d_parent;
	struct qstr d_name;
	struct inode___105 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___103 *d_op;
	struct super_block___104 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct rw_semaphore___104 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___104 *owner;
};

struct address_space_operations___103;

struct address_space___103 {
	struct inode___105 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___104 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___103 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___103;

struct block_device___104;

struct inode___105 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___103 *i_op;
	struct super_block___104 *i_sb;
	struct address_space___103 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___104 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___104 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___103 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___104 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___103;

struct dentry_operations___103 {
	int (*d_revalidate)(struct dentry___104 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___104 *, unsigned int);
	int (*d_hash)(const struct dentry___104 *, struct qstr *);
	int (*d_compare)(const struct dentry___104 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___104 *);
	int (*d_init)(struct dentry___104 *);
	void (*d_release)(struct dentry___104 *);
	void (*d_prune)(struct dentry___104 *);
	void (*d_iput)(struct dentry___104 *, struct inode___105 *);
	char * (*d_dname)(struct dentry___104 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___103 *);
	int (*d_manage)(const struct path___103 *, bool);
	struct dentry___104 * (*d_real)(struct dentry___104 *, const struct inode___105 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___103;

struct mem_dqinfo___103 {
	struct quota_format_type___103 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___103;

struct quota_info___103 {
	unsigned int flags;
	struct rw_semaphore___104 dqio_sem;
	struct inode___105 *files[3];
	struct mem_dqinfo___103 info[3];
	const struct quota_format_ops___103 *ops[3];
};

struct rcuwait___103 {
	struct task_struct___104 *task;
};

struct percpu_rw_semaphore___103 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___104 rw_sem;
	struct rcuwait___103 writer;
	int readers_block;
};

struct sb_writers___103 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___103 rw_sem[3];
};

struct file_system_type___103;

struct super_operations___103;

struct dquot_operations___103;

struct quotactl_ops___103;

struct user_namespace___84;

struct super_block___104 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___103 *s_type;
	const struct super_operations___103 *s_op;
	const struct dquot_operations___103 *dq_op;
	const struct quotactl_ops___103 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___104 *s_root;
	struct rw_semaphore___104 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___104 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___103 s_dquot;
	struct sb_writers___103 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___103 *s_d_op;
	int cleancache_poolid;
	struct shrinker___36 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___84 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct path___103 {
	struct vfsmount *mnt;
	struct dentry___104 *dentry;
};

struct key___99;

struct ucounts___84;

struct user_namespace___84 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___84 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___7 ns;
	long unsigned int flags;
	struct key___99 *persistent_keyring_register;
	struct rw_semaphore___104 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___84 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___104 *pgtable_t___103;

struct dev_pagemap___101;

struct page___104 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___103 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___104 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___103 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___103 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___101 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___103;

struct lruvec___103 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___103 *pgdat;
};

struct zone___103 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___103 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___103 {
	struct zone___103 *zone;
	int zone_idx;
};

struct zonelist___103 {
	struct zoneref___103 _zonerefs[25];
};

struct pglist_data___103 {
	struct zone___103 node_zones[3];
	struct zonelist___103 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___104 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___104 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___103 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___104 {
	void *stack;
	struct task_struct___104 *task;
	long int status;
};

struct blocking_notifier_head___103 {
	struct rw_semaphore___104 rwsem;
	struct notifier_block *head;
};

struct upid___86 {
	int nr;
	struct pid_namespace___86 *ns;
};

struct pid_namespace___86 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___104 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___86 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___104 *proc_self;
	struct dentry___104 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___84 *user_ns;
	struct ucounts___84 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___7 ns;
};

struct pid___86 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___86 numbers[1];
};

struct vm_operations_struct___101;

struct vm_area_struct___104 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___104 *vm_next;
	struct vm_area_struct___104 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___103 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___101 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___104 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___103;

struct mm_struct___103 {
	struct {
		struct vm_area_struct___104 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___104 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___104 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___103 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___104 *owner;
		struct user_namespace___84 *user_ns;
		struct file___104 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___103 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___101)(struct vm_area_struct___104 *, long unsigned int, const struct page___104 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___101)(struct page___104 *, void *);

struct device___95;

struct dev_pagemap___101 {
	dev_page_fault_t___101 page_fault;
	dev_page_free_t___101 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___95 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct fown_struct___86 {
	rwlock_t lock;
	struct pid___86 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___104 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___103 f_path;
	struct inode___105 *f_inode;
	const struct file_operations___104 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___86 f_owner;
	const struct cred___99 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___103 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___101;

struct vm_operations_struct___101 {
	void (*open)(struct vm_area_struct___104 *);
	void (*close)(struct vm_area_struct___104 *);
	int (*split)(struct vm_area_struct___104 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___104 *);
	vm_fault_t (*fault)(struct vm_fault___101 *);
	vm_fault_t (*huge_fault)(struct vm_fault___101 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___101 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___104 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___101 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___101 *);
	int (*access)(struct vm_area_struct___104 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___104 *);
	int (*set_policy)(struct vm_area_struct___104 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___104 *, long unsigned int);
	struct page___104 * (*find_special_page)(struct vm_area_struct___104 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___103 {
	struct task_struct___104 *task;
	struct core_thread___103 *next;
};

struct core_state___103 {
	atomic_t nr_threads;
	struct core_thread___103 dumper;
	struct completion startup;
};

struct vm_fault___101 {
	struct vm_area_struct___104 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___104 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___104 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___103 prealloc_pte;
};

struct user_struct___99 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___99 *uid_keyring;
	struct key___99 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___99 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___99 *session_keyring;
	struct key___99 *process_keyring;
	struct key___99 *thread_keyring;
	struct key___99 *request_key_auth;
	void *security;
	struct user_struct___99 *user;
	struct user_namespace___84 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___80;

struct nsproxy___96 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___86 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___80 *cgroup_ns;
};

struct signal_struct___93 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___104 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___104 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___86 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___86 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___103 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___86 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___80;

struct cgroup___80;

struct css_set___80 {
	struct cgroup_subsys_state___80 *subsys[13];
	refcount_t refcount;
	struct css_set___80 *dom_cset;
	struct cgroup___80 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___80 *mg_src_cgrp;
	struct cgroup___80 *mg_dst_cgrp;
	struct css_set___80 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___62 {
	struct pmu___62 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___104 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___62 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___75 {
	struct vm_struct___75 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___104 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___93 {
	struct task_struct___104 task;
	long unsigned int stack[8192];
};

struct kiocb___104 {
	struct file___104 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___104 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___104 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___104 *ia_file;
};

struct dquot___103 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___104 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___103 {
	int qf_fmt_id;
	const struct quota_format_ops___103 *qf_ops;
	struct module___87 *qf_owner;
	struct quota_format_type___103 *qf_next;
};

struct quota_format_ops___103 {
	int (*check_quota_file)(struct super_block___104 *, int);
	int (*read_file_info)(struct super_block___104 *, int);
	int (*write_file_info)(struct super_block___104 *, int);
	int (*free_file_info)(struct super_block___104 *, int);
	int (*read_dqblk)(struct dquot___103 *);
	int (*commit_dqblk)(struct dquot___103 *);
	int (*release_dqblk)(struct dquot___103 *);
	int (*get_next_id)(struct super_block___104 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___103 {
	int (*write_dquot)(struct dquot___103 *);
	struct dquot___103 * (*alloc_dquot)(struct super_block___104 *, int);
	void (*destroy_dquot)(struct dquot___103 *);
	int (*acquire_dquot)(struct dquot___103 *);
	int (*release_dquot)(struct dquot___103 *);
	int (*mark_dirty)(struct dquot___103 *);
	int (*write_info)(struct super_block___104 *, int);
	qsize_t * (*get_reserved_space)(struct inode___105 *);
	int (*get_projid)(struct inode___105 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___105 *, qsize_t *);
	int (*get_next_id)(struct super_block___104 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___103 {
	int (*quota_on)(struct super_block___104 *, int, int, const struct path___103 *);
	int (*quota_off)(struct super_block___104 *, int);
	int (*quota_enable)(struct super_block___104 *, unsigned int);
	int (*quota_disable)(struct super_block___104 *, unsigned int);
	int (*quota_sync)(struct super_block___104 *, int);
	int (*set_info)(struct super_block___104 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___104 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___104 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___104 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___104 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___104 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___97;

struct kobj_type___97;

struct kernfs_node___100;

struct kobject___98 {
	const char *name;
	struct list_head entry;
	struct kobject___98 *parent;
	struct kset___97 *kset;
	struct kobj_type___97 *ktype;
	struct kernfs_node___100 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___84 {
	struct kobject___98 kobj;
	struct module___87 *mod;
	struct kobject___98 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___84 {
	struct module___87 *mod;
	struct latch_tree_node node;
};

struct module_layout___84 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___84 mtn;
};

struct module_attribute___84;

struct kernel_param___84;

struct module___87 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___84 mkobj;
	struct module_attribute___84 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___98 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___84 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___84 core_layout;
	struct module_layout___84 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___57 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___103 {
	int (*writepage)(struct page___104 *, struct writeback_control___3 *);
	int (*readpage)(struct file___104 *, struct page___104 *);
	int (*writepages)(struct address_space___103 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___104 *);
	int (*readpages)(struct file___104 *, struct address_space___103 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___104 *, struct address_space___103 *, loff_t, unsigned int, unsigned int, struct page___104 **, void **);
	int (*write_end)(struct file___104 *, struct address_space___103 *, loff_t, unsigned int, unsigned int, struct page___104 *, void *);
	sector_t (*bmap)(struct address_space___103 *, sector_t);
	void (*invalidatepage)(struct page___104 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___104 *, gfp_t);
	void (*freepage)(struct page___104 *);
	ssize_t (*direct_IO)(struct kiocb___104 *, struct iov_iter___41 *);
	int (*migratepage)(struct address_space___103 *, struct page___104 *, struct page___104 *, enum migrate_mode);
	bool (*isolate_page)(struct page___104 *, isolate_mode_t);
	void (*putback_page)(struct page___104 *);
	int (*launder_page)(struct page___104 *);
	int (*is_partially_uptodate)(struct page___104 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___104 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___103 *, struct page___104 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___104 *, sector_t *);
	void (*swap_deactivate)(struct file___104 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___104 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___105 *bd_inode;
	struct super_block___104 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___104 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___103 {
	struct dentry___104 * (*lookup)(struct inode___105 *, struct dentry___104 *, unsigned int);
	const char * (*get_link)(struct dentry___104 *, struct inode___105 *, struct delayed_call *);
	int (*permission)(struct inode___105 *, int);
	struct posix_acl * (*get_acl)(struct inode___105 *, int);
	int (*readlink)(struct dentry___104 *, char *, int);
	int (*create)(struct inode___105 *, struct dentry___104 *, umode_t, bool);
	int (*link)(struct dentry___104 *, struct inode___105 *, struct dentry___104 *);
	int (*unlink)(struct inode___105 *, struct dentry___104 *);
	int (*symlink)(struct inode___105 *, struct dentry___104 *, const char *);
	int (*mkdir)(struct inode___105 *, struct dentry___104 *, umode_t);
	int (*rmdir)(struct inode___105 *, struct dentry___104 *);
	int (*mknod)(struct inode___105 *, struct dentry___104 *, umode_t, dev_t);
	int (*rename)(struct inode___105 *, struct dentry___104 *, struct inode___105 *, struct dentry___104 *, unsigned int);
	int (*setattr)(struct dentry___104 *, struct iattr___104 *);
	int (*getattr)(const struct path___103 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___104 *, char *, size_t);
	int (*fiemap)(struct inode___105 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___105 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___105 *, struct dentry___104 *, struct file___104 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___105 *, struct dentry___104 *, umode_t);
	int (*set_acl)(struct inode___105 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___103 {
	void (*fl_copy_lock)(struct file_lock___104 *, struct file_lock___104 *);
	void (*fl_release_private)(struct file_lock___104 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___103;

struct file_lock___104 {
	struct file_lock___104 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___104 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___103 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___103 *fl_ops;
	const struct lock_manager_operations___103 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___103 {
	int (*lm_compare_owner)(struct file_lock___104 *, struct file_lock___104 *);
	long unsigned int (*lm_owner_key)(struct file_lock___104 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___104 *);
	int (*lm_grant)(struct file_lock___104 *, int);
	bool (*lm_break)(struct file_lock___104 *);
	int (*lm_change)(struct file_lock___104 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___104 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___103 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___103 *fa_next;
	struct file___104 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___103 {
	const char *name;
	int fs_flags;
	struct dentry___104 * (*mount)(struct file_system_type___103 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___104 *);
	struct module___87 *owner;
	struct file_system_type___103 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___103 {
	struct inode___105 * (*alloc_inode)(struct super_block___104 *);
	void (*destroy_inode)(struct inode___105 *);
	void (*dirty_inode)(struct inode___105 *, int);
	int (*write_inode)(struct inode___105 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___105 *);
	void (*evict_inode)(struct inode___105 *);
	void (*put_super)(struct super_block___104 *);
	int (*sync_fs)(struct super_block___104 *, int);
	int (*freeze_super)(struct super_block___104 *);
	int (*freeze_fs)(struct super_block___104 *);
	int (*thaw_super)(struct super_block___104 *);
	int (*unfreeze_fs)(struct super_block___104 *);
	int (*statfs)(struct dentry___104 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___104 *, int *, char *);
	void (*umount_begin)(struct super_block___104 *);
	int (*show_options)(struct seq_file___94 *, struct dentry___104 *);
	int (*show_devname)(struct seq_file___94 *, struct dentry___104 *);
	int (*show_path)(struct seq_file___94 *, struct dentry___104 *);
	int (*show_stats)(struct seq_file___94 *, struct dentry___104 *);
	ssize_t (*quota_read)(struct super_block___104 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___104 *, int, const char *, size_t, loff_t);
	struct dquot___103 ** (*get_dquots)(struct inode___105 *);
	int (*bdev_try_to_free_page)(struct super_block___104 *, struct page___104 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___104 *, struct shrink_control___36 *);
	long int (*free_cached_objects)(struct super_block___104 *, struct shrink_control___36 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___66)(struct file___104 *, wait_queue_head_t *, struct poll_table_struct___67 *);

struct poll_table_struct___67 {
	poll_queue_proc___66 _qproc;
	__poll_t _key;
};

struct seq_operations___92;

struct seq_file___94 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___92 *op;
	int poll_event;
	const struct file___104 *file;
	void *private;
};

typedef int (*key_restrict_link_func_t___99)(struct key___99 *, const struct key_type *, const union key_payload *, struct key___99 *);

struct key_restriction___99;

struct key___99 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___104 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___99 *restrict_link;
};

struct key_restriction___99 {
	key_restrict_link_func_t___99 check;
	struct key___99 *key;
	struct key_type *keytype;
};

struct seq_operations___92 {
	void * (*start)(struct seq_file___94 *, loff_t *);
	void (*stop)(struct seq_file___94 *, void *);
	void * (*next)(struct seq_file___94 *, void *, loff_t *);
	int (*show)(struct seq_file___94 *, void *);
};

struct dev_pm_info___95 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___95 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___95;

struct bus_type___95;

struct device_driver___95;

struct dev_pm_domain___95;

struct device_node___33;

struct fwnode_handle___69;

struct class___95;

struct attribute_group___94;

struct device___95 {
	struct device___95 *parent;
	struct device_private *p;
	struct kobject___98 kobj;
	const char *init_name;
	const struct device_type___95 *type;
	struct mutex mutex;
	struct bus_type___95 *bus;
	struct device_driver___95 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___95 power;
	struct dev_pm_domain___95 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___33 *of_node;
	struct fwnode_handle___69 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___95 *class;
	const struct attribute_group___94 **groups;
	void (*release)(struct device___95 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct kobj_attribute___98 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___98 *, struct kobj_attribute___98 *, char *);
	ssize_t (*store)(struct kobject___98 *, struct kobj_attribute___98 *, const char *, size_t);
};

typedef void compound_page_dtor___101(struct page___104 *);

struct kernfs_root___100;

struct kernfs_elem_dir___100 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___100 *root;
};

struct kernfs_syscall_ops___100;

struct kernfs_root___100 {
	struct kernfs_node___100 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___100 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___100 {
	struct kernfs_node___100 *target_kn;
};

struct kernfs_ops___100;

struct kernfs_elem_attr___100 {
	const struct kernfs_ops___100 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___100 *notify_next;
};

struct kernfs_node___100 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___100 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___100 dir;
		struct kernfs_elem_symlink___100 symlink;
		struct kernfs_elem_attr___100 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___100;

struct kernfs_ops___100 {
	int (*open)(struct kernfs_open_file___100 *);
	void (*release)(struct kernfs_open_file___100 *);
	int (*seq_show)(struct seq_file___94 *, void *);
	void * (*seq_start)(struct seq_file___94 *, loff_t *);
	void * (*seq_next)(struct seq_file___94 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___94 *, void *);
	ssize_t (*read)(struct kernfs_open_file___100 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___100 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___100 *, struct vm_area_struct___104 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___100 *, struct poll_table_struct___67 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___100 {
	int (*remount_fs)(struct kernfs_root___100 *, int *, char *);
	int (*show_options)(struct seq_file___94 *, struct kernfs_root___100 *);
	int (*mkdir)(struct kernfs_node___100 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___100 *);
	int (*rename)(struct kernfs_node___100 *, struct kernfs_node___100 *, const char *);
	int (*show_path)(struct seq_file___94 *, struct kernfs_node___100 *, struct kernfs_root___100 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___100 {
	struct kernfs_node___100 *kn;
	struct file___104 *file;
	struct seq_file___94 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___101 *vm_ops;
};

struct bin_attribute___94;

struct attribute_group___94 {
	const char *name;
	umode_t (*is_visible)(struct kobject___98 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___98 *, struct bin_attribute___94 *, int);
	struct attribute **attrs;
	struct bin_attribute___94 **bin_attrs;
};

struct bin_attribute___94 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___104 *, struct kobject___98 *, struct bin_attribute___94 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___104 *, struct kobject___98 *, struct bin_attribute___94 *, char *, loff_t, size_t);
	int (*mmap)(struct file___104 *, struct kobject___98 *, struct bin_attribute___94 *, struct vm_area_struct___104 *);
};

struct sysfs_ops___97 {
	ssize_t (*show)(struct kobject___98 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___98 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___97;

struct kset___97 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___98 kobj;
	const struct kset_uevent_ops___97 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___97 {
	void (*release)(struct kobject___98 *);
	const struct sysfs_ops___97 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___5 * (*child_ns_type)(struct kobject___98 *);
	const void * (*namespace)(struct kobject___98 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___97 {
	int (* const filter)(struct kset___97 *, struct kobject___98 *);
	const char * (* const name)(struct kset___97 *, struct kobject___98 *);
	int (* const uevent)(struct kset___97 *, struct kobject___98 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___84 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___84 *);
	int (*get)(char *, const struct kernel_param___84 *);
	void (*free)(void *);
};

struct kparam_array___84;

struct kernel_param___84 {
	const char *name;
	struct module___87 *mod;
	const struct kernel_param_ops___84 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___84 *arr;
	};
};

struct kparam_array___84 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___84 *ops;
	void *elem;
};

struct module_attribute___84 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___84 *, struct module_kobject___84 *, char *);
	ssize_t (*store)(struct module_attribute___84 *, struct module_kobject___84 *, const char *, size_t);
	void (*setup)(struct module___87 *, const char *);
	int (*test)(struct module___87 *);
	void (*free)(struct module___87 *);
};

struct trace_event_functions___5;

struct trace_event___5 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___5 *funcs;
};

struct trace_event_class___57;

struct trace_event_call___57 {
	struct list_head list;
	struct trace_event_class___57 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___5 event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___9 *prog_array;
	int (*perf_perm)(struct trace_event_call___57 *, struct perf_event___62 *);
};

struct cgroup_namespace___80 {
	refcount_t count;
	struct ns_common___7 ns;
	struct user_namespace___84 *user_ns;
	struct ucounts___84 *ucounts;
	struct css_set___80 *root_cset;
};

struct ucounts___84 {
	struct hlist_node node;
	struct user_namespace___84 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct fwnode_operations___69;

struct fwnode_handle___69 {
	struct fwnode_handle___69 *secondary;
	const struct fwnode_operations___69 *ops;
};

struct fwnode_reference_args___69;

struct fwnode_endpoint___69;

struct fwnode_operations___69 {
	struct fwnode_handle___69 * (*get)(struct fwnode_handle___69 *);
	void (*put)(struct fwnode_handle___69 *);
	bool (*device_is_available)(const struct fwnode_handle___69 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___69 *, const struct device___95 *);
	bool (*property_present)(const struct fwnode_handle___69 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___69 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___69 *, const char *, const char **, size_t);
	struct fwnode_handle___69 * (*get_parent)(const struct fwnode_handle___69 *);
	struct fwnode_handle___69 * (*get_next_child_node)(const struct fwnode_handle___69 *, struct fwnode_handle___69 *);
	struct fwnode_handle___69 * (*get_named_child_node)(const struct fwnode_handle___69 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___69 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___69 *);
	struct fwnode_handle___69 * (*graph_get_next_endpoint)(const struct fwnode_handle___69 *, struct fwnode_handle___69 *);
	struct fwnode_handle___69 * (*graph_get_remote_endpoint)(const struct fwnode_handle___69 *);
	struct fwnode_handle___69 * (*graph_get_port_parent)(struct fwnode_handle___69 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___69 *, struct fwnode_endpoint___69 *);
};

struct fwnode_endpoint___69 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___69 *local_fwnode;
};

struct fwnode_reference_args___69 {
	struct fwnode_handle___69 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct property___32 {
	char *name;
	int length;
	void *value;
	struct property___32 *next;
	long unsigned int _flags;
	struct bin_attribute___94 attr;
};

struct device_node___33 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___69 fwnode;
	struct property___32 *properties;
	struct property___32 *deadprops;
	struct device_node___33 *parent;
	struct device_node___33 *child;
	struct device_node___33 *sibling;
	struct kobject___98 kobj;
	long unsigned int _flags;
	void *data;
};

struct dev_pm_ops___95 {
	int (*prepare)(struct device___95 *);
	void (*complete)(struct device___95 *);
	int (*suspend)(struct device___95 *);
	int (*resume)(struct device___95 *);
	int (*freeze)(struct device___95 *);
	int (*thaw)(struct device___95 *);
	int (*poweroff)(struct device___95 *);
	int (*restore)(struct device___95 *);
	int (*suspend_late)(struct device___95 *);
	int (*resume_early)(struct device___95 *);
	int (*freeze_late)(struct device___95 *);
	int (*thaw_early)(struct device___95 *);
	int (*poweroff_late)(struct device___95 *);
	int (*restore_early)(struct device___95 *);
	int (*suspend_noirq)(struct device___95 *);
	int (*resume_noirq)(struct device___95 *);
	int (*freeze_noirq)(struct device___95 *);
	int (*thaw_noirq)(struct device___95 *);
	int (*poweroff_noirq)(struct device___95 *);
	int (*restore_noirq)(struct device___95 *);
	int (*runtime_suspend)(struct device___95 *);
	int (*runtime_resume)(struct device___95 *);
	int (*runtime_idle)(struct device___95 *);
};

struct dev_pm_domain___95 {
	struct dev_pm_ops___95 ops;
	void (*detach)(struct device___95 *, bool);
	int (*activate)(struct device___95 *);
	void (*sync)(struct device___95 *);
	void (*dismiss)(struct device___95 *);
};

struct bus_type___95 {
	const char *name;
	const char *dev_name;
	struct device___95 *dev_root;
	const struct attribute_group___94 **bus_groups;
	const struct attribute_group___94 **dev_groups;
	const struct attribute_group___94 **drv_groups;
	int (*match)(struct device___95 *, struct device_driver___95 *);
	int (*uevent)(struct device___95 *, struct kobj_uevent_env *);
	int (*probe)(struct device___95 *);
	int (*remove)(struct device___95 *);
	void (*shutdown)(struct device___95 *);
	int (*online)(struct device___95 *);
	int (*offline)(struct device___95 *);
	int (*suspend)(struct device___95 *, pm_message_t);
	int (*resume)(struct device___95 *);
	int (*num_vf)(struct device___95 *);
	int (*dma_configure)(struct device___95 *);
	const struct dev_pm_ops___95 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___95 {
	const char *name;
	struct bus_type___95 *bus;
	struct module___87 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___95 *);
	int (*remove)(struct device___95 *);
	void (*shutdown)(struct device___95 *);
	int (*suspend)(struct device___95 *, pm_message_t);
	int (*resume)(struct device___95 *);
	const struct attribute_group___94 **groups;
	const struct dev_pm_ops___95 *pm;
	void (*coredump)(struct device___95 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___95 {
	const char *name;
	const struct attribute_group___94 **groups;
	int (*uevent)(struct device___95 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___95 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___95 *);
	const struct dev_pm_ops___95 *pm;
};

struct class___95 {
	const char *name;
	struct module___87 *owner;
	const struct attribute_group___94 **class_groups;
	const struct attribute_group___94 **dev_groups;
	struct kobject___98 *dev_kobj;
	int (*dev_uevent)(struct device___95 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___95 *, umode_t *);
	void (*class_release)(struct class___95 *);
	void (*dev_release)(struct device___95 *);
	int (*shutdown_pre)(struct device___95 *);
	const struct kobj_ns_type_operations___5 *ns_type;
	const void * (*namespace)(struct device___95 *);
	const struct dev_pm_ops___95 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___81 {
	struct device___95 dev;
};

struct bpf_map___80;

struct bpf_map_ops___80 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___80 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___80 *, struct file___104 *);
	void (*map_free)(struct bpf_map___80 *);
	int (*map_get_next_key)(struct bpf_map___80 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___80 *);
	void * (*map_lookup_elem)(struct bpf_map___80 *, void *);
	int (*map_update_elem)(struct bpf_map___80 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___80 *, void *);
	int (*map_push_elem)(struct bpf_map___80 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___80 *, void *);
	int (*map_peek_elem)(struct bpf_map___80 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___80 *, struct file___104 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___80 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___80 *, void *, struct seq_file___94 *);
	int (*map_check_btf)(const struct bpf_map___80 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___80 {
	const struct bpf_map_ops___80 *ops;
	struct bpf_map___80 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___99 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___80;

typedef void (*kthread_work_func_t___80)(struct kthread_work___80 *);

struct kthread_worker___80;

struct kthread_work___80 {
	struct list_head node;
	kthread_work_func_t___80 func;
	struct kthread_worker___80 *worker;
	int canceling;
};

struct kthread_worker___80 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___104 *task;
	struct kthread_work___80 *current_work;
};

struct kthread_delayed_work___80 {
	struct kthread_work___80 work;
	struct timer_list timer;
};

struct psi_group___80 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___80 *poll_kworker;
	struct kthread_delayed_work___80 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___80 {
	struct kernfs_node___100 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___80;

struct cgroup_subsys_state___80 {
	struct cgroup___80 *cgroup;
	struct cgroup_subsys___80 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___80 *parent;
};

struct cgroup_root___80;

struct cgroup_rstat_cpu___80;

struct cgroup___80 {
	struct cgroup_subsys_state___80 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___100 *kn;
	struct cgroup_file___80 procs_file;
	struct cgroup_file___80 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___80 *subsys[13];
	struct cgroup_root___80 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___80 *dom_cgrp;
	struct cgroup_rstat_cpu___80 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___9 bpf;
	atomic_t congestion_count;
	struct cgroup___80 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___80 psi;
	int ancestor_ids[0];
};

struct cftype___80;

struct cgroup_subsys___80 {
	struct cgroup_subsys_state___80 * (*css_alloc)(struct cgroup_subsys_state___80 *);
	int (*css_online)(struct cgroup_subsys_state___80 *);
	void (*css_offline)(struct cgroup_subsys_state___80 *);
	void (*css_released)(struct cgroup_subsys_state___80 *);
	void (*css_free)(struct cgroup_subsys_state___80 *);
	void (*css_reset)(struct cgroup_subsys_state___80 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___80 *, int);
	int (*css_extra_stat_show)(struct seq_file___94 *, struct cgroup_subsys_state___80 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___104 *);
	void (*cancel_fork)(struct task_struct___104 *);
	void (*fork)(struct task_struct___104 *);
	void (*exit)(struct task_struct___104 *);
	void (*free)(struct task_struct___104 *);
	void (*bind)(struct cgroup_subsys_state___80 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___80 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___80 *dfl_cftypes;
	struct cftype___80 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___80 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___80 *updated_children;
	struct cgroup___80 *updated_next;
};

struct cgroup_root___80 {
	struct kernfs_root___100 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___80 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___80 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___80 *ss;
	struct list_head node;
	struct kernfs_ops___100 *kf_ops;
	int (*open)(struct kernfs_open_file___100 *);
	void (*release)(struct kernfs_open_file___100 *);
	u64 (*read_u64)(struct cgroup_subsys_state___80 *, struct cftype___80 *);
	s64 (*read_s64)(struct cgroup_subsys_state___80 *, struct cftype___80 *);
	int (*seq_show)(struct seq_file___94 *, void *);
	void * (*seq_start)(struct seq_file___94 *, loff_t *);
	void * (*seq_next)(struct seq_file___94 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___94 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___80 *, struct cftype___80 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___80 *, struct cftype___80 *, s64);
	ssize_t (*write)(struct kernfs_open_file___100 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___100 *, struct poll_table_struct___67 *);
};

struct perf_cpu_context___62;

struct pmu___62 {
	struct list_head entry;
	struct module___87 *module;
	struct device___95 *dev;
	const struct attribute_group___94 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___62 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___62 *);
	void (*pmu_disable)(struct pmu___62 *);
	int (*event_init)(struct perf_event___62 *);
	void (*event_mapped)(struct perf_event___62 *, struct mm_struct___103 *);
	void (*event_unmapped)(struct perf_event___62 *, struct mm_struct___103 *);
	int (*add)(struct perf_event___62 *, int);
	void (*del)(struct perf_event___62 *, int);
	void (*start)(struct perf_event___62 *, int);
	void (*stop)(struct perf_event___62 *, int);
	void (*read)(struct perf_event___62 *);
	void (*start_txn)(struct pmu___62 *, unsigned int);
	int (*commit_txn)(struct pmu___62 *);
	void (*cancel_txn)(struct pmu___62 *);
	int (*event_idx)(struct perf_event___62 *);
	void (*sched_task)(struct perf_event_context___62 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___62 *);
	int (*filter_match)(struct perf_event___62 *);
	int (*check_period)(struct perf_event___62 *, u64);
};

struct perf_cpu_context___62 {
	struct perf_event_context___62 ctx;
	struct perf_event_context___62 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___62 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___62 {
	struct cgroup_subsys_state___80 css;
	struct perf_cgroup_info *info;
};

struct trace_array___5;

struct tracer___5;

struct trace_buffer___5;

struct trace_iterator___5 {
	struct trace_array___5 *tr;
	struct tracer___5 *trace;
	struct trace_buffer___5 *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

struct trace_buffer___5 {
	struct trace_array___5 *tr;
	struct ring_buffer *buffer;
	struct trace_array_cpu *data;
	u64 time_start;
	int cpu;
};

struct trace_event_file___22;

struct trace_options___5;

struct trace_array___5 {
	struct list_head list;
	char *name;
	struct trace_buffer___5 trace_buffer;
	struct trace_buffer___5 max_buffer;
	bool allocated_snapshot;
	long unsigned int max_latency;
	struct trace_pid_list *filtered_pids;
	arch_spinlock_t max_lock;
	int buffer_disabled;
	int sys_refcount_enter;
	int sys_refcount_exit;
	struct trace_event_file___22 *enter_syscall_files[295];
	struct trace_event_file___22 *exit_syscall_files[295];
	int stop_count;
	int clock_id;
	int nr_topts;
	bool clear_trace;
	struct tracer___5 *current_trace;
	unsigned int trace_flags;
	unsigned char trace_flags_index[32];
	unsigned int flags;
	raw_spinlock_t start_lock;
	struct dentry___104 *dir;
	struct dentry___104 *options;
	struct dentry___104 *percpu_dir;
	struct dentry___104 *event_dir;
	struct trace_options___5 *topts;
	struct list_head systems;
	struct list_head events;
	struct trace_event_file___22 *trace_marker_file;
	cpumask_var_t tracing_cpumask;
	int ref;
	struct ftrace_ops *ops;
	struct trace_pid_list *function_pids;
	struct list_head func_probes;
	struct list_head mod_trace;
	struct list_head mod_notrace;
	int function_enabled;
	int time_stamp_abs_ref;
	struct list_head hist_vars;
};

struct tracer_flags___5;

struct tracer___5 {
	const char *name;
	int (*init)(struct trace_array___5 *);
	void (*reset)(struct trace_array___5 *);
	void (*start)(struct trace_array___5 *);
	void (*stop)(struct trace_array___5 *);
	int (*update_thresh)(struct trace_array___5 *);
	void (*open)(struct trace_iterator___5 *);
	void (*pipe_open)(struct trace_iterator___5 *);
	void (*close)(struct trace_iterator___5 *);
	void (*pipe_close)(struct trace_iterator___5 *);
	ssize_t (*read)(struct trace_iterator___5 *, struct file___104 *, char *, size_t, loff_t *);
	ssize_t (*splice_read)(struct trace_iterator___5 *, struct file___104 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	void (*print_header)(struct seq_file___94 *);
	enum print_line_t (*print_line)(struct trace_iterator___5 *);
	int (*set_flag)(struct trace_array___5 *, u32, u32, int);
	int (*flag_changed)(struct trace_array___5 *, u32, int);
	struct tracer___5 *next;
	struct tracer_flags___5 *flags;
	int enabled;
	int ref;
	bool print_max;
	bool allow_instances;
	bool use_max_tr;
	bool noboot;
};

typedef enum print_line_t (*trace_print_func___5)(struct trace_iterator___5 *, int, struct trace_event___5 *);

struct trace_event_functions___5 {
	trace_print_func___5 trace;
	trace_print_func___5 raw;
	trace_print_func___5 hex;
	trace_print_func___5 binary;
};

struct trace_event_class___57 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___57 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___57 *);
	struct list_head * (*get_fields)(struct trace_event_call___57 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___57 *);
};

struct trace_subsystem_dir___6;

struct trace_event_file___22 {
	struct list_head list;
	struct trace_event_call___57 *event_call;
	struct event_filter *filter;
	struct dentry___104 *dir;
	struct trace_array___5 *tr;
	struct trace_subsystem_dir___6 *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_subsystem_dir___6 {
	struct list_head list;
	struct event_subsystem *subsystem;
	struct trace_array___5 *tr;
	struct dentry___104 *entry;
	int ref_count;
	int nr_events;
};

struct trace_option_dentry___5;

struct trace_options___5 {
	struct tracer___5 *tracer;
	struct trace_option_dentry___5 *topts;
};

struct trace_option_dentry___5 {
	struct tracer_opt *opt;
	struct tracer_flags___5 *flags;
	struct trace_array___5 *tr;
	struct dentry___104 *entry;
};

struct tracer_flags___5 {
	u32 val;
	struct tracer_opt *opts;
	struct tracer___5 *trace;
};

struct trace_bprintk_fmt {
	struct list_head list;
	const char *fmt;
};

typedef int (*tracing_map_cmp_fn_t)(void *, void *);

struct tracing_map_field {
	tracing_map_cmp_fn_t cmp_fn;
	union {
		atomic64_t sum;
		unsigned int offset;
	};
};

struct tracing_map;

struct tracing_map_elt {
	struct tracing_map *map;
	struct tracing_map_field *fields;
	atomic64_t *vars;
	bool *var_set;
	void *key;
	void *private_data;
};

struct tracing_map_sort_key {
	unsigned int field_idx;
	bool descending;
};

struct tracing_map_array;

struct tracing_map_ops;

struct tracing_map {
	unsigned int key_size;
	unsigned int map_bits;
	unsigned int map_size;
	unsigned int max_elts;
	atomic_t next_elt;
	struct tracing_map_array *elts;
	struct tracing_map_array *map;
	const struct tracing_map_ops *ops;
	void *private_data;
	struct tracing_map_field fields[6];
	unsigned int n_fields;
	int key_idx[3];
	unsigned int n_keys;
	struct tracing_map_sort_key sort_key;
	unsigned int n_vars;
	atomic64_t hits;
	atomic64_t drops;
};

struct tracing_map_entry {
	u32 key;
	struct tracing_map_elt *val;
};

struct tracing_map_sort_entry {
	void *key;
	struct tracing_map_elt *elt;
	bool elt_copied;
	bool dup;
};

struct tracing_map_array {
	unsigned int entries_per_page;
	unsigned int entry_size_shift;
	unsigned int entry_shift;
	unsigned int entry_mask;
	unsigned int n_pages;
	void **pages;
};

struct tracing_map_ops {
	int (*elt_alloc)(struct tracing_map_elt *);
	void (*elt_free)(struct tracing_map_elt *);
	void (*elt_clear)(struct tracing_map_elt *);
	void (*elt_init)(struct tracing_map_elt *);
};

struct module___88;

struct file___105;

struct kiocb___105;

struct poll_table_struct___68;

struct vm_area_struct___105;

struct inode___106;

struct file_lock___105;

struct page___105;

struct seq_file___95;

struct file_operations___105 {
	struct module___88 *owner;
	loff_t (*llseek)(struct file___105 *, loff_t, int);
	ssize_t (*read)(struct file___105 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___105 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___105 *, struct iov_iter___41 *);
	ssize_t (*write_iter)(struct kiocb___105 *, struct iov_iter___41 *);
	int (*iopoll)(struct kiocb___105 *, bool);
	int (*iterate)(struct file___105 *, struct dir_context *);
	int (*iterate_shared)(struct file___105 *, struct dir_context *);
	__poll_t (*poll)(struct file___105 *, struct poll_table_struct___68 *);
	long int (*unlocked_ioctl)(struct file___105 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___105 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___105 *, struct vm_area_struct___105 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___106 *, struct file___105 *);
	int (*flush)(struct file___105 *, fl_owner_t);
	int (*release)(struct inode___106 *, struct file___105 *);
	int (*fsync)(struct file___105 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___105 *, int);
	int (*lock)(struct file___105 *, int, struct file_lock___105 *);
	ssize_t (*sendpage)(struct file___105 *, struct page___105 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___105 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___105 *, int, struct file_lock___105 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___105 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___105 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___105 *, long int, struct file_lock___105 **, void **);
	long int (*fallocate)(struct file___105 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___95 *, struct file___105 *);
	ssize_t (*copy_file_range)(struct file___105 *, loff_t, struct file___105 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___105 *, loff_t, struct file___105 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___105 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___104 {
	u64 seqnum;
	struct vm_area_struct___105 *vmas[4];
};

struct page_frag___104 {
	struct page___105 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___63;

struct debug_info___63 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___63 *hbp_break[16];
	struct perf_event___63 *hbp_watch[16];
};

struct thread_struct___63 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___63 debug;
	long: 64;
};

struct mm_struct___104;

struct pid___87;

struct cred___100;

struct nsproxy___97;

struct signal_struct___94;

struct css_set___81;

struct perf_event_context___63;

struct vm_struct___76;

struct task_struct___105 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___105 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___104 *mm;
	struct mm_struct___104 *active_mm;
	struct vmacache___104 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___105 *real_parent;
	struct task_struct___105 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___105 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___87 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___87 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___87 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___100 *ptracer_cred;
	const struct cred___100 *real_cred;
	const struct cred___100 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___97 *nsproxy;
	struct signal_struct___94 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___105 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___16 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___81 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___63 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___104 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___105 *oom_reaper_list;
	struct vm_struct___76 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___63 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___63 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___105 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___63)(struct perf_event___63 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___63;

struct fasync_struct___104;

struct pid_namespace___87;

struct trace_event_call___58;

struct perf_cgroup___63;

struct perf_event___63 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___63 *group_leader;
	struct pmu___63 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___63 hw;
	struct perf_event_context___63 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___63 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___105 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___104 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___63 *);
	struct callback_head callback_head;
	struct pid_namespace___87 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___63 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___63 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___58 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___63 *cgrp;
	struct list_head sb_list;
};

struct rw_semaphore___105 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___105 *owner;
};

struct key___100;

struct ucounts___85;

struct user_namespace___85 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___85 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___7 ns;
	long unsigned int flags;
	struct key___100 *persistent_keyring_register;
	struct rw_semaphore___105 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___85 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___105 *pgtable_t___104;

struct address_space___104;

struct dev_pagemap___102;

struct page___105 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___104 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___105 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___104 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___104 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___102 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___104;

struct lruvec___104 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___104 *pgdat;
};

struct zone___104 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___104 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___104 {
	struct zone___104 *zone;
	int zone_idx;
};

struct zonelist___104 {
	struct zoneref___104 _zonerefs[25];
};

struct pglist_data___104 {
	struct zone___104 node_zones[3];
	struct zonelist___104 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___105 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___105 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___104 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___105 {
	void *stack;
	struct task_struct___105 *task;
	long int status;
};

struct blocking_notifier_head___104 {
	struct rw_semaphore___105 rwsem;
	struct notifier_block *head;
};

struct dentry___105;

struct path___104 {
	struct vfsmount *mnt;
	struct dentry___105 *dentry;
};

struct fown_struct___87 {
	rwlock_t lock;
	struct pid___87 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___105 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___104 f_path;
	struct inode___106 *f_inode;
	const struct file_operations___105 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___87 f_owner;
	const struct cred___100 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___104 *f_mapping;
	errseq_t f_wb_err;
};

struct user_struct___100;

struct cred___100 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___100 *session_keyring;
	struct key___100 *process_keyring;
	struct key___100 *thread_keyring;
	struct key___100 *request_key_auth;
	void *security;
	struct user_struct___100 *user;
	struct user_namespace___85 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___101;

struct kernfs_elem_dir___101 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___101 *root;
};

struct kernfs_node___101;

struct kernfs_syscall_ops___101;

struct kernfs_root___101 {
	struct kernfs_node___101 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___101 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___101 {
	struct kernfs_node___101 *target_kn;
};

struct kernfs_ops___101;

struct kernfs_elem_attr___101 {
	const struct kernfs_ops___101 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___101 *notify_next;
};

struct kernfs_node___101 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___101 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___101 dir;
		struct kernfs_elem_symlink___101 symlink;
		struct kernfs_elem_attr___101 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___101;

struct kernfs_ops___101 {
	int (*open)(struct kernfs_open_file___101 *);
	void (*release)(struct kernfs_open_file___101 *);
	int (*seq_show)(struct seq_file___95 *, void *);
	void * (*seq_start)(struct seq_file___95 *, loff_t *);
	void * (*seq_next)(struct seq_file___95 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___95 *, void *);
	ssize_t (*read)(struct kernfs_open_file___101 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___101 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___101 *, struct vm_area_struct___105 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___101 *, struct poll_table_struct___68 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___101 {
	int (*remount_fs)(struct kernfs_root___101 *, int *, char *);
	int (*show_options)(struct seq_file___95 *, struct kernfs_root___101 *);
	int (*mkdir)(struct kernfs_node___101 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___101 *);
	int (*rename)(struct kernfs_node___101 *, struct kernfs_node___101 *, const char *);
	int (*show_path)(struct seq_file___95 *, struct kernfs_node___101 *, struct kernfs_root___101 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___93;

struct seq_file___95 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___93 *op;
	int poll_event;
	const struct file___105 *file;
	void *private;
};

struct vm_operations_struct___102;

struct kernfs_open_file___101 {
	struct kernfs_node___101 *kn;
	struct file___105 *file;
	struct seq_file___95 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___102 *vm_ops;
};

struct vm_fault___102;

struct vm_operations_struct___102 {
	void (*open)(struct vm_area_struct___105 *);
	void (*close)(struct vm_area_struct___105 *);
	int (*split)(struct vm_area_struct___105 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___105 *);
	vm_fault_t (*fault)(struct vm_fault___102 *);
	vm_fault_t (*huge_fault)(struct vm_fault___102 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___102 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___105 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___102 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___102 *);
	int (*access)(struct vm_area_struct___105 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___105 *);
	int (*set_policy)(struct vm_area_struct___105 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___105 *, long unsigned int);
	struct page___105 * (*find_special_page)(struct vm_area_struct___105 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___67)(struct file___105 *, wait_queue_head_t *, struct poll_table_struct___68 *);

struct poll_table_struct___68 {
	poll_queue_proc___67 _qproc;
	__poll_t _key;
};

struct vm_area_struct___105 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___105 *vm_next;
	struct vm_area_struct___105 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___104 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___102 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___105 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___99;

struct bin_attribute___95;

struct attribute_group___95 {
	const char *name;
	umode_t (*is_visible)(struct kobject___99 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___99 *, struct bin_attribute___95 *, int);
	struct attribute **attrs;
	struct bin_attribute___95 **bin_attrs;
};

struct kset___98;

struct kobj_type___98;

struct kobject___99 {
	const char *name;
	struct list_head entry;
	struct kobject___99 *parent;
	struct kset___98 *kset;
	struct kobj_type___98 *ktype;
	struct kernfs_node___101 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___95 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___105 *, struct kobject___99 *, struct bin_attribute___95 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___105 *, struct kobject___99 *, struct bin_attribute___95 *, char *, loff_t, size_t);
	int (*mmap)(struct file___105 *, struct kobject___99 *, struct bin_attribute___95 *, struct vm_area_struct___105 *);
};

struct sysfs_ops___98 {
	ssize_t (*show)(struct kobject___99 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___99 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___98;

struct kset___98 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___99 kobj;
	const struct kset_uevent_ops___98 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___98 {
	void (*release)(struct kobject___99 *);
	const struct sysfs_ops___98 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___5 * (*child_ns_type)(struct kobject___99 *);
	const void * (*namespace)(struct kobject___99 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___98 {
	int (* const filter)(struct kset___98 *, struct kobject___99 *);
	const char * (* const name)(struct kset___98 *, struct kobject___99 *);
	int (* const uevent)(struct kset___98 *, struct kobject___99 *, struct kobj_uevent_env *);
};

struct kobj_attribute___99 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___99 *, struct kobj_attribute___99 *, char *);
	ssize_t (*store)(struct kobject___99 *, struct kobj_attribute___99 *, const char *, size_t);
};

struct kernel_param___85;

struct kernel_param_ops___85 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___85 *);
	int (*get)(char *, const struct kernel_param___85 *);
	void (*free)(void *);
};

struct kparam_array___85;

struct kernel_param___85 {
	const char *name;
	struct module___88 *mod;
	const struct kernel_param_ops___85 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___85 *arr;
	};
};

struct kparam_array___85 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___85 *ops;
	void *elem;
};

struct module_kobject___85 {
	struct kobject___99 kobj;
	struct module___88 *mod;
	struct kobject___99 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___85 {
	struct module___88 *mod;
	struct latch_tree_node node;
};

struct module_layout___85 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___85 mtn;
};

struct module_attribute___85;

struct module___88 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___85 mkobj;
	struct module_attribute___85 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___99 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___85 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___85 core_layout;
	struct module_layout___85 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___58 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___85 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___85 *, struct module_kobject___85 *, char *);
	ssize_t (*store)(struct module_attribute___85 *, struct module_kobject___85 *, const char *, size_t);
	void (*setup)(struct module___88 *, const char *);
	int (*test)(struct module___88 *);
	void (*free)(struct module___88 *);
};

struct trace_event_functions___6;

struct trace_event___6 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___6 *funcs;
};

struct trace_event_class___58;

struct trace_event_call___58 {
	struct list_head list;
	struct trace_event_class___58 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___6 event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___9 *prog_array;
	int (*perf_perm)(struct trace_event_call___58 *, struct perf_event___63 *);
};

struct linux_binfmt___15;

struct core_state___104;

struct mm_struct___104 {
	struct {
		struct vm_area_struct___105 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___105 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___105 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___15 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___104 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___105 *owner;
		struct user_namespace___85 *user_ns;
		struct file___105 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___104 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___104;

struct address_space___104 {
	struct inode___106 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___105 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___104 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___102)(struct vm_area_struct___105 *, long unsigned int, const struct page___105 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___102)(struct page___105 *, void *);

struct device___96;

struct dev_pagemap___102 {
	dev_page_fault_t___102 page_fault;
	dev_page_free_t___102 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___96 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___104 {
	struct task_struct___105 *task;
	struct core_thread___104 *next;
};

struct core_state___104 {
	atomic_t nr_threads;
	struct core_thread___104 dumper;
	struct completion startup;
};

struct linux_binprm___16;

struct coredump_params___15;

struct linux_binfmt___15 {
	struct list_head lh;
	struct module___88 *module;
	int (*load_binary)(struct linux_binprm___16 *);
	int (*load_shlib)(struct file___105 *);
	int (*core_dump)(struct coredump_params___15 *);
	long unsigned int min_coredump;
};

struct vm_fault___102 {
	struct vm_area_struct___105 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___105 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___105 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___104 prealloc_pte;
};

struct upid___87 {
	int nr;
	struct pid_namespace___87 *ns;
};

struct pid_namespace___87 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___105 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___87 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___105 *proc_self;
	struct dentry___105 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___85 *user_ns;
	struct ucounts___85 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___7 ns;
};

struct pid___87 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___87 numbers[1];
};

struct user_struct___100 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___100 *uid_keyring;
	struct key___100 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cgroup_namespace___81;

struct nsproxy___97 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___87 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___81 *cgroup_ns;
};

struct signal_struct___94 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___105 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___105 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___87 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___87 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___104 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___87 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___81;

struct cgroup___81;

struct css_set___81 {
	struct cgroup_subsys_state___81 *subsys[13];
	refcount_t refcount;
	struct css_set___81 *dom_cset;
	struct cgroup___81 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___81 *mg_src_cgrp;
	struct cgroup___81 *mg_dst_cgrp;
	struct css_set___81 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___63 {
	struct pmu___63 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___105 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___63 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___76 {
	struct vm_struct___76 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___105 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___94 {
	struct task_struct___105 task;
	long unsigned int stack[8192];
};

struct dev_pm_info___96 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___96 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___96;

struct bus_type___96;

struct device_driver___96;

struct dev_pm_domain___96;

struct device_node___34;

struct fwnode_handle___70;

struct class___96;

struct device___96 {
	struct device___96 *parent;
	struct device_private *p;
	struct kobject___99 kobj;
	const char *init_name;
	const struct device_type___96 *type;
	struct mutex mutex;
	struct bus_type___96 *bus;
	struct device_driver___96 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___96 power;
	struct dev_pm_domain___96 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___34 *of_node;
	struct fwnode_handle___70 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___96 *class;
	const struct attribute_group___95 **groups;
	void (*release)(struct device___96 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___104;

struct super_block___105;

struct dentry___105 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___105 *d_parent;
	struct qstr d_name;
	struct inode___106 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___104 *d_op;
	struct super_block___105 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___104;

struct block_device___105;

struct inode___106 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___104 *i_op;
	struct super_block___105 *i_sb;
	struct address_space___104 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___105 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___105 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___104 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___105 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___104 {
	int (*d_revalidate)(struct dentry___105 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___105 *, unsigned int);
	int (*d_hash)(const struct dentry___105 *, struct qstr *);
	int (*d_compare)(const struct dentry___105 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___105 *);
	int (*d_init)(struct dentry___105 *);
	void (*d_release)(struct dentry___105 *);
	void (*d_prune)(struct dentry___105 *);
	void (*d_iput)(struct dentry___105 *, struct inode___106 *);
	char * (*d_dname)(struct dentry___105 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___104 *);
	int (*d_manage)(const struct path___104 *, bool);
	struct dentry___105 * (*d_real)(struct dentry___105 *, const struct inode___106 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___104;

struct mem_dqinfo___104 {
	struct quota_format_type___104 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___104;

struct quota_info___104 {
	unsigned int flags;
	struct rw_semaphore___105 dqio_sem;
	struct inode___106 *files[3];
	struct mem_dqinfo___104 info[3];
	const struct quota_format_ops___104 *ops[3];
};

struct rcuwait___104 {
	struct task_struct___105 *task;
};

struct percpu_rw_semaphore___104 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___105 rw_sem;
	struct rcuwait___104 writer;
	int readers_block;
};

struct sb_writers___104 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___104 rw_sem[3];
};

struct file_system_type___104;

struct super_operations___104;

struct dquot_operations___104;

struct quotactl_ops___104;

struct super_block___105 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___104 *s_type;
	const struct super_operations___104 *s_op;
	const struct dquot_operations___104 *dq_op;
	const struct quotactl_ops___104 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___105 *s_root;
	struct rw_semaphore___105 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___105 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___104 s_dquot;
	struct sb_writers___104 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___104 *s_d_op;
	int cleancache_poolid;
	struct shrinker___36 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___85 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___105 {
	struct file___105 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___105 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___105 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___105 *ia_file;
};

struct dquot___104 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___105 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___104 {
	int qf_fmt_id;
	const struct quota_format_ops___104 *qf_ops;
	struct module___88 *qf_owner;
	struct quota_format_type___104 *qf_next;
};

struct quota_format_ops___104 {
	int (*check_quota_file)(struct super_block___105 *, int);
	int (*read_file_info)(struct super_block___105 *, int);
	int (*write_file_info)(struct super_block___105 *, int);
	int (*free_file_info)(struct super_block___105 *, int);
	int (*read_dqblk)(struct dquot___104 *);
	int (*commit_dqblk)(struct dquot___104 *);
	int (*release_dqblk)(struct dquot___104 *);
	int (*get_next_id)(struct super_block___105 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___104 {
	int (*write_dquot)(struct dquot___104 *);
	struct dquot___104 * (*alloc_dquot)(struct super_block___105 *, int);
	void (*destroy_dquot)(struct dquot___104 *);
	int (*acquire_dquot)(struct dquot___104 *);
	int (*release_dquot)(struct dquot___104 *);
	int (*mark_dirty)(struct dquot___104 *);
	int (*write_info)(struct super_block___105 *, int);
	qsize_t * (*get_reserved_space)(struct inode___106 *);
	int (*get_projid)(struct inode___106 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___106 *, qsize_t *);
	int (*get_next_id)(struct super_block___105 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___104 {
	int (*quota_on)(struct super_block___105 *, int, int, const struct path___104 *);
	int (*quota_off)(struct super_block___105 *, int);
	int (*quota_enable)(struct super_block___105 *, unsigned int);
	int (*quota_disable)(struct super_block___105 *, unsigned int);
	int (*quota_sync)(struct super_block___105 *, int);
	int (*set_info)(struct super_block___105 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___105 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___105 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___105 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___105 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___105 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___104 {
	int (*writepage)(struct page___105 *, struct writeback_control___3 *);
	int (*readpage)(struct file___105 *, struct page___105 *);
	int (*writepages)(struct address_space___104 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___105 *);
	int (*readpages)(struct file___105 *, struct address_space___104 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___105 *, struct address_space___104 *, loff_t, unsigned int, unsigned int, struct page___105 **, void **);
	int (*write_end)(struct file___105 *, struct address_space___104 *, loff_t, unsigned int, unsigned int, struct page___105 *, void *);
	sector_t (*bmap)(struct address_space___104 *, sector_t);
	void (*invalidatepage)(struct page___105 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___105 *, gfp_t);
	void (*freepage)(struct page___105 *);
	ssize_t (*direct_IO)(struct kiocb___105 *, struct iov_iter___41 *);
	int (*migratepage)(struct address_space___104 *, struct page___105 *, struct page___105 *, enum migrate_mode);
	bool (*isolate_page)(struct page___105 *, isolate_mode_t);
	void (*putback_page)(struct page___105 *);
	int (*launder_page)(struct page___105 *);
	int (*is_partially_uptodate)(struct page___105 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___105 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___104 *, struct page___105 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___105 *, sector_t *);
	void (*swap_deactivate)(struct file___105 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___105 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___106 *bd_inode;
	struct super_block___105 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___105 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___104 {
	struct dentry___105 * (*lookup)(struct inode___106 *, struct dentry___105 *, unsigned int);
	const char * (*get_link)(struct dentry___105 *, struct inode___106 *, struct delayed_call *);
	int (*permission)(struct inode___106 *, int);
	struct posix_acl * (*get_acl)(struct inode___106 *, int);
	int (*readlink)(struct dentry___105 *, char *, int);
	int (*create)(struct inode___106 *, struct dentry___105 *, umode_t, bool);
	int (*link)(struct dentry___105 *, struct inode___106 *, struct dentry___105 *);
	int (*unlink)(struct inode___106 *, struct dentry___105 *);
	int (*symlink)(struct inode___106 *, struct dentry___105 *, const char *);
	int (*mkdir)(struct inode___106 *, struct dentry___105 *, umode_t);
	int (*rmdir)(struct inode___106 *, struct dentry___105 *);
	int (*mknod)(struct inode___106 *, struct dentry___105 *, umode_t, dev_t);
	int (*rename)(struct inode___106 *, struct dentry___105 *, struct inode___106 *, struct dentry___105 *, unsigned int);
	int (*setattr)(struct dentry___105 *, struct iattr___105 *);
	int (*getattr)(const struct path___104 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___105 *, char *, size_t);
	int (*fiemap)(struct inode___106 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___106 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___106 *, struct dentry___105 *, struct file___105 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___106 *, struct dentry___105 *, umode_t);
	int (*set_acl)(struct inode___106 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___104 {
	void (*fl_copy_lock)(struct file_lock___105 *, struct file_lock___105 *);
	void (*fl_release_private)(struct file_lock___105 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___104;

struct file_lock___105 {
	struct file_lock___105 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___105 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___104 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___104 *fl_ops;
	const struct lock_manager_operations___104 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___104 {
	int (*lm_compare_owner)(struct file_lock___105 *, struct file_lock___105 *);
	long unsigned int (*lm_owner_key)(struct file_lock___105 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___105 *);
	int (*lm_grant)(struct file_lock___105 *, int);
	bool (*lm_break)(struct file_lock___105 *);
	int (*lm_change)(struct file_lock___105 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___105 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___104 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___104 *fa_next;
	struct file___105 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___104 {
	const char *name;
	int fs_flags;
	struct dentry___105 * (*mount)(struct file_system_type___104 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___105 *);
	struct module___88 *owner;
	struct file_system_type___104 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___104 {
	struct inode___106 * (*alloc_inode)(struct super_block___105 *);
	void (*destroy_inode)(struct inode___106 *);
	void (*dirty_inode)(struct inode___106 *, int);
	int (*write_inode)(struct inode___106 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___106 *);
	void (*evict_inode)(struct inode___106 *);
	void (*put_super)(struct super_block___105 *);
	int (*sync_fs)(struct super_block___105 *, int);
	int (*freeze_super)(struct super_block___105 *);
	int (*freeze_fs)(struct super_block___105 *);
	int (*thaw_super)(struct super_block___105 *);
	int (*unfreeze_fs)(struct super_block___105 *);
	int (*statfs)(struct dentry___105 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___105 *, int *, char *);
	void (*umount_begin)(struct super_block___105 *);
	int (*show_options)(struct seq_file___95 *, struct dentry___105 *);
	int (*show_devname)(struct seq_file___95 *, struct dentry___105 *);
	int (*show_path)(struct seq_file___95 *, struct dentry___105 *);
	int (*show_stats)(struct seq_file___95 *, struct dentry___105 *);
	ssize_t (*quota_read)(struct super_block___105 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___105 *, int, const char *, size_t, loff_t);
	struct dquot___104 ** (*get_dquots)(struct inode___106 *);
	int (*bdev_try_to_free_page)(struct super_block___105 *, struct page___105 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___105 *, struct shrink_control___36 *);
	long int (*free_cached_objects)(struct super_block___105 *, struct shrink_control___36 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___102(struct page___105 *);

typedef int (*key_restrict_link_func_t___100)(struct key___100 *, const struct key_type *, const union key_payload *, struct key___100 *);

struct key_restriction___100;

struct key___100 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___105 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___100 *restrict_link;
};

struct key_restriction___100 {
	key_restrict_link_func_t___100 check;
	struct key___100 *key;
	struct key_type *keytype;
};

struct cgroup_namespace___81 {
	refcount_t count;
	struct ns_common___7 ns;
	struct user_namespace___85 *user_ns;
	struct ucounts___85 *ucounts;
	struct css_set___81 *root_cset;
};

struct ucounts___85 {
	struct hlist_node node;
	struct user_namespace___85 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct linux_binprm___16 {
	char buf[256];
	struct vm_area_struct___105 *vma;
	long unsigned int vma_pages;
	struct mm_struct___104 *mm;
	long unsigned int p;
	unsigned int called_set_creds: 1;
	unsigned int cap_elevated: 1;
	unsigned int secureexec: 1;
	unsigned int recursion_depth;
	struct file___105 *file;
	struct cred___100 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
};

struct coredump_params___15 {
	union {
		const kernel_siginfo_t *siginfo;
		struct {
			const siginfo_t *siginfo;
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	struct pt_regs *regs;
	struct file___105 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
};

struct fwnode_operations___70;

struct fwnode_handle___70 {
	struct fwnode_handle___70 *secondary;
	const struct fwnode_operations___70 *ops;
};

struct fwnode_reference_args___70;

struct fwnode_endpoint___70;

struct fwnode_operations___70 {
	struct fwnode_handle___70 * (*get)(struct fwnode_handle___70 *);
	void (*put)(struct fwnode_handle___70 *);
	bool (*device_is_available)(const struct fwnode_handle___70 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___70 *, const struct device___96 *);
	bool (*property_present)(const struct fwnode_handle___70 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___70 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___70 *, const char *, const char **, size_t);
	struct fwnode_handle___70 * (*get_parent)(const struct fwnode_handle___70 *);
	struct fwnode_handle___70 * (*get_next_child_node)(const struct fwnode_handle___70 *, struct fwnode_handle___70 *);
	struct fwnode_handle___70 * (*get_named_child_node)(const struct fwnode_handle___70 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___70 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___70 *);
	struct fwnode_handle___70 * (*graph_get_next_endpoint)(const struct fwnode_handle___70 *, struct fwnode_handle___70 *);
	struct fwnode_handle___70 * (*graph_get_remote_endpoint)(const struct fwnode_handle___70 *);
	struct fwnode_handle___70 * (*graph_get_port_parent)(struct fwnode_handle___70 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___70 *, struct fwnode_endpoint___70 *);
};

struct fwnode_endpoint___70 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___70 *local_fwnode;
};

struct fwnode_reference_args___70 {
	struct fwnode_handle___70 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct property___33 {
	char *name;
	int length;
	void *value;
	struct property___33 *next;
	long unsigned int _flags;
	struct bin_attribute___95 attr;
};

struct device_node___34 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___70 fwnode;
	struct property___33 *properties;
	struct property___33 *deadprops;
	struct device_node___34 *parent;
	struct device_node___34 *child;
	struct device_node___34 *sibling;
	struct kobject___99 kobj;
	long unsigned int _flags;
	void *data;
};

struct seq_operations___93 {
	void * (*start)(struct seq_file___95 *, loff_t *);
	void (*stop)(struct seq_file___95 *, void *);
	void * (*next)(struct seq_file___95 *, void *, loff_t *);
	int (*show)(struct seq_file___95 *, void *);
};

struct dev_pm_ops___96 {
	int (*prepare)(struct device___96 *);
	void (*complete)(struct device___96 *);
	int (*suspend)(struct device___96 *);
	int (*resume)(struct device___96 *);
	int (*freeze)(struct device___96 *);
	int (*thaw)(struct device___96 *);
	int (*poweroff)(struct device___96 *);
	int (*restore)(struct device___96 *);
	int (*suspend_late)(struct device___96 *);
	int (*resume_early)(struct device___96 *);
	int (*freeze_late)(struct device___96 *);
	int (*thaw_early)(struct device___96 *);
	int (*poweroff_late)(struct device___96 *);
	int (*restore_early)(struct device___96 *);
	int (*suspend_noirq)(struct device___96 *);
	int (*resume_noirq)(struct device___96 *);
	int (*freeze_noirq)(struct device___96 *);
	int (*thaw_noirq)(struct device___96 *);
	int (*poweroff_noirq)(struct device___96 *);
	int (*restore_noirq)(struct device___96 *);
	int (*runtime_suspend)(struct device___96 *);
	int (*runtime_resume)(struct device___96 *);
	int (*runtime_idle)(struct device___96 *);
};

struct dev_pm_domain___96 {
	struct dev_pm_ops___96 ops;
	void (*detach)(struct device___96 *, bool);
	int (*activate)(struct device___96 *);
	void (*sync)(struct device___96 *);
	void (*dismiss)(struct device___96 *);
};

struct bus_type___96 {
	const char *name;
	const char *dev_name;
	struct device___96 *dev_root;
	const struct attribute_group___95 **bus_groups;
	const struct attribute_group___95 **dev_groups;
	const struct attribute_group___95 **drv_groups;
	int (*match)(struct device___96 *, struct device_driver___96 *);
	int (*uevent)(struct device___96 *, struct kobj_uevent_env *);
	int (*probe)(struct device___96 *);
	int (*remove)(struct device___96 *);
	void (*shutdown)(struct device___96 *);
	int (*online)(struct device___96 *);
	int (*offline)(struct device___96 *);
	int (*suspend)(struct device___96 *, pm_message_t);
	int (*resume)(struct device___96 *);
	int (*num_vf)(struct device___96 *);
	int (*dma_configure)(struct device___96 *);
	const struct dev_pm_ops___96 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___96 {
	const char *name;
	struct bus_type___96 *bus;
	struct module___88 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___96 *);
	int (*remove)(struct device___96 *);
	void (*shutdown)(struct device___96 *);
	int (*suspend)(struct device___96 *, pm_message_t);
	int (*resume)(struct device___96 *);
	const struct attribute_group___95 **groups;
	const struct dev_pm_ops___96 *pm;
	void (*coredump)(struct device___96 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___96 {
	const char *name;
	const struct attribute_group___95 **groups;
	int (*uevent)(struct device___96 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___96 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___96 *);
	const struct dev_pm_ops___96 *pm;
};

struct class___96 {
	const char *name;
	struct module___88 *owner;
	const struct attribute_group___95 **class_groups;
	const struct attribute_group___95 **dev_groups;
	struct kobject___99 *dev_kobj;
	int (*dev_uevent)(struct device___96 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___96 *, umode_t *);
	void (*class_release)(struct class___96 *);
	void (*dev_release)(struct device___96 *);
	int (*shutdown_pre)(struct device___96 *);
	const struct kobj_ns_type_operations___5 *ns_type;
	const void * (*namespace)(struct device___96 *);
	const struct dev_pm_ops___96 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___82 {
	struct device___96 dev;
};

struct bpf_map___81;

struct bpf_map_ops___81 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___81 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___81 *, struct file___105 *);
	void (*map_free)(struct bpf_map___81 *);
	int (*map_get_next_key)(struct bpf_map___81 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___81 *);
	void * (*map_lookup_elem)(struct bpf_map___81 *, void *);
	int (*map_update_elem)(struct bpf_map___81 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___81 *, void *);
	int (*map_push_elem)(struct bpf_map___81 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___81 *, void *);
	int (*map_peek_elem)(struct bpf_map___81 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___81 *, struct file___105 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___81 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___81 *, void *, struct seq_file___95 *);
	int (*map_check_btf)(const struct bpf_map___81 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___81 {
	const struct bpf_map_ops___81 *ops;
	struct bpf_map___81 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___100 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___81;

typedef void (*kthread_work_func_t___81)(struct kthread_work___81 *);

struct kthread_worker___81;

struct kthread_work___81 {
	struct list_head node;
	kthread_work_func_t___81 func;
	struct kthread_worker___81 *worker;
	int canceling;
};

struct kthread_worker___81 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___105 *task;
	struct kthread_work___81 *current_work;
};

struct kthread_delayed_work___81 {
	struct kthread_work___81 work;
	struct timer_list timer;
};

struct psi_group___81 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___81 *poll_kworker;
	struct kthread_delayed_work___81 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___81 {
	struct kernfs_node___101 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___81;

struct cgroup_subsys_state___81 {
	struct cgroup___81 *cgroup;
	struct cgroup_subsys___81 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___81 *parent;
};

struct cgroup_root___81;

struct cgroup_rstat_cpu___81;

struct cgroup___81 {
	struct cgroup_subsys_state___81 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___101 *kn;
	struct cgroup_file___81 procs_file;
	struct cgroup_file___81 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___81 *subsys[13];
	struct cgroup_root___81 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___81 *dom_cgrp;
	struct cgroup_rstat_cpu___81 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___9 bpf;
	atomic_t congestion_count;
	struct cgroup___81 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___81 psi;
	int ancestor_ids[0];
};

struct cftype___81;

struct cgroup_subsys___81 {
	struct cgroup_subsys_state___81 * (*css_alloc)(struct cgroup_subsys_state___81 *);
	int (*css_online)(struct cgroup_subsys_state___81 *);
	void (*css_offline)(struct cgroup_subsys_state___81 *);
	void (*css_released)(struct cgroup_subsys_state___81 *);
	void (*css_free)(struct cgroup_subsys_state___81 *);
	void (*css_reset)(struct cgroup_subsys_state___81 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___81 *, int);
	int (*css_extra_stat_show)(struct seq_file___95 *, struct cgroup_subsys_state___81 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___105 *);
	void (*cancel_fork)(struct task_struct___105 *);
	void (*fork)(struct task_struct___105 *);
	void (*exit)(struct task_struct___105 *);
	void (*free)(struct task_struct___105 *);
	void (*bind)(struct cgroup_subsys_state___81 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___81 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___81 *dfl_cftypes;
	struct cftype___81 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___81 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___81 *updated_children;
	struct cgroup___81 *updated_next;
};

struct cgroup_root___81 {
	struct kernfs_root___101 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___81 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___81 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___81 *ss;
	struct list_head node;
	struct kernfs_ops___101 *kf_ops;
	int (*open)(struct kernfs_open_file___101 *);
	void (*release)(struct kernfs_open_file___101 *);
	u64 (*read_u64)(struct cgroup_subsys_state___81 *, struct cftype___81 *);
	s64 (*read_s64)(struct cgroup_subsys_state___81 *, struct cftype___81 *);
	int (*seq_show)(struct seq_file___95 *, void *);
	void * (*seq_start)(struct seq_file___95 *, loff_t *);
	void * (*seq_next)(struct seq_file___95 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___95 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___81 *, struct cftype___81 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___81 *, struct cftype___81 *, s64);
	ssize_t (*write)(struct kernfs_open_file___101 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___101 *, struct poll_table_struct___68 *);
};

struct perf_cpu_context___63;

struct pmu___63 {
	struct list_head entry;
	struct module___88 *module;
	struct device___96 *dev;
	const struct attribute_group___95 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___63 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___63 *);
	void (*pmu_disable)(struct pmu___63 *);
	int (*event_init)(struct perf_event___63 *);
	void (*event_mapped)(struct perf_event___63 *, struct mm_struct___104 *);
	void (*event_unmapped)(struct perf_event___63 *, struct mm_struct___104 *);
	int (*add)(struct perf_event___63 *, int);
	void (*del)(struct perf_event___63 *, int);
	void (*start)(struct perf_event___63 *, int);
	void (*stop)(struct perf_event___63 *, int);
	void (*read)(struct perf_event___63 *);
	void (*start_txn)(struct pmu___63 *, unsigned int);
	int (*commit_txn)(struct pmu___63 *);
	void (*cancel_txn)(struct pmu___63 *);
	int (*event_idx)(struct perf_event___63 *);
	void (*sched_task)(struct perf_event_context___63 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___63 *);
	int (*filter_match)(struct perf_event___63 *);
	int (*check_period)(struct perf_event___63 *, u64);
};

struct perf_cpu_context___63 {
	struct perf_event_context___63 ctx;
	struct perf_event_context___63 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___63 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___63 {
	struct cgroup_subsys_state___81 css;
	struct perf_cgroup_info *info;
};

struct trace_array___6;

struct tracer___6;

struct trace_buffer___6;

struct trace_iterator___6 {
	struct trace_array___6 *tr;
	struct tracer___6 *trace;
	struct trace_buffer___6 *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

struct trace_buffer___6 {
	struct trace_array___6 *tr;
	struct ring_buffer *buffer;
	struct trace_array_cpu *data;
	u64 time_start;
	int cpu;
};

struct trace_event_file___23;

struct trace_options___6;

struct trace_array___6 {
	struct list_head list;
	char *name;
	struct trace_buffer___6 trace_buffer;
	struct trace_buffer___6 max_buffer;
	bool allocated_snapshot;
	long unsigned int max_latency;
	struct trace_pid_list *filtered_pids;
	arch_spinlock_t max_lock;
	int buffer_disabled;
	int sys_refcount_enter;
	int sys_refcount_exit;
	struct trace_event_file___23 *enter_syscall_files[295];
	struct trace_event_file___23 *exit_syscall_files[295];
	int stop_count;
	int clock_id;
	int nr_topts;
	bool clear_trace;
	struct tracer___6 *current_trace;
	unsigned int trace_flags;
	unsigned char trace_flags_index[32];
	unsigned int flags;
	raw_spinlock_t start_lock;
	struct dentry___105 *dir;
	struct dentry___105 *options;
	struct dentry___105 *percpu_dir;
	struct dentry___105 *event_dir;
	struct trace_options___6 *topts;
	struct list_head systems;
	struct list_head events;
	struct trace_event_file___23 *trace_marker_file;
	cpumask_var_t tracing_cpumask;
	int ref;
	struct ftrace_ops *ops;
	struct trace_pid_list *function_pids;
	struct list_head func_probes;
	struct list_head mod_trace;
	struct list_head mod_notrace;
	int function_enabled;
	int time_stamp_abs_ref;
	struct list_head hist_vars;
};

struct tracer_flags___6;

struct tracer___6 {
	const char *name;
	int (*init)(struct trace_array___6 *);
	void (*reset)(struct trace_array___6 *);
	void (*start)(struct trace_array___6 *);
	void (*stop)(struct trace_array___6 *);
	int (*update_thresh)(struct trace_array___6 *);
	void (*open)(struct trace_iterator___6 *);
	void (*pipe_open)(struct trace_iterator___6 *);
	void (*close)(struct trace_iterator___6 *);
	void (*pipe_close)(struct trace_iterator___6 *);
	ssize_t (*read)(struct trace_iterator___6 *, struct file___105 *, char *, size_t, loff_t *);
	ssize_t (*splice_read)(struct trace_iterator___6 *, struct file___105 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	void (*print_header)(struct seq_file___95 *);
	enum print_line_t (*print_line)(struct trace_iterator___6 *);
	int (*set_flag)(struct trace_array___6 *, u32, u32, int);
	int (*flag_changed)(struct trace_array___6 *, u32, int);
	struct tracer___6 *next;
	struct tracer_flags___6 *flags;
	int enabled;
	int ref;
	bool print_max;
	bool allow_instances;
	bool use_max_tr;
	bool noboot;
};

typedef enum print_line_t (*trace_print_func___6)(struct trace_iterator___6 *, int, struct trace_event___6 *);

struct trace_event_functions___6 {
	trace_print_func___6 trace;
	trace_print_func___6 raw;
	trace_print_func___6 hex;
	trace_print_func___6 binary;
};

struct trace_event_class___58 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___58 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___58 *);
	struct list_head * (*get_fields)(struct trace_event_call___58 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___58 *);
};

struct trace_subsystem_dir___7;

struct trace_event_file___23 {
	struct list_head list;
	struct trace_event_call___58 *event_call;
	struct event_filter *filter;
	struct dentry___105 *dir;
	struct trace_array___6 *tr;
	struct trace_subsystem_dir___7 *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_subsystem_dir___7 {
	struct list_head list;
	struct event_subsystem *subsystem;
	struct trace_array___6 *tr;
	struct dentry___105 *entry;
	int ref_count;
	int nr_events;
};

struct trace_option_dentry___6;

struct trace_options___6 {
	struct tracer___6 *tracer;
	struct trace_option_dentry___6 *topts;
};

struct trace_option_dentry___6 {
	struct tracer_opt *opt;
	struct tracer_flags___6 *flags;
	struct trace_array___6 *tr;
	struct dentry___105 *entry;
};

struct tracer_flags___6 {
	u32 val;
	struct tracer_opt *opts;
	struct tracer___6 *trace;
};

struct ftrace_func_command___3 {
	struct list_head list;
	char *name;
	int (*func)(struct trace_array___5 *, struct ftrace_hash *, char *, char *, char *, int);
};

struct ftrace_probe_ops___3 {
	void (*func)(long unsigned int, long unsigned int, struct trace_array___5 *, struct ftrace_probe_ops___3 *, void *);
	int (*init)(struct ftrace_probe_ops___3 *, struct trace_array___5 *, long unsigned int, void *, void **);
	void (*free)(struct ftrace_probe_ops___3 *, struct trace_array___5 *, long unsigned int, void *);
	int (*print)(struct seq_file___94 *, long unsigned int, struct ftrace_probe_ops___3 *, void *);
};

enum {
	TRACE_FUNC_OPT_STACK = 1,
};

struct hwlat_sample {
	u64 seqnum;
	u64 duration;
	u64 outer_duration;
	u64 nmi_total_ts;
	struct timespec64 timestamp;
	int nmi_count;
};

struct hwlat_data {
	struct mutex lock;
	u64 count;
	u64 sample_window;
	u64 sample_width;
};

enum {
	TRACE_NOP_OPT_ACCEPT = 1,
	TRACE_NOP_OPT_REFUSE = 2,
};

struct ftrace_graph_ent_entry {
	struct trace_entry ent;
	struct ftrace_graph_ent graph_ent;
} __attribute__((packed));

struct ftrace_graph_ret_entry {
	struct trace_entry ent;
	struct ftrace_graph_ret ret;
} __attribute__((packed));

struct fgraph_cpu_data {
	pid_t last_pid;
	int depth;
	int depth_irq;
	int ignore;
	long unsigned int enter_funcs[50];
};

struct fgraph_data {
	struct fgraph_cpu_data *cpu_data;
	struct ftrace_graph_ent_entry ent;
	struct ftrace_graph_ret_entry ret;
	int failed;
	int cpu;
} __attribute__((packed));

enum {
	FLAGS_FILL_FULL = 268435456,
	FLAGS_FILL_START = 536870912,
	FLAGS_FILL_END = 805306368,
};

struct module___89;

struct file___106;

struct kiocb___106;

struct iov_iter___42;

struct poll_table_struct___69;

struct vm_area_struct___106;

struct inode___107;

struct file_lock___106;

struct page___106;

struct seq_file___96;

struct file_operations___106 {
	struct module___89 *owner;
	loff_t (*llseek)(struct file___106 *, loff_t, int);
	ssize_t (*read)(struct file___106 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___106 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___106 *, struct iov_iter___42 *);
	ssize_t (*write_iter)(struct kiocb___106 *, struct iov_iter___42 *);
	int (*iopoll)(struct kiocb___106 *, bool);
	int (*iterate)(struct file___106 *, struct dir_context *);
	int (*iterate_shared)(struct file___106 *, struct dir_context *);
	__poll_t (*poll)(struct file___106 *, struct poll_table_struct___69 *);
	long int (*unlocked_ioctl)(struct file___106 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___106 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___106 *, struct vm_area_struct___106 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___107 *, struct file___106 *);
	int (*flush)(struct file___106 *, fl_owner_t);
	int (*release)(struct inode___107 *, struct file___106 *);
	int (*fsync)(struct file___106 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___106 *, int);
	int (*lock)(struct file___106 *, int, struct file_lock___106 *);
	ssize_t (*sendpage)(struct file___106 *, struct page___106 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___106 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___106 *, int, struct file_lock___106 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___106 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___106 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___106 *, long int, struct file_lock___106 **, void **);
	long int (*fallocate)(struct file___106 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___96 *, struct file___106 *);
	ssize_t (*copy_file_range)(struct file___106 *, loff_t, struct file___106 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___106 *, loff_t, struct file___106 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___106 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___105 {
	u64 seqnum;
	struct vm_area_struct___106 *vmas[4];
};

struct page_frag___105 {
	struct page___106 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___64;

struct debug_info___64 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___64 *hbp_break[16];
	struct perf_event___64 *hbp_watch[16];
};

struct thread_struct___64 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___64 debug;
	long: 64;
};

struct mm_struct___105;

struct pid___88;

struct cred___101;

struct nsproxy___98;

struct signal_struct___95;

struct bio_list___41;

struct backing_dev_info___41;

struct io_context___17;

struct css_set___82;

struct perf_event_context___64;

struct request_queue___18;

struct vm_struct___77;

struct task_struct___106 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___106 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___105 *mm;
	struct mm_struct___105 *active_mm;
	struct vmacache___105 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___106 *real_parent;
	struct task_struct___106 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___106 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___88 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___88 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___88 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___101 *ptracer_cred;
	const struct cred___101 *real_cred;
	const struct cred___101 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___98 *nsproxy;
	struct signal_struct___95 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___106 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___41 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___41 *backing_dev_info;
	struct io_context___17 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___82 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___64 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___105 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___18 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___106 *oom_reaper_list;
	struct vm_struct___77 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___64 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___64 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___106 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___64)(struct perf_event___64 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___64;

struct fasync_struct___105;

struct pid_namespace___88;

struct trace_event_call___59;

struct perf_cgroup___64;

struct perf_event___64 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___64 *group_leader;
	struct pmu___64 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___64 hw;
	struct perf_event_context___64 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___64 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___106 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___105 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___64 *);
	struct callback_head callback_head;
	struct pid_namespace___88 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___64 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___64 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___59 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___64 *cgrp;
	struct list_head sb_list;
};

struct upid___88 {
	int nr;
	struct pid_namespace___88 *ns;
};

struct dentry___106;

struct user_namespace___86;

struct ucounts___86;

struct pid_namespace___88 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___106 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___88 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___106 *proc_self;
	struct dentry___106 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___86 *user_ns;
	struct ucounts___86 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___7 ns;
};

struct pid___88 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___88 numbers[1];
};

struct rw_semaphore___106 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___106 *owner;
};

struct key___101;

struct user_namespace___86 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___86 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___7 ns;
	long unsigned int flags;
	struct key___101 *persistent_keyring_register;
	struct rw_semaphore___106 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___86 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct secondary_data___106 {
	void *stack;
	struct task_struct___106 *task;
	long int status;
};

typedef struct page___106 *pgtable_t___105;

struct address_space___105;

struct dev_pagemap___103;

struct page___106 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___105 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___106 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___105 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___105 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___103 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct user_struct___101 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___101 *uid_keyring;
	struct key___101 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___103;

struct vm_area_struct___106 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___106 *vm_next;
	struct vm_area_struct___106 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___105 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___103 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___106 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___105;

struct mm_struct___105 {
	struct {
		struct vm_area_struct___106 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___106 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___106 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___105 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___106 *owner;
		struct user_namespace___86 *user_ns;
		struct file___106 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___105 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___101 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___101 *session_keyring;
	struct key___101 *process_keyring;
	struct key___101 *thread_keyring;
	struct key___101 *request_key_auth;
	void *security;
	struct user_struct___101 *user;
	struct user_namespace___86 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___82;

struct nsproxy___98 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___88 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___82 *cgroup_ns;
};

struct signal_struct___95 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___106 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___106 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___88 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___88 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___105 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___88 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide49;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___41;

struct bio_list___41 {
	struct bio___41 *head;
	struct bio___41 *tail;
};

struct bdi_writeback_congested___41;

struct cgroup_subsys_state___82;

struct bdi_writeback___41 {
	struct backing_dev_info___41 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___41 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___82 *memcg_css;
	struct cgroup_subsys_state___82 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___97;

struct backing_dev_info___41 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___41 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___97 *dev;
	struct device___97 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___106 *debug_dir;
	struct dentry___106 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___17;

struct io_context___17 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___17 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___82;

struct css_set___82 {
	struct cgroup_subsys_state___82 *subsys[13];
	refcount_t refcount;
	struct css_set___82 *dom_cset;
	struct cgroup___82 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___82 *mg_src_cgrp;
	struct cgroup___82 *mg_dst_cgrp;
	struct css_set___82 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___64 {
	struct pmu___64 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___106 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___64 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

typedef blk_qc_t make_request_fn___17(struct request_queue___18 *, struct bio___41 *);

struct request___18;

typedef int dma_drain_needed_fn___17(struct request___18 *);

struct kset___99;

struct kobj_type___99;

struct kernfs_node___102;

struct kobject___100 {
	const char *name;
	struct list_head entry;
	struct kobject___100 *parent;
	struct kset___99 *kset;
	struct kobj_type___99 *ktype;
	struct kernfs_node___102 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___17;

struct bsg_class_device___17 {
	struct device___97 *class_dev;
	int minor;
	struct request_queue___18 *queue;
	const struct bsg_ops___17 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___41 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___41 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___17;

struct blk_mq_ops___2;

struct blk_mq_ctx___2;

struct blk_stat_callback___2;

struct blkcg_gq___10;

struct blk_trace___2;

struct blk_flush_queue___2;

struct blk_mq_tag_set___2;

struct request_queue___18 {
	struct list_head queue_head;
	struct request___18 *last_merge;
	struct elevator_queue___17 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___17 *make_request_fn;
	dma_drain_needed_fn___17 *dma_drain_needed;
	const struct blk_mq_ops___2 *mq_ops;
	struct blk_mq_ctx___2 *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___41 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___100 kobj;
	struct kobject___100 *mq_kobj;
	struct blk_integrity integrity;
	struct device___97 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback___2 *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___10 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace___2 *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue___2 *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	struct bsg_class_device___17 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set___2 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___41 bio_split;
	struct dentry___106 *debugfs_dir;
	struct dentry___106 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___77 {
	struct vm_struct___77 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___106 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___95 {
	struct task_struct___106 task;
	long unsigned int stack[8192];
};

struct pglist_data___105;

struct lruvec___105 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___105 *pgdat;
};

struct zone___105 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___105 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___105 {
	struct zone___105 *zone;
	int zone_idx;
};

struct zonelist___105 {
	struct zoneref___105 _zonerefs[25];
};

struct pglist_data___105 {
	struct zone___105 node_zones[3];
	struct zonelist___105 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___106 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___106 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___105 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___105 {
	struct rw_semaphore___106 rwsem;
	struct notifier_block *head;
};

struct bio_vec___41 {
	struct page___106 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

typedef void bio_end_io_t___41(struct bio___41 *);

struct gendisk___18;

struct bio_integrity_payload___41;

struct bio___41 {
	struct bio___41 *bi_next;
	struct gendisk___18 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___41 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___10 *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___41 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___41 *bi_io_vec;
	struct bio_set___41 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___41 bi_inline_vecs[0];
};

struct bio_integrity_payload___41 {
	struct bio___41 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___41 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___41 bip_inline_vecs[0];
};

struct dev_pm_info___97 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___97 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___97;

struct bus_type___97;

struct device_driver___97;

struct dev_pm_domain___97;

struct device_node___35;

struct fwnode_handle___71;

struct class___97;

struct attribute_group___96;

struct device___97 {
	struct device___97 *parent;
	struct device_private *p;
	struct kobject___100 kobj;
	const char *init_name;
	const struct device_type___97 *type;
	struct mutex mutex;
	struct bus_type___97 *bus;
	struct device_driver___97 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___97 power;
	struct dev_pm_domain___97 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___35 *of_node;
	struct fwnode_handle___71 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___97 *class;
	const struct attribute_group___96 **groups;
	void (*release)(struct device___97 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___18 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___97 __dev;
	struct kobject___100 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___18;

struct block_device_operations___18;

struct gendisk___18 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___18 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___18 *part_tbl;
	struct hd_struct___18 part0;
	const struct block_device_operations___18 *fops;
	struct request_queue___18 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___106 lookup_sem;
	struct kobject___100 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___100 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct blkcg___10;

struct blkg_policy_data___10;

struct blkcg_gq___10 {
	struct request_queue___18 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___10 *blkcg;
	struct bdi_writeback_congested___41 *wb_congested;
	struct blkcg_gq___10 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_rwstat stat_bytes;
	struct blkg_rwstat stat_ios;
	struct blkg_policy_data___10 *pd[5];
	struct callback_head callback_head;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
};

typedef __u32 blk_mq_req_flags_t;

struct dev_pm_ops___97;

struct device_type___97 {
	const char *name;
	const struct attribute_group___96 **groups;
	int (*uevent)(struct device___97 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___97 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___97 *);
	const struct dev_pm_ops___97 *pm;
};

struct class___97 {
	const char *name;
	struct module___89 *owner;
	const struct attribute_group___96 **class_groups;
	const struct attribute_group___96 **dev_groups;
	struct kobject___100 *dev_kobj;
	int (*dev_uevent)(struct device___97 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___97 *, umode_t *);
	void (*class_release)(struct class___97 *);
	void (*dev_release)(struct device___97 *);
	int (*shutdown_pre)(struct device___97 *);
	const struct kobj_ns_type_operations___5 *ns_type;
	const void * (*namespace)(struct device___97 *);
	const struct dev_pm_ops___97 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct kernfs_root___102;

struct kernfs_elem_dir___102 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___102 *root;
};

struct kernfs_syscall_ops___102;

struct kernfs_root___102 {
	struct kernfs_node___102 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___102 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___102 {
	struct kernfs_node___102 *target_kn;
};

struct kernfs_ops___102;

struct kernfs_elem_attr___102 {
	const struct kernfs_ops___102 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___102 *notify_next;
};

struct kernfs_node___102 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___102 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___102 dir;
		struct kernfs_elem_symlink___102 symlink;
		struct kernfs_elem_attr___102 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___102;

struct kernfs_ops___102 {
	int (*open)(struct kernfs_open_file___102 *);
	void (*release)(struct kernfs_open_file___102 *);
	int (*seq_show)(struct seq_file___96 *, void *);
	void * (*seq_start)(struct seq_file___96 *, loff_t *);
	void * (*seq_next)(struct seq_file___96 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___96 *, void *);
	ssize_t (*read)(struct kernfs_open_file___102 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___102 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___102 *, struct vm_area_struct___106 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___102 *, struct poll_table_struct___69 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___102 {
	int (*remount_fs)(struct kernfs_root___102 *, int *, char *);
	int (*show_options)(struct seq_file___96 *, struct kernfs_root___102 *);
	int (*mkdir)(struct kernfs_node___102 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___102 *);
	int (*rename)(struct kernfs_node___102 *, struct kernfs_node___102 *, const char *);
	int (*show_path)(struct seq_file___96 *, struct kernfs_node___102 *, struct kernfs_root___102 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___94;

struct seq_file___96 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___94 *op;
	int poll_event;
	const struct file___106 *file;
	void *private;
};

struct kernfs_open_file___102 {
	struct kernfs_node___102 *kn;
	struct file___106 *file;
	struct seq_file___96 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___103 *vm_ops;
};

struct path___105 {
	struct vfsmount *mnt;
	struct dentry___106 *dentry;
};

struct fown_struct___88 {
	rwlock_t lock;
	struct pid___88 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___106 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___105 f_path;
	struct inode___107 *f_inode;
	const struct file_operations___106 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___88 f_owner;
	const struct cred___101 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___105 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___103;

struct vm_operations_struct___103 {
	void (*open)(struct vm_area_struct___106 *);
	void (*close)(struct vm_area_struct___106 *);
	int (*split)(struct vm_area_struct___106 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___106 *);
	vm_fault_t (*fault)(struct vm_fault___103 *);
	vm_fault_t (*huge_fault)(struct vm_fault___103 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___103 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___106 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___103 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___103 *);
	int (*access)(struct vm_area_struct___106 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___106 *);
	int (*set_policy)(struct vm_area_struct___106 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___106 *, long unsigned int);
	struct page___106 * (*find_special_page)(struct vm_area_struct___106 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___68)(struct file___106 *, wait_queue_head_t *, struct poll_table_struct___69 *);

struct poll_table_struct___69 {
	poll_queue_proc___68 _qproc;
	__poll_t _key;
};

struct bin_attribute___96;

struct attribute_group___96 {
	const char *name;
	umode_t (*is_visible)(struct kobject___100 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___100 *, struct bin_attribute___96 *, int);
	struct attribute **attrs;
	struct bin_attribute___96 **bin_attrs;
};

struct bin_attribute___96 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___106 *, struct kobject___100 *, struct bin_attribute___96 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___106 *, struct kobject___100 *, struct bin_attribute___96 *, char *, loff_t, size_t);
	int (*mmap)(struct file___106 *, struct kobject___100 *, struct bin_attribute___96 *, struct vm_area_struct___106 *);
};

struct sysfs_ops___99 {
	ssize_t (*show)(struct kobject___100 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___100 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___99;

struct kset___99 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___100 kobj;
	const struct kset_uevent_ops___99 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___99 {
	void (*release)(struct kobject___100 *);
	const struct sysfs_ops___99 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___5 * (*child_ns_type)(struct kobject___100 *);
	const void * (*namespace)(struct kobject___100 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___99 {
	int (* const filter)(struct kset___99 *, struct kobject___100 *);
	const char * (* const name)(struct kset___99 *, struct kobject___100 *);
	int (* const uevent)(struct kset___99 *, struct kobject___100 *, struct kobj_uevent_env *);
};

struct kobj_attribute___100 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___100 *, struct kobj_attribute___100 *, char *);
	ssize_t (*store)(struct kobject___100 *, struct kobj_attribute___100 *, const char *, size_t);
};

struct dev_pm_ops___97 {
	int (*prepare)(struct device___97 *);
	void (*complete)(struct device___97 *);
	int (*suspend)(struct device___97 *);
	int (*resume)(struct device___97 *);
	int (*freeze)(struct device___97 *);
	int (*thaw)(struct device___97 *);
	int (*poweroff)(struct device___97 *);
	int (*restore)(struct device___97 *);
	int (*suspend_late)(struct device___97 *);
	int (*resume_early)(struct device___97 *);
	int (*freeze_late)(struct device___97 *);
	int (*thaw_early)(struct device___97 *);
	int (*poweroff_late)(struct device___97 *);
	int (*restore_early)(struct device___97 *);
	int (*suspend_noirq)(struct device___97 *);
	int (*resume_noirq)(struct device___97 *);
	int (*freeze_noirq)(struct device___97 *);
	int (*thaw_noirq)(struct device___97 *);
	int (*poweroff_noirq)(struct device___97 *);
	int (*restore_noirq)(struct device___97 *);
	int (*runtime_suspend)(struct device___97 *);
	int (*runtime_resume)(struct device___97 *);
	int (*runtime_idle)(struct device___97 *);
};

struct dev_pm_domain___97 {
	struct dev_pm_ops___97 ops;
	void (*detach)(struct device___97 *, bool);
	int (*activate)(struct device___97 *);
	void (*sync)(struct device___97 *);
	void (*dismiss)(struct device___97 *);
};

struct bus_type___97 {
	const char *name;
	const char *dev_name;
	struct device___97 *dev_root;
	const struct attribute_group___96 **bus_groups;
	const struct attribute_group___96 **dev_groups;
	const struct attribute_group___96 **drv_groups;
	int (*match)(struct device___97 *, struct device_driver___97 *);
	int (*uevent)(struct device___97 *, struct kobj_uevent_env *);
	int (*probe)(struct device___97 *);
	int (*remove)(struct device___97 *);
	void (*shutdown)(struct device___97 *);
	int (*online)(struct device___97 *);
	int (*offline)(struct device___97 *);
	int (*suspend)(struct device___97 *, pm_message_t);
	int (*resume)(struct device___97 *);
	int (*num_vf)(struct device___97 *);
	int (*dma_configure)(struct device___97 *);
	const struct dev_pm_ops___97 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___97 {
	const char *name;
	struct bus_type___97 *bus;
	struct module___89 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___97 *);
	int (*remove)(struct device___97 *);
	void (*shutdown)(struct device___97 *);
	int (*suspend)(struct device___97 *, pm_message_t);
	int (*resume)(struct device___97 *);
	const struct attribute_group___96 **groups;
	const struct dev_pm_ops___97 *pm;
	void (*coredump)(struct device___97 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct module_kobject___86 {
	struct kobject___100 kobj;
	struct module___89 *mod;
	struct kobject___100 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___86 {
	struct module___89 *mod;
	struct latch_tree_node node;
};

struct module_layout___86 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___86 mtn;
};

struct module_attribute___86;

struct kernel_param___86;

struct module___89 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___86 mkobj;
	struct module_attribute___86 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___100 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___86 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___86 core_layout;
	struct module_layout___86 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___59 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide47;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide48;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct device_attribute___6 {
	struct attribute attr;
	ssize_t (*show)(struct device___97 *, struct device_attribute___6 *, char *);
	ssize_t (*store)(struct device___97 *, struct device_attribute___6 *, const char *, size_t);
};

struct fwnode_operations___71;

struct fwnode_handle___71 {
	struct fwnode_handle___71 *secondary;
	const struct fwnode_operations___71 *ops;
};

struct property___34;

struct device_node___35 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___71 fwnode;
	struct property___34 *properties;
	struct property___34 *deadprops;
	struct device_node___35 *parent;
	struct device_node___35 *child;
	struct device_node___35 *sibling;
	struct kobject___100 kobj;
	long unsigned int _flags;
	void *data;
};

struct dentry_operations___105;

struct super_block___106;

struct dentry___106 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___106 *d_parent;
	struct qstr d_name;
	struct inode___107 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___105 *d_op;
	struct super_block___106 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___105;

struct address_space___105 {
	struct inode___107 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___106 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___105 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___105;

struct block_device___106;

struct inode___107 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___105 *i_op;
	struct super_block___106 *i_sb;
	struct address_space___105 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___106 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___41 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___106 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___105 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___106 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___105 {
	int (*d_revalidate)(struct dentry___106 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___106 *, unsigned int);
	int (*d_hash)(const struct dentry___106 *, struct qstr *);
	int (*d_compare)(const struct dentry___106 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___106 *);
	int (*d_init)(struct dentry___106 *);
	void (*d_release)(struct dentry___106 *);
	void (*d_prune)(struct dentry___106 *);
	void (*d_iput)(struct dentry___106 *, struct inode___107 *);
	char * (*d_dname)(struct dentry___106 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___105 *);
	int (*d_manage)(const struct path___105 *, bool);
	struct dentry___106 * (*d_real)(struct dentry___106 *, const struct inode___107 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___105;

struct mem_dqinfo___105 {
	struct quota_format_type___105 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___105;

struct quota_info___105 {
	unsigned int flags;
	struct rw_semaphore___106 dqio_sem;
	struct inode___107 *files[3];
	struct mem_dqinfo___105 info[3];
	const struct quota_format_ops___105 *ops[3];
};

struct rcuwait___105 {
	struct task_struct___106 *task;
};

struct percpu_rw_semaphore___105 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___106 rw_sem;
	struct rcuwait___105 writer;
	int readers_block;
};

struct sb_writers___105 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___105 rw_sem[3];
};

struct file_system_type___105;

struct super_operations___105;

struct dquot_operations___105;

struct quotactl_ops___105;

struct super_block___106 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___105 *s_type;
	const struct super_operations___105 *s_op;
	const struct dquot_operations___105 *dq_op;
	const struct quotactl_ops___105 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___106 *s_root;
	struct rw_semaphore___106 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___106 *s_bdev;
	struct backing_dev_info___41 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___105 s_dquot;
	struct sb_writers___105 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___105 *s_d_op;
	int cleancache_poolid;
	struct shrinker___36 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___86 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

typedef int (*dev_page_fault_t___103)(struct vm_area_struct___106 *, long unsigned int, const struct page___106 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___103)(struct page___106 *, void *);

struct dev_pagemap___103 {
	dev_page_fault_t___103 page_fault;
	dev_page_free_t___103 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___97 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___105 {
	struct task_struct___106 *task;
	struct core_thread___105 *next;
};

struct core_state___105 {
	atomic_t nr_threads;
	struct core_thread___105 dumper;
	struct completion startup;
};

struct vm_fault___103 {
	struct vm_area_struct___106 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___106 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___106 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___105 prealloc_pte;
};

struct io_cq___17 {
	struct request_queue___18 *q;
	struct io_context___17 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___106 {
	struct file___106 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___106 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___106 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___106 *ia_file;
};

struct dquot___105 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___106 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___105 {
	int qf_fmt_id;
	const struct quota_format_ops___105 *qf_ops;
	struct module___89 *qf_owner;
	struct quota_format_type___105 *qf_next;
};

struct quota_format_ops___105 {
	int (*check_quota_file)(struct super_block___106 *, int);
	int (*read_file_info)(struct super_block___106 *, int);
	int (*write_file_info)(struct super_block___106 *, int);
	int (*free_file_info)(struct super_block___106 *, int);
	int (*read_dqblk)(struct dquot___105 *);
	int (*commit_dqblk)(struct dquot___105 *);
	int (*release_dqblk)(struct dquot___105 *);
	int (*get_next_id)(struct super_block___106 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___105 {
	int (*write_dquot)(struct dquot___105 *);
	struct dquot___105 * (*alloc_dquot)(struct super_block___106 *, int);
	void (*destroy_dquot)(struct dquot___105 *);
	int (*acquire_dquot)(struct dquot___105 *);
	int (*release_dquot)(struct dquot___105 *);
	int (*mark_dirty)(struct dquot___105 *);
	int (*write_info)(struct super_block___106 *, int);
	qsize_t * (*get_reserved_space)(struct inode___107 *);
	int (*get_projid)(struct inode___107 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___107 *, qsize_t *);
	int (*get_next_id)(struct super_block___106 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___105 {
	int (*quota_on)(struct super_block___106 *, int, int, const struct path___105 *);
	int (*quota_off)(struct super_block___106 *, int);
	int (*quota_enable)(struct super_block___106 *, unsigned int);
	int (*quota_disable)(struct super_block___106 *, unsigned int);
	int (*quota_sync)(struct super_block___106 *, int);
	int (*set_info)(struct super_block___106 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___106 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___106 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___106 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___106 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___106 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___105 {
	int (*writepage)(struct page___106 *, struct writeback_control___3 *);
	int (*readpage)(struct file___106 *, struct page___106 *);
	int (*writepages)(struct address_space___105 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___106 *);
	int (*readpages)(struct file___106 *, struct address_space___105 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___106 *, struct address_space___105 *, loff_t, unsigned int, unsigned int, struct page___106 **, void **);
	int (*write_end)(struct file___106 *, struct address_space___105 *, loff_t, unsigned int, unsigned int, struct page___106 *, void *);
	sector_t (*bmap)(struct address_space___105 *, sector_t);
	void (*invalidatepage)(struct page___106 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___106 *, gfp_t);
	void (*freepage)(struct page___106 *);
	ssize_t (*direct_IO)(struct kiocb___106 *, struct iov_iter___42 *);
	int (*migratepage)(struct address_space___105 *, struct page___106 *, struct page___106 *, enum migrate_mode);
	bool (*isolate_page)(struct page___106 *, isolate_mode_t);
	void (*putback_page)(struct page___106 *);
	int (*launder_page)(struct page___106 *);
	int (*is_partially_uptodate)(struct page___106 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___106 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___105 *, struct page___106 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___106 *, sector_t *);
	void (*swap_deactivate)(struct file___106 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct iov_iter___42 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___41 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___106 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___107 *bd_inode;
	struct super_block___106 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___106 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___18 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___18 *bd_disk;
	struct request_queue___18 *bd_queue;
	struct backing_dev_info___41 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___105 {
	struct dentry___106 * (*lookup)(struct inode___107 *, struct dentry___106 *, unsigned int);
	const char * (*get_link)(struct dentry___106 *, struct inode___107 *, struct delayed_call *);
	int (*permission)(struct inode___107 *, int);
	struct posix_acl * (*get_acl)(struct inode___107 *, int);
	int (*readlink)(struct dentry___106 *, char *, int);
	int (*create)(struct inode___107 *, struct dentry___106 *, umode_t, bool);
	int (*link)(struct dentry___106 *, struct inode___107 *, struct dentry___106 *);
	int (*unlink)(struct inode___107 *, struct dentry___106 *);
	int (*symlink)(struct inode___107 *, struct dentry___106 *, const char *);
	int (*mkdir)(struct inode___107 *, struct dentry___106 *, umode_t);
	int (*rmdir)(struct inode___107 *, struct dentry___106 *);
	int (*mknod)(struct inode___107 *, struct dentry___106 *, umode_t, dev_t);
	int (*rename)(struct inode___107 *, struct dentry___106 *, struct inode___107 *, struct dentry___106 *, unsigned int);
	int (*setattr)(struct dentry___106 *, struct iattr___106 *);
	int (*getattr)(const struct path___105 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___106 *, char *, size_t);
	int (*fiemap)(struct inode___107 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___107 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___107 *, struct dentry___106 *, struct file___106 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___107 *, struct dentry___106 *, umode_t);
	int (*set_acl)(struct inode___107 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___105 {
	void (*fl_copy_lock)(struct file_lock___106 *, struct file_lock___106 *);
	void (*fl_release_private)(struct file_lock___106 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___105;

struct file_lock___106 {
	struct file_lock___106 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___106 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___105 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___105 *fl_ops;
	const struct lock_manager_operations___105 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___105 {
	int (*lm_compare_owner)(struct file_lock___106 *, struct file_lock___106 *);
	long unsigned int (*lm_owner_key)(struct file_lock___106 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___106 *);
	int (*lm_grant)(struct file_lock___106 *, int);
	bool (*lm_break)(struct file_lock___106 *);
	int (*lm_change)(struct file_lock___106 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___106 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___105 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___105 *fa_next;
	struct file___106 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___105 {
	const char *name;
	int fs_flags;
	struct dentry___106 * (*mount)(struct file_system_type___105 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___106 *);
	struct module___89 *owner;
	struct file_system_type___105 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___105 {
	struct inode___107 * (*alloc_inode)(struct super_block___106 *);
	void (*destroy_inode)(struct inode___107 *);
	void (*dirty_inode)(struct inode___107 *, int);
	int (*write_inode)(struct inode___107 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___107 *);
	void (*evict_inode)(struct inode___107 *);
	void (*put_super)(struct super_block___106 *);
	int (*sync_fs)(struct super_block___106 *, int);
	int (*freeze_super)(struct super_block___106 *);
	int (*freeze_fs)(struct super_block___106 *);
	int (*thaw_super)(struct super_block___106 *);
	int (*unfreeze_fs)(struct super_block___106 *);
	int (*statfs)(struct dentry___106 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___106 *, int *, char *);
	void (*umount_begin)(struct super_block___106 *);
	int (*show_options)(struct seq_file___96 *, struct dentry___106 *);
	int (*show_devname)(struct seq_file___96 *, struct dentry___106 *);
	int (*show_path)(struct seq_file___96 *, struct dentry___106 *);
	int (*show_stats)(struct seq_file___96 *, struct dentry___106 *);
	ssize_t (*quota_read)(struct super_block___106 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___106 *, int, const char *, size_t, loff_t);
	struct dquot___105 ** (*get_dquots)(struct inode___107 *);
	int (*bdev_try_to_free_page)(struct super_block___106 *, struct page___106 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___106 *, struct shrink_control___36 *);
	long int (*free_cached_objects)(struct super_block___106 *, struct shrink_control___36 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___18 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___18 *last_lookup;
	struct hd_struct___18 *part[0];
};

struct block_device_operations___18 {
	int (*open)(struct block_device___106 *, fmode_t);
	void (*release)(struct gendisk___18 *, fmode_t);
	int (*rw_page)(struct block_device___106 *, sector_t, struct page___106 *, unsigned int);
	int (*ioctl)(struct block_device___106 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___106 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___18 *, unsigned int);
	int (*media_changed)(struct gendisk___18 *);
	void (*unlock_native_capacity)(struct gendisk___18 *);
	int (*revalidate_disk)(struct gendisk___18 *);
	int (*getgeo)(struct block_device___106 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___106 *, long unsigned int);
	int (*report_zones)(struct gendisk___18 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___89 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___103(struct page___106 *);

struct bdi_writeback_congested___41 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___41 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct cgroup_subsys___82;

struct cgroup_subsys_state___82 {
	struct cgroup___82 *cgroup;
	struct cgroup_subsys___82 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___82 *parent;
};

struct bsg_ops___17 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___18 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___18 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___18 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___17(struct request___18 *, blk_status_t);

struct request___18 {
	struct request_queue___18 *q;
	struct blk_mq_ctx___2 *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___41 *bio;
	struct bio___41 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___41 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___17 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___17 *saved_end_io;
		} flush;
	};
	struct gendisk___18 *rq_disk;
	struct hd_struct___18 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___17 *end_io;
	void *end_io_data;
	struct request___18 *next_rq;
};

struct fwnode_reference_args___71;

struct fwnode_endpoint___71;

struct fwnode_operations___71 {
	struct fwnode_handle___71 * (*get)(struct fwnode_handle___71 *);
	void (*put)(struct fwnode_handle___71 *);
	bool (*device_is_available)(const struct fwnode_handle___71 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___71 *, const struct device___97 *);
	bool (*property_present)(const struct fwnode_handle___71 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___71 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___71 *, const char *, const char **, size_t);
	struct fwnode_handle___71 * (*get_parent)(const struct fwnode_handle___71 *);
	struct fwnode_handle___71 * (*get_next_child_node)(const struct fwnode_handle___71 *, struct fwnode_handle___71 *);
	struct fwnode_handle___71 * (*get_named_child_node)(const struct fwnode_handle___71 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___71 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___71 *);
	struct fwnode_handle___71 * (*graph_get_next_endpoint)(const struct fwnode_handle___71 *, struct fwnode_handle___71 *);
	struct fwnode_handle___71 * (*graph_get_remote_endpoint)(const struct fwnode_handle___71 *);
	struct fwnode_handle___71 * (*graph_get_port_parent)(struct fwnode_handle___71 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___71 *, struct fwnode_endpoint___71 *);
};

struct fwnode_endpoint___71 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___71 *local_fwnode;
};

struct fwnode_reference_args___71 {
	struct fwnode_handle___71 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct blk_mq_ctxs;

struct blk_mq_ctx___2 {
	struct {
		spinlock_t lock;
		struct list_head rq_lists[3];
		long: 64;
	};
	unsigned int cpu;
	short unsigned int index_hw[3];
	struct blk_mq_hw_ctx *hctxs[3];
	long unsigned int rq_dispatched[2];
	long unsigned int rq_merged;
	long unsigned int rq_completed[2];
	struct request_queue___18 *queue;
	struct blk_mq_ctxs *ctxs;
	struct kobject___100 kobj;
};

struct sbitmap_word;

struct sbitmap {
	unsigned int depth;
	unsigned int shift;
	unsigned int map_nr;
	struct sbitmap_word *map;
};

struct blk_mq_tags;

struct blk_mq_hw_ctx {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___18 *queue;
	struct blk_flush_queue___2 *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx___2 *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx___2 **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	unsigned int rh_reserved_nr_expired;
	struct hlist_node cpuhp_dead;
	struct kobject___100 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___106 *debugfs_dir;
	struct dentry___106 *sched_debugfs_dir;
	struct list_head hctx_list;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___17;

struct blk_mq_alloc_data___2;

struct elevator_mq_ops___17 {
	int (*init_sched)(struct request_queue___18 *, struct elevator_type___17 *);
	void (*exit_sched)(struct elevator_queue___17 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	bool (*allow_merge)(struct request_queue___18 *, struct request___18 *, struct bio___41 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx *, struct bio___41 *);
	int (*request_merge)(struct request_queue___18 *, struct request___18 **, struct bio___41 *);
	void (*request_merged)(struct request_queue___18 *, struct request___18 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___18 *, struct request___18 *, struct request___18 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data___2 *);
	void (*prepare_request)(struct request___18 *, struct bio___41 *);
	void (*finish_request)(struct request___18 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___18 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___18 *, u64);
	void (*started_request)(struct request___18 *);
	void (*requeue_request)(struct request___18 *);
	struct request___18 * (*former_request)(struct request_queue___18 *, struct request___18 *);
	struct request___18 * (*next_request)(struct request_queue___18 *, struct request___18 *);
	void (*init_icq)(struct io_cq___17 *);
	void (*exit_icq)(struct io_cq___17 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___17;

struct elevator_type___17 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___17 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___17 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___89 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___17 {
	struct elevator_type___17 *type;
	void *elevator_data;
	struct kobject___100 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct blk_mq_alloc_data___2 {
	struct request_queue___18 *q;
	blk_mq_req_flags_t flags;
	unsigned int shallow_depth;
	unsigned int cmd_flags;
	struct blk_mq_ctx___2 *ctx;
	struct blk_mq_hw_ctx *hctx;
};

struct elv_fs_entry___17 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___17 *, char *);
	ssize_t (*store)(struct elevator_queue___17 *, const char *, size_t);
};

struct blk_mq_queue_data___2;

typedef blk_status_t queue_rq_fn___2(struct blk_mq_hw_ctx *, const struct blk_mq_queue_data___2 *);

typedef void commit_rqs_fn___2(struct blk_mq_hw_ctx *);

typedef bool get_budget_fn___2(struct blk_mq_hw_ctx *);

typedef void put_budget_fn___2(struct blk_mq_hw_ctx *);

typedef enum blk_eh_timer_return timeout_fn___2(struct request___18 *, bool);

typedef int poll_fn___2(struct blk_mq_hw_ctx *);

typedef void complete_fn___2(struct request___18 *);

typedef int init_hctx_fn___2(struct blk_mq_hw_ctx *, void *, unsigned int);

typedef void exit_hctx_fn___2(struct blk_mq_hw_ctx *, unsigned int);

typedef int init_request_fn___2(struct blk_mq_tag_set___2 *, struct request___18 *, unsigned int, unsigned int);

typedef void exit_request_fn___2(struct blk_mq_tag_set___2 *, struct request___18 *, unsigned int);

typedef bool busy_fn___2(struct request_queue___18 *);

typedef int map_queues_fn___2(struct blk_mq_tag_set___2 *);

typedef void cleanup_rq_fn___2(struct request___18 *);

struct blk_mq_ops___2 {
	queue_rq_fn___2 *queue_rq;
	commit_rqs_fn___2 *commit_rqs;
	get_budget_fn___2 *get_budget;
	put_budget_fn___2 *put_budget;
	timeout_fn___2 *timeout;
	poll_fn___2 *poll;
	complete_fn___2 *complete;
	init_hctx_fn___2 *init_hctx;
	exit_hctx_fn___2 *exit_hctx;
	init_request_fn___2 *init_request;
	exit_request_fn___2 *exit_request;
	void (*initialize_rq_fn)(struct request___18 *);
	busy_fn___2 *busy;
	map_queues_fn___2 *map_queues;
	void (*show_rq)(struct seq_file___96 *, struct request___18 *);
	union {
		cleanup_rq_fn___2 *cleanup_rq;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide44;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct blk_stat_callback___2 {
	struct list_head list;
	struct timer_list timer;
	struct blk_rq_stat *cpu_stat;
	int (*bucket_fn)(const struct request___18 *);
	unsigned int buckets;
	struct blk_rq_stat *stat;
	void (*timer_fn)(struct blk_stat_callback___2 *);
	void *data;
	struct callback_head rcu;
};

struct rchan___2;

struct blk_trace___2 {
	int trace_state;
	struct rchan___2 *rchan;
	long unsigned int *sequence;
	unsigned char *msg_data;
	u16 act_mask;
	u64 start_lba;
	u64 end_lba;
	u32 pid;
	u32 dev;
	struct dentry___106 *dir;
	struct dentry___106 *dropped_file;
	struct dentry___106 *msg_file;
	struct list_head running_list;
	atomic_t dropped;
};

struct blk_flush_queue___2 {
	unsigned int flush_queue_delayed: 1;
	unsigned int flush_pending_idx: 1;
	unsigned int flush_running_idx: 1;
	long unsigned int flush_pending_since;
	struct list_head flush_queue[2];
	struct list_head flush_data_in_flight;
	struct request___18 *flush_rq;
	struct request___18 *orig_rq;
	spinlock_t mq_flush_lock;
};

struct blk_mq_queue_map {
	unsigned int *mq_map;
	unsigned int nr_queues;
	unsigned int queue_offset;
};

struct blk_mq_tag_set___2 {
	struct blk_mq_queue_map map[6];
	unsigned int nr_maps;
	const struct blk_mq_ops___2 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct rchan_buf___2 {
	void *start;
	void *data;
	size_t offset;
	size_t subbufs_produced;
	size_t subbufs_consumed;
	struct rchan___2 *chan;
	wait_queue_head_t read_wait;
	struct irq_work wakeup_work;
	struct dentry___106 *dentry;
	struct kref kref;
	struct page___106 **page_array;
	unsigned int page_count;
	unsigned int finalized;
	size_t *padding;
	size_t prev_padding;
	size_t bytes_consumed;
	size_t early_bytes;
	unsigned int cpu;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
};

struct rchan_callbacks___2;

struct rchan___2 {
	u32 version;
	size_t subbuf_size;
	size_t n_subbufs;
	size_t alloc_size;
	struct rchan_callbacks___2 *cb;
	struct kref kref;
	void *private_data;
	size_t last_toobig;
	struct rchan_buf___2 **buf;
	int is_global;
	struct list_head list;
	struct dentry___106 *parent;
	int has_base_filename;
	char base_filename[255];
};

struct rchan_callbacks___2 {
	int (*subbuf_start)(struct rchan_buf___2 *, void *, void *, size_t);
	void (*buf_mapped)(struct rchan_buf___2 *, struct file___106 *);
	void (*buf_unmapped)(struct rchan_buf___2 *, struct file___106 *);
	struct dentry___106 * (*create_buf_file)(const char *, struct dentry___106 *, umode_t, struct rchan_buf___2 *, int *);
	int (*remove_buf_file)(struct dentry___106 *);
};

enum blktrace_cat {
	BLK_TC_READ = 1,
	BLK_TC_WRITE = 2,
	BLK_TC_FLUSH = 4,
	BLK_TC_SYNC = 8,
	BLK_TC_SYNCIO = 8,
	BLK_TC_QUEUE = 16,
	BLK_TC_REQUEUE = 32,
	BLK_TC_ISSUE = 64,
	BLK_TC_COMPLETE = 128,
	BLK_TC_FS = 256,
	BLK_TC_PC = 512,
	BLK_TC_NOTIFY = 1024,
	BLK_TC_AHEAD = 2048,
	BLK_TC_META = 4096,
	BLK_TC_DISCARD = 8192,
	BLK_TC_DRV_DATA = 16384,
	BLK_TC_FUA = 32768,
	BLK_TC_END = 32768,
};

enum blktrace_act {
	__BLK_TA_QUEUE = 1,
	__BLK_TA_BACKMERGE = 2,
	__BLK_TA_FRONTMERGE = 3,
	__BLK_TA_GETRQ = 4,
	__BLK_TA_SLEEPRQ = 5,
	__BLK_TA_REQUEUE = 6,
	__BLK_TA_ISSUE = 7,
	__BLK_TA_COMPLETE = 8,
	__BLK_TA_PLUG = 9,
	__BLK_TA_UNPLUG_IO = 10,
	__BLK_TA_UNPLUG_TIMER = 11,
	__BLK_TA_INSERT = 12,
	__BLK_TA_SPLIT = 13,
	__BLK_TA_BOUNCE = 14,
	__BLK_TA_REMAP = 15,
	__BLK_TA_ABORT = 16,
	__BLK_TA_DRV_DATA = 17,
	__BLK_TA_CGROUP = 256,
};

enum blktrace_notify {
	__BLK_TN_PROCESS = 0,
	__BLK_TN_TIMESTAMP = 1,
	__BLK_TN_MESSAGE = 2,
	__BLK_TN_CGROUP = 256,
};

struct blk_io_trace {
	__u32 magic;
	__u32 sequence;
	__u64 time;
	__u64 sector;
	__u32 bytes;
	__u32 action;
	__u32 pid;
	__u32 device;
	__u32 cpu;
	__u16 error;
	__u16 pdu_len;
};

struct blk_io_trace_remap {
	__be32 device_from;
	__be32 device_to;
	__be64 sector_from;
};

enum {
	Blktrace_setup = 1,
	Blktrace_running = 2,
	Blktrace_stopped = 3,
};

struct blk_user_trace_setup {
	char name[32];
	__u16 act_mask;
	__u32 buf_size;
	__u32 buf_nr;
	__u64 start_lba;
	__u64 end_lba;
	__u32 pid;
};

typedef int (*key_restrict_link_func_t___101)(struct key___101 *, const struct key_type *, const union key_payload *, struct key___101 *);

struct key_restriction___101;

struct key___101 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___106 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___101 *restrict_link;
};

struct key_restriction___101 {
	key_restrict_link_func_t___101 check;
	struct key___101 *key;
	struct key_type *keytype;
};

struct seq_operations___94 {
	void * (*start)(struct seq_file___96 *, loff_t *);
	void (*stop)(struct seq_file___96 *, void *);
	void * (*next)(struct seq_file___96 *, void *, loff_t *);
	int (*show)(struct seq_file___96 *, void *);
};

struct cgroup_namespace___82 {
	refcount_t count;
	struct ns_common___7 ns;
	struct user_namespace___86 *user_ns;
	struct ucounts___86 *ucounts;
	struct css_set___82 *root_cset;
};

struct ucounts___86 {
	struct hlist_node node;
	struct user_namespace___86 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___82;

struct bpf_map_ops___82 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___82 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___82 *, struct file___106 *);
	void (*map_free)(struct bpf_map___82 *);
	int (*map_get_next_key)(struct bpf_map___82 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___82 *);
	void * (*map_lookup_elem)(struct bpf_map___82 *, void *);
	int (*map_update_elem)(struct bpf_map___82 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___82 *, void *);
	int (*map_push_elem)(struct bpf_map___82 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___82 *, void *);
	int (*map_peek_elem)(struct bpf_map___82 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___82 *, struct file___106 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___82 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___82 *, void *, struct seq_file___96 *);
	int (*map_check_btf)(const struct bpf_map___82 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___82 {
	const struct bpf_map_ops___82 *ops;
	struct bpf_map___82 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___101 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___82;

typedef void (*kthread_work_func_t___82)(struct kthread_work___82 *);

struct kthread_worker___82;

struct kthread_work___82 {
	struct list_head node;
	kthread_work_func_t___82 func;
	struct kthread_worker___82 *worker;
	int canceling;
};

struct kthread_worker___82 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___106 *task;
	struct kthread_work___82 *current_work;
};

struct kthread_delayed_work___82 {
	struct kthread_work___82 work;
	struct timer_list timer;
};

struct psi_group___82 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___82 *poll_kworker;
	struct kthread_delayed_work___82 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___82 {
	struct kernfs_node___102 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_root___82;

struct cgroup_rstat_cpu___82;

struct cgroup___82 {
	struct cgroup_subsys_state___82 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___102 *kn;
	struct cgroup_file___82 procs_file;
	struct cgroup_file___82 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___82 *subsys[13];
	struct cgroup_root___82 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___82 *dom_cgrp;
	struct cgroup_rstat_cpu___82 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___9 bpf;
	atomic_t congestion_count;
	struct cgroup___82 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___82 psi;
	int ancestor_ids[0];
};

struct cftype___82;

struct cgroup_subsys___82 {
	struct cgroup_subsys_state___82 * (*css_alloc)(struct cgroup_subsys_state___82 *);
	int (*css_online)(struct cgroup_subsys_state___82 *);
	void (*css_offline)(struct cgroup_subsys_state___82 *);
	void (*css_released)(struct cgroup_subsys_state___82 *);
	void (*css_free)(struct cgroup_subsys_state___82 *);
	void (*css_reset)(struct cgroup_subsys_state___82 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___82 *, int);
	int (*css_extra_stat_show)(struct seq_file___96 *, struct cgroup_subsys_state___82 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___106 *);
	void (*cancel_fork)(struct task_struct___106 *);
	void (*fork)(struct task_struct___106 *);
	void (*exit)(struct task_struct___106 *);
	void (*free)(struct task_struct___106 *);
	void (*bind)(struct cgroup_subsys_state___82 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___82 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___82 *dfl_cftypes;
	struct cftype___82 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___82 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___82 *updated_children;
	struct cgroup___82 *updated_next;
};

struct cgroup_root___82 {
	struct kernfs_root___102 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___82 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___82 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___82 *ss;
	struct list_head node;
	struct kernfs_ops___102 *kf_ops;
	int (*open)(struct kernfs_open_file___102 *);
	void (*release)(struct kernfs_open_file___102 *);
	u64 (*read_u64)(struct cgroup_subsys_state___82 *, struct cftype___82 *);
	s64 (*read_s64)(struct cgroup_subsys_state___82 *, struct cftype___82 *);
	int (*seq_show)(struct seq_file___96 *, void *);
	void * (*seq_start)(struct seq_file___96 *, loff_t *);
	void * (*seq_next)(struct seq_file___96 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___96 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___82 *, struct cftype___82 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___82 *, struct cftype___82 *, s64);
	ssize_t (*write)(struct kernfs_open_file___102 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___102 *, struct poll_table_struct___69 *);
};

struct blkcg_policy_data___10;

struct blkcg___10 {
	struct cgroup_subsys_state___82 css;
	spinlock_t lock;
	struct xarray blkg_tree;
	struct blkcg_gq___10 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___10 *cpd[5];
	struct list_head all_blkcgs_node;
	struct list_head cgwb_list;
	refcount_t cgwb_refcnt;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct blkcg_policy_data___10 {
	struct blkcg___10 *blkcg;
	int plid;
};

struct blkg_policy_data___10 {
	struct blkcg_gq___10 *blkg;
	int plid;
};

struct sbitmap_word {
	long unsigned int depth;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int word;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int cleared;
	spinlock_t swap_lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sbq_wait_state {
	atomic_t wait_cnt;
	wait_queue_head_t wait;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sbitmap_queue {
	struct sbitmap sb;
	unsigned int *alloc_hint;
	unsigned int wake_batch;
	atomic_t wake_index;
	struct sbq_wait_state *ws;
	atomic_t ws_active;
	bool round_robin;
	unsigned int min_shallow_depth;
};

struct blk_mq_tags {
	unsigned int nr_tags;
	unsigned int nr_reserved_tags;
	atomic_t active_queues;
	struct sbitmap_queue bitmap_tags;
	struct sbitmap_queue breserved_tags;
	struct request___18 **rqs;
	struct request___18 **static_rqs;
	struct list_head page_list;
};

enum hctx_type {
	HCTX_TYPE_DEFAULT = 0,
	HCTX_TYPE_READ = 1,
	HCTX_TYPE_POLL = 2,
	HCTX_MAX_TYPES = 3,
	RH_HCTX_MAX_TYPES = 6,
};

struct blk_mq_queue_data___2 {
	struct request___18 *rq;
	bool last;
	long unsigned int rh_reserved1;
};

struct blk_mq_ctxs {
	struct kobject___100 kobj;
	struct blk_mq_ctx___2 *queue_ctx;
};

struct property___34 {
	char *name;
	int length;
	void *value;
	struct property___34 *next;
	long unsigned int _flags;
	struct bin_attribute___96 attr;
};

struct kernel_param_ops___86 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___86 *);
	int (*get)(char *, const struct kernel_param___86 *);
	void (*free)(void *);
};

struct kparam_array___86;

struct kernel_param___86 {
	const char *name;
	struct module___89 *mod;
	const struct kernel_param_ops___86 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___86 *arr;
	};
};

struct kparam_array___86 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___86 *ops;
	void *elem;
};

struct module_attribute___86 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___86 *, struct module_kobject___86 *, char *);
	ssize_t (*store)(struct module_attribute___86 *, struct module_kobject___86 *, const char *, size_t);
	void (*setup)(struct module___89 *, const char *);
	int (*test)(struct module___89 *);
	void (*free)(struct module___89 *);
};

struct trace_event_functions___7;

struct trace_event___7 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___7 *funcs;
};

struct trace_event_class___59;

struct trace_event_call___59 {
	struct list_head list;
	struct trace_event_class___59 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___7 event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___9 *prog_array;
	int (*perf_perm)(struct trace_event_call___59 *, struct perf_event___64 *);
};

struct node___83 {
	struct device___97 dev;
};

struct perf_cpu_context___64;

struct pmu___64 {
	struct list_head entry;
	struct module___89 *module;
	struct device___97 *dev;
	const struct attribute_group___96 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___64 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___64 *);
	void (*pmu_disable)(struct pmu___64 *);
	int (*event_init)(struct perf_event___64 *);
	void (*event_mapped)(struct perf_event___64 *, struct mm_struct___105 *);
	void (*event_unmapped)(struct perf_event___64 *, struct mm_struct___105 *);
	int (*add)(struct perf_event___64 *, int);
	void (*del)(struct perf_event___64 *, int);
	void (*start)(struct perf_event___64 *, int);
	void (*stop)(struct perf_event___64 *, int);
	void (*read)(struct perf_event___64 *);
	void (*start_txn)(struct pmu___64 *, unsigned int);
	int (*commit_txn)(struct pmu___64 *);
	void (*cancel_txn)(struct pmu___64 *);
	int (*event_idx)(struct perf_event___64 *);
	void (*sched_task)(struct perf_event_context___64 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___64 *);
	int (*filter_match)(struct perf_event___64 *);
	int (*check_period)(struct perf_event___64 *, u64);
};

struct perf_cpu_context___64 {
	struct perf_event_context___64 ctx;
	struct perf_event_context___64 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___64 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___64 {
	struct cgroup_subsys_state___82 css;
	struct perf_cgroup_info *info;
};

struct trace_array___7;

struct tracer___7;

struct trace_buffer___7;

struct trace_iterator___7 {
	struct trace_array___7 *tr;
	struct tracer___7 *trace;
	struct trace_buffer___7 *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

struct trace_buffer___7 {
	struct trace_array___7 *tr;
	struct ring_buffer *buffer;
	struct trace_array_cpu *data;
	u64 time_start;
	int cpu;
};

struct trace_event_file___24;

struct trace_options___7;

struct trace_array___7 {
	struct list_head list;
	char *name;
	struct trace_buffer___7 trace_buffer;
	struct trace_buffer___7 max_buffer;
	bool allocated_snapshot;
	long unsigned int max_latency;
	struct trace_pid_list *filtered_pids;
	arch_spinlock_t max_lock;
	int buffer_disabled;
	int sys_refcount_enter;
	int sys_refcount_exit;
	struct trace_event_file___24 *enter_syscall_files[295];
	struct trace_event_file___24 *exit_syscall_files[295];
	int stop_count;
	int clock_id;
	int nr_topts;
	bool clear_trace;
	struct tracer___7 *current_trace;
	unsigned int trace_flags;
	unsigned char trace_flags_index[32];
	unsigned int flags;
	raw_spinlock_t start_lock;
	struct dentry___106 *dir;
	struct dentry___106 *options;
	struct dentry___106 *percpu_dir;
	struct dentry___106 *event_dir;
	struct trace_options___7 *topts;
	struct list_head systems;
	struct list_head events;
	struct trace_event_file___24 *trace_marker_file;
	cpumask_var_t tracing_cpumask;
	int ref;
	struct ftrace_ops *ops;
	struct trace_pid_list *function_pids;
	struct list_head func_probes;
	struct list_head mod_trace;
	struct list_head mod_notrace;
	int function_enabled;
	int time_stamp_abs_ref;
	struct list_head hist_vars;
};

struct tracer_flags___7;

struct tracer___7 {
	const char *name;
	int (*init)(struct trace_array___7 *);
	void (*reset)(struct trace_array___7 *);
	void (*start)(struct trace_array___7 *);
	void (*stop)(struct trace_array___7 *);
	int (*update_thresh)(struct trace_array___7 *);
	void (*open)(struct trace_iterator___7 *);
	void (*pipe_open)(struct trace_iterator___7 *);
	void (*close)(struct trace_iterator___7 *);
	void (*pipe_close)(struct trace_iterator___7 *);
	ssize_t (*read)(struct trace_iterator___7 *, struct file___106 *, char *, size_t, loff_t *);
	ssize_t (*splice_read)(struct trace_iterator___7 *, struct file___106 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	void (*print_header)(struct seq_file___96 *);
	enum print_line_t (*print_line)(struct trace_iterator___7 *);
	int (*set_flag)(struct trace_array___7 *, u32, u32, int);
	int (*flag_changed)(struct trace_array___7 *, u32, int);
	struct tracer___7 *next;
	struct tracer_flags___7 *flags;
	int enabled;
	int ref;
	bool print_max;
	bool allow_instances;
	bool use_max_tr;
	bool noboot;
};

typedef enum print_line_t (*trace_print_func___7)(struct trace_iterator___7 *, int, struct trace_event___7 *);

struct trace_event_functions___7 {
	trace_print_func___7 trace;
	trace_print_func___7 raw;
	trace_print_func___7 hex;
	trace_print_func___7 binary;
};

struct trace_event_class___59 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___59 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___59 *);
	struct list_head * (*get_fields)(struct trace_event_call___59 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___59 *);
};

struct trace_subsystem_dir___8;

struct trace_event_file___24 {
	struct list_head list;
	struct trace_event_call___59 *event_call;
	struct event_filter *filter;
	struct dentry___106 *dir;
	struct trace_array___7 *tr;
	struct trace_subsystem_dir___8 *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_subsystem_dir___8 {
	struct list_head list;
	struct event_subsystem *subsystem;
	struct trace_array___7 *tr;
	struct dentry___106 *entry;
	int ref_count;
	int nr_events;
};

struct trace_option_dentry___7;

struct trace_options___7 {
	struct tracer___7 *tracer;
	struct trace_option_dentry___7 *topts;
};

struct trace_option_dentry___7 {
	struct tracer_opt *opt;
	struct tracer_flags___7 *flags;
	struct trace_array___7 *tr;
	struct dentry___106 *entry;
};

struct tracer_flags___7 {
	u32 val;
	struct tracer_opt *opts;
	struct tracer___7 *trace;
};

typedef void blk_log_action_t(struct trace_iterator___7 *, const char *, bool);

struct module___90;

struct file___107;

struct kiocb___107;

struct poll_table_struct___70;

struct vm_area_struct___107;

struct inode___108;

struct file_lock___107;

struct page___107;

struct seq_file___97;

struct file_operations___107 {
	struct module___90 *owner;
	loff_t (*llseek)(struct file___107 *, loff_t, int);
	ssize_t (*read)(struct file___107 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___107 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___107 *, struct iov_iter___42 *);
	ssize_t (*write_iter)(struct kiocb___107 *, struct iov_iter___42 *);
	int (*iopoll)(struct kiocb___107 *, bool);
	int (*iterate)(struct file___107 *, struct dir_context *);
	int (*iterate_shared)(struct file___107 *, struct dir_context *);
	__poll_t (*poll)(struct file___107 *, struct poll_table_struct___70 *);
	long int (*unlocked_ioctl)(struct file___107 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___107 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___107 *, struct vm_area_struct___107 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___108 *, struct file___107 *);
	int (*flush)(struct file___107 *, fl_owner_t);
	int (*release)(struct inode___108 *, struct file___107 *);
	int (*fsync)(struct file___107 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___107 *, int);
	int (*lock)(struct file___107 *, int, struct file_lock___107 *);
	ssize_t (*sendpage)(struct file___107 *, struct page___107 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___107 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___107 *, int, struct file_lock___107 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___107 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___107 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___107 *, long int, struct file_lock___107 **, void **);
	long int (*fallocate)(struct file___107 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___97 *, struct file___107 *);
	ssize_t (*copy_file_range)(struct file___107 *, loff_t, struct file___107 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___107 *, loff_t, struct file___107 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___107 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___106 {
	u64 seqnum;
	struct vm_area_struct___107 *vmas[4];
};

struct page_frag___106 {
	struct page___107 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___65;

struct debug_info___65 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___65 *hbp_break[16];
	struct perf_event___65 *hbp_watch[16];
};

struct thread_struct___65 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___65 debug;
	long: 64;
};

struct mm_struct___106;

struct pid___89;

struct cred___102;

struct nsproxy___99;

struct signal_struct___96;

struct css_set___83;

struct perf_event_context___65;

struct vm_struct___78;

struct task_struct___107 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___107 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___106 *mm;
	struct mm_struct___106 *active_mm;
	struct vmacache___106 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___107 *real_parent;
	struct task_struct___107 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___107 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___89 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___89 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___89 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___102 *ptracer_cred;
	const struct cred___102 *real_cred;
	const struct cred___102 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___99 *nsproxy;
	struct signal_struct___96 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___107 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___17 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___83 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___65 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___106 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___107 *oom_reaper_list;
	struct vm_struct___78 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___65 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___65 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___107 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___65)(struct perf_event___65 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___65;

struct fasync_struct___106;

struct pid_namespace___89;

struct trace_event_call___60;

struct perf_cgroup___65;

struct perf_event___65 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___65 *group_leader;
	struct pmu___65 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___65 hw;
	struct perf_event_context___65 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___65 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___107 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___106 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___65 *);
	struct callback_head callback_head;
	struct pid_namespace___89 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___65 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___65 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___60 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___65 *cgrp;
	struct list_head sb_list;
};

struct secondary_data___107 {
	void *stack;
	struct task_struct___107 *task;
	long int status;
};

struct upid___89 {
	int nr;
	struct pid_namespace___89 *ns;
};

struct dentry___107;

struct user_namespace___87;

struct ucounts___87;

struct pid_namespace___89 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___107 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___89 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___107 *proc_self;
	struct dentry___107 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___87 *user_ns;
	struct ucounts___87 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___7 ns;
};

struct pid___89 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___89 numbers[1];
};

struct rw_semaphore___107 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___107 *owner;
};

struct key___102;

struct user_namespace___87 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___87 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___7 ns;
	long unsigned int flags;
	struct key___102 *persistent_keyring_register;
	struct rw_semaphore___107 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___87 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___107 *pgtable_t___106;

struct address_space___106;

struct dev_pagemap___104;

struct page___107 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___106 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___107 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___106 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___106 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___104 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct user_struct___102 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___102 *uid_keyring;
	struct key___102 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___104;

struct vm_area_struct___107 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___107 *vm_next;
	struct vm_area_struct___107 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___106 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___104 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___107 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct linux_binfmt___16;

struct core_state___106;

struct mm_struct___106 {
	struct {
		struct vm_area_struct___107 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___107 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___107 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___16 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___106 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___107 *owner;
		struct user_namespace___87 *user_ns;
		struct file___107 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___106 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___102 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___102 *session_keyring;
	struct key___102 *process_keyring;
	struct key___102 *thread_keyring;
	struct key___102 *request_key_auth;
	void *security;
	struct user_struct___102 *user;
	struct user_namespace___87 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___83;

struct nsproxy___99 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___89 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___83 *cgroup_ns;
};

struct signal_struct___96 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___107 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___107 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___89 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___89 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___106 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___89 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___83;

struct cgroup___83;

struct css_set___83 {
	struct cgroup_subsys_state___83 *subsys[13];
	refcount_t refcount;
	struct css_set___83 *dom_cset;
	struct cgroup___83 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___83 *mg_src_cgrp;
	struct cgroup___83 *mg_dst_cgrp;
	struct css_set___83 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___65 {
	struct pmu___65 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___107 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___65 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___78 {
	struct vm_struct___78 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___107 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___96 {
	struct task_struct___107 task;
	long unsigned int stack[8192];
};

struct kthread_work___83;

typedef void (*kthread_work_func_t___83)(struct kthread_work___83 *);

struct kthread_worker___83;

struct kthread_work___83 {
	struct list_head node;
	kthread_work_func_t___83 func;
	struct kthread_worker___83 *worker;
	int canceling;
};

struct kthread_worker___83 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___107 *task;
	struct kthread_work___83 *current_work;
};

struct kthread_delayed_work___83 {
	struct kthread_work___83 work;
	struct timer_list timer;
};

struct dentry_operations___106;

struct super_block___107;

struct dentry___107 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___107 *d_parent;
	struct qstr d_name;
	struct inode___108 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___106 *d_op;
	struct super_block___107 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___106;

struct address_space___106 {
	struct inode___108 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___107 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___106 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___106;

struct block_device___107;

struct inode___108 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___106 *i_op;
	struct super_block___107 *i_sb;
	struct address_space___106 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___107 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___107 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___106 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___107 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___106;

struct dentry_operations___106 {
	int (*d_revalidate)(struct dentry___107 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___107 *, unsigned int);
	int (*d_hash)(const struct dentry___107 *, struct qstr *);
	int (*d_compare)(const struct dentry___107 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___107 *);
	int (*d_init)(struct dentry___107 *);
	void (*d_release)(struct dentry___107 *);
	void (*d_prune)(struct dentry___107 *);
	void (*d_iput)(struct dentry___107 *, struct inode___108 *);
	char * (*d_dname)(struct dentry___107 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___106 *);
	int (*d_manage)(const struct path___106 *, bool);
	struct dentry___107 * (*d_real)(struct dentry___107 *, const struct inode___108 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___106;

struct mem_dqinfo___106 {
	struct quota_format_type___106 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___106;

struct quota_info___106 {
	unsigned int flags;
	struct rw_semaphore___107 dqio_sem;
	struct inode___108 *files[3];
	struct mem_dqinfo___106 info[3];
	const struct quota_format_ops___106 *ops[3];
};

struct rcuwait___106 {
	struct task_struct___107 *task;
};

struct percpu_rw_semaphore___106 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___107 rw_sem;
	struct rcuwait___106 writer;
	int readers_block;
};

struct sb_writers___106 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___106 rw_sem[3];
};

struct file_system_type___106;

struct super_operations___106;

struct dquot_operations___106;

struct quotactl_ops___106;

struct super_block___107 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___106 *s_type;
	const struct super_operations___106 *s_op;
	const struct dquot_operations___106 *dq_op;
	const struct quotactl_ops___106 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___107 *s_root;
	struct rw_semaphore___107 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___107 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___106 s_dquot;
	struct sb_writers___106 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___106 *s_d_op;
	int cleancache_poolid;
	struct shrinker___36 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___87 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct path___106 {
	struct vfsmount *mnt;
	struct dentry___107 *dentry;
};

struct pglist_data___106;

struct lruvec___106 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___106 *pgdat;
};

struct zone___106 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___106 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___106 {
	struct zone___106 *zone;
	int zone_idx;
};

struct zonelist___106 {
	struct zoneref___106 _zonerefs[25];
};

struct pglist_data___106 {
	struct zone___106 node_zones[3];
	struct zonelist___106 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___107 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___107 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___106 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___106 {
	struct rw_semaphore___107 rwsem;
	struct notifier_block *head;
};

typedef int (*dev_page_fault_t___104)(struct vm_area_struct___107 *, long unsigned int, const struct page___107 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___104)(struct page___107 *, void *);

struct device___98;

struct dev_pagemap___104 {
	dev_page_fault_t___104 page_fault;
	dev_page_free_t___104 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___98 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct fown_struct___89 {
	rwlock_t lock;
	struct pid___89 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___107 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___106 f_path;
	struct inode___108 *f_inode;
	const struct file_operations___107 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___89 f_owner;
	const struct cred___102 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___106 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___104;

struct vm_operations_struct___104 {
	void (*open)(struct vm_area_struct___107 *);
	void (*close)(struct vm_area_struct___107 *);
	int (*split)(struct vm_area_struct___107 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___107 *);
	vm_fault_t (*fault)(struct vm_fault___104 *);
	vm_fault_t (*huge_fault)(struct vm_fault___104 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___104 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___107 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___104 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___104 *);
	int (*access)(struct vm_area_struct___107 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___107 *);
	int (*set_policy)(struct vm_area_struct___107 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___107 *, long unsigned int);
	struct page___107 * (*find_special_page)(struct vm_area_struct___107 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___106 {
	struct task_struct___107 *task;
	struct core_thread___106 *next;
};

struct core_state___106 {
	atomic_t nr_threads;
	struct core_thread___106 dumper;
	struct completion startup;
};

struct linux_binprm___17;

struct coredump_params___16;

struct linux_binfmt___16 {
	struct list_head lh;
	struct module___90 *module;
	int (*load_binary)(struct linux_binprm___17 *);
	int (*load_shlib)(struct file___107 *);
	int (*core_dump)(struct coredump_params___16 *);
	long unsigned int min_coredump;
};

struct vm_fault___104 {
	struct vm_area_struct___107 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___107 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___107 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___106 prealloc_pte;
};

struct kiocb___107 {
	struct file___107 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___107 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___107 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___107 *ia_file;
};

struct dquot___106 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___107 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___106 {
	int qf_fmt_id;
	const struct quota_format_ops___106 *qf_ops;
	struct module___90 *qf_owner;
	struct quota_format_type___106 *qf_next;
};

struct quota_format_ops___106 {
	int (*check_quota_file)(struct super_block___107 *, int);
	int (*read_file_info)(struct super_block___107 *, int);
	int (*write_file_info)(struct super_block___107 *, int);
	int (*free_file_info)(struct super_block___107 *, int);
	int (*read_dqblk)(struct dquot___106 *);
	int (*commit_dqblk)(struct dquot___106 *);
	int (*release_dqblk)(struct dquot___106 *);
	int (*get_next_id)(struct super_block___107 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___106 {
	int (*write_dquot)(struct dquot___106 *);
	struct dquot___106 * (*alloc_dquot)(struct super_block___107 *, int);
	void (*destroy_dquot)(struct dquot___106 *);
	int (*acquire_dquot)(struct dquot___106 *);
	int (*release_dquot)(struct dquot___106 *);
	int (*mark_dirty)(struct dquot___106 *);
	int (*write_info)(struct super_block___107 *, int);
	qsize_t * (*get_reserved_space)(struct inode___108 *);
	int (*get_projid)(struct inode___108 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___108 *, qsize_t *);
	int (*get_next_id)(struct super_block___107 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___106 {
	int (*quota_on)(struct super_block___107 *, int, int, const struct path___106 *);
	int (*quota_off)(struct super_block___107 *, int);
	int (*quota_enable)(struct super_block___107 *, unsigned int);
	int (*quota_disable)(struct super_block___107 *, unsigned int);
	int (*quota_sync)(struct super_block___107 *, int);
	int (*set_info)(struct super_block___107 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___107 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___107 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___107 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___107 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___107 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___100;

struct kobj_type___100;

struct kernfs_node___103;

struct kobject___101 {
	const char *name;
	struct list_head entry;
	struct kobject___101 *parent;
	struct kset___100 *kset;
	struct kobj_type___100 *ktype;
	struct kernfs_node___103 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___87 {
	struct kobject___101 kobj;
	struct module___90 *mod;
	struct kobject___101 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___87 {
	struct module___90 *mod;
	struct latch_tree_node node;
};

struct module_layout___87 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___87 mtn;
};

struct module_attribute___87;

struct kernel_param___87;

struct module___90 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___87 mkobj;
	struct module_attribute___87 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___101 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___87 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___87 core_layout;
	struct module_layout___87 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___60 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___106 {
	int (*writepage)(struct page___107 *, struct writeback_control___3 *);
	int (*readpage)(struct file___107 *, struct page___107 *);
	int (*writepages)(struct address_space___106 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___107 *);
	int (*readpages)(struct file___107 *, struct address_space___106 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___107 *, struct address_space___106 *, loff_t, unsigned int, unsigned int, struct page___107 **, void **);
	int (*write_end)(struct file___107 *, struct address_space___106 *, loff_t, unsigned int, unsigned int, struct page___107 *, void *);
	sector_t (*bmap)(struct address_space___106 *, sector_t);
	void (*invalidatepage)(struct page___107 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___107 *, gfp_t);
	void (*freepage)(struct page___107 *);
	ssize_t (*direct_IO)(struct kiocb___107 *, struct iov_iter___42 *);
	int (*migratepage)(struct address_space___106 *, struct page___107 *, struct page___107 *, enum migrate_mode);
	bool (*isolate_page)(struct page___107 *, isolate_mode_t);
	void (*putback_page)(struct page___107 *);
	int (*launder_page)(struct page___107 *);
	int (*is_partially_uptodate)(struct page___107 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___107 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___106 *, struct page___107 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___107 *, sector_t *);
	void (*swap_deactivate)(struct file___107 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___107 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___108 *bd_inode;
	struct super_block___107 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___107 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___106 {
	struct dentry___107 * (*lookup)(struct inode___108 *, struct dentry___107 *, unsigned int);
	const char * (*get_link)(struct dentry___107 *, struct inode___108 *, struct delayed_call *);
	int (*permission)(struct inode___108 *, int);
	struct posix_acl * (*get_acl)(struct inode___108 *, int);
	int (*readlink)(struct dentry___107 *, char *, int);
	int (*create)(struct inode___108 *, struct dentry___107 *, umode_t, bool);
	int (*link)(struct dentry___107 *, struct inode___108 *, struct dentry___107 *);
	int (*unlink)(struct inode___108 *, struct dentry___107 *);
	int (*symlink)(struct inode___108 *, struct dentry___107 *, const char *);
	int (*mkdir)(struct inode___108 *, struct dentry___107 *, umode_t);
	int (*rmdir)(struct inode___108 *, struct dentry___107 *);
	int (*mknod)(struct inode___108 *, struct dentry___107 *, umode_t, dev_t);
	int (*rename)(struct inode___108 *, struct dentry___107 *, struct inode___108 *, struct dentry___107 *, unsigned int);
	int (*setattr)(struct dentry___107 *, struct iattr___107 *);
	int (*getattr)(const struct path___106 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___107 *, char *, size_t);
	int (*fiemap)(struct inode___108 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___108 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___108 *, struct dentry___107 *, struct file___107 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___108 *, struct dentry___107 *, umode_t);
	int (*set_acl)(struct inode___108 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___106 {
	void (*fl_copy_lock)(struct file_lock___107 *, struct file_lock___107 *);
	void (*fl_release_private)(struct file_lock___107 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___106;

struct file_lock___107 {
	struct file_lock___107 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___107 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___106 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___106 *fl_ops;
	const struct lock_manager_operations___106 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___106 {
	int (*lm_compare_owner)(struct file_lock___107 *, struct file_lock___107 *);
	long unsigned int (*lm_owner_key)(struct file_lock___107 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___107 *);
	int (*lm_grant)(struct file_lock___107 *, int);
	bool (*lm_break)(struct file_lock___107 *);
	int (*lm_change)(struct file_lock___107 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___107 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___106 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___106 *fa_next;
	struct file___107 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___106 {
	const char *name;
	int fs_flags;
	struct dentry___107 * (*mount)(struct file_system_type___106 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___107 *);
	struct module___90 *owner;
	struct file_system_type___106 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___106 {
	struct inode___108 * (*alloc_inode)(struct super_block___107 *);
	void (*destroy_inode)(struct inode___108 *);
	void (*dirty_inode)(struct inode___108 *, int);
	int (*write_inode)(struct inode___108 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___108 *);
	void (*evict_inode)(struct inode___108 *);
	void (*put_super)(struct super_block___107 *);
	int (*sync_fs)(struct super_block___107 *, int);
	int (*freeze_super)(struct super_block___107 *);
	int (*freeze_fs)(struct super_block___107 *);
	int (*thaw_super)(struct super_block___107 *);
	int (*unfreeze_fs)(struct super_block___107 *);
	int (*statfs)(struct dentry___107 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___107 *, int *, char *);
	void (*umount_begin)(struct super_block___107 *);
	int (*show_options)(struct seq_file___97 *, struct dentry___107 *);
	int (*show_devname)(struct seq_file___97 *, struct dentry___107 *);
	int (*show_path)(struct seq_file___97 *, struct dentry___107 *);
	int (*show_stats)(struct seq_file___97 *, struct dentry___107 *);
	ssize_t (*quota_read)(struct super_block___107 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___107 *, int, const char *, size_t, loff_t);
	struct dquot___106 ** (*get_dquots)(struct inode___108 *);
	int (*bdev_try_to_free_page)(struct super_block___107 *, struct page___107 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___107 *, struct shrink_control___36 *);
	long int (*free_cached_objects)(struct super_block___107 *, struct shrink_control___36 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___69)(struct file___107 *, wait_queue_head_t *, struct poll_table_struct___70 *);

struct poll_table_struct___70 {
	poll_queue_proc___69 _qproc;
	__poll_t _key;
};

struct seq_operations___95;

struct seq_file___97 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___95 *op;
	int poll_event;
	const struct file___107 *file;
	void *private;
};

typedef int (*key_restrict_link_func_t___102)(struct key___102 *, const struct key_type *, const union key_payload *, struct key___102 *);

struct key_restriction___102;

struct key___102 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___107 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___102 *restrict_link;
};

struct key_restriction___102 {
	key_restrict_link_func_t___102 check;
	struct key___102 *key;
	struct key_type *keytype;
};

struct seq_operations___95 {
	void * (*start)(struct seq_file___97 *, loff_t *);
	void (*stop)(struct seq_file___97 *, void *);
	void * (*next)(struct seq_file___97 *, void *, loff_t *);
	int (*show)(struct seq_file___97 *, void *);
};

struct kernfs_root___103;

struct kernfs_elem_dir___103 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___103 *root;
};

struct kernfs_syscall_ops___103;

struct kernfs_root___103 {
	struct kernfs_node___103 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___103 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___103 {
	struct kernfs_node___103 *target_kn;
};

struct kernfs_ops___103;

struct kernfs_elem_attr___103 {
	const struct kernfs_ops___103 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___103 *notify_next;
};

struct kernfs_node___103 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___103 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___103 dir;
		struct kernfs_elem_symlink___103 symlink;
		struct kernfs_elem_attr___103 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___103;

struct kernfs_ops___103 {
	int (*open)(struct kernfs_open_file___103 *);
	void (*release)(struct kernfs_open_file___103 *);
	int (*seq_show)(struct seq_file___97 *, void *);
	void * (*seq_start)(struct seq_file___97 *, loff_t *);
	void * (*seq_next)(struct seq_file___97 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___97 *, void *);
	ssize_t (*read)(struct kernfs_open_file___103 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___103 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___103 *, struct vm_area_struct___107 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___103 *, struct poll_table_struct___70 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___103 {
	int (*remount_fs)(struct kernfs_root___103 *, int *, char *);
	int (*show_options)(struct seq_file___97 *, struct kernfs_root___103 *);
	int (*mkdir)(struct kernfs_node___103 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___103 *);
	int (*rename)(struct kernfs_node___103 *, struct kernfs_node___103 *, const char *);
	int (*show_path)(struct seq_file___97 *, struct kernfs_node___103 *, struct kernfs_root___103 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___103 {
	struct kernfs_node___103 *kn;
	struct file___107 *file;
	struct seq_file___97 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___104 *vm_ops;
};

struct bin_attribute___97;

struct attribute_group___97 {
	const char *name;
	umode_t (*is_visible)(struct kobject___101 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___101 *, struct bin_attribute___97 *, int);
	struct attribute **attrs;
	struct bin_attribute___97 **bin_attrs;
};

struct bin_attribute___97 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___107 *, struct kobject___101 *, struct bin_attribute___97 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___107 *, struct kobject___101 *, struct bin_attribute___97 *, char *, loff_t, size_t);
	int (*mmap)(struct file___107 *, struct kobject___101 *, struct bin_attribute___97 *, struct vm_area_struct___107 *);
};

struct sysfs_ops___100 {
	ssize_t (*show)(struct kobject___101 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___101 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___100;

struct kset___100 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___101 kobj;
	const struct kset_uevent_ops___100 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___100 {
	void (*release)(struct kobject___101 *);
	const struct sysfs_ops___100 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___5 * (*child_ns_type)(struct kobject___101 *);
	const void * (*namespace)(struct kobject___101 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___100 {
	int (* const filter)(struct kset___100 *, struct kobject___101 *);
	const char * (* const name)(struct kset___100 *, struct kobject___101 *);
	int (* const uevent)(struct kset___100 *, struct kobject___101 *, struct kobj_uevent_env *);
};

struct kobj_attribute___101 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___101 *, struct kobj_attribute___101 *, char *);
	ssize_t (*store)(struct kobject___101 *, struct kobj_attribute___101 *, const char *, size_t);
};

struct kernel_param_ops___87 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___87 *);
	int (*get)(char *, const struct kernel_param___87 *);
	void (*free)(void *);
};

struct kparam_array___87;

struct kernel_param___87 {
	const char *name;
	struct module___90 *mod;
	const struct kernel_param_ops___87 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___87 *arr;
	};
};

struct kparam_array___87 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___87 *ops;
	void *elem;
};

struct module_attribute___87 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___87 *, struct module_kobject___87 *, char *);
	ssize_t (*store)(struct module_attribute___87 *, struct module_kobject___87 *, const char *, size_t);
	void (*setup)(struct module___90 *, const char *);
	int (*test)(struct module___90 *);
	void (*free)(struct module___90 *);
};

struct trace_event_functions___8;

struct trace_event___8 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___8 *funcs;
};

struct trace_event_class___60;

struct trace_event_call___60 {
	struct list_head list;
	struct trace_event_class___60 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___8 event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___9 *prog_array;
	int (*perf_perm)(struct trace_event_call___60 *, struct perf_event___65 *);
};

struct linux_binprm___17 {
	char buf[256];
	struct vm_area_struct___107 *vma;
	long unsigned int vma_pages;
	struct mm_struct___106 *mm;
	long unsigned int p;
	unsigned int called_set_creds: 1;
	unsigned int cap_elevated: 1;
	unsigned int secureexec: 1;
	unsigned int recursion_depth;
	struct file___107 *file;
	struct cred___102 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
};

struct coredump_params___16 {
	union {
		const kernel_siginfo_t *siginfo;
		struct {
			const siginfo_t *siginfo;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	struct pt_regs *regs;
	struct file___107 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
};

struct fwnode_operations___72;

struct fwnode_handle___72 {
	struct fwnode_handle___72 *secondary;
	const struct fwnode_operations___72 *ops;
};

struct fwnode_reference_args___72;

struct fwnode_endpoint___72;

struct fwnode_operations___72 {
	struct fwnode_handle___72 * (*get)(struct fwnode_handle___72 *);
	void (*put)(struct fwnode_handle___72 *);
	bool (*device_is_available)(const struct fwnode_handle___72 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___72 *, const struct device___98 *);
	bool (*property_present)(const struct fwnode_handle___72 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___72 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___72 *, const char *, const char **, size_t);
	struct fwnode_handle___72 * (*get_parent)(const struct fwnode_handle___72 *);
	struct fwnode_handle___72 * (*get_next_child_node)(const struct fwnode_handle___72 *, struct fwnode_handle___72 *);
	struct fwnode_handle___72 * (*get_named_child_node)(const struct fwnode_handle___72 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___72 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___72 *);
	struct fwnode_handle___72 * (*graph_get_next_endpoint)(const struct fwnode_handle___72 *, struct fwnode_handle___72 *);
	struct fwnode_handle___72 * (*graph_get_remote_endpoint)(const struct fwnode_handle___72 *);
	struct fwnode_handle___72 * (*graph_get_port_parent)(struct fwnode_handle___72 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___72 *, struct fwnode_endpoint___72 *);
};

struct fwnode_endpoint___72 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___72 *local_fwnode;
};

struct fwnode_reference_args___72 {
	struct fwnode_handle___72 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct dev_pm_info___98 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___98 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___98;

struct bus_type___98;

struct device_driver___98;

struct dev_pm_domain___98;

struct device_node___36;

struct class___98;

struct device___98 {
	struct device___98 *parent;
	struct device_private *p;
	struct kobject___101 kobj;
	const char *init_name;
	const struct device_type___98 *type;
	struct mutex mutex;
	struct bus_type___98 *bus;
	struct device_driver___98 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___98 power;
	struct dev_pm_domain___98 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___36 *of_node;
	struct fwnode_handle___72 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___98 *class;
	const struct attribute_group___97 **groups;
	void (*release)(struct device___98 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct property___35 {
	char *name;
	int length;
	void *value;
	struct property___35 *next;
	long unsigned int _flags;
	struct bin_attribute___97 attr;
};

struct device_node___36 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___72 fwnode;
	struct property___35 *properties;
	struct property___35 *deadprops;
	struct device_node___36 *parent;
	struct device_node___36 *child;
	struct device_node___36 *sibling;
	struct kobject___101 kobj;
	long unsigned int _flags;
	void *data;
};

typedef void compound_page_dtor___104(struct page___107 *);

struct cgroup_namespace___83 {
	refcount_t count;
	struct ns_common___7 ns;
	struct user_namespace___87 *user_ns;
	struct ucounts___87 *ucounts;
	struct css_set___83 *root_cset;
};

struct ucounts___87 {
	struct hlist_node node;
	struct user_namespace___87 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct dev_pm_ops___98 {
	int (*prepare)(struct device___98 *);
	void (*complete)(struct device___98 *);
	int (*suspend)(struct device___98 *);
	int (*resume)(struct device___98 *);
	int (*freeze)(struct device___98 *);
	int (*thaw)(struct device___98 *);
	int (*poweroff)(struct device___98 *);
	int (*restore)(struct device___98 *);
	int (*suspend_late)(struct device___98 *);
	int (*resume_early)(struct device___98 *);
	int (*freeze_late)(struct device___98 *);
	int (*thaw_early)(struct device___98 *);
	int (*poweroff_late)(struct device___98 *);
	int (*restore_early)(struct device___98 *);
	int (*suspend_noirq)(struct device___98 *);
	int (*resume_noirq)(struct device___98 *);
	int (*freeze_noirq)(struct device___98 *);
	int (*thaw_noirq)(struct device___98 *);
	int (*poweroff_noirq)(struct device___98 *);
	int (*restore_noirq)(struct device___98 *);
	int (*runtime_suspend)(struct device___98 *);
	int (*runtime_resume)(struct device___98 *);
	int (*runtime_idle)(struct device___98 *);
};

struct dev_pm_domain___98 {
	struct dev_pm_ops___98 ops;
	void (*detach)(struct device___98 *, bool);
	int (*activate)(struct device___98 *);
	void (*sync)(struct device___98 *);
	void (*dismiss)(struct device___98 *);
};

struct bus_type___98 {
	const char *name;
	const char *dev_name;
	struct device___98 *dev_root;
	const struct attribute_group___97 **bus_groups;
	const struct attribute_group___97 **dev_groups;
	const struct attribute_group___97 **drv_groups;
	int (*match)(struct device___98 *, struct device_driver___98 *);
	int (*uevent)(struct device___98 *, struct kobj_uevent_env *);
	int (*probe)(struct device___98 *);
	int (*remove)(struct device___98 *);
	void (*shutdown)(struct device___98 *);
	int (*online)(struct device___98 *);
	int (*offline)(struct device___98 *);
	int (*suspend)(struct device___98 *, pm_message_t);
	int (*resume)(struct device___98 *);
	int (*num_vf)(struct device___98 *);
	int (*dma_configure)(struct device___98 *);
	const struct dev_pm_ops___98 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___98 {
	const char *name;
	struct bus_type___98 *bus;
	struct module___90 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___98 *);
	int (*remove)(struct device___98 *);
	void (*shutdown)(struct device___98 *);
	int (*suspend)(struct device___98 *, pm_message_t);
	int (*resume)(struct device___98 *);
	const struct attribute_group___97 **groups;
	const struct dev_pm_ops___98 *pm;
	void (*coredump)(struct device___98 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___98 {
	const char *name;
	const struct attribute_group___97 **groups;
	int (*uevent)(struct device___98 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___98 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___98 *);
	const struct dev_pm_ops___98 *pm;
};

struct class___98 {
	const char *name;
	struct module___90 *owner;
	const struct attribute_group___97 **class_groups;
	const struct attribute_group___97 **dev_groups;
	struct kobject___101 *dev_kobj;
	int (*dev_uevent)(struct device___98 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___98 *, umode_t *);
	void (*class_release)(struct class___98 *);
	void (*dev_release)(struct device___98 *);
	int (*shutdown_pre)(struct device___98 *);
	const struct kobj_ns_type_operations___5 *ns_type;
	const void * (*namespace)(struct device___98 *);
	const struct dev_pm_ops___98 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___84 {
	struct device___98 dev;
};

struct bpf_map___83;

struct bpf_map_ops___83 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___83 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___83 *, struct file___107 *);
	void (*map_free)(struct bpf_map___83 *);
	int (*map_get_next_key)(struct bpf_map___83 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___83 *);
	void * (*map_lookup_elem)(struct bpf_map___83 *, void *);
	int (*map_update_elem)(struct bpf_map___83 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___83 *, void *);
	int (*map_push_elem)(struct bpf_map___83 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___83 *, void *);
	int (*map_peek_elem)(struct bpf_map___83 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___83 *, struct file___107 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___83 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___83 *, void *, struct seq_file___97 *);
	int (*map_check_btf)(const struct bpf_map___83 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___83 {
	const struct bpf_map_ops___83 *ops;
	struct bpf_map___83 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___102 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct psi_group___83 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___83 *poll_kworker;
	struct kthread_delayed_work___83 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___83 {
	struct kernfs_node___103 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___83;

struct cgroup_subsys_state___83 {
	struct cgroup___83 *cgroup;
	struct cgroup_subsys___83 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___83 *parent;
};

struct cgroup_root___83;

struct cgroup_rstat_cpu___83;

struct cgroup___83 {
	struct cgroup_subsys_state___83 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___103 *kn;
	struct cgroup_file___83 procs_file;
	struct cgroup_file___83 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___83 *subsys[13];
	struct cgroup_root___83 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___83 *dom_cgrp;
	struct cgroup_rstat_cpu___83 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___9 bpf;
	atomic_t congestion_count;
	struct cgroup___83 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___83 psi;
	int ancestor_ids[0];
};

struct cftype___83;

struct cgroup_subsys___83 {
	struct cgroup_subsys_state___83 * (*css_alloc)(struct cgroup_subsys_state___83 *);
	int (*css_online)(struct cgroup_subsys_state___83 *);
	void (*css_offline)(struct cgroup_subsys_state___83 *);
	void (*css_released)(struct cgroup_subsys_state___83 *);
	void (*css_free)(struct cgroup_subsys_state___83 *);
	void (*css_reset)(struct cgroup_subsys_state___83 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___83 *, int);
	int (*css_extra_stat_show)(struct seq_file___97 *, struct cgroup_subsys_state___83 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___107 *);
	void (*cancel_fork)(struct task_struct___107 *);
	void (*fork)(struct task_struct___107 *);
	void (*exit)(struct task_struct___107 *);
	void (*free)(struct task_struct___107 *);
	void (*bind)(struct cgroup_subsys_state___83 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___83 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___83 *dfl_cftypes;
	struct cftype___83 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___83 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___83 *updated_children;
	struct cgroup___83 *updated_next;
};

struct cgroup_root___83 {
	struct kernfs_root___103 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___83 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___83 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___83 *ss;
	struct list_head node;
	struct kernfs_ops___103 *kf_ops;
	int (*open)(struct kernfs_open_file___103 *);
	void (*release)(struct kernfs_open_file___103 *);
	u64 (*read_u64)(struct cgroup_subsys_state___83 *, struct cftype___83 *);
	s64 (*read_s64)(struct cgroup_subsys_state___83 *, struct cftype___83 *);
	int (*seq_show)(struct seq_file___97 *, void *);
	void * (*seq_start)(struct seq_file___97 *, loff_t *);
	void * (*seq_next)(struct seq_file___97 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___97 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___83 *, struct cftype___83 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___83 *, struct cftype___83 *, s64);
	ssize_t (*write)(struct kernfs_open_file___103 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___103 *, struct poll_table_struct___70 *);
};

struct perf_cpu_context___65;

struct pmu___65 {
	struct list_head entry;
	struct module___90 *module;
	struct device___98 *dev;
	const struct attribute_group___97 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___65 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___65 *);
	void (*pmu_disable)(struct pmu___65 *);
	int (*event_init)(struct perf_event___65 *);
	void (*event_mapped)(struct perf_event___65 *, struct mm_struct___106 *);
	void (*event_unmapped)(struct perf_event___65 *, struct mm_struct___106 *);
	int (*add)(struct perf_event___65 *, int);
	void (*del)(struct perf_event___65 *, int);
	void (*start)(struct perf_event___65 *, int);
	void (*stop)(struct perf_event___65 *, int);
	void (*read)(struct perf_event___65 *);
	void (*start_txn)(struct pmu___65 *, unsigned int);
	int (*commit_txn)(struct pmu___65 *);
	void (*cancel_txn)(struct pmu___65 *);
	int (*event_idx)(struct perf_event___65 *);
	void (*sched_task)(struct perf_event_context___65 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___65 *);
	int (*filter_match)(struct perf_event___65 *);
	int (*check_period)(struct perf_event___65 *, u64);
};

struct perf_cpu_context___65 {
	struct perf_event_context___65 ctx;
	struct perf_event_context___65 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___65 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___65 {
	struct cgroup_subsys_state___83 css;
	struct perf_cgroup_info *info;
};

struct trace_array___8;

struct tracer___8;

struct trace_buffer___8;

struct trace_iterator___8 {
	struct trace_array___8 *tr;
	struct tracer___8 *trace;
	struct trace_buffer___8 *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

struct trace_buffer___8 {
	struct trace_array___8 *tr;
	struct ring_buffer *buffer;
	struct trace_array_cpu *data;
	u64 time_start;
	int cpu;
};

struct trace_event_file___25;

struct trace_options___8;

struct trace_array___8 {
	struct list_head list;
	char *name;
	struct trace_buffer___8 trace_buffer;
	struct trace_buffer___8 max_buffer;
	bool allocated_snapshot;
	long unsigned int max_latency;
	struct trace_pid_list *filtered_pids;
	arch_spinlock_t max_lock;
	int buffer_disabled;
	int sys_refcount_enter;
	int sys_refcount_exit;
	struct trace_event_file___25 *enter_syscall_files[295];
	struct trace_event_file___25 *exit_syscall_files[295];
	int stop_count;
	int clock_id;
	int nr_topts;
	bool clear_trace;
	struct tracer___8 *current_trace;
	unsigned int trace_flags;
	unsigned char trace_flags_index[32];
	unsigned int flags;
	raw_spinlock_t start_lock;
	struct dentry___107 *dir;
	struct dentry___107 *options;
	struct dentry___107 *percpu_dir;
	struct dentry___107 *event_dir;
	struct trace_options___8 *topts;
	struct list_head systems;
	struct list_head events;
	struct trace_event_file___25 *trace_marker_file;
	cpumask_var_t tracing_cpumask;
	int ref;
	struct ftrace_ops *ops;
	struct trace_pid_list *function_pids;
	struct list_head func_probes;
	struct list_head mod_trace;
	struct list_head mod_notrace;
	int function_enabled;
	int time_stamp_abs_ref;
	struct list_head hist_vars;
};

struct tracer_flags___8;

struct tracer___8 {
	const char *name;
	int (*init)(struct trace_array___8 *);
	void (*reset)(struct trace_array___8 *);
	void (*start)(struct trace_array___8 *);
	void (*stop)(struct trace_array___8 *);
	int (*update_thresh)(struct trace_array___8 *);
	void (*open)(struct trace_iterator___8 *);
	void (*pipe_open)(struct trace_iterator___8 *);
	void (*close)(struct trace_iterator___8 *);
	void (*pipe_close)(struct trace_iterator___8 *);
	ssize_t (*read)(struct trace_iterator___8 *, struct file___107 *, char *, size_t, loff_t *);
	ssize_t (*splice_read)(struct trace_iterator___8 *, struct file___107 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	void (*print_header)(struct seq_file___97 *);
	enum print_line_t (*print_line)(struct trace_iterator___8 *);
	int (*set_flag)(struct trace_array___8 *, u32, u32, int);
	int (*flag_changed)(struct trace_array___8 *, u32, int);
	struct tracer___8 *next;
	struct tracer_flags___8 *flags;
	int enabled;
	int ref;
	bool print_max;
	bool allow_instances;
	bool use_max_tr;
	bool noboot;
};

typedef enum print_line_t (*trace_print_func___8)(struct trace_iterator___8 *, int, struct trace_event___8 *);

struct trace_event_functions___8 {
	trace_print_func___8 trace;
	trace_print_func___8 raw;
	trace_print_func___8 hex;
	trace_print_func___8 binary;
};

struct trace_event_class___60 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___60 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___60 *);
	struct list_head * (*get_fields)(struct trace_event_call___60 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___60 *);
};

struct trace_event_buffer___19 {
	struct ring_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___25 *trace_file;
	void *entry;
	long unsigned int flags;
	int pc;
};

struct trace_subsystem_dir___9;

struct trace_event_file___25 {
	struct list_head list;
	struct trace_event_call___60 *event_call;
	struct event_filter *filter;
	struct dentry___107 *dir;
	struct trace_array___8 *tr;
	struct trace_subsystem_dir___9 *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_subsystem_dir___9 {
	struct list_head list;
	struct event_subsystem *subsystem;
	struct trace_array___8 *tr;
	struct dentry___107 *entry;
	int ref_count;
	int nr_events;
};

struct trace_option_dentry___8;

struct trace_options___8 {
	struct tracer___8 *tracer;
	struct trace_option_dentry___8 *topts;
};

struct trace_option_dentry___8 {
	struct tracer_opt *opt;
	struct tracer_flags___8 *flags;
	struct trace_array___8 *tr;
	struct dentry___107 *entry;
};

struct tracer_flags___8 {
	u32 val;
	struct tracer_opt *opts;
	struct tracer___8 *trace;
};

struct ftrace_func_command___4 {
	struct list_head list;
	char *name;
	int (*func)(struct trace_array___8 *, struct ftrace_hash *, char *, char *, char *, int);
};

struct ftrace_probe_ops___4 {
	void (*func)(long unsigned int, long unsigned int, struct trace_array___8 *, struct ftrace_probe_ops___4 *, void *);
	int (*init)(struct ftrace_probe_ops___4 *, struct trace_array___8 *, long unsigned int, void *, void **);
	void (*free)(struct ftrace_probe_ops___4 *, struct trace_array___8 *, long unsigned int, void *);
	int (*print)(struct seq_file___97 *, long unsigned int, struct ftrace_probe_ops___4 *, void *);
};

struct ftrace_event_field {
	struct list_head link;
	const char *name;
	const char *type;
	int filter_type;
	int offset;
	int size;
	int is_signed;
};

enum {
	FORMAT_HEADER = 1,
	FORMAT_FIELD_SEPERATOR = 2,
	FORMAT_PRINTFMT = 3,
};

struct event_probe_data {
	struct trace_event_file___25 *file;
	long unsigned int count;
	int ref;
	bool enable;
};

struct mmiotrace_rw {
	resource_size_t phys;
	long unsigned int value;
	long unsigned int pc;
	int map_id;
	unsigned char opcode;
	unsigned char width;
};

struct mmiotrace_map {
	resource_size_t phys;
	long unsigned int virt;
	long unsigned int len;
	int map_id;
	unsigned char opcode;
};

struct trace_mmiotrace_rw {
	struct trace_entry ent;
	struct mmiotrace_rw rw;
};

struct trace_mmiotrace_map {
	struct trace_entry ent;
	struct mmiotrace_map map;
};

struct trace_branch {
	struct trace_entry ent;
	unsigned int line;
	char func[31];
	char file[21];
	char correct;
	char constant;
};

struct module___91;

struct file___108;

struct kiocb___108;

struct poll_table_struct___71;

struct vm_area_struct___108;

struct inode___109;

struct file_lock___108;

struct page___108;

struct seq_file___98;

struct file_operations___108 {
	struct module___91 *owner;
	loff_t (*llseek)(struct file___108 *, loff_t, int);
	ssize_t (*read)(struct file___108 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___108 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___108 *, struct iov_iter___42 *);
	ssize_t (*write_iter)(struct kiocb___108 *, struct iov_iter___42 *);
	int (*iopoll)(struct kiocb___108 *, bool);
	int (*iterate)(struct file___108 *, struct dir_context *);
	int (*iterate_shared)(struct file___108 *, struct dir_context *);
	__poll_t (*poll)(struct file___108 *, struct poll_table_struct___71 *);
	long int (*unlocked_ioctl)(struct file___108 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___108 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___108 *, struct vm_area_struct___108 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___109 *, struct file___108 *);
	int (*flush)(struct file___108 *, fl_owner_t);
	int (*release)(struct inode___109 *, struct file___108 *);
	int (*fsync)(struct file___108 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___108 *, int);
	int (*lock)(struct file___108 *, int, struct file_lock___108 *);
	ssize_t (*sendpage)(struct file___108 *, struct page___108 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___108 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___108 *, int, struct file_lock___108 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___108 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___108 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___108 *, long int, struct file_lock___108 **, void **);
	long int (*fallocate)(struct file___108 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___98 *, struct file___108 *);
	ssize_t (*copy_file_range)(struct file___108 *, loff_t, struct file___108 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___108 *, loff_t, struct file___108 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___108 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___107 {
	u64 seqnum;
	struct vm_area_struct___108 *vmas[4];
};

struct page_frag___107 {
	struct page___108 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___66;

struct debug_info___66 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___66 *hbp_break[16];
	struct perf_event___66 *hbp_watch[16];
};

struct thread_struct___66 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___66 debug;
	long: 64;
};

struct mm_struct___107;

struct pid___90;

struct cred___103;

struct nsproxy___100;

struct signal_struct___97;

struct css_set___84;

struct perf_event_context___66;

struct vm_struct___79;

struct task_struct___108 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___108 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___107 *mm;
	struct mm_struct___107 *active_mm;
	struct vmacache___107 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___108 *real_parent;
	struct task_struct___108 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___108 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___90 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___90 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___90 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___103 *ptracer_cred;
	const struct cred___103 *real_cred;
	const struct cred___103 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___100 *nsproxy;
	struct signal_struct___97 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___108 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___17 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___84 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___66 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___107 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___108 *oom_reaper_list;
	struct vm_struct___79 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___66 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct secondary_data___108 {
	void *stack;
	struct task_struct___108 *task;
	long int status;
};

struct hw_perf_event___66 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___108 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___66)(struct perf_event___66 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___66;

struct fasync_struct___107;

struct pid_namespace___90;

struct trace_event_call___61;

struct perf_cgroup___66;

struct perf_event___66 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___66 *group_leader;
	struct pmu___66 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___66 hw;
	struct perf_event_context___66 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___66 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___108 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___107 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___66 *);
	struct callback_head callback_head;
	struct pid_namespace___90 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___66 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___66 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___61 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___66 *cgrp;
	struct list_head sb_list;
};

struct kset___101;

struct kobj_type___101;

struct kernfs_node___104;

struct kobject___102 {
	const char *name;
	struct list_head entry;
	struct kobject___102 *parent;
	struct kset___101 *kset;
	struct kobj_type___101 *ktype;
	struct kernfs_node___104 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___88 {
	struct kobject___102 kobj;
	struct module___91 *mod;
	struct kobject___102 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___88 {
	struct module___91 *mod;
	struct latch_tree_node node;
};

struct module_layout___88 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___88 mtn;
};

struct module_attribute___88;

struct kernel_param___88;

struct module___91 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___88 mkobj;
	struct module_attribute___88 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___102 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___88 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___88 core_layout;
	struct module_layout___88 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___61 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___108 *pgtable_t___107;

struct address_space___107;

struct dev_pagemap___105;

struct page___108 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___107 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___108 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___107 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___107 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___105 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___107;

struct lruvec___107 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___107 *pgdat;
};

struct zone___107 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___107 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___107 {
	struct zone___107 *zone;
	int zone_idx;
};

struct zonelist___107 {
	struct zoneref___107 _zonerefs[25];
};

struct pglist_data___107 {
	struct zone___107 node_zones[3];
	struct zonelist___107 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___108 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___108 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___107 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___108 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___108 *owner;
};

struct blocking_notifier_head___107 {
	struct rw_semaphore___108 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___105;

struct vm_area_struct___108 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___108 *vm_next;
	struct vm_area_struct___108 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___107 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___105 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___108 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___107;

struct user_namespace___88;

struct mm_struct___107 {
	struct {
		struct vm_area_struct___108 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___108 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___108 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___107 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___108 *owner;
		struct user_namespace___88 *user_ns;
		struct file___108 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___107 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___107;

struct address_space___107 {
	struct inode___109 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___108 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___107 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___105)(struct vm_area_struct___108 *, long unsigned int, const struct page___108 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___105)(struct page___108 *, void *);

struct device___99;

struct dev_pagemap___105 {
	dev_page_fault_t___105 page_fault;
	dev_page_free_t___105 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___99 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct dentry___108;

struct path___107 {
	struct vfsmount *mnt;
	struct dentry___108 *dentry;
};

struct fown_struct___90 {
	rwlock_t lock;
	struct pid___90 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___108 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___107 f_path;
	struct inode___109 *f_inode;
	const struct file_operations___108 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___90 f_owner;
	const struct cred___103 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___107 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___105;

struct vm_operations_struct___105 {
	void (*open)(struct vm_area_struct___108 *);
	void (*close)(struct vm_area_struct___108 *);
	int (*split)(struct vm_area_struct___108 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___108 *);
	vm_fault_t (*fault)(struct vm_fault___105 *);
	vm_fault_t (*huge_fault)(struct vm_fault___105 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___105 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___108 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___105 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___105 *);
	int (*access)(struct vm_area_struct___108 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___108 *);
	int (*set_policy)(struct vm_area_struct___108 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___108 *, long unsigned int);
	struct page___108 * (*find_special_page)(struct vm_area_struct___108 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___107 {
	struct task_struct___108 *task;
	struct core_thread___107 *next;
};

struct core_state___107 {
	atomic_t nr_threads;
	struct core_thread___107 dumper;
	struct completion startup;
};

struct key___103;

struct ucounts___88;

struct user_namespace___88 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___88 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___7 ns;
	long unsigned int flags;
	struct key___103 *persistent_keyring_register;
	struct rw_semaphore___108 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___88 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___105 {
	struct vm_area_struct___108 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___108 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___108 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___107 prealloc_pte;
};

struct upid___90 {
	int nr;
	struct pid_namespace___90 *ns;
};

struct pid_namespace___90 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___108 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___90 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___108 *proc_self;
	struct dentry___108 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___88 *user_ns;
	struct ucounts___88 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___7 ns;
};

struct pid___90 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___90 numbers[1];
};

struct user_struct___103 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___103 *uid_keyring;
	struct key___103 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___103 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___103 *session_keyring;
	struct key___103 *process_keyring;
	struct key___103 *thread_keyring;
	struct key___103 *request_key_auth;
	void *security;
	struct user_struct___103 *user;
	struct user_namespace___88 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___84;

struct nsproxy___100 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___90 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___84 *cgroup_ns;
};

struct signal_struct___97 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___108 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___108 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___90 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___90 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___107 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___90 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___84;

struct cgroup___84;

struct css_set___84 {
	struct cgroup_subsys_state___84 *subsys[13];
	refcount_t refcount;
	struct css_set___84 *dom_cset;
	struct cgroup___84 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___84 *mg_src_cgrp;
	struct cgroup___84 *mg_dst_cgrp;
	struct css_set___84 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___66 {
	struct pmu___66 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___108 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___66 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___79 {
	struct vm_struct___79 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___108 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___97 {
	struct task_struct___108 task;
	long unsigned int stack[8192];
};

struct dev_pm_info___99 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___99 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___99;

struct bus_type___99;

struct device_driver___99;

struct dev_pm_domain___99;

struct device_node___37;

struct fwnode_handle___73;

struct class___99;

struct attribute_group___98;

struct device___99 {
	struct device___99 *parent;
	struct device_private *p;
	struct kobject___102 kobj;
	const char *init_name;
	const struct device_type___99 *type;
	struct mutex mutex;
	struct bus_type___99 *bus;
	struct device_driver___99 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___99 power;
	struct dev_pm_domain___99 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___37 *of_node;
	struct fwnode_handle___73 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___99 *class;
	const struct attribute_group___98 **groups;
	void (*release)(struct device___99 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___107;

struct super_block___108;

struct dentry___108 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___108 *d_parent;
	struct qstr d_name;
	struct inode___109 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___107 *d_op;
	struct super_block___108 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___107;

struct block_device___108;

struct inode___109 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___107 *i_op;
	struct super_block___108 *i_sb;
	struct address_space___107 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___108 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___108 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___107 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___108 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___107 {
	int (*d_revalidate)(struct dentry___108 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___108 *, unsigned int);
	int (*d_hash)(const struct dentry___108 *, struct qstr *);
	int (*d_compare)(const struct dentry___108 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___108 *);
	int (*d_init)(struct dentry___108 *);
	void (*d_release)(struct dentry___108 *);
	void (*d_prune)(struct dentry___108 *);
	void (*d_iput)(struct dentry___108 *, struct inode___109 *);
	char * (*d_dname)(struct dentry___108 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___107 *);
	int (*d_manage)(const struct path___107 *, bool);
	struct dentry___108 * (*d_real)(struct dentry___108 *, const struct inode___109 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___107;

struct mem_dqinfo___107 {
	struct quota_format_type___107 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___107;

struct quota_info___107 {
	unsigned int flags;
	struct rw_semaphore___108 dqio_sem;
	struct inode___109 *files[3];
	struct mem_dqinfo___107 info[3];
	const struct quota_format_ops___107 *ops[3];
};

struct rcuwait___107 {
	struct task_struct___108 *task;
};

struct percpu_rw_semaphore___107 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___108 rw_sem;
	struct rcuwait___107 writer;
	int readers_block;
};

struct sb_writers___107 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___107 rw_sem[3];
};

struct file_system_type___107;

struct super_operations___107;

struct dquot_operations___107;

struct quotactl_ops___107;

struct super_block___108 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___107 *s_type;
	const struct super_operations___107 *s_op;
	const struct dquot_operations___107 *dq_op;
	const struct quotactl_ops___107 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___108 *s_root;
	struct rw_semaphore___108 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___108 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___107 s_dquot;
	struct sb_writers___107 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___107 *s_d_op;
	int cleancache_poolid;
	struct shrinker___36 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___88 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___108 {
	struct file___108 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___108 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___108 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___108 *ia_file;
};

struct dquot___107 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___108 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___107 {
	int qf_fmt_id;
	const struct quota_format_ops___107 *qf_ops;
	struct module___91 *qf_owner;
	struct quota_format_type___107 *qf_next;
};

struct quota_format_ops___107 {
	int (*check_quota_file)(struct super_block___108 *, int);
	int (*read_file_info)(struct super_block___108 *, int);
	int (*write_file_info)(struct super_block___108 *, int);
	int (*free_file_info)(struct super_block___108 *, int);
	int (*read_dqblk)(struct dquot___107 *);
	int (*commit_dqblk)(struct dquot___107 *);
	int (*release_dqblk)(struct dquot___107 *);
	int (*get_next_id)(struct super_block___108 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___107 {
	int (*write_dquot)(struct dquot___107 *);
	struct dquot___107 * (*alloc_dquot)(struct super_block___108 *, int);
	void (*destroy_dquot)(struct dquot___107 *);
	int (*acquire_dquot)(struct dquot___107 *);
	int (*release_dquot)(struct dquot___107 *);
	int (*mark_dirty)(struct dquot___107 *);
	int (*write_info)(struct super_block___108 *, int);
	qsize_t * (*get_reserved_space)(struct inode___109 *);
	int (*get_projid)(struct inode___109 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___109 *, qsize_t *);
	int (*get_next_id)(struct super_block___108 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___107 {
	int (*quota_on)(struct super_block___108 *, int, int, const struct path___107 *);
	int (*quota_off)(struct super_block___108 *, int);
	int (*quota_enable)(struct super_block___108 *, unsigned int);
	int (*quota_disable)(struct super_block___108 *, unsigned int);
	int (*quota_sync)(struct super_block___108 *, int);
	int (*set_info)(struct super_block___108 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___108 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___108 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___108 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___108 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___108 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___107 {
	int (*writepage)(struct page___108 *, struct writeback_control___3 *);
	int (*readpage)(struct file___108 *, struct page___108 *);
	int (*writepages)(struct address_space___107 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___108 *);
	int (*readpages)(struct file___108 *, struct address_space___107 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___108 *, struct address_space___107 *, loff_t, unsigned int, unsigned int, struct page___108 **, void **);
	int (*write_end)(struct file___108 *, struct address_space___107 *, loff_t, unsigned int, unsigned int, struct page___108 *, void *);
	sector_t (*bmap)(struct address_space___107 *, sector_t);
	void (*invalidatepage)(struct page___108 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___108 *, gfp_t);
	void (*freepage)(struct page___108 *);
	ssize_t (*direct_IO)(struct kiocb___108 *, struct iov_iter___42 *);
	int (*migratepage)(struct address_space___107 *, struct page___108 *, struct page___108 *, enum migrate_mode);
	bool (*isolate_page)(struct page___108 *, isolate_mode_t);
	void (*putback_page)(struct page___108 *);
	int (*launder_page)(struct page___108 *);
	int (*is_partially_uptodate)(struct page___108 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___108 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___107 *, struct page___108 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___108 *, sector_t *);
	void (*swap_deactivate)(struct file___108 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___108 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___109 *bd_inode;
	struct super_block___108 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___108 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___107 {
	struct dentry___108 * (*lookup)(struct inode___109 *, struct dentry___108 *, unsigned int);
	const char * (*get_link)(struct dentry___108 *, struct inode___109 *, struct delayed_call *);
	int (*permission)(struct inode___109 *, int);
	struct posix_acl * (*get_acl)(struct inode___109 *, int);
	int (*readlink)(struct dentry___108 *, char *, int);
	int (*create)(struct inode___109 *, struct dentry___108 *, umode_t, bool);
	int (*link)(struct dentry___108 *, struct inode___109 *, struct dentry___108 *);
	int (*unlink)(struct inode___109 *, struct dentry___108 *);
	int (*symlink)(struct inode___109 *, struct dentry___108 *, const char *);
	int (*mkdir)(struct inode___109 *, struct dentry___108 *, umode_t);
	int (*rmdir)(struct inode___109 *, struct dentry___108 *);
	int (*mknod)(struct inode___109 *, struct dentry___108 *, umode_t, dev_t);
	int (*rename)(struct inode___109 *, struct dentry___108 *, struct inode___109 *, struct dentry___108 *, unsigned int);
	int (*setattr)(struct dentry___108 *, struct iattr___108 *);
	int (*getattr)(const struct path___107 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___108 *, char *, size_t);
	int (*fiemap)(struct inode___109 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___109 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___109 *, struct dentry___108 *, struct file___108 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___109 *, struct dentry___108 *, umode_t);
	int (*set_acl)(struct inode___109 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___107 {
	void (*fl_copy_lock)(struct file_lock___108 *, struct file_lock___108 *);
	void (*fl_release_private)(struct file_lock___108 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___107;

struct file_lock___108 {
	struct file_lock___108 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___108 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___107 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___107 *fl_ops;
	const struct lock_manager_operations___107 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___107 {
	int (*lm_compare_owner)(struct file_lock___108 *, struct file_lock___108 *);
	long unsigned int (*lm_owner_key)(struct file_lock___108 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___108 *);
	int (*lm_grant)(struct file_lock___108 *, int);
	bool (*lm_break)(struct file_lock___108 *);
	int (*lm_change)(struct file_lock___108 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___108 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___107 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___107 *fa_next;
	struct file___108 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___107 {
	const char *name;
	int fs_flags;
	struct dentry___108 * (*mount)(struct file_system_type___107 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___108 *);
	struct module___91 *owner;
	struct file_system_type___107 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___107 {
	struct inode___109 * (*alloc_inode)(struct super_block___108 *);
	void (*destroy_inode)(struct inode___109 *);
	void (*dirty_inode)(struct inode___109 *, int);
	int (*write_inode)(struct inode___109 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___109 *);
	void (*evict_inode)(struct inode___109 *);
	void (*put_super)(struct super_block___108 *);
	int (*sync_fs)(struct super_block___108 *, int);
	int (*freeze_super)(struct super_block___108 *);
	int (*freeze_fs)(struct super_block___108 *);
	int (*thaw_super)(struct super_block___108 *);
	int (*unfreeze_fs)(struct super_block___108 *);
	int (*statfs)(struct dentry___108 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___108 *, int *, char *);
	void (*umount_begin)(struct super_block___108 *);
	int (*show_options)(struct seq_file___98 *, struct dentry___108 *);
	int (*show_devname)(struct seq_file___98 *, struct dentry___108 *);
	int (*show_path)(struct seq_file___98 *, struct dentry___108 *);
	int (*show_stats)(struct seq_file___98 *, struct dentry___108 *);
	ssize_t (*quota_read)(struct super_block___108 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___108 *, int, const char *, size_t, loff_t);
	struct dquot___107 ** (*get_dquots)(struct inode___109 *);
	int (*bdev_try_to_free_page)(struct super_block___108 *, struct page___108 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___108 *, struct shrink_control___36 *);
	long int (*free_cached_objects)(struct super_block___108 *, struct shrink_control___36 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___70)(struct file___108 *, wait_queue_head_t *, struct poll_table_struct___71 *);

struct poll_table_struct___71 {
	poll_queue_proc___70 _qproc;
	__poll_t _key;
};

struct seq_operations___96;

struct seq_file___98 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___96 *op;
	int poll_event;
	const struct file___108 *file;
	void *private;
};

struct kobj_attribute___102 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___102 *, struct kobj_attribute___102 *, char *);
	ssize_t (*store)(struct kobject___102 *, struct kobj_attribute___102 *, const char *, size_t);
};

typedef void compound_page_dtor___105(struct page___108 *);

typedef int (*key_restrict_link_func_t___103)(struct key___103 *, const struct key_type *, const union key_payload *, struct key___103 *);

struct key_restriction___103;

struct key___103 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___108 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___103 *restrict_link;
};

struct key_restriction___103 {
	key_restrict_link_func_t___103 check;
	struct key___103 *key;
	struct key_type *keytype;
};

struct seq_operations___96 {
	void * (*start)(struct seq_file___98 *, loff_t *);
	void (*stop)(struct seq_file___98 *, void *);
	void * (*next)(struct seq_file___98 *, void *, loff_t *);
	int (*show)(struct seq_file___98 *, void *);
};

struct cgroup_namespace___84 {
	refcount_t count;
	struct ns_common___7 ns;
	struct user_namespace___88 *user_ns;
	struct ucounts___88 *ucounts;
	struct css_set___84 *root_cset;
};

struct ucounts___88 {
	struct hlist_node node;
	struct user_namespace___88 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct kernfs_root___104;

struct kernfs_elem_dir___104 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___104 *root;
};

struct kernfs_syscall_ops___104;

struct kernfs_root___104 {
	struct kernfs_node___104 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___104 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___104 {
	struct kernfs_node___104 *target_kn;
};

struct kernfs_ops___104;

struct kernfs_elem_attr___104 {
	const struct kernfs_ops___104 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___104 *notify_next;
};

struct kernfs_node___104 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___104 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___104 dir;
		struct kernfs_elem_symlink___104 symlink;
		struct kernfs_elem_attr___104 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___104;

struct kernfs_ops___104 {
	int (*open)(struct kernfs_open_file___104 *);
	void (*release)(struct kernfs_open_file___104 *);
	int (*seq_show)(struct seq_file___98 *, void *);
	void * (*seq_start)(struct seq_file___98 *, loff_t *);
	void * (*seq_next)(struct seq_file___98 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___98 *, void *);
	ssize_t (*read)(struct kernfs_open_file___104 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___104 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___104 *, struct vm_area_struct___108 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___104 *, struct poll_table_struct___71 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___104 {
	int (*remount_fs)(struct kernfs_root___104 *, int *, char *);
	int (*show_options)(struct seq_file___98 *, struct kernfs_root___104 *);
	int (*mkdir)(struct kernfs_node___104 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___104 *);
	int (*rename)(struct kernfs_node___104 *, struct kernfs_node___104 *, const char *);
	int (*show_path)(struct seq_file___98 *, struct kernfs_node___104 *, struct kernfs_root___104 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___104 {
	struct kernfs_node___104 *kn;
	struct file___108 *file;
	struct seq_file___98 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___105 *vm_ops;
};

struct bin_attribute___98;

struct attribute_group___98 {
	const char *name;
	umode_t (*is_visible)(struct kobject___102 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___102 *, struct bin_attribute___98 *, int);
	struct attribute **attrs;
	struct bin_attribute___98 **bin_attrs;
};

struct bin_attribute___98 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___108 *, struct kobject___102 *, struct bin_attribute___98 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___108 *, struct kobject___102 *, struct bin_attribute___98 *, char *, loff_t, size_t);
	int (*mmap)(struct file___108 *, struct kobject___102 *, struct bin_attribute___98 *, struct vm_area_struct___108 *);
};

struct sysfs_ops___101 {
	ssize_t (*show)(struct kobject___102 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___102 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___101;

struct kset___101 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___102 kobj;
	const struct kset_uevent_ops___101 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___101 {
	void (*release)(struct kobject___102 *);
	const struct sysfs_ops___101 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___5 * (*child_ns_type)(struct kobject___102 *);
	const void * (*namespace)(struct kobject___102 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___101 {
	int (* const filter)(struct kset___101 *, struct kobject___102 *);
	const char * (* const name)(struct kset___101 *, struct kobject___102 *);
	int (* const uevent)(struct kset___101 *, struct kobject___102 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___88 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___88 *);
	int (*get)(char *, const struct kernel_param___88 *);
	void (*free)(void *);
};

struct kparam_array___88;

struct kernel_param___88 {
	const char *name;
	struct module___91 *mod;
	const struct kernel_param_ops___88 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___88 *arr;
	};
};

struct kparam_array___88 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___88 *ops;
	void *elem;
};

struct module_attribute___88 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___88 *, struct module_kobject___88 *, char *);
	ssize_t (*store)(struct module_attribute___88 *, struct module_kobject___88 *, const char *, size_t);
	void (*setup)(struct module___91 *, const char *);
	int (*test)(struct module___91 *);
	void (*free)(struct module___91 *);
};

struct trace_event_functions___9;

struct trace_event___9 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___9 *funcs;
};

struct trace_event_class___61;

struct trace_event_call___61 {
	struct list_head list;
	struct trace_event_class___61 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___9 event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___9 *prog_array;
	int (*perf_perm)(struct trace_event_call___61 *, struct perf_event___66 *);
};

struct dev_pm_ops___99 {
	int (*prepare)(struct device___99 *);
	void (*complete)(struct device___99 *);
	int (*suspend)(struct device___99 *);
	int (*resume)(struct device___99 *);
	int (*freeze)(struct device___99 *);
	int (*thaw)(struct device___99 *);
	int (*poweroff)(struct device___99 *);
	int (*restore)(struct device___99 *);
	int (*suspend_late)(struct device___99 *);
	int (*resume_early)(struct device___99 *);
	int (*freeze_late)(struct device___99 *);
	int (*thaw_early)(struct device___99 *);
	int (*poweroff_late)(struct device___99 *);
	int (*restore_early)(struct device___99 *);
	int (*suspend_noirq)(struct device___99 *);
	int (*resume_noirq)(struct device___99 *);
	int (*freeze_noirq)(struct device___99 *);
	int (*thaw_noirq)(struct device___99 *);
	int (*poweroff_noirq)(struct device___99 *);
	int (*restore_noirq)(struct device___99 *);
	int (*runtime_suspend)(struct device___99 *);
	int (*runtime_resume)(struct device___99 *);
	int (*runtime_idle)(struct device___99 *);
};

struct dev_pm_domain___99 {
	struct dev_pm_ops___99 ops;
	void (*detach)(struct device___99 *, bool);
	int (*activate)(struct device___99 *);
	void (*sync)(struct device___99 *);
	void (*dismiss)(struct device___99 *);
};

struct bus_type___99 {
	const char *name;
	const char *dev_name;
	struct device___99 *dev_root;
	const struct attribute_group___98 **bus_groups;
	const struct attribute_group___98 **dev_groups;
	const struct attribute_group___98 **drv_groups;
	int (*match)(struct device___99 *, struct device_driver___99 *);
	int (*uevent)(struct device___99 *, struct kobj_uevent_env *);
	int (*probe)(struct device___99 *);
	int (*remove)(struct device___99 *);
	void (*shutdown)(struct device___99 *);
	int (*online)(struct device___99 *);
	int (*offline)(struct device___99 *);
	int (*suspend)(struct device___99 *, pm_message_t);
	int (*resume)(struct device___99 *);
	int (*num_vf)(struct device___99 *);
	int (*dma_configure)(struct device___99 *);
	const struct dev_pm_ops___99 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___99 {
	const char *name;
	struct bus_type___99 *bus;
	struct module___91 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___99 *);
	int (*remove)(struct device___99 *);
	void (*shutdown)(struct device___99 *);
	int (*suspend)(struct device___99 *, pm_message_t);
	int (*resume)(struct device___99 *);
	const struct attribute_group___98 **groups;
	const struct dev_pm_ops___99 *pm;
	void (*coredump)(struct device___99 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___99 {
	const char *name;
	const struct attribute_group___98 **groups;
	int (*uevent)(struct device___99 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___99 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___99 *);
	const struct dev_pm_ops___99 *pm;
};

struct class___99 {
	const char *name;
	struct module___91 *owner;
	const struct attribute_group___98 **class_groups;
	const struct attribute_group___98 **dev_groups;
	struct kobject___102 *dev_kobj;
	int (*dev_uevent)(struct device___99 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___99 *, umode_t *);
	void (*class_release)(struct class___99 *);
	void (*dev_release)(struct device___99 *);
	int (*shutdown_pre)(struct device___99 *);
	const struct kobj_ns_type_operations___5 *ns_type;
	const void * (*namespace)(struct device___99 *);
	const struct dev_pm_ops___99 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct fwnode_operations___73;

struct fwnode_handle___73 {
	struct fwnode_handle___73 *secondary;
	const struct fwnode_operations___73 *ops;
};

struct property___36;

struct device_node___37 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___73 fwnode;
	struct property___36 *properties;
	struct property___36 *deadprops;
	struct device_node___37 *parent;
	struct device_node___37 *child;
	struct device_node___37 *sibling;
	struct kobject___102 kobj;
	long unsigned int _flags;
	void *data;
};

struct node___85 {
	struct device___99 dev;
};

struct bpf_map___84;

struct bpf_map_ops___84 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___84 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___84 *, struct file___108 *);
	void (*map_free)(struct bpf_map___84 *);
	int (*map_get_next_key)(struct bpf_map___84 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___84 *);
	void * (*map_lookup_elem)(struct bpf_map___84 *, void *);
	int (*map_update_elem)(struct bpf_map___84 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___84 *, void *);
	int (*map_push_elem)(struct bpf_map___84 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___84 *, void *);
	int (*map_peek_elem)(struct bpf_map___84 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___84 *, struct file___108 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___84 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___84 *, void *, struct seq_file___98 *);
	int (*map_check_btf)(const struct bpf_map___84 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___84 {
	const struct bpf_map_ops___84 *ops;
	struct bpf_map___84 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___103 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___84;

typedef void (*kthread_work_func_t___84)(struct kthread_work___84 *);

struct kthread_worker___84;

struct kthread_work___84 {
	struct list_head node;
	kthread_work_func_t___84 func;
	struct kthread_worker___84 *worker;
	int canceling;
};

struct kthread_worker___84 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___108 *task;
	struct kthread_work___84 *current_work;
};

struct kthread_delayed_work___84 {
	struct kthread_work___84 work;
	struct timer_list timer;
};

struct psi_group___84 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___84 *poll_kworker;
	struct kthread_delayed_work___84 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___84 {
	struct kernfs_node___104 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___84;

struct cgroup_subsys_state___84 {
	struct cgroup___84 *cgroup;
	struct cgroup_subsys___84 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___84 *parent;
};

struct cgroup_root___84;

struct cgroup_rstat_cpu___84;

struct cgroup___84 {
	struct cgroup_subsys_state___84 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___104 *kn;
	struct cgroup_file___84 procs_file;
	struct cgroup_file___84 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___84 *subsys[13];
	struct cgroup_root___84 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___84 *dom_cgrp;
	struct cgroup_rstat_cpu___84 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___9 bpf;
	atomic_t congestion_count;
	struct cgroup___84 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___84 psi;
	int ancestor_ids[0];
};

struct cftype___84;

struct cgroup_subsys___84 {
	struct cgroup_subsys_state___84 * (*css_alloc)(struct cgroup_subsys_state___84 *);
	int (*css_online)(struct cgroup_subsys_state___84 *);
	void (*css_offline)(struct cgroup_subsys_state___84 *);
	void (*css_released)(struct cgroup_subsys_state___84 *);
	void (*css_free)(struct cgroup_subsys_state___84 *);
	void (*css_reset)(struct cgroup_subsys_state___84 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___84 *, int);
	int (*css_extra_stat_show)(struct seq_file___98 *, struct cgroup_subsys_state___84 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___108 *);
	void (*cancel_fork)(struct task_struct___108 *);
	void (*fork)(struct task_struct___108 *);
	void (*exit)(struct task_struct___108 *);
	void (*free)(struct task_struct___108 *);
	void (*bind)(struct cgroup_subsys_state___84 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___84 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___84 *dfl_cftypes;
	struct cftype___84 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___84 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___84 *updated_children;
	struct cgroup___84 *updated_next;
};

struct cgroup_root___84 {
	struct kernfs_root___104 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___84 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___84 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___84 *ss;
	struct list_head node;
	struct kernfs_ops___104 *kf_ops;
	int (*open)(struct kernfs_open_file___104 *);
	void (*release)(struct kernfs_open_file___104 *);
	u64 (*read_u64)(struct cgroup_subsys_state___84 *, struct cftype___84 *);
	s64 (*read_s64)(struct cgroup_subsys_state___84 *, struct cftype___84 *);
	int (*seq_show)(struct seq_file___98 *, void *);
	void * (*seq_start)(struct seq_file___98 *, loff_t *);
	void * (*seq_next)(struct seq_file___98 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___98 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___84 *, struct cftype___84 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___84 *, struct cftype___84 *, s64);
	ssize_t (*write)(struct kernfs_open_file___104 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___104 *, struct poll_table_struct___71 *);
};

struct perf_cpu_context___66;

struct pmu___66 {
	struct list_head entry;
	struct module___91 *module;
	struct device___99 *dev;
	const struct attribute_group___98 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___66 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___66 *);
	void (*pmu_disable)(struct pmu___66 *);
	int (*event_init)(struct perf_event___66 *);
	void (*event_mapped)(struct perf_event___66 *, struct mm_struct___107 *);
	void (*event_unmapped)(struct perf_event___66 *, struct mm_struct___107 *);
	int (*add)(struct perf_event___66 *, int);
	void (*del)(struct perf_event___66 *, int);
	void (*start)(struct perf_event___66 *, int);
	void (*stop)(struct perf_event___66 *, int);
	void (*read)(struct perf_event___66 *);
	void (*start_txn)(struct pmu___66 *, unsigned int);
	int (*commit_txn)(struct pmu___66 *);
	void (*cancel_txn)(struct pmu___66 *);
	int (*event_idx)(struct perf_event___66 *);
	void (*sched_task)(struct perf_event_context___66 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___66 *);
	int (*filter_match)(struct perf_event___66 *);
	int (*check_period)(struct perf_event___66 *, u64);
};

struct perf_cpu_context___66 {
	struct perf_event_context___66 ctx;
	struct perf_event_context___66 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___66 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___66 {
	struct cgroup_subsys_state___84 css;
	struct perf_cgroup_info *info;
};

struct trace_array___9;

struct tracer___9;

struct trace_buffer___9;

struct trace_iterator___9 {
	struct trace_array___9 *tr;
	struct tracer___9 *trace;
	struct trace_buffer___9 *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

struct trace_buffer___9 {
	struct trace_array___9 *tr;
	struct ring_buffer *buffer;
	struct trace_array_cpu *data;
	u64 time_start;
	int cpu;
};

struct trace_event_file___26;

struct trace_options___9;

struct trace_array___9 {
	struct list_head list;
	char *name;
	struct trace_buffer___9 trace_buffer;
	struct trace_buffer___9 max_buffer;
	bool allocated_snapshot;
	long unsigned int max_latency;
	struct trace_pid_list *filtered_pids;
	arch_spinlock_t max_lock;
	int buffer_disabled;
	int sys_refcount_enter;
	int sys_refcount_exit;
	struct trace_event_file___26 *enter_syscall_files[295];
	struct trace_event_file___26 *exit_syscall_files[295];
	int stop_count;
	int clock_id;
	int nr_topts;
	bool clear_trace;
	struct tracer___9 *current_trace;
	unsigned int trace_flags;
	unsigned char trace_flags_index[32];
	unsigned int flags;
	raw_spinlock_t start_lock;
	struct dentry___108 *dir;
	struct dentry___108 *options;
	struct dentry___108 *percpu_dir;
	struct dentry___108 *event_dir;
	struct trace_options___9 *topts;
	struct list_head systems;
	struct list_head events;
	struct trace_event_file___26 *trace_marker_file;
	cpumask_var_t tracing_cpumask;
	int ref;
	struct ftrace_ops *ops;
	struct trace_pid_list *function_pids;
	struct list_head func_probes;
	struct list_head mod_trace;
	struct list_head mod_notrace;
	int function_enabled;
	int time_stamp_abs_ref;
	struct list_head hist_vars;
};

struct tracer_flags___9;

struct tracer___9 {
	const char *name;
	int (*init)(struct trace_array___9 *);
	void (*reset)(struct trace_array___9 *);
	void (*start)(struct trace_array___9 *);
	void (*stop)(struct trace_array___9 *);
	int (*update_thresh)(struct trace_array___9 *);
	void (*open)(struct trace_iterator___9 *);
	void (*pipe_open)(struct trace_iterator___9 *);
	void (*close)(struct trace_iterator___9 *);
	void (*pipe_close)(struct trace_iterator___9 *);
	ssize_t (*read)(struct trace_iterator___9 *, struct file___108 *, char *, size_t, loff_t *);
	ssize_t (*splice_read)(struct trace_iterator___9 *, struct file___108 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	void (*print_header)(struct seq_file___98 *);
	enum print_line_t (*print_line)(struct trace_iterator___9 *);
	int (*set_flag)(struct trace_array___9 *, u32, u32, int);
	int (*flag_changed)(struct trace_array___9 *, u32, int);
	struct tracer___9 *next;
	struct tracer_flags___9 *flags;
	int enabled;
	int ref;
	bool print_max;
	bool allow_instances;
	bool use_max_tr;
	bool noboot;
};

typedef enum print_line_t (*trace_print_func___9)(struct trace_iterator___9 *, int, struct trace_event___9 *);

struct trace_event_functions___9 {
	trace_print_func___9 trace;
	trace_print_func___9 raw;
	trace_print_func___9 hex;
	trace_print_func___9 binary;
};

struct trace_event_class___61 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___61 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___61 *);
	struct list_head * (*get_fields)(struct trace_event_call___61 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___61 *);
};

struct trace_subsystem_dir___10;

struct trace_event_file___26 {
	struct list_head list;
	struct trace_event_call___61 *event_call;
	struct event_filter *filter;
	struct dentry___108 *dir;
	struct trace_array___9 *tr;
	struct trace_subsystem_dir___10 *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_subsystem_dir___10 {
	struct list_head list;
	struct event_subsystem *subsystem;
	struct trace_array___9 *tr;
	struct dentry___108 *entry;
	int ref_count;
	int nr_events;
};

struct syscall_metadata___24 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___61 *enter_event;
	struct trace_event_call___61 *exit_event;
};

struct fwnode_reference_args___73;

struct fwnode_endpoint___73;

struct fwnode_operations___73 {
	struct fwnode_handle___73 * (*get)(struct fwnode_handle___73 *);
	void (*put)(struct fwnode_handle___73 *);
	bool (*device_is_available)(const struct fwnode_handle___73 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___73 *, const struct device___99 *);
	bool (*property_present)(const struct fwnode_handle___73 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___73 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___73 *, const char *, const char **, size_t);
	struct fwnode_handle___73 * (*get_parent)(const struct fwnode_handle___73 *);
	struct fwnode_handle___73 * (*get_next_child_node)(const struct fwnode_handle___73 *, struct fwnode_handle___73 *);
	struct fwnode_handle___73 * (*get_named_child_node)(const struct fwnode_handle___73 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___73 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___73 *);
	struct fwnode_handle___73 * (*graph_get_next_endpoint)(const struct fwnode_handle___73 *, struct fwnode_handle___73 *);
	struct fwnode_handle___73 * (*graph_get_remote_endpoint)(const struct fwnode_handle___73 *);
	struct fwnode_handle___73 * (*graph_get_port_parent)(struct fwnode_handle___73 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___73 *, struct fwnode_endpoint___73 *);
};

struct fwnode_endpoint___73 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___73 *local_fwnode;
};

struct fwnode_reference_args___73 {
	struct fwnode_handle___73 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct property___36 {
	char *name;
	int length;
	void *value;
	struct property___36 *next;
	long unsigned int _flags;
	struct bin_attribute___98 attr;
};

struct syscall_trace_enter {
	struct trace_entry ent;
	int nr;
	long unsigned int args[0];
};

struct syscall_trace_exit {
	struct trace_entry ent;
	int nr;
	long int ret;
};

struct trace_option_dentry___9;

struct trace_options___9 {
	struct tracer___9 *tracer;
	struct trace_option_dentry___9 *topts;
};

struct trace_option_dentry___9 {
	struct tracer_opt *opt;
	struct tracer_flags___9 *flags;
	struct trace_array___9 *tr;
	struct dentry___108 *entry;
};

struct tracer_flags___9 {
	u32 val;
	struct tracer_opt *opts;
	struct tracer___9 *trace;
};

struct syscall_tp_t {
	long long unsigned int regs;
	long unsigned int syscall_nr;
	long unsigned int ret;
};

struct syscall_tp_t___2 {
	long long unsigned int regs;
	long unsigned int syscall_nr;
	long unsigned int args[6];
};

enum perf_event_sample_format {
	PERF_SAMPLE_IP = 1,
	PERF_SAMPLE_TID = 2,
	PERF_SAMPLE_TIME = 4,
	PERF_SAMPLE_ADDR = 8,
	PERF_SAMPLE_READ = 16,
	PERF_SAMPLE_CALLCHAIN = 32,
	PERF_SAMPLE_ID = 64,
	PERF_SAMPLE_CPU = 128,
	PERF_SAMPLE_PERIOD = 256,
	PERF_SAMPLE_STREAM_ID = 512,
	PERF_SAMPLE_RAW = 1024,
	PERF_SAMPLE_BRANCH_STACK = 2048,
	PERF_SAMPLE_REGS_USER = 4096,
	PERF_SAMPLE_STACK_USER = 8192,
	PERF_SAMPLE_WEIGHT = 16384,
	PERF_SAMPLE_DATA_SRC = 32768,
	PERF_SAMPLE_IDENTIFIER = 65536,
	PERF_SAMPLE_TRANSACTION = 131072,
	PERF_SAMPLE_REGS_INTR = 262144,
	PERF_SAMPLE_PHYS_ADDR = 524288,
	PERF_SAMPLE_MAX = 1048576,
	__PERF_SAMPLE_CALLCHAIN_EARLY = 0,
};

enum {
	FETCH_MTD_reg = 0,
	FETCH_MTD_stack = 1,
	FETCH_MTD_retval = 2,
	FETCH_MTD_comm = 3,
	FETCH_MTD_memory = 4,
	FETCH_MTD_symbol = 5,
	FETCH_MTD_deref = 6,
	FETCH_MTD_bitfield = 7,
	FETCH_MTD_file_offset = 8,
	FETCH_MTD_END = 9,
};

typedef long unsigned int perf_trace_t[256];

struct filter_pred;

struct prog_entry {
	int target;
	int when_to_branch;
	struct filter_pred *pred;
};

typedef int (*filter_pred_fn_t)(struct filter_pred *, void *);

struct regex;

typedef int (*regex_match_func)(char *, struct regex *, int);

struct regex {
	char pattern[256];
	int len;
	int field_len;
	regex_match_func match;
};

struct filter_pred {
	filter_pred_fn_t fn;
	u64 val;
	struct regex regex;
	short unsigned int *ops;
	struct ftrace_event_field *field;
	int offset;
	int not;
	int op;
};

enum filter_op_ids {
	OP_GLOB = 0,
	OP_NE = 1,
	OP_EQ = 2,
	OP_LE = 3,
	OP_LT = 4,
	OP_GE = 5,
	OP_GT = 6,
	OP_BAND = 7,
	OP_MAX = 8,
};

enum {
	FILT_ERR_NONE = 0,
	FILT_ERR_INVALID_OP = 1,
	FILT_ERR_TOO_MANY_OPEN = 2,
	FILT_ERR_TOO_MANY_CLOSE = 3,
	FILT_ERR_MISSING_QUOTE = 4,
	FILT_ERR_OPERAND_TOO_LONG = 5,
	FILT_ERR_EXPECT_STRING = 6,
	FILT_ERR_EXPECT_DIGIT = 7,
	FILT_ERR_ILLEGAL_FIELD_OP = 8,
	FILT_ERR_FIELD_NOT_FOUND = 9,
	FILT_ERR_ILLEGAL_INTVAL = 10,
	FILT_ERR_BAD_SUBSYS_FILTER = 11,
	FILT_ERR_TOO_MANY_PREDS = 12,
	FILT_ERR_INVALID_FILTER = 13,
	FILT_ERR_IP_FIELD_ONLY = 14,
	FILT_ERR_INVALID_VALUE = 15,
	FILT_ERR_NO_FILTER = 16,
};

struct filter_parse_error {
	int lasterr;
	int lasterr_pos;
};

typedef int (*parse_pred_fn)(const char *, void *, int, struct filter_parse_error *, struct filter_pred **);

enum {
	INVERT = 1,
	PROCESS_AND = 2,
	PROCESS_OR = 4,
};

enum {
	TOO_MANY_CLOSE = 4294967295,
	TOO_MANY_OPEN = 4294967294,
	MISSING_QUOTE = 4294967293,
};

struct filter_list {
	struct list_head list;
	struct event_filter *filter;
};

struct function_filter_data {
	struct ftrace_ops *ops;
	int first_filter;
	int first_notrace;
};

struct event_trigger_ops;

struct event_command;

struct event_trigger_data {
	long unsigned int count;
	int ref;
	struct event_trigger_ops *ops;
	struct event_command *cmd_ops;
	struct event_filter *filter;
	char *filter_str;
	void *private_data;
	bool paused;
	bool paused_tmp;
	struct list_head list;
	char *name;
	struct list_head named_list;
	struct event_trigger_data *named_data;
};

struct event_trigger_ops {
	void (*func)(struct event_trigger_data *, void *, struct ring_buffer_event *);
	int (*init)(struct event_trigger_ops *, struct event_trigger_data *);
	void (*free)(struct event_trigger_ops *, struct event_trigger_data *);
	int (*print)(struct seq_file___95 *, struct event_trigger_ops *, struct event_trigger_data *);
};

struct event_command {
	struct list_head list;
	char *name;
	enum event_trigger_type trigger_type;
	int flags;
	int (*func)(struct event_command *, struct trace_event_file___23 *, char *, char *, char *);
	int (*reg)(char *, struct event_trigger_ops *, struct event_trigger_data *, struct trace_event_file___23 *);
	void (*unreg)(char *, struct event_trigger_ops *, struct event_trigger_data *, struct trace_event_file___23 *);
	void (*unreg_all)(struct trace_event_file___23 *);
	int (*set_filter)(char *, struct event_trigger_data *, struct trace_event_file___23 *);
	struct event_trigger_ops * (*get_trigger_ops)(char *, char *);
};

struct enable_trigger_data {
	struct trace_event_file___23 *file;
	bool enable;
	bool hist;
};

enum event_command_flags {
	EVENT_CMD_FL_POST_TRIGGER = 1,
	EVENT_CMD_FL_NEEDS_REC = 2,
};

struct trace_event_buffer___20 {
	struct ring_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___23 *trace_file;
	void *entry;
	long unsigned int flags;
	int pc;
};

struct hist_field;

typedef u64 (*hist_field_fn_t)(struct hist_field *, struct tracing_map_elt *, struct ring_buffer_event *, void *);

struct hist_trigger_data;

struct hist_var {
	char *name;
	struct hist_trigger_data *hist_data;
	unsigned int idx;
};

enum field_op_id {
	FIELD_OP_NONE = 0,
	FIELD_OP_PLUS = 1,
	FIELD_OP_MINUS = 2,
	FIELD_OP_UNARY_MINUS = 3,
};

struct hist_field {
	struct ftrace_event_field *field;
	long unsigned int flags;
	hist_field_fn_t fn;
	unsigned int size;
	unsigned int offset;
	unsigned int is_signed;
	const char *type;
	struct hist_field *operands[2];
	struct hist_trigger_data *hist_data;
	struct hist_var var;
	enum field_op_id operator;
	char *system;
	char *event_name;
	char *name;
	unsigned int var_idx;
	unsigned int var_ref_idx;
	bool read_once;
};

struct hist_trigger_attrs;

struct action_data;

struct field_var;

struct field_var_hist;

struct hist_trigger_data {
	struct hist_field *fields[22];
	unsigned int n_vals;
	unsigned int n_keys;
	unsigned int n_fields;
	unsigned int n_vars;
	unsigned int key_size;
	struct tracing_map_sort_key sort_keys[2];
	unsigned int n_sort_keys;
	struct trace_event_file___23 *event_file;
	struct hist_trigger_attrs *attrs;
	struct tracing_map *map;
	bool enable_timestamps;
	bool remove;
	struct hist_field *var_refs[16];
	unsigned int n_var_refs;
	struct action_data *actions[8];
	unsigned int n_actions;
	struct hist_field *synth_var_refs[16];
	unsigned int n_synth_var_refs;
	struct field_var *field_vars[16];
	unsigned int n_field_vars;
	unsigned int n_field_var_str;
	struct field_var_hist *field_var_hists[16];
	unsigned int n_field_var_hists;
	struct field_var *max_vars[16];
	unsigned int n_max_vars;
	unsigned int n_max_var_str;
};

enum hist_field_flags {
	HIST_FIELD_FL_HITCOUNT = 1,
	HIST_FIELD_FL_KEY = 2,
	HIST_FIELD_FL_STRING = 4,
	HIST_FIELD_FL_HEX = 8,
	HIST_FIELD_FL_SYM = 16,
	HIST_FIELD_FL_SYM_OFFSET = 32,
	HIST_FIELD_FL_EXECNAME = 64,
	HIST_FIELD_FL_SYSCALL = 128,
	HIST_FIELD_FL_STACKTRACE = 256,
	HIST_FIELD_FL_LOG2 = 512,
	HIST_FIELD_FL_TIMESTAMP = 1024,
	HIST_FIELD_FL_TIMESTAMP_USECS = 2048,
	HIST_FIELD_FL_VAR = 4096,
	HIST_FIELD_FL_EXPR = 8192,
	HIST_FIELD_FL_VAR_REF = 16384,
	HIST_FIELD_FL_CPU = 32768,
	HIST_FIELD_FL_ALIAS = 65536,
};

struct var_defs {
	unsigned int n_vars;
	char *name[16];
	char *expr[16];
};

struct hist_trigger_attrs {
	char *keys_str;
	char *vals_str;
	char *sort_key_str;
	char *name;
	char *clock;
	bool pause;
	bool cont;
	bool clear;
	bool ts_in_usecs;
	unsigned int map_bits;
	char *assignment_str[16];
	unsigned int n_assignments;
	char *action_str[8];
	unsigned int n_actions;
	struct var_defs var_defs;
};

struct field_var {
	struct hist_field *var;
	struct hist_field *val;
};

struct field_var_hist {
	struct hist_trigger_data *hist_data;
	char *cmd;
};

typedef void (*action_fn_t)(struct hist_trigger_data *, struct tracing_map_elt *, void *, struct ring_buffer_event *, struct action_data *, u64 *);

struct synth_event;

struct action_data {
	action_fn_t fn;
	unsigned int n_params;
	char *params[16];
	union {
		struct {
			unsigned int var_ref_idx;
			char *match_event;
			char *match_event_system;
			char *synth_event_name;
			struct synth_event *synth_event;
		} onmatch;
		struct {
			char *var_str;
			char *fn_name;
			unsigned int max_var_ref_idx;
			struct hist_field *max_var;
			struct hist_field *var;
		} onmax;
	};
};

struct synth_field {
	char *type;
	char *name;
	size_t size;
	bool is_signed;
	bool is_string;
};

struct synth_event {
	struct list_head list;
	int ref;
	char *name;
	struct synth_field **fields;
	unsigned int n_fields;
	unsigned int n_u64;
	struct trace_event_class___58 class;
	struct trace_event_call___58 call;
	struct tracepoint *tp;
};

struct synth_trace_event {
	struct trace_entry ent;
	u64 fields[0];
};

typedef void (*synth_probe_func_t)(void *, u64 *, unsigned int);

struct hist_var_data {
	struct list_head list;
	struct hist_trigger_data *hist_data;
};

struct hist_elt_data {
	char *comm;
	u64 *var_ref_vals;
	char *field_var_str[16];
};

struct module___92;

struct file___109;

struct kiocb___109;

struct iov_iter___43;

struct poll_table_struct___72;

struct vm_area_struct___109;

struct inode___110;

struct file_lock___109;

struct page___109;

struct pipe_inode_info___24;

struct seq_file___99;

struct file_operations___109 {
	struct module___92 *owner;
	loff_t (*llseek)(struct file___109 *, loff_t, int);
	ssize_t (*read)(struct file___109 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___109 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___109 *, struct iov_iter___43 *);
	ssize_t (*write_iter)(struct kiocb___109 *, struct iov_iter___43 *);
	int (*iopoll)(struct kiocb___109 *, bool);
	int (*iterate)(struct file___109 *, struct dir_context *);
	int (*iterate_shared)(struct file___109 *, struct dir_context *);
	__poll_t (*poll)(struct file___109 *, struct poll_table_struct___72 *);
	long int (*unlocked_ioctl)(struct file___109 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___109 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___109 *, struct vm_area_struct___109 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___110 *, struct file___109 *);
	int (*flush)(struct file___109 *, fl_owner_t);
	int (*release)(struct inode___110 *, struct file___109 *);
	int (*fsync)(struct file___109 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___109 *, int);
	int (*lock)(struct file___109 *, int, struct file_lock___109 *);
	ssize_t (*sendpage)(struct file___109 *, struct page___109 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___109 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___109 *, int, struct file_lock___109 *);
	ssize_t (*splice_write)(struct pipe_inode_info___24 *, struct file___109 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___109 *, loff_t *, struct pipe_inode_info___24 *, size_t, unsigned int);
	int (*setlease)(struct file___109 *, long int, struct file_lock___109 **, void **);
	long int (*fallocate)(struct file___109 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___99 *, struct file___109 *);
	ssize_t (*copy_file_range)(struct file___109 *, loff_t, struct file___109 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___109 *, loff_t, struct file___109 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___109 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___108 {
	u64 seqnum;
	struct vm_area_struct___109 *vmas[4];
};

struct page_frag___108 {
	struct page___109 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___67;

struct debug_info___67 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___67 *hbp_break[16];
	struct perf_event___67 *hbp_watch[16];
};

struct thread_struct___67 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___67 debug;
	long: 64;
};

struct mm_struct___108;

struct pid___91;

struct cred___104;

struct nsproxy___101;

struct signal_struct___98;

struct css_set___85;

struct perf_event_context___67;

struct vm_struct___80;

struct task_struct___109 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___109 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___108 *mm;
	struct mm_struct___108 *active_mm;
	struct vmacache___108 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___109 *real_parent;
	struct task_struct___109 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___109 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___91 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___91 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___91 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___104 *ptracer_cred;
	const struct cred___104 *real_cred;
	const struct cred___104 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___101 *nsproxy;
	struct signal_struct___98 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___109 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___17 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___85 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___67 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___24 *splice_pipe;
	struct page_frag___108 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___109 *oom_reaper_list;
	struct vm_struct___80 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___67 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___67 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___109 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___67)(struct perf_event___67 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___67;

struct fasync_struct___108;

struct pid_namespace___91;

struct bpf_prog___10;

struct trace_event_call___62;

struct perf_cgroup___67;

struct perf_event___67 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___67 *group_leader;
	struct pmu___67 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___67 hw;
	struct perf_event_context___67 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___67 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___109 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___108 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___67 *);
	struct callback_head callback_head;
	struct pid_namespace___91 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___67 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___67 orig_overflow_handler;
	struct bpf_prog___10 *prog;
	struct trace_event_call___62 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___67 *cgrp;
	struct list_head sb_list;
};

typedef struct page___109 *pgtable_t___108;

struct address_space___108;

struct dev_pagemap___106;

struct page___109 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___108 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___109 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___108 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___108 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___106 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___108;

struct lruvec___108 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___108 *pgdat;
};

struct zone___108 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___108 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___108 {
	struct zone___108 *zone;
	int zone_idx;
};

struct zonelist___108 {
	struct zoneref___108 _zonerefs[25];
};

struct pglist_data___108 {
	struct zone___108 node_zones[3];
	struct zonelist___108 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___109 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___109 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___108 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___109 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___109 *owner;
};

struct secondary_data___109 {
	void *stack;
	struct task_struct___109 *task;
	long int status;
};

struct blocking_notifier_head___108 {
	struct rw_semaphore___109 rwsem;
	struct notifier_block *head;
};

struct bpf_perf_event_value {
	__u64 counter;
	__u64 enabled;
	__u64 running;
};

struct bpf_raw_tracepoint_args {
	__u64 args[0];
};

enum bpf_task_fd_type {
	BPF_FD_TYPE_RAW_TRACEPOINT = 0,
	BPF_FD_TYPE_TRACEPOINT = 1,
	BPF_FD_TYPE_KPROBE = 2,
	BPF_FD_TYPE_KRETPROBE = 3,
	BPF_FD_TYPE_UPROBE = 4,
	BPF_FD_TYPE_URETPROBE = 5,
};

struct dentry___109;

struct path___108 {
	struct vfsmount *mnt;
	struct dentry___109 *dentry;
};

struct fown_struct___91 {
	rwlock_t lock;
	struct pid___91 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___109 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___108 f_path;
	struct inode___110 *f_inode;
	const struct file_operations___109 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___91 f_owner;
	const struct cred___104 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___108 *f_mapping;
	errseq_t f_wb_err;
};

struct bpf_map___85;

struct bpf_map_ops___85 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___85 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___85 *, struct file___109 *);
	void (*map_free)(struct bpf_map___85 *);
	int (*map_get_next_key)(struct bpf_map___85 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___85 *);
	void * (*map_lookup_elem)(struct bpf_map___85 *, void *);
	int (*map_update_elem)(struct bpf_map___85 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___85 *, void *);
	int (*map_push_elem)(struct bpf_map___85 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___85 *, void *);
	int (*map_peek_elem)(struct bpf_map___85 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___85 *, struct file___109 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___85 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___85 *, void *, struct seq_file___99 *);
	int (*map_check_btf)(const struct bpf_map___85 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct user_struct___104;

struct bpf_map___85 {
	const struct bpf_map_ops___85 *ops;
	struct bpf_map___85 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___104 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct seq_operations___97;

struct seq_file___99 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___97 *op;
	int poll_event;
	const struct file___109 *file;
	void *private;
};

struct key___104;

struct user_struct___104 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___104 *uid_keyring;
	struct key___104 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bpf_offloaded_map___11;

struct bpf_map_dev_ops___11 {
	int (*map_get_next_key)(struct bpf_offloaded_map___11 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___11 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___11 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___11 *, void *);
};

struct net_device___16;

struct bpf_offloaded_map___11 {
	struct bpf_map___85 map;
	struct net_device___16 *netdev;
	const struct bpf_map_dev_ops___11 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___15;

typedef rx_handler_result_t rx_handler_func_t___11(struct sk_buff___15 **);

struct net___21;

typedef struct {
	struct net___21 *net;
} possible_net_t___12;

struct kset___102;

struct kobj_type___102;

struct kernfs_node___105;

struct kobject___103 {
	const char *name;
	struct list_head entry;
	struct kobject___103 *parent;
	struct kset___102 *kset;
	struct kobj_type___102 *ktype;
	struct kernfs_node___105 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___100;

struct dev_pm_info___100 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___100 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___100;

struct bus_type___100;

struct device_driver___100;

struct dev_pm_domain___100;

struct dma_map_ops___27;

struct device_node___38;

struct fwnode_handle___74;

struct class___100;

struct attribute_group___99;

struct device___100 {
	struct device___100 *parent;
	struct device_private *p;
	struct kobject___103 kobj;
	const char *init_name;
	const struct device_type___100 *type;
	struct mutex mutex;
	struct bus_type___100 *bus;
	struct device_driver___100 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___100 power;
	struct dev_pm_domain___100 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___27 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___38 *of_node;
	struct fwnode_handle___74 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___100 *class;
	const struct attribute_group___99 **groups;
	void (*release)(struct device___100 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct net_device_ops___11;

struct ethtool_ops___11;

struct xfrmdev_ops___11;

struct tlsdev_ops___11;

struct header_ops___11;

struct netdev_rx_queue___11;

struct mini_Qdisc___10;

struct netdev_queue___11;

struct Qdisc___10;

struct rtnl_link_ops___10;

struct dcbnl_rtnl_ops___11;

struct net_device___16 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___11 *netdev_ops;
	const struct ethtool_ops___11 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___2 *l3mdev_ops;
	const struct ndisc_ops___2 *ndisc_ops;
	const struct xfrmdev_ops___11 *xfrmdev_ops;
	const struct tlsdev_ops___11 *tlsdev_ops;
	const struct header_ops___11 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___102 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___2 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___11 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___10 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___11 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___10 *miniq_ingress;
	struct netdev_queue___11 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___11 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___10 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___10 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___11 = 0,
		NETREG_REGISTERED___11 = 1,
		NETREG_UNREGISTERING___11 = 2,
		NETREG_UNREGISTERED___11 = 3,
		NETREG_RELEASED___11 = 4,
		NETREG_DUMMY___11 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___11 = 0,
		RTNL_LINK_INITIALIZING___11 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___16 *);
	struct netpoll_info *npinfo;
	possible_net_t___12 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___100 dev;
	const struct attribute_group___99 *sysfs_groups[4];
	const struct attribute_group___99 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___10 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___11 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide35;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct bpf_prog_ops___10 {
	int (*test_run)(struct bpf_prog___10 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_aux___10;

struct bpf_prog___10 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___10 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

struct bpf_verifier_ops___10 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___10 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___10 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___10 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___10 *, u32 *);
};

struct bpf_prog_offload_ops___10 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___10 *);
	int (*translate)(struct bpf_prog___10 *);
	void (*destroy)(struct bpf_prog___10 *);
};

struct bpf_prog_offload___10 {
	struct bpf_prog___10 *prog;
	struct net_device___16 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___10 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___10 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___10 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___10 *ops;
	struct bpf_map___85 **used_maps;
	struct bpf_prog___10 *prog;
	struct user_struct___104 *user;
	u64 load_time;
	struct bpf_map___85 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___10 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_array {
	struct bpf_map___85 map;
	u32 elem_size;
	u32 index_mask;
	enum bpf_prog_type owner_prog_type;
	bool owner_jited;
	union {
		char value[0];
		void *ptrs[0];
		void *pptrs[0];
	};
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_event_entry {
	struct perf_event___67 *event;
	struct file___109 *perf_file;
	struct file___109 *map_file;
	struct callback_head rcu;
};

typedef long unsigned int (*bpf_ctx_copy_t)(void *, const void *, long unsigned int, long unsigned int);

struct bpf_prog_array_item___10 {
	struct bpf_prog___10 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___10 {
	struct callback_head rcu;
	struct bpf_prog_array_item___10 items[0];
};

typedef struct user_pt_regs bpf_user_pt_regs_t;

struct bpf_perf_event_data {
	bpf_user_pt_regs_t regs;
	__u64 sample_period;
	__u64 addr;
};

struct ucounts___89;

struct user_namespace___89 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___89 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___7 ns;
	long unsigned int flags;
	struct key___104 *persistent_keyring_register;
	struct rw_semaphore___109 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___89 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct upid___91 {
	int nr;
	struct pid_namespace___91 *ns;
};

struct pid_namespace___91 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___109 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___91 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___109 *proc_self;
	struct dentry___109 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___89 *user_ns;
	struct ucounts___89 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___7 ns;
};

struct pid___91 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___91 numbers[1];
};

struct vm_operations_struct___106;

struct vm_area_struct___109 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___109 *vm_next;
	struct vm_area_struct___109 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___108 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___106 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___109 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___108;

struct mm_struct___108 {
	struct {
		struct vm_area_struct___109 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___109 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___109 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___108 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___109 *owner;
		struct user_namespace___89 *user_ns;
		struct file___109 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___108 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___104 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___104 *session_keyring;
	struct key___104 *process_keyring;
	struct key___104 *thread_keyring;
	struct key___104 *request_key_auth;
	void *security;
	struct user_struct___104 *user;
	struct user_namespace___89 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___85;

struct nsproxy___101 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___91 *pid_ns_for_children;
	struct net___21 *net_ns;
	struct cgroup_namespace___85 *cgroup_ns;
};

struct signal_struct___98 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___109 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___109 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___91 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___91 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___108 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___91 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___85;

struct cgroup___85;

struct css_set___85 {
	struct cgroup_subsys_state___85 *subsys[13];
	refcount_t refcount;
	struct css_set___85 *dom_cset;
	struct cgroup___85 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___85 *mg_src_cgrp;
	struct cgroup___85 *mg_dst_cgrp;
	struct css_set___85 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___67 {
	struct pmu___67 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___109 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___67 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___24;

struct pipe_inode_info___24 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___109 *tmp_page;
	struct fasync_struct___108 *fasync_readers;
	struct fasync_struct___108 *fasync_writers;
	struct pipe_buffer___24 *bufs;
	struct user_struct___104 *user;
};

struct vm_struct___80 {
	struct vm_struct___80 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___109 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___98 {
	struct task_struct___109 task;
	long unsigned int stack[8192];
};

struct address_space_operations___108;

struct address_space___108 {
	struct inode___110 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___109 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___108 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___106)(struct vm_area_struct___109 *, long unsigned int, const struct page___109 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___106)(struct page___109 *, void *);

struct dev_pagemap___106 {
	dev_page_fault_t___106 page_fault;
	dev_page_free_t___106 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___100 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct vm_fault___106;

struct vm_operations_struct___106 {
	void (*open)(struct vm_area_struct___109 *);
	void (*close)(struct vm_area_struct___109 *);
	int (*split)(struct vm_area_struct___109 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___109 *);
	vm_fault_t (*fault)(struct vm_fault___106 *);
	vm_fault_t (*huge_fault)(struct vm_fault___106 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___106 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___109 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___106 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___106 *);
	int (*access)(struct vm_area_struct___109 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___109 *);
	int (*set_policy)(struct vm_area_struct___109 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___109 *, long unsigned int);
	struct page___109 * (*find_special_page)(struct vm_area_struct___109 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___108 {
	struct task_struct___109 *task;
	struct core_thread___108 *next;
};

struct core_state___108 {
	atomic_t nr_threads;
	struct core_thread___108 dumper;
	struct completion startup;
};

struct vm_fault___106 {
	struct vm_area_struct___109 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___109 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___109 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___108 prealloc_pte;
};

struct module_kobject___89 {
	struct kobject___103 kobj;
	struct module___92 *mod;
	struct kobject___103 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___89 {
	struct module___92 *mod;
	struct latch_tree_node node;
};

struct module_layout___89 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___89 mtn;
};

struct module_attribute___89;

struct kernel_param___89;

struct module___92 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___89 mkobj;
	struct module_attribute___89 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___103 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___89 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___89 core_layout;
	struct module_layout___89 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___62 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct iov_iter___43 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___3 *bvec;
		struct pipe_inode_info___24 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct kiocb___109 {
	struct file___109 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___109 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dentry_operations___108;

struct super_block___109;

struct dentry___109 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___109 *d_parent;
	struct qstr d_name;
	struct inode___110 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___108 *d_op;
	struct super_block___109 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___108;

struct block_device___109;

struct inode___110 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___108 *i_op;
	struct super_block___109 *i_sb;
	struct address_space___108 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___109 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___109 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___108 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___24 *i_pipe;
		struct block_device___109 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___108 {
	int (*d_revalidate)(struct dentry___109 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___109 *, unsigned int);
	int (*d_hash)(const struct dentry___109 *, struct qstr *);
	int (*d_compare)(const struct dentry___109 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___109 *);
	int (*d_init)(struct dentry___109 *);
	void (*d_release)(struct dentry___109 *);
	void (*d_prune)(struct dentry___109 *);
	void (*d_iput)(struct dentry___109 *, struct inode___110 *);
	char * (*d_dname)(struct dentry___109 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___108 *);
	int (*d_manage)(const struct path___108 *, bool);
	struct dentry___109 * (*d_real)(struct dentry___109 *, const struct inode___110 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___108;

struct mem_dqinfo___108 {
	struct quota_format_type___108 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___108;

struct quota_info___108 {
	unsigned int flags;
	struct rw_semaphore___109 dqio_sem;
	struct inode___110 *files[3];
	struct mem_dqinfo___108 info[3];
	const struct quota_format_ops___108 *ops[3];
};

struct rcuwait___108 {
	struct task_struct___109 *task;
};

struct percpu_rw_semaphore___108 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___109 rw_sem;
	struct rcuwait___108 writer;
	int readers_block;
};

struct sb_writers___108 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___108 rw_sem[3];
};

struct file_system_type___108;

struct super_operations___108;

struct dquot_operations___108;

struct quotactl_ops___108;

struct super_block___109 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___108 *s_type;
	const struct super_operations___108 *s_op;
	const struct dquot_operations___108 *dq_op;
	const struct quotactl_ops___108 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___109 *s_root;
	struct rw_semaphore___109 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___109 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___108 s_dquot;
	struct sb_writers___108 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___108 *s_d_op;
	int cleancache_poolid;
	struct shrinker___36 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___89 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct iattr___109 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___109 *ia_file;
};

struct dquot___108 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___109 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___108 {
	int qf_fmt_id;
	const struct quota_format_ops___108 *qf_ops;
	struct module___92 *qf_owner;
	struct quota_format_type___108 *qf_next;
};

struct quota_format_ops___108 {
	int (*check_quota_file)(struct super_block___109 *, int);
	int (*read_file_info)(struct super_block___109 *, int);
	int (*write_file_info)(struct super_block___109 *, int);
	int (*free_file_info)(struct super_block___109 *, int);
	int (*read_dqblk)(struct dquot___108 *);
	int (*commit_dqblk)(struct dquot___108 *);
	int (*release_dqblk)(struct dquot___108 *);
	int (*get_next_id)(struct super_block___109 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___108 {
	int (*write_dquot)(struct dquot___108 *);
	struct dquot___108 * (*alloc_dquot)(struct super_block___109 *, int);
	void (*destroy_dquot)(struct dquot___108 *);
	int (*acquire_dquot)(struct dquot___108 *);
	int (*release_dquot)(struct dquot___108 *);
	int (*mark_dirty)(struct dquot___108 *);
	int (*write_info)(struct super_block___109 *, int);
	qsize_t * (*get_reserved_space)(struct inode___110 *);
	int (*get_projid)(struct inode___110 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___110 *, qsize_t *);
	int (*get_next_id)(struct super_block___109 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___108 {
	int (*quota_on)(struct super_block___109 *, int, int, const struct path___108 *);
	int (*quota_off)(struct super_block___109 *, int);
	int (*quota_enable)(struct super_block___109 *, unsigned int);
	int (*quota_disable)(struct super_block___109 *, unsigned int);
	int (*quota_sync)(struct super_block___109 *, int);
	int (*set_info)(struct super_block___109 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___109 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___109 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___109 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___109 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___109 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___108 {
	int (*writepage)(struct page___109 *, struct writeback_control___3 *);
	int (*readpage)(struct file___109 *, struct page___109 *);
	int (*writepages)(struct address_space___108 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___109 *);
	int (*readpages)(struct file___109 *, struct address_space___108 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___109 *, struct address_space___108 *, loff_t, unsigned int, unsigned int, struct page___109 **, void **);
	int (*write_end)(struct file___109 *, struct address_space___108 *, loff_t, unsigned int, unsigned int, struct page___109 *, void *);
	sector_t (*bmap)(struct address_space___108 *, sector_t);
	void (*invalidatepage)(struct page___109 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___109 *, gfp_t);
	void (*freepage)(struct page___109 *);
	ssize_t (*direct_IO)(struct kiocb___109 *, struct iov_iter___43 *);
	int (*migratepage)(struct address_space___108 *, struct page___109 *, struct page___109 *, enum migrate_mode);
	bool (*isolate_page)(struct page___109 *, isolate_mode_t);
	void (*putback_page)(struct page___109 *);
	int (*launder_page)(struct page___109 *);
	int (*is_partially_uptodate)(struct page___109 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___109 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___108 *, struct page___109 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___109 *, sector_t *);
	void (*swap_deactivate)(struct file___109 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___109 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___110 *bd_inode;
	struct super_block___109 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___109 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___108 {
	struct dentry___109 * (*lookup)(struct inode___110 *, struct dentry___109 *, unsigned int);
	const char * (*get_link)(struct dentry___109 *, struct inode___110 *, struct delayed_call *);
	int (*permission)(struct inode___110 *, int);
	struct posix_acl * (*get_acl)(struct inode___110 *, int);
	int (*readlink)(struct dentry___109 *, char *, int);
	int (*create)(struct inode___110 *, struct dentry___109 *, umode_t, bool);
	int (*link)(struct dentry___109 *, struct inode___110 *, struct dentry___109 *);
	int (*unlink)(struct inode___110 *, struct dentry___109 *);
	int (*symlink)(struct inode___110 *, struct dentry___109 *, const char *);
	int (*mkdir)(struct inode___110 *, struct dentry___109 *, umode_t);
	int (*rmdir)(struct inode___110 *, struct dentry___109 *);
	int (*mknod)(struct inode___110 *, struct dentry___109 *, umode_t, dev_t);
	int (*rename)(struct inode___110 *, struct dentry___109 *, struct inode___110 *, struct dentry___109 *, unsigned int);
	int (*setattr)(struct dentry___109 *, struct iattr___109 *);
	int (*getattr)(const struct path___108 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___109 *, char *, size_t);
	int (*fiemap)(struct inode___110 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___110 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___110 *, struct dentry___109 *, struct file___109 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___110 *, struct dentry___109 *, umode_t);
	int (*set_acl)(struct inode___110 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___108 {
	void (*fl_copy_lock)(struct file_lock___109 *, struct file_lock___109 *);
	void (*fl_release_private)(struct file_lock___109 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___108;

struct file_lock___109 {
	struct file_lock___109 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___109 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___108 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___108 *fl_ops;
	const struct lock_manager_operations___108 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___108 {
	int (*lm_compare_owner)(struct file_lock___109 *, struct file_lock___109 *);
	long unsigned int (*lm_owner_key)(struct file_lock___109 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___109 *);
	int (*lm_grant)(struct file_lock___109 *, int);
	bool (*lm_break)(struct file_lock___109 *);
	int (*lm_change)(struct file_lock___109 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___109 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___108 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___108 *fa_next;
	struct file___109 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___108 {
	const char *name;
	int fs_flags;
	struct dentry___109 * (*mount)(struct file_system_type___108 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___109 *);
	struct module___92 *owner;
	struct file_system_type___108 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___108 {
	struct inode___110 * (*alloc_inode)(struct super_block___109 *);
	void (*destroy_inode)(struct inode___110 *);
	void (*dirty_inode)(struct inode___110 *, int);
	int (*write_inode)(struct inode___110 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___110 *);
	void (*evict_inode)(struct inode___110 *);
	void (*put_super)(struct super_block___109 *);
	int (*sync_fs)(struct super_block___109 *, int);
	int (*freeze_super)(struct super_block___109 *);
	int (*freeze_fs)(struct super_block___109 *);
	int (*thaw_super)(struct super_block___109 *);
	int (*unfreeze_fs)(struct super_block___109 *);
	int (*statfs)(struct dentry___109 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___109 *, int *, char *);
	void (*umount_begin)(struct super_block___109 *);
	int (*show_options)(struct seq_file___99 *, struct dentry___109 *);
	int (*show_devname)(struct seq_file___99 *, struct dentry___109 *);
	int (*show_path)(struct seq_file___99 *, struct dentry___109 *);
	int (*show_stats)(struct seq_file___99 *, struct dentry___109 *);
	ssize_t (*quota_read)(struct super_block___109 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___109 *, int, const char *, size_t, loff_t);
	struct dquot___108 ** (*get_dquots)(struct inode___110 *);
	int (*bdev_try_to_free_page)(struct super_block___109 *, struct page___109 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___109 *, struct shrink_control___36 *);
	long int (*free_cached_objects)(struct super_block___109 *, struct shrink_control___36 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___71)(struct file___109 *, wait_queue_head_t *, struct poll_table_struct___72 *);

struct poll_table_struct___72 {
	poll_queue_proc___71 _qproc;
	__poll_t _key;
};

struct nf_bridge_info___11;

struct sk_buff___15 {
	union {
		struct {
			struct sk_buff___15 *next;
			struct sk_buff___15 *prev;
			union {
				struct net_device___16 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___8 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___15 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___11 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___11;

struct netns_frags___11 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___11 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv4___11 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct sock *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock **tcp_sk;
	struct netns_frags___11 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct dst_ops___19 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___19 *);
	struct dst_entry___2 * (*check)(struct dst_entry___2 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___2 *);
	unsigned int (*mtu)(const struct dst_entry___2 *);
	u32 * (*cow_metrics)(struct dst_entry___2 *, long unsigned int);
	void (*destroy)(struct dst_entry___2 *);
	void (*ifdown)(struct dst_entry___2 *, struct net_device___16 *, int);
	struct dst_entry___2 * (*negative_advice)(struct dst_entry___2 *);
	void (*link_failure)(struct sk_buff___15 *);
	void (*update_pmtu)(struct dst_entry___2 *, struct sock *, struct sk_buff___15 *, u32);
	void (*redirect)(struct dst_entry___2 *, struct sock *, struct sk_buff___15 *);
	int (*local_out)(struct net___21 *, struct sock *, struct sk_buff___15 *);
	struct neighbour___2 * (*neigh_lookup)(const struct dst_entry___2 *, struct sk_buff___15 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___2 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___18 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___11 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___19 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct sock *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops *notifier_ops;
	struct fib_notifier_ops *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_nf_frag___11 {
	struct netns_frags___11 frags;
};

struct netns_xfrm___18 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___19 xfrm4_dst_ops;
	struct dst_ops___19 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct net___21 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___89 *user_ns;
	struct ucounts___89 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___7 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___16 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___11 ipv4;
	struct netns_ipv6___18 ipv6;
	struct netns_sctp___5 sctp;
	struct netns_nf nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___11 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock *nfnl;
	struct sock *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___18 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___10 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kernfs_root___105;

struct kernfs_elem_dir___105 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___105 *root;
};

struct kernfs_syscall_ops___105;

struct kernfs_root___105 {
	struct kernfs_node___105 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___105 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___105 {
	struct kernfs_node___105 *target_kn;
};

struct kernfs_ops___105;

struct kernfs_elem_attr___105 {
	const struct kernfs_ops___105 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___105 *notify_next;
};

struct kernfs_node___105 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___105 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___105 dir;
		struct kernfs_elem_symlink___105 symlink;
		struct kernfs_elem_attr___105 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___105;

struct kernfs_ops___105 {
	int (*open)(struct kernfs_open_file___105 *);
	void (*release)(struct kernfs_open_file___105 *);
	int (*seq_show)(struct seq_file___99 *, void *);
	void * (*seq_start)(struct seq_file___99 *, loff_t *);
	void * (*seq_next)(struct seq_file___99 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___99 *, void *);
	ssize_t (*read)(struct kernfs_open_file___105 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___105 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___105 *, struct vm_area_struct___109 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___105 *, struct poll_table_struct___72 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___105 {
	int (*remount_fs)(struct kernfs_root___105 *, int *, char *);
	int (*show_options)(struct seq_file___99 *, struct kernfs_root___105 *);
	int (*mkdir)(struct kernfs_node___105 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___105 *);
	int (*rename)(struct kernfs_node___105 *, struct kernfs_node___105 *, const char *);
	int (*show_path)(struct seq_file___99 *, struct kernfs_node___105 *, struct kernfs_root___105 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___105 {
	struct kernfs_node___105 *kn;
	struct file___109 *file;
	struct seq_file___99 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___106 *vm_ops;
};

struct bin_attribute___99;

struct attribute_group___99 {
	const char *name;
	umode_t (*is_visible)(struct kobject___103 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___103 *, struct bin_attribute___99 *, int);
	struct attribute **attrs;
	struct bin_attribute___99 **bin_attrs;
};

struct bin_attribute___99 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___109 *, struct kobject___103 *, struct bin_attribute___99 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___109 *, struct kobject___103 *, struct bin_attribute___99 *, char *, loff_t, size_t);
	int (*mmap)(struct file___109 *, struct kobject___103 *, struct bin_attribute___99 *, struct vm_area_struct___109 *);
};

struct sysfs_ops___102 {
	ssize_t (*show)(struct kobject___103 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___103 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___102;

struct kset___102 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___103 kobj;
	const struct kset_uevent_ops___102 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___102 {
	void (*release)(struct kobject___103 *);
	const struct sysfs_ops___102 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___5 * (*child_ns_type)(struct kobject___103 *);
	const void * (*namespace)(struct kobject___103 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___102 {
	int (* const filter)(struct kset___102 *, struct kobject___103 *);
	const char * (* const name)(struct kset___102 *, struct kobject___103 *);
	int (* const uevent)(struct kset___102 *, struct kobject___103 *, struct kobj_uevent_env *);
};

struct kobj_attribute___103 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___103 *, struct kobj_attribute___103 *, char *);
	ssize_t (*store)(struct kobject___103 *, struct kobj_attribute___103 *, const char *, size_t);
};

struct dev_pm_ops___100 {
	int (*prepare)(struct device___100 *);
	void (*complete)(struct device___100 *);
	int (*suspend)(struct device___100 *);
	int (*resume)(struct device___100 *);
	int (*freeze)(struct device___100 *);
	int (*thaw)(struct device___100 *);
	int (*poweroff)(struct device___100 *);
	int (*restore)(struct device___100 *);
	int (*suspend_late)(struct device___100 *);
	int (*resume_early)(struct device___100 *);
	int (*freeze_late)(struct device___100 *);
	int (*thaw_early)(struct device___100 *);
	int (*poweroff_late)(struct device___100 *);
	int (*restore_early)(struct device___100 *);
	int (*suspend_noirq)(struct device___100 *);
	int (*resume_noirq)(struct device___100 *);
	int (*freeze_noirq)(struct device___100 *);
	int (*thaw_noirq)(struct device___100 *);
	int (*poweroff_noirq)(struct device___100 *);
	int (*restore_noirq)(struct device___100 *);
	int (*runtime_suspend)(struct device___100 *);
	int (*runtime_resume)(struct device___100 *);
	int (*runtime_idle)(struct device___100 *);
};

struct dev_pm_domain___100 {
	struct dev_pm_ops___100 ops;
	void (*detach)(struct device___100 *, bool);
	int (*activate)(struct device___100 *);
	void (*sync)(struct device___100 *);
	void (*dismiss)(struct device___100 *);
};

struct bus_type___100 {
	const char *name;
	const char *dev_name;
	struct device___100 *dev_root;
	const struct attribute_group___99 **bus_groups;
	const struct attribute_group___99 **dev_groups;
	const struct attribute_group___99 **drv_groups;
	int (*match)(struct device___100 *, struct device_driver___100 *);
	int (*uevent)(struct device___100 *, struct kobj_uevent_env *);
	int (*probe)(struct device___100 *);
	int (*remove)(struct device___100 *);
	void (*shutdown)(struct device___100 *);
	int (*online)(struct device___100 *);
	int (*offline)(struct device___100 *);
	int (*suspend)(struct device___100 *, pm_message_t);
	int (*resume)(struct device___100 *);
	int (*num_vf)(struct device___100 *);
	int (*dma_configure)(struct device___100 *);
	const struct dev_pm_ops___100 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___100 {
	const char *name;
	struct bus_type___100 *bus;
	struct module___92 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___100 *);
	int (*remove)(struct device___100 *);
	void (*shutdown)(struct device___100 *);
	int (*suspend)(struct device___100 *, pm_message_t);
	int (*resume)(struct device___100 *);
	const struct attribute_group___99 **groups;
	const struct dev_pm_ops___100 *pm;
	void (*coredump)(struct device___100 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___100 {
	const char *name;
	const struct attribute_group___99 **groups;
	int (*uevent)(struct device___100 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___100 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___100 *);
	const struct dev_pm_ops___100 *pm;
};

struct class___100 {
	const char *name;
	struct module___92 *owner;
	const struct attribute_group___99 **class_groups;
	const struct attribute_group___99 **dev_groups;
	struct kobject___103 *dev_kobj;
	int (*dev_uevent)(struct device___100 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___100 *, umode_t *);
	void (*class_release)(struct class___100 *);
	void (*dev_release)(struct device___100 *);
	int (*shutdown_pre)(struct device___100 *);
	const struct kobj_ns_type_operations___5 *ns_type;
	const void * (*namespace)(struct device___100 *);
	const struct dev_pm_ops___100 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___27 {
	void * (*alloc)(struct device___100 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___100 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___100 *, struct vm_area_struct___109 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___100 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___100 *, struct page___109 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___100 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___100 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___100 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___100 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___100 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___100 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___100 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___100 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___100 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___100 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___100 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___100 *, u64);
	u64 (*get_required_mask)(struct device___100 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___74;

struct fwnode_handle___74 {
	struct fwnode_handle___74 *secondary;
	const struct fwnode_operations___74 *ops;
};

struct property___37;

struct device_node___38 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___74 fwnode;
	struct property___37 *properties;
	struct property___37 *deadprops;
	struct device_node___38 *parent;
	struct device_node___38 *child;
	struct device_node___38 *sibling;
	struct kobject___103 kobj;
	long unsigned int _flags;
	void *data;
};

typedef void compound_page_dtor___106(struct page___109 *);

struct fwnode_reference_args___74;

struct fwnode_endpoint___74;

struct fwnode_operations___74 {
	struct fwnode_handle___74 * (*get)(struct fwnode_handle___74 *);
	void (*put)(struct fwnode_handle___74 *);
	bool (*device_is_available)(const struct fwnode_handle___74 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___74 *, const struct device___100 *);
	bool (*property_present)(const struct fwnode_handle___74 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___74 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___74 *, const char *, const char **, size_t);
	struct fwnode_handle___74 * (*get_parent)(const struct fwnode_handle___74 *);
	struct fwnode_handle___74 * (*get_next_child_node)(const struct fwnode_handle___74 *, struct fwnode_handle___74 *);
	struct fwnode_handle___74 * (*get_named_child_node)(const struct fwnode_handle___74 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___74 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___74 *);
	struct fwnode_handle___74 * (*graph_get_next_endpoint)(const struct fwnode_handle___74 *, struct fwnode_handle___74 *);
	struct fwnode_handle___74 * (*graph_get_remote_endpoint)(const struct fwnode_handle___74 *);
	struct fwnode_handle___74 * (*graph_get_port_parent)(struct fwnode_handle___74 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___74 *, struct fwnode_endpoint___74 *);
};

struct fwnode_endpoint___74 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___74 *local_fwnode;
};

struct fwnode_reference_args___74 {
	struct fwnode_handle___74 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___24;

struct pipe_buffer___24 {
	struct page___109 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___24 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___24 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___24 *, struct pipe_buffer___24 *);
	void (*release)(struct pipe_inode_info___24 *, struct pipe_buffer___24 *);
	int (*steal)(struct pipe_inode_info___24 *, struct pipe_buffer___24 *);
	union {
		bool (*get)(struct pipe_inode_info___24 *, struct pipe_buffer___24 *);
		struct {
			void (*get)(struct pipe_inode_info___24 *, struct pipe_buffer___24 *);
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
};

struct nf_bridge_info___11 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___11 = 0,
		BRNF_PROTO_8021Q___11 = 1,
		BRNF_PROTO_PPPOE___11 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___16 *physindev;
	struct net_device___16 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

struct sk_buff_head___12 {
	struct sk_buff___15 *next;
	struct sk_buff___15 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct kernel_param_ops___89 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___89 *);
	int (*get)(char *, const struct kernel_param___89 *);
	void (*free)(void *);
};

struct kparam_array___89;

struct kernel_param___89 {
	const char *name;
	struct module___92 *mod;
	const struct kernel_param_ops___89 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___89 *arr;
	};
};

struct kparam_array___89 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___89 *ops;
	void *elem;
};

struct module_attribute___89 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___89 *, struct module_kobject___89 *, char *);
	ssize_t (*store)(struct module_attribute___89 *, struct module_kobject___89 *, const char *, size_t);
	void (*setup)(struct module___92 *, const char *);
	int (*test)(struct module___92 *);
	void (*free)(struct module___92 *);
};

struct trace_event_functions___10;

struct trace_event___10 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___10 *funcs;
};

struct trace_event_class___62;

struct trace_event_call___62 {
	struct list_head list;
	struct trace_event_class___62 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___10 event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___10 *prog_array;
	int (*perf_perm)(struct trace_event_call___62 *, struct perf_event___67 *);
};

struct ethtool_ops___11 {
	int (*get_settings)(struct net_device___16 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___16 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___16 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___16 *);
	void (*get_regs)(struct net_device___16 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___16 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___16 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___16 *);
	void (*set_msglevel)(struct net_device___16 *, u32);
	int (*nway_reset)(struct net_device___16 *);
	u32 (*get_link)(struct net_device___16 *);
	int (*get_eeprom_len)(struct net_device___16 *);
	int (*get_eeprom)(struct net_device___16 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___16 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___16 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___16 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___16 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___16 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___16 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___16 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___16 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___16 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___16 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___16 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___16 *);
	void (*complete)(struct net_device___16 *);
	u32 (*get_priv_flags)(struct net_device___16 *);
	int (*set_priv_flags)(struct net_device___16 *, u32);
	int (*get_sset_count)(struct net_device___16 *, int);
	int (*get_rxnfc)(struct net_device___16 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___16 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___16 *, struct ethtool_flash *);
	int (*reset)(struct net_device___16 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___16 *);
	u32 (*get_rxfh_indir_size)(struct net_device___16 *);
	int (*get_rxfh)(struct net_device___16 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___16 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___16 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___16 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___16 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___16 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___16 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___16 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___16 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___16 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___16 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___16 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___16 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___16 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___16 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___16 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___16 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___16 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___16 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___16 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___16 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___16 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	int (*get_fecparam)(struct net_device___16 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___16 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___16 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___16 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___16 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___11;

struct inet_frags___11 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___11 *, const void *);
	void (*destructor)(struct inet_frag_queue___11 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___11 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___15 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___15 *fragments_tail;
	struct sk_buff___15 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___11 *net;
	struct callback_head rcu;
};

struct ucounts___89 {
	struct hlist_node node;
	struct user_namespace___89 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

typedef int (*key_restrict_link_func_t___104)(struct key___104 *, const struct key_type *, const union key_payload *, struct key___104 *);

struct key_restriction___104;

struct key___104 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___109 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___104 *restrict_link;
};

struct key_restriction___104 {
	key_restrict_link_func_t___104 check;
	struct key___104 *key;
	struct key_type *keytype;
};

struct seq_operations___97 {
	void * (*start)(struct seq_file___99 *, loff_t *);
	void (*stop)(struct seq_file___99 *, void *);
	void * (*next)(struct seq_file___99 *, void *, loff_t *);
	int (*show)(struct seq_file___99 *, void *);
};

struct pernet_operations___11 {
	struct list_head list;
	int (*init)(struct net___21 *);
	void (*exit)(struct net___21 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___11 {
	int (*ieee_getets)(struct net_device___16 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___16 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___16 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___16 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___16 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___16 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___16 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___16 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___16 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___16 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___16 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___16 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___16 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___16 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___16 *);
	u8 (*setstate)(struct net_device___16 *, u8);
	void (*getpermhwaddr)(struct net_device___16 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___16 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___16 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___16 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___16 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___16 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___16 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___16 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___16 *, int, u8 *);
	void (*setpfccfg)(struct net_device___16 *, int, u8);
	void (*getpfccfg)(struct net_device___16 *, int, u8 *);
	u8 (*setall)(struct net_device___16 *);
	u8 (*getcap)(struct net_device___16 *, int, u8 *);
	int (*getnumtcs)(struct net_device___16 *, int, u8 *);
	int (*setnumtcs)(struct net_device___16 *, int, u8);
	u8 (*getpfcstate)(struct net_device___16 *);
	void (*setpfcstate)(struct net_device___16 *, u8);
	void (*getbcncfg)(struct net_device___16 *, int, u32 *);
	void (*setbcncfg)(struct net_device___16 *, int, u32);
	void (*getbcnrp)(struct net_device___16 *, int, u8 *);
	void (*setbcnrp)(struct net_device___16 *, int, u8);
	int (*setapp)(struct net_device___16 *, u8, u16, u8);
	int (*getapp)(struct net_device___16 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___16 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___16 *, int, u8);
	u8 (*getdcbx)(struct net_device___16 *);
	u8 (*setdcbx)(struct net_device___16 *, u8);
	int (*peer_getappinfo)(struct net_device___16 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___16 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___16 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___16 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___16 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___16 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___85 {
	refcount_t count;
	struct ns_common___7 ns;
	struct user_namespace___89 *user_ns;
	struct ucounts___89 *ucounts;
	struct css_set___85 *root_cset;
};

struct cgroup_bpf___10 {
	struct bpf_prog_array___10 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___10 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___85;

typedef void (*kthread_work_func_t___85)(struct kthread_work___85 *);

struct kthread_worker___85;

struct kthread_work___85 {
	struct list_head node;
	kthread_work_func_t___85 func;
	struct kthread_worker___85 *worker;
	int canceling;
};

struct kthread_worker___85 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___109 *task;
	struct kthread_work___85 *current_work;
};

struct kthread_delayed_work___85 {
	struct kthread_work___85 work;
	struct timer_list timer;
};

struct psi_group___85 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___85 *poll_kworker;
	struct kthread_delayed_work___85 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___85 {
	struct kernfs_node___105 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___85;

struct cgroup_subsys_state___85 {
	struct cgroup___85 *cgroup;
	struct cgroup_subsys___85 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___85 *parent;
};

struct cgroup_root___85;

struct cgroup_rstat_cpu___85;

struct cgroup___85 {
	struct cgroup_subsys_state___85 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___105 *kn;
	struct cgroup_file___85 procs_file;
	struct cgroup_file___85 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___85 *subsys[13];
	struct cgroup_root___85 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___85 *dom_cgrp;
	struct cgroup_rstat_cpu___85 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___10 bpf;
	atomic_t congestion_count;
	struct cgroup___85 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___85 psi;
	int ancestor_ids[0];
};

struct cftype___85;

struct cgroup_subsys___85 {
	struct cgroup_subsys_state___85 * (*css_alloc)(struct cgroup_subsys_state___85 *);
	int (*css_online)(struct cgroup_subsys_state___85 *);
	void (*css_offline)(struct cgroup_subsys_state___85 *);
	void (*css_released)(struct cgroup_subsys_state___85 *);
	void (*css_free)(struct cgroup_subsys_state___85 *);
	void (*css_reset)(struct cgroup_subsys_state___85 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___85 *, int);
	int (*css_extra_stat_show)(struct seq_file___99 *, struct cgroup_subsys_state___85 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___109 *);
	void (*cancel_fork)(struct task_struct___109 *);
	void (*fork)(struct task_struct___109 *);
	void (*exit)(struct task_struct___109 *);
	void (*free)(struct task_struct___109 *);
	void (*bind)(struct cgroup_subsys_state___85 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___85 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___85 *dfl_cftypes;
	struct cftype___85 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___85 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___85 *updated_children;
	struct cgroup___85 *updated_next;
};

struct cgroup_root___85 {
	struct kernfs_root___105 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___85 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___85 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___85 *ss;
	struct list_head node;
	struct kernfs_ops___105 *kf_ops;
	int (*open)(struct kernfs_open_file___105 *);
	void (*release)(struct kernfs_open_file___105 *);
	u64 (*read_u64)(struct cgroup_subsys_state___85 *, struct cftype___85 *);
	s64 (*read_s64)(struct cgroup_subsys_state___85 *, struct cftype___85 *);
	int (*seq_show)(struct seq_file___99 *, void *);
	void * (*seq_start)(struct seq_file___99 *, loff_t *);
	void * (*seq_next)(struct seq_file___99 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___99 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___85 *, struct cftype___85 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___85 *, struct cftype___85 *, s64);
	ssize_t (*write)(struct kernfs_open_file___105 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___105 *, struct poll_table_struct___72 *);
};

struct xdp_rxq_info___11 {
	struct net_device___16 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___11 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___16 *dev_rx;
};

struct netlink_callback___11 {
	struct sk_buff___15 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___11 *);
	int (*dump)(struct sk_buff___15 *, struct netlink_callback___11 *);
	int (*done)(struct netlink_callback___11 *);
	void *data;
	struct module___92 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___11 {
	int (*create)(struct sk_buff___15 *, struct net_device___16 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___15 *, unsigned char *);
	int (*cache)(const struct neighbour___2 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___16 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___11 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___11 *, int);
	int poll_owner;
	struct net_device___16 *dev;
	struct sk_buff___15 *gro_list;
	struct sk_buff___15 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___11 {
	struct net_device___16 *dev;
	struct Qdisc___10 *qdisc;
	struct Qdisc___10 *qdisc_sleeping;
	struct kobject___103 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___16 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___10 {
	struct sk_buff___15 *head;
	struct sk_buff___15 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___10;

struct Qdisc___10 {
	int (*enqueue)(struct sk_buff___15 *, struct Qdisc___10 *, struct sk_buff___15 **);
	struct sk_buff___15 * (*dequeue)(struct Qdisc___10 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___10 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___11 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___12 gso_skb;
	struct qdisc_skb_head___10 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___10 *next_sched;
	struct sk_buff_head___12 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___11 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___103 kobj;
	struct net_device___16 *dev;
	long: 64;
	struct xdp_rxq_info___11 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___11)(struct net_device___16 *, struct sk_buff___15 *, struct net_device___16 *);

struct netdev_bpf___11 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___10 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___10 *prog;
			const struct bpf_prog_offload_ops___10 *ops;
		} verifier;
		struct {
			struct bpf_prog___10 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___11 *offmap;
		};
		struct {
			struct xdp_umem *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___11 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___15 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___11 {
	int (*tls_dev_add)(struct net_device___16 *, struct sock *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___16 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___16 *, struct sock *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___11 {
	int (*ndo_init)(struct net_device___16 *);
	void (*ndo_uninit)(struct net_device___16 *);
	int (*ndo_open)(struct net_device___16 *);
	int (*ndo_stop)(struct net_device___16 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___15 *, struct net_device___16 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___15 *, struct net_device___16 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___16 *, struct sk_buff___15 *, struct net_device___16 *, select_queue_fallback_t___11);
	void (*ndo_change_rx_flags)(struct net_device___16 *, int);
	void (*ndo_set_rx_mode)(struct net_device___16 *);
	int (*ndo_set_mac_address)(struct net_device___16 *, void *);
	int (*ndo_validate_addr)(struct net_device___16 *);
	int (*ndo_do_ioctl)(struct net_device___16 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___16 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___16 *, int);
	int (*ndo_neigh_setup)(struct net_device___16 *, struct neigh_parms___3 *);
	void (*ndo_tx_timeout)(struct net_device___16 *);
	void (*ndo_get_stats64)(struct net_device___16 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___16 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___16 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___16 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___16 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___16 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___16 *);
	int (*ndo_netpoll_setup)(struct net_device___16 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___16 *);
	int (*ndo_set_vf_mac)(struct net_device___16 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___16 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___16 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___16 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___16 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___16 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___16 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___16 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___16 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___16 *, int, struct sk_buff___15 *);
	int (*ndo_set_vf_guid)(struct net_device___16 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___16 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___16 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___16 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___16 *, const struct sk_buff___15 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___16 *, struct net_device___16 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___16 *, struct net_device___16 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___16 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___16 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___16 *, struct neighbour___2 *);
	void (*ndo_neigh_destroy)(struct net_device___16 *, struct neighbour___2 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___16 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___16 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___16 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___15 *, struct netlink_callback___11 *, struct net_device___16 *, struct net_device___16 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___16 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___16 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___15 *, u32, u32, struct net_device___16 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___16 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___16 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___16 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___16 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___16 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___16 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___16 *, struct net_device___16 *);
	void (*ndo_dfwd_del_station)(struct net_device___16 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___16 *);
	int (*ndo_set_tx_maxrate)(struct net_device___16 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___16 *);
	int (*ndo_change_proto_down)(struct net_device___16 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___16 *, struct sk_buff___15 *);
	void (*ndo_set_rx_headroom)(struct net_device___16 *, int);
	int (*ndo_bpf)(struct net_device___16 *, struct netdev_bpf___11 *);
	int (*ndo_xdp_xmit)(struct net_device___16 *, int, struct xdp_frame___11 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___16 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___16 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct tcf_proto___10;

struct mini_Qdisc___10 {
	struct tcf_proto___10 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___10 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___16 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___21 *, struct net_device___16 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___16 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___16 *, struct list_head *);
	size_t (*get_size)(const struct net_device___16 *);
	int (*fill_info)(struct sk_buff___15 *, const struct net_device___16 *);
	size_t (*get_xstats_size)(const struct net_device___16 *);
	int (*fill_xstats)(struct sk_buff___15 *, const struct net_device___16 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___16 *, struct net_device___16 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___16 *, const struct net_device___16 *);
	int (*fill_slave_info)(struct sk_buff___15 *, const struct net_device___16 *, const struct net_device___16 *);
	struct net___21 * (*get_link_net)(const struct net_device___16 *);
	size_t (*get_linkxstats_size)(const struct net_device___16 *, int);
	int (*fill_linkxstats)(struct sk_buff___15 *, const struct net_device___16 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___11 {
	struct list_head poll_list;
	struct sk_buff_head___12 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___11 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___10 *output_queue;
	struct Qdisc___10 **output_queue_tailp;
	struct sk_buff___15 *completion_queue;
	struct sk_buff_head___12 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___11 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___12 input_pkt_queue;
	struct napi_struct___11 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct gnet_dump___10 {
	spinlock_t *lock;
	struct sk_buff___15 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___10;

struct Qdisc_ops___10 {
	struct Qdisc_ops___10 *next;
	const struct Qdisc_class_ops___10 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___15 *, struct Qdisc___10 *, struct sk_buff___15 **);
	struct sk_buff___15 * (*dequeue)(struct Qdisc___10 *);
	struct sk_buff___15 * (*peek)(struct Qdisc___10 *);
	int (*init)(struct Qdisc___10 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___10 *);
	void (*destroy)(struct Qdisc___10 *);
	int (*change)(struct Qdisc___10 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___10 *);
	int (*change_tx_queue_len)(struct Qdisc___10 *, unsigned int);
	int (*dump)(struct Qdisc___10 *, struct sk_buff___15 *);
	int (*dump_stats)(struct Qdisc___10 *, struct gnet_dump___10 *);
	void (*ingress_block_set)(struct Qdisc___10 *, u32);
	void (*egress_block_set)(struct Qdisc___10 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___10 *);
	u32 (*egress_block_get)(struct Qdisc___10 *);
	struct module___92 *owner;
};

struct tcf_block___10;

struct Qdisc_class_ops___10 {
	unsigned int flags;
	struct netdev_queue___11 * (*select_queue)(struct Qdisc___10 *, struct tcmsg *);
	int (*graft)(struct Qdisc___10 *, long unsigned int, struct Qdisc___10 *, struct Qdisc___10 **, struct netlink_ext_ack *);
	struct Qdisc___10 * (*leaf)(struct Qdisc___10 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___10 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___10 *, u32);
	int (*change)(struct Qdisc___10 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___10 *, long unsigned int);
	void (*walk)(struct Qdisc___10 *, struct qdisc_walker *);
	struct tcf_block___10 * (*tcf_block)(struct Qdisc___10 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___10 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___10 *, long unsigned int);
	int (*dump)(struct Qdisc___10 *, long unsigned int, struct sk_buff___15 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___10 *, long unsigned int, struct gnet_dump___10 *);
};

struct tcf_chain___10;

struct tcf_block___10 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___21 *net;
	struct Qdisc___10 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___10 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___10;

struct tcf_proto_ops___10;

struct tcf_proto___10 {
	struct tcf_proto___10 *next;
	void *root;
	int (*classify)(struct sk_buff___15 *, const struct tcf_proto___10 *, struct tcf_result___10 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___10 *ops;
	struct tcf_chain___10 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___10 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___10 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___10 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___15 *, const struct tcf_proto___10 *, struct tcf_result___10 *);
	int (*init)(struct tcf_proto___10 *);
	void (*destroy)(struct tcf_proto___10 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___10 *, u32);
	void (*put)(struct tcf_proto___10 *, void *);
	int (*change)(struct net___21 *, struct sk_buff___15 *, struct tcf_proto___10 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___10 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___10 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___10 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___21 *, struct tcf_chain___10 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___21 *, struct tcf_proto___10 *, void *, struct sk_buff___15 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___15 *, struct net___21 *, void *);
	struct module___92 *owner;
	int flags;
};

struct tcf_chain___10 {
	struct mutex filter_chain_lock;
	struct tcf_proto___10 *filter_chain;
	struct list_head list;
	struct tcf_block___10 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___10 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct bpf_redirect_info___10 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___85 *map;
	struct bpf_map___85 *map_to_flush;
	u32 kern_flags;
};

struct perf_event_query_bpf {
	__u32 ids_len;
	__u32 prog_cnt;
	__u32 ids[0];
};

struct node___86 {
	struct device___100 dev;
};

struct perf_cpu_context___67;

struct pmu___67 {
	struct list_head entry;
	struct module___92 *module;
	struct device___100 *dev;
	const struct attribute_group___99 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___67 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___67 *);
	void (*pmu_disable)(struct pmu___67 *);
	int (*event_init)(struct perf_event___67 *);
	void (*event_mapped)(struct perf_event___67 *, struct mm_struct___108 *);
	void (*event_unmapped)(struct perf_event___67 *, struct mm_struct___108 *);
	int (*add)(struct perf_event___67 *, int);
	void (*del)(struct perf_event___67 *, int);
	void (*start)(struct perf_event___67 *, int);
	void (*stop)(struct perf_event___67 *, int);
	void (*read)(struct perf_event___67 *);
	void (*start_txn)(struct pmu___67 *, unsigned int);
	int (*commit_txn)(struct pmu___67 *);
	void (*cancel_txn)(struct pmu___67 *);
	int (*event_idx)(struct perf_event___67 *);
	void (*sched_task)(struct perf_event_context___67 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___67 *);
	int (*filter_match)(struct perf_event___67 *);
	int (*check_period)(struct perf_event___67 *, u64);
};

struct perf_cpu_context___67 {
	struct perf_event_context___67 ctx;
	struct perf_event_context___67 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___67 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___67 {
	struct cgroup_subsys_state___85 css;
	struct perf_cgroup_info *info;
};

struct bpf_perf_event_data_kern {
	bpf_user_pt_regs_t *regs;
	struct perf_sample_data *data;
	struct perf_event___67 *event;
};

struct trace_array___10;

struct tracer___10;

struct trace_buffer___10;

struct trace_iterator___10 {
	struct trace_array___10 *tr;
	struct tracer___10 *trace;
	struct trace_buffer___10 *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

struct trace_buffer___10 {
	struct trace_array___10 *tr;
	struct ring_buffer *buffer;
	struct trace_array_cpu *data;
	u64 time_start;
	int cpu;
};

struct trace_event_file___27;

struct trace_options___10;

struct trace_array___10 {
	struct list_head list;
	char *name;
	struct trace_buffer___10 trace_buffer;
	struct trace_buffer___10 max_buffer;
	bool allocated_snapshot;
	long unsigned int max_latency;
	struct trace_pid_list *filtered_pids;
	arch_spinlock_t max_lock;
	int buffer_disabled;
	int sys_refcount_enter;
	int sys_refcount_exit;
	struct trace_event_file___27 *enter_syscall_files[295];
	struct trace_event_file___27 *exit_syscall_files[295];
	int stop_count;
	int clock_id;
	int nr_topts;
	bool clear_trace;
	struct tracer___10 *current_trace;
	unsigned int trace_flags;
	unsigned char trace_flags_index[32];
	unsigned int flags;
	raw_spinlock_t start_lock;
	struct dentry___109 *dir;
	struct dentry___109 *options;
	struct dentry___109 *percpu_dir;
	struct dentry___109 *event_dir;
	struct trace_options___10 *topts;
	struct list_head systems;
	struct list_head events;
	struct trace_event_file___27 *trace_marker_file;
	cpumask_var_t tracing_cpumask;
	int ref;
	struct ftrace_ops *ops;
	struct trace_pid_list *function_pids;
	struct list_head func_probes;
	struct list_head mod_trace;
	struct list_head mod_notrace;
	int function_enabled;
	int time_stamp_abs_ref;
	struct list_head hist_vars;
};

struct tracer_flags___10;

struct tracer___10 {
	const char *name;
	int (*init)(struct trace_array___10 *);
	void (*reset)(struct trace_array___10 *);
	void (*start)(struct trace_array___10 *);
	void (*stop)(struct trace_array___10 *);
	int (*update_thresh)(struct trace_array___10 *);
	void (*open)(struct trace_iterator___10 *);
	void (*pipe_open)(struct trace_iterator___10 *);
	void (*close)(struct trace_iterator___10 *);
	void (*pipe_close)(struct trace_iterator___10 *);
	ssize_t (*read)(struct trace_iterator___10 *, struct file___109 *, char *, size_t, loff_t *);
	ssize_t (*splice_read)(struct trace_iterator___10 *, struct file___109 *, loff_t *, struct pipe_inode_info___24 *, size_t, unsigned int);
	void (*print_header)(struct seq_file___99 *);
	enum print_line_t (*print_line)(struct trace_iterator___10 *);
	int (*set_flag)(struct trace_array___10 *, u32, u32, int);
	int (*flag_changed)(struct trace_array___10 *, u32, int);
	struct tracer___10 *next;
	struct tracer_flags___10 *flags;
	int enabled;
	int ref;
	bool print_max;
	bool allow_instances;
	bool use_max_tr;
	bool noboot;
};

typedef enum print_line_t (*trace_print_func___10)(struct trace_iterator___10 *, int, struct trace_event___10 *);

struct trace_event_functions___10 {
	trace_print_func___10 trace;
	trace_print_func___10 raw;
	trace_print_func___10 hex;
	trace_print_func___10 binary;
};

struct trace_event_class___62 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___62 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___62 *);
	struct list_head * (*get_fields)(struct trace_event_call___62 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___62 *);
};

struct trace_event_file___27 {
	struct list_head list;
	struct trace_event_call___62 *event_call;
	struct event_filter *filter;
	struct dentry___109 *dir;
	struct trace_array___10 *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_subsystem_dir {
	struct list_head list;
	struct event_subsystem *subsystem;
	struct trace_array___10 *tr;
	struct dentry___109 *entry;
	int ref_count;
	int nr_events;
};

struct property___37 {
	char *name;
	int length;
	void *value;
	struct property___37 *next;
	long unsigned int _flags;
	struct bin_attribute___99 attr;
};

struct trace_option_dentry___10;

struct trace_options___10 {
	struct tracer___10 *tracer;
	struct trace_option_dentry___10 *topts;
};

struct trace_option_dentry___10 {
	struct tracer_opt *opt;
	struct tracer_flags___10 *flags;
	struct trace_array___10 *tr;
	struct dentry___109 *entry;
};

struct tracer_flags___10 {
	u32 val;
	struct tracer_opt *opts;
	struct tracer___10 *trace;
};

struct bpf_trace_module {
	struct module___92 *module;
	struct list_head list;
};

struct module___93;

struct file___110;

struct kiocb___110;

struct poll_table_struct___73;

struct vm_area_struct___110;

struct inode___111;

struct file_lock___110;

struct page___110;

struct seq_file___100;

struct file_operations___110 {
	struct module___93 *owner;
	loff_t (*llseek)(struct file___110 *, loff_t, int);
	ssize_t (*read)(struct file___110 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___110 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___110 *, struct iov_iter___43 *);
	ssize_t (*write_iter)(struct kiocb___110 *, struct iov_iter___43 *);
	int (*iopoll)(struct kiocb___110 *, bool);
	int (*iterate)(struct file___110 *, struct dir_context *);
	int (*iterate_shared)(struct file___110 *, struct dir_context *);
	__poll_t (*poll)(struct file___110 *, struct poll_table_struct___73 *);
	long int (*unlocked_ioctl)(struct file___110 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___110 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___110 *, struct vm_area_struct___110 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___111 *, struct file___110 *);
	int (*flush)(struct file___110 *, fl_owner_t);
	int (*release)(struct inode___111 *, struct file___110 *);
	int (*fsync)(struct file___110 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___110 *, int);
	int (*lock)(struct file___110 *, int, struct file_lock___110 *);
	ssize_t (*sendpage)(struct file___110 *, struct page___110 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___110 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___110 *, int, struct file_lock___110 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___110 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___110 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___110 *, long int, struct file_lock___110 **, void **);
	long int (*fallocate)(struct file___110 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___100 *, struct file___110 *);
	ssize_t (*copy_file_range)(struct file___110 *, loff_t, struct file___110 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___110 *, loff_t, struct file___110 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___110 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___109 {
	u64 seqnum;
	struct vm_area_struct___110 *vmas[4];
};

struct page_frag___109 {
	struct page___110 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___68;

struct debug_info___68 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___68 *hbp_break[16];
	struct perf_event___68 *hbp_watch[16];
};

struct thread_struct___68 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___68 debug;
	long: 64;
};

struct mm_struct___109;

struct pid___92;

struct cred___105;

struct nsproxy___102;

struct signal_struct___99;

struct css_set___86;

struct perf_event_context___68;

struct vm_struct___81;

struct task_struct___110 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___110 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___109 *mm;
	struct mm_struct___109 *active_mm;
	struct vmacache___109 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___110 *real_parent;
	struct task_struct___110 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___110 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___92 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___92 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___92 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___105 *ptracer_cred;
	const struct cred___105 *real_cred;
	const struct cred___105 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___102 *nsproxy;
	struct signal_struct___99 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___110 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___17 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___86 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___68 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___109 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___110 *oom_reaper_list;
	struct vm_struct___81 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___68 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___68 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___110 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___68)(struct perf_event___68 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___68;

struct fasync_struct___109;

struct pid_namespace___92;

struct trace_event_call___63;

struct perf_cgroup___68;

struct perf_event___68 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___68 *group_leader;
	struct pmu___68 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___68 hw;
	struct perf_event_context___68 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___68 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___110 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___109 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___68 *);
	struct callback_head callback_head;
	struct pid_namespace___92 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___68 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___68 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___63 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___68 *cgrp;
	struct list_head sb_list;
};

struct rw_semaphore___110 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___110 *owner;
};

struct key___105;

struct ucounts___90;

struct user_namespace___90 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___90 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___7 ns;
	long unsigned int flags;
	struct key___105 *persistent_keyring_register;
	struct rw_semaphore___110 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___90 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___110 *pgtable_t___109;

struct address_space___109;

struct dev_pagemap___107;

struct page___110 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___109 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___110 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___109 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___109 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___107 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___109;

struct lruvec___109 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___109 *pgdat;
};

struct zone___109 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___109 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___109 {
	struct zone___109 *zone;
	int zone_idx;
};

struct zonelist___109 {
	struct zoneref___109 _zonerefs[25];
};

struct pglist_data___109 {
	struct zone___109 node_zones[3];
	struct zonelist___109 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___110 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___110 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___109 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___110 {
	void *stack;
	struct task_struct___110 *task;
	long int status;
};

struct blocking_notifier_head___109 {
	struct rw_semaphore___110 rwsem;
	struct notifier_block *head;
};

struct dentry___110;

struct path___109 {
	struct vfsmount *mnt;
	struct dentry___110 *dentry;
};

struct fown_struct___92 {
	rwlock_t lock;
	struct pid___92 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___110 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___109 f_path;
	struct inode___111 *f_inode;
	const struct file_operations___110 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___92 f_owner;
	const struct cred___105 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___109 *f_mapping;
	errseq_t f_wb_err;
};

struct user_struct___105;

struct cred___105 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___105 *session_keyring;
	struct key___105 *process_keyring;
	struct key___105 *thread_keyring;
	struct key___105 *request_key_auth;
	void *security;
	struct user_struct___105 *user;
	struct user_namespace___90 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___106;

struct kernfs_elem_dir___106 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___106 *root;
};

struct kernfs_node___106;

struct kernfs_syscall_ops___106;

struct kernfs_root___106 {
	struct kernfs_node___106 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___106 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___106 {
	struct kernfs_node___106 *target_kn;
};

struct kernfs_ops___106;

struct kernfs_elem_attr___106 {
	const struct kernfs_ops___106 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___106 *notify_next;
};

struct kernfs_node___106 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___106 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___106 dir;
		struct kernfs_elem_symlink___106 symlink;
		struct kernfs_elem_attr___106 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___106;

struct kernfs_ops___106 {
	int (*open)(struct kernfs_open_file___106 *);
	void (*release)(struct kernfs_open_file___106 *);
	int (*seq_show)(struct seq_file___100 *, void *);
	void * (*seq_start)(struct seq_file___100 *, loff_t *);
	void * (*seq_next)(struct seq_file___100 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___100 *, void *);
	ssize_t (*read)(struct kernfs_open_file___106 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___106 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___106 *, struct vm_area_struct___110 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___106 *, struct poll_table_struct___73 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___106 {
	int (*remount_fs)(struct kernfs_root___106 *, int *, char *);
	int (*show_options)(struct seq_file___100 *, struct kernfs_root___106 *);
	int (*mkdir)(struct kernfs_node___106 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___106 *);
	int (*rename)(struct kernfs_node___106 *, struct kernfs_node___106 *, const char *);
	int (*show_path)(struct seq_file___100 *, struct kernfs_node___106 *, struct kernfs_root___106 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___98;

struct seq_file___100 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___98 *op;
	int poll_event;
	const struct file___110 *file;
	void *private;
};

struct vm_operations_struct___107;

struct kernfs_open_file___106 {
	struct kernfs_node___106 *kn;
	struct file___110 *file;
	struct seq_file___100 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___107 *vm_ops;
};

struct vm_fault___107;

struct vm_operations_struct___107 {
	void (*open)(struct vm_area_struct___110 *);
	void (*close)(struct vm_area_struct___110 *);
	int (*split)(struct vm_area_struct___110 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___110 *);
	vm_fault_t (*fault)(struct vm_fault___107 *);
	vm_fault_t (*huge_fault)(struct vm_fault___107 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___107 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___110 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___107 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___107 *);
	int (*access)(struct vm_area_struct___110 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___110 *);
	int (*set_policy)(struct vm_area_struct___110 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___110 *, long unsigned int);
	struct page___110 * (*find_special_page)(struct vm_area_struct___110 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___72)(struct file___110 *, wait_queue_head_t *, struct poll_table_struct___73 *);

struct poll_table_struct___73 {
	poll_queue_proc___72 _qproc;
	__poll_t _key;
};

struct vm_area_struct___110 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___110 *vm_next;
	struct vm_area_struct___110 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___109 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___107 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___110 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___104;

struct bin_attribute___100;

struct attribute_group___100 {
	const char *name;
	umode_t (*is_visible)(struct kobject___104 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___104 *, struct bin_attribute___100 *, int);
	struct attribute **attrs;
	struct bin_attribute___100 **bin_attrs;
};

struct kset___103;

struct kobj_type___103;

struct kobject___104 {
	const char *name;
	struct list_head entry;
	struct kobject___104 *parent;
	struct kset___103 *kset;
	struct kobj_type___103 *ktype;
	struct kernfs_node___106 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___100 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___110 *, struct kobject___104 *, struct bin_attribute___100 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___110 *, struct kobject___104 *, struct bin_attribute___100 *, char *, loff_t, size_t);
	int (*mmap)(struct file___110 *, struct kobject___104 *, struct bin_attribute___100 *, struct vm_area_struct___110 *);
};

struct sysfs_ops___103 {
	ssize_t (*show)(struct kobject___104 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___104 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___103;

struct kset___103 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___104 kobj;
	const struct kset_uevent_ops___103 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___103 {
	void (*release)(struct kobject___104 *);
	const struct sysfs_ops___103 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___5 * (*child_ns_type)(struct kobject___104 *);
	const void * (*namespace)(struct kobject___104 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___103 {
	int (* const filter)(struct kset___103 *, struct kobject___104 *);
	const char * (* const name)(struct kset___103 *, struct kobject___104 *);
	int (* const uevent)(struct kset___103 *, struct kobject___104 *, struct kobj_uevent_env *);
};

struct kobj_attribute___104 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___104 *, struct kobj_attribute___104 *, char *);
	ssize_t (*store)(struct kobject___104 *, struct kobj_attribute___104 *, const char *, size_t);
};

struct kernel_param___90;

struct kernel_param_ops___90 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___90 *);
	int (*get)(char *, const struct kernel_param___90 *);
	void (*free)(void *);
};

struct kparam_array___90;

struct kernel_param___90 {
	const char *name;
	struct module___93 *mod;
	const struct kernel_param_ops___90 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___90 *arr;
	};
};

struct kparam_array___90 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___90 *ops;
	void *elem;
};

struct module_kobject___90 {
	struct kobject___104 kobj;
	struct module___93 *mod;
	struct kobject___104 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___90 {
	struct module___93 *mod;
	struct latch_tree_node node;
};

struct module_layout___90 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___90 mtn;
};

struct module_attribute___90;

struct module___93 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___90 mkobj;
	struct module_attribute___90 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___104 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___90 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___90 core_layout;
	struct module_layout___90 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___63 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___90 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___90 *, struct module_kobject___90 *, char *);
	ssize_t (*store)(struct module_attribute___90 *, struct module_kobject___90 *, const char *, size_t);
	void (*setup)(struct module___93 *, const char *);
	int (*test)(struct module___93 *);
	void (*free)(struct module___93 *);
};

struct trace_event_functions___11;

struct trace_event___11 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___11 *funcs;
};

struct trace_event_class___63;

struct trace_event_call___63 {
	struct list_head list;
	struct trace_event_class___63 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___11 event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___10 *prog_array;
	int (*perf_perm)(struct trace_event_call___63 *, struct perf_event___68 *);
};

struct upid___92 {
	int nr;
	struct pid_namespace___92 *ns;
};

struct pid_namespace___92 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___110 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___92 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___110 *proc_self;
	struct dentry___110 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___90 *user_ns;
	struct ucounts___90 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___7 ns;
};

struct pid___92 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___92 numbers[1];
};

struct user_struct___105 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___105 *uid_keyring;
	struct key___105 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___109;

struct mm_struct___109 {
	struct {
		struct vm_area_struct___110 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___110 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___110 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___109 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___110 *owner;
		struct user_namespace___90 *user_ns;
		struct file___110 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___109 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___86;

struct nsproxy___102 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___92 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___86 *cgroup_ns;
};

struct signal_struct___99 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___110 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___110 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___92 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___92 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___109 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___92 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___86;

struct cgroup___86;

struct css_set___86 {
	struct cgroup_subsys_state___86 *subsys[13];
	refcount_t refcount;
	struct css_set___86 *dom_cset;
	struct cgroup___86 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___86 *mg_src_cgrp;
	struct cgroup___86 *mg_dst_cgrp;
	struct css_set___86 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___68 {
	struct pmu___68 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___110 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___68 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___81 {
	struct vm_struct___81 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___110 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___99 {
	struct task_struct___110 task;
	long unsigned int stack[8192];
};

struct address_space_operations___109;

struct address_space___109 {
	struct inode___111 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___110 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___109 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___107)(struct vm_area_struct___110 *, long unsigned int, const struct page___110 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___107)(struct page___110 *, void *);

struct device___101;

struct dev_pagemap___107 {
	dev_page_fault_t___107 page_fault;
	dev_page_free_t___107 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___101 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___109 {
	struct task_struct___110 *task;
	struct core_thread___109 *next;
};

struct core_state___109 {
	atomic_t nr_threads;
	struct core_thread___109 dumper;
	struct completion startup;
};

struct vm_fault___107 {
	struct vm_area_struct___110 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___110 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___110 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___109 prealloc_pte;
};

struct dentry_operations___109;

struct super_block___110;

struct dentry___110 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___110 *d_parent;
	struct qstr d_name;
	struct inode___111 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___109 *d_op;
	struct super_block___110 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___109;

struct block_device___110;

struct inode___111 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___109 *i_op;
	struct super_block___110 *i_sb;
	struct address_space___109 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___110 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___110 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___109 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___110 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___109 {
	int (*d_revalidate)(struct dentry___110 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___110 *, unsigned int);
	int (*d_hash)(const struct dentry___110 *, struct qstr *);
	int (*d_compare)(const struct dentry___110 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___110 *);
	int (*d_init)(struct dentry___110 *);
	void (*d_release)(struct dentry___110 *);
	void (*d_prune)(struct dentry___110 *);
	void (*d_iput)(struct dentry___110 *, struct inode___111 *);
	char * (*d_dname)(struct dentry___110 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___109 *);
	int (*d_manage)(const struct path___109 *, bool);
	struct dentry___110 * (*d_real)(struct dentry___110 *, const struct inode___111 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___109;

struct mem_dqinfo___109 {
	struct quota_format_type___109 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___109;

struct quota_info___109 {
	unsigned int flags;
	struct rw_semaphore___110 dqio_sem;
	struct inode___111 *files[3];
	struct mem_dqinfo___109 info[3];
	const struct quota_format_ops___109 *ops[3];
};

struct rcuwait___109 {
	struct task_struct___110 *task;
};

struct percpu_rw_semaphore___109 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___110 rw_sem;
	struct rcuwait___109 writer;
	int readers_block;
};

struct sb_writers___109 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___109 rw_sem[3];
};

struct file_system_type___109;

struct super_operations___109;

struct dquot_operations___109;

struct quotactl_ops___109;

struct super_block___110 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___109 *s_type;
	const struct super_operations___109 *s_op;
	const struct dquot_operations___109 *dq_op;
	const struct quotactl_ops___109 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___110 *s_root;
	struct rw_semaphore___110 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___110 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___109 s_dquot;
	struct sb_writers___109 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___109 *s_d_op;
	int cleancache_poolid;
	struct shrinker___36 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___90 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___110 {
	struct file___110 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___110 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___110 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___110 *ia_file;
};

struct dquot___109 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___110 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___109 {
	int qf_fmt_id;
	const struct quota_format_ops___109 *qf_ops;
	struct module___93 *qf_owner;
	struct quota_format_type___109 *qf_next;
};

struct quota_format_ops___109 {
	int (*check_quota_file)(struct super_block___110 *, int);
	int (*read_file_info)(struct super_block___110 *, int);
	int (*write_file_info)(struct super_block___110 *, int);
	int (*free_file_info)(struct super_block___110 *, int);
	int (*read_dqblk)(struct dquot___109 *);
	int (*commit_dqblk)(struct dquot___109 *);
	int (*release_dqblk)(struct dquot___109 *);
	int (*get_next_id)(struct super_block___110 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___109 {
	int (*write_dquot)(struct dquot___109 *);
	struct dquot___109 * (*alloc_dquot)(struct super_block___110 *, int);
	void (*destroy_dquot)(struct dquot___109 *);
	int (*acquire_dquot)(struct dquot___109 *);
	int (*release_dquot)(struct dquot___109 *);
	int (*mark_dirty)(struct dquot___109 *);
	int (*write_info)(struct super_block___110 *, int);
	qsize_t * (*get_reserved_space)(struct inode___111 *);
	int (*get_projid)(struct inode___111 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___111 *, qsize_t *);
	int (*get_next_id)(struct super_block___110 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___109 {
	int (*quota_on)(struct super_block___110 *, int, int, const struct path___109 *);
	int (*quota_off)(struct super_block___110 *, int);
	int (*quota_enable)(struct super_block___110 *, unsigned int);
	int (*quota_disable)(struct super_block___110 *, unsigned int);
	int (*quota_sync)(struct super_block___110 *, int);
	int (*set_info)(struct super_block___110 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___110 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___110 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___110 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___110 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___110 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___109 {
	int (*writepage)(struct page___110 *, struct writeback_control___3 *);
	int (*readpage)(struct file___110 *, struct page___110 *);
	int (*writepages)(struct address_space___109 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___110 *);
	int (*readpages)(struct file___110 *, struct address_space___109 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___110 *, struct address_space___109 *, loff_t, unsigned int, unsigned int, struct page___110 **, void **);
	int (*write_end)(struct file___110 *, struct address_space___109 *, loff_t, unsigned int, unsigned int, struct page___110 *, void *);
	sector_t (*bmap)(struct address_space___109 *, sector_t);
	void (*invalidatepage)(struct page___110 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___110 *, gfp_t);
	void (*freepage)(struct page___110 *);
	ssize_t (*direct_IO)(struct kiocb___110 *, struct iov_iter___43 *);
	int (*migratepage)(struct address_space___109 *, struct page___110 *, struct page___110 *, enum migrate_mode);
	bool (*isolate_page)(struct page___110 *, isolate_mode_t);
	void (*putback_page)(struct page___110 *);
	int (*launder_page)(struct page___110 *);
	int (*is_partially_uptodate)(struct page___110 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___110 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___109 *, struct page___110 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___110 *, sector_t *);
	void (*swap_deactivate)(struct file___110 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___110 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___111 *bd_inode;
	struct super_block___110 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___110 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___109 {
	struct dentry___110 * (*lookup)(struct inode___111 *, struct dentry___110 *, unsigned int);
	const char * (*get_link)(struct dentry___110 *, struct inode___111 *, struct delayed_call *);
	int (*permission)(struct inode___111 *, int);
	struct posix_acl * (*get_acl)(struct inode___111 *, int);
	int (*readlink)(struct dentry___110 *, char *, int);
	int (*create)(struct inode___111 *, struct dentry___110 *, umode_t, bool);
	int (*link)(struct dentry___110 *, struct inode___111 *, struct dentry___110 *);
	int (*unlink)(struct inode___111 *, struct dentry___110 *);
	int (*symlink)(struct inode___111 *, struct dentry___110 *, const char *);
	int (*mkdir)(struct inode___111 *, struct dentry___110 *, umode_t);
	int (*rmdir)(struct inode___111 *, struct dentry___110 *);
	int (*mknod)(struct inode___111 *, struct dentry___110 *, umode_t, dev_t);
	int (*rename)(struct inode___111 *, struct dentry___110 *, struct inode___111 *, struct dentry___110 *, unsigned int);
	int (*setattr)(struct dentry___110 *, struct iattr___110 *);
	int (*getattr)(const struct path___109 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___110 *, char *, size_t);
	int (*fiemap)(struct inode___111 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___111 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___111 *, struct dentry___110 *, struct file___110 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___111 *, struct dentry___110 *, umode_t);
	int (*set_acl)(struct inode___111 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___109 {
	void (*fl_copy_lock)(struct file_lock___110 *, struct file_lock___110 *);
	void (*fl_release_private)(struct file_lock___110 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___109;

struct file_lock___110 {
	struct file_lock___110 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___110 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___109 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___109 *fl_ops;
	const struct lock_manager_operations___109 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___109 {
	int (*lm_compare_owner)(struct file_lock___110 *, struct file_lock___110 *);
	long unsigned int (*lm_owner_key)(struct file_lock___110 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___110 *);
	int (*lm_grant)(struct file_lock___110 *, int);
	bool (*lm_break)(struct file_lock___110 *);
	int (*lm_change)(struct file_lock___110 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___110 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___109 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___109 *fa_next;
	struct file___110 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___109 {
	const char *name;
	int fs_flags;
	struct dentry___110 * (*mount)(struct file_system_type___109 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___110 *);
	struct module___93 *owner;
	struct file_system_type___109 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___109 {
	struct inode___111 * (*alloc_inode)(struct super_block___110 *);
	void (*destroy_inode)(struct inode___111 *);
	void (*dirty_inode)(struct inode___111 *, int);
	int (*write_inode)(struct inode___111 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___111 *);
	void (*evict_inode)(struct inode___111 *);
	void (*put_super)(struct super_block___110 *);
	int (*sync_fs)(struct super_block___110 *, int);
	int (*freeze_super)(struct super_block___110 *);
	int (*freeze_fs)(struct super_block___110 *);
	int (*thaw_super)(struct super_block___110 *);
	int (*unfreeze_fs)(struct super_block___110 *);
	int (*statfs)(struct dentry___110 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___110 *, int *, char *);
	void (*umount_begin)(struct super_block___110 *);
	int (*show_options)(struct seq_file___100 *, struct dentry___110 *);
	int (*show_devname)(struct seq_file___100 *, struct dentry___110 *);
	int (*show_path)(struct seq_file___100 *, struct dentry___110 *);
	int (*show_stats)(struct seq_file___100 *, struct dentry___110 *);
	ssize_t (*quota_read)(struct super_block___110 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___110 *, int, const char *, size_t, loff_t);
	struct dquot___109 ** (*get_dquots)(struct inode___111 *);
	int (*bdev_try_to_free_page)(struct super_block___110 *, struct page___110 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___110 *, struct shrink_control___36 *);
	long int (*free_cached_objects)(struct super_block___110 *, struct shrink_control___36 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*key_restrict_link_func_t___105)(struct key___105 *, const struct key_type *, const union key_payload *, struct key___105 *);

struct key_restriction___105;

struct key___105 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___110 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___105 *restrict_link;
};

struct key_restriction___105 {
	key_restrict_link_func_t___105 check;
	struct key___105 *key;
	struct key_type *keytype;
};

struct seq_operations___98 {
	void * (*start)(struct seq_file___100 *, loff_t *);
	void (*stop)(struct seq_file___100 *, void *);
	void * (*next)(struct seq_file___100 *, void *, loff_t *);
	int (*show)(struct seq_file___100 *, void *);
};

struct dev_pm_info___101 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___101 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___101;

struct bus_type___101;

struct device_driver___101;

struct dev_pm_domain___101;

struct device_node___39;

struct fwnode_handle___75;

struct class___101;

struct device___101 {
	struct device___101 *parent;
	struct device_private *p;
	struct kobject___104 kobj;
	const char *init_name;
	const struct device_type___101 *type;
	struct mutex mutex;
	struct bus_type___101 *bus;
	struct device_driver___101 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___101 power;
	struct dev_pm_domain___101 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___39 *of_node;
	struct fwnode_handle___75 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___101 *class;
	const struct attribute_group___100 **groups;
	void (*release)(struct device___101 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

typedef void compound_page_dtor___107(struct page___110 *);

struct cgroup_namespace___86 {
	refcount_t count;
	struct ns_common___7 ns;
	struct user_namespace___90 *user_ns;
	struct ucounts___90 *ucounts;
	struct css_set___86 *root_cset;
};

struct ucounts___90 {
	struct hlist_node node;
	struct user_namespace___90 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct dev_pm_ops___101 {
	int (*prepare)(struct device___101 *);
	void (*complete)(struct device___101 *);
	int (*suspend)(struct device___101 *);
	int (*resume)(struct device___101 *);
	int (*freeze)(struct device___101 *);
	int (*thaw)(struct device___101 *);
	int (*poweroff)(struct device___101 *);
	int (*restore)(struct device___101 *);
	int (*suspend_late)(struct device___101 *);
	int (*resume_early)(struct device___101 *);
	int (*freeze_late)(struct device___101 *);
	int (*thaw_early)(struct device___101 *);
	int (*poweroff_late)(struct device___101 *);
	int (*restore_early)(struct device___101 *);
	int (*suspend_noirq)(struct device___101 *);
	int (*resume_noirq)(struct device___101 *);
	int (*freeze_noirq)(struct device___101 *);
	int (*thaw_noirq)(struct device___101 *);
	int (*poweroff_noirq)(struct device___101 *);
	int (*restore_noirq)(struct device___101 *);
	int (*runtime_suspend)(struct device___101 *);
	int (*runtime_resume)(struct device___101 *);
	int (*runtime_idle)(struct device___101 *);
};

struct dev_pm_domain___101 {
	struct dev_pm_ops___101 ops;
	void (*detach)(struct device___101 *, bool);
	int (*activate)(struct device___101 *);
	void (*sync)(struct device___101 *);
	void (*dismiss)(struct device___101 *);
};

struct bus_type___101 {
	const char *name;
	const char *dev_name;
	struct device___101 *dev_root;
	const struct attribute_group___100 **bus_groups;
	const struct attribute_group___100 **dev_groups;
	const struct attribute_group___100 **drv_groups;
	int (*match)(struct device___101 *, struct device_driver___101 *);
	int (*uevent)(struct device___101 *, struct kobj_uevent_env *);
	int (*probe)(struct device___101 *);
	int (*remove)(struct device___101 *);
	void (*shutdown)(struct device___101 *);
	int (*online)(struct device___101 *);
	int (*offline)(struct device___101 *);
	int (*suspend)(struct device___101 *, pm_message_t);
	int (*resume)(struct device___101 *);
	int (*num_vf)(struct device___101 *);
	int (*dma_configure)(struct device___101 *);
	const struct dev_pm_ops___101 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___101 {
	const char *name;
	struct bus_type___101 *bus;
	struct module___93 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___101 *);
	int (*remove)(struct device___101 *);
	void (*shutdown)(struct device___101 *);
	int (*suspend)(struct device___101 *, pm_message_t);
	int (*resume)(struct device___101 *);
	const struct attribute_group___100 **groups;
	const struct dev_pm_ops___101 *pm;
	void (*coredump)(struct device___101 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___101 {
	const char *name;
	const struct attribute_group___100 **groups;
	int (*uevent)(struct device___101 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___101 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___101 *);
	const struct dev_pm_ops___101 *pm;
};

struct class___101 {
	const char *name;
	struct module___93 *owner;
	const struct attribute_group___100 **class_groups;
	const struct attribute_group___100 **dev_groups;
	struct kobject___104 *dev_kobj;
	int (*dev_uevent)(struct device___101 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___101 *, umode_t *);
	void (*class_release)(struct class___101 *);
	void (*dev_release)(struct device___101 *);
	int (*shutdown_pre)(struct device___101 *);
	const struct kobj_ns_type_operations___5 *ns_type;
	const void * (*namespace)(struct device___101 *);
	const struct dev_pm_ops___101 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct fwnode_operations___75;

struct fwnode_handle___75 {
	struct fwnode_handle___75 *secondary;
	const struct fwnode_operations___75 *ops;
};

struct property___38;

struct device_node___39 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___75 fwnode;
	struct property___38 *properties;
	struct property___38 *deadprops;
	struct device_node___39 *parent;
	struct device_node___39 *child;
	struct device_node___39 *sibling;
	struct kobject___104 kobj;
	long unsigned int _flags;
	void *data;
};

struct node___87 {
	struct device___101 dev;
};

struct bpf_map___86;

struct bpf_map_ops___86 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___86 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___86 *, struct file___110 *);
	void (*map_free)(struct bpf_map___86 *);
	int (*map_get_next_key)(struct bpf_map___86 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___86 *);
	void * (*map_lookup_elem)(struct bpf_map___86 *, void *);
	int (*map_update_elem)(struct bpf_map___86 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___86 *, void *);
	int (*map_push_elem)(struct bpf_map___86 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___86 *, void *);
	int (*map_peek_elem)(struct bpf_map___86 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___86 *, struct file___110 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___86 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___86 *, void *, struct seq_file___100 *);
	int (*map_check_btf)(const struct bpf_map___86 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___86 {
	const struct bpf_map_ops___86 *ops;
	struct bpf_map___86 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___105 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___86;

typedef void (*kthread_work_func_t___86)(struct kthread_work___86 *);

struct kthread_worker___86;

struct kthread_work___86 {
	struct list_head node;
	kthread_work_func_t___86 func;
	struct kthread_worker___86 *worker;
	int canceling;
};

struct kthread_worker___86 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___110 *task;
	struct kthread_work___86 *current_work;
};

struct kthread_delayed_work___86 {
	struct kthread_work___86 work;
	struct timer_list timer;
};

struct psi_group___86 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___86 *poll_kworker;
	struct kthread_delayed_work___86 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___86 {
	struct kernfs_node___106 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___86;

struct cgroup_subsys_state___86 {
	struct cgroup___86 *cgroup;
	struct cgroup_subsys___86 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___86 *parent;
};

struct cgroup_root___86;

struct cgroup_rstat_cpu___86;

struct cgroup___86 {
	struct cgroup_subsys_state___86 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___106 *kn;
	struct cgroup_file___86 procs_file;
	struct cgroup_file___86 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___86 *subsys[13];
	struct cgroup_root___86 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___86 *dom_cgrp;
	struct cgroup_rstat_cpu___86 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___10 bpf;
	atomic_t congestion_count;
	struct cgroup___86 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___86 psi;
	int ancestor_ids[0];
};

struct cftype___86;

struct cgroup_subsys___86 {
	struct cgroup_subsys_state___86 * (*css_alloc)(struct cgroup_subsys_state___86 *);
	int (*css_online)(struct cgroup_subsys_state___86 *);
	void (*css_offline)(struct cgroup_subsys_state___86 *);
	void (*css_released)(struct cgroup_subsys_state___86 *);
	void (*css_free)(struct cgroup_subsys_state___86 *);
	void (*css_reset)(struct cgroup_subsys_state___86 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___86 *, int);
	int (*css_extra_stat_show)(struct seq_file___100 *, struct cgroup_subsys_state___86 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___110 *);
	void (*cancel_fork)(struct task_struct___110 *);
	void (*fork)(struct task_struct___110 *);
	void (*exit)(struct task_struct___110 *);
	void (*free)(struct task_struct___110 *);
	void (*bind)(struct cgroup_subsys_state___86 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___86 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___86 *dfl_cftypes;
	struct cftype___86 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___86 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___86 *updated_children;
	struct cgroup___86 *updated_next;
};

struct cgroup_root___86 {
	struct kernfs_root___106 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___86 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___86 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___86 *ss;
	struct list_head node;
	struct kernfs_ops___106 *kf_ops;
	int (*open)(struct kernfs_open_file___106 *);
	void (*release)(struct kernfs_open_file___106 *);
	u64 (*read_u64)(struct cgroup_subsys_state___86 *, struct cftype___86 *);
	s64 (*read_s64)(struct cgroup_subsys_state___86 *, struct cftype___86 *);
	int (*seq_show)(struct seq_file___100 *, void *);
	void * (*seq_start)(struct seq_file___100 *, loff_t *);
	void * (*seq_next)(struct seq_file___100 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___100 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___86 *, struct cftype___86 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___86 *, struct cftype___86 *, s64);
	ssize_t (*write)(struct kernfs_open_file___106 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___106 *, struct poll_table_struct___73 *);
};

struct perf_cpu_context___68;

struct pmu___68 {
	struct list_head entry;
	struct module___93 *module;
	struct device___101 *dev;
	const struct attribute_group___100 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___68 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___68 *);
	void (*pmu_disable)(struct pmu___68 *);
	int (*event_init)(struct perf_event___68 *);
	void (*event_mapped)(struct perf_event___68 *, struct mm_struct___109 *);
	void (*event_unmapped)(struct perf_event___68 *, struct mm_struct___109 *);
	int (*add)(struct perf_event___68 *, int);
	void (*del)(struct perf_event___68 *, int);
	void (*start)(struct perf_event___68 *, int);
	void (*stop)(struct perf_event___68 *, int);
	void (*read)(struct perf_event___68 *);
	void (*start_txn)(struct pmu___68 *, unsigned int);
	int (*commit_txn)(struct pmu___68 *);
	void (*cancel_txn)(struct pmu___68 *);
	int (*event_idx)(struct perf_event___68 *);
	void (*sched_task)(struct perf_event_context___68 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___68 *);
	int (*filter_match)(struct perf_event___68 *);
	int (*check_period)(struct perf_event___68 *, u64);
};

struct perf_cpu_context___68 {
	struct perf_event_context___68 ctx;
	struct perf_event_context___68 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___68 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___68 {
	struct cgroup_subsys_state___86 css;
	struct perf_cgroup_info *info;
};

struct kretprobe_instance___2;

typedef int (*kretprobe_handler_t___2)(struct kretprobe_instance___2 *, struct pt_regs *);

struct kretprobe___2;

struct kretprobe_instance___2 {
	struct hlist_node hlist;
	struct kretprobe___2 *rp;
	kprobe_opcode_t *ret_addr;
	struct task_struct___110 *task;
	char data[0];
};

struct kretprobe___2 {
	struct kprobe kp;
	kretprobe_handler_t___2 handler;
	kretprobe_handler_t___2 entry_handler;
	int maxactive;
	int nmissed;
	size_t data_size;
	struct hlist_head free_instances;
	raw_spinlock_t lock;
};

struct fwnode_reference_args___75;

struct fwnode_endpoint___75;

struct fwnode_operations___75 {
	struct fwnode_handle___75 * (*get)(struct fwnode_handle___75 *);
	void (*put)(struct fwnode_handle___75 *);
	bool (*device_is_available)(const struct fwnode_handle___75 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___75 *, const struct device___101 *);
	bool (*property_present)(const struct fwnode_handle___75 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___75 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___75 *, const char *, const char **, size_t);
	struct fwnode_handle___75 * (*get_parent)(const struct fwnode_handle___75 *);
	struct fwnode_handle___75 * (*get_next_child_node)(const struct fwnode_handle___75 *, struct fwnode_handle___75 *);
	struct fwnode_handle___75 * (*get_named_child_node)(const struct fwnode_handle___75 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___75 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___75 *);
	struct fwnode_handle___75 * (*graph_get_next_endpoint)(const struct fwnode_handle___75 *, struct fwnode_handle___75 *);
	struct fwnode_handle___75 * (*graph_get_remote_endpoint)(const struct fwnode_handle___75 *);
	struct fwnode_handle___75 * (*graph_get_port_parent)(struct fwnode_handle___75 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___75 *, struct fwnode_endpoint___75 *);
};

struct fwnode_endpoint___75 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___75 *local_fwnode;
};

struct fwnode_reference_args___75 {
	struct fwnode_handle___75 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct property___38 {
	char *name;
	int length;
	void *value;
	struct property___38 *next;
	long unsigned int _flags;
	struct bin_attribute___100 attr;
};

struct trace_array___11;

struct tracer___11;

struct trace_buffer___11;

struct trace_iterator___11 {
	struct trace_array___11 *tr;
	struct tracer___11 *trace;
	struct trace_buffer___11 *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

struct trace_buffer___11 {
	struct trace_array___11 *tr;
	struct ring_buffer *buffer;
	struct trace_array_cpu *data;
	u64 time_start;
	int cpu;
};

struct trace_event_file___28;

struct trace_options___11;

struct trace_array___11 {
	struct list_head list;
	char *name;
	struct trace_buffer___11 trace_buffer;
	struct trace_buffer___11 max_buffer;
	bool allocated_snapshot;
	long unsigned int max_latency;
	struct trace_pid_list *filtered_pids;
	arch_spinlock_t max_lock;
	int buffer_disabled;
	int sys_refcount_enter;
	int sys_refcount_exit;
	struct trace_event_file___28 *enter_syscall_files[295];
	struct trace_event_file___28 *exit_syscall_files[295];
	int stop_count;
	int clock_id;
	int nr_topts;
	bool clear_trace;
	struct tracer___11 *current_trace;
	unsigned int trace_flags;
	unsigned char trace_flags_index[32];
	unsigned int flags;
	raw_spinlock_t start_lock;
	struct dentry___110 *dir;
	struct dentry___110 *options;
	struct dentry___110 *percpu_dir;
	struct dentry___110 *event_dir;
	struct trace_options___11 *topts;
	struct list_head systems;
	struct list_head events;
	struct trace_event_file___28 *trace_marker_file;
	cpumask_var_t tracing_cpumask;
	int ref;
	struct ftrace_ops *ops;
	struct trace_pid_list *function_pids;
	struct list_head func_probes;
	struct list_head mod_trace;
	struct list_head mod_notrace;
	int function_enabled;
	int time_stamp_abs_ref;
	struct list_head hist_vars;
};

struct tracer_flags___11;

struct tracer___11 {
	const char *name;
	int (*init)(struct trace_array___11 *);
	void (*reset)(struct trace_array___11 *);
	void (*start)(struct trace_array___11 *);
	void (*stop)(struct trace_array___11 *);
	int (*update_thresh)(struct trace_array___11 *);
	void (*open)(struct trace_iterator___11 *);
	void (*pipe_open)(struct trace_iterator___11 *);
	void (*close)(struct trace_iterator___11 *);
	void (*pipe_close)(struct trace_iterator___11 *);
	ssize_t (*read)(struct trace_iterator___11 *, struct file___110 *, char *, size_t, loff_t *);
	ssize_t (*splice_read)(struct trace_iterator___11 *, struct file___110 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	void (*print_header)(struct seq_file___100 *);
	enum print_line_t (*print_line)(struct trace_iterator___11 *);
	int (*set_flag)(struct trace_array___11 *, u32, u32, int);
	int (*flag_changed)(struct trace_array___11 *, u32, int);
	struct tracer___11 *next;
	struct tracer_flags___11 *flags;
	int enabled;
	int ref;
	bool print_max;
	bool allow_instances;
	bool use_max_tr;
	bool noboot;
};

typedef enum print_line_t (*trace_print_func___11)(struct trace_iterator___11 *, int, struct trace_event___11 *);

struct trace_event_functions___11 {
	trace_print_func___11 trace;
	trace_print_func___11 raw;
	trace_print_func___11 hex;
	trace_print_func___11 binary;
};

struct trace_event_class___63 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___63 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___63 *);
	struct list_head * (*get_fields)(struct trace_event_call___63 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___63 *);
};

struct trace_subsystem_dir___11;

struct trace_event_file___28 {
	struct list_head list;
	struct trace_event_call___63 *event_call;
	struct event_filter *filter;
	struct dentry___110 *dir;
	struct trace_array___11 *tr;
	struct trace_subsystem_dir___11 *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_subsystem_dir___11 {
	struct list_head list;
	struct event_subsystem *subsystem;
	struct trace_array___11 *tr;
	struct dentry___110 *entry;
	int ref_count;
	int nr_events;
};

struct kprobe_trace_entry_head {
	struct trace_entry ent;
	long unsigned int ip;
};

struct kretprobe_trace_entry_head {
	struct trace_entry ent;
	long unsigned int func;
	long unsigned int ret_ip;
};

struct trace_option_dentry___11;

struct trace_options___11 {
	struct tracer___11 *tracer;
	struct trace_option_dentry___11 *topts;
};

struct trace_option_dentry___11 {
	struct tracer_opt *opt;
	struct tracer_flags___11 *flags;
	struct trace_array___11 *tr;
	struct dentry___110 *entry;
};

struct tracer_flags___11 {
	u32 val;
	struct tracer_opt *opts;
	struct tracer___11 *trace;
};

typedef void (*fetch_func_t)(struct pt_regs *, void *, void *);

typedef int (*print_type_func_t)(struct trace_seq *, const char *, void *, void *);

struct fetch_type {
	const char *name;
	size_t size;
	int is_signed;
	print_type_func_t print;
	const char *fmt;
	const char *fmttype;
	fetch_func_t fetch[9];
};

struct fetch_param {
	fetch_func_t fn;
	void *data;
};

typedef u32 string;

typedef u32 string_size;

struct probe_arg {
	struct fetch_param fetch;
	struct fetch_param fetch_size;
	unsigned int offset;
	const char *name;
	const char *comm;
	const struct fetch_type *type;
};

struct trace_probe {
	unsigned int flags;
	struct trace_event_class___63 class;
	struct trace_event_call___63 call;
	struct list_head files;
	ssize_t size;
	unsigned int nr_args;
	struct probe_arg args[0];
};

struct event_file_link {
	struct trace_event_file___28 *file;
	struct list_head list;
};

struct trace_kprobe {
	struct list_head list;
	struct kretprobe___2 rp;
	long unsigned int *nhit;
	const char *symbol;
	struct trace_probe tp;
};

struct symbol_cache {
	char *symbol;
	long int offset;
	long unsigned int addr;
};

struct module___94;

struct file___111;

struct kiocb___111;

struct poll_table_struct___74;

struct vm_area_struct___111;

struct inode___112;

struct file_lock___111;

struct page___111;

struct seq_file___101;

struct file_operations___111 {
	struct module___94 *owner;
	loff_t (*llseek)(struct file___111 *, loff_t, int);
	ssize_t (*read)(struct file___111 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___111 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___111 *, struct iov_iter___43 *);
	ssize_t (*write_iter)(struct kiocb___111 *, struct iov_iter___43 *);
	int (*iopoll)(struct kiocb___111 *, bool);
	int (*iterate)(struct file___111 *, struct dir_context *);
	int (*iterate_shared)(struct file___111 *, struct dir_context *);
	__poll_t (*poll)(struct file___111 *, struct poll_table_struct___74 *);
	long int (*unlocked_ioctl)(struct file___111 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___111 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___111 *, struct vm_area_struct___111 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___112 *, struct file___111 *);
	int (*flush)(struct file___111 *, fl_owner_t);
	int (*release)(struct inode___112 *, struct file___111 *);
	int (*fsync)(struct file___111 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___111 *, int);
	int (*lock)(struct file___111 *, int, struct file_lock___111 *);
	ssize_t (*sendpage)(struct file___111 *, struct page___111 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___111 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___111 *, int, struct file_lock___111 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___111 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___111 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___111 *, long int, struct file_lock___111 **, void **);
	long int (*fallocate)(struct file___111 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___101 *, struct file___111 *);
	ssize_t (*copy_file_range)(struct file___111 *, loff_t, struct file___111 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___111 *, loff_t, struct file___111 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___111 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___110 {
	u64 seqnum;
	struct vm_area_struct___111 *vmas[4];
};

struct page_frag___110 {
	struct page___111 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___69;

struct debug_info___69 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___69 *hbp_break[16];
	struct perf_event___69 *hbp_watch[16];
};

struct thread_struct___69 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___69 debug;
	long: 64;
};

struct mm_struct___110;

struct pid___93;

struct cred___106;

struct nsproxy___103;

struct signal_struct___100;

struct css_set___87;

struct perf_event_context___69;

struct task_struct___111 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___111 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___110 *mm;
	struct mm_struct___110 *active_mm;
	struct vmacache___110 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___111 *real_parent;
	struct task_struct___111 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___111 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___93 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___93 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___93 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___106 *ptracer_cred;
	const struct cred___106 *real_cred;
	const struct cred___106 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___103 *nsproxy;
	struct signal_struct___100 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___111 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___17 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___87 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___69 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___110 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___111 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___69 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___69 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___111 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___69)(struct perf_event___69 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___69;

struct fasync_struct___110;

struct pid_namespace___93;

struct trace_event_call___64;

struct perf_cgroup___69;

struct perf_event___69 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___69 *group_leader;
	struct pmu___69 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___69 hw;
	struct perf_event_context___69 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___69 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___111 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___110 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___69 *);
	struct callback_head callback_head;
	struct pid_namespace___93 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___69 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___69 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___64 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___69 *cgrp;
	struct list_head sb_list;
};

struct secondary_data___111 {
	void *stack;
	struct task_struct___111 *task;
	long int status;
};

struct upid___93 {
	int nr;
	struct pid_namespace___93 *ns;
};

struct dentry___111;

struct user_namespace___91;

struct ucounts___91;

struct pid_namespace___93 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___111 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___93 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___111 *proc_self;
	struct dentry___111 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___91 *user_ns;
	struct ucounts___91 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___7 ns;
};

struct pid___93 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___93 numbers[1];
};

struct rw_semaphore___111 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___111 *owner;
};

struct key___106;

struct user_namespace___91 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___91 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___7 ns;
	long unsigned int flags;
	struct key___106 *persistent_keyring_register;
	struct rw_semaphore___111 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___91 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___111 *pgtable_t___110;

struct address_space___110;

struct dev_pagemap___108;

struct page___111 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___110 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___111 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___110 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___110 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___108 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct user_struct___106 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___106 *uid_keyring;
	struct key___106 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___108;

struct vm_area_struct___111 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___111 *vm_next;
	struct vm_area_struct___111 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___110 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___108 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___111 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___110;

struct mm_struct___110 {
	struct {
		struct vm_area_struct___111 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___111 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___111 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___110 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___111 *owner;
		struct user_namespace___91 *user_ns;
		struct file___111 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___110 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___106 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___106 *session_keyring;
	struct key___106 *process_keyring;
	struct key___106 *thread_keyring;
	struct key___106 *request_key_auth;
	void *security;
	struct user_struct___106 *user;
	struct user_namespace___91 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___87;

struct nsproxy___103 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___93 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___87 *cgroup_ns;
};

struct signal_struct___100 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___111 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___111 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___93 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___93 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___110 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___93 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___87;

struct cgroup___87;

struct css_set___87 {
	struct cgroup_subsys_state___87 *subsys[13];
	refcount_t refcount;
	struct css_set___87 *dom_cset;
	struct cgroup___87 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___87 *mg_src_cgrp;
	struct cgroup___87 *mg_dst_cgrp;
	struct css_set___87 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___69 {
	struct pmu___69 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___111 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___69 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

union thread_union___100 {
	struct task_struct___111 task;
	long unsigned int stack[8192];
};

struct pglist_data___110;

struct lruvec___110 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___110 *pgdat;
};

struct zone___110 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___110 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___110 {
	struct zone___110 *zone;
	int zone_idx;
};

struct zonelist___110 {
	struct zoneref___110 _zonerefs[25];
};

struct pglist_data___110 {
	struct zone___110 node_zones[3];
	struct zonelist___110 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___111 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___111 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___110 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___110 {
	struct rw_semaphore___111 rwsem;
	struct notifier_block *head;
};

struct path___110 {
	struct vfsmount *mnt;
	struct dentry___111 *dentry;
};

struct fown_struct___93 {
	rwlock_t lock;
	struct pid___93 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___111 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___110 f_path;
	struct inode___112 *f_inode;
	const struct file_operations___111 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___93 f_owner;
	const struct cred___106 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___110 *f_mapping;
	errseq_t f_wb_err;
};

struct kernfs_root___107;

struct kernfs_elem_dir___107 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___107 *root;
};

struct kernfs_node___107;

struct kernfs_syscall_ops___107;

struct kernfs_root___107 {
	struct kernfs_node___107 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___107 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___107 {
	struct kernfs_node___107 *target_kn;
};

struct kernfs_ops___107;

struct kernfs_elem_attr___107 {
	const struct kernfs_ops___107 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___107 *notify_next;
};

struct kernfs_node___107 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___107 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___107 dir;
		struct kernfs_elem_symlink___107 symlink;
		struct kernfs_elem_attr___107 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___107;

struct kernfs_ops___107 {
	int (*open)(struct kernfs_open_file___107 *);
	void (*release)(struct kernfs_open_file___107 *);
	int (*seq_show)(struct seq_file___101 *, void *);
	void * (*seq_start)(struct seq_file___101 *, loff_t *);
	void * (*seq_next)(struct seq_file___101 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___101 *, void *);
	ssize_t (*read)(struct kernfs_open_file___107 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___107 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___107 *, struct vm_area_struct___111 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___107 *, struct poll_table_struct___74 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___107 {
	int (*remount_fs)(struct kernfs_root___107 *, int *, char *);
	int (*show_options)(struct seq_file___101 *, struct kernfs_root___107 *);
	int (*mkdir)(struct kernfs_node___107 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___107 *);
	int (*rename)(struct kernfs_node___107 *, struct kernfs_node___107 *, const char *);
	int (*show_path)(struct seq_file___101 *, struct kernfs_node___107 *, struct kernfs_root___107 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___99;

struct seq_file___101 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___99 *op;
	int poll_event;
	const struct file___111 *file;
	void *private;
};

struct kernfs_open_file___107 {
	struct kernfs_node___107 *kn;
	struct file___111 *file;
	struct seq_file___101 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___108 *vm_ops;
};

struct vm_fault___108;

struct vm_operations_struct___108 {
	void (*open)(struct vm_area_struct___111 *);
	void (*close)(struct vm_area_struct___111 *);
	int (*split)(struct vm_area_struct___111 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___111 *);
	vm_fault_t (*fault)(struct vm_fault___108 *);
	vm_fault_t (*huge_fault)(struct vm_fault___108 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___108 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___111 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___108 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___108 *);
	int (*access)(struct vm_area_struct___111 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___111 *);
	int (*set_policy)(struct vm_area_struct___111 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___111 *, long unsigned int);
	struct page___111 * (*find_special_page)(struct vm_area_struct___111 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___73)(struct file___111 *, wait_queue_head_t *, struct poll_table_struct___74 *);

struct poll_table_struct___74 {
	poll_queue_proc___73 _qproc;
	__poll_t _key;
};

struct kobject___105;

struct bin_attribute___101;

struct attribute_group___101 {
	const char *name;
	umode_t (*is_visible)(struct kobject___105 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___105 *, struct bin_attribute___101 *, int);
	struct attribute **attrs;
	struct bin_attribute___101 **bin_attrs;
};

struct kset___104;

struct kobj_type___104;

struct kobject___105 {
	const char *name;
	struct list_head entry;
	struct kobject___105 *parent;
	struct kset___104 *kset;
	struct kobj_type___104 *ktype;
	struct kernfs_node___107 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___101 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___111 *, struct kobject___105 *, struct bin_attribute___101 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___111 *, struct kobject___105 *, struct bin_attribute___101 *, char *, loff_t, size_t);
	int (*mmap)(struct file___111 *, struct kobject___105 *, struct bin_attribute___101 *, struct vm_area_struct___111 *);
};

struct sysfs_ops___104 {
	ssize_t (*show)(struct kobject___105 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___105 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___104;

struct kset___104 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___105 kobj;
	const struct kset_uevent_ops___104 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___104 {
	void (*release)(struct kobject___105 *);
	const struct sysfs_ops___104 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___5 * (*child_ns_type)(struct kobject___105 *);
	const void * (*namespace)(struct kobject___105 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___104 {
	int (* const filter)(struct kset___104 *, struct kobject___105 *);
	const char * (* const name)(struct kset___104 *, struct kobject___105 *);
	int (* const uevent)(struct kset___104 *, struct kobject___105 *, struct kobj_uevent_env *);
};

struct kobj_attribute___105 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___105 *, struct kobj_attribute___105 *, char *);
	ssize_t (*store)(struct kobject___105 *, struct kobj_attribute___105 *, const char *, size_t);
};

struct kernel_param___91;

struct kernel_param_ops___91 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___91 *);
	int (*get)(char *, const struct kernel_param___91 *);
	void (*free)(void *);
};

struct kparam_array___91;

struct kernel_param___91 {
	const char *name;
	struct module___94 *mod;
	const struct kernel_param_ops___91 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___91 *arr;
	};
};

struct kparam_array___91 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___91 *ops;
	void *elem;
};

struct module_kobject___91 {
	struct kobject___105 kobj;
	struct module___94 *mod;
	struct kobject___105 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___91 {
	struct module___94 *mod;
	struct latch_tree_node node;
};

struct module_layout___91 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___91 mtn;
};

struct module_attribute___91;

struct module___94 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___91 mkobj;
	struct module_attribute___91 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___105 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___91 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___91 core_layout;
	struct module_layout___91 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___64 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___91 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___91 *, struct module_kobject___91 *, char *);
	ssize_t (*store)(struct module_attribute___91 *, struct module_kobject___91 *, const char *, size_t);
	void (*setup)(struct module___94 *, const char *);
	int (*test)(struct module___94 *);
	void (*free)(struct module___94 *);
};

struct trace_event_class___64;

struct trace_event_call___64 {
	struct list_head list;
	struct trace_event_class___64 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___11 event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___10 *prog_array;
	int (*perf_perm)(struct trace_event_call___64 *, struct perf_event___69 *);
};

struct device___102;

struct dev_pm_ops___102 {
	int (*prepare)(struct device___102 *);
	void (*complete)(struct device___102 *);
	int (*suspend)(struct device___102 *);
	int (*resume)(struct device___102 *);
	int (*freeze)(struct device___102 *);
	int (*thaw)(struct device___102 *);
	int (*poweroff)(struct device___102 *);
	int (*restore)(struct device___102 *);
	int (*suspend_late)(struct device___102 *);
	int (*resume_early)(struct device___102 *);
	int (*freeze_late)(struct device___102 *);
	int (*thaw_early)(struct device___102 *);
	int (*poweroff_late)(struct device___102 *);
	int (*restore_early)(struct device___102 *);
	int (*suspend_noirq)(struct device___102 *);
	int (*resume_noirq)(struct device___102 *);
	int (*freeze_noirq)(struct device___102 *);
	int (*thaw_noirq)(struct device___102 *);
	int (*poweroff_noirq)(struct device___102 *);
	int (*restore_noirq)(struct device___102 *);
	int (*runtime_suspend)(struct device___102 *);
	int (*runtime_resume)(struct device___102 *);
	int (*runtime_idle)(struct device___102 *);
};

struct dev_pm_qos___9;

struct dev_pm_info___102 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___102 *, s32);
	struct dev_pm_qos___9 *qos;
};

struct device_type___102;

struct bus_type___102;

struct device_driver___102;

struct dev_pm_domain___102;

struct class___102;

struct device___102 {
	struct device___102 *parent;
	struct device_private *p;
	struct kobject___105 kobj;
	const char *init_name;
	const struct device_type___102 *type;
	struct mutex mutex;
	struct bus_type___102 *bus;
	struct device_driver___102 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___102 power;
	struct dev_pm_domain___102 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___102 *class;
	const struct attribute_group___101 **groups;
	void (*release)(struct device___102 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct pm_qos_constraints___9 {
	struct plist_head list;
	s32 target_value;
	s32 default_value;
	s32 no_constraint_value;
	enum pm_qos_type type;
	struct blocking_notifier_head___110 *notifiers;
};

struct dev_pm_qos_request___9;

struct dev_pm_qos___9 {
	struct pm_qos_constraints___9 resume_latency;
	struct pm_qos_constraints___9 latency_tolerance;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___9 *resume_latency_req;
	struct dev_pm_qos_request___9 *latency_tolerance_req;
	struct dev_pm_qos_request___9 *flags_req;
};

struct dev_pm_domain___102 {
	struct dev_pm_ops___102 ops;
	void (*detach)(struct device___102 *, bool);
	int (*activate)(struct device___102 *);
	void (*sync)(struct device___102 *);
	void (*dismiss)(struct device___102 *);
};

struct bus_type___102 {
	const char *name;
	const char *dev_name;
	struct device___102 *dev_root;
	const struct attribute_group___101 **bus_groups;
	const struct attribute_group___101 **dev_groups;
	const struct attribute_group___101 **drv_groups;
	int (*match)(struct device___102 *, struct device_driver___102 *);
	int (*uevent)(struct device___102 *, struct kobj_uevent_env *);
	int (*probe)(struct device___102 *);
	int (*remove)(struct device___102 *);
	void (*shutdown)(struct device___102 *);
	int (*online)(struct device___102 *);
	int (*offline)(struct device___102 *);
	int (*suspend)(struct device___102 *, pm_message_t);
	int (*resume)(struct device___102 *);
	int (*num_vf)(struct device___102 *);
	int (*dma_configure)(struct device___102 *);
	const struct dev_pm_ops___102 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___102 {
	const char *name;
	struct bus_type___102 *bus;
	struct module___94 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___102 *);
	int (*remove)(struct device___102 *);
	void (*shutdown)(struct device___102 *);
	int (*suspend)(struct device___102 *, pm_message_t);
	int (*resume)(struct device___102 *);
	const struct attribute_group___101 **groups;
	const struct dev_pm_ops___102 *pm;
	void (*coredump)(struct device___102 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___102 {
	const char *name;
	const struct attribute_group___101 **groups;
	int (*uevent)(struct device___102 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___102 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___102 *);
	const struct dev_pm_ops___102 *pm;
};

struct class___102 {
	const char *name;
	struct module___94 *owner;
	const struct attribute_group___101 **class_groups;
	const struct attribute_group___101 **dev_groups;
	struct kobject___105 *dev_kobj;
	int (*dev_uevent)(struct device___102 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___102 *, umode_t *);
	void (*class_release)(struct class___102 *);
	void (*dev_release)(struct device___102 *);
	int (*shutdown_pre)(struct device___102 *);
	const struct kobj_ns_type_operations___5 *ns_type;
	const void * (*namespace)(struct device___102 *);
	const struct dev_pm_ops___102 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dev_pm_qos_request___9 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___102 *dev;
};

struct address_space_operations___110;

struct address_space___110 {
	struct inode___112 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___111 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___110 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___108)(struct vm_area_struct___111 *, long unsigned int, const struct page___111 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___108)(struct page___111 *, void *);

struct dev_pagemap___108 {
	dev_page_fault_t___108 page_fault;
	dev_page_free_t___108 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___102 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___110 {
	struct task_struct___111 *task;
	struct core_thread___110 *next;
};

struct core_state___110 {
	atomic_t nr_threads;
	struct core_thread___110 dumper;
	struct completion startup;
};

struct vm_fault___108 {
	struct vm_area_struct___111 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___111 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___111 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___110 prealloc_pte;
};

struct dentry_operations___110;

struct super_block___111;

struct dentry___111 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___111 *d_parent;
	struct qstr d_name;
	struct inode___112 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___110 *d_op;
	struct super_block___111 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___110;

struct block_device___111;

struct inode___112 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___110 *i_op;
	struct super_block___111 *i_sb;
	struct address_space___110 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___111 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___111 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___110 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___111 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___110 {
	int (*d_revalidate)(struct dentry___111 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___111 *, unsigned int);
	int (*d_hash)(const struct dentry___111 *, struct qstr *);
	int (*d_compare)(const struct dentry___111 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___111 *);
	int (*d_init)(struct dentry___111 *);
	void (*d_release)(struct dentry___111 *);
	void (*d_prune)(struct dentry___111 *);
	void (*d_iput)(struct dentry___111 *, struct inode___112 *);
	char * (*d_dname)(struct dentry___111 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___110 *);
	int (*d_manage)(const struct path___110 *, bool);
	struct dentry___111 * (*d_real)(struct dentry___111 *, const struct inode___112 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___110;

struct mem_dqinfo___110 {
	struct quota_format_type___110 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___110;

struct quota_info___110 {
	unsigned int flags;
	struct rw_semaphore___111 dqio_sem;
	struct inode___112 *files[3];
	struct mem_dqinfo___110 info[3];
	const struct quota_format_ops___110 *ops[3];
};

struct rcuwait___110 {
	struct task_struct___111 *task;
};

struct percpu_rw_semaphore___110 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___111 rw_sem;
	struct rcuwait___110 writer;
	int readers_block;
};

struct sb_writers___110 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___110 rw_sem[3];
};

struct file_system_type___110;

struct super_operations___110;

struct dquot_operations___110;

struct quotactl_ops___110;

struct super_block___111 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___110 *s_type;
	const struct super_operations___110 *s_op;
	const struct dquot_operations___110 *dq_op;
	const struct quotactl_ops___110 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___111 *s_root;
	struct rw_semaphore___111 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___111 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___110 s_dquot;
	struct sb_writers___110 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___110 *s_d_op;
	int cleancache_poolid;
	struct shrinker___36 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___91 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___111 {
	struct file___111 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___111 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___111 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___111 *ia_file;
};

struct dquot___110 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___111 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___110 {
	int qf_fmt_id;
	const struct quota_format_ops___110 *qf_ops;
	struct module___94 *qf_owner;
	struct quota_format_type___110 *qf_next;
};

struct quota_format_ops___110 {
	int (*check_quota_file)(struct super_block___111 *, int);
	int (*read_file_info)(struct super_block___111 *, int);
	int (*write_file_info)(struct super_block___111 *, int);
	int (*free_file_info)(struct super_block___111 *, int);
	int (*read_dqblk)(struct dquot___110 *);
	int (*commit_dqblk)(struct dquot___110 *);
	int (*release_dqblk)(struct dquot___110 *);
	int (*get_next_id)(struct super_block___111 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___110 {
	int (*write_dquot)(struct dquot___110 *);
	struct dquot___110 * (*alloc_dquot)(struct super_block___111 *, int);
	void (*destroy_dquot)(struct dquot___110 *);
	int (*acquire_dquot)(struct dquot___110 *);
	int (*release_dquot)(struct dquot___110 *);
	int (*mark_dirty)(struct dquot___110 *);
	int (*write_info)(struct super_block___111 *, int);
	qsize_t * (*get_reserved_space)(struct inode___112 *);
	int (*get_projid)(struct inode___112 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___112 *, qsize_t *);
	int (*get_next_id)(struct super_block___111 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___110 {
	int (*quota_on)(struct super_block___111 *, int, int, const struct path___110 *);
	int (*quota_off)(struct super_block___111 *, int);
	int (*quota_enable)(struct super_block___111 *, unsigned int);
	int (*quota_disable)(struct super_block___111 *, unsigned int);
	int (*quota_sync)(struct super_block___111 *, int);
	int (*set_info)(struct super_block___111 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___111 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___111 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___111 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___111 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___111 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___110 {
	int (*writepage)(struct page___111 *, struct writeback_control___3 *);
	int (*readpage)(struct file___111 *, struct page___111 *);
	int (*writepages)(struct address_space___110 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___111 *);
	int (*readpages)(struct file___111 *, struct address_space___110 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___111 *, struct address_space___110 *, loff_t, unsigned int, unsigned int, struct page___111 **, void **);
	int (*write_end)(struct file___111 *, struct address_space___110 *, loff_t, unsigned int, unsigned int, struct page___111 *, void *);
	sector_t (*bmap)(struct address_space___110 *, sector_t);
	void (*invalidatepage)(struct page___111 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___111 *, gfp_t);
	void (*freepage)(struct page___111 *);
	ssize_t (*direct_IO)(struct kiocb___111 *, struct iov_iter___43 *);
	int (*migratepage)(struct address_space___110 *, struct page___111 *, struct page___111 *, enum migrate_mode);
	bool (*isolate_page)(struct page___111 *, isolate_mode_t);
	void (*putback_page)(struct page___111 *);
	int (*launder_page)(struct page___111 *);
	int (*is_partially_uptodate)(struct page___111 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___111 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___110 *, struct page___111 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___111 *, sector_t *);
	void (*swap_deactivate)(struct file___111 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___111 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___112 *bd_inode;
	struct super_block___111 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___111 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___110 {
	struct dentry___111 * (*lookup)(struct inode___112 *, struct dentry___111 *, unsigned int);
	const char * (*get_link)(struct dentry___111 *, struct inode___112 *, struct delayed_call *);
	int (*permission)(struct inode___112 *, int);
	struct posix_acl * (*get_acl)(struct inode___112 *, int);
	int (*readlink)(struct dentry___111 *, char *, int);
	int (*create)(struct inode___112 *, struct dentry___111 *, umode_t, bool);
	int (*link)(struct dentry___111 *, struct inode___112 *, struct dentry___111 *);
	int (*unlink)(struct inode___112 *, struct dentry___111 *);
	int (*symlink)(struct inode___112 *, struct dentry___111 *, const char *);
	int (*mkdir)(struct inode___112 *, struct dentry___111 *, umode_t);
	int (*rmdir)(struct inode___112 *, struct dentry___111 *);
	int (*mknod)(struct inode___112 *, struct dentry___111 *, umode_t, dev_t);
	int (*rename)(struct inode___112 *, struct dentry___111 *, struct inode___112 *, struct dentry___111 *, unsigned int);
	int (*setattr)(struct dentry___111 *, struct iattr___111 *);
	int (*getattr)(const struct path___110 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___111 *, char *, size_t);
	int (*fiemap)(struct inode___112 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___112 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___112 *, struct dentry___111 *, struct file___111 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___112 *, struct dentry___111 *, umode_t);
	int (*set_acl)(struct inode___112 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___110 {
	void (*fl_copy_lock)(struct file_lock___111 *, struct file_lock___111 *);
	void (*fl_release_private)(struct file_lock___111 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___110;

struct file_lock___111 {
	struct file_lock___111 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___111 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___110 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___110 *fl_ops;
	const struct lock_manager_operations___110 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___110 {
	int (*lm_compare_owner)(struct file_lock___111 *, struct file_lock___111 *);
	long unsigned int (*lm_owner_key)(struct file_lock___111 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___111 *);
	int (*lm_grant)(struct file_lock___111 *, int);
	bool (*lm_break)(struct file_lock___111 *);
	int (*lm_change)(struct file_lock___111 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___111 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___110 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___110 *fa_next;
	struct file___111 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___110 {
	const char *name;
	int fs_flags;
	struct dentry___111 * (*mount)(struct file_system_type___110 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___111 *);
	struct module___94 *owner;
	struct file_system_type___110 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___110 {
	struct inode___112 * (*alloc_inode)(struct super_block___111 *);
	void (*destroy_inode)(struct inode___112 *);
	void (*dirty_inode)(struct inode___112 *, int);
	int (*write_inode)(struct inode___112 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___112 *);
	void (*evict_inode)(struct inode___112 *);
	void (*put_super)(struct super_block___111 *);
	int (*sync_fs)(struct super_block___111 *, int);
	int (*freeze_super)(struct super_block___111 *);
	int (*freeze_fs)(struct super_block___111 *);
	int (*thaw_super)(struct super_block___111 *);
	int (*unfreeze_fs)(struct super_block___111 *);
	int (*statfs)(struct dentry___111 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___111 *, int *, char *);
	void (*umount_begin)(struct super_block___111 *);
	int (*show_options)(struct seq_file___101 *, struct dentry___111 *);
	int (*show_devname)(struct seq_file___101 *, struct dentry___111 *);
	int (*show_path)(struct seq_file___101 *, struct dentry___111 *);
	int (*show_stats)(struct seq_file___101 *, struct dentry___111 *);
	ssize_t (*quota_read)(struct super_block___111 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___111 *, int, const char *, size_t, loff_t);
	struct dquot___110 ** (*get_dquots)(struct inode___112 *);
	int (*bdev_try_to_free_page)(struct super_block___111 *, struct page___111 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___111 *, struct shrink_control___36 *);
	long int (*free_cached_objects)(struct super_block___111 *, struct shrink_control___36 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___108(struct page___111 *);

typedef int (*key_restrict_link_func_t___106)(struct key___106 *, const struct key_type *, const union key_payload *, struct key___106 *);

struct key_restriction___106;

struct key___106 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___111 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___106 *restrict_link;
};

struct key_restriction___106 {
	key_restrict_link_func_t___106 check;
	struct key___106 *key;
	struct key_type *keytype;
};

struct seq_operations___99 {
	void * (*start)(struct seq_file___101 *, loff_t *);
	void (*stop)(struct seq_file___101 *, void *);
	void * (*next)(struct seq_file___101 *, void *, loff_t *);
	int (*show)(struct seq_file___101 *, void *);
};

struct cgroup_namespace___87 {
	refcount_t count;
	struct ns_common___7 ns;
	struct user_namespace___91 *user_ns;
	struct ucounts___91 *ucounts;
	struct css_set___87 *root_cset;
};

struct ucounts___91 {
	struct hlist_node node;
	struct user_namespace___91 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct node___88 {
	struct device___102 dev;
};

struct bpf_map___87;

struct bpf_map_ops___87 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___87 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___87 *, struct file___111 *);
	void (*map_free)(struct bpf_map___87 *);
	int (*map_get_next_key)(struct bpf_map___87 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___87 *);
	void * (*map_lookup_elem)(struct bpf_map___87 *, void *);
	int (*map_update_elem)(struct bpf_map___87 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___87 *, void *);
	int (*map_push_elem)(struct bpf_map___87 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___87 *, void *);
	int (*map_peek_elem)(struct bpf_map___87 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___87 *, struct file___111 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___87 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___87 *, void *, struct seq_file___101 *);
	int (*map_check_btf)(const struct bpf_map___87 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___87 {
	const struct bpf_map_ops___87 *ops;
	struct bpf_map___87 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___106 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___87;

typedef void (*kthread_work_func_t___87)(struct kthread_work___87 *);

struct kthread_worker___87;

struct kthread_work___87 {
	struct list_head node;
	kthread_work_func_t___87 func;
	struct kthread_worker___87 *worker;
	int canceling;
};

struct kthread_worker___87 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___111 *task;
	struct kthread_work___87 *current_work;
};

struct kthread_delayed_work___87 {
	struct kthread_work___87 work;
	struct timer_list timer;
};

struct psi_group___87 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___87 *poll_kworker;
	struct kthread_delayed_work___87 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___87 {
	struct kernfs_node___107 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___87;

struct cgroup_subsys_state___87 {
	struct cgroup___87 *cgroup;
	struct cgroup_subsys___87 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___87 *parent;
};

struct cgroup_root___87;

struct cgroup_rstat_cpu___87;

struct cgroup___87 {
	struct cgroup_subsys_state___87 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___107 *kn;
	struct cgroup_file___87 procs_file;
	struct cgroup_file___87 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___87 *subsys[13];
	struct cgroup_root___87 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___87 *dom_cgrp;
	struct cgroup_rstat_cpu___87 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___10 bpf;
	atomic_t congestion_count;
	struct cgroup___87 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___87 psi;
	int ancestor_ids[0];
};

struct cftype___87;

struct cgroup_subsys___87 {
	struct cgroup_subsys_state___87 * (*css_alloc)(struct cgroup_subsys_state___87 *);
	int (*css_online)(struct cgroup_subsys_state___87 *);
	void (*css_offline)(struct cgroup_subsys_state___87 *);
	void (*css_released)(struct cgroup_subsys_state___87 *);
	void (*css_free)(struct cgroup_subsys_state___87 *);
	void (*css_reset)(struct cgroup_subsys_state___87 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___87 *, int);
	int (*css_extra_stat_show)(struct seq_file___101 *, struct cgroup_subsys_state___87 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___111 *);
	void (*cancel_fork)(struct task_struct___111 *);
	void (*fork)(struct task_struct___111 *);
	void (*exit)(struct task_struct___111 *);
	void (*free)(struct task_struct___111 *);
	void (*bind)(struct cgroup_subsys_state___87 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___87 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___87 *dfl_cftypes;
	struct cftype___87 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___87 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___87 *updated_children;
	struct cgroup___87 *updated_next;
};

struct cgroup_root___87 {
	struct kernfs_root___107 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___87 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___87 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___87 *ss;
	struct list_head node;
	struct kernfs_ops___107 *kf_ops;
	int (*open)(struct kernfs_open_file___107 *);
	void (*release)(struct kernfs_open_file___107 *);
	u64 (*read_u64)(struct cgroup_subsys_state___87 *, struct cftype___87 *);
	s64 (*read_s64)(struct cgroup_subsys_state___87 *, struct cftype___87 *);
	int (*seq_show)(struct seq_file___101 *, void *);
	void * (*seq_start)(struct seq_file___101 *, loff_t *);
	void * (*seq_next)(struct seq_file___101 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___101 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___87 *, struct cftype___87 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___87 *, struct cftype___87 *, s64);
	ssize_t (*write)(struct kernfs_open_file___107 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___107 *, struct poll_table_struct___74 *);
};

struct perf_cpu_context___69;

struct pmu___69 {
	struct list_head entry;
	struct module___94 *module;
	struct device___102 *dev;
	const struct attribute_group___101 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___69 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___69 *);
	void (*pmu_disable)(struct pmu___69 *);
	int (*event_init)(struct perf_event___69 *);
	void (*event_mapped)(struct perf_event___69 *, struct mm_struct___110 *);
	void (*event_unmapped)(struct perf_event___69 *, struct mm_struct___110 *);
	int (*add)(struct perf_event___69 *, int);
	void (*del)(struct perf_event___69 *, int);
	void (*start)(struct perf_event___69 *, int);
	void (*stop)(struct perf_event___69 *, int);
	void (*read)(struct perf_event___69 *);
	void (*start_txn)(struct pmu___69 *, unsigned int);
	int (*commit_txn)(struct pmu___69 *);
	void (*cancel_txn)(struct pmu___69 *);
	int (*event_idx)(struct perf_event___69 *);
	void (*sched_task)(struct perf_event_context___69 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___69 *);
	int (*filter_match)(struct perf_event___69 *);
	int (*check_period)(struct perf_event___69 *, u64);
};

struct perf_cpu_context___69 {
	struct perf_event_context___69 ctx;
	struct perf_event_context___69 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___69 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___69 {
	struct cgroup_subsys_state___87 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___64 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___64 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___64 *);
	struct list_head * (*get_fields)(struct trace_event_call___64 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___64 *);
};

struct trace_event_file___29;

struct trace_event_buffer___21 {
	struct ring_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___29 *trace_file;
	void *entry;
	long unsigned int flags;
	int pc;
};

struct trace_event_file___29 {
	struct list_head list;
	struct trace_event_call___64 *event_call;
	struct event_filter *filter;
	struct dentry___111 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_cpu {
	struct trace_entry ent;
	u32 state;
	u32 cpu_id;
	char __data[0];
};

struct trace_event_raw_powernv_throttle {
	struct trace_entry ent;
	int chip_id;
	u32 __data_loc_reason;
	int pmax;
	char __data[0];
};

struct trace_event_raw_pstate_sample {
	struct trace_entry ent;
	u32 core_busy;
	u32 scaled_busy;
	u32 from;
	u32 to;
	u64 mperf;
	u64 aperf;
	u64 tsc;
	u32 freq;
	u32 io_boost;
	char __data[0];
};

struct trace_event_raw_device_pm_callback_start {
	struct trace_entry ent;
	u32 __data_loc_device;
	u32 __data_loc_driver;
	u32 __data_loc_parent;
	u32 __data_loc_pm_ops;
	int event;
	char __data[0];
};

struct trace_event_raw_device_pm_callback_end {
	struct trace_entry ent;
	u32 __data_loc_device;
	u32 __data_loc_driver;
	int error;
	char __data[0];
};

struct trace_event_raw_suspend_resume {
	struct trace_entry ent;
	const char *action;
	int val;
	bool start;
	char __data[0];
};

struct trace_event_raw_wakeup_source {
	struct trace_entry ent;
	u32 __data_loc_name;
	u64 state;
	char __data[0];
};

struct trace_event_raw_clock {
	struct trace_entry ent;
	u32 __data_loc_name;
	u64 state;
	u64 cpu_id;
	char __data[0];
};

struct trace_event_raw_power_domain {
	struct trace_entry ent;
	u32 __data_loc_name;
	u64 state;
	u64 cpu_id;
	char __data[0];
};

struct trace_event_raw_pm_qos_request {
	struct trace_entry ent;
	int pm_qos_class;
	s32 value;
	char __data[0];
};

struct trace_event_raw_pm_qos_update_request_timeout {
	struct trace_entry ent;
	int pm_qos_class;
	s32 value;
	long unsigned int timeout_us;
	char __data[0];
};

struct trace_event_raw_pm_qos_update {
	struct trace_entry ent;
	enum pm_qos_req_action action;
	int prev_value;
	int curr_value;
	char __data[0];
};

struct trace_event_raw_dev_pm_qos_request {
	struct trace_entry ent;
	u32 __data_loc_name;
	enum dev_pm_qos_req_type type;
	s32 new_value;
	char __data[0];
};

struct trace_event_data_offsets_cpu {};

struct trace_event_data_offsets_powernv_throttle {
	u32 reason;
};

struct trace_event_data_offsets_pstate_sample {};

struct trace_event_data_offsets_device_pm_callback_start {
	u32 device;
	u32 driver;
	u32 parent;
	u32 pm_ops;
};

struct trace_event_data_offsets_device_pm_callback_end {
	u32 device;
	u32 driver;
};

struct trace_event_data_offsets_suspend_resume {};

struct trace_event_data_offsets_wakeup_source {
	u32 name;
};

struct trace_event_data_offsets_clock {
	u32 name;
};

struct trace_event_data_offsets_power_domain {
	u32 name;
};

struct trace_event_data_offsets_pm_qos_request {};

struct trace_event_data_offsets_pm_qos_update_request_timeout {};

struct trace_event_data_offsets_pm_qos_update {};

struct trace_event_data_offsets_dev_pm_qos_request {
	u32 name;
};

struct module___95;

struct file___112;

struct kiocb___112;

struct poll_table_struct___75;

struct vm_area_struct___112;

struct inode___113;

struct file_lock___112;

struct page___112;

struct seq_file___102;

struct file_operations___112 {
	struct module___95 *owner;
	loff_t (*llseek)(struct file___112 *, loff_t, int);
	ssize_t (*read)(struct file___112 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___112 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___112 *, struct iov_iter___43 *);
	ssize_t (*write_iter)(struct kiocb___112 *, struct iov_iter___43 *);
	int (*iopoll)(struct kiocb___112 *, bool);
	int (*iterate)(struct file___112 *, struct dir_context *);
	int (*iterate_shared)(struct file___112 *, struct dir_context *);
	__poll_t (*poll)(struct file___112 *, struct poll_table_struct___75 *);
	long int (*unlocked_ioctl)(struct file___112 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___112 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___112 *, struct vm_area_struct___112 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___113 *, struct file___112 *);
	int (*flush)(struct file___112 *, fl_owner_t);
	int (*release)(struct inode___113 *, struct file___112 *);
	int (*fsync)(struct file___112 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___112 *, int);
	int (*lock)(struct file___112 *, int, struct file_lock___112 *);
	ssize_t (*sendpage)(struct file___112 *, struct page___112 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___112 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___112 *, int, struct file_lock___112 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___112 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___112 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___112 *, long int, struct file_lock___112 **, void **);
	long int (*fallocate)(struct file___112 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___102 *, struct file___112 *);
	ssize_t (*copy_file_range)(struct file___112 *, loff_t, struct file___112 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___112 *, loff_t, struct file___112 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___112 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___111 {
	u64 seqnum;
	struct vm_area_struct___112 *vmas[4];
};

struct page_frag___111 {
	struct page___112 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___70;

struct debug_info___70 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___70 *hbp_break[16];
	struct perf_event___70 *hbp_watch[16];
};

struct thread_struct___70 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___70 debug;
	long: 64;
};

struct mm_struct___111;

struct pid___94;

struct cred___107;

struct nsproxy___104;

struct signal_struct___101;

struct css_set___88;

struct perf_event_context___70;

struct task_struct___112 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___112 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___111 *mm;
	struct mm_struct___111 *active_mm;
	struct vmacache___111 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___112 *real_parent;
	struct task_struct___112 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___112 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___94 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___94 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___94 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___107 *ptracer_cred;
	const struct cred___107 *real_cred;
	const struct cred___107 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___104 *nsproxy;
	struct signal_struct___101 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___112 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___17 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___88 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___70 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___111 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___112 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___70 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___70 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___112 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___70)(struct perf_event___70 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___70;

struct fasync_struct___111;

struct pid_namespace___94;

struct trace_event_call___65;

struct perf_cgroup___70;

struct perf_event___70 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___70 *group_leader;
	struct pmu___70 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___70 hw;
	struct perf_event_context___70 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___70 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___112 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___111 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___70 *);
	struct callback_head callback_head;
	struct pid_namespace___94 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___70 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___70 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___65 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___70 *cgrp;
	struct list_head sb_list;
};

struct secondary_data___112 {
	void *stack;
	struct task_struct___112 *task;
	long int status;
};

struct upid___94 {
	int nr;
	struct pid_namespace___94 *ns;
};

struct dentry___112;

struct user_namespace___92;

struct ucounts___92;

struct pid_namespace___94 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___112 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___94 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___112 *proc_self;
	struct dentry___112 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___92 *user_ns;
	struct ucounts___92 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___7 ns;
};

struct pid___94 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___94 numbers[1];
};

struct rw_semaphore___112 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___112 *owner;
};

struct key___107;

struct user_namespace___92 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___92 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___7 ns;
	long unsigned int flags;
	struct key___107 *persistent_keyring_register;
	struct rw_semaphore___112 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___92 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___112 *pgtable_t___111;

struct address_space___111;

struct dev_pagemap___109;

struct page___112 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___111 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___112 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___111 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___111 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___109 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct user_struct___107 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___107 *uid_keyring;
	struct key___107 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___109;

struct vm_area_struct___112 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___112 *vm_next;
	struct vm_area_struct___112 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___111 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___109 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___112 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___111;

struct mm_struct___111 {
	struct {
		struct vm_area_struct___112 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___112 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___112 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___111 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___112 *owner;
		struct user_namespace___92 *user_ns;
		struct file___112 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___111 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___107 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___107 *session_keyring;
	struct key___107 *process_keyring;
	struct key___107 *thread_keyring;
	struct key___107 *request_key_auth;
	void *security;
	struct user_struct___107 *user;
	struct user_namespace___92 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___88;

struct nsproxy___104 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___94 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___88 *cgroup_ns;
};

struct signal_struct___101 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___112 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___112 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___94 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___94 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___111 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___94 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___88;

struct cgroup___88;

struct css_set___88 {
	struct cgroup_subsys_state___88 *subsys[13];
	refcount_t refcount;
	struct css_set___88 *dom_cset;
	struct cgroup___88 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___88 *mg_src_cgrp;
	struct cgroup___88 *mg_dst_cgrp;
	struct css_set___88 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___70 {
	struct pmu___70 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___112 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___70 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

union thread_union___101 {
	struct task_struct___112 task;
	long unsigned int stack[8192];
};

struct pglist_data___111;

struct lruvec___111 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___111 *pgdat;
};

struct zone___111 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___111 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___111 {
	struct zone___111 *zone;
	int zone_idx;
};

struct zonelist___111 {
	struct zoneref___111 _zonerefs[25];
};

struct pglist_data___111 {
	struct zone___111 node_zones[3];
	struct zonelist___111 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___112 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___112 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___111 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___111 {
	struct rw_semaphore___112 rwsem;
	struct notifier_block *head;
};

struct path___111 {
	struct vfsmount *mnt;
	struct dentry___112 *dentry;
};

struct fown_struct___94 {
	rwlock_t lock;
	struct pid___94 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___112 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___111 f_path;
	struct inode___113 *f_inode;
	const struct file_operations___112 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___94 f_owner;
	const struct cred___107 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___111 *f_mapping;
	errseq_t f_wb_err;
};

struct kernfs_root___108;

struct kernfs_elem_dir___108 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___108 *root;
};

struct kernfs_node___108;

struct kernfs_syscall_ops___108;

struct kernfs_root___108 {
	struct kernfs_node___108 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___108 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___108 {
	struct kernfs_node___108 *target_kn;
};

struct kernfs_ops___108;

struct kernfs_elem_attr___108 {
	const struct kernfs_ops___108 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___108 *notify_next;
};

struct kernfs_node___108 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___108 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___108 dir;
		struct kernfs_elem_symlink___108 symlink;
		struct kernfs_elem_attr___108 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___108;

struct kernfs_ops___108 {
	int (*open)(struct kernfs_open_file___108 *);
	void (*release)(struct kernfs_open_file___108 *);
	int (*seq_show)(struct seq_file___102 *, void *);
	void * (*seq_start)(struct seq_file___102 *, loff_t *);
	void * (*seq_next)(struct seq_file___102 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___102 *, void *);
	ssize_t (*read)(struct kernfs_open_file___108 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___108 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___108 *, struct vm_area_struct___112 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___108 *, struct poll_table_struct___75 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___108 {
	int (*remount_fs)(struct kernfs_root___108 *, int *, char *);
	int (*show_options)(struct seq_file___102 *, struct kernfs_root___108 *);
	int (*mkdir)(struct kernfs_node___108 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___108 *);
	int (*rename)(struct kernfs_node___108 *, struct kernfs_node___108 *, const char *);
	int (*show_path)(struct seq_file___102 *, struct kernfs_node___108 *, struct kernfs_root___108 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___100;

struct seq_file___102 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___100 *op;
	int poll_event;
	const struct file___112 *file;
	void *private;
};

struct kernfs_open_file___108 {
	struct kernfs_node___108 *kn;
	struct file___112 *file;
	struct seq_file___102 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___109 *vm_ops;
};

struct vm_fault___109;

struct vm_operations_struct___109 {
	void (*open)(struct vm_area_struct___112 *);
	void (*close)(struct vm_area_struct___112 *);
	int (*split)(struct vm_area_struct___112 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___112 *);
	vm_fault_t (*fault)(struct vm_fault___109 *);
	vm_fault_t (*huge_fault)(struct vm_fault___109 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___109 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___112 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___109 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___109 *);
	int (*access)(struct vm_area_struct___112 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___112 *);
	int (*set_policy)(struct vm_area_struct___112 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___112 *, long unsigned int);
	struct page___112 * (*find_special_page)(struct vm_area_struct___112 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___74)(struct file___112 *, wait_queue_head_t *, struct poll_table_struct___75 *);

struct poll_table_struct___75 {
	poll_queue_proc___74 _qproc;
	__poll_t _key;
};

struct kobject___106;

struct bin_attribute___102;

struct attribute_group___102 {
	const char *name;
	umode_t (*is_visible)(struct kobject___106 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___106 *, struct bin_attribute___102 *, int);
	struct attribute **attrs;
	struct bin_attribute___102 **bin_attrs;
};

struct kset___105;

struct kobj_type___105;

struct kobject___106 {
	const char *name;
	struct list_head entry;
	struct kobject___106 *parent;
	struct kset___105 *kset;
	struct kobj_type___105 *ktype;
	struct kernfs_node___108 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___102 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___112 *, struct kobject___106 *, struct bin_attribute___102 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___112 *, struct kobject___106 *, struct bin_attribute___102 *, char *, loff_t, size_t);
	int (*mmap)(struct file___112 *, struct kobject___106 *, struct bin_attribute___102 *, struct vm_area_struct___112 *);
};

struct sysfs_ops___105 {
	ssize_t (*show)(struct kobject___106 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___106 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___105;

struct kset___105 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___106 kobj;
	const struct kset_uevent_ops___105 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___105 {
	void (*release)(struct kobject___106 *);
	const struct sysfs_ops___105 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___5 * (*child_ns_type)(struct kobject___106 *);
	const void * (*namespace)(struct kobject___106 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___105 {
	int (* const filter)(struct kset___105 *, struct kobject___106 *);
	const char * (* const name)(struct kset___105 *, struct kobject___106 *);
	int (* const uevent)(struct kset___105 *, struct kobject___106 *, struct kobj_uevent_env *);
};

struct kobj_attribute___106 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___106 *, struct kobj_attribute___106 *, char *);
	ssize_t (*store)(struct kobject___106 *, struct kobj_attribute___106 *, const char *, size_t);
};

struct kernel_param___92;

struct kernel_param_ops___92 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___92 *);
	int (*get)(char *, const struct kernel_param___92 *);
	void (*free)(void *);
};

struct kparam_array___92;

struct kernel_param___92 {
	const char *name;
	struct module___95 *mod;
	const struct kernel_param_ops___92 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___92 *arr;
	};
};

struct kparam_array___92 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___92 *ops;
	void *elem;
};

struct module_kobject___92 {
	struct kobject___106 kobj;
	struct module___95 *mod;
	struct kobject___106 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___92 {
	struct module___95 *mod;
	struct latch_tree_node node;
};

struct module_layout___92 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___92 mtn;
};

struct module_attribute___92;

struct module___95 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___92 mkobj;
	struct module_attribute___92 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___106 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___92 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___92 core_layout;
	struct module_layout___92 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___65 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___92 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___92 *, struct module_kobject___92 *, char *);
	ssize_t (*store)(struct module_attribute___92 *, struct module_kobject___92 *, const char *, size_t);
	void (*setup)(struct module___95 *, const char *);
	int (*test)(struct module___95 *);
	void (*free)(struct module___95 *);
};

struct trace_event_class___65;

struct trace_event_call___65 {
	struct list_head list;
	struct trace_event_class___65 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___11 event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___10 *prog_array;
	int (*perf_perm)(struct trace_event_call___65 *, struct perf_event___70 *);
};

struct device___103;

struct dev_pm_ops___103 {
	int (*prepare)(struct device___103 *);
	void (*complete)(struct device___103 *);
	int (*suspend)(struct device___103 *);
	int (*resume)(struct device___103 *);
	int (*freeze)(struct device___103 *);
	int (*thaw)(struct device___103 *);
	int (*poweroff)(struct device___103 *);
	int (*restore)(struct device___103 *);
	int (*suspend_late)(struct device___103 *);
	int (*resume_early)(struct device___103 *);
	int (*freeze_late)(struct device___103 *);
	int (*thaw_early)(struct device___103 *);
	int (*poweroff_late)(struct device___103 *);
	int (*restore_early)(struct device___103 *);
	int (*suspend_noirq)(struct device___103 *);
	int (*resume_noirq)(struct device___103 *);
	int (*freeze_noirq)(struct device___103 *);
	int (*thaw_noirq)(struct device___103 *);
	int (*poweroff_noirq)(struct device___103 *);
	int (*restore_noirq)(struct device___103 *);
	int (*runtime_suspend)(struct device___103 *);
	int (*runtime_resume)(struct device___103 *);
	int (*runtime_idle)(struct device___103 *);
};

struct dev_pm_info___103 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___103 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___103;

struct bus_type___103;

struct device_driver___103;

struct dev_pm_domain___103;

struct class___103;

struct device___103 {
	struct device___103 *parent;
	struct device_private *p;
	struct kobject___106 kobj;
	const char *init_name;
	const struct device_type___103 *type;
	struct mutex mutex;
	struct bus_type___103 *bus;
	struct device_driver___103 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___103 power;
	struct dev_pm_domain___103 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___103 *class;
	const struct attribute_group___102 **groups;
	void (*release)(struct device___103 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___103 {
	struct dev_pm_ops___103 ops;
	void (*detach)(struct device___103 *, bool);
	int (*activate)(struct device___103 *);
	void (*sync)(struct device___103 *);
	void (*dismiss)(struct device___103 *);
};

struct bus_type___103 {
	const char *name;
	const char *dev_name;
	struct device___103 *dev_root;
	const struct attribute_group___102 **bus_groups;
	const struct attribute_group___102 **dev_groups;
	const struct attribute_group___102 **drv_groups;
	int (*match)(struct device___103 *, struct device_driver___103 *);
	int (*uevent)(struct device___103 *, struct kobj_uevent_env *);
	int (*probe)(struct device___103 *);
	int (*remove)(struct device___103 *);
	void (*shutdown)(struct device___103 *);
	int (*online)(struct device___103 *);
	int (*offline)(struct device___103 *);
	int (*suspend)(struct device___103 *, pm_message_t);
	int (*resume)(struct device___103 *);
	int (*num_vf)(struct device___103 *);
	int (*dma_configure)(struct device___103 *);
	const struct dev_pm_ops___103 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___103 {
	const char *name;
	struct bus_type___103 *bus;
	struct module___95 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___103 *);
	int (*remove)(struct device___103 *);
	void (*shutdown)(struct device___103 *);
	int (*suspend)(struct device___103 *, pm_message_t);
	int (*resume)(struct device___103 *);
	const struct attribute_group___102 **groups;
	const struct dev_pm_ops___103 *pm;
	void (*coredump)(struct device___103 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___103 {
	const char *name;
	const struct attribute_group___102 **groups;
	int (*uevent)(struct device___103 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___103 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___103 *);
	const struct dev_pm_ops___103 *pm;
};

struct class___103 {
	const char *name;
	struct module___95 *owner;
	const struct attribute_group___102 **class_groups;
	const struct attribute_group___102 **dev_groups;
	struct kobject___106 *dev_kobj;
	int (*dev_uevent)(struct device___103 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___103 *, umode_t *);
	void (*class_release)(struct class___103 *);
	void (*dev_release)(struct device___103 *);
	int (*shutdown_pre)(struct device___103 *);
	const struct kobj_ns_type_operations___5 *ns_type;
	const void * (*namespace)(struct device___103 *);
	const struct dev_pm_ops___103 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dentry_operations___111;

struct super_block___112;

struct dentry___112 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___112 *d_parent;
	struct qstr d_name;
	struct inode___113 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___111 *d_op;
	struct super_block___112 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___111;

struct address_space___111 {
	struct inode___113 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___112 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___111 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___111;

struct block_device___112;

struct inode___113 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___111 *i_op;
	struct super_block___112 *i_sb;
	struct address_space___111 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___112 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___112 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___111 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___112 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___111 {
	int (*d_revalidate)(struct dentry___112 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___112 *, unsigned int);
	int (*d_hash)(const struct dentry___112 *, struct qstr *);
	int (*d_compare)(const struct dentry___112 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___112 *);
	int (*d_init)(struct dentry___112 *);
	void (*d_release)(struct dentry___112 *);
	void (*d_prune)(struct dentry___112 *);
	void (*d_iput)(struct dentry___112 *, struct inode___113 *);
	char * (*d_dname)(struct dentry___112 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___111 *);
	int (*d_manage)(const struct path___111 *, bool);
	struct dentry___112 * (*d_real)(struct dentry___112 *, const struct inode___113 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___111;

struct mem_dqinfo___111 {
	struct quota_format_type___111 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___111;

struct quota_info___111 {
	unsigned int flags;
	struct rw_semaphore___112 dqio_sem;
	struct inode___113 *files[3];
	struct mem_dqinfo___111 info[3];
	const struct quota_format_ops___111 *ops[3];
};

struct rcuwait___111 {
	struct task_struct___112 *task;
};

struct percpu_rw_semaphore___111 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___112 rw_sem;
	struct rcuwait___111 writer;
	int readers_block;
};

struct sb_writers___111 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___111 rw_sem[3];
};

struct file_system_type___111;

struct super_operations___111;

struct dquot_operations___111;

struct quotactl_ops___111;

struct super_block___112 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___111 *s_type;
	const struct super_operations___111 *s_op;
	const struct dquot_operations___111 *dq_op;
	const struct quotactl_ops___111 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___112 *s_root;
	struct rw_semaphore___112 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___112 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___111 s_dquot;
	struct sb_writers___111 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___111 *s_d_op;
	int cleancache_poolid;
	struct shrinker___36 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___92 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

typedef int (*dev_page_fault_t___109)(struct vm_area_struct___112 *, long unsigned int, const struct page___112 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___109)(struct page___112 *, void *);

struct dev_pagemap___109 {
	dev_page_fault_t___109 page_fault;
	dev_page_free_t___109 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___103 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___111 {
	struct task_struct___112 *task;
	struct core_thread___111 *next;
};

struct core_state___111 {
	atomic_t nr_threads;
	struct core_thread___111 dumper;
	struct completion startup;
};

struct vm_fault___109 {
	struct vm_area_struct___112 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___112 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___112 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___111 prealloc_pte;
};

struct kiocb___112 {
	struct file___112 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___112 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___112 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___112 *ia_file;
};

struct dquot___111 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___112 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___111 {
	int qf_fmt_id;
	const struct quota_format_ops___111 *qf_ops;
	struct module___95 *qf_owner;
	struct quota_format_type___111 *qf_next;
};

struct quota_format_ops___111 {
	int (*check_quota_file)(struct super_block___112 *, int);
	int (*read_file_info)(struct super_block___112 *, int);
	int (*write_file_info)(struct super_block___112 *, int);
	int (*free_file_info)(struct super_block___112 *, int);
	int (*read_dqblk)(struct dquot___111 *);
	int (*commit_dqblk)(struct dquot___111 *);
	int (*release_dqblk)(struct dquot___111 *);
	int (*get_next_id)(struct super_block___112 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___111 {
	int (*write_dquot)(struct dquot___111 *);
	struct dquot___111 * (*alloc_dquot)(struct super_block___112 *, int);
	void (*destroy_dquot)(struct dquot___111 *);
	int (*acquire_dquot)(struct dquot___111 *);
	int (*release_dquot)(struct dquot___111 *);
	int (*mark_dirty)(struct dquot___111 *);
	int (*write_info)(struct super_block___112 *, int);
	qsize_t * (*get_reserved_space)(struct inode___113 *);
	int (*get_projid)(struct inode___113 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___113 *, qsize_t *);
	int (*get_next_id)(struct super_block___112 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___111 {
	int (*quota_on)(struct super_block___112 *, int, int, const struct path___111 *);
	int (*quota_off)(struct super_block___112 *, int);
	int (*quota_enable)(struct super_block___112 *, unsigned int);
	int (*quota_disable)(struct super_block___112 *, unsigned int);
	int (*quota_sync)(struct super_block___112 *, int);
	int (*set_info)(struct super_block___112 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___112 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___112 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___112 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___112 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___112 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___111 {
	int (*writepage)(struct page___112 *, struct writeback_control___3 *);
	int (*readpage)(struct file___112 *, struct page___112 *);
	int (*writepages)(struct address_space___111 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___112 *);
	int (*readpages)(struct file___112 *, struct address_space___111 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___112 *, struct address_space___111 *, loff_t, unsigned int, unsigned int, struct page___112 **, void **);
	int (*write_end)(struct file___112 *, struct address_space___111 *, loff_t, unsigned int, unsigned int, struct page___112 *, void *);
	sector_t (*bmap)(struct address_space___111 *, sector_t);
	void (*invalidatepage)(struct page___112 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___112 *, gfp_t);
	void (*freepage)(struct page___112 *);
	ssize_t (*direct_IO)(struct kiocb___112 *, struct iov_iter___43 *);
	int (*migratepage)(struct address_space___111 *, struct page___112 *, struct page___112 *, enum migrate_mode);
	bool (*isolate_page)(struct page___112 *, isolate_mode_t);
	void (*putback_page)(struct page___112 *);
	int (*launder_page)(struct page___112 *);
	int (*is_partially_uptodate)(struct page___112 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___112 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___111 *, struct page___112 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___112 *, sector_t *);
	void (*swap_deactivate)(struct file___112 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___112 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___113 *bd_inode;
	struct super_block___112 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___112 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___111 {
	struct dentry___112 * (*lookup)(struct inode___113 *, struct dentry___112 *, unsigned int);
	const char * (*get_link)(struct dentry___112 *, struct inode___113 *, struct delayed_call *);
	int (*permission)(struct inode___113 *, int);
	struct posix_acl * (*get_acl)(struct inode___113 *, int);
	int (*readlink)(struct dentry___112 *, char *, int);
	int (*create)(struct inode___113 *, struct dentry___112 *, umode_t, bool);
	int (*link)(struct dentry___112 *, struct inode___113 *, struct dentry___112 *);
	int (*unlink)(struct inode___113 *, struct dentry___112 *);
	int (*symlink)(struct inode___113 *, struct dentry___112 *, const char *);
	int (*mkdir)(struct inode___113 *, struct dentry___112 *, umode_t);
	int (*rmdir)(struct inode___113 *, struct dentry___112 *);
	int (*mknod)(struct inode___113 *, struct dentry___112 *, umode_t, dev_t);
	int (*rename)(struct inode___113 *, struct dentry___112 *, struct inode___113 *, struct dentry___112 *, unsigned int);
	int (*setattr)(struct dentry___112 *, struct iattr___112 *);
	int (*getattr)(const struct path___111 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___112 *, char *, size_t);
	int (*fiemap)(struct inode___113 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___113 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___113 *, struct dentry___112 *, struct file___112 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___113 *, struct dentry___112 *, umode_t);
	int (*set_acl)(struct inode___113 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___111 {
	void (*fl_copy_lock)(struct file_lock___112 *, struct file_lock___112 *);
	void (*fl_release_private)(struct file_lock___112 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___111;

struct file_lock___112 {
	struct file_lock___112 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___112 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___111 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___111 *fl_ops;
	const struct lock_manager_operations___111 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___111 {
	int (*lm_compare_owner)(struct file_lock___112 *, struct file_lock___112 *);
	long unsigned int (*lm_owner_key)(struct file_lock___112 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___112 *);
	int (*lm_grant)(struct file_lock___112 *, int);
	bool (*lm_break)(struct file_lock___112 *);
	int (*lm_change)(struct file_lock___112 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___112 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___111 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___111 *fa_next;
	struct file___112 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___111 {
	const char *name;
	int fs_flags;
	struct dentry___112 * (*mount)(struct file_system_type___111 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___112 *);
	struct module___95 *owner;
	struct file_system_type___111 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___111 {
	struct inode___113 * (*alloc_inode)(struct super_block___112 *);
	void (*destroy_inode)(struct inode___113 *);
	void (*dirty_inode)(struct inode___113 *, int);
	int (*write_inode)(struct inode___113 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___113 *);
	void (*evict_inode)(struct inode___113 *);
	void (*put_super)(struct super_block___112 *);
	int (*sync_fs)(struct super_block___112 *, int);
	int (*freeze_super)(struct super_block___112 *);
	int (*freeze_fs)(struct super_block___112 *);
	int (*thaw_super)(struct super_block___112 *);
	int (*unfreeze_fs)(struct super_block___112 *);
	int (*statfs)(struct dentry___112 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___112 *, int *, char *);
	void (*umount_begin)(struct super_block___112 *);
	int (*show_options)(struct seq_file___102 *, struct dentry___112 *);
	int (*show_devname)(struct seq_file___102 *, struct dentry___112 *);
	int (*show_path)(struct seq_file___102 *, struct dentry___112 *);
	int (*show_stats)(struct seq_file___102 *, struct dentry___112 *);
	ssize_t (*quota_read)(struct super_block___112 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___112 *, int, const char *, size_t, loff_t);
	struct dquot___111 ** (*get_dquots)(struct inode___113 *);
	int (*bdev_try_to_free_page)(struct super_block___112 *, struct page___112 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___112 *, struct shrink_control___36 *);
	long int (*free_cached_objects)(struct super_block___112 *, struct shrink_control___36 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___109(struct page___112 *);

typedef int (*key_restrict_link_func_t___107)(struct key___107 *, const struct key_type *, const union key_payload *, struct key___107 *);

struct key_restriction___107;

struct key___107 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___112 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___107 *restrict_link;
};

struct key_restriction___107 {
	key_restrict_link_func_t___107 check;
	struct key___107 *key;
	struct key_type *keytype;
};

struct seq_operations___100 {
	void * (*start)(struct seq_file___102 *, loff_t *);
	void (*stop)(struct seq_file___102 *, void *);
	void * (*next)(struct seq_file___102 *, void *, loff_t *);
	int (*show)(struct seq_file___102 *, void *);
};

struct cgroup_namespace___88 {
	refcount_t count;
	struct ns_common___7 ns;
	struct user_namespace___92 *user_ns;
	struct ucounts___92 *ucounts;
	struct css_set___88 *root_cset;
};

struct ucounts___92 {
	struct hlist_node node;
	struct user_namespace___92 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct node___89 {
	struct device___103 dev;
};

struct bpf_map___88;

struct bpf_map_ops___88 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___88 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___88 *, struct file___112 *);
	void (*map_free)(struct bpf_map___88 *);
	int (*map_get_next_key)(struct bpf_map___88 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___88 *);
	void * (*map_lookup_elem)(struct bpf_map___88 *, void *);
	int (*map_update_elem)(struct bpf_map___88 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___88 *, void *);
	int (*map_push_elem)(struct bpf_map___88 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___88 *, void *);
	int (*map_peek_elem)(struct bpf_map___88 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___88 *, struct file___112 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___88 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___88 *, void *, struct seq_file___102 *);
	int (*map_check_btf)(const struct bpf_map___88 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___88 {
	const struct bpf_map_ops___88 *ops;
	struct bpf_map___88 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___107 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___88;

typedef void (*kthread_work_func_t___88)(struct kthread_work___88 *);

struct kthread_worker___88;

struct kthread_work___88 {
	struct list_head node;
	kthread_work_func_t___88 func;
	struct kthread_worker___88 *worker;
	int canceling;
};

struct kthread_worker___88 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___112 *task;
	struct kthread_work___88 *current_work;
};

struct kthread_delayed_work___88 {
	struct kthread_work___88 work;
	struct timer_list timer;
};

struct psi_group___88 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___88 *poll_kworker;
	struct kthread_delayed_work___88 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___88 {
	struct kernfs_node___108 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___88;

struct cgroup_subsys_state___88 {
	struct cgroup___88 *cgroup;
	struct cgroup_subsys___88 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___88 *parent;
};

struct cgroup_root___88;

struct cgroup_rstat_cpu___88;

struct cgroup___88 {
	struct cgroup_subsys_state___88 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___108 *kn;
	struct cgroup_file___88 procs_file;
	struct cgroup_file___88 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___88 *subsys[13];
	struct cgroup_root___88 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___88 *dom_cgrp;
	struct cgroup_rstat_cpu___88 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___10 bpf;
	atomic_t congestion_count;
	struct cgroup___88 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___88 psi;
	int ancestor_ids[0];
};

struct cftype___88;

struct cgroup_subsys___88 {
	struct cgroup_subsys_state___88 * (*css_alloc)(struct cgroup_subsys_state___88 *);
	int (*css_online)(struct cgroup_subsys_state___88 *);
	void (*css_offline)(struct cgroup_subsys_state___88 *);
	void (*css_released)(struct cgroup_subsys_state___88 *);
	void (*css_free)(struct cgroup_subsys_state___88 *);
	void (*css_reset)(struct cgroup_subsys_state___88 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___88 *, int);
	int (*css_extra_stat_show)(struct seq_file___102 *, struct cgroup_subsys_state___88 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___112 *);
	void (*cancel_fork)(struct task_struct___112 *);
	void (*fork)(struct task_struct___112 *);
	void (*exit)(struct task_struct___112 *);
	void (*free)(struct task_struct___112 *);
	void (*bind)(struct cgroup_subsys_state___88 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___88 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___88 *dfl_cftypes;
	struct cftype___88 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___88 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___88 *updated_children;
	struct cgroup___88 *updated_next;
};

struct cgroup_root___88 {
	struct kernfs_root___108 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___88 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___88 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___88 *ss;
	struct list_head node;
	struct kernfs_ops___108 *kf_ops;
	int (*open)(struct kernfs_open_file___108 *);
	void (*release)(struct kernfs_open_file___108 *);
	u64 (*read_u64)(struct cgroup_subsys_state___88 *, struct cftype___88 *);
	s64 (*read_s64)(struct cgroup_subsys_state___88 *, struct cftype___88 *);
	int (*seq_show)(struct seq_file___102 *, void *);
	void * (*seq_start)(struct seq_file___102 *, loff_t *);
	void * (*seq_next)(struct seq_file___102 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___102 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___88 *, struct cftype___88 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___88 *, struct cftype___88 *, s64);
	ssize_t (*write)(struct kernfs_open_file___108 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___108 *, struct poll_table_struct___75 *);
};

struct perf_cpu_context___70;

struct pmu___70 {
	struct list_head entry;
	struct module___95 *module;
	struct device___103 *dev;
	const struct attribute_group___102 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___70 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___70 *);
	void (*pmu_disable)(struct pmu___70 *);
	int (*event_init)(struct perf_event___70 *);
	void (*event_mapped)(struct perf_event___70 *, struct mm_struct___111 *);
	void (*event_unmapped)(struct perf_event___70 *, struct mm_struct___111 *);
	int (*add)(struct perf_event___70 *, int);
	void (*del)(struct perf_event___70 *, int);
	void (*start)(struct perf_event___70 *, int);
	void (*stop)(struct perf_event___70 *, int);
	void (*read)(struct perf_event___70 *);
	void (*start_txn)(struct pmu___70 *, unsigned int);
	int (*commit_txn)(struct pmu___70 *);
	void (*cancel_txn)(struct pmu___70 *);
	int (*event_idx)(struct perf_event___70 *);
	void (*sched_task)(struct perf_event_context___70 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___70 *);
	int (*filter_match)(struct perf_event___70 *);
	int (*check_period)(struct perf_event___70 *, u64);
};

struct perf_cpu_context___70 {
	struct perf_event_context___70 ctx;
	struct perf_event_context___70 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___70 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___70 {
	struct cgroup_subsys_state___88 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___65 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___65 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___65 *);
	struct list_head * (*get_fields)(struct trace_event_call___65 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___65 *);
};

struct trace_event_file___30;

struct trace_event_buffer___22 {
	struct ring_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___30 *trace_file;
	void *entry;
	long unsigned int flags;
	int pc;
};

struct trace_event_file___30 {
	struct list_head list;
	struct trace_event_call___65 *event_call;
	struct event_filter *filter;
	struct dentry___112 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_rpm_internal {
	struct trace_entry ent;
	u32 __data_loc_name;
	int flags;
	int usage_count;
	int disable_depth;
	int runtime_auto;
	int request_pending;
	int irq_safe;
	int child_count;
	char __data[0];
};

struct trace_event_raw_rpm_return_int {
	struct trace_entry ent;
	u32 __data_loc_name;
	long unsigned int ip;
	int ret;
	char __data[0];
};

struct trace_event_data_offsets_rpm_internal {
	u32 name;
};

struct trace_event_data_offsets_rpm_return_int {
	u32 name;
};

struct module___96;

struct file___113;

struct kiocb___113;

struct poll_table_struct___76;

struct vm_area_struct___113;

struct inode___114;

struct file_lock___113;

struct page___113;

struct seq_file___103;

struct file_operations___113 {
	struct module___96 *owner;
	loff_t (*llseek)(struct file___113 *, loff_t, int);
	ssize_t (*read)(struct file___113 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___113 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___113 *, struct iov_iter___43 *);
	ssize_t (*write_iter)(struct kiocb___113 *, struct iov_iter___43 *);
	int (*iopoll)(struct kiocb___113 *, bool);
	int (*iterate)(struct file___113 *, struct dir_context *);
	int (*iterate_shared)(struct file___113 *, struct dir_context *);
	__poll_t (*poll)(struct file___113 *, struct poll_table_struct___76 *);
	long int (*unlocked_ioctl)(struct file___113 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___113 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___113 *, struct vm_area_struct___113 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___114 *, struct file___113 *);
	int (*flush)(struct file___113 *, fl_owner_t);
	int (*release)(struct inode___114 *, struct file___113 *);
	int (*fsync)(struct file___113 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___113 *, int);
	int (*lock)(struct file___113 *, int, struct file_lock___113 *);
	ssize_t (*sendpage)(struct file___113 *, struct page___113 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___113 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___113 *, int, struct file_lock___113 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___113 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___113 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___113 *, long int, struct file_lock___113 **, void **);
	long int (*fallocate)(struct file___113 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___103 *, struct file___113 *);
	ssize_t (*copy_file_range)(struct file___113 *, loff_t, struct file___113 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___113 *, loff_t, struct file___113 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___113 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___112 {
	u64 seqnum;
	struct vm_area_struct___113 *vmas[4];
};

struct page_frag___112 {
	struct page___113 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___71;

struct debug_info___71 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___71 *hbp_break[16];
	struct perf_event___71 *hbp_watch[16];
};

struct thread_struct___71 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___71 debug;
	long: 64;
};

struct mm_struct___112;

struct pid___95;

struct cred___108;

struct nsproxy___105;

struct signal_struct___102;

struct css_set___89;

struct perf_event_context___71;

struct vm_struct___82;

struct task_struct___113 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___113 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___112 *mm;
	struct mm_struct___112 *active_mm;
	struct vmacache___112 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___113 *real_parent;
	struct task_struct___113 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___113 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___95 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___95 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___95 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___108 *ptracer_cred;
	const struct cred___108 *real_cred;
	const struct cred___108 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___105 *nsproxy;
	struct signal_struct___102 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___113 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___17 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___89 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___71 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___112 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___113 *oom_reaper_list;
	struct vm_struct___82 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___71 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___71 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___113 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___71)(struct perf_event___71 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___71;

struct fasync_struct___112;

struct pid_namespace___95;

struct trace_event_call___66;

struct perf_cgroup___71;

struct perf_event___71 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___71 *group_leader;
	struct pmu___71 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___71 hw;
	struct perf_event_context___71 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___71 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___113 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___112 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___71 *);
	struct callback_head callback_head;
	struct pid_namespace___95 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___71 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___71 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___66 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___71 *cgrp;
	struct list_head sb_list;
};

struct upid___95 {
	int nr;
	struct pid_namespace___95 *ns;
};

struct dentry___113;

struct user_namespace___93;

struct ucounts___93;

struct pid_namespace___95 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___113 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___95 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___113 *proc_self;
	struct dentry___113 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___93 *user_ns;
	struct ucounts___93 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___7 ns;
};

struct pid___95 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___95 numbers[1];
};

struct rw_semaphore___113 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___113 *owner;
};

struct key___108;

struct user_namespace___93 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___93 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___7 ns;
	long unsigned int flags;
	struct key___108 *persistent_keyring_register;
	struct rw_semaphore___113 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___93 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct secondary_data___113 {
	void *stack;
	struct task_struct___113 *task;
	long int status;
};

typedef struct page___113 *pgtable_t___112;

struct address_space___112;

struct dev_pagemap___110;

struct page___113 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___112 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___113 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___112 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___112 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___110 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct user_struct___108 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___108 *uid_keyring;
	struct key___108 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___110;

struct vm_area_struct___113 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___113 *vm_next;
	struct vm_area_struct___113 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___112 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___110 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___113 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___112;

struct mm_struct___112 {
	struct {
		struct vm_area_struct___113 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___113 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___113 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___112 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___113 *owner;
		struct user_namespace___93 *user_ns;
		struct file___113 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___112 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___108 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___108 *session_keyring;
	struct key___108 *process_keyring;
	struct key___108 *thread_keyring;
	struct key___108 *request_key_auth;
	void *security;
	struct user_struct___108 *user;
	struct user_namespace___93 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___89;

struct nsproxy___105 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___95 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___89 *cgroup_ns;
};

struct signal_struct___102 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___113 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___113 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___95 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___95 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___112 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___95 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___89;

struct cgroup___89;

struct css_set___89 {
	struct cgroup_subsys_state___89 *subsys[13];
	refcount_t refcount;
	struct css_set___89 *dom_cset;
	struct cgroup___89 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___89 *mg_src_cgrp;
	struct cgroup___89 *mg_dst_cgrp;
	struct css_set___89 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___71 {
	struct pmu___71 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___113 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___71 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___82 {
	struct vm_struct___82 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___113 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___102 {
	struct task_struct___113 task;
	long unsigned int stack[8192];
};

typedef int (*key_restrict_link_func_t___108)(struct key___108 *, const struct key_type *, const union key_payload *, struct key___108 *);

struct key_restriction___108;

struct key___108 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___113 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___108 *restrict_link;
};

struct key_restriction___108 {
	key_restrict_link_func_t___108 check;
	struct key___108 *key;
	struct key_type *keytype;
};

struct pglist_data___112;

struct lruvec___112 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___112 *pgdat;
};

struct zone___112 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___112 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___112 {
	struct zone___112 *zone;
	int zone_idx;
};

struct zonelist___112 {
	struct zoneref___112 _zonerefs[25];
};

struct pglist_data___112 {
	struct zone___112 node_zones[3];
	struct zonelist___112 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___113 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___113 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___112 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___112 {
	struct rw_semaphore___113 rwsem;
	struct notifier_block *head;
};

struct address_space_operations___112;

struct address_space___112 {
	struct inode___114 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___113 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___112 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___110)(struct vm_area_struct___113 *, long unsigned int, const struct page___113 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___110)(struct page___113 *, void *);

struct device___104;

struct dev_pagemap___110 {
	dev_page_fault_t___110 page_fault;
	dev_page_free_t___110 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___104 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___112 {
	struct vfsmount *mnt;
	struct dentry___113 *dentry;
};

struct fown_struct___95 {
	rwlock_t lock;
	struct pid___95 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___113 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___112 f_path;
	struct inode___114 *f_inode;
	const struct file_operations___113 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___95 f_owner;
	const struct cred___108 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___112 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___110;

struct vm_operations_struct___110 {
	void (*open)(struct vm_area_struct___113 *);
	void (*close)(struct vm_area_struct___113 *);
	int (*split)(struct vm_area_struct___113 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___113 *);
	vm_fault_t (*fault)(struct vm_fault___110 *);
	vm_fault_t (*huge_fault)(struct vm_fault___110 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___110 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___113 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___110 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___110 *);
	int (*access)(struct vm_area_struct___113 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___113 *);
	int (*set_policy)(struct vm_area_struct___113 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___113 *, long unsigned int);
	struct page___113 * (*find_special_page)(struct vm_area_struct___113 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___112 {
	struct task_struct___113 *task;
	struct core_thread___112 *next;
};

struct core_state___112 {
	atomic_t nr_threads;
	struct core_thread___112 dumper;
	struct completion startup;
};

struct vm_fault___110 {
	struct vm_area_struct___113 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___113 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___113 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___112 prealloc_pte;
};

struct kset___106;

struct kobj_type___106;

struct kernfs_node___109;

struct kobject___107 {
	const char *name;
	struct list_head entry;
	struct kobject___107 *parent;
	struct kset___106 *kset;
	struct kobj_type___106 *ktype;
	struct kernfs_node___109 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___104 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___104 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___104;

struct bus_type___104;

struct device_driver___104;

struct dev_pm_domain___104;

struct device_node___40;

struct fwnode_handle___76;

struct class___104;

struct attribute_group___103;

struct device___104 {
	struct device___104 *parent;
	struct device_private *p;
	struct kobject___107 kobj;
	const char *init_name;
	const struct device_type___104 *type;
	struct mutex mutex;
	struct bus_type___104 *bus;
	struct device_driver___104 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___104 power;
	struct dev_pm_domain___104 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___40 *of_node;
	struct fwnode_handle___76 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___104 *class;
	const struct attribute_group___103 **groups;
	void (*release)(struct device___104 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___112;

struct super_block___113;

struct dentry___113 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___113 *d_parent;
	struct qstr d_name;
	struct inode___114 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___112 *d_op;
	struct super_block___113 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___112;

struct block_device___113;

struct inode___114 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___112 *i_op;
	struct super_block___113 *i_sb;
	struct address_space___112 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___113 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___113 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___112 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___113 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___112 {
	int (*d_revalidate)(struct dentry___113 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___113 *, unsigned int);
	int (*d_hash)(const struct dentry___113 *, struct qstr *);
	int (*d_compare)(const struct dentry___113 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___113 *);
	int (*d_init)(struct dentry___113 *);
	void (*d_release)(struct dentry___113 *);
	void (*d_prune)(struct dentry___113 *);
	void (*d_iput)(struct dentry___113 *, struct inode___114 *);
	char * (*d_dname)(struct dentry___113 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___112 *);
	int (*d_manage)(const struct path___112 *, bool);
	struct dentry___113 * (*d_real)(struct dentry___113 *, const struct inode___114 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___112;

struct mem_dqinfo___112 {
	struct quota_format_type___112 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___112;

struct quota_info___112 {
	unsigned int flags;
	struct rw_semaphore___113 dqio_sem;
	struct inode___114 *files[3];
	struct mem_dqinfo___112 info[3];
	const struct quota_format_ops___112 *ops[3];
};

struct rcuwait___112 {
	struct task_struct___113 *task;
};

struct percpu_rw_semaphore___112 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___113 rw_sem;
	struct rcuwait___112 writer;
	int readers_block;
};

struct sb_writers___112 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___112 rw_sem[3];
};

struct file_system_type___112;

struct super_operations___112;

struct dquot_operations___112;

struct quotactl_ops___112;

struct super_block___113 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___112 *s_type;
	const struct super_operations___112 *s_op;
	const struct dquot_operations___112 *dq_op;
	const struct quotactl_ops___112 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___113 *s_root;
	struct rw_semaphore___113 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___113 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___112 s_dquot;
	struct sb_writers___112 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___112 *s_d_op;
	int cleancache_poolid;
	struct shrinker___36 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___93 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___113 {
	struct file___113 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___113 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___113 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___113 *ia_file;
};

struct dquot___112 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___113 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___112 {
	int qf_fmt_id;
	const struct quota_format_ops___112 *qf_ops;
	struct module___96 *qf_owner;
	struct quota_format_type___112 *qf_next;
};

struct quota_format_ops___112 {
	int (*check_quota_file)(struct super_block___113 *, int);
	int (*read_file_info)(struct super_block___113 *, int);
	int (*write_file_info)(struct super_block___113 *, int);
	int (*free_file_info)(struct super_block___113 *, int);
	int (*read_dqblk)(struct dquot___112 *);
	int (*commit_dqblk)(struct dquot___112 *);
	int (*release_dqblk)(struct dquot___112 *);
	int (*get_next_id)(struct super_block___113 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___112 {
	int (*write_dquot)(struct dquot___112 *);
	struct dquot___112 * (*alloc_dquot)(struct super_block___113 *, int);
	void (*destroy_dquot)(struct dquot___112 *);
	int (*acquire_dquot)(struct dquot___112 *);
	int (*release_dquot)(struct dquot___112 *);
	int (*mark_dirty)(struct dquot___112 *);
	int (*write_info)(struct super_block___113 *, int);
	qsize_t * (*get_reserved_space)(struct inode___114 *);
	int (*get_projid)(struct inode___114 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___114 *, qsize_t *);
	int (*get_next_id)(struct super_block___113 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___112 {
	int (*quota_on)(struct super_block___113 *, int, int, const struct path___112 *);
	int (*quota_off)(struct super_block___113 *, int);
	int (*quota_enable)(struct super_block___113 *, unsigned int);
	int (*quota_disable)(struct super_block___113 *, unsigned int);
	int (*quota_sync)(struct super_block___113 *, int);
	int (*set_info)(struct super_block___113 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___113 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___113 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___113 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___113 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___113 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___93 {
	struct kobject___107 kobj;
	struct module___96 *mod;
	struct kobject___107 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___93 {
	struct module___96 *mod;
	struct latch_tree_node node;
};

struct module_layout___93 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___93 mtn;
};

struct module_attribute___93;

struct kernel_param___93;

struct module___96 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___93 mkobj;
	struct module_attribute___93 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___107 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___93 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___93 core_layout;
	struct module_layout___93 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___66 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___112 {
	int (*writepage)(struct page___113 *, struct writeback_control___3 *);
	int (*readpage)(struct file___113 *, struct page___113 *);
	int (*writepages)(struct address_space___112 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___113 *);
	int (*readpages)(struct file___113 *, struct address_space___112 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___113 *, struct address_space___112 *, loff_t, unsigned int, unsigned int, struct page___113 **, void **);
	int (*write_end)(struct file___113 *, struct address_space___112 *, loff_t, unsigned int, unsigned int, struct page___113 *, void *);
	sector_t (*bmap)(struct address_space___112 *, sector_t);
	void (*invalidatepage)(struct page___113 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___113 *, gfp_t);
	void (*freepage)(struct page___113 *);
	ssize_t (*direct_IO)(struct kiocb___113 *, struct iov_iter___43 *);
	int (*migratepage)(struct address_space___112 *, struct page___113 *, struct page___113 *, enum migrate_mode);
	bool (*isolate_page)(struct page___113 *, isolate_mode_t);
	void (*putback_page)(struct page___113 *);
	int (*launder_page)(struct page___113 *);
	int (*is_partially_uptodate)(struct page___113 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___113 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___112 *, struct page___113 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___113 *, sector_t *);
	void (*swap_deactivate)(struct file___113 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___113 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___114 *bd_inode;
	struct super_block___113 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___113 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___112 {
	struct dentry___113 * (*lookup)(struct inode___114 *, struct dentry___113 *, unsigned int);
	const char * (*get_link)(struct dentry___113 *, struct inode___114 *, struct delayed_call *);
	int (*permission)(struct inode___114 *, int);
	struct posix_acl * (*get_acl)(struct inode___114 *, int);
	int (*readlink)(struct dentry___113 *, char *, int);
	int (*create)(struct inode___114 *, struct dentry___113 *, umode_t, bool);
	int (*link)(struct dentry___113 *, struct inode___114 *, struct dentry___113 *);
	int (*unlink)(struct inode___114 *, struct dentry___113 *);
	int (*symlink)(struct inode___114 *, struct dentry___113 *, const char *);
	int (*mkdir)(struct inode___114 *, struct dentry___113 *, umode_t);
	int (*rmdir)(struct inode___114 *, struct dentry___113 *);
	int (*mknod)(struct inode___114 *, struct dentry___113 *, umode_t, dev_t);
	int (*rename)(struct inode___114 *, struct dentry___113 *, struct inode___114 *, struct dentry___113 *, unsigned int);
	int (*setattr)(struct dentry___113 *, struct iattr___113 *);
	int (*getattr)(const struct path___112 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___113 *, char *, size_t);
	int (*fiemap)(struct inode___114 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___114 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___114 *, struct dentry___113 *, struct file___113 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___114 *, struct dentry___113 *, umode_t);
	int (*set_acl)(struct inode___114 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___112 {
	void (*fl_copy_lock)(struct file_lock___113 *, struct file_lock___113 *);
	void (*fl_release_private)(struct file_lock___113 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___112;

struct file_lock___113 {
	struct file_lock___113 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___113 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___112 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___112 *fl_ops;
	const struct lock_manager_operations___112 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___112 {
	int (*lm_compare_owner)(struct file_lock___113 *, struct file_lock___113 *);
	long unsigned int (*lm_owner_key)(struct file_lock___113 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___113 *);
	int (*lm_grant)(struct file_lock___113 *, int);
	bool (*lm_break)(struct file_lock___113 *);
	int (*lm_change)(struct file_lock___113 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___113 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___112 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___112 *fa_next;
	struct file___113 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___112 {
	const char *name;
	int fs_flags;
	struct dentry___113 * (*mount)(struct file_system_type___112 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___113 *);
	struct module___96 *owner;
	struct file_system_type___112 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___112 {
	struct inode___114 * (*alloc_inode)(struct super_block___113 *);
	void (*destroy_inode)(struct inode___114 *);
	void (*dirty_inode)(struct inode___114 *, int);
	int (*write_inode)(struct inode___114 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___114 *);
	void (*evict_inode)(struct inode___114 *);
	void (*put_super)(struct super_block___113 *);
	int (*sync_fs)(struct super_block___113 *, int);
	int (*freeze_super)(struct super_block___113 *);
	int (*freeze_fs)(struct super_block___113 *);
	int (*thaw_super)(struct super_block___113 *);
	int (*unfreeze_fs)(struct super_block___113 *);
	int (*statfs)(struct dentry___113 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___113 *, int *, char *);
	void (*umount_begin)(struct super_block___113 *);
	int (*show_options)(struct seq_file___103 *, struct dentry___113 *);
	int (*show_devname)(struct seq_file___103 *, struct dentry___113 *);
	int (*show_path)(struct seq_file___103 *, struct dentry___113 *);
	int (*show_stats)(struct seq_file___103 *, struct dentry___113 *);
	ssize_t (*quota_read)(struct super_block___113 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___113 *, int, const char *, size_t, loff_t);
	struct dquot___112 ** (*get_dquots)(struct inode___114 *);
	int (*bdev_try_to_free_page)(struct super_block___113 *, struct page___113 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___113 *, struct shrink_control___36 *);
	long int (*free_cached_objects)(struct super_block___113 *, struct shrink_control___36 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___75)(struct file___113 *, wait_queue_head_t *, struct poll_table_struct___76 *);

struct poll_table_struct___76 {
	poll_queue_proc___75 _qproc;
	__poll_t _key;
};

struct seq_operations___101;

struct seq_file___103 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___101 *op;
	int poll_event;
	const struct file___113 *file;
	void *private;
};

struct kobj_attribute___107 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___107 *, struct kobj_attribute___107 *, char *);
	ssize_t (*store)(struct kobject___107 *, struct kobj_attribute___107 *, const char *, size_t);
};

typedef void compound_page_dtor___110(struct page___113 *);

struct cgroup_namespace___89 {
	refcount_t count;
	struct ns_common___7 ns;
	struct user_namespace___93 *user_ns;
	struct ucounts___93 *ucounts;
	struct css_set___89 *root_cset;
};

struct ucounts___93 {
	struct hlist_node node;
	struct user_namespace___93 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct kernfs_root___109;

struct kernfs_elem_dir___109 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___109 *root;
};

struct kernfs_syscall_ops___109;

struct kernfs_root___109 {
	struct kernfs_node___109 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___109 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___109 {
	struct kernfs_node___109 *target_kn;
};

struct kernfs_ops___109;

struct kernfs_elem_attr___109 {
	const struct kernfs_ops___109 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___109 *notify_next;
};

struct kernfs_node___109 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___109 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___109 dir;
		struct kernfs_elem_symlink___109 symlink;
		struct kernfs_elem_attr___109 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___109;

struct kernfs_ops___109 {
	int (*open)(struct kernfs_open_file___109 *);
	void (*release)(struct kernfs_open_file___109 *);
	int (*seq_show)(struct seq_file___103 *, void *);
	void * (*seq_start)(struct seq_file___103 *, loff_t *);
	void * (*seq_next)(struct seq_file___103 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___103 *, void *);
	ssize_t (*read)(struct kernfs_open_file___109 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___109 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___109 *, struct vm_area_struct___113 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___109 *, struct poll_table_struct___76 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___109 {
	int (*remount_fs)(struct kernfs_root___109 *, int *, char *);
	int (*show_options)(struct seq_file___103 *, struct kernfs_root___109 *);
	int (*mkdir)(struct kernfs_node___109 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___109 *);
	int (*rename)(struct kernfs_node___109 *, struct kernfs_node___109 *, const char *);
	int (*show_path)(struct seq_file___103 *, struct kernfs_node___109 *, struct kernfs_root___109 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___109 {
	struct kernfs_node___109 *kn;
	struct file___113 *file;
	struct seq_file___103 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___110 *vm_ops;
};

struct bin_attribute___103;

struct attribute_group___103 {
	const char *name;
	umode_t (*is_visible)(struct kobject___107 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___107 *, struct bin_attribute___103 *, int);
	struct attribute **attrs;
	struct bin_attribute___103 **bin_attrs;
};

struct bin_attribute___103 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___113 *, struct kobject___107 *, struct bin_attribute___103 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___113 *, struct kobject___107 *, struct bin_attribute___103 *, char *, loff_t, size_t);
	int (*mmap)(struct file___113 *, struct kobject___107 *, struct bin_attribute___103 *, struct vm_area_struct___113 *);
};

struct sysfs_ops___106 {
	ssize_t (*show)(struct kobject___107 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___107 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___106;

struct kset___106 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___107 kobj;
	const struct kset_uevent_ops___106 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___106 {
	void (*release)(struct kobject___107 *);
	const struct sysfs_ops___106 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___5 * (*child_ns_type)(struct kobject___107 *);
	const void * (*namespace)(struct kobject___107 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___106 {
	int (* const filter)(struct kset___106 *, struct kobject___107 *);
	const char * (* const name)(struct kset___106 *, struct kobject___107 *);
	int (* const uevent)(struct kset___106 *, struct kobject___107 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___93 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___93 *);
	int (*get)(char *, const struct kernel_param___93 *);
	void (*free)(void *);
};

struct kparam_array___93;

struct kernel_param___93 {
	const char *name;
	struct module___96 *mod;
	const struct kernel_param_ops___93 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___93 *arr;
	};
};

struct kparam_array___93 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___93 *ops;
	void *elem;
};

struct module_attribute___93 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___93 *, struct module_kobject___93 *, char *);
	ssize_t (*store)(struct module_attribute___93 *, struct module_kobject___93 *, const char *, size_t);
	void (*setup)(struct module___96 *, const char *);
	int (*test)(struct module___96 *);
	void (*free)(struct module___96 *);
};

struct trace_event_functions___12;

struct trace_event___12 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___12 *funcs;
};

struct trace_event_class___66;

struct trace_event_call___66 {
	struct list_head list;
	struct trace_event_class___66 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___12 event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___10 *prog_array;
	int (*perf_perm)(struct trace_event_call___66 *, struct perf_event___71 *);
};

struct fwnode_operations___76;

struct fwnode_handle___76 {
	struct fwnode_handle___76 *secondary;
	const struct fwnode_operations___76 *ops;
};

struct fwnode_reference_args___76;

struct fwnode_endpoint___76;

struct fwnode_operations___76 {
	struct fwnode_handle___76 * (*get)(struct fwnode_handle___76 *);
	void (*put)(struct fwnode_handle___76 *);
	bool (*device_is_available)(const struct fwnode_handle___76 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___76 *, const struct device___104 *);
	bool (*property_present)(const struct fwnode_handle___76 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___76 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___76 *, const char *, const char **, size_t);
	struct fwnode_handle___76 * (*get_parent)(const struct fwnode_handle___76 *);
	struct fwnode_handle___76 * (*get_next_child_node)(const struct fwnode_handle___76 *, struct fwnode_handle___76 *);
	struct fwnode_handle___76 * (*get_named_child_node)(const struct fwnode_handle___76 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___76 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___76 *);
	struct fwnode_handle___76 * (*graph_get_next_endpoint)(const struct fwnode_handle___76 *, struct fwnode_handle___76 *);
	struct fwnode_handle___76 * (*graph_get_remote_endpoint)(const struct fwnode_handle___76 *);
	struct fwnode_handle___76 * (*graph_get_port_parent)(struct fwnode_handle___76 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___76 *, struct fwnode_endpoint___76 *);
};

struct fwnode_endpoint___76 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___76 *local_fwnode;
};

struct fwnode_reference_args___76 {
	struct fwnode_handle___76 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct property___39 {
	char *name;
	int length;
	void *value;
	struct property___39 *next;
	long unsigned int _flags;
	struct bin_attribute___103 attr;
};

struct device_node___40 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___76 fwnode;
	struct property___39 *properties;
	struct property___39 *deadprops;
	struct device_node___40 *parent;
	struct device_node___40 *child;
	struct device_node___40 *sibling;
	struct kobject___107 kobj;
	long unsigned int _flags;
	void *data;
};

struct seq_operations___101 {
	void * (*start)(struct seq_file___103 *, loff_t *);
	void (*stop)(struct seq_file___103 *, void *);
	void * (*next)(struct seq_file___103 *, void *, loff_t *);
	int (*show)(struct seq_file___103 *, void *);
};

struct dev_pm_ops___104 {
	int (*prepare)(struct device___104 *);
	void (*complete)(struct device___104 *);
	int (*suspend)(struct device___104 *);
	int (*resume)(struct device___104 *);
	int (*freeze)(struct device___104 *);
	int (*thaw)(struct device___104 *);
	int (*poweroff)(struct device___104 *);
	int (*restore)(struct device___104 *);
	int (*suspend_late)(struct device___104 *);
	int (*resume_early)(struct device___104 *);
	int (*freeze_late)(struct device___104 *);
	int (*thaw_early)(struct device___104 *);
	int (*poweroff_late)(struct device___104 *);
	int (*restore_early)(struct device___104 *);
	int (*suspend_noirq)(struct device___104 *);
	int (*resume_noirq)(struct device___104 *);
	int (*freeze_noirq)(struct device___104 *);
	int (*thaw_noirq)(struct device___104 *);
	int (*poweroff_noirq)(struct device___104 *);
	int (*restore_noirq)(struct device___104 *);
	int (*runtime_suspend)(struct device___104 *);
	int (*runtime_resume)(struct device___104 *);
	int (*runtime_idle)(struct device___104 *);
};

struct dev_pm_domain___104 {
	struct dev_pm_ops___104 ops;
	void (*detach)(struct device___104 *, bool);
	int (*activate)(struct device___104 *);
	void (*sync)(struct device___104 *);
	void (*dismiss)(struct device___104 *);
};

struct bus_type___104 {
	const char *name;
	const char *dev_name;
	struct device___104 *dev_root;
	const struct attribute_group___103 **bus_groups;
	const struct attribute_group___103 **dev_groups;
	const struct attribute_group___103 **drv_groups;
	int (*match)(struct device___104 *, struct device_driver___104 *);
	int (*uevent)(struct device___104 *, struct kobj_uevent_env *);
	int (*probe)(struct device___104 *);
	int (*remove)(struct device___104 *);
	void (*shutdown)(struct device___104 *);
	int (*online)(struct device___104 *);
	int (*offline)(struct device___104 *);
	int (*suspend)(struct device___104 *, pm_message_t);
	int (*resume)(struct device___104 *);
	int (*num_vf)(struct device___104 *);
	int (*dma_configure)(struct device___104 *);
	const struct dev_pm_ops___104 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___104 {
	const char *name;
	struct bus_type___104 *bus;
	struct module___96 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___104 *);
	int (*remove)(struct device___104 *);
	void (*shutdown)(struct device___104 *);
	int (*suspend)(struct device___104 *, pm_message_t);
	int (*resume)(struct device___104 *);
	const struct attribute_group___103 **groups;
	const struct dev_pm_ops___104 *pm;
	void (*coredump)(struct device___104 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___104 {
	const char *name;
	const struct attribute_group___103 **groups;
	int (*uevent)(struct device___104 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___104 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___104 *);
	const struct dev_pm_ops___104 *pm;
};

struct class___104 {
	const char *name;
	struct module___96 *owner;
	const struct attribute_group___103 **class_groups;
	const struct attribute_group___103 **dev_groups;
	struct kobject___107 *dev_kobj;
	int (*dev_uevent)(struct device___104 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___104 *, umode_t *);
	void (*class_release)(struct class___104 *);
	void (*dev_release)(struct device___104 *);
	int (*shutdown_pre)(struct device___104 *);
	const struct kobj_ns_type_operations___5 *ns_type;
	const void * (*namespace)(struct device___104 *);
	const struct dev_pm_ops___104 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___90 {
	struct device___104 dev;
};

struct bpf_map___89;

struct bpf_map_ops___89 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___89 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___89 *, struct file___113 *);
	void (*map_free)(struct bpf_map___89 *);
	int (*map_get_next_key)(struct bpf_map___89 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___89 *);
	void * (*map_lookup_elem)(struct bpf_map___89 *, void *);
	int (*map_update_elem)(struct bpf_map___89 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___89 *, void *);
	int (*map_push_elem)(struct bpf_map___89 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___89 *, void *);
	int (*map_peek_elem)(struct bpf_map___89 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___89 *, struct file___113 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___89 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___89 *, void *, struct seq_file___103 *);
	int (*map_check_btf)(const struct bpf_map___89 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___89 {
	const struct bpf_map_ops___89 *ops;
	struct bpf_map___89 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___108 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___89;

typedef void (*kthread_work_func_t___89)(struct kthread_work___89 *);

struct kthread_worker___89;

struct kthread_work___89 {
	struct list_head node;
	kthread_work_func_t___89 func;
	struct kthread_worker___89 *worker;
	int canceling;
};

struct kthread_worker___89 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___113 *task;
	struct kthread_work___89 *current_work;
};

struct kthread_delayed_work___89 {
	struct kthread_work___89 work;
	struct timer_list timer;
};

struct psi_group___89 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___89 *poll_kworker;
	struct kthread_delayed_work___89 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___89 {
	struct kernfs_node___109 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___89;

struct cgroup_subsys_state___89 {
	struct cgroup___89 *cgroup;
	struct cgroup_subsys___89 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___89 *parent;
};

struct cgroup_root___89;

struct cgroup_rstat_cpu___89;

struct cgroup___89 {
	struct cgroup_subsys_state___89 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___109 *kn;
	struct cgroup_file___89 procs_file;
	struct cgroup_file___89 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___89 *subsys[13];
	struct cgroup_root___89 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___89 *dom_cgrp;
	struct cgroup_rstat_cpu___89 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___10 bpf;
	atomic_t congestion_count;
	struct cgroup___89 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___89 psi;
	int ancestor_ids[0];
};

struct cftype___89;

struct cgroup_subsys___89 {
	struct cgroup_subsys_state___89 * (*css_alloc)(struct cgroup_subsys_state___89 *);
	int (*css_online)(struct cgroup_subsys_state___89 *);
	void (*css_offline)(struct cgroup_subsys_state___89 *);
	void (*css_released)(struct cgroup_subsys_state___89 *);
	void (*css_free)(struct cgroup_subsys_state___89 *);
	void (*css_reset)(struct cgroup_subsys_state___89 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___89 *, int);
	int (*css_extra_stat_show)(struct seq_file___103 *, struct cgroup_subsys_state___89 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___113 *);
	void (*cancel_fork)(struct task_struct___113 *);
	void (*fork)(struct task_struct___113 *);
	void (*exit)(struct task_struct___113 *);
	void (*free)(struct task_struct___113 *);
	void (*bind)(struct cgroup_subsys_state___89 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___89 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___89 *dfl_cftypes;
	struct cftype___89 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___89 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___89 *updated_children;
	struct cgroup___89 *updated_next;
};

struct cgroup_root___89 {
	struct kernfs_root___109 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___89 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___89 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___89 *ss;
	struct list_head node;
	struct kernfs_ops___109 *kf_ops;
	int (*open)(struct kernfs_open_file___109 *);
	void (*release)(struct kernfs_open_file___109 *);
	u64 (*read_u64)(struct cgroup_subsys_state___89 *, struct cftype___89 *);
	s64 (*read_s64)(struct cgroup_subsys_state___89 *, struct cftype___89 *);
	int (*seq_show)(struct seq_file___103 *, void *);
	void * (*seq_start)(struct seq_file___103 *, loff_t *);
	void * (*seq_next)(struct seq_file___103 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___103 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___89 *, struct cftype___89 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___89 *, struct cftype___89 *, s64);
	ssize_t (*write)(struct kernfs_open_file___109 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___109 *, struct poll_table_struct___76 *);
};

struct perf_cpu_context___71;

struct pmu___71 {
	struct list_head entry;
	struct module___96 *module;
	struct device___104 *dev;
	const struct attribute_group___103 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___71 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___71 *);
	void (*pmu_disable)(struct pmu___71 *);
	int (*event_init)(struct perf_event___71 *);
	void (*event_mapped)(struct perf_event___71 *, struct mm_struct___112 *);
	void (*event_unmapped)(struct perf_event___71 *, struct mm_struct___112 *);
	int (*add)(struct perf_event___71 *, int);
	void (*del)(struct perf_event___71 *, int);
	void (*start)(struct perf_event___71 *, int);
	void (*stop)(struct perf_event___71 *, int);
	void (*read)(struct perf_event___71 *);
	void (*start_txn)(struct pmu___71 *, unsigned int);
	int (*commit_txn)(struct pmu___71 *);
	void (*cancel_txn)(struct pmu___71 *);
	int (*event_idx)(struct perf_event___71 *);
	void (*sched_task)(struct perf_event_context___71 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___71 *);
	int (*filter_match)(struct perf_event___71 *);
	int (*check_period)(struct perf_event___71 *, u64);
};

struct perf_cpu_context___71 {
	struct perf_event_context___71 ctx;
	struct perf_event_context___71 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___71 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___71 {
	struct cgroup_subsys_state___89 css;
	struct perf_cgroup_info *info;
};

struct trace_array___12;

struct tracer___12;

struct trace_buffer___12;

struct trace_iterator___12 {
	struct trace_array___12 *tr;
	struct tracer___12 *trace;
	struct trace_buffer___12 *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

struct trace_buffer___12 {
	struct trace_array___12 *tr;
	struct ring_buffer *buffer;
	struct trace_array_cpu *data;
	u64 time_start;
	int cpu;
};

struct trace_event_file___31;

struct trace_options___12;

struct trace_array___12 {
	struct list_head list;
	char *name;
	struct trace_buffer___12 trace_buffer;
	struct trace_buffer___12 max_buffer;
	bool allocated_snapshot;
	long unsigned int max_latency;
	struct trace_pid_list *filtered_pids;
	arch_spinlock_t max_lock;
	int buffer_disabled;
	int sys_refcount_enter;
	int sys_refcount_exit;
	struct trace_event_file___31 *enter_syscall_files[295];
	struct trace_event_file___31 *exit_syscall_files[295];
	int stop_count;
	int clock_id;
	int nr_topts;
	bool clear_trace;
	struct tracer___12 *current_trace;
	unsigned int trace_flags;
	unsigned char trace_flags_index[32];
	unsigned int flags;
	raw_spinlock_t start_lock;
	struct dentry___113 *dir;
	struct dentry___113 *options;
	struct dentry___113 *percpu_dir;
	struct dentry___113 *event_dir;
	struct trace_options___12 *topts;
	struct list_head systems;
	struct list_head events;
	struct trace_event_file___31 *trace_marker_file;
	cpumask_var_t tracing_cpumask;
	int ref;
	struct ftrace_ops *ops;
	struct trace_pid_list *function_pids;
	struct list_head func_probes;
	struct list_head mod_trace;
	struct list_head mod_notrace;
	int function_enabled;
	int time_stamp_abs_ref;
	struct list_head hist_vars;
};

struct tracer_flags___12;

struct tracer___12 {
	const char *name;
	int (*init)(struct trace_array___12 *);
	void (*reset)(struct trace_array___12 *);
	void (*start)(struct trace_array___12 *);
	void (*stop)(struct trace_array___12 *);
	int (*update_thresh)(struct trace_array___12 *);
	void (*open)(struct trace_iterator___12 *);
	void (*pipe_open)(struct trace_iterator___12 *);
	void (*close)(struct trace_iterator___12 *);
	void (*pipe_close)(struct trace_iterator___12 *);
	ssize_t (*read)(struct trace_iterator___12 *, struct file___113 *, char *, size_t, loff_t *);
	ssize_t (*splice_read)(struct trace_iterator___12 *, struct file___113 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	void (*print_header)(struct seq_file___103 *);
	enum print_line_t (*print_line)(struct trace_iterator___12 *);
	int (*set_flag)(struct trace_array___12 *, u32, u32, int);
	int (*flag_changed)(struct trace_array___12 *, u32, int);
	struct tracer___12 *next;
	struct tracer_flags___12 *flags;
	int enabled;
	int ref;
	bool print_max;
	bool allow_instances;
	bool use_max_tr;
	bool noboot;
};

typedef enum print_line_t (*trace_print_func___12)(struct trace_iterator___12 *, int, struct trace_event___12 *);

struct trace_event_functions___12 {
	trace_print_func___12 trace;
	trace_print_func___12 raw;
	trace_print_func___12 hex;
	trace_print_func___12 binary;
};

struct trace_event_class___66 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___66 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___66 *);
	struct list_head * (*get_fields)(struct trace_event_call___66 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___66 *);
};

struct trace_subsystem_dir___12;

struct trace_event_file___31 {
	struct list_head list;
	struct trace_event_call___66 *event_call;
	struct event_filter *filter;
	struct dentry___113 *dir;
	struct trace_array___12 *tr;
	struct trace_subsystem_dir___12 *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_subsystem_dir___12 {
	struct list_head list;
	struct event_subsystem *subsystem;
	struct trace_array___12 *tr;
	struct dentry___113 *entry;
	int ref_count;
	int nr_events;
};

struct trace_option_dentry___12;

struct trace_options___12 {
	struct tracer___12 *tracer;
	struct trace_option_dentry___12 *topts;
};

struct trace_option_dentry___12 {
	struct tracer_opt *opt;
	struct tracer_flags___12 *flags;
	struct trace_array___12 *tr;
	struct dentry___113 *entry;
};

struct tracer_flags___12 {
	u32 val;
	struct tracer_opt *opts;
	struct tracer___12 *trace;
};

struct trace_probe___2 {
	unsigned int flags;
	struct trace_event_class___66 class;
	struct trace_event_call___66 call;
	struct list_head files;
	ssize_t size;
	unsigned int nr_args;
	struct probe_arg args[0];
};

struct deref_fetch_param {
	struct fetch_param orig;
	long int offset;
	fetch_func_t fetch;
	fetch_func_t fetch_size;
};

struct bitfield_fetch_param {
	struct fetch_param orig;
	unsigned char hi_shift;
	unsigned char low_shift;
};

struct module___97;

struct file___114;

struct kiocb___114;

struct poll_table_struct___77;

struct vm_area_struct___114;

struct inode___115;

struct file_lock___114;

struct page___114;

struct seq_file___104;

struct file_operations___114 {
	struct module___97 *owner;
	loff_t (*llseek)(struct file___114 *, loff_t, int);
	ssize_t (*read)(struct file___114 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___114 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___114 *, struct iov_iter___43 *);
	ssize_t (*write_iter)(struct kiocb___114 *, struct iov_iter___43 *);
	int (*iopoll)(struct kiocb___114 *, bool);
	int (*iterate)(struct file___114 *, struct dir_context *);
	int (*iterate_shared)(struct file___114 *, struct dir_context *);
	__poll_t (*poll)(struct file___114 *, struct poll_table_struct___77 *);
	long int (*unlocked_ioctl)(struct file___114 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___114 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___114 *, struct vm_area_struct___114 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___115 *, struct file___114 *);
	int (*flush)(struct file___114 *, fl_owner_t);
	int (*release)(struct inode___115 *, struct file___114 *);
	int (*fsync)(struct file___114 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___114 *, int);
	int (*lock)(struct file___114 *, int, struct file_lock___114 *);
	ssize_t (*sendpage)(struct file___114 *, struct page___114 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___114 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___114 *, int, struct file_lock___114 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___114 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___114 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___114 *, long int, struct file_lock___114 **, void **);
	long int (*fallocate)(struct file___114 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___104 *, struct file___114 *);
	ssize_t (*copy_file_range)(struct file___114 *, loff_t, struct file___114 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___114 *, loff_t, struct file___114 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___114 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___113 {
	u64 seqnum;
	struct vm_area_struct___114 *vmas[4];
};

struct page_frag___113 {
	struct page___114 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___72;

struct debug_info___72 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___72 *hbp_break[16];
	struct perf_event___72 *hbp_watch[16];
};

struct thread_struct___72 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___72 debug;
	long: 64;
};

struct mm_struct___113;

struct pid___96;

struct cred___109;

struct nsproxy___106;

struct signal_struct___103;

struct css_set___90;

struct perf_event_context___72;

struct vm_struct___83;

struct task_struct___114 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___114 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___113 *mm;
	struct mm_struct___113 *active_mm;
	struct vmacache___113 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___114 *real_parent;
	struct task_struct___114 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___114 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___96 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___96 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___96 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___109 *ptracer_cred;
	const struct cred___109 *real_cred;
	const struct cred___109 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___106 *nsproxy;
	struct signal_struct___103 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___114 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___17 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___90 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___72 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___113 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___114 *oom_reaper_list;
	struct vm_struct___83 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___72 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___72 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___114 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___72)(struct perf_event___72 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___72;

struct fasync_struct___113;

struct pid_namespace___96;

struct trace_event_call___67;

struct perf_cgroup___72;

struct perf_event___72 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___72 *group_leader;
	struct pmu___72 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___72 hw;
	struct perf_event_context___72 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___72 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___114 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___113 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___72 *);
	struct callback_head callback_head;
	struct pid_namespace___96 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___72 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___72 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___67 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___72 *cgrp;
	struct list_head sb_list;
};

struct rw_semaphore___114 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___114 *owner;
};

struct key___109;

struct ucounts___94;

struct user_namespace___94 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___94 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___7 ns;
	long unsigned int flags;
	struct key___109 *persistent_keyring_register;
	struct rw_semaphore___114 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___94 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___114 *pgtable_t___113;

struct address_space___113;

struct dev_pagemap___111;

struct page___114 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___113 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___114 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___113 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___113 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___111 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___113;

struct lruvec___113 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___113 *pgdat;
};

struct zone___113 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___113 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___113 {
	struct zone___113 *zone;
	int zone_idx;
};

struct zonelist___113 {
	struct zoneref___113 _zonerefs[25];
};

struct pglist_data___113 {
	struct zone___113 node_zones[3];
	struct zonelist___113 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___114 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___114 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___113 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___114 {
	void *stack;
	struct task_struct___114 *task;
	long int status;
};

struct blocking_notifier_head___113 {
	struct rw_semaphore___114 rwsem;
	struct notifier_block *head;
};

struct dentry___114;

struct path___113 {
	struct vfsmount *mnt;
	struct dentry___114 *dentry;
};

struct fown_struct___96 {
	rwlock_t lock;
	struct pid___96 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___114 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___113 f_path;
	struct inode___115 *f_inode;
	const struct file_operations___114 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___96 f_owner;
	const struct cred___109 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___113 *f_mapping;
	errseq_t f_wb_err;
};

struct user_struct___109;

struct cred___109 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___109 *session_keyring;
	struct key___109 *process_keyring;
	struct key___109 *thread_keyring;
	struct key___109 *request_key_auth;
	void *security;
	struct user_struct___109 *user;
	struct user_namespace___94 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___110;

struct kernfs_elem_dir___110 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___110 *root;
};

struct kernfs_node___110;

struct kernfs_syscall_ops___110;

struct kernfs_root___110 {
	struct kernfs_node___110 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___110 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___110 {
	struct kernfs_node___110 *target_kn;
};

struct kernfs_ops___110;

struct kernfs_elem_attr___110 {
	const struct kernfs_ops___110 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___110 *notify_next;
};

struct kernfs_node___110 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___110 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___110 dir;
		struct kernfs_elem_symlink___110 symlink;
		struct kernfs_elem_attr___110 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___110;

struct kernfs_ops___110 {
	int (*open)(struct kernfs_open_file___110 *);
	void (*release)(struct kernfs_open_file___110 *);
	int (*seq_show)(struct seq_file___104 *, void *);
	void * (*seq_start)(struct seq_file___104 *, loff_t *);
	void * (*seq_next)(struct seq_file___104 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___104 *, void *);
	ssize_t (*read)(struct kernfs_open_file___110 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___110 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___110 *, struct vm_area_struct___114 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___110 *, struct poll_table_struct___77 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___110 {
	int (*remount_fs)(struct kernfs_root___110 *, int *, char *);
	int (*show_options)(struct seq_file___104 *, struct kernfs_root___110 *);
	int (*mkdir)(struct kernfs_node___110 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___110 *);
	int (*rename)(struct kernfs_node___110 *, struct kernfs_node___110 *, const char *);
	int (*show_path)(struct seq_file___104 *, struct kernfs_node___110 *, struct kernfs_root___110 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___102;

struct seq_file___104 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___102 *op;
	int poll_event;
	const struct file___114 *file;
	void *private;
};

struct vm_operations_struct___111;

struct kernfs_open_file___110 {
	struct kernfs_node___110 *kn;
	struct file___114 *file;
	struct seq_file___104 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___111 *vm_ops;
};

struct vm_fault___111;

struct vm_operations_struct___111 {
	void (*open)(struct vm_area_struct___114 *);
	void (*close)(struct vm_area_struct___114 *);
	int (*split)(struct vm_area_struct___114 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___114 *);
	vm_fault_t (*fault)(struct vm_fault___111 *);
	vm_fault_t (*huge_fault)(struct vm_fault___111 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___111 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___114 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___111 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___111 *);
	int (*access)(struct vm_area_struct___114 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___114 *);
	int (*set_policy)(struct vm_area_struct___114 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___114 *, long unsigned int);
	struct page___114 * (*find_special_page)(struct vm_area_struct___114 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___76)(struct file___114 *, wait_queue_head_t *, struct poll_table_struct___77 *);

struct poll_table_struct___77 {
	poll_queue_proc___76 _qproc;
	__poll_t _key;
};

struct vm_area_struct___114 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___114 *vm_next;
	struct vm_area_struct___114 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___113 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___111 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___114 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___108;

struct bin_attribute___104;

struct attribute_group___104 {
	const char *name;
	umode_t (*is_visible)(struct kobject___108 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___108 *, struct bin_attribute___104 *, int);
	struct attribute **attrs;
	struct bin_attribute___104 **bin_attrs;
};

struct kset___107;

struct kobj_type___107;

struct kobject___108 {
	const char *name;
	struct list_head entry;
	struct kobject___108 *parent;
	struct kset___107 *kset;
	struct kobj_type___107 *ktype;
	struct kernfs_node___110 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___104 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___114 *, struct kobject___108 *, struct bin_attribute___104 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___114 *, struct kobject___108 *, struct bin_attribute___104 *, char *, loff_t, size_t);
	int (*mmap)(struct file___114 *, struct kobject___108 *, struct bin_attribute___104 *, struct vm_area_struct___114 *);
};

struct sysfs_ops___107 {
	ssize_t (*show)(struct kobject___108 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___108 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___107;

struct kset___107 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___108 kobj;
	const struct kset_uevent_ops___107 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___107 {
	void (*release)(struct kobject___108 *);
	const struct sysfs_ops___107 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___5 * (*child_ns_type)(struct kobject___108 *);
	const void * (*namespace)(struct kobject___108 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___107 {
	int (* const filter)(struct kset___107 *, struct kobject___108 *);
	const char * (* const name)(struct kset___107 *, struct kobject___108 *);
	int (* const uevent)(struct kset___107 *, struct kobject___108 *, struct kobj_uevent_env *);
};

struct kobj_attribute___108 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___108 *, struct kobj_attribute___108 *, char *);
	ssize_t (*store)(struct kobject___108 *, struct kobj_attribute___108 *, const char *, size_t);
};

struct kernel_param___94;

struct kernel_param_ops___94 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___94 *);
	int (*get)(char *, const struct kernel_param___94 *);
	void (*free)(void *);
};

struct kparam_array___94;

struct kernel_param___94 {
	const char *name;
	struct module___97 *mod;
	const struct kernel_param_ops___94 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___94 *arr;
	};
};

struct kparam_array___94 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___94 *ops;
	void *elem;
};

struct module_kobject___94 {
	struct kobject___108 kobj;
	struct module___97 *mod;
	struct kobject___108 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___94 {
	struct module___97 *mod;
	struct latch_tree_node node;
};

struct module_layout___94 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___94 mtn;
};

struct module_attribute___94;

struct module___97 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___94 mkobj;
	struct module_attribute___94 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___108 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___94 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___94 core_layout;
	struct module_layout___94 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___67 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___94 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___94 *, struct module_kobject___94 *, char *);
	ssize_t (*store)(struct module_attribute___94 *, struct module_kobject___94 *, const char *, size_t);
	void (*setup)(struct module___97 *, const char *);
	int (*test)(struct module___97 *);
	void (*free)(struct module___97 *);
};

struct trace_event_functions___13;

struct trace_event___13 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___13 *funcs;
};

struct trace_event_class___67;

struct trace_event_call___67 {
	struct list_head list;
	struct trace_event_class___67 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___13 event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___10 *prog_array;
	int (*perf_perm)(struct trace_event_call___67 *, struct perf_event___72 *);
};

struct upid___96 {
	int nr;
	struct pid_namespace___96 *ns;
};

struct pid_namespace___96 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___114 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___96 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___114 *proc_self;
	struct dentry___114 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___94 *user_ns;
	struct ucounts___94 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___7 ns;
};

struct pid___96 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___96 numbers[1];
};

struct user_struct___109 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___109 *uid_keyring;
	struct key___109 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___113;

struct mm_struct___113 {
	struct {
		struct vm_area_struct___114 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___114 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___114 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___113 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___114 *owner;
		struct user_namespace___94 *user_ns;
		struct file___114 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___113 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___90;

struct nsproxy___106 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___96 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___90 *cgroup_ns;
};

struct signal_struct___103 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___114 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___114 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___96 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___96 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___113 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___96 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___90;

struct cgroup___90;

struct css_set___90 {
	struct cgroup_subsys_state___90 *subsys[13];
	refcount_t refcount;
	struct css_set___90 *dom_cset;
	struct cgroup___90 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___90 *mg_src_cgrp;
	struct cgroup___90 *mg_dst_cgrp;
	struct css_set___90 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___72 {
	struct pmu___72 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___114 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___72 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___83 {
	struct vm_struct___83 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___114 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___103 {
	struct task_struct___114 task;
	long unsigned int stack[8192];
};

enum uprobe_filter_ctx {
	UPROBE_FILTER_REGISTER = 0,
	UPROBE_FILTER_UNREGISTER = 1,
	UPROBE_FILTER_MMAP = 2,
};

struct uprobe_consumer {
	int (*handler)(struct uprobe_consumer *, struct pt_regs *);
	int (*ret_handler)(struct uprobe_consumer *, long unsigned int, struct pt_regs *);
	bool (*filter)(struct uprobe_consumer *, enum uprobe_filter_ctx, struct mm_struct___113 *);
	struct uprobe_consumer *next;
};

struct address_space_operations___113;

struct address_space___113 {
	struct inode___115 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___114 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___113 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___111)(struct vm_area_struct___114 *, long unsigned int, const struct page___114 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___111)(struct page___114 *, void *);

struct device___105;

struct dev_pagemap___111 {
	dev_page_fault_t___111 page_fault;
	dev_page_free_t___111 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___105 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___113 {
	struct task_struct___114 *task;
	struct core_thread___113 *next;
};

struct core_state___113 {
	atomic_t nr_threads;
	struct core_thread___113 dumper;
	struct completion startup;
};

struct vm_fault___111 {
	struct vm_area_struct___114 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___114 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___114 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___113 prealloc_pte;
};

struct dentry_operations___113;

struct super_block___114;

struct dentry___114 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___114 *d_parent;
	struct qstr d_name;
	struct inode___115 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___113 *d_op;
	struct super_block___114 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___113;

struct block_device___114;

struct inode___115 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___113 *i_op;
	struct super_block___114 *i_sb;
	struct address_space___113 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___114 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___114 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___113 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___114 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___113 {
	int (*d_revalidate)(struct dentry___114 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___114 *, unsigned int);
	int (*d_hash)(const struct dentry___114 *, struct qstr *);
	int (*d_compare)(const struct dentry___114 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___114 *);
	int (*d_init)(struct dentry___114 *);
	void (*d_release)(struct dentry___114 *);
	void (*d_prune)(struct dentry___114 *);
	void (*d_iput)(struct dentry___114 *, struct inode___115 *);
	char * (*d_dname)(struct dentry___114 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___113 *);
	int (*d_manage)(const struct path___113 *, bool);
	struct dentry___114 * (*d_real)(struct dentry___114 *, const struct inode___115 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___113;

struct mem_dqinfo___113 {
	struct quota_format_type___113 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___113;

struct quota_info___113 {
	unsigned int flags;
	struct rw_semaphore___114 dqio_sem;
	struct inode___115 *files[3];
	struct mem_dqinfo___113 info[3];
	const struct quota_format_ops___113 *ops[3];
};

struct rcuwait___113 {
	struct task_struct___114 *task;
};

struct percpu_rw_semaphore___113 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___114 rw_sem;
	struct rcuwait___113 writer;
	int readers_block;
};

struct sb_writers___113 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___113 rw_sem[3];
};

struct file_system_type___113;

struct super_operations___113;

struct dquot_operations___113;

struct quotactl_ops___113;

struct super_block___114 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___113 *s_type;
	const struct super_operations___113 *s_op;
	const struct dquot_operations___113 *dq_op;
	const struct quotactl_ops___113 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___114 *s_root;
	struct rw_semaphore___114 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___114 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___113 s_dquot;
	struct sb_writers___113 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___113 *s_d_op;
	int cleancache_poolid;
	struct shrinker___36 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___94 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___114 {
	struct file___114 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___114 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___114 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___114 *ia_file;
};

struct dquot___113 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___114 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___113 {
	int qf_fmt_id;
	const struct quota_format_ops___113 *qf_ops;
	struct module___97 *qf_owner;
	struct quota_format_type___113 *qf_next;
};

struct quota_format_ops___113 {
	int (*check_quota_file)(struct super_block___114 *, int);
	int (*read_file_info)(struct super_block___114 *, int);
	int (*write_file_info)(struct super_block___114 *, int);
	int (*free_file_info)(struct super_block___114 *, int);
	int (*read_dqblk)(struct dquot___113 *);
	int (*commit_dqblk)(struct dquot___113 *);
	int (*release_dqblk)(struct dquot___113 *);
	int (*get_next_id)(struct super_block___114 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___113 {
	int (*write_dquot)(struct dquot___113 *);
	struct dquot___113 * (*alloc_dquot)(struct super_block___114 *, int);
	void (*destroy_dquot)(struct dquot___113 *);
	int (*acquire_dquot)(struct dquot___113 *);
	int (*release_dquot)(struct dquot___113 *);
	int (*mark_dirty)(struct dquot___113 *);
	int (*write_info)(struct super_block___114 *, int);
	qsize_t * (*get_reserved_space)(struct inode___115 *);
	int (*get_projid)(struct inode___115 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___115 *, qsize_t *);
	int (*get_next_id)(struct super_block___114 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___113 {
	int (*quota_on)(struct super_block___114 *, int, int, const struct path___113 *);
	int (*quota_off)(struct super_block___114 *, int);
	int (*quota_enable)(struct super_block___114 *, unsigned int);
	int (*quota_disable)(struct super_block___114 *, unsigned int);
	int (*quota_sync)(struct super_block___114 *, int);
	int (*set_info)(struct super_block___114 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___114 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___114 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___114 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___114 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___114 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___113 {
	int (*writepage)(struct page___114 *, struct writeback_control___3 *);
	int (*readpage)(struct file___114 *, struct page___114 *);
	int (*writepages)(struct address_space___113 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___114 *);
	int (*readpages)(struct file___114 *, struct address_space___113 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___114 *, struct address_space___113 *, loff_t, unsigned int, unsigned int, struct page___114 **, void **);
	int (*write_end)(struct file___114 *, struct address_space___113 *, loff_t, unsigned int, unsigned int, struct page___114 *, void *);
	sector_t (*bmap)(struct address_space___113 *, sector_t);
	void (*invalidatepage)(struct page___114 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___114 *, gfp_t);
	void (*freepage)(struct page___114 *);
	ssize_t (*direct_IO)(struct kiocb___114 *, struct iov_iter___43 *);
	int (*migratepage)(struct address_space___113 *, struct page___114 *, struct page___114 *, enum migrate_mode);
	bool (*isolate_page)(struct page___114 *, isolate_mode_t);
	void (*putback_page)(struct page___114 *);
	int (*launder_page)(struct page___114 *);
	int (*is_partially_uptodate)(struct page___114 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___114 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___113 *, struct page___114 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___114 *, sector_t *);
	void (*swap_deactivate)(struct file___114 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___114 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___115 *bd_inode;
	struct super_block___114 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___114 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___113 {
	struct dentry___114 * (*lookup)(struct inode___115 *, struct dentry___114 *, unsigned int);
	const char * (*get_link)(struct dentry___114 *, struct inode___115 *, struct delayed_call *);
	int (*permission)(struct inode___115 *, int);
	struct posix_acl * (*get_acl)(struct inode___115 *, int);
	int (*readlink)(struct dentry___114 *, char *, int);
	int (*create)(struct inode___115 *, struct dentry___114 *, umode_t, bool);
	int (*link)(struct dentry___114 *, struct inode___115 *, struct dentry___114 *);
	int (*unlink)(struct inode___115 *, struct dentry___114 *);
	int (*symlink)(struct inode___115 *, struct dentry___114 *, const char *);
	int (*mkdir)(struct inode___115 *, struct dentry___114 *, umode_t);
	int (*rmdir)(struct inode___115 *, struct dentry___114 *);
	int (*mknod)(struct inode___115 *, struct dentry___114 *, umode_t, dev_t);
	int (*rename)(struct inode___115 *, struct dentry___114 *, struct inode___115 *, struct dentry___114 *, unsigned int);
	int (*setattr)(struct dentry___114 *, struct iattr___114 *);
	int (*getattr)(const struct path___113 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___114 *, char *, size_t);
	int (*fiemap)(struct inode___115 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___115 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___115 *, struct dentry___114 *, struct file___114 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___115 *, struct dentry___114 *, umode_t);
	int (*set_acl)(struct inode___115 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___113 {
	void (*fl_copy_lock)(struct file_lock___114 *, struct file_lock___114 *);
	void (*fl_release_private)(struct file_lock___114 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___113;

struct file_lock___114 {
	struct file_lock___114 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___114 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___113 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___113 *fl_ops;
	const struct lock_manager_operations___113 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___113 {
	int (*lm_compare_owner)(struct file_lock___114 *, struct file_lock___114 *);
	long unsigned int (*lm_owner_key)(struct file_lock___114 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___114 *);
	int (*lm_grant)(struct file_lock___114 *, int);
	bool (*lm_break)(struct file_lock___114 *);
	int (*lm_change)(struct file_lock___114 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___114 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___113 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___113 *fa_next;
	struct file___114 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___113 {
	const char *name;
	int fs_flags;
	struct dentry___114 * (*mount)(struct file_system_type___113 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___114 *);
	struct module___97 *owner;
	struct file_system_type___113 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___113 {
	struct inode___115 * (*alloc_inode)(struct super_block___114 *);
	void (*destroy_inode)(struct inode___115 *);
	void (*dirty_inode)(struct inode___115 *, int);
	int (*write_inode)(struct inode___115 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___115 *);
	void (*evict_inode)(struct inode___115 *);
	void (*put_super)(struct super_block___114 *);
	int (*sync_fs)(struct super_block___114 *, int);
	int (*freeze_super)(struct super_block___114 *);
	int (*freeze_fs)(struct super_block___114 *);
	int (*thaw_super)(struct super_block___114 *);
	int (*unfreeze_fs)(struct super_block___114 *);
	int (*statfs)(struct dentry___114 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___114 *, int *, char *);
	void (*umount_begin)(struct super_block___114 *);
	int (*show_options)(struct seq_file___104 *, struct dentry___114 *);
	int (*show_devname)(struct seq_file___104 *, struct dentry___114 *);
	int (*show_path)(struct seq_file___104 *, struct dentry___114 *);
	int (*show_stats)(struct seq_file___104 *, struct dentry___114 *);
	ssize_t (*quota_read)(struct super_block___114 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___114 *, int, const char *, size_t, loff_t);
	struct dquot___113 ** (*get_dquots)(struct inode___115 *);
	int (*bdev_try_to_free_page)(struct super_block___114 *, struct page___114 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___114 *, struct shrink_control___36 *);
	long int (*free_cached_objects)(struct super_block___114 *, struct shrink_control___36 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*key_restrict_link_func_t___109)(struct key___109 *, const struct key_type *, const union key_payload *, struct key___109 *);

struct key_restriction___109;

struct key___109 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___114 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___109 *restrict_link;
};

struct key_restriction___109 {
	key_restrict_link_func_t___109 check;
	struct key___109 *key;
	struct key_type *keytype;
};

struct seq_operations___102 {
	void * (*start)(struct seq_file___104 *, loff_t *);
	void (*stop)(struct seq_file___104 *, void *);
	void * (*next)(struct seq_file___104 *, void *, loff_t *);
	int (*show)(struct seq_file___104 *, void *);
};

struct dev_pm_info___105 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___105 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___105;

struct bus_type___105;

struct device_driver___105;

struct dev_pm_domain___105;

struct device_node___41;

struct fwnode_handle___77;

struct class___105;

struct device___105 {
	struct device___105 *parent;
	struct device_private *p;
	struct kobject___108 kobj;
	const char *init_name;
	const struct device_type___105 *type;
	struct mutex mutex;
	struct bus_type___105 *bus;
	struct device_driver___105 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___105 power;
	struct dev_pm_domain___105 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___41 *of_node;
	struct fwnode_handle___77 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___105 *class;
	const struct attribute_group___104 **groups;
	void (*release)(struct device___105 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

typedef void compound_page_dtor___111(struct page___114 *);

struct cgroup_namespace___90 {
	refcount_t count;
	struct ns_common___7 ns;
	struct user_namespace___94 *user_ns;
	struct ucounts___94 *ucounts;
	struct css_set___90 *root_cset;
};

struct ucounts___94 {
	struct hlist_node node;
	struct user_namespace___94 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct dev_pm_ops___105 {
	int (*prepare)(struct device___105 *);
	void (*complete)(struct device___105 *);
	int (*suspend)(struct device___105 *);
	int (*resume)(struct device___105 *);
	int (*freeze)(struct device___105 *);
	int (*thaw)(struct device___105 *);
	int (*poweroff)(struct device___105 *);
	int (*restore)(struct device___105 *);
	int (*suspend_late)(struct device___105 *);
	int (*resume_early)(struct device___105 *);
	int (*freeze_late)(struct device___105 *);
	int (*thaw_early)(struct device___105 *);
	int (*poweroff_late)(struct device___105 *);
	int (*restore_early)(struct device___105 *);
	int (*suspend_noirq)(struct device___105 *);
	int (*resume_noirq)(struct device___105 *);
	int (*freeze_noirq)(struct device___105 *);
	int (*thaw_noirq)(struct device___105 *);
	int (*poweroff_noirq)(struct device___105 *);
	int (*restore_noirq)(struct device___105 *);
	int (*runtime_suspend)(struct device___105 *);
	int (*runtime_resume)(struct device___105 *);
	int (*runtime_idle)(struct device___105 *);
};

struct dev_pm_domain___105 {
	struct dev_pm_ops___105 ops;
	void (*detach)(struct device___105 *, bool);
	int (*activate)(struct device___105 *);
	void (*sync)(struct device___105 *);
	void (*dismiss)(struct device___105 *);
};

struct bus_type___105 {
	const char *name;
	const char *dev_name;
	struct device___105 *dev_root;
	const struct attribute_group___104 **bus_groups;
	const struct attribute_group___104 **dev_groups;
	const struct attribute_group___104 **drv_groups;
	int (*match)(struct device___105 *, struct device_driver___105 *);
	int (*uevent)(struct device___105 *, struct kobj_uevent_env *);
	int (*probe)(struct device___105 *);
	int (*remove)(struct device___105 *);
	void (*shutdown)(struct device___105 *);
	int (*online)(struct device___105 *);
	int (*offline)(struct device___105 *);
	int (*suspend)(struct device___105 *, pm_message_t);
	int (*resume)(struct device___105 *);
	int (*num_vf)(struct device___105 *);
	int (*dma_configure)(struct device___105 *);
	const struct dev_pm_ops___105 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___105 {
	const char *name;
	struct bus_type___105 *bus;
	struct module___97 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___105 *);
	int (*remove)(struct device___105 *);
	void (*shutdown)(struct device___105 *);
	int (*suspend)(struct device___105 *, pm_message_t);
	int (*resume)(struct device___105 *);
	const struct attribute_group___104 **groups;
	const struct dev_pm_ops___105 *pm;
	void (*coredump)(struct device___105 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___105 {
	const char *name;
	const struct attribute_group___104 **groups;
	int (*uevent)(struct device___105 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___105 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___105 *);
	const struct dev_pm_ops___105 *pm;
};

struct class___105 {
	const char *name;
	struct module___97 *owner;
	const struct attribute_group___104 **class_groups;
	const struct attribute_group___104 **dev_groups;
	struct kobject___108 *dev_kobj;
	int (*dev_uevent)(struct device___105 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___105 *, umode_t *);
	void (*class_release)(struct class___105 *);
	void (*dev_release)(struct device___105 *);
	int (*shutdown_pre)(struct device___105 *);
	const struct kobj_ns_type_operations___5 *ns_type;
	const void * (*namespace)(struct device___105 *);
	const struct dev_pm_ops___105 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct fwnode_operations___77;

struct fwnode_handle___77 {
	struct fwnode_handle___77 *secondary;
	const struct fwnode_operations___77 *ops;
};

struct property___40;

struct device_node___41 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___77 fwnode;
	struct property___40 *properties;
	struct property___40 *deadprops;
	struct device_node___41 *parent;
	struct device_node___41 *child;
	struct device_node___41 *sibling;
	struct kobject___108 kobj;
	long unsigned int _flags;
	void *data;
};

struct node___91 {
	struct device___105 dev;
};

struct bpf_map___90;

struct bpf_map_ops___90 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___90 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___90 *, struct file___114 *);
	void (*map_free)(struct bpf_map___90 *);
	int (*map_get_next_key)(struct bpf_map___90 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___90 *);
	void * (*map_lookup_elem)(struct bpf_map___90 *, void *);
	int (*map_update_elem)(struct bpf_map___90 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___90 *, void *);
	int (*map_push_elem)(struct bpf_map___90 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___90 *, void *);
	int (*map_peek_elem)(struct bpf_map___90 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___90 *, struct file___114 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___90 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___90 *, void *, struct seq_file___104 *);
	int (*map_check_btf)(const struct bpf_map___90 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___90 {
	const struct bpf_map_ops___90 *ops;
	struct bpf_map___90 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___109 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___90;

typedef void (*kthread_work_func_t___90)(struct kthread_work___90 *);

struct kthread_worker___90;

struct kthread_work___90 {
	struct list_head node;
	kthread_work_func_t___90 func;
	struct kthread_worker___90 *worker;
	int canceling;
};

struct kthread_worker___90 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___114 *task;
	struct kthread_work___90 *current_work;
};

struct kthread_delayed_work___90 {
	struct kthread_work___90 work;
	struct timer_list timer;
};

struct psi_group___90 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___90 *poll_kworker;
	struct kthread_delayed_work___90 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___90 {
	struct kernfs_node___110 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___90;

struct cgroup_subsys_state___90 {
	struct cgroup___90 *cgroup;
	struct cgroup_subsys___90 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___90 *parent;
};

struct cgroup_root___90;

struct cgroup_rstat_cpu___90;

struct cgroup___90 {
	struct cgroup_subsys_state___90 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___110 *kn;
	struct cgroup_file___90 procs_file;
	struct cgroup_file___90 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___90 *subsys[13];
	struct cgroup_root___90 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___90 *dom_cgrp;
	struct cgroup_rstat_cpu___90 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___10 bpf;
	atomic_t congestion_count;
	struct cgroup___90 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___90 psi;
	int ancestor_ids[0];
};

struct cftype___90;

struct cgroup_subsys___90 {
	struct cgroup_subsys_state___90 * (*css_alloc)(struct cgroup_subsys_state___90 *);
	int (*css_online)(struct cgroup_subsys_state___90 *);
	void (*css_offline)(struct cgroup_subsys_state___90 *);
	void (*css_released)(struct cgroup_subsys_state___90 *);
	void (*css_free)(struct cgroup_subsys_state___90 *);
	void (*css_reset)(struct cgroup_subsys_state___90 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___90 *, int);
	int (*css_extra_stat_show)(struct seq_file___104 *, struct cgroup_subsys_state___90 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___114 *);
	void (*cancel_fork)(struct task_struct___114 *);
	void (*fork)(struct task_struct___114 *);
	void (*exit)(struct task_struct___114 *);
	void (*free)(struct task_struct___114 *);
	void (*bind)(struct cgroup_subsys_state___90 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___90 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___90 *dfl_cftypes;
	struct cftype___90 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___90 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___90 *updated_children;
	struct cgroup___90 *updated_next;
};

struct cgroup_root___90 {
	struct kernfs_root___110 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___90 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___90 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___90 *ss;
	struct list_head node;
	struct kernfs_ops___110 *kf_ops;
	int (*open)(struct kernfs_open_file___110 *);
	void (*release)(struct kernfs_open_file___110 *);
	u64 (*read_u64)(struct cgroup_subsys_state___90 *, struct cftype___90 *);
	s64 (*read_s64)(struct cgroup_subsys_state___90 *, struct cftype___90 *);
	int (*seq_show)(struct seq_file___104 *, void *);
	void * (*seq_start)(struct seq_file___104 *, loff_t *);
	void * (*seq_next)(struct seq_file___104 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___104 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___90 *, struct cftype___90 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___90 *, struct cftype___90 *, s64);
	ssize_t (*write)(struct kernfs_open_file___110 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___110 *, struct poll_table_struct___77 *);
};

struct perf_cpu_context___72;

struct pmu___72 {
	struct list_head entry;
	struct module___97 *module;
	struct device___105 *dev;
	const struct attribute_group___104 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___72 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___72 *);
	void (*pmu_disable)(struct pmu___72 *);
	int (*event_init)(struct perf_event___72 *);
	void (*event_mapped)(struct perf_event___72 *, struct mm_struct___113 *);
	void (*event_unmapped)(struct perf_event___72 *, struct mm_struct___113 *);
	int (*add)(struct perf_event___72 *, int);
	void (*del)(struct perf_event___72 *, int);
	void (*start)(struct perf_event___72 *, int);
	void (*stop)(struct perf_event___72 *, int);
	void (*read)(struct perf_event___72 *);
	void (*start_txn)(struct pmu___72 *, unsigned int);
	int (*commit_txn)(struct pmu___72 *);
	void (*cancel_txn)(struct pmu___72 *);
	int (*event_idx)(struct perf_event___72 *);
	void (*sched_task)(struct perf_event_context___72 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___72 *);
	int (*filter_match)(struct perf_event___72 *);
	int (*check_period)(struct perf_event___72 *, u64);
};

struct perf_cpu_context___72 {
	struct perf_event_context___72 ctx;
	struct perf_event_context___72 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___72 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___72 {
	struct cgroup_subsys_state___90 css;
	struct perf_cgroup_info *info;
};

struct fwnode_reference_args___77;

struct fwnode_endpoint___77;

struct fwnode_operations___77 {
	struct fwnode_handle___77 * (*get)(struct fwnode_handle___77 *);
	void (*put)(struct fwnode_handle___77 *);
	bool (*device_is_available)(const struct fwnode_handle___77 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___77 *, const struct device___105 *);
	bool (*property_present)(const struct fwnode_handle___77 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___77 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___77 *, const char *, const char **, size_t);
	struct fwnode_handle___77 * (*get_parent)(const struct fwnode_handle___77 *);
	struct fwnode_handle___77 * (*get_next_child_node)(const struct fwnode_handle___77 *, struct fwnode_handle___77 *);
	struct fwnode_handle___77 * (*get_named_child_node)(const struct fwnode_handle___77 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___77 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___77 *);
	struct fwnode_handle___77 * (*graph_get_next_endpoint)(const struct fwnode_handle___77 *, struct fwnode_handle___77 *);
	struct fwnode_handle___77 * (*graph_get_remote_endpoint)(const struct fwnode_handle___77 *);
	struct fwnode_handle___77 * (*graph_get_port_parent)(struct fwnode_handle___77 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___77 *, struct fwnode_endpoint___77 *);
};

struct fwnode_endpoint___77 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___77 *local_fwnode;
};

struct fwnode_reference_args___77 {
	struct fwnode_handle___77 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct property___40 {
	char *name;
	int length;
	void *value;
	struct property___40 *next;
	long unsigned int _flags;
	struct bin_attribute___104 attr;
};

struct trace_array___13;

struct tracer___13;

struct trace_buffer___13;

struct trace_iterator___13 {
	struct trace_array___13 *tr;
	struct tracer___13 *trace;
	struct trace_buffer___13 *trace_buffer;
	void *private;
	int cpu_file;
	struct mutex mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

struct trace_buffer___13 {
	struct trace_array___13 *tr;
	struct ring_buffer *buffer;
	struct trace_array_cpu *data;
	u64 time_start;
	int cpu;
};

struct trace_event_file___32;

struct trace_options___13;

struct trace_array___13 {
	struct list_head list;
	char *name;
	struct trace_buffer___13 trace_buffer;
	struct trace_buffer___13 max_buffer;
	bool allocated_snapshot;
	long unsigned int max_latency;
	struct trace_pid_list *filtered_pids;
	arch_spinlock_t max_lock;
	int buffer_disabled;
	int sys_refcount_enter;
	int sys_refcount_exit;
	struct trace_event_file___32 *enter_syscall_files[295];
	struct trace_event_file___32 *exit_syscall_files[295];
	int stop_count;
	int clock_id;
	int nr_topts;
	bool clear_trace;
	struct tracer___13 *current_trace;
	unsigned int trace_flags;
	unsigned char trace_flags_index[32];
	unsigned int flags;
	raw_spinlock_t start_lock;
	struct dentry___114 *dir;
	struct dentry___114 *options;
	struct dentry___114 *percpu_dir;
	struct dentry___114 *event_dir;
	struct trace_options___13 *topts;
	struct list_head systems;
	struct list_head events;
	struct trace_event_file___32 *trace_marker_file;
	cpumask_var_t tracing_cpumask;
	int ref;
	struct ftrace_ops *ops;
	struct trace_pid_list *function_pids;
	struct list_head func_probes;
	struct list_head mod_trace;
	struct list_head mod_notrace;
	int function_enabled;
	int time_stamp_abs_ref;
	struct list_head hist_vars;
};

struct tracer_flags___13;

struct tracer___13 {
	const char *name;
	int (*init)(struct trace_array___13 *);
	void (*reset)(struct trace_array___13 *);
	void (*start)(struct trace_array___13 *);
	void (*stop)(struct trace_array___13 *);
	int (*update_thresh)(struct trace_array___13 *);
	void (*open)(struct trace_iterator___13 *);
	void (*pipe_open)(struct trace_iterator___13 *);
	void (*close)(struct trace_iterator___13 *);
	void (*pipe_close)(struct trace_iterator___13 *);
	ssize_t (*read)(struct trace_iterator___13 *, struct file___114 *, char *, size_t, loff_t *);
	ssize_t (*splice_read)(struct trace_iterator___13 *, struct file___114 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	void (*print_header)(struct seq_file___104 *);
	enum print_line_t (*print_line)(struct trace_iterator___13 *);
	int (*set_flag)(struct trace_array___13 *, u32, u32, int);
	int (*flag_changed)(struct trace_array___13 *, u32, int);
	struct tracer___13 *next;
	struct tracer_flags___13 *flags;
	int enabled;
	int ref;
	bool print_max;
	bool allow_instances;
	bool use_max_tr;
	bool noboot;
};

typedef enum print_line_t (*trace_print_func___13)(struct trace_iterator___13 *, int, struct trace_event___13 *);

struct trace_event_functions___13 {
	trace_print_func___13 trace;
	trace_print_func___13 raw;
	trace_print_func___13 hex;
	trace_print_func___13 binary;
};

struct trace_event_class___67 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___67 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___67 *);
	struct list_head * (*get_fields)(struct trace_event_call___67 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___67 *);
};

struct trace_subsystem_dir___13;

struct trace_event_file___32 {
	struct list_head list;
	struct trace_event_call___67 *event_call;
	struct event_filter *filter;
	struct dentry___114 *dir;
	struct trace_array___13 *tr;
	struct trace_subsystem_dir___13 *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_subsystem_dir___13 {
	struct list_head list;
	struct event_subsystem *subsystem;
	struct trace_array___13 *tr;
	struct dentry___114 *entry;
	int ref_count;
	int nr_events;
};

struct trace_option_dentry___13;

struct trace_options___13 {
	struct tracer___13 *tracer;
	struct trace_option_dentry___13 *topts;
};

struct trace_option_dentry___13 {
	struct tracer_opt *opt;
	struct tracer_flags___13 *flags;
	struct trace_array___13 *tr;
	struct dentry___114 *entry;
};

struct tracer_flags___13 {
	u32 val;
	struct tracer_opt *opts;
	struct tracer___13 *trace;
};

struct trace_probe___3 {
	unsigned int flags;
	struct trace_event_class___67 class;
	struct trace_event_call___67 call;
	struct list_head files;
	ssize_t size;
	unsigned int nr_args;
	struct probe_arg args[0];
};

struct event_file_link___2 {
	struct trace_event_file___32 *file;
	struct list_head list;
};

struct uprobe_trace_entry_head {
	struct trace_entry ent;
	long unsigned int vaddr[0];
};

struct trace_uprobe_filter {
	rwlock_t rwlock;
	int nr_systemwide;
	struct list_head perf_events;
};

struct trace_uprobe {
	struct list_head list;
	struct trace_uprobe_filter filter;
	struct uprobe_consumer consumer;
	struct path___113 path;
	struct inode___115 *inode;
	char *filename;
	long unsigned int offset;
	long unsigned int ref_ctr_offset;
	long unsigned int nhit;
	struct trace_probe___3 tp;
};

struct uprobe_dispatch_data {
	struct trace_uprobe *tu;
	long unsigned int bp_addr;
};

struct uprobe_cpu_buffer {
	struct mutex mutex;
	void *buf;
};

typedef bool (*filter_func_t)(struct uprobe_consumer *, enum uprobe_filter_ctx, struct mm_struct___113 *);

struct rnd_state {
	__u32 s1;
	__u32 s2;
	__u32 s3;
	__u32 s4;
};

enum xdp_action {
	XDP_ABORTED = 0,
	XDP_DROP = 1,
	XDP_PASS = 2,
	XDP_TX = 3,
	XDP_REDIRECT = 4,
};

typedef void (*bpf_jit_fill_hole_t)(void *, unsigned int);

struct bpf_prog_dummy {
	struct bpf_prog___10 prog;
};

struct trace_event_buffer___23 {
	struct ring_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___27 *trace_file;
	void *entry;
	long unsigned int flags;
	int pc;
};

struct trace_event_raw_xdp_exception {
	struct trace_entry ent;
	int prog_id;
	u32 act;
	int ifindex;
	char __data[0];
};

struct trace_event_raw_xdp_redirect_template {
	struct trace_entry ent;
	int prog_id;
	u32 act;
	int ifindex;
	int err;
	int to_ifindex;
	u32 map_id;
	int map_index;
	char __data[0];
};

struct trace_event_raw_xdp_cpumap_kthread {
	struct trace_entry ent;
	int map_id;
	u32 act;
	int cpu;
	unsigned int drops;
	unsigned int processed;
	int sched;
	char __data[0];
};

struct trace_event_raw_xdp_cpumap_enqueue {
	struct trace_entry ent;
	int map_id;
	u32 act;
	int cpu;
	unsigned int drops;
	unsigned int processed;
	int to_cpu;
	char __data[0];
};

struct trace_event_raw_xdp_devmap_xmit {
	struct trace_entry ent;
	int map_id;
	u32 act;
	u32 map_index;
	int drops;
	int sent;
	int from_ifindex;
	int to_ifindex;
	int err;
	char __data[0];
};

struct trace_event_data_offsets_xdp_exception {};

struct trace_event_data_offsets_xdp_redirect_template {};

struct trace_event_data_offsets_xdp_cpumap_kthread {};

struct trace_event_data_offsets_xdp_cpumap_enqueue {};

struct trace_event_data_offsets_xdp_devmap_xmit {};

enum bpf_cmd {
	BPF_MAP_CREATE = 0,
	BPF_MAP_LOOKUP_ELEM = 1,
	BPF_MAP_UPDATE_ELEM = 2,
	BPF_MAP_DELETE_ELEM = 3,
	BPF_MAP_GET_NEXT_KEY = 4,
	BPF_PROG_LOAD = 5,
	BPF_OBJ_PIN = 6,
	BPF_OBJ_GET = 7,
	BPF_PROG_ATTACH = 8,
	BPF_PROG_DETACH = 9,
	BPF_PROG_TEST_RUN = 10,
	BPF_PROG_GET_NEXT_ID = 11,
	BPF_MAP_GET_NEXT_ID = 12,
	BPF_PROG_GET_FD_BY_ID = 13,
	BPF_MAP_GET_FD_BY_ID = 14,
	BPF_OBJ_GET_INFO_BY_FD = 15,
	BPF_PROG_QUERY = 16,
	BPF_RAW_TRACEPOINT_OPEN = 17,
	BPF_BTF_LOAD = 18,
	BPF_BTF_GET_FD_BY_ID = 19,
	BPF_TASK_FD_QUERY = 20,
	BPF_MAP_LOOKUP_AND_DELETE_ELEM = 21,
};

struct bpf_prog_info {
	__u32 type;
	__u32 id;
	__u8 tag[8];
	__u32 jited_prog_len;
	__u32 xlated_prog_len;
	__u64 jited_prog_insns;
	__u64 xlated_prog_insns;
	__u64 load_time;
	__u32 created_by_uid;
	__u32 nr_map_ids;
	__u64 map_ids;
	char name[16];
	__u32 ifindex;
	__u32 gpl_compatible: 1;
	__u64 netns_dev;
	__u64 netns_ino;
	__u32 nr_jited_ksyms;
	__u32 nr_jited_func_lens;
	__u64 jited_ksyms;
	__u64 jited_func_lens;
	__u32 btf_id;
	__u32 func_info_rec_size;
	__u64 func_info;
	__u32 nr_func_info;
	__u32 nr_line_info;
	__u64 line_info;
	__u64 jited_line_info;
	__u32 nr_jited_line_info;
	__u32 line_info_rec_size;
	__u32 jited_line_info_rec_size;
	__u32 nr_prog_tags;
	__u64 prog_tags;
};

struct bpf_map_info {
	__u32 type;
	__u32 id;
	__u32 key_size;
	__u32 value_size;
	__u32 max_entries;
	__u32 map_flags;
	char name[16];
	__u32 ifindex;
	__u64 netns_dev;
	__u64 netns_ino;
	__u32 btf_id;
	__u32 btf_key_type_id;
	__u32 btf_value_type_id;
};

struct bpf_btf_info {
	__u64 btf;
	__u32 btf_size;
	__u32 id;
};

struct module___98;

struct file___115;

struct kiocb___115;

struct iov_iter___44;

struct poll_table_struct___78;

struct vm_area_struct___115;

struct inode___116;

struct file_lock___115;

struct page___115;

struct pipe_inode_info___25;

struct seq_file___105;

struct file_operations___115 {
	struct module___98 *owner;
	loff_t (*llseek)(struct file___115 *, loff_t, int);
	ssize_t (*read)(struct file___115 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___115 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___115 *, struct iov_iter___44 *);
	ssize_t (*write_iter)(struct kiocb___115 *, struct iov_iter___44 *);
	int (*iopoll)(struct kiocb___115 *, bool);
	int (*iterate)(struct file___115 *, struct dir_context *);
	int (*iterate_shared)(struct file___115 *, struct dir_context *);
	__poll_t (*poll)(struct file___115 *, struct poll_table_struct___78 *);
	long int (*unlocked_ioctl)(struct file___115 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___115 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___115 *, struct vm_area_struct___115 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___116 *, struct file___115 *);
	int (*flush)(struct file___115 *, fl_owner_t);
	int (*release)(struct inode___116 *, struct file___115 *);
	int (*fsync)(struct file___115 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___115 *, int);
	int (*lock)(struct file___115 *, int, struct file_lock___115 *);
	ssize_t (*sendpage)(struct file___115 *, struct page___115 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___115 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___115 *, int, struct file_lock___115 *);
	ssize_t (*splice_write)(struct pipe_inode_info___25 *, struct file___115 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___115 *, loff_t *, struct pipe_inode_info___25 *, size_t, unsigned int);
	int (*setlease)(struct file___115 *, long int, struct file_lock___115 **, void **);
	long int (*fallocate)(struct file___115 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___105 *, struct file___115 *);
	ssize_t (*copy_file_range)(struct file___115 *, loff_t, struct file___115 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___115 *, loff_t, struct file___115 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___115 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___114 {
	u64 seqnum;
	struct vm_area_struct___115 *vmas[4];
};

struct page_frag___114 {
	struct page___115 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___73;

struct debug_info___73 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___73 *hbp_break[16];
	struct perf_event___73 *hbp_watch[16];
};

struct thread_struct___73 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___73 debug;
	long: 64;
};

struct mm_struct___114;

struct pid___97;

struct cred___110;

struct files_struct___5;

struct nsproxy___107;

struct signal_struct___104;

struct css_set___91;

struct perf_event_context___73;

struct vm_struct___84;

struct task_struct___115 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___115 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___114 *mm;
	struct mm_struct___114 *active_mm;
	struct vmacache___114 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___115 *real_parent;
	struct task_struct___115 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___115 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___97 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___97 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___97 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___110 *ptracer_cred;
	const struct cred___110 *real_cred;
	const struct cred___110 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct___5 *files;
	struct nsproxy___107 *nsproxy;
	struct signal_struct___104 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___115 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___17 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___91 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___73 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___25 *splice_pipe;
	struct page_frag___114 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___115 *oom_reaper_list;
	struct vm_struct___84 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___73 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___73 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___115 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___73)(struct perf_event___73 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___73;

struct fasync_struct___114;

struct pid_namespace___97;

struct bpf_prog___11;

struct trace_event_call___68;

struct perf_cgroup___73;

struct perf_event___73 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___73 *group_leader;
	struct pmu___73 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___73 hw;
	struct perf_event_context___73 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___73 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___115 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___114 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___73 *);
	struct callback_head callback_head;
	struct pid_namespace___97 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___73 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___73 orig_overflow_handler;
	struct bpf_prog___11 *prog;
	struct trace_event_call___68 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___73 *cgrp;
	struct list_head sb_list;
};

struct secondary_data___115 {
	void *stack;
	struct task_struct___115 *task;
	long int status;
};

struct fd___5 {
	struct file___115 *file;
	unsigned int flags;
};

struct dentry___115;

struct path___114 {
	struct vfsmount *mnt;
	struct dentry___115 *dentry;
};

struct fown_struct___97 {
	rwlock_t lock;
	struct pid___97 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct address_space___114;

struct file___115 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___114 f_path;
	struct inode___116 *f_inode;
	const struct file_operations___115 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___97 f_owner;
	const struct cred___110 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___114 *f_mapping;
	errseq_t f_wb_err;
};

struct bpf_map___91;

struct bpf_map_ops___91 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___91 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___91 *, struct file___115 *);
	void (*map_free)(struct bpf_map___91 *);
	int (*map_get_next_key)(struct bpf_map___91 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___91 *);
	void * (*map_lookup_elem)(struct bpf_map___91 *, void *);
	int (*map_update_elem)(struct bpf_map___91 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___91 *, void *);
	int (*map_push_elem)(struct bpf_map___91 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___91 *, void *);
	int (*map_peek_elem)(struct bpf_map___91 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___91 *, struct file___115 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___91 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___91 *, void *, struct seq_file___105 *);
	int (*map_check_btf)(const struct bpf_map___91 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct user_struct___110;

struct bpf_map___91 {
	const struct bpf_map_ops___91 *ops;
	struct bpf_map___91 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___110 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct seq_operations___103;

struct seq_file___105 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___103 *op;
	int poll_event;
	const struct file___115 *file;
	void *private;
};

struct key___110;

struct user_struct___110 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___110 *uid_keyring;
	struct key___110 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bpf_offloaded_map___12;

struct bpf_map_dev_ops___12 {
	int (*map_get_next_key)(struct bpf_offloaded_map___12 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___12 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___12 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___12 *, void *);
};

struct net_device___17;

struct bpf_offloaded_map___12 {
	struct bpf_map___91 map;
	struct net_device___17 *netdev;
	const struct bpf_map_dev_ops___12 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___16;

typedef rx_handler_result_t rx_handler_func_t___12(struct sk_buff___16 **);

struct net___22;

typedef struct {
	struct net___22 *net;
} possible_net_t___13;

struct kset___108;

struct kobj_type___108;

struct kernfs_node___111;

struct kobject___109 {
	const char *name;
	struct list_head entry;
	struct kobject___109 *parent;
	struct kset___108 *kset;
	struct kobj_type___108 *ktype;
	struct kernfs_node___111 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___106;

struct dev_pm_info___106 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___106 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___106;

struct bus_type___106;

struct device_driver___106;

struct dev_pm_domain___106;

struct dma_map_ops___28;

struct fwnode_handle___78;

struct class___106;

struct attribute_group___105;

struct device___106 {
	struct device___106 *parent;
	struct device_private *p;
	struct kobject___109 kobj;
	const char *init_name;
	const struct device_type___106 *type;
	struct mutex mutex;
	struct bus_type___106 *bus;
	struct device_driver___106 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___106 power;
	struct dev_pm_domain___106 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___28 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___78 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___106 *class;
	const struct attribute_group___105 **groups;
	void (*release)(struct device___106 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct net_device_ops___12;

struct ethtool_ops___12;

struct xfrmdev_ops___12;

struct tlsdev_ops___12;

struct header_ops___12;

struct netdev_rx_queue___12;

struct mini_Qdisc___11;

struct netdev_queue___12;

struct Qdisc___11;

struct rtnl_link_ops___11;

struct dcbnl_rtnl_ops___12;

struct net_device___17 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___12 *netdev_ops;
	const struct ethtool_ops___12 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___2 *l3mdev_ops;
	const struct ndisc_ops___2 *ndisc_ops;
	const struct xfrmdev_ops___12 *xfrmdev_ops;
	const struct tlsdev_ops___12 *tlsdev_ops;
	const struct header_ops___12 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___108 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___2 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___12 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___11 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___12 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___11 *miniq_ingress;
	struct netdev_queue___12 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___12 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___11 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___11 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___12 = 0,
		NETREG_REGISTERED___12 = 1,
		NETREG_UNREGISTERING___12 = 2,
		NETREG_UNREGISTERED___12 = 3,
		NETREG_RELEASED___12 = 4,
		NETREG_DUMMY___12 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___12 = 0,
		RTNL_LINK_INITIALIZING___12 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___17 *);
	struct netpoll_info *npinfo;
	possible_net_t___13 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___106 dev;
	const struct attribute_group___105 *sysfs_groups[4];
	const struct attribute_group___105 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___11 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___12 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct bpf_prog_ops___11 {
	int (*test_run)(struct bpf_prog___11 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_aux___11;

struct bpf_prog___11 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___11 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

struct bpf_verifier_ops___11 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___11 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___11 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___11 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___11 *, u32 *);
};

struct bpf_prog_offload_ops___11 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___11 *);
	int (*translate)(struct bpf_prog___11 *);
	void (*destroy)(struct bpf_prog___11 *);
};

struct bpf_prog_offload___11 {
	struct bpf_prog___11 *prog;
	struct net_device___17 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___11 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___11 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___11 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___11 *ops;
	struct bpf_map___91 **used_maps;
	struct bpf_prog___11 *prog;
	struct user_struct___110 *user;
	u64 load_time;
	struct bpf_map___91 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___11 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_array___2 {
	struct bpf_map___91 map;
	u32 elem_size;
	u32 index_mask;
	enum bpf_prog_type owner_prog_type;
	bool owner_jited;
	union {
		char value[0];
		void *ptrs[0];
		void *pptrs[0];
	};
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_array_item___11 {
	struct bpf_prog___11 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___11 {
	struct callback_head rcu;
	struct bpf_prog_array_item___11 items[0];
};

struct rw_semaphore___115 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___115 *owner;
};

struct ucounts___95;

struct user_namespace___95 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___95 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___7 ns;
	long unsigned int flags;
	struct key___110 *persistent_keyring_register;
	struct rw_semaphore___115 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___95 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___115 *pgtable_t___114;

struct dev_pagemap___112;

struct page___115 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___114 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___115 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___114 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___114 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___112 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___114;

struct lruvec___114 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___114 *pgdat;
};

struct zone___114 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___114 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___114 {
	struct zone___114 *zone;
	int zone_idx;
};

struct zonelist___114 {
	struct zoneref___114 _zonerefs[25];
};

struct pglist_data___114 {
	struct zone___114 node_zones[3];
	struct zonelist___114 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___115 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___115 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___114 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___114 {
	struct rw_semaphore___115 rwsem;
	struct notifier_block *head;
};

struct upid___97 {
	int nr;
	struct pid_namespace___97 *ns;
};

struct pid_namespace___97 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___115 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___97 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___115 *proc_self;
	struct dentry___115 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___95 *user_ns;
	struct ucounts___95 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___7 ns;
};

struct pid___97 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___97 numbers[1];
};

struct vm_operations_struct___112;

struct vm_area_struct___115 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___115 *vm_next;
	struct vm_area_struct___115 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___114 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___112 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___115 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___114;

struct mm_struct___114 {
	struct {
		struct vm_area_struct___115 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___115 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___115 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___114 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___115 *owner;
		struct user_namespace___95 *user_ns;
		struct file___115 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___114 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___110 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___110 *session_keyring;
	struct key___110 *process_keyring;
	struct key___110 *thread_keyring;
	struct key___110 *request_key_auth;
	void *security;
	struct user_struct___110 *user;
	struct user_namespace___95 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct fdtable___5 {
	unsigned int max_fds;
	struct file___115 **fd;
	long unsigned int *close_on_exec;
	long unsigned int *open_fds;
	long unsigned int *full_fds_bits;
	struct callback_head rcu;
};

struct files_struct___5 {
	atomic_t count;
	bool resize_in_progress;
	wait_queue_head_t resize_wait;
	struct fdtable___5 *fdt;
	struct fdtable___5 fdtab;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t file_lock;
	unsigned int next_fd;
	long unsigned int close_on_exec_init[1];
	long unsigned int open_fds_init[1];
	long unsigned int full_fds_bits_init[1];
	struct file___115 *fd_array[64];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cgroup_namespace___91;

struct nsproxy___107 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___97 *pid_ns_for_children;
	struct net___22 *net_ns;
	struct cgroup_namespace___91 *cgroup_ns;
};

struct signal_struct___104 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___115 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___115 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___97 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___97 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___114 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___97 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___91;

struct cgroup___91;

struct css_set___91 {
	struct cgroup_subsys_state___91 *subsys[13];
	refcount_t refcount;
	struct css_set___91 *dom_cset;
	struct cgroup___91 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___91 *mg_src_cgrp;
	struct cgroup___91 *mg_dst_cgrp;
	struct css_set___91 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___73 {
	struct pmu___73 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___115 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___73 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___25;

struct pipe_inode_info___25 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___115 *tmp_page;
	struct fasync_struct___114 *fasync_readers;
	struct fasync_struct___114 *fasync_writers;
	struct pipe_buffer___25 *bufs;
	struct user_struct___110 *user;
};

struct vm_struct___84 {
	struct vm_struct___84 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___115 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___104 {
	struct task_struct___115 task;
	long unsigned int stack[8192];
};

struct address_space_operations___114;

struct address_space___114 {
	struct inode___116 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___115 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___114 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___112)(struct vm_area_struct___115 *, long unsigned int, const struct page___115 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___112)(struct page___115 *, void *);

struct dev_pagemap___112 {
	dev_page_fault_t___112 page_fault;
	dev_page_free_t___112 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___106 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct vm_fault___112;

struct vm_operations_struct___112 {
	void (*open)(struct vm_area_struct___115 *);
	void (*close)(struct vm_area_struct___115 *);
	int (*split)(struct vm_area_struct___115 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___115 *);
	vm_fault_t (*fault)(struct vm_fault___112 *);
	vm_fault_t (*huge_fault)(struct vm_fault___112 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___112 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___115 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___112 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___112 *);
	int (*access)(struct vm_area_struct___115 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___115 *);
	int (*set_policy)(struct vm_area_struct___115 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___115 *, long unsigned int);
	struct page___115 * (*find_special_page)(struct vm_area_struct___115 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___114 {
	struct task_struct___115 *task;
	struct core_thread___114 *next;
};

struct core_state___114 {
	atomic_t nr_threads;
	struct core_thread___114 dumper;
	struct completion startup;
};

struct vm_fault___112 {
	struct vm_area_struct___115 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___115 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___115 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___114 prealloc_pte;
};

struct module_kobject___95 {
	struct kobject___109 kobj;
	struct module___98 *mod;
	struct kobject___109 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___95 {
	struct module___98 *mod;
	struct latch_tree_node node;
};

struct module_layout___95 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___95 mtn;
};

struct module_attribute___95;

struct kernel_param___95;

struct module___98 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___95 mkobj;
	struct module_attribute___95 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___109 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___95 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___95 core_layout;
	struct module_layout___95 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___68 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide38;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide39;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct iov_iter___44 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___3 *bvec;
		struct pipe_inode_info___25 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct kiocb___115 {
	struct file___115 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___115 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dentry_operations___114;

struct super_block___115;

struct dentry___115 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___115 *d_parent;
	struct qstr d_name;
	struct inode___116 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___114 *d_op;
	struct super_block___115 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___114;

struct block_device___115;

struct inode___116 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___114 *i_op;
	struct super_block___115 *i_sb;
	struct address_space___114 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___115 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___115 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___114 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___25 *i_pipe;
		struct block_device___115 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___114 {
	int (*d_revalidate)(struct dentry___115 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___115 *, unsigned int);
	int (*d_hash)(const struct dentry___115 *, struct qstr *);
	int (*d_compare)(const struct dentry___115 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___115 *);
	int (*d_init)(struct dentry___115 *);
	void (*d_release)(struct dentry___115 *);
	void (*d_prune)(struct dentry___115 *);
	void (*d_iput)(struct dentry___115 *, struct inode___116 *);
	char * (*d_dname)(struct dentry___115 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___114 *);
	int (*d_manage)(const struct path___114 *, bool);
	struct dentry___115 * (*d_real)(struct dentry___115 *, const struct inode___116 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___114;

struct mem_dqinfo___114 {
	struct quota_format_type___114 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___114;

struct quota_info___114 {
	unsigned int flags;
	struct rw_semaphore___115 dqio_sem;
	struct inode___116 *files[3];
	struct mem_dqinfo___114 info[3];
	const struct quota_format_ops___114 *ops[3];
};

struct rcuwait___114 {
	struct task_struct___115 *task;
};

struct percpu_rw_semaphore___114 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___115 rw_sem;
	struct rcuwait___114 writer;
	int readers_block;
};

struct sb_writers___114 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___114 rw_sem[3];
};

struct file_system_type___114;

struct super_operations___114;

struct dquot_operations___114;

struct quotactl_ops___114;

struct super_block___115 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___114 *s_type;
	const struct super_operations___114 *s_op;
	const struct dquot_operations___114 *dq_op;
	const struct quotactl_ops___114 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___115 *s_root;
	struct rw_semaphore___115 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___115 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___114 s_dquot;
	struct sb_writers___114 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___114 *s_d_op;
	int cleancache_poolid;
	struct shrinker___36 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___95 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct iattr___115 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___115 *ia_file;
};

struct dquot___114 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___115 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___114 {
	int qf_fmt_id;
	const struct quota_format_ops___114 *qf_ops;
	struct module___98 *qf_owner;
	struct quota_format_type___114 *qf_next;
};

struct quota_format_ops___114 {
	int (*check_quota_file)(struct super_block___115 *, int);
	int (*read_file_info)(struct super_block___115 *, int);
	int (*write_file_info)(struct super_block___115 *, int);
	int (*free_file_info)(struct super_block___115 *, int);
	int (*read_dqblk)(struct dquot___114 *);
	int (*commit_dqblk)(struct dquot___114 *);
	int (*release_dqblk)(struct dquot___114 *);
	int (*get_next_id)(struct super_block___115 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___114 {
	int (*write_dquot)(struct dquot___114 *);
	struct dquot___114 * (*alloc_dquot)(struct super_block___115 *, int);
	void (*destroy_dquot)(struct dquot___114 *);
	int (*acquire_dquot)(struct dquot___114 *);
	int (*release_dquot)(struct dquot___114 *);
	int (*mark_dirty)(struct dquot___114 *);
	int (*write_info)(struct super_block___115 *, int);
	qsize_t * (*get_reserved_space)(struct inode___116 *);
	int (*get_projid)(struct inode___116 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___116 *, qsize_t *);
	int (*get_next_id)(struct super_block___115 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___114 {
	int (*quota_on)(struct super_block___115 *, int, int, const struct path___114 *);
	int (*quota_off)(struct super_block___115 *, int);
	int (*quota_enable)(struct super_block___115 *, unsigned int);
	int (*quota_disable)(struct super_block___115 *, unsigned int);
	int (*quota_sync)(struct super_block___115 *, int);
	int (*set_info)(struct super_block___115 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___115 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___115 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___115 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___115 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___115 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___114 {
	int (*writepage)(struct page___115 *, struct writeback_control___3 *);
	int (*readpage)(struct file___115 *, struct page___115 *);
	int (*writepages)(struct address_space___114 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___115 *);
	int (*readpages)(struct file___115 *, struct address_space___114 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___115 *, struct address_space___114 *, loff_t, unsigned int, unsigned int, struct page___115 **, void **);
	int (*write_end)(struct file___115 *, struct address_space___114 *, loff_t, unsigned int, unsigned int, struct page___115 *, void *);
	sector_t (*bmap)(struct address_space___114 *, sector_t);
	void (*invalidatepage)(struct page___115 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___115 *, gfp_t);
	void (*freepage)(struct page___115 *);
	ssize_t (*direct_IO)(struct kiocb___115 *, struct iov_iter___44 *);
	int (*migratepage)(struct address_space___114 *, struct page___115 *, struct page___115 *, enum migrate_mode);
	bool (*isolate_page)(struct page___115 *, isolate_mode_t);
	void (*putback_page)(struct page___115 *);
	int (*launder_page)(struct page___115 *);
	int (*is_partially_uptodate)(struct page___115 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___115 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___114 *, struct page___115 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___115 *, sector_t *);
	void (*swap_deactivate)(struct file___115 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___115 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___116 *bd_inode;
	struct super_block___115 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___115 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___114 {
	struct dentry___115 * (*lookup)(struct inode___116 *, struct dentry___115 *, unsigned int);
	const char * (*get_link)(struct dentry___115 *, struct inode___116 *, struct delayed_call *);
	int (*permission)(struct inode___116 *, int);
	struct posix_acl * (*get_acl)(struct inode___116 *, int);
	int (*readlink)(struct dentry___115 *, char *, int);
	int (*create)(struct inode___116 *, struct dentry___115 *, umode_t, bool);
	int (*link)(struct dentry___115 *, struct inode___116 *, struct dentry___115 *);
	int (*unlink)(struct inode___116 *, struct dentry___115 *);
	int (*symlink)(struct inode___116 *, struct dentry___115 *, const char *);
	int (*mkdir)(struct inode___116 *, struct dentry___115 *, umode_t);
	int (*rmdir)(struct inode___116 *, struct dentry___115 *);
	int (*mknod)(struct inode___116 *, struct dentry___115 *, umode_t, dev_t);
	int (*rename)(struct inode___116 *, struct dentry___115 *, struct inode___116 *, struct dentry___115 *, unsigned int);
	int (*setattr)(struct dentry___115 *, struct iattr___115 *);
	int (*getattr)(const struct path___114 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___115 *, char *, size_t);
	int (*fiemap)(struct inode___116 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___116 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___116 *, struct dentry___115 *, struct file___115 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___116 *, struct dentry___115 *, umode_t);
	int (*set_acl)(struct inode___116 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___114 {
	void (*fl_copy_lock)(struct file_lock___115 *, struct file_lock___115 *);
	void (*fl_release_private)(struct file_lock___115 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___114;

struct file_lock___115 {
	struct file_lock___115 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___115 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___114 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___114 *fl_ops;
	const struct lock_manager_operations___114 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___114 {
	int (*lm_compare_owner)(struct file_lock___115 *, struct file_lock___115 *);
	long unsigned int (*lm_owner_key)(struct file_lock___115 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___115 *);
	int (*lm_grant)(struct file_lock___115 *, int);
	bool (*lm_break)(struct file_lock___115 *);
	int (*lm_change)(struct file_lock___115 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___115 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___114 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___114 *fa_next;
	struct file___115 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___114 {
	const char *name;
	int fs_flags;
	struct dentry___115 * (*mount)(struct file_system_type___114 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___115 *);
	struct module___98 *owner;
	struct file_system_type___114 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___114 {
	struct inode___116 * (*alloc_inode)(struct super_block___115 *);
	void (*destroy_inode)(struct inode___116 *);
	void (*dirty_inode)(struct inode___116 *, int);
	int (*write_inode)(struct inode___116 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___116 *);
	void (*evict_inode)(struct inode___116 *);
	void (*put_super)(struct super_block___115 *);
	int (*sync_fs)(struct super_block___115 *, int);
	int (*freeze_super)(struct super_block___115 *);
	int (*freeze_fs)(struct super_block___115 *);
	int (*thaw_super)(struct super_block___115 *);
	int (*unfreeze_fs)(struct super_block___115 *);
	int (*statfs)(struct dentry___115 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___115 *, int *, char *);
	void (*umount_begin)(struct super_block___115 *);
	int (*show_options)(struct seq_file___105 *, struct dentry___115 *);
	int (*show_devname)(struct seq_file___105 *, struct dentry___115 *);
	int (*show_path)(struct seq_file___105 *, struct dentry___115 *);
	int (*show_stats)(struct seq_file___105 *, struct dentry___115 *);
	ssize_t (*quota_read)(struct super_block___115 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___115 *, int, const char *, size_t, loff_t);
	struct dquot___114 ** (*get_dquots)(struct inode___116 *);
	int (*bdev_try_to_free_page)(struct super_block___115 *, struct page___115 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___115 *, struct shrink_control___36 *);
	long int (*free_cached_objects)(struct super_block___115 *, struct shrink_control___36 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___77)(struct file___115 *, wait_queue_head_t *, struct poll_table_struct___78 *);

struct poll_table_struct___78 {
	poll_queue_proc___77 _qproc;
	__poll_t _key;
};

struct nf_bridge_info___12;

struct sk_buff___16 {
	union {
		struct {
			struct sk_buff___16 *next;
			struct sk_buff___16 *prev;
			union {
				struct net_device___17 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___8 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___16 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___12 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___12;

struct netns_frags___12 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___12 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv4___12 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct sock *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock **tcp_sk;
	struct netns_frags___12 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct dst_ops___20 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___20 *);
	struct dst_entry___2 * (*check)(struct dst_entry___2 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___2 *);
	unsigned int (*mtu)(const struct dst_entry___2 *);
	u32 * (*cow_metrics)(struct dst_entry___2 *, long unsigned int);
	void (*destroy)(struct dst_entry___2 *);
	void (*ifdown)(struct dst_entry___2 *, struct net_device___17 *, int);
	struct dst_entry___2 * (*negative_advice)(struct dst_entry___2 *);
	void (*link_failure)(struct sk_buff___16 *);
	void (*update_pmtu)(struct dst_entry___2 *, struct sock *, struct sk_buff___16 *, u32);
	void (*redirect)(struct dst_entry___2 *, struct sock *, struct sk_buff___16 *);
	int (*local_out)(struct net___22 *, struct sock *, struct sk_buff___16 *);
	struct neighbour___2 * (*neigh_lookup)(const struct dst_entry___2 *, struct sk_buff___16 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___2 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___19 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___12 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___20 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct sock *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops *notifier_ops;
	struct fib_notifier_ops *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_nf_frag___12 {
	struct netns_frags___12 frags;
};

struct netns_xfrm___19 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___20 xfrm4_dst_ops;
	struct dst_ops___20 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct net___22 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___95 *user_ns;
	struct ucounts___95 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___7 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___17 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___12 ipv4;
	struct netns_ipv6___19 ipv6;
	struct netns_sctp___5 sctp;
	struct netns_nf nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___12 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock *nfnl;
	struct sock *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___19 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___11 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kernfs_root___111;

struct kernfs_elem_dir___111 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___111 *root;
};

struct kernfs_syscall_ops___111;

struct kernfs_root___111 {
	struct kernfs_node___111 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___111 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___111 {
	struct kernfs_node___111 *target_kn;
};

struct kernfs_ops___111;

struct kernfs_elem_attr___111 {
	const struct kernfs_ops___111 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___111 *notify_next;
};

struct kernfs_node___111 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___111 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___111 dir;
		struct kernfs_elem_symlink___111 symlink;
		struct kernfs_elem_attr___111 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___111;

struct kernfs_ops___111 {
	int (*open)(struct kernfs_open_file___111 *);
	void (*release)(struct kernfs_open_file___111 *);
	int (*seq_show)(struct seq_file___105 *, void *);
	void * (*seq_start)(struct seq_file___105 *, loff_t *);
	void * (*seq_next)(struct seq_file___105 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___105 *, void *);
	ssize_t (*read)(struct kernfs_open_file___111 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___111 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___111 *, struct vm_area_struct___115 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___111 *, struct poll_table_struct___78 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___111 {
	int (*remount_fs)(struct kernfs_root___111 *, int *, char *);
	int (*show_options)(struct seq_file___105 *, struct kernfs_root___111 *);
	int (*mkdir)(struct kernfs_node___111 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___111 *);
	int (*rename)(struct kernfs_node___111 *, struct kernfs_node___111 *, const char *);
	int (*show_path)(struct seq_file___105 *, struct kernfs_node___111 *, struct kernfs_root___111 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___111 {
	struct kernfs_node___111 *kn;
	struct file___115 *file;
	struct seq_file___105 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___112 *vm_ops;
};

struct bin_attribute___105;

struct attribute_group___105 {
	const char *name;
	umode_t (*is_visible)(struct kobject___109 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___109 *, struct bin_attribute___105 *, int);
	struct attribute **attrs;
	struct bin_attribute___105 **bin_attrs;
};

struct bin_attribute___105 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___115 *, struct kobject___109 *, struct bin_attribute___105 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___115 *, struct kobject___109 *, struct bin_attribute___105 *, char *, loff_t, size_t);
	int (*mmap)(struct file___115 *, struct kobject___109 *, struct bin_attribute___105 *, struct vm_area_struct___115 *);
};

struct sysfs_ops___108 {
	ssize_t (*show)(struct kobject___109 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___109 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___108;

struct kset___108 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___109 kobj;
	const struct kset_uevent_ops___108 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___108 {
	void (*release)(struct kobject___109 *);
	const struct sysfs_ops___108 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___5 * (*child_ns_type)(struct kobject___109 *);
	const void * (*namespace)(struct kobject___109 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___108 {
	int (* const filter)(struct kset___108 *, struct kobject___109 *);
	const char * (* const name)(struct kset___108 *, struct kobject___109 *);
	int (* const uevent)(struct kset___108 *, struct kobject___109 *, struct kobj_uevent_env *);
};

struct kobj_attribute___109 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___109 *, struct kobj_attribute___109 *, char *);
	ssize_t (*store)(struct kobject___109 *, struct kobj_attribute___109 *, const char *, size_t);
};

struct dev_pm_ops___106 {
	int (*prepare)(struct device___106 *);
	void (*complete)(struct device___106 *);
	int (*suspend)(struct device___106 *);
	int (*resume)(struct device___106 *);
	int (*freeze)(struct device___106 *);
	int (*thaw)(struct device___106 *);
	int (*poweroff)(struct device___106 *);
	int (*restore)(struct device___106 *);
	int (*suspend_late)(struct device___106 *);
	int (*resume_early)(struct device___106 *);
	int (*freeze_late)(struct device___106 *);
	int (*thaw_early)(struct device___106 *);
	int (*poweroff_late)(struct device___106 *);
	int (*restore_early)(struct device___106 *);
	int (*suspend_noirq)(struct device___106 *);
	int (*resume_noirq)(struct device___106 *);
	int (*freeze_noirq)(struct device___106 *);
	int (*thaw_noirq)(struct device___106 *);
	int (*poweroff_noirq)(struct device___106 *);
	int (*restore_noirq)(struct device___106 *);
	int (*runtime_suspend)(struct device___106 *);
	int (*runtime_resume)(struct device___106 *);
	int (*runtime_idle)(struct device___106 *);
};

struct dev_pm_domain___106 {
	struct dev_pm_ops___106 ops;
	void (*detach)(struct device___106 *, bool);
	int (*activate)(struct device___106 *);
	void (*sync)(struct device___106 *);
	void (*dismiss)(struct device___106 *);
};

struct bus_type___106 {
	const char *name;
	const char *dev_name;
	struct device___106 *dev_root;
	const struct attribute_group___105 **bus_groups;
	const struct attribute_group___105 **dev_groups;
	const struct attribute_group___105 **drv_groups;
	int (*match)(struct device___106 *, struct device_driver___106 *);
	int (*uevent)(struct device___106 *, struct kobj_uevent_env *);
	int (*probe)(struct device___106 *);
	int (*remove)(struct device___106 *);
	void (*shutdown)(struct device___106 *);
	int (*online)(struct device___106 *);
	int (*offline)(struct device___106 *);
	int (*suspend)(struct device___106 *, pm_message_t);
	int (*resume)(struct device___106 *);
	int (*num_vf)(struct device___106 *);
	int (*dma_configure)(struct device___106 *);
	const struct dev_pm_ops___106 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___106 {
	const char *name;
	struct bus_type___106 *bus;
	struct module___98 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___106 *);
	int (*remove)(struct device___106 *);
	void (*shutdown)(struct device___106 *);
	int (*suspend)(struct device___106 *, pm_message_t);
	int (*resume)(struct device___106 *);
	const struct attribute_group___105 **groups;
	const struct dev_pm_ops___106 *pm;
	void (*coredump)(struct device___106 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___106 {
	const char *name;
	const struct attribute_group___105 **groups;
	int (*uevent)(struct device___106 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___106 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___106 *);
	const struct dev_pm_ops___106 *pm;
};

struct class___106 {
	const char *name;
	struct module___98 *owner;
	const struct attribute_group___105 **class_groups;
	const struct attribute_group___105 **dev_groups;
	struct kobject___109 *dev_kobj;
	int (*dev_uevent)(struct device___106 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___106 *, umode_t *);
	void (*class_release)(struct class___106 *);
	void (*dev_release)(struct device___106 *);
	int (*shutdown_pre)(struct device___106 *);
	const struct kobj_ns_type_operations___5 *ns_type;
	const void * (*namespace)(struct device___106 *);
	const struct dev_pm_ops___106 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___28 {
	void * (*alloc)(struct device___106 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___106 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___106 *, struct vm_area_struct___115 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___106 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___106 *, struct page___115 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___106 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___106 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___106 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___106 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___106 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___106 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___106 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___106 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___106 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___106 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___106 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___106 *, u64);
	u64 (*get_required_mask)(struct device___106 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___78;

struct fwnode_handle___78 {
	struct fwnode_handle___78 *secondary;
	const struct fwnode_operations___78 *ops;
};

typedef void compound_page_dtor___112(struct page___115 *);

struct fwnode_reference_args___78;

struct fwnode_endpoint___78;

struct fwnode_operations___78 {
	struct fwnode_handle___78 * (*get)(struct fwnode_handle___78 *);
	void (*put)(struct fwnode_handle___78 *);
	bool (*device_is_available)(const struct fwnode_handle___78 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___78 *, const struct device___106 *);
	bool (*property_present)(const struct fwnode_handle___78 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___78 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___78 *, const char *, const char **, size_t);
	struct fwnode_handle___78 * (*get_parent)(const struct fwnode_handle___78 *);
	struct fwnode_handle___78 * (*get_next_child_node)(const struct fwnode_handle___78 *, struct fwnode_handle___78 *);
	struct fwnode_handle___78 * (*get_named_child_node)(const struct fwnode_handle___78 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___78 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___78 *);
	struct fwnode_handle___78 * (*graph_get_next_endpoint)(const struct fwnode_handle___78 *, struct fwnode_handle___78 *);
	struct fwnode_handle___78 * (*graph_get_remote_endpoint)(const struct fwnode_handle___78 *);
	struct fwnode_handle___78 * (*graph_get_port_parent)(struct fwnode_handle___78 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___78 *, struct fwnode_endpoint___78 *);
};

struct fwnode_endpoint___78 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___78 *local_fwnode;
};

struct fwnode_reference_args___78 {
	struct fwnode_handle___78 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___25;

struct pipe_buffer___25 {
	struct page___115 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___25 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___25 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___25 *, struct pipe_buffer___25 *);
	void (*release)(struct pipe_inode_info___25 *, struct pipe_buffer___25 *);
	int (*steal)(struct pipe_inode_info___25 *, struct pipe_buffer___25 *);
	union {
		bool (*get)(struct pipe_inode_info___25 *, struct pipe_buffer___25 *);
		struct {
			void (*get)(struct pipe_inode_info___25 *, struct pipe_buffer___25 *);
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
};

struct nf_bridge_info___12 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___12 = 0,
		BRNF_PROTO_8021Q___12 = 1,
		BRNF_PROTO_PPPOE___12 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___17 *physindev;
	struct net_device___17 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

struct sk_buff_head___13 {
	struct sk_buff___16 *next;
	struct sk_buff___16 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct ethtool_ops___12 {
	int (*get_settings)(struct net_device___17 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___17 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___17 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___17 *);
	void (*get_regs)(struct net_device___17 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___17 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___17 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___17 *);
	void (*set_msglevel)(struct net_device___17 *, u32);
	int (*nway_reset)(struct net_device___17 *);
	u32 (*get_link)(struct net_device___17 *);
	int (*get_eeprom_len)(struct net_device___17 *);
	int (*get_eeprom)(struct net_device___17 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___17 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___17 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___17 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___17 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___17 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___17 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___17 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___17 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___17 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___17 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___17 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___17 *);
	void (*complete)(struct net_device___17 *);
	u32 (*get_priv_flags)(struct net_device___17 *);
	int (*set_priv_flags)(struct net_device___17 *, u32);
	int (*get_sset_count)(struct net_device___17 *, int);
	int (*get_rxnfc)(struct net_device___17 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___17 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___17 *, struct ethtool_flash *);
	int (*reset)(struct net_device___17 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___17 *);
	u32 (*get_rxfh_indir_size)(struct net_device___17 *);
	int (*get_rxfh)(struct net_device___17 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___17 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___17 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___17 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___17 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___17 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___17 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___17 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___17 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___17 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___17 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___17 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___17 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___17 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___17 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___17 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___17 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___17 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___17 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___17 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___17 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___17 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	int (*get_fecparam)(struct net_device___17 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___17 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___17 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___17 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___17 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___12;

struct inet_frags___12 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___12 *, const void *);
	void (*destructor)(struct inet_frag_queue___12 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___12 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___16 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___16 *fragments_tail;
	struct sk_buff___16 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___12 *net;
	struct callback_head rcu;
};

struct ucounts___95 {
	struct hlist_node node;
	struct user_namespace___95 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

typedef int (*key_restrict_link_func_t___110)(struct key___110 *, const struct key_type *, const union key_payload *, struct key___110 *);

struct key_restriction___110;

struct key___110 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___115 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___110 *restrict_link;
};

struct key_restriction___110 {
	key_restrict_link_func_t___110 check;
	struct key___110 *key;
	struct key_type *keytype;
};

struct seq_operations___103 {
	void * (*start)(struct seq_file___105 *, loff_t *);
	void (*stop)(struct seq_file___105 *, void *);
	void * (*next)(struct seq_file___105 *, void *, loff_t *);
	int (*show)(struct seq_file___105 *, void *);
};

struct pernet_operations___12 {
	struct list_head list;
	int (*init)(struct net___22 *);
	void (*exit)(struct net___22 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___12 {
	int (*ieee_getets)(struct net_device___17 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___17 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___17 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___17 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___17 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___17 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___17 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___17 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___17 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___17 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___17 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___17 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___17 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___17 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___17 *);
	u8 (*setstate)(struct net_device___17 *, u8);
	void (*getpermhwaddr)(struct net_device___17 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___17 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___17 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___17 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___17 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___17 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___17 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___17 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___17 *, int, u8 *);
	void (*setpfccfg)(struct net_device___17 *, int, u8);
	void (*getpfccfg)(struct net_device___17 *, int, u8 *);
	u8 (*setall)(struct net_device___17 *);
	u8 (*getcap)(struct net_device___17 *, int, u8 *);
	int (*getnumtcs)(struct net_device___17 *, int, u8 *);
	int (*setnumtcs)(struct net_device___17 *, int, u8);
	u8 (*getpfcstate)(struct net_device___17 *);
	void (*setpfcstate)(struct net_device___17 *, u8);
	void (*getbcncfg)(struct net_device___17 *, int, u32 *);
	void (*setbcncfg)(struct net_device___17 *, int, u32);
	void (*getbcnrp)(struct net_device___17 *, int, u8 *);
	void (*setbcnrp)(struct net_device___17 *, int, u8);
	int (*setapp)(struct net_device___17 *, u8, u16, u8);
	int (*getapp)(struct net_device___17 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___17 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___17 *, int, u8);
	u8 (*getdcbx)(struct net_device___17 *);
	u8 (*setdcbx)(struct net_device___17 *, u8);
	int (*peer_getappinfo)(struct net_device___17 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___17 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___17 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___17 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___17 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___17 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___91 {
	refcount_t count;
	struct ns_common___7 ns;
	struct user_namespace___95 *user_ns;
	struct ucounts___95 *ucounts;
	struct css_set___91 *root_cset;
};

struct cgroup_bpf___11 {
	struct bpf_prog_array___11 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___11 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___91;

typedef void (*kthread_work_func_t___91)(struct kthread_work___91 *);

struct kthread_worker___91;

struct kthread_work___91 {
	struct list_head node;
	kthread_work_func_t___91 func;
	struct kthread_worker___91 *worker;
	int canceling;
};

struct kthread_worker___91 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___115 *task;
	struct kthread_work___91 *current_work;
};

struct kthread_delayed_work___91 {
	struct kthread_work___91 work;
	struct timer_list timer;
};

struct psi_group___91 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___91 *poll_kworker;
	struct kthread_delayed_work___91 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___91 {
	struct kernfs_node___111 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___91;

struct cgroup_subsys_state___91 {
	struct cgroup___91 *cgroup;
	struct cgroup_subsys___91 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___91 *parent;
};

struct cgroup_root___91;

struct cgroup_rstat_cpu___91;

struct cgroup___91 {
	struct cgroup_subsys_state___91 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___111 *kn;
	struct cgroup_file___91 procs_file;
	struct cgroup_file___91 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___91 *subsys[13];
	struct cgroup_root___91 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___91 *dom_cgrp;
	struct cgroup_rstat_cpu___91 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___11 bpf;
	atomic_t congestion_count;
	struct cgroup___91 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___91 psi;
	int ancestor_ids[0];
};

struct cftype___91;

struct cgroup_subsys___91 {
	struct cgroup_subsys_state___91 * (*css_alloc)(struct cgroup_subsys_state___91 *);
	int (*css_online)(struct cgroup_subsys_state___91 *);
	void (*css_offline)(struct cgroup_subsys_state___91 *);
	void (*css_released)(struct cgroup_subsys_state___91 *);
	void (*css_free)(struct cgroup_subsys_state___91 *);
	void (*css_reset)(struct cgroup_subsys_state___91 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___91 *, int);
	int (*css_extra_stat_show)(struct seq_file___105 *, struct cgroup_subsys_state___91 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___115 *);
	void (*cancel_fork)(struct task_struct___115 *);
	void (*fork)(struct task_struct___115 *);
	void (*exit)(struct task_struct___115 *);
	void (*free)(struct task_struct___115 *);
	void (*bind)(struct cgroup_subsys_state___91 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___91 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___91 *dfl_cftypes;
	struct cftype___91 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___91 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___91 *updated_children;
	struct cgroup___91 *updated_next;
};

struct cgroup_root___91 {
	struct kernfs_root___111 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___91 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___91 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___91 *ss;
	struct list_head node;
	struct kernfs_ops___111 *kf_ops;
	int (*open)(struct kernfs_open_file___111 *);
	void (*release)(struct kernfs_open_file___111 *);
	u64 (*read_u64)(struct cgroup_subsys_state___91 *, struct cftype___91 *);
	s64 (*read_s64)(struct cgroup_subsys_state___91 *, struct cftype___91 *);
	int (*seq_show)(struct seq_file___105 *, void *);
	void * (*seq_start)(struct seq_file___105 *, loff_t *);
	void * (*seq_next)(struct seq_file___105 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___105 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___91 *, struct cftype___91 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___91 *, struct cftype___91 *, s64);
	ssize_t (*write)(struct kernfs_open_file___111 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___111 *, struct poll_table_struct___78 *);
};

struct xdp_rxq_info___12 {
	struct net_device___17 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___12 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___17 *dev_rx;
};

struct netlink_callback___12 {
	struct sk_buff___16 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___12 *);
	int (*dump)(struct sk_buff___16 *, struct netlink_callback___12 *);
	int (*done)(struct netlink_callback___12 *);
	void *data;
	struct module___98 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___12 {
	int (*create)(struct sk_buff___16 *, struct net_device___17 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___16 *, unsigned char *);
	int (*cache)(const struct neighbour___2 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___17 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___12 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___12 *, int);
	int poll_owner;
	struct net_device___17 *dev;
	struct sk_buff___16 *gro_list;
	struct sk_buff___16 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___12 {
	struct net_device___17 *dev;
	struct Qdisc___11 *qdisc;
	struct Qdisc___11 *qdisc_sleeping;
	struct kobject___109 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___17 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___11 {
	struct sk_buff___16 *head;
	struct sk_buff___16 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___11;

struct Qdisc___11 {
	int (*enqueue)(struct sk_buff___16 *, struct Qdisc___11 *, struct sk_buff___16 **);
	struct sk_buff___16 * (*dequeue)(struct Qdisc___11 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___11 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___12 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___13 gso_skb;
	struct qdisc_skb_head___11 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___11 *next_sched;
	struct sk_buff_head___13 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___12 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___109 kobj;
	struct net_device___17 *dev;
	long: 64;
	struct xdp_rxq_info___12 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___12)(struct net_device___17 *, struct sk_buff___16 *, struct net_device___17 *);

struct netdev_bpf___12 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___11 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___11 *prog;
			const struct bpf_prog_offload_ops___11 *ops;
		} verifier;
		struct {
			struct bpf_prog___11 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___12 *offmap;
		};
		struct {
			struct xdp_umem *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___12 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___16 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___12 {
	int (*tls_dev_add)(struct net_device___17 *, struct sock *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___17 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___17 *, struct sock *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___12 {
	int (*ndo_init)(struct net_device___17 *);
	void (*ndo_uninit)(struct net_device___17 *);
	int (*ndo_open)(struct net_device___17 *);
	int (*ndo_stop)(struct net_device___17 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___16 *, struct net_device___17 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___16 *, struct net_device___17 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___17 *, struct sk_buff___16 *, struct net_device___17 *, select_queue_fallback_t___12);
	void (*ndo_change_rx_flags)(struct net_device___17 *, int);
	void (*ndo_set_rx_mode)(struct net_device___17 *);
	int (*ndo_set_mac_address)(struct net_device___17 *, void *);
	int (*ndo_validate_addr)(struct net_device___17 *);
	int (*ndo_do_ioctl)(struct net_device___17 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___17 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___17 *, int);
	int (*ndo_neigh_setup)(struct net_device___17 *, struct neigh_parms___3 *);
	void (*ndo_tx_timeout)(struct net_device___17 *);
	void (*ndo_get_stats64)(struct net_device___17 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___17 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___17 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___17 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___17 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___17 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___17 *);
	int (*ndo_netpoll_setup)(struct net_device___17 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___17 *);
	int (*ndo_set_vf_mac)(struct net_device___17 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___17 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___17 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___17 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___17 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___17 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___17 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___17 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___17 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___17 *, int, struct sk_buff___16 *);
	int (*ndo_set_vf_guid)(struct net_device___17 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___17 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___17 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___17 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___17 *, const struct sk_buff___16 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___17 *, struct net_device___17 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___17 *, struct net_device___17 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___17 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___17 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___17 *, struct neighbour___2 *);
	void (*ndo_neigh_destroy)(struct net_device___17 *, struct neighbour___2 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___17 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___17 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___17 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___16 *, struct netlink_callback___12 *, struct net_device___17 *, struct net_device___17 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___17 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___17 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___16 *, u32, u32, struct net_device___17 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___17 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___17 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___17 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___17 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___17 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___17 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___17 *, struct net_device___17 *);
	void (*ndo_dfwd_del_station)(struct net_device___17 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___17 *);
	int (*ndo_set_tx_maxrate)(struct net_device___17 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___17 *);
	int (*ndo_change_proto_down)(struct net_device___17 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___17 *, struct sk_buff___16 *);
	void (*ndo_set_rx_headroom)(struct net_device___17 *, int);
	int (*ndo_bpf)(struct net_device___17 *, struct netdev_bpf___12 *);
	int (*ndo_xdp_xmit)(struct net_device___17 *, int, struct xdp_frame___12 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___17 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___17 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct tcf_proto___11;

struct mini_Qdisc___11 {
	struct tcf_proto___11 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___11 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___17 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___22 *, struct net_device___17 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___17 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___17 *, struct list_head *);
	size_t (*get_size)(const struct net_device___17 *);
	int (*fill_info)(struct sk_buff___16 *, const struct net_device___17 *);
	size_t (*get_xstats_size)(const struct net_device___17 *);
	int (*fill_xstats)(struct sk_buff___16 *, const struct net_device___17 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___17 *, struct net_device___17 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___17 *, const struct net_device___17 *);
	int (*fill_slave_info)(struct sk_buff___16 *, const struct net_device___17 *, const struct net_device___17 *);
	struct net___22 * (*get_link_net)(const struct net_device___17 *);
	size_t (*get_linkxstats_size)(const struct net_device___17 *, int);
	int (*fill_linkxstats)(struct sk_buff___16 *, const struct net_device___17 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___12 {
	struct list_head poll_list;
	struct sk_buff_head___13 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___12 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___11 *output_queue;
	struct Qdisc___11 **output_queue_tailp;
	struct sk_buff___16 *completion_queue;
	struct sk_buff_head___13 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___12 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___13 input_pkt_queue;
	struct napi_struct___12 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kernel_param_ops___95 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___95 *);
	int (*get)(char *, const struct kernel_param___95 *);
	void (*free)(void *);
};

struct kparam_array___95;

struct kernel_param___95 {
	const char *name;
	struct module___98 *mod;
	const struct kernel_param_ops___95 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___95 *arr;
	};
};

struct kparam_array___95 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___95 *ops;
	void *elem;
};

struct module_attribute___95 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___95 *, struct module_kobject___95 *, char *);
	ssize_t (*store)(struct module_attribute___95 *, struct module_kobject___95 *, const char *, size_t);
	void (*setup)(struct module___98 *, const char *);
	int (*test)(struct module___98 *);
	void (*free)(struct module___98 *);
};

struct trace_event_class___68;

struct trace_event_call___68 {
	struct list_head list;
	struct trace_event_class___68 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___13 event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___11 *prog_array;
	int (*perf_perm)(struct trace_event_call___68 *, struct perf_event___73 *);
};

struct gnet_dump___11 {
	spinlock_t *lock;
	struct sk_buff___16 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___11;

struct Qdisc_ops___11 {
	struct Qdisc_ops___11 *next;
	const struct Qdisc_class_ops___11 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___16 *, struct Qdisc___11 *, struct sk_buff___16 **);
	struct sk_buff___16 * (*dequeue)(struct Qdisc___11 *);
	struct sk_buff___16 * (*peek)(struct Qdisc___11 *);
	int (*init)(struct Qdisc___11 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___11 *);
	void (*destroy)(struct Qdisc___11 *);
	int (*change)(struct Qdisc___11 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___11 *);
	int (*change_tx_queue_len)(struct Qdisc___11 *, unsigned int);
	int (*dump)(struct Qdisc___11 *, struct sk_buff___16 *);
	int (*dump_stats)(struct Qdisc___11 *, struct gnet_dump___11 *);
	void (*ingress_block_set)(struct Qdisc___11 *, u32);
	void (*egress_block_set)(struct Qdisc___11 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___11 *);
	u32 (*egress_block_get)(struct Qdisc___11 *);
	struct module___98 *owner;
};

struct tcf_block___11;

struct Qdisc_class_ops___11 {
	unsigned int flags;
	struct netdev_queue___12 * (*select_queue)(struct Qdisc___11 *, struct tcmsg *);
	int (*graft)(struct Qdisc___11 *, long unsigned int, struct Qdisc___11 *, struct Qdisc___11 **, struct netlink_ext_ack *);
	struct Qdisc___11 * (*leaf)(struct Qdisc___11 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___11 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___11 *, u32);
	int (*change)(struct Qdisc___11 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___11 *, long unsigned int);
	void (*walk)(struct Qdisc___11 *, struct qdisc_walker *);
	struct tcf_block___11 * (*tcf_block)(struct Qdisc___11 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___11 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___11 *, long unsigned int);
	int (*dump)(struct Qdisc___11 *, long unsigned int, struct sk_buff___16 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___11 *, long unsigned int, struct gnet_dump___11 *);
};

struct tcf_chain___11;

struct tcf_block___11 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___22 *net;
	struct Qdisc___11 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___11 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___11;

struct tcf_proto_ops___11;

struct tcf_proto___11 {
	struct tcf_proto___11 *next;
	void *root;
	int (*classify)(struct sk_buff___16 *, const struct tcf_proto___11 *, struct tcf_result___11 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___11 *ops;
	struct tcf_chain___11 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___11 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___11 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___11 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___16 *, const struct tcf_proto___11 *, struct tcf_result___11 *);
	int (*init)(struct tcf_proto___11 *);
	void (*destroy)(struct tcf_proto___11 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___11 *, u32);
	void (*put)(struct tcf_proto___11 *, void *);
	int (*change)(struct net___22 *, struct sk_buff___16 *, struct tcf_proto___11 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___11 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___11 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___11 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___22 *, struct tcf_chain___11 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___22 *, struct tcf_proto___11 *, void *, struct sk_buff___16 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___16 *, struct net___22 *, void *);
	struct module___98 *owner;
	int flags;
};

struct tcf_chain___11 {
	struct mutex filter_chain_lock;
	struct tcf_proto___11 *filter_chain;
	struct list_head list;
	struct tcf_block___11 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___11 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct bpf_redirect_info___11 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___91 *map;
	struct bpf_map___91 *map_to_flush;
	u32 kern_flags;
};

struct node___92 {
	struct device___106 dev;
};

struct perf_cpu_context___73;

struct pmu___73 {
	struct list_head entry;
	struct module___98 *module;
	struct device___106 *dev;
	const struct attribute_group___105 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___73 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___73 *);
	void (*pmu_disable)(struct pmu___73 *);
	int (*event_init)(struct perf_event___73 *);
	void (*event_mapped)(struct perf_event___73 *, struct mm_struct___114 *);
	void (*event_unmapped)(struct perf_event___73 *, struct mm_struct___114 *);
	int (*add)(struct perf_event___73 *, int);
	void (*del)(struct perf_event___73 *, int);
	void (*start)(struct perf_event___73 *, int);
	void (*stop)(struct perf_event___73 *, int);
	void (*read)(struct perf_event___73 *);
	void (*start_txn)(struct pmu___73 *, unsigned int);
	int (*commit_txn)(struct pmu___73 *);
	void (*cancel_txn)(struct pmu___73 *);
	int (*event_idx)(struct perf_event___73 *);
	void (*sched_task)(struct perf_event_context___73 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___73 *);
	int (*filter_match)(struct perf_event___73 *);
	int (*check_period)(struct perf_event___73 *, u64);
};

struct perf_cpu_context___73 {
	struct perf_event_context___73 ctx;
	struct perf_event_context___73 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___73 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___73 {
	struct cgroup_subsys_state___91 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___68 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___68 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___68 *);
	struct list_head * (*get_fields)(struct trace_event_call___68 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___68 *);
};

struct syscall_metadata___25 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___68 *enter_event;
	struct trace_event_call___68 *exit_event;
};

struct bpf_raw_tracepoint {
	struct bpf_raw_event_map *btp;
	struct bpf_prog___11 *prog;
};

struct fd___6 {
	struct file___109 *file;
	unsigned int flags;
};

struct bpf_verifier_log {
	u32 level;
	char kbuf[1024];
	char *ubuf;
	u32 len_used;
	u32 len_total;
};

struct bpf_subprog_info {
	u32 start;
	u32 linfo_idx;
	u16 stack_depth;
};

struct bpf_verifier_stack_elem;

struct bpf_verifier_state;

struct bpf_verifier_state_list;

struct bpf_insn_aux_data;

struct bpf_verifier_env {
	u32 insn_idx;
	u32 prev_insn_idx;
	struct bpf_prog___10 *prog;
	const struct bpf_verifier_ops___10 *ops;
	struct bpf_verifier_stack_elem *head;
	int stack_size;
	bool strict_alignment;
	struct bpf_verifier_state *cur_state;
	struct bpf_verifier_state_list **explored_states;
	struct bpf_map___85 *used_maps[64];
	u32 used_map_cnt;
	u32 id_gen;
	bool allow_ptr_leaks;
	bool seen_direct_write;
	struct bpf_insn_aux_data *insn_aux_data;
	const struct bpf_line_info *prev_linfo;
	struct bpf_verifier_log log;
	struct bpf_subprog_info subprog_info[257];
	u32 subprog_cnt;
};

typedef u32 (*bpf_convert_ctx_access_t)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___10 *, u32 *);

struct tnum {
	u64 value;
	u64 mask;
};

enum bpf_reg_liveness {
	REG_LIVE_NONE = 0,
	REG_LIVE_READ = 1,
	REG_LIVE_WRITTEN = 2,
	REG_LIVE_DONE = 4,
};

struct bpf_reg_state {
	enum bpf_reg_type type;
	union {
		u16 range;
		struct bpf_map___85 *map_ptr;
		long unsigned int raw;
	};
	s32 off;
	u32 id;
	struct tnum var_off;
	s64 smin_value;
	s64 smax_value;
	u64 umin_value;
	u64 umax_value;
	struct bpf_reg_state *parent;
	u32 frameno;
	enum bpf_reg_liveness live;
};

enum bpf_stack_slot_type {
	STACK_INVALID = 0,
	STACK_SPILL = 1,
	STACK_MISC = 2,
	STACK_ZERO = 3,
};

struct bpf_stack_state {
	struct bpf_reg_state spilled_ptr;
	u8 slot_type[8];
};

struct bpf_reference_state {
	int id;
	int insn_idx;
};

struct bpf_func_state {
	struct bpf_reg_state regs[11];
	int callsite;
	u32 frameno;
	u32 subprogno;
	int acquired_refs;
	struct bpf_reference_state *refs;
	int allocated_stack;
	struct bpf_stack_state *stack;
};

struct bpf_verifier_state {
	struct bpf_func_state *frame[8];
	u32 curframe;
	bool speculative;
};

struct bpf_verifier_state_list {
	struct bpf_verifier_state state;
	struct bpf_verifier_state_list *next;
};

struct bpf_insn_aux_data {
	union {
		enum bpf_reg_type ptr_type;
		long unsigned int map_state;
		s32 call_imm;
		u32 alu_limit;
	};
	int ctx_field_size;
	int sanitize_stack_off;
	bool seen;
	u8 alu_state;
};

struct bpf_verifier_stack_elem {
	struct bpf_verifier_state st;
	int insn_idx;
	int prev_insn_idx;
	struct bpf_verifier_stack_elem *next;
};

typedef void (*bpf_insn_print_t)(void *, const char *, ...);

typedef const char * (*bpf_insn_revmap_call_t)(void *, const struct bpf_insn *);

typedef const char * (*bpf_insn_print_imm_t)(void *, const struct bpf_insn *, __u64);

struct bpf_insn_cbs {
	bpf_insn_print_t cb_print;
	bpf_insn_revmap_call_t cb_call;
	bpf_insn_print_imm_t cb_imm;
	void *private_data;
};

struct bpf_call_arg_meta {
	struct bpf_map___85 *map_ptr;
	bool raw_mode;
	bool pkt_access;
	int regno;
	int access_size;
	s64 msize_smax_value;
	u64 msize_umax_value;
	int ptr_id;
};

enum reg_arg_type {
	SRC_OP = 0,
	DST_OP = 1,
	DST_OP_NO_MARK = 2,
};

enum {
	DISCOVERED = 16,
	EXPLORED = 32,
	FALLTHROUGH = 1,
	BRANCH = 2,
};

struct idpair {
	u32 old;
	u32 cur;
};

struct module___99;

struct file___116;

struct kiocb___116;

struct iov_iter___45;

struct vm_area_struct___116;

struct inode___117;

struct file_lock___116;

struct page___116;

struct pipe_inode_info___26;

struct seq_file___106;

struct file_operations___116 {
	struct module___99 *owner;
	loff_t (*llseek)(struct file___116 *, loff_t, int);
	ssize_t (*read)(struct file___116 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___116 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___116 *, struct iov_iter___45 *);
	ssize_t (*write_iter)(struct kiocb___116 *, struct iov_iter___45 *);
	int (*iopoll)(struct kiocb___116 *, bool);
	int (*iterate)(struct file___116 *, struct dir_context *);
	int (*iterate_shared)(struct file___116 *, struct dir_context *);
	__poll_t (*poll)(struct file___116 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___116 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___116 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___116 *, struct vm_area_struct___116 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___117 *, struct file___116 *);
	int (*flush)(struct file___116 *, fl_owner_t);
	int (*release)(struct inode___117 *, struct file___116 *);
	int (*fsync)(struct file___116 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___116 *, int);
	int (*lock)(struct file___116 *, int, struct file_lock___116 *);
	ssize_t (*sendpage)(struct file___116 *, struct page___116 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___116 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___116 *, int, struct file_lock___116 *);
	ssize_t (*splice_write)(struct pipe_inode_info___26 *, struct file___116 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___116 *, loff_t *, struct pipe_inode_info___26 *, size_t, unsigned int);
	int (*setlease)(struct file___116 *, long int, struct file_lock___116 **, void **);
	long int (*fallocate)(struct file___116 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___106 *, struct file___116 *);
	ssize_t (*copy_file_range)(struct file___116 *, loff_t, struct file___116 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___116 *, loff_t, struct file___116 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___116 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___115 {
	u64 seqnum;
	struct vm_area_struct___116 *vmas[4];
};

struct page_frag___115 {
	struct page___116 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___115;

struct cred___111;

struct nsproxy___108;

struct signal_struct___105;

struct css_set___92;

struct vm_struct___85;

struct task_struct___116 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___116 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___115 *mm;
	struct mm_struct___115 *active_mm;
	struct vmacache___115 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___116 *real_parent;
	struct task_struct___116 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___116 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___97 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___97 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___97 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___111 *ptracer_cred;
	const struct cred___111 *real_cred;
	const struct cred___111 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___108 *nsproxy;
	struct signal_struct___105 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___116 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___17 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___92 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___26 *splice_pipe;
	struct page_frag___115 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___116 *oom_reaper_list;
	struct vm_struct___85 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___73 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry___116;

struct super_block___116;

struct vfsmount___17 {
	struct dentry___116 *mnt_root;
	struct super_block___116 *mnt_sb;
	int mnt_flags;
};

struct dentry_operations___115;

struct dentry___116 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___116 *d_parent;
	struct qstr d_name;
	struct inode___117 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___115 *d_op;
	struct super_block___116 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct rw_semaphore___116 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___116 *owner;
};

struct quota_format_type___115;

struct mem_dqinfo___115 {
	struct quota_format_type___115 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___115;

struct quota_info___115 {
	unsigned int flags;
	struct rw_semaphore___116 dqio_sem;
	struct inode___117 *files[3];
	struct mem_dqinfo___115 info[3];
	const struct quota_format_ops___115 *ops[3];
};

struct rcuwait___115 {
	struct task_struct___116 *task;
};

struct percpu_rw_semaphore___115 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___116 rw_sem;
	struct rcuwait___115 writer;
	int readers_block;
};

struct sb_writers___115 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___115 rw_sem[3];
};

struct file_system_type___115;

struct super_operations___115;

struct dquot_operations___115;

struct quotactl_ops___115;

struct block_device___116;

struct user_namespace___96;

struct super_block___116 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___115 *s_type;
	const struct super_operations___115 *s_op;
	const struct dquot_operations___115 *dq_op;
	const struct quotactl_ops___115 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___116 *s_root;
	struct rw_semaphore___116 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___116 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___115 s_dquot;
	struct sb_writers___115 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___115 *s_d_op;
	int cleancache_poolid;
	struct shrinker___36 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___96 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct path___115 {
	struct vfsmount___17 *mnt;
	struct dentry___116 *dentry;
};

struct address_space_operations___115;

struct address_space___115 {
	struct inode___117 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___116 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___115 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___115;

struct inode___117 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___115 *i_op;
	struct super_block___116 *i_sb;
	struct address_space___115 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___116 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___116 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___115 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___26 *i_pipe;
		struct block_device___116 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___115 {
	int (*d_revalidate)(struct dentry___116 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___116 *, unsigned int);
	int (*d_hash)(const struct dentry___116 *, struct qstr *);
	int (*d_compare)(const struct dentry___116 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___116 *);
	int (*d_init)(struct dentry___116 *);
	void (*d_release)(struct dentry___116 *);
	void (*d_prune)(struct dentry___116 *);
	void (*d_iput)(struct dentry___116 *, struct inode___117 *);
	char * (*d_dname)(struct dentry___116 *, char *, int);
	struct vfsmount___17 * (*d_automount)(struct path___115 *);
	int (*d_manage)(const struct path___115 *, bool);
	struct dentry___116 * (*d_real)(struct dentry___116 *, const struct inode___117 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct key___111;

struct ucounts___96;

struct user_namespace___96 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___96 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___7 ns;
	long unsigned int flags;
	struct key___111 *persistent_keyring_register;
	struct rw_semaphore___116 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___96 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___116 *pgtable_t___115;

struct dev_pagemap___113;

struct page___116 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___115 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___116 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___115 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___115 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___113 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___115;

struct lruvec___115 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___115 *pgdat;
};

struct zone___115 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___115 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___115 {
	struct zone___115 *zone;
	int zone_idx;
};

struct zonelist___115 {
	struct zoneref___115 _zonerefs[25];
};

struct pglist_data___115 {
	struct zone___115 node_zones[3];
	struct zonelist___115 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___116 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___116 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___115 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___116 {
	void *stack;
	struct task_struct___116 *task;
	long int status;
};

struct blocking_notifier_head___115 {
	struct rw_semaphore___116 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___113;

struct vm_area_struct___116 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___116 *vm_next;
	struct vm_area_struct___116 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___115 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___113 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___116 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___115;

struct mm_struct___115 {
	struct {
		struct vm_area_struct___116 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___116 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___116 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___115 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___116 *owner;
		struct user_namespace___96 *user_ns;
		struct file___116 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___115 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___113)(struct vm_area_struct___116 *, long unsigned int, const struct page___116 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___113)(struct page___116 *, void *);

struct device___107;

struct dev_pagemap___113 {
	dev_page_fault_t___113 page_fault;
	dev_page_free_t___113 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___107 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct file___116 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___115 f_path;
	struct inode___117 *f_inode;
	const struct file_operations___116 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___97 f_owner;
	const struct cred___111 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___115 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___113;

struct vm_operations_struct___113 {
	void (*open)(struct vm_area_struct___116 *);
	void (*close)(struct vm_area_struct___116 *);
	int (*split)(struct vm_area_struct___116 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___116 *);
	vm_fault_t (*fault)(struct vm_fault___113 *);
	vm_fault_t (*huge_fault)(struct vm_fault___113 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___113 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___116 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___113 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___113 *);
	int (*access)(struct vm_area_struct___116 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___116 *);
	int (*set_policy)(struct vm_area_struct___116 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___116 *, long unsigned int);
	struct page___116 * (*find_special_page)(struct vm_area_struct___116 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___115 {
	struct task_struct___116 *task;
	struct core_thread___115 *next;
};

struct core_state___115 {
	atomic_t nr_threads;
	struct core_thread___115 dumper;
	struct completion startup;
};

struct vm_fault___113 {
	struct vm_area_struct___116 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___116 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___116 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___115 prealloc_pte;
};

struct user_struct___111 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___111 *uid_keyring;
	struct key___111 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___111 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___111 *session_keyring;
	struct key___111 *process_keyring;
	struct key___111 *thread_keyring;
	struct key___111 *request_key_auth;
	void *security;
	struct user_struct___111 *user;
	struct user_namespace___96 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___23;

struct cgroup_namespace___92;

struct nsproxy___108 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net___23 *net_ns;
	struct cgroup_namespace___92 *cgroup_ns;
};

struct signal_struct___105 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___116 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___116 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___97 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___97 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___115 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___97 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___92;

struct cgroup___92;

struct css_set___92 {
	struct cgroup_subsys_state___92 *subsys[13];
	refcount_t refcount;
	struct css_set___92 *dom_cset;
	struct cgroup___92 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___92 *mg_src_cgrp;
	struct cgroup___92 *mg_dst_cgrp;
	struct css_set___92 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___115;

struct pipe_buffer___26;

struct pipe_inode_info___26 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___116 *tmp_page;
	struct fasync_struct___115 *fasync_readers;
	struct fasync_struct___115 *fasync_writers;
	struct pipe_buffer___26 *bufs;
	struct user_struct___111 *user;
};

struct vm_struct___85 {
	struct vm_struct___85 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___116 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___105 {
	struct task_struct___116 task;
	long unsigned int stack[8192];
};

struct kiocb___116 {
	struct file___116 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___116 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___116 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___116 *ia_file;
};

struct dquot___115 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___116 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___115 {
	int qf_fmt_id;
	const struct quota_format_ops___115 *qf_ops;
	struct module___99 *qf_owner;
	struct quota_format_type___115 *qf_next;
};

struct quota_format_ops___115 {
	int (*check_quota_file)(struct super_block___116 *, int);
	int (*read_file_info)(struct super_block___116 *, int);
	int (*write_file_info)(struct super_block___116 *, int);
	int (*free_file_info)(struct super_block___116 *, int);
	int (*read_dqblk)(struct dquot___115 *);
	int (*commit_dqblk)(struct dquot___115 *);
	int (*release_dqblk)(struct dquot___115 *);
	int (*get_next_id)(struct super_block___116 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___115 {
	int (*write_dquot)(struct dquot___115 *);
	struct dquot___115 * (*alloc_dquot)(struct super_block___116 *, int);
	void (*destroy_dquot)(struct dquot___115 *);
	int (*acquire_dquot)(struct dquot___115 *);
	int (*release_dquot)(struct dquot___115 *);
	int (*mark_dirty)(struct dquot___115 *);
	int (*write_info)(struct super_block___116 *, int);
	qsize_t * (*get_reserved_space)(struct inode___117 *);
	int (*get_projid)(struct inode___117 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___117 *, qsize_t *);
	int (*get_next_id)(struct super_block___116 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___115 {
	int (*quota_on)(struct super_block___116 *, int, int, const struct path___115 *);
	int (*quota_off)(struct super_block___116 *, int);
	int (*quota_enable)(struct super_block___116 *, unsigned int);
	int (*quota_disable)(struct super_block___116 *, unsigned int);
	int (*quota_sync)(struct super_block___116 *, int);
	int (*set_info)(struct super_block___116 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___116 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___116 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___116 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___116 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___116 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___109;

struct kobj_type___109;

struct kernfs_node___112;

struct kobject___110 {
	const char *name;
	struct list_head entry;
	struct kobject___110 *parent;
	struct kset___109 *kset;
	struct kobj_type___109 *ktype;
	struct kernfs_node___112 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___96 {
	struct kobject___110 kobj;
	struct module___99 *mod;
	struct kobject___110 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___96 {
	struct module___99 *mod;
	struct latch_tree_node node;
};

struct module_layout___96 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___96 mtn;
};

struct module_attribute___96;

struct kernel_param___96;

struct module___99 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___96 mkobj;
	struct module_attribute___96 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___110 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___96 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___96 core_layout;
	struct module_layout___96 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___115 {
	int (*writepage)(struct page___116 *, struct writeback_control___3 *);
	int (*readpage)(struct file___116 *, struct page___116 *);
	int (*writepages)(struct address_space___115 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___116 *);
	int (*readpages)(struct file___116 *, struct address_space___115 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___116 *, struct address_space___115 *, loff_t, unsigned int, unsigned int, struct page___116 **, void **);
	int (*write_end)(struct file___116 *, struct address_space___115 *, loff_t, unsigned int, unsigned int, struct page___116 *, void *);
	sector_t (*bmap)(struct address_space___115 *, sector_t);
	void (*invalidatepage)(struct page___116 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___116 *, gfp_t);
	void (*freepage)(struct page___116 *);
	ssize_t (*direct_IO)(struct kiocb___116 *, struct iov_iter___45 *);
	int (*migratepage)(struct address_space___115 *, struct page___116 *, struct page___116 *, enum migrate_mode);
	bool (*isolate_page)(struct page___116 *, isolate_mode_t);
	void (*putback_page)(struct page___116 *);
	int (*launder_page)(struct page___116 *);
	int (*is_partially_uptodate)(struct page___116 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___116 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___115 *, struct page___116 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___116 *, sector_t *);
	void (*swap_deactivate)(struct file___116 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct iov_iter___45 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___3 *bvec;
		struct pipe_inode_info___26 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___116 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___117 *bd_inode;
	struct super_block___116 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___116 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___115 {
	struct dentry___116 * (*lookup)(struct inode___117 *, struct dentry___116 *, unsigned int);
	const char * (*get_link)(struct dentry___116 *, struct inode___117 *, struct delayed_call *);
	int (*permission)(struct inode___117 *, int);
	struct posix_acl * (*get_acl)(struct inode___117 *, int);
	int (*readlink)(struct dentry___116 *, char *, int);
	int (*create)(struct inode___117 *, struct dentry___116 *, umode_t, bool);
	int (*link)(struct dentry___116 *, struct inode___117 *, struct dentry___116 *);
	int (*unlink)(struct inode___117 *, struct dentry___116 *);
	int (*symlink)(struct inode___117 *, struct dentry___116 *, const char *);
	int (*mkdir)(struct inode___117 *, struct dentry___116 *, umode_t);
	int (*rmdir)(struct inode___117 *, struct dentry___116 *);
	int (*mknod)(struct inode___117 *, struct dentry___116 *, umode_t, dev_t);
	int (*rename)(struct inode___117 *, struct dentry___116 *, struct inode___117 *, struct dentry___116 *, unsigned int);
	int (*setattr)(struct dentry___116 *, struct iattr___116 *);
	int (*getattr)(const struct path___115 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___116 *, char *, size_t);
	int (*fiemap)(struct inode___117 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___117 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___117 *, struct dentry___116 *, struct file___116 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___117 *, struct dentry___116 *, umode_t);
	int (*set_acl)(struct inode___117 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___115 {
	void (*fl_copy_lock)(struct file_lock___116 *, struct file_lock___116 *);
	void (*fl_release_private)(struct file_lock___116 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___115;

struct file_lock___116 {
	struct file_lock___116 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___116 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___115 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___115 *fl_ops;
	const struct lock_manager_operations___115 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___115 {
	int (*lm_compare_owner)(struct file_lock___116 *, struct file_lock___116 *);
	long unsigned int (*lm_owner_key)(struct file_lock___116 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___116 *);
	int (*lm_grant)(struct file_lock___116 *, int);
	bool (*lm_break)(struct file_lock___116 *);
	int (*lm_change)(struct file_lock___116 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___116 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___115 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___115 *fa_next;
	struct file___116 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___115 {
	const char *name;
	int fs_flags;
	struct dentry___116 * (*mount)(struct file_system_type___115 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___116 *);
	struct module___99 *owner;
	struct file_system_type___115 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___115 {
	struct inode___117 * (*alloc_inode)(struct super_block___116 *);
	void (*destroy_inode)(struct inode___117 *);
	void (*dirty_inode)(struct inode___117 *, int);
	int (*write_inode)(struct inode___117 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___117 *);
	void (*evict_inode)(struct inode___117 *);
	void (*put_super)(struct super_block___116 *);
	int (*sync_fs)(struct super_block___116 *, int);
	int (*freeze_super)(struct super_block___116 *);
	int (*freeze_fs)(struct super_block___116 *);
	int (*thaw_super)(struct super_block___116 *);
	int (*unfreeze_fs)(struct super_block___116 *);
	int (*statfs)(struct dentry___116 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___116 *, int *, char *);
	void (*umount_begin)(struct super_block___116 *);
	int (*show_options)(struct seq_file___106 *, struct dentry___116 *);
	int (*show_devname)(struct seq_file___106 *, struct dentry___116 *);
	int (*show_path)(struct seq_file___106 *, struct dentry___116 *);
	int (*show_stats)(struct seq_file___106 *, struct dentry___116 *);
	ssize_t (*quota_read)(struct super_block___116 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___116 *, int, const char *, size_t, loff_t);
	struct dquot___115 ** (*get_dquots)(struct inode___117 *);
	int (*bdev_try_to_free_page)(struct super_block___116 *, struct page___116 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___116 *, struct shrink_control___36 *);
	long int (*free_cached_objects)(struct super_block___116 *, struct shrink_control___36 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___104;

struct seq_file___106 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___104 *op;
	int poll_event;
	const struct file___116 *file;
	void *private;
};

struct tree_descr {
	const char *name;
	const struct file_operations___116 *ops;
	int mode;
};

struct match_token {
	int token;
	const char *pattern;
};

enum {
	MAX_OPT_ARGS = 3,
};

struct net_device___18;

struct nf_bridge_info___13;

struct sk_buff___17 {
	union {
		struct {
			struct sk_buff___17 *next;
			struct sk_buff___17 *prev;
			union {
				struct net_device___18 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___8 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___17 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___13 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___13;

struct netns_frags___13 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___13 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv4___13 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct sock *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock **tcp_sk;
	struct netns_frags___13 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct dst_ops___21 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___21 *);
	struct dst_entry___2 * (*check)(struct dst_entry___2 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___2 *);
	unsigned int (*mtu)(const struct dst_entry___2 *);
	u32 * (*cow_metrics)(struct dst_entry___2 *, long unsigned int);
	void (*destroy)(struct dst_entry___2 *);
	void (*ifdown)(struct dst_entry___2 *, struct net_device___18 *, int);
	struct dst_entry___2 * (*negative_advice)(struct dst_entry___2 *);
	void (*link_failure)(struct sk_buff___17 *);
	void (*update_pmtu)(struct dst_entry___2 *, struct sock *, struct sk_buff___17 *, u32);
	void (*redirect)(struct dst_entry___2 *, struct sock *, struct sk_buff___17 *);
	int (*local_out)(struct net___23 *, struct sock *, struct sk_buff___17 *);
	struct neighbour___2 * (*neigh_lookup)(const struct dst_entry___2 *, struct sk_buff___17 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___2 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___20 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___13 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___21 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct sock *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops *notifier_ops;
	struct fib_notifier_ops *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_nf_frag___13 {
	struct netns_frags___13 frags;
};

struct netns_xfrm___20 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___21 xfrm4_dst_ops;
	struct dst_ops___21 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___12;

struct net___23 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___96 *user_ns;
	struct ucounts___96 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___7 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___18 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___13 ipv4;
	struct netns_ipv6___20 ipv6;
	struct netns_sctp___5 sctp;
	struct netns_nf nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___13 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock *nfnl;
	struct sock *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___20 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___12 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kernfs_root___112;

struct kernfs_elem_dir___112 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___112 *root;
};

struct kernfs_syscall_ops___112;

struct kernfs_root___112 {
	struct kernfs_node___112 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___112 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___112 {
	struct kernfs_node___112 *target_kn;
};

struct kernfs_ops___112;

struct kernfs_elem_attr___112 {
	const struct kernfs_ops___112 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___112 *notify_next;
};

struct kernfs_node___112 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___112 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___112 dir;
		struct kernfs_elem_symlink___112 symlink;
		struct kernfs_elem_attr___112 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___112;

struct kernfs_ops___112 {
	int (*open)(struct kernfs_open_file___112 *);
	void (*release)(struct kernfs_open_file___112 *);
	int (*seq_show)(struct seq_file___106 *, void *);
	void * (*seq_start)(struct seq_file___106 *, loff_t *);
	void * (*seq_next)(struct seq_file___106 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___106 *, void *);
	ssize_t (*read)(struct kernfs_open_file___112 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___112 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___112 *, struct vm_area_struct___116 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___112 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___112 {
	int (*remount_fs)(struct kernfs_root___112 *, int *, char *);
	int (*show_options)(struct seq_file___106 *, struct kernfs_root___112 *);
	int (*mkdir)(struct kernfs_node___112 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___112 *);
	int (*rename)(struct kernfs_node___112 *, struct kernfs_node___112 *, const char *);
	int (*show_path)(struct seq_file___106 *, struct kernfs_node___112 *, struct kernfs_root___112 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___112 {
	struct kernfs_node___112 *kn;
	struct file___116 *file;
	struct seq_file___106 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___113 *vm_ops;
};

struct bin_attribute___106;

struct attribute_group___106 {
	const char *name;
	umode_t (*is_visible)(struct kobject___110 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___110 *, struct bin_attribute___106 *, int);
	struct attribute **attrs;
	struct bin_attribute___106 **bin_attrs;
};

struct bin_attribute___106 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___116 *, struct kobject___110 *, struct bin_attribute___106 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___116 *, struct kobject___110 *, struct bin_attribute___106 *, char *, loff_t, size_t);
	int (*mmap)(struct file___116 *, struct kobject___110 *, struct bin_attribute___106 *, struct vm_area_struct___116 *);
};

struct sysfs_ops___109 {
	ssize_t (*show)(struct kobject___110 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___110 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___109;

struct kset___109 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___110 kobj;
	const struct kset_uevent_ops___109 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___109 {
	void (*release)(struct kobject___110 *);
	const struct sysfs_ops___109 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___5 * (*child_ns_type)(struct kobject___110 *);
	const void * (*namespace)(struct kobject___110 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___109 {
	int (* const filter)(struct kset___109 *, struct kobject___110 *);
	const char * (* const name)(struct kset___109 *, struct kobject___110 *);
	int (* const uevent)(struct kset___109 *, struct kobject___110 *, struct kobj_uevent_env *);
};

struct kobj_attribute___110 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___110 *, struct kobj_attribute___110 *, char *);
	ssize_t (*store)(struct kobject___110 *, struct kobj_attribute___110 *, const char *, size_t);
};

struct dev_pm_ops___107 {
	int (*prepare)(struct device___107 *);
	void (*complete)(struct device___107 *);
	int (*suspend)(struct device___107 *);
	int (*resume)(struct device___107 *);
	int (*freeze)(struct device___107 *);
	int (*thaw)(struct device___107 *);
	int (*poweroff)(struct device___107 *);
	int (*restore)(struct device___107 *);
	int (*suspend_late)(struct device___107 *);
	int (*resume_early)(struct device___107 *);
	int (*freeze_late)(struct device___107 *);
	int (*thaw_early)(struct device___107 *);
	int (*poweroff_late)(struct device___107 *);
	int (*restore_early)(struct device___107 *);
	int (*suspend_noirq)(struct device___107 *);
	int (*resume_noirq)(struct device___107 *);
	int (*freeze_noirq)(struct device___107 *);
	int (*thaw_noirq)(struct device___107 *);
	int (*poweroff_noirq)(struct device___107 *);
	int (*restore_noirq)(struct device___107 *);
	int (*runtime_suspend)(struct device___107 *);
	int (*runtime_resume)(struct device___107 *);
	int (*runtime_idle)(struct device___107 *);
};

struct dev_pm_info___107 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___107 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___107;

struct bus_type___107;

struct device_driver___107;

struct dev_pm_domain___107;

struct dma_map_ops___29;

struct fwnode_handle___79;

struct class___107;

struct device___107 {
	struct device___107 *parent;
	struct device_private *p;
	struct kobject___110 kobj;
	const char *init_name;
	const struct device_type___107 *type;
	struct mutex mutex;
	struct bus_type___107 *bus;
	struct device_driver___107 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___107 power;
	struct dev_pm_domain___107 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___29 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___79 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___107 *class;
	const struct attribute_group___106 **groups;
	void (*release)(struct device___107 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___107 {
	struct dev_pm_ops___107 ops;
	void (*detach)(struct device___107 *, bool);
	int (*activate)(struct device___107 *);
	void (*sync)(struct device___107 *);
	void (*dismiss)(struct device___107 *);
};

struct bus_type___107 {
	const char *name;
	const char *dev_name;
	struct device___107 *dev_root;
	const struct attribute_group___106 **bus_groups;
	const struct attribute_group___106 **dev_groups;
	const struct attribute_group___106 **drv_groups;
	int (*match)(struct device___107 *, struct device_driver___107 *);
	int (*uevent)(struct device___107 *, struct kobj_uevent_env *);
	int (*probe)(struct device___107 *);
	int (*remove)(struct device___107 *);
	void (*shutdown)(struct device___107 *);
	int (*online)(struct device___107 *);
	int (*offline)(struct device___107 *);
	int (*suspend)(struct device___107 *, pm_message_t);
	int (*resume)(struct device___107 *);
	int (*num_vf)(struct device___107 *);
	int (*dma_configure)(struct device___107 *);
	const struct dev_pm_ops___107 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___107 {
	const char *name;
	struct bus_type___107 *bus;
	struct module___99 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___107 *);
	int (*remove)(struct device___107 *);
	void (*shutdown)(struct device___107 *);
	int (*suspend)(struct device___107 *, pm_message_t);
	int (*resume)(struct device___107 *);
	const struct attribute_group___106 **groups;
	const struct dev_pm_ops___107 *pm;
	void (*coredump)(struct device___107 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___107 {
	const char *name;
	const struct attribute_group___106 **groups;
	int (*uevent)(struct device___107 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___107 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___107 *);
	const struct dev_pm_ops___107 *pm;
};

struct class___107 {
	const char *name;
	struct module___99 *owner;
	const struct attribute_group___106 **class_groups;
	const struct attribute_group___106 **dev_groups;
	struct kobject___110 *dev_kobj;
	int (*dev_uevent)(struct device___107 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___107 *, umode_t *);
	void (*class_release)(struct class___107 *);
	void (*dev_release)(struct device___107 *);
	int (*shutdown_pre)(struct device___107 *);
	const struct kobj_ns_type_operations___5 *ns_type;
	const void * (*namespace)(struct device___107 *);
	const struct dev_pm_ops___107 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___29 {
	void * (*alloc)(struct device___107 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___107 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___107 *, struct vm_area_struct___116 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___107 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___107 *, struct page___116 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___107 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___107 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___107 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___107 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___107 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___107 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___107 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___107 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___107 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___107 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___107 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___107 *, u64);
	u64 (*get_required_mask)(struct device___107 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___79;

struct fwnode_handle___79 {
	struct fwnode_handle___79 *secondary;
	const struct fwnode_operations___79 *ops;
};

typedef void compound_page_dtor___113(struct page___116 *);

struct fwnode_reference_args___79;

struct fwnode_endpoint___79;

struct fwnode_operations___79 {
	struct fwnode_handle___79 * (*get)(struct fwnode_handle___79 *);
	void (*put)(struct fwnode_handle___79 *);
	bool (*device_is_available)(const struct fwnode_handle___79 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___79 *, const struct device___107 *);
	bool (*property_present)(const struct fwnode_handle___79 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___79 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___79 *, const char *, const char **, size_t);
	struct fwnode_handle___79 * (*get_parent)(const struct fwnode_handle___79 *);
	struct fwnode_handle___79 * (*get_next_child_node)(const struct fwnode_handle___79 *, struct fwnode_handle___79 *);
	struct fwnode_handle___79 * (*get_named_child_node)(const struct fwnode_handle___79 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___79 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___79 *);
	struct fwnode_handle___79 * (*graph_get_next_endpoint)(const struct fwnode_handle___79 *, struct fwnode_handle___79 *);
	struct fwnode_handle___79 * (*graph_get_remote_endpoint)(const struct fwnode_handle___79 *);
	struct fwnode_handle___79 * (*graph_get_port_parent)(struct fwnode_handle___79 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___79 *, struct fwnode_endpoint___79 *);
};

struct fwnode_endpoint___79 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___79 *local_fwnode;
};

struct fwnode_reference_args___79 {
	struct fwnode_handle___79 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___26;

struct pipe_buffer___26 {
	struct page___116 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___26 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___26 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___26 *, struct pipe_buffer___26 *);
	void (*release)(struct pipe_inode_info___26 *, struct pipe_buffer___26 *);
	int (*steal)(struct pipe_inode_info___26 *, struct pipe_buffer___26 *);
	union {
		bool (*get)(struct pipe_inode_info___26 *, struct pipe_buffer___26 *);
		struct {
			void (*get)(struct pipe_inode_info___26 *, struct pipe_buffer___26 *);
		} __UNIQUE_ID_rh_kabi_hide21;
		union {		};
	};
};

struct nf_bridge_info___13 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___13 = 0,
		BRNF_PROTO_8021Q___13 = 1,
		BRNF_PROTO_PPPOE___13 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___18 *physindev;
	struct net_device___18 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___13(struct sk_buff___17 **);

typedef struct {
	struct net___23 *net;
} possible_net_t___14;

struct net_device_ops___13;

struct ethtool_ops___13;

struct xfrmdev_ops___13;

struct tlsdev_ops___13;

struct header_ops___13;

struct netdev_rx_queue___13;

struct mini_Qdisc___12;

struct netdev_queue___13;

struct Qdisc___12;

struct rtnl_link_ops___12;

struct dcbnl_rtnl_ops___13;

struct net_device___18 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___13 *netdev_ops;
	const struct ethtool_ops___13 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___2 *l3mdev_ops;
	const struct ndisc_ops___2 *ndisc_ops;
	const struct xfrmdev_ops___13 *xfrmdev_ops;
	const struct tlsdev_ops___13 *tlsdev_ops;
	const struct header_ops___13 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___109 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___2 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___13 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___12 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___13 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___12 *miniq_ingress;
	struct netdev_queue___13 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___13 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___12 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___12 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___13 = 0,
		NETREG_REGISTERED___13 = 1,
		NETREG_UNREGISTERING___13 = 2,
		NETREG_UNREGISTERED___13 = 3,
		NETREG_RELEASED___13 = 4,
		NETREG_DUMMY___13 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___13 = 0,
		RTNL_LINK_INITIALIZING___13 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___18 *);
	struct netpoll_info *npinfo;
	possible_net_t___14 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___107 dev;
	const struct attribute_group___106 *sysfs_groups[4];
	const struct attribute_group___106 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___12 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___13 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide37;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct sk_buff_head___14 {
	struct sk_buff___17 *next;
	struct sk_buff___17 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct kernel_param_ops___96 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___96 *);
	int (*get)(char *, const struct kernel_param___96 *);
	void (*free)(void *);
};

struct kparam_array___96;

struct kernel_param___96 {
	const char *name;
	struct module___99 *mod;
	const struct kernel_param_ops___96 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___96 *arr;
	};
};

struct kparam_array___96 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___96 *ops;
	void *elem;
};

struct module_attribute___96 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___96 *, struct module_kobject___96 *, char *);
	ssize_t (*store)(struct module_attribute___96 *, struct module_kobject___96 *, const char *, size_t);
	void (*setup)(struct module___99 *, const char *);
	int (*test)(struct module___99 *);
	void (*free)(struct module___99 *);
};

struct ethtool_ops___13 {
	int (*get_settings)(struct net_device___18 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___18 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___18 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___18 *);
	void (*get_regs)(struct net_device___18 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___18 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___18 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___18 *);
	void (*set_msglevel)(struct net_device___18 *, u32);
	int (*nway_reset)(struct net_device___18 *);
	u32 (*get_link)(struct net_device___18 *);
	int (*get_eeprom_len)(struct net_device___18 *);
	int (*get_eeprom)(struct net_device___18 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___18 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___18 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___18 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___18 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___18 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___18 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___18 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___18 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___18 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___18 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___18 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___18 *);
	void (*complete)(struct net_device___18 *);
	u32 (*get_priv_flags)(struct net_device___18 *);
	int (*set_priv_flags)(struct net_device___18 *, u32);
	int (*get_sset_count)(struct net_device___18 *, int);
	int (*get_rxnfc)(struct net_device___18 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___18 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___18 *, struct ethtool_flash *);
	int (*reset)(struct net_device___18 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___18 *);
	u32 (*get_rxfh_indir_size)(struct net_device___18 *);
	int (*get_rxfh)(struct net_device___18 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___18 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___18 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___18 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___18 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___18 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___18 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___18 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___18 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___18 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___18 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___18 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___18 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___18 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___18 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___18 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___18 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___18 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___18 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___18 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___18 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___18 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	int (*get_fecparam)(struct net_device___18 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___18 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___18 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___18 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___18 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___13;

struct inet_frags___13 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___13 *, const void *);
	void (*destructor)(struct inet_frag_queue___13 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___13 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___17 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___17 *fragments_tail;
	struct sk_buff___17 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___13 *net;
	struct callback_head rcu;
};

struct ucounts___96 {
	struct hlist_node node;
	struct user_namespace___96 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_prog_aux___12;

struct bpf_prog___12 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___12 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

typedef int (*key_restrict_link_func_t___111)(struct key___111 *, const struct key_type *, const union key_payload *, struct key___111 *);

struct key_restriction___111;

struct key___111 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___116 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___111 *restrict_link;
};

struct key_restriction___111 {
	key_restrict_link_func_t___111 check;
	struct key___111 *key;
	struct key_type *keytype;
};

struct seq_operations___104 {
	void * (*start)(struct seq_file___106 *, loff_t *);
	void (*stop)(struct seq_file___106 *, void *);
	void * (*next)(struct seq_file___106 *, void *, loff_t *);
	int (*show)(struct seq_file___106 *, void *);
};

struct pernet_operations___13 {
	struct list_head list;
	int (*init)(struct net___23 *);
	void (*exit)(struct net___23 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___13 {
	int (*ieee_getets)(struct net_device___18 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___18 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___18 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___18 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___18 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___18 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___18 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___18 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___18 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___18 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___18 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___18 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___18 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___18 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___18 *);
	u8 (*setstate)(struct net_device___18 *, u8);
	void (*getpermhwaddr)(struct net_device___18 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___18 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___18 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___18 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___18 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___18 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___18 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___18 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___18 *, int, u8 *);
	void (*setpfccfg)(struct net_device___18 *, int, u8);
	void (*getpfccfg)(struct net_device___18 *, int, u8 *);
	u8 (*setall)(struct net_device___18 *);
	u8 (*getcap)(struct net_device___18 *, int, u8 *);
	int (*getnumtcs)(struct net_device___18 *, int, u8 *);
	int (*setnumtcs)(struct net_device___18 *, int, u8);
	u8 (*getpfcstate)(struct net_device___18 *);
	void (*setpfcstate)(struct net_device___18 *, u8);
	void (*getbcncfg)(struct net_device___18 *, int, u32 *);
	void (*setbcncfg)(struct net_device___18 *, int, u32);
	void (*getbcnrp)(struct net_device___18 *, int, u8 *);
	void (*setbcnrp)(struct net_device___18 *, int, u8);
	int (*setapp)(struct net_device___18 *, u8, u16, u8);
	int (*getapp)(struct net_device___18 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___18 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___18 *, int, u8);
	u8 (*getdcbx)(struct net_device___18 *);
	u8 (*setdcbx)(struct net_device___18 *, u8);
	int (*peer_getappinfo)(struct net_device___18 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___18 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___18 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___18 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___18 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___18 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___92 {
	refcount_t count;
	struct ns_common___7 ns;
	struct user_namespace___96 *user_ns;
	struct ucounts___96 *ucounts;
	struct css_set___92 *root_cset;
};

struct bpf_map___92;

struct bpf_map_ops___92 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___92 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___92 *, struct file___116 *);
	void (*map_free)(struct bpf_map___92 *);
	int (*map_get_next_key)(struct bpf_map___92 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___92 *);
	void * (*map_lookup_elem)(struct bpf_map___92 *, void *);
	int (*map_update_elem)(struct bpf_map___92 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___92 *, void *);
	int (*map_push_elem)(struct bpf_map___92 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___92 *, void *);
	int (*map_peek_elem)(struct bpf_map___92 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___92 *, struct file___116 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___92 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___92 *, void *, struct seq_file___106 *);
	int (*map_check_btf)(const struct bpf_map___92 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___92 {
	const struct bpf_map_ops___92 *ops;
	struct bpf_map___92 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___111 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___13;

struct bpf_map_dev_ops___13 {
	int (*map_get_next_key)(struct bpf_offloaded_map___13 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___13 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___13 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___13 *, void *);
};

struct bpf_offloaded_map___13 {
	struct bpf_map___92 map;
	struct net_device___18 *netdev;
	const struct bpf_map_dev_ops___13 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___12 {
	int (*test_run)(struct bpf_prog___12 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___12 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___12 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___12 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___12 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___12 *, u32 *);
};

struct bpf_prog_offload_ops___12 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___12 *);
	int (*translate)(struct bpf_prog___12 *);
	void (*destroy)(struct bpf_prog___12 *);
};

struct bpf_prog_offload___12 {
	struct bpf_prog___12 *prog;
	struct net_device___18 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___12 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___12 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___12 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___12 *ops;
	struct bpf_map___92 **used_maps;
	struct bpf_prog___12 *prog;
	struct user_struct___111 *user;
	u64 load_time;
	struct bpf_map___92 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___12 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___12 {
	struct bpf_prog___12 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___12 {
	struct callback_head rcu;
	struct bpf_prog_array_item___12 items[0];
};

struct cgroup_bpf___12 {
	struct bpf_prog_array___12 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___12 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___92;

typedef void (*kthread_work_func_t___92)(struct kthread_work___92 *);

struct kthread_worker___92;

struct kthread_work___92 {
	struct list_head node;
	kthread_work_func_t___92 func;
	struct kthread_worker___92 *worker;
	int canceling;
};

struct kthread_worker___92 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___116 *task;
	struct kthread_work___92 *current_work;
};

struct kthread_delayed_work___92 {
	struct kthread_work___92 work;
	struct timer_list timer;
};

struct psi_group___92 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___92 *poll_kworker;
	struct kthread_delayed_work___92 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___92 {
	struct kernfs_node___112 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___92;

struct cgroup_subsys_state___92 {
	struct cgroup___92 *cgroup;
	struct cgroup_subsys___92 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___92 *parent;
};

struct cgroup_root___92;

struct cgroup_rstat_cpu___92;

struct cgroup___92 {
	struct cgroup_subsys_state___92 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___112 *kn;
	struct cgroup_file___92 procs_file;
	struct cgroup_file___92 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___92 *subsys[13];
	struct cgroup_root___92 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___92 *dom_cgrp;
	struct cgroup_rstat_cpu___92 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___12 bpf;
	atomic_t congestion_count;
	struct cgroup___92 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___92 psi;
	int ancestor_ids[0];
};

struct cftype___92;

struct cgroup_subsys___92 {
	struct cgroup_subsys_state___92 * (*css_alloc)(struct cgroup_subsys_state___92 *);
	int (*css_online)(struct cgroup_subsys_state___92 *);
	void (*css_offline)(struct cgroup_subsys_state___92 *);
	void (*css_released)(struct cgroup_subsys_state___92 *);
	void (*css_free)(struct cgroup_subsys_state___92 *);
	void (*css_reset)(struct cgroup_subsys_state___92 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___92 *, int);
	int (*css_extra_stat_show)(struct seq_file___106 *, struct cgroup_subsys_state___92 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___116 *);
	void (*cancel_fork)(struct task_struct___116 *);
	void (*fork)(struct task_struct___116 *);
	void (*exit)(struct task_struct___116 *);
	void (*free)(struct task_struct___116 *);
	void (*bind)(struct cgroup_subsys_state___92 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___92 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___92 *dfl_cftypes;
	struct cftype___92 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___92 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___92 *updated_children;
	struct cgroup___92 *updated_next;
};

struct cgroup_root___92 {
	struct kernfs_root___112 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___92 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___92 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___92 *ss;
	struct list_head node;
	struct kernfs_ops___112 *kf_ops;
	int (*open)(struct kernfs_open_file___112 *);
	void (*release)(struct kernfs_open_file___112 *);
	u64 (*read_u64)(struct cgroup_subsys_state___92 *, struct cftype___92 *);
	s64 (*read_s64)(struct cgroup_subsys_state___92 *, struct cftype___92 *);
	int (*seq_show)(struct seq_file___106 *, void *);
	void * (*seq_start)(struct seq_file___106 *, loff_t *);
	void * (*seq_next)(struct seq_file___106 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___106 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___92 *, struct cftype___92 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___92 *, struct cftype___92 *, s64);
	ssize_t (*write)(struct kernfs_open_file___112 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___112 *, struct poll_table_struct___6 *);
};

struct xdp_rxq_info___13 {
	struct net_device___18 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___13 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___18 *dev_rx;
};

struct netlink_callback___13 {
	struct sk_buff___17 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___13 *);
	int (*dump)(struct sk_buff___17 *, struct netlink_callback___13 *);
	int (*done)(struct netlink_callback___13 *);
	void *data;
	struct module___99 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___13 {
	int (*create)(struct sk_buff___17 *, struct net_device___18 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___17 *, unsigned char *);
	int (*cache)(const struct neighbour___2 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___18 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___13 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___13 *, int);
	int poll_owner;
	struct net_device___18 *dev;
	struct sk_buff___17 *gro_list;
	struct sk_buff___17 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___13 {
	struct net_device___18 *dev;
	struct Qdisc___12 *qdisc;
	struct Qdisc___12 *qdisc_sleeping;
	struct kobject___110 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___18 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___12 {
	struct sk_buff___17 *head;
	struct sk_buff___17 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___12;

struct Qdisc___12 {
	int (*enqueue)(struct sk_buff___17 *, struct Qdisc___12 *, struct sk_buff___17 **);
	struct sk_buff___17 * (*dequeue)(struct Qdisc___12 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___12 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___13 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___14 gso_skb;
	struct qdisc_skb_head___12 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___12 *next_sched;
	struct sk_buff_head___14 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___13 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___110 kobj;
	struct net_device___18 *dev;
	long: 64;
	struct xdp_rxq_info___13 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___13)(struct net_device___18 *, struct sk_buff___17 *, struct net_device___18 *);

struct netdev_bpf___13 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___12 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___12 *prog;
			const struct bpf_prog_offload_ops___12 *ops;
		} verifier;
		struct {
			struct bpf_prog___12 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___13 *offmap;
		};
		struct {
			struct xdp_umem *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___13 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___17 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___13 {
	int (*tls_dev_add)(struct net_device___18 *, struct sock *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___18 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___18 *, struct sock *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___13 {
	int (*ndo_init)(struct net_device___18 *);
	void (*ndo_uninit)(struct net_device___18 *);
	int (*ndo_open)(struct net_device___18 *);
	int (*ndo_stop)(struct net_device___18 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___17 *, struct net_device___18 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___17 *, struct net_device___18 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___18 *, struct sk_buff___17 *, struct net_device___18 *, select_queue_fallback_t___13);
	void (*ndo_change_rx_flags)(struct net_device___18 *, int);
	void (*ndo_set_rx_mode)(struct net_device___18 *);
	int (*ndo_set_mac_address)(struct net_device___18 *, void *);
	int (*ndo_validate_addr)(struct net_device___18 *);
	int (*ndo_do_ioctl)(struct net_device___18 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___18 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___18 *, int);
	int (*ndo_neigh_setup)(struct net_device___18 *, struct neigh_parms___3 *);
	void (*ndo_tx_timeout)(struct net_device___18 *);
	void (*ndo_get_stats64)(struct net_device___18 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___18 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___18 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___18 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___18 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___18 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___18 *);
	int (*ndo_netpoll_setup)(struct net_device___18 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___18 *);
	int (*ndo_set_vf_mac)(struct net_device___18 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___18 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___18 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___18 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___18 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___18 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___18 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___18 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___18 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___18 *, int, struct sk_buff___17 *);
	int (*ndo_set_vf_guid)(struct net_device___18 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___18 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___18 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___18 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___18 *, const struct sk_buff___17 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___18 *, struct net_device___18 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___18 *, struct net_device___18 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___18 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___18 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___18 *, struct neighbour___2 *);
	void (*ndo_neigh_destroy)(struct net_device___18 *, struct neighbour___2 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___18 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___18 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___18 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___17 *, struct netlink_callback___13 *, struct net_device___18 *, struct net_device___18 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___18 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___18 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide35;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___17 *, u32, u32, struct net_device___18 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___18 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___18 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___18 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___18 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___18 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___18 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___18 *, struct net_device___18 *);
	void (*ndo_dfwd_del_station)(struct net_device___18 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___18 *);
	int (*ndo_set_tx_maxrate)(struct net_device___18 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___18 *);
	int (*ndo_change_proto_down)(struct net_device___18 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___18 *, struct sk_buff___17 *);
	void (*ndo_set_rx_headroom)(struct net_device___18 *, int);
	int (*ndo_bpf)(struct net_device___18 *, struct netdev_bpf___13 *);
	int (*ndo_xdp_xmit)(struct net_device___18 *, int, struct xdp_frame___13 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___18 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___18 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide36;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct tcf_proto___12;

struct mini_Qdisc___12 {
	struct tcf_proto___12 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___12 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___18 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___23 *, struct net_device___18 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___18 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___18 *, struct list_head *);
	size_t (*get_size)(const struct net_device___18 *);
	int (*fill_info)(struct sk_buff___17 *, const struct net_device___18 *);
	size_t (*get_xstats_size)(const struct net_device___18 *);
	int (*fill_xstats)(struct sk_buff___17 *, const struct net_device___18 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___18 *, struct net_device___18 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___18 *, const struct net_device___18 *);
	int (*fill_slave_info)(struct sk_buff___17 *, const struct net_device___18 *, const struct net_device___18 *);
	struct net___23 * (*get_link_net)(const struct net_device___18 *);
	size_t (*get_linkxstats_size)(const struct net_device___18 *, int);
	int (*fill_linkxstats)(struct sk_buff___17 *, const struct net_device___18 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___13 {
	struct list_head poll_list;
	struct sk_buff_head___14 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___13 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___12 *output_queue;
	struct Qdisc___12 **output_queue_tailp;
	struct sk_buff___17 *completion_queue;
	struct sk_buff_head___14 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___13 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___14 input_pkt_queue;
	struct napi_struct___13 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct gnet_dump___12 {
	spinlock_t *lock;
	struct sk_buff___17 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___12;

struct Qdisc_ops___12 {
	struct Qdisc_ops___12 *next;
	const struct Qdisc_class_ops___12 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___17 *, struct Qdisc___12 *, struct sk_buff___17 **);
	struct sk_buff___17 * (*dequeue)(struct Qdisc___12 *);
	struct sk_buff___17 * (*peek)(struct Qdisc___12 *);
	int (*init)(struct Qdisc___12 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___12 *);
	void (*destroy)(struct Qdisc___12 *);
	int (*change)(struct Qdisc___12 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___12 *);
	int (*change_tx_queue_len)(struct Qdisc___12 *, unsigned int);
	int (*dump)(struct Qdisc___12 *, struct sk_buff___17 *);
	int (*dump_stats)(struct Qdisc___12 *, struct gnet_dump___12 *);
	void (*ingress_block_set)(struct Qdisc___12 *, u32);
	void (*egress_block_set)(struct Qdisc___12 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___12 *);
	u32 (*egress_block_get)(struct Qdisc___12 *);
	struct module___99 *owner;
};

struct tcf_block___12;

struct Qdisc_class_ops___12 {
	unsigned int flags;
	struct netdev_queue___13 * (*select_queue)(struct Qdisc___12 *, struct tcmsg *);
	int (*graft)(struct Qdisc___12 *, long unsigned int, struct Qdisc___12 *, struct Qdisc___12 **, struct netlink_ext_ack *);
	struct Qdisc___12 * (*leaf)(struct Qdisc___12 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___12 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___12 *, u32);
	int (*change)(struct Qdisc___12 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___12 *, long unsigned int);
	void (*walk)(struct Qdisc___12 *, struct qdisc_walker *);
	struct tcf_block___12 * (*tcf_block)(struct Qdisc___12 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___12 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___12 *, long unsigned int);
	int (*dump)(struct Qdisc___12 *, long unsigned int, struct sk_buff___17 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___12 *, long unsigned int, struct gnet_dump___12 *);
};

struct tcf_chain___12;

struct tcf_block___12 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___23 *net;
	struct Qdisc___12 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___12 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___12;

struct tcf_proto_ops___12;

struct tcf_proto___12 {
	struct tcf_proto___12 *next;
	void *root;
	int (*classify)(struct sk_buff___17 *, const struct tcf_proto___12 *, struct tcf_result___12 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___12 *ops;
	struct tcf_chain___12 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___12 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___12 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___12 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___17 *, const struct tcf_proto___12 *, struct tcf_result___12 *);
	int (*init)(struct tcf_proto___12 *);
	void (*destroy)(struct tcf_proto___12 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___12 *, u32);
	void (*put)(struct tcf_proto___12 *, void *);
	int (*change)(struct net___23 *, struct sk_buff___17 *, struct tcf_proto___12 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___12 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___12 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___12 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___23 *, struct tcf_chain___12 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___23 *, struct tcf_proto___12 *, void *, struct sk_buff___17 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___17 *, struct net___23 *, void *);
	struct module___99 *owner;
	int flags;
};

struct tcf_chain___12 {
	struct mutex filter_chain_lock;
	struct tcf_proto___12 *filter_chain;
	struct list_head list;
	struct tcf_block___12 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___12 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct bpf_redirect_info___12 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___92 *map;
	struct bpf_map___92 *map_to_flush;
	u32 kern_flags;
};

enum bpf_type {
	BPF_TYPE_UNSPEC = 0,
	BPF_TYPE_PROG = 1,
	BPF_TYPE_MAP = 2,
};

struct map_iter {
	void *key;
	bool done;
};

enum {
	OPT_MODE = 0,
	OPT_ERR = 1,
};

struct bpf_mount_opts {
	umode_t mode;
};

struct pcpu_freelist_node;

struct pcpu_freelist_head {
	struct pcpu_freelist_node *first;
	raw_spinlock_t lock;
};

struct pcpu_freelist_node {
	struct pcpu_freelist_node *next;
};

struct pcpu_freelist {
	struct pcpu_freelist_head *freelist;
};

struct bpf_lru_node {
	struct list_head list;
	u16 cpu;
	u8 type;
	u8 ref;
};

struct bpf_lru_list {
	struct list_head lists[3];
	unsigned int counts[2];
	struct list_head *next_inactive_rotation;
	raw_spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_lru_locallist {
	struct list_head lists[2];
	u16 next_steal;
	raw_spinlock_t lock;
};

struct bpf_common_lru {
	struct bpf_lru_list lru_list;
	struct bpf_lru_locallist *local_list;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef bool (*del_from_htab_func)(void *, struct bpf_lru_node *);

struct bpf_lru {
	union {
		struct bpf_common_lru common_lru;
		struct bpf_lru_list *percpu_lru;
	};
	del_from_htab_func del_from_htab;
	void *del_arg;
	unsigned int hash_offset;
	unsigned int nr_scans;
	bool percpu;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bucket {
	struct hlist_nulls_head head;
	raw_spinlock_t lock;
};

struct htab_elem;

struct bpf_htab {
	struct bpf_map___85 map;
	struct bucket *buckets;
	void *elems;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	union {
		struct pcpu_freelist freelist;
		struct bpf_lru lru;
	};
	struct htab_elem **extra_elems;
	atomic_t count;
	u32 n_buckets;
	u32 elem_size;
	u32 hashrnd;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct htab_elem {
	union {
		struct hlist_nulls_node hash_node;
		struct {
			void *padding;
			union {
				struct bpf_htab *htab;
				struct pcpu_freelist_node fnode;
			};
		};
	};
	union {
		struct callback_head rcu;
		struct bpf_lru_node lru_node;
	};
	u32 hash;
	int: 32;
	char key[0];
};

struct module___100;

struct file___117;

struct kiocb___117;

struct iov_iter___46;

struct vm_area_struct___117;

struct inode___118;

struct file_lock___117;

struct page___117;

struct pipe_inode_info___27;

struct seq_file___107;

struct file_operations___117 {
	struct module___100 *owner;
	loff_t (*llseek)(struct file___117 *, loff_t, int);
	ssize_t (*read)(struct file___117 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___117 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___117 *, struct iov_iter___46 *);
	ssize_t (*write_iter)(struct kiocb___117 *, struct iov_iter___46 *);
	int (*iopoll)(struct kiocb___117 *, bool);
	int (*iterate)(struct file___117 *, struct dir_context *);
	int (*iterate_shared)(struct file___117 *, struct dir_context *);
	__poll_t (*poll)(struct file___117 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___117 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___117 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___117 *, struct vm_area_struct___117 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___118 *, struct file___117 *);
	int (*flush)(struct file___117 *, fl_owner_t);
	int (*release)(struct inode___118 *, struct file___117 *);
	int (*fsync)(struct file___117 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___117 *, int);
	int (*lock)(struct file___117 *, int, struct file_lock___117 *);
	ssize_t (*sendpage)(struct file___117 *, struct page___117 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___117 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___117 *, int, struct file_lock___117 *);
	ssize_t (*splice_write)(struct pipe_inode_info___27 *, struct file___117 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___117 *, loff_t *, struct pipe_inode_info___27 *, size_t, unsigned int);
	int (*setlease)(struct file___117 *, long int, struct file_lock___117 **, void **);
	long int (*fallocate)(struct file___117 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___107 *, struct file___117 *);
	ssize_t (*copy_file_range)(struct file___117 *, loff_t, struct file___117 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___117 *, loff_t, struct file___117 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___117 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___116 {
	u64 seqnum;
	struct vm_area_struct___117 *vmas[4];
};

struct page_frag___116 {
	struct page___117 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___74;

struct debug_info___74 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___74 *hbp_break[16];
	struct perf_event___74 *hbp_watch[16];
};

struct thread_struct___74 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___74 debug;
	long: 64;
};

struct mm_struct___116;

struct pid___98;

struct cred___112;

struct nsproxy___109;

struct signal_struct___106;

struct css_set___93;

struct perf_event_context___74;

struct vm_struct___86;

struct task_struct___117 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___117 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___116 *mm;
	struct mm_struct___116 *active_mm;
	struct vmacache___116 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___117 *real_parent;
	struct task_struct___117 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___117 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___98 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___98 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___98 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___112 *ptracer_cred;
	const struct cred___112 *real_cred;
	const struct cred___112 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___109 *nsproxy;
	struct signal_struct___106 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___117 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___17 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___93 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___74 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___27 *splice_pipe;
	struct page_frag___116 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___117 *oom_reaper_list;
	struct vm_struct___86 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___74 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___74 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___117 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___74)(struct perf_event___74 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___74;

struct fasync_struct___116;

struct pid_namespace___98;

struct bpf_prog___13;

struct perf_cgroup___74;

struct perf_event___74 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___74 *group_leader;
	struct pmu___74 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___74 hw;
	struct perf_event_context___74 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___74 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___117 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___116 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___74 *);
	struct callback_head callback_head;
	struct pid_namespace___98 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___74 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___74 orig_overflow_handler;
	struct bpf_prog___13 *prog;
	struct trace_event_call___5 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___74 *cgrp;
	struct list_head sb_list;
};

struct secondary_data___117 {
	void *stack;
	struct task_struct___117 *task;
	long int status;
};

struct dentry___117;

struct path___116 {
	struct vfsmount *mnt;
	struct dentry___117 *dentry;
};

struct fown_struct___98 {
	rwlock_t lock;
	struct pid___98 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct address_space___116;

struct file___117 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___116 f_path;
	struct inode___118 *f_inode;
	const struct file_operations___117 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___98 f_owner;
	const struct cred___112 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___116 *f_mapping;
	errseq_t f_wb_err;
};

struct bpf_map___93;

struct bpf_map_ops___93 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___93 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___93 *, struct file___117 *);
	void (*map_free)(struct bpf_map___93 *);
	int (*map_get_next_key)(struct bpf_map___93 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___93 *);
	void * (*map_lookup_elem)(struct bpf_map___93 *, void *);
	int (*map_update_elem)(struct bpf_map___93 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___93 *, void *);
	int (*map_push_elem)(struct bpf_map___93 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___93 *, void *);
	int (*map_peek_elem)(struct bpf_map___93 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___93 *, struct file___117 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___93 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___93 *, void *, struct seq_file___107 *);
	int (*map_check_btf)(const struct bpf_map___93 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct user_struct___112;

struct bpf_map___93 {
	const struct bpf_map_ops___93 *ops;
	struct bpf_map___93 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___112 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct seq_operations___105;

struct seq_file___107 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___105 *op;
	int poll_event;
	const struct file___117 *file;
	void *private;
};

struct key___112;

struct user_struct___112 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___112 *uid_keyring;
	struct key___112 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bpf_offloaded_map___14;

struct bpf_map_dev_ops___14 {
	int (*map_get_next_key)(struct bpf_offloaded_map___14 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___14 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___14 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___14 *, void *);
};

struct net_device___19;

struct bpf_offloaded_map___14 {
	struct bpf_map___93 map;
	struct net_device___19 *netdev;
	const struct bpf_map_dev_ops___14 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___18;

typedef rx_handler_result_t rx_handler_func_t___14(struct sk_buff___18 **);

struct net___24;

typedef struct {
	struct net___24 *net;
} possible_net_t___15;

struct kset___110;

struct kobj_type___110;

struct kernfs_node___113;

struct kobject___111 {
	const char *name;
	struct list_head entry;
	struct kobject___111 *parent;
	struct kset___110 *kset;
	struct kobj_type___110 *ktype;
	struct kernfs_node___113 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___108;

struct dev_pm_info___108 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___108 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___108;

struct bus_type___108;

struct device_driver___108;

struct dev_pm_domain___108;

struct dma_map_ops___30;

struct fwnode_handle___80;

struct class___108;

struct attribute_group___107;

struct device___108 {
	struct device___108 *parent;
	struct device_private *p;
	struct kobject___111 kobj;
	const char *init_name;
	const struct device_type___108 *type;
	struct mutex mutex;
	struct bus_type___108 *bus;
	struct device_driver___108 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___108 power;
	struct dev_pm_domain___108 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___30 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___80 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___108 *class;
	const struct attribute_group___107 **groups;
	void (*release)(struct device___108 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct net_device_ops___14;

struct ethtool_ops___14;

struct xfrmdev_ops___14;

struct tlsdev_ops___14;

struct header_ops___14;

struct netdev_rx_queue___14;

struct mini_Qdisc___13;

struct netdev_queue___14;

struct Qdisc___13;

struct rtnl_link_ops___13;

struct dcbnl_rtnl_ops___14;

struct net_device___19 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___14 *netdev_ops;
	const struct ethtool_ops___14 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___2 *l3mdev_ops;
	const struct ndisc_ops___2 *ndisc_ops;
	const struct xfrmdev_ops___14 *xfrmdev_ops;
	const struct tlsdev_ops___14 *tlsdev_ops;
	const struct header_ops___14 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___110 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___2 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___14 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___13 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___14 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___13 *miniq_ingress;
	struct netdev_queue___14 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___14 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___13 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___13 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___14 = 0,
		NETREG_REGISTERED___14 = 1,
		NETREG_UNREGISTERING___14 = 2,
		NETREG_UNREGISTERED___14 = 3,
		NETREG_RELEASED___14 = 4,
		NETREG_DUMMY___14 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___14 = 0,
		RTNL_LINK_INITIALIZING___14 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___19 *);
	struct netpoll_info *npinfo;
	possible_net_t___15 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___108 dev;
	const struct attribute_group___107 *sysfs_groups[4];
	const struct attribute_group___107 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___13 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___14 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide35;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct bpf_prog_ops___13 {
	int (*test_run)(struct bpf_prog___13 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_aux___13;

struct bpf_prog___13 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___13 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

struct bpf_verifier_ops___13 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___13 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___13 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___13 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___13 *, u32 *);
};

struct bpf_prog_offload_ops___13 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___13 *);
	int (*translate)(struct bpf_prog___13 *);
	void (*destroy)(struct bpf_prog___13 *);
};

struct bpf_prog_offload___13 {
	struct bpf_prog___13 *prog;
	struct net_device___19 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___13 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___13 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___13 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___13 *ops;
	struct bpf_map___93 **used_maps;
	struct bpf_prog___13 *prog;
	struct user_struct___112 *user;
	u64 load_time;
	struct bpf_map___93 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___13 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_array___3 {
	struct bpf_map___93 map;
	u32 elem_size;
	u32 index_mask;
	enum bpf_prog_type owner_prog_type;
	bool owner_jited;
	union {
		char value[0];
		void *ptrs[0];
		void *pptrs[0];
	};
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_event_entry___2 {
	struct perf_event___74 *event;
	struct file___117 *perf_file;
	struct file___117 *map_file;
	struct callback_head rcu;
};

struct bpf_prog_array_item___13 {
	struct bpf_prog___13 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___13 {
	struct callback_head rcu;
	struct bpf_prog_array_item___13 items[0];
};

typedef struct page___117 *pgtable_t___116;

struct dev_pagemap___114;

struct page___117 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___116 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___117 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___116 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___116 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___114 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___116;

struct lruvec___116 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___116 *pgdat;
};

struct zone___116 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___116 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___116 {
	struct zone___116 *zone;
	int zone_idx;
};

struct zonelist___116 {
	struct zoneref___116 _zonerefs[25];
};

struct pglist_data___116 {
	struct zone___116 node_zones[3];
	struct zonelist___116 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___117 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___117 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___116 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___117 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___117 *owner;
};

struct blocking_notifier_head___116 {
	struct rw_semaphore___117 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___114;

struct vm_area_struct___117 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___117 *vm_next;
	struct vm_area_struct___117 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___116 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___114 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___117 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___116;

struct user_namespace___97;

struct mm_struct___116 {
	struct {
		struct vm_area_struct___117 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___117 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___117 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___116 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___117 *owner;
		struct user_namespace___97 *user_ns;
		struct file___117 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___116 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___116;

struct address_space___116 {
	struct inode___118 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___117 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___116 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___114)(struct vm_area_struct___117 *, long unsigned int, const struct page___117 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___114)(struct page___117 *, void *);

struct dev_pagemap___114 {
	dev_page_fault_t___114 page_fault;
	dev_page_free_t___114 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___108 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct vm_fault___114;

struct vm_operations_struct___114 {
	void (*open)(struct vm_area_struct___117 *);
	void (*close)(struct vm_area_struct___117 *);
	int (*split)(struct vm_area_struct___117 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___117 *);
	vm_fault_t (*fault)(struct vm_fault___114 *);
	vm_fault_t (*huge_fault)(struct vm_fault___114 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___114 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___117 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___114 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___114 *);
	int (*access)(struct vm_area_struct___117 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___117 *);
	int (*set_policy)(struct vm_area_struct___117 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___117 *, long unsigned int);
	struct page___117 * (*find_special_page)(struct vm_area_struct___117 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___116 {
	struct task_struct___117 *task;
	struct core_thread___116 *next;
};

struct core_state___116 {
	atomic_t nr_threads;
	struct core_thread___116 dumper;
	struct completion startup;
};

struct ucounts___97;

struct user_namespace___97 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___97 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___7 ns;
	long unsigned int flags;
	struct key___112 *persistent_keyring_register;
	struct rw_semaphore___117 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___97 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___114 {
	struct vm_area_struct___117 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___117 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___117 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___116 prealloc_pte;
};

struct upid___98 {
	int nr;
	struct pid_namespace___98 *ns;
};

struct pid_namespace___98 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___117 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___98 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___117 *proc_self;
	struct dentry___117 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___97 *user_ns;
	struct ucounts___97 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___7 ns;
};

struct pid___98 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___98 numbers[1];
};

struct cred___112 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___112 *session_keyring;
	struct key___112 *process_keyring;
	struct key___112 *thread_keyring;
	struct key___112 *request_key_auth;
	void *security;
	struct user_struct___112 *user;
	struct user_namespace___97 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___93;

struct nsproxy___109 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___98 *pid_ns_for_children;
	struct net___24 *net_ns;
	struct cgroup_namespace___93 *cgroup_ns;
};

struct signal_struct___106 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___117 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___117 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___98 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___98 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___116 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___98 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___93;

struct cgroup___93;

struct css_set___93 {
	struct cgroup_subsys_state___93 *subsys[13];
	refcount_t refcount;
	struct css_set___93 *dom_cset;
	struct cgroup___93 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___93 *mg_src_cgrp;
	struct cgroup___93 *mg_dst_cgrp;
	struct css_set___93 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___74 {
	struct pmu___74 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___117 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___74 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___27;

struct pipe_inode_info___27 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___117 *tmp_page;
	struct fasync_struct___116 *fasync_readers;
	struct fasync_struct___116 *fasync_writers;
	struct pipe_buffer___27 *bufs;
	struct user_struct___112 *user;
};

struct vm_struct___86 {
	struct vm_struct___86 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___117 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___106 {
	struct task_struct___117 task;
	long unsigned int stack[8192];
};

struct dentry_operations___116;

struct super_block___117;

struct dentry___117 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___117 *d_parent;
	struct qstr d_name;
	struct inode___118 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___116 *d_op;
	struct super_block___117 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___116;

struct block_device___117;

struct inode___118 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___116 *i_op;
	struct super_block___117 *i_sb;
	struct address_space___116 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___117 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___117 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___116 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___27 *i_pipe;
		struct block_device___117 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___116 {
	int (*d_revalidate)(struct dentry___117 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___117 *, unsigned int);
	int (*d_hash)(const struct dentry___117 *, struct qstr *);
	int (*d_compare)(const struct dentry___117 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___117 *);
	int (*d_init)(struct dentry___117 *);
	void (*d_release)(struct dentry___117 *);
	void (*d_prune)(struct dentry___117 *);
	void (*d_iput)(struct dentry___117 *, struct inode___118 *);
	char * (*d_dname)(struct dentry___117 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___116 *);
	int (*d_manage)(const struct path___116 *, bool);
	struct dentry___117 * (*d_real)(struct dentry___117 *, const struct inode___118 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___116;

struct mem_dqinfo___116 {
	struct quota_format_type___116 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___116;

struct quota_info___116 {
	unsigned int flags;
	struct rw_semaphore___117 dqio_sem;
	struct inode___118 *files[3];
	struct mem_dqinfo___116 info[3];
	const struct quota_format_ops___116 *ops[3];
};

struct rcuwait___116 {
	struct task_struct___117 *task;
};

struct percpu_rw_semaphore___116 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___117 rw_sem;
	struct rcuwait___116 writer;
	int readers_block;
};

struct sb_writers___116 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___116 rw_sem[3];
};

struct file_system_type___116;

struct super_operations___116;

struct dquot_operations___116;

struct quotactl_ops___116;

struct super_block___117 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___116 *s_type;
	const struct super_operations___116 *s_op;
	const struct dquot_operations___116 *dq_op;
	const struct quotactl_ops___116 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___117 *s_root;
	struct rw_semaphore___117 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___117 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___116 s_dquot;
	struct sb_writers___116 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___116 *s_d_op;
	int cleancache_poolid;
	struct shrinker___36 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___97 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___117 {
	struct file___117 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___117 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___117 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___117 *ia_file;
};

struct dquot___116 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___117 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___116 {
	int qf_fmt_id;
	const struct quota_format_ops___116 *qf_ops;
	struct module___100 *qf_owner;
	struct quota_format_type___116 *qf_next;
};

struct quota_format_ops___116 {
	int (*check_quota_file)(struct super_block___117 *, int);
	int (*read_file_info)(struct super_block___117 *, int);
	int (*write_file_info)(struct super_block___117 *, int);
	int (*free_file_info)(struct super_block___117 *, int);
	int (*read_dqblk)(struct dquot___116 *);
	int (*commit_dqblk)(struct dquot___116 *);
	int (*release_dqblk)(struct dquot___116 *);
	int (*get_next_id)(struct super_block___117 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___116 {
	int (*write_dquot)(struct dquot___116 *);
	struct dquot___116 * (*alloc_dquot)(struct super_block___117 *, int);
	void (*destroy_dquot)(struct dquot___116 *);
	int (*acquire_dquot)(struct dquot___116 *);
	int (*release_dquot)(struct dquot___116 *);
	int (*mark_dirty)(struct dquot___116 *);
	int (*write_info)(struct super_block___117 *, int);
	qsize_t * (*get_reserved_space)(struct inode___118 *);
	int (*get_projid)(struct inode___118 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___118 *, qsize_t *);
	int (*get_next_id)(struct super_block___117 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___116 {
	int (*quota_on)(struct super_block___117 *, int, int, const struct path___116 *);
	int (*quota_off)(struct super_block___117 *, int);
	int (*quota_enable)(struct super_block___117 *, unsigned int);
	int (*quota_disable)(struct super_block___117 *, unsigned int);
	int (*quota_sync)(struct super_block___117 *, int);
	int (*set_info)(struct super_block___117 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___117 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___117 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___117 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___117 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___117 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___97 {
	struct kobject___111 kobj;
	struct module___100 *mod;
	struct kobject___111 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___97 {
	struct module___100 *mod;
	struct latch_tree_node node;
};

struct module_layout___97 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___97 mtn;
};

struct module_attribute___97;

struct kernel_param___97;

struct module___100 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___97 mkobj;
	struct module_attribute___97 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___111 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___97 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___97 core_layout;
	struct module_layout___97 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___116 {
	int (*writepage)(struct page___117 *, struct writeback_control___3 *);
	int (*readpage)(struct file___117 *, struct page___117 *);
	int (*writepages)(struct address_space___116 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___117 *);
	int (*readpages)(struct file___117 *, struct address_space___116 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___117 *, struct address_space___116 *, loff_t, unsigned int, unsigned int, struct page___117 **, void **);
	int (*write_end)(struct file___117 *, struct address_space___116 *, loff_t, unsigned int, unsigned int, struct page___117 *, void *);
	sector_t (*bmap)(struct address_space___116 *, sector_t);
	void (*invalidatepage)(struct page___117 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___117 *, gfp_t);
	void (*freepage)(struct page___117 *);
	ssize_t (*direct_IO)(struct kiocb___117 *, struct iov_iter___46 *);
	int (*migratepage)(struct address_space___116 *, struct page___117 *, struct page___117 *, enum migrate_mode);
	bool (*isolate_page)(struct page___117 *, isolate_mode_t);
	void (*putback_page)(struct page___117 *);
	int (*launder_page)(struct page___117 *);
	int (*is_partially_uptodate)(struct page___117 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___117 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___116 *, struct page___117 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___117 *, sector_t *);
	void (*swap_deactivate)(struct file___117 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct iov_iter___46 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___3 *bvec;
		struct pipe_inode_info___27 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___117 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___118 *bd_inode;
	struct super_block___117 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___117 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___116 {
	struct dentry___117 * (*lookup)(struct inode___118 *, struct dentry___117 *, unsigned int);
	const char * (*get_link)(struct dentry___117 *, struct inode___118 *, struct delayed_call *);
	int (*permission)(struct inode___118 *, int);
	struct posix_acl * (*get_acl)(struct inode___118 *, int);
	int (*readlink)(struct dentry___117 *, char *, int);
	int (*create)(struct inode___118 *, struct dentry___117 *, umode_t, bool);
	int (*link)(struct dentry___117 *, struct inode___118 *, struct dentry___117 *);
	int (*unlink)(struct inode___118 *, struct dentry___117 *);
	int (*symlink)(struct inode___118 *, struct dentry___117 *, const char *);
	int (*mkdir)(struct inode___118 *, struct dentry___117 *, umode_t);
	int (*rmdir)(struct inode___118 *, struct dentry___117 *);
	int (*mknod)(struct inode___118 *, struct dentry___117 *, umode_t, dev_t);
	int (*rename)(struct inode___118 *, struct dentry___117 *, struct inode___118 *, struct dentry___117 *, unsigned int);
	int (*setattr)(struct dentry___117 *, struct iattr___117 *);
	int (*getattr)(const struct path___116 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___117 *, char *, size_t);
	int (*fiemap)(struct inode___118 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___118 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___118 *, struct dentry___117 *, struct file___117 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___118 *, struct dentry___117 *, umode_t);
	int (*set_acl)(struct inode___118 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___116 {
	void (*fl_copy_lock)(struct file_lock___117 *, struct file_lock___117 *);
	void (*fl_release_private)(struct file_lock___117 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___116;

struct file_lock___117 {
	struct file_lock___117 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___117 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___116 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___116 *fl_ops;
	const struct lock_manager_operations___116 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___116 {
	int (*lm_compare_owner)(struct file_lock___117 *, struct file_lock___117 *);
	long unsigned int (*lm_owner_key)(struct file_lock___117 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___117 *);
	int (*lm_grant)(struct file_lock___117 *, int);
	bool (*lm_break)(struct file_lock___117 *);
	int (*lm_change)(struct file_lock___117 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___117 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___116 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___116 *fa_next;
	struct file___117 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___116 {
	const char *name;
	int fs_flags;
	struct dentry___117 * (*mount)(struct file_system_type___116 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___117 *);
	struct module___100 *owner;
	struct file_system_type___116 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___116 {
	struct inode___118 * (*alloc_inode)(struct super_block___117 *);
	void (*destroy_inode)(struct inode___118 *);
	void (*dirty_inode)(struct inode___118 *, int);
	int (*write_inode)(struct inode___118 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___118 *);
	void (*evict_inode)(struct inode___118 *);
	void (*put_super)(struct super_block___117 *);
	int (*sync_fs)(struct super_block___117 *, int);
	int (*freeze_super)(struct super_block___117 *);
	int (*freeze_fs)(struct super_block___117 *);
	int (*thaw_super)(struct super_block___117 *);
	int (*unfreeze_fs)(struct super_block___117 *);
	int (*statfs)(struct dentry___117 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___117 *, int *, char *);
	void (*umount_begin)(struct super_block___117 *);
	int (*show_options)(struct seq_file___107 *, struct dentry___117 *);
	int (*show_devname)(struct seq_file___107 *, struct dentry___117 *);
	int (*show_path)(struct seq_file___107 *, struct dentry___117 *);
	int (*show_stats)(struct seq_file___107 *, struct dentry___117 *);
	ssize_t (*quota_read)(struct super_block___117 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___117 *, int, const char *, size_t, loff_t);
	struct dquot___116 ** (*get_dquots)(struct inode___118 *);
	int (*bdev_try_to_free_page)(struct super_block___117 *, struct page___117 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___117 *, struct shrink_control___36 *);
	long int (*free_cached_objects)(struct super_block___117 *, struct shrink_control___36 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_attribute___111 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___111 *, struct kobj_attribute___111 *, char *);
	ssize_t (*store)(struct kobject___111 *, struct kobj_attribute___111 *, const char *, size_t);
};

typedef void compound_page_dtor___114(struct page___117 *);

struct nf_bridge_info___14;

struct sk_buff___18 {
	union {
		struct {
			struct sk_buff___18 *next;
			struct sk_buff___18 *prev;
			union {
				struct net_device___19 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___8 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___18 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___14 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___14;

struct netns_frags___14 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___14 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv4___14 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct sock *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock **tcp_sk;
	struct netns_frags___14 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct dst_ops___22 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___22 *);
	struct dst_entry___2 * (*check)(struct dst_entry___2 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___2 *);
	unsigned int (*mtu)(const struct dst_entry___2 *);
	u32 * (*cow_metrics)(struct dst_entry___2 *, long unsigned int);
	void (*destroy)(struct dst_entry___2 *);
	void (*ifdown)(struct dst_entry___2 *, struct net_device___19 *, int);
	struct dst_entry___2 * (*negative_advice)(struct dst_entry___2 *);
	void (*link_failure)(struct sk_buff___18 *);
	void (*update_pmtu)(struct dst_entry___2 *, struct sock *, struct sk_buff___18 *, u32);
	void (*redirect)(struct dst_entry___2 *, struct sock *, struct sk_buff___18 *);
	int (*local_out)(struct net___24 *, struct sock *, struct sk_buff___18 *);
	struct neighbour___2 * (*neigh_lookup)(const struct dst_entry___2 *, struct sk_buff___18 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___2 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___21 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___14 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___22 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct sock *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops *notifier_ops;
	struct fib_notifier_ops *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_nf_frag___14 {
	struct netns_frags___14 frags;
};

struct netns_xfrm___21 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___22 xfrm4_dst_ops;
	struct dst_ops___22 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct net___24 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___97 *user_ns;
	struct ucounts___97 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___7 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___19 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___14 ipv4;
	struct netns_ipv6___21 ipv6;
	struct netns_sctp___5 sctp;
	struct netns_nf nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___14 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock *nfnl;
	struct sock *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___21 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___13 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kernfs_root___113;

struct kernfs_elem_dir___113 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___113 *root;
};

struct kernfs_syscall_ops___113;

struct kernfs_root___113 {
	struct kernfs_node___113 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___113 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___113 {
	struct kernfs_node___113 *target_kn;
};

struct kernfs_ops___113;

struct kernfs_elem_attr___113 {
	const struct kernfs_ops___113 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___113 *notify_next;
};

struct kernfs_node___113 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___113 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___113 dir;
		struct kernfs_elem_symlink___113 symlink;
		struct kernfs_elem_attr___113 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___113;

struct kernfs_ops___113 {
	int (*open)(struct kernfs_open_file___113 *);
	void (*release)(struct kernfs_open_file___113 *);
	int (*seq_show)(struct seq_file___107 *, void *);
	void * (*seq_start)(struct seq_file___107 *, loff_t *);
	void * (*seq_next)(struct seq_file___107 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___107 *, void *);
	ssize_t (*read)(struct kernfs_open_file___113 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___113 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___113 *, struct vm_area_struct___117 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___113 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___113 {
	int (*remount_fs)(struct kernfs_root___113 *, int *, char *);
	int (*show_options)(struct seq_file___107 *, struct kernfs_root___113 *);
	int (*mkdir)(struct kernfs_node___113 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___113 *);
	int (*rename)(struct kernfs_node___113 *, struct kernfs_node___113 *, const char *);
	int (*show_path)(struct seq_file___107 *, struct kernfs_node___113 *, struct kernfs_root___113 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___113 {
	struct kernfs_node___113 *kn;
	struct file___117 *file;
	struct seq_file___107 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___114 *vm_ops;
};

struct bin_attribute___107;

struct attribute_group___107 {
	const char *name;
	umode_t (*is_visible)(struct kobject___111 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___111 *, struct bin_attribute___107 *, int);
	struct attribute **attrs;
	struct bin_attribute___107 **bin_attrs;
};

struct bin_attribute___107 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___117 *, struct kobject___111 *, struct bin_attribute___107 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___117 *, struct kobject___111 *, struct bin_attribute___107 *, char *, loff_t, size_t);
	int (*mmap)(struct file___117 *, struct kobject___111 *, struct bin_attribute___107 *, struct vm_area_struct___117 *);
};

struct sysfs_ops___110 {
	ssize_t (*show)(struct kobject___111 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___111 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___110;

struct kset___110 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___111 kobj;
	const struct kset_uevent_ops___110 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___110 {
	void (*release)(struct kobject___111 *);
	const struct sysfs_ops___110 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___5 * (*child_ns_type)(struct kobject___111 *);
	const void * (*namespace)(struct kobject___111 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___110 {
	int (* const filter)(struct kset___110 *, struct kobject___111 *);
	const char * (* const name)(struct kset___110 *, struct kobject___111 *);
	int (* const uevent)(struct kset___110 *, struct kobject___111 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___108 {
	int (*prepare)(struct device___108 *);
	void (*complete)(struct device___108 *);
	int (*suspend)(struct device___108 *);
	int (*resume)(struct device___108 *);
	int (*freeze)(struct device___108 *);
	int (*thaw)(struct device___108 *);
	int (*poweroff)(struct device___108 *);
	int (*restore)(struct device___108 *);
	int (*suspend_late)(struct device___108 *);
	int (*resume_early)(struct device___108 *);
	int (*freeze_late)(struct device___108 *);
	int (*thaw_early)(struct device___108 *);
	int (*poweroff_late)(struct device___108 *);
	int (*restore_early)(struct device___108 *);
	int (*suspend_noirq)(struct device___108 *);
	int (*resume_noirq)(struct device___108 *);
	int (*freeze_noirq)(struct device___108 *);
	int (*thaw_noirq)(struct device___108 *);
	int (*poweroff_noirq)(struct device___108 *);
	int (*restore_noirq)(struct device___108 *);
	int (*runtime_suspend)(struct device___108 *);
	int (*runtime_resume)(struct device___108 *);
	int (*runtime_idle)(struct device___108 *);
};

struct dev_pm_domain___108 {
	struct dev_pm_ops___108 ops;
	void (*detach)(struct device___108 *, bool);
	int (*activate)(struct device___108 *);
	void (*sync)(struct device___108 *);
	void (*dismiss)(struct device___108 *);
};

struct bus_type___108 {
	const char *name;
	const char *dev_name;
	struct device___108 *dev_root;
	const struct attribute_group___107 **bus_groups;
	const struct attribute_group___107 **dev_groups;
	const struct attribute_group___107 **drv_groups;
	int (*match)(struct device___108 *, struct device_driver___108 *);
	int (*uevent)(struct device___108 *, struct kobj_uevent_env *);
	int (*probe)(struct device___108 *);
	int (*remove)(struct device___108 *);
	void (*shutdown)(struct device___108 *);
	int (*online)(struct device___108 *);
	int (*offline)(struct device___108 *);
	int (*suspend)(struct device___108 *, pm_message_t);
	int (*resume)(struct device___108 *);
	int (*num_vf)(struct device___108 *);
	int (*dma_configure)(struct device___108 *);
	const struct dev_pm_ops___108 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___108 {
	const char *name;
	struct bus_type___108 *bus;
	struct module___100 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___108 *);
	int (*remove)(struct device___108 *);
	void (*shutdown)(struct device___108 *);
	int (*suspend)(struct device___108 *, pm_message_t);
	int (*resume)(struct device___108 *);
	const struct attribute_group___107 **groups;
	const struct dev_pm_ops___108 *pm;
	void (*coredump)(struct device___108 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___108 {
	const char *name;
	const struct attribute_group___107 **groups;
	int (*uevent)(struct device___108 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___108 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___108 *);
	const struct dev_pm_ops___108 *pm;
};

struct class___108 {
	const char *name;
	struct module___100 *owner;
	const struct attribute_group___107 **class_groups;
	const struct attribute_group___107 **dev_groups;
	struct kobject___111 *dev_kobj;
	int (*dev_uevent)(struct device___108 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___108 *, umode_t *);
	void (*class_release)(struct class___108 *);
	void (*dev_release)(struct device___108 *);
	int (*shutdown_pre)(struct device___108 *);
	const struct kobj_ns_type_operations___5 *ns_type;
	const void * (*namespace)(struct device___108 *);
	const struct dev_pm_ops___108 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___30 {
	void * (*alloc)(struct device___108 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___108 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___108 *, struct vm_area_struct___117 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___108 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___108 *, struct page___117 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___108 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___108 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___108 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___108 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___108 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___108 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___108 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___108 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___108 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___108 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___108 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___108 *, u64);
	u64 (*get_required_mask)(struct device___108 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___80;

struct fwnode_handle___80 {
	struct fwnode_handle___80 *secondary;
	const struct fwnode_operations___80 *ops;
};

struct fwnode_reference_args___80;

struct fwnode_endpoint___80;

struct fwnode_operations___80 {
	struct fwnode_handle___80 * (*get)(struct fwnode_handle___80 *);
	void (*put)(struct fwnode_handle___80 *);
	bool (*device_is_available)(const struct fwnode_handle___80 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___80 *, const struct device___108 *);
	bool (*property_present)(const struct fwnode_handle___80 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___80 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___80 *, const char *, const char **, size_t);
	struct fwnode_handle___80 * (*get_parent)(const struct fwnode_handle___80 *);
	struct fwnode_handle___80 * (*get_next_child_node)(const struct fwnode_handle___80 *, struct fwnode_handle___80 *);
	struct fwnode_handle___80 * (*get_named_child_node)(const struct fwnode_handle___80 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___80 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___80 *);
	struct fwnode_handle___80 * (*graph_get_next_endpoint)(const struct fwnode_handle___80 *, struct fwnode_handle___80 *);
	struct fwnode_handle___80 * (*graph_get_remote_endpoint)(const struct fwnode_handle___80 *);
	struct fwnode_handle___80 * (*graph_get_port_parent)(struct fwnode_handle___80 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___80 *, struct fwnode_endpoint___80 *);
};

struct fwnode_endpoint___80 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___80 *local_fwnode;
};

struct fwnode_reference_args___80 {
	struct fwnode_handle___80 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___27;

struct pipe_buffer___27 {
	struct page___117 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___27 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___27 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___27 *, struct pipe_buffer___27 *);
	void (*release)(struct pipe_inode_info___27 *, struct pipe_buffer___27 *);
	int (*steal)(struct pipe_inode_info___27 *, struct pipe_buffer___27 *);
	union {
		bool (*get)(struct pipe_inode_info___27 *, struct pipe_buffer___27 *);
		struct {
			void (*get)(struct pipe_inode_info___27 *, struct pipe_buffer___27 *);
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
};

struct nf_bridge_info___14 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___14 = 0,
		BRNF_PROTO_8021Q___14 = 1,
		BRNF_PROTO_PPPOE___14 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___19 *physindev;
	struct net_device___19 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

struct sk_buff_head___15 {
	struct sk_buff___18 *next;
	struct sk_buff___18 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct kernel_param_ops___97 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___97 *);
	int (*get)(char *, const struct kernel_param___97 *);
	void (*free)(void *);
};

struct kparam_array___97;

struct kernel_param___97 {
	const char *name;
	struct module___100 *mod;
	const struct kernel_param_ops___97 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___97 *arr;
	};
};

struct kparam_array___97 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___97 *ops;
	void *elem;
};

struct module_attribute___97 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___97 *, struct module_kobject___97 *, char *);
	ssize_t (*store)(struct module_attribute___97 *, struct module_kobject___97 *, const char *, size_t);
	void (*setup)(struct module___100 *, const char *);
	int (*test)(struct module___100 *);
	void (*free)(struct module___100 *);
};

struct ethtool_ops___14 {
	int (*get_settings)(struct net_device___19 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___19 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___19 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___19 *);
	void (*get_regs)(struct net_device___19 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___19 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___19 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___19 *);
	void (*set_msglevel)(struct net_device___19 *, u32);
	int (*nway_reset)(struct net_device___19 *);
	u32 (*get_link)(struct net_device___19 *);
	int (*get_eeprom_len)(struct net_device___19 *);
	int (*get_eeprom)(struct net_device___19 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___19 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___19 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___19 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___19 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___19 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___19 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___19 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___19 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___19 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___19 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___19 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___19 *);
	void (*complete)(struct net_device___19 *);
	u32 (*get_priv_flags)(struct net_device___19 *);
	int (*set_priv_flags)(struct net_device___19 *, u32);
	int (*get_sset_count)(struct net_device___19 *, int);
	int (*get_rxnfc)(struct net_device___19 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___19 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___19 *, struct ethtool_flash *);
	int (*reset)(struct net_device___19 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___19 *);
	u32 (*get_rxfh_indir_size)(struct net_device___19 *);
	int (*get_rxfh)(struct net_device___19 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___19 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___19 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___19 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___19 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___19 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___19 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___19 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___19 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___19 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___19 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___19 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___19 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___19 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___19 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___19 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___19 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___19 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___19 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___19 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___19 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___19 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	int (*get_fecparam)(struct net_device___19 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___19 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___19 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___19 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___19 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___14;

struct inet_frags___14 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___14 *, const void *);
	void (*destructor)(struct inet_frag_queue___14 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___14 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___18 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___18 *fragments_tail;
	struct sk_buff___18 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___14 *net;
	struct callback_head rcu;
};

struct ucounts___97 {
	struct hlist_node node;
	struct user_namespace___97 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

typedef int (*key_restrict_link_func_t___112)(struct key___112 *, const struct key_type *, const union key_payload *, struct key___112 *);

struct key_restriction___112;

struct key___112 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___117 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___112 *restrict_link;
};

struct key_restriction___112 {
	key_restrict_link_func_t___112 check;
	struct key___112 *key;
	struct key_type *keytype;
};

struct seq_operations___105 {
	void * (*start)(struct seq_file___107 *, loff_t *);
	void (*stop)(struct seq_file___107 *, void *);
	void * (*next)(struct seq_file___107 *, void *, loff_t *);
	int (*show)(struct seq_file___107 *, void *);
};

struct pernet_operations___14 {
	struct list_head list;
	int (*init)(struct net___24 *);
	void (*exit)(struct net___24 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___14 {
	int (*ieee_getets)(struct net_device___19 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___19 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___19 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___19 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___19 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___19 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___19 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___19 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___19 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___19 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___19 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___19 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___19 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___19 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___19 *);
	u8 (*setstate)(struct net_device___19 *, u8);
	void (*getpermhwaddr)(struct net_device___19 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___19 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___19 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___19 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___19 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___19 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___19 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___19 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___19 *, int, u8 *);
	void (*setpfccfg)(struct net_device___19 *, int, u8);
	void (*getpfccfg)(struct net_device___19 *, int, u8 *);
	u8 (*setall)(struct net_device___19 *);
	u8 (*getcap)(struct net_device___19 *, int, u8 *);
	int (*getnumtcs)(struct net_device___19 *, int, u8 *);
	int (*setnumtcs)(struct net_device___19 *, int, u8);
	u8 (*getpfcstate)(struct net_device___19 *);
	void (*setpfcstate)(struct net_device___19 *, u8);
	void (*getbcncfg)(struct net_device___19 *, int, u32 *);
	void (*setbcncfg)(struct net_device___19 *, int, u32);
	void (*getbcnrp)(struct net_device___19 *, int, u8 *);
	void (*setbcnrp)(struct net_device___19 *, int, u8);
	int (*setapp)(struct net_device___19 *, u8, u16, u8);
	int (*getapp)(struct net_device___19 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___19 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___19 *, int, u8);
	u8 (*getdcbx)(struct net_device___19 *);
	u8 (*setdcbx)(struct net_device___19 *, u8);
	int (*peer_getappinfo)(struct net_device___19 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___19 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___19 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___19 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___19 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___19 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___93 {
	refcount_t count;
	struct ns_common___7 ns;
	struct user_namespace___97 *user_ns;
	struct ucounts___97 *ucounts;
	struct css_set___93 *root_cset;
};

struct cgroup_bpf___13 {
	struct bpf_prog_array___13 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___13 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___93;

typedef void (*kthread_work_func_t___93)(struct kthread_work___93 *);

struct kthread_worker___93;

struct kthread_work___93 {
	struct list_head node;
	kthread_work_func_t___93 func;
	struct kthread_worker___93 *worker;
	int canceling;
};

struct kthread_worker___93 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___117 *task;
	struct kthread_work___93 *current_work;
};

struct kthread_delayed_work___93 {
	struct kthread_work___93 work;
	struct timer_list timer;
};

struct psi_group___93 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___93 *poll_kworker;
	struct kthread_delayed_work___93 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___93 {
	struct kernfs_node___113 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___93;

struct cgroup_subsys_state___93 {
	struct cgroup___93 *cgroup;
	struct cgroup_subsys___93 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___93 *parent;
};

struct cgroup_root___93;

struct cgroup_rstat_cpu___93;

struct cgroup___93 {
	struct cgroup_subsys_state___93 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___113 *kn;
	struct cgroup_file___93 procs_file;
	struct cgroup_file___93 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___93 *subsys[13];
	struct cgroup_root___93 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___93 *dom_cgrp;
	struct cgroup_rstat_cpu___93 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___13 bpf;
	atomic_t congestion_count;
	struct cgroup___93 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___93 psi;
	int ancestor_ids[0];
};

struct cftype___93;

struct cgroup_subsys___93 {
	struct cgroup_subsys_state___93 * (*css_alloc)(struct cgroup_subsys_state___93 *);
	int (*css_online)(struct cgroup_subsys_state___93 *);
	void (*css_offline)(struct cgroup_subsys_state___93 *);
	void (*css_released)(struct cgroup_subsys_state___93 *);
	void (*css_free)(struct cgroup_subsys_state___93 *);
	void (*css_reset)(struct cgroup_subsys_state___93 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___93 *, int);
	int (*css_extra_stat_show)(struct seq_file___107 *, struct cgroup_subsys_state___93 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___117 *);
	void (*cancel_fork)(struct task_struct___117 *);
	void (*fork)(struct task_struct___117 *);
	void (*exit)(struct task_struct___117 *);
	void (*free)(struct task_struct___117 *);
	void (*bind)(struct cgroup_subsys_state___93 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___93 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___93 *dfl_cftypes;
	struct cftype___93 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___93 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___93 *updated_children;
	struct cgroup___93 *updated_next;
};

struct cgroup_root___93 {
	struct kernfs_root___113 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___93 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___93 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___93 *ss;
	struct list_head node;
	struct kernfs_ops___113 *kf_ops;
	int (*open)(struct kernfs_open_file___113 *);
	void (*release)(struct kernfs_open_file___113 *);
	u64 (*read_u64)(struct cgroup_subsys_state___93 *, struct cftype___93 *);
	s64 (*read_s64)(struct cgroup_subsys_state___93 *, struct cftype___93 *);
	int (*seq_show)(struct seq_file___107 *, void *);
	void * (*seq_start)(struct seq_file___107 *, loff_t *);
	void * (*seq_next)(struct seq_file___107 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___107 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___93 *, struct cftype___93 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___93 *, struct cftype___93 *, s64);
	ssize_t (*write)(struct kernfs_open_file___113 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___113 *, struct poll_table_struct___6 *);
};

struct xdp_rxq_info___14 {
	struct net_device___19 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___14 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___19 *dev_rx;
};

struct netlink_callback___14 {
	struct sk_buff___18 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___14 *);
	int (*dump)(struct sk_buff___18 *, struct netlink_callback___14 *);
	int (*done)(struct netlink_callback___14 *);
	void *data;
	struct module___100 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___14 {
	int (*create)(struct sk_buff___18 *, struct net_device___19 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___18 *, unsigned char *);
	int (*cache)(const struct neighbour___2 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___19 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___14 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___14 *, int);
	int poll_owner;
	struct net_device___19 *dev;
	struct sk_buff___18 *gro_list;
	struct sk_buff___18 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___14 {
	struct net_device___19 *dev;
	struct Qdisc___13 *qdisc;
	struct Qdisc___13 *qdisc_sleeping;
	struct kobject___111 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___19 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___13 {
	struct sk_buff___18 *head;
	struct sk_buff___18 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___13;

struct Qdisc___13 {
	int (*enqueue)(struct sk_buff___18 *, struct Qdisc___13 *, struct sk_buff___18 **);
	struct sk_buff___18 * (*dequeue)(struct Qdisc___13 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___13 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___14 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___15 gso_skb;
	struct qdisc_skb_head___13 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___13 *next_sched;
	struct sk_buff_head___15 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___14 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___111 kobj;
	struct net_device___19 *dev;
	long: 64;
	struct xdp_rxq_info___14 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___14)(struct net_device___19 *, struct sk_buff___18 *, struct net_device___19 *);

struct netdev_bpf___14 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___13 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___13 *prog;
			const struct bpf_prog_offload_ops___13 *ops;
		} verifier;
		struct {
			struct bpf_prog___13 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___14 *offmap;
		};
		struct {
			struct xdp_umem *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___14 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___18 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___14 {
	int (*tls_dev_add)(struct net_device___19 *, struct sock *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___19 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___19 *, struct sock *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___14 {
	int (*ndo_init)(struct net_device___19 *);
	void (*ndo_uninit)(struct net_device___19 *);
	int (*ndo_open)(struct net_device___19 *);
	int (*ndo_stop)(struct net_device___19 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___18 *, struct net_device___19 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___18 *, struct net_device___19 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___19 *, struct sk_buff___18 *, struct net_device___19 *, select_queue_fallback_t___14);
	void (*ndo_change_rx_flags)(struct net_device___19 *, int);
	void (*ndo_set_rx_mode)(struct net_device___19 *);
	int (*ndo_set_mac_address)(struct net_device___19 *, void *);
	int (*ndo_validate_addr)(struct net_device___19 *);
	int (*ndo_do_ioctl)(struct net_device___19 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___19 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___19 *, int);
	int (*ndo_neigh_setup)(struct net_device___19 *, struct neigh_parms___3 *);
	void (*ndo_tx_timeout)(struct net_device___19 *);
	void (*ndo_get_stats64)(struct net_device___19 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___19 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___19 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___19 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___19 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___19 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___19 *);
	int (*ndo_netpoll_setup)(struct net_device___19 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___19 *);
	int (*ndo_set_vf_mac)(struct net_device___19 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___19 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___19 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___19 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___19 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___19 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___19 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___19 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___19 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___19 *, int, struct sk_buff___18 *);
	int (*ndo_set_vf_guid)(struct net_device___19 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___19 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___19 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___19 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___19 *, const struct sk_buff___18 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___19 *, struct net_device___19 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___19 *, struct net_device___19 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___19 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___19 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___19 *, struct neighbour___2 *);
	void (*ndo_neigh_destroy)(struct net_device___19 *, struct neighbour___2 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___19 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___19 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___19 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___18 *, struct netlink_callback___14 *, struct net_device___19 *, struct net_device___19 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___19 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___19 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___18 *, u32, u32, struct net_device___19 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___19 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___19 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___19 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___19 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___19 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___19 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___19 *, struct net_device___19 *);
	void (*ndo_dfwd_del_station)(struct net_device___19 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___19 *);
	int (*ndo_set_tx_maxrate)(struct net_device___19 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___19 *);
	int (*ndo_change_proto_down)(struct net_device___19 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___19 *, struct sk_buff___18 *);
	void (*ndo_set_rx_headroom)(struct net_device___19 *, int);
	int (*ndo_bpf)(struct net_device___19 *, struct netdev_bpf___14 *);
	int (*ndo_xdp_xmit)(struct net_device___19 *, int, struct xdp_frame___14 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___19 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___19 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct tcf_proto___13;

struct mini_Qdisc___13 {
	struct tcf_proto___13 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___13 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___19 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___24 *, struct net_device___19 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___19 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___19 *, struct list_head *);
	size_t (*get_size)(const struct net_device___19 *);
	int (*fill_info)(struct sk_buff___18 *, const struct net_device___19 *);
	size_t (*get_xstats_size)(const struct net_device___19 *);
	int (*fill_xstats)(struct sk_buff___18 *, const struct net_device___19 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___19 *, struct net_device___19 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___19 *, const struct net_device___19 *);
	int (*fill_slave_info)(struct sk_buff___18 *, const struct net_device___19 *, const struct net_device___19 *);
	struct net___24 * (*get_link_net)(const struct net_device___19 *);
	size_t (*get_linkxstats_size)(const struct net_device___19 *, int);
	int (*fill_linkxstats)(struct sk_buff___18 *, const struct net_device___19 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___14 {
	struct list_head poll_list;
	struct sk_buff_head___15 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___14 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___13 *output_queue;
	struct Qdisc___13 **output_queue_tailp;
	struct sk_buff___18 *completion_queue;
	struct sk_buff_head___15 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___14 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___15 input_pkt_queue;
	struct napi_struct___14 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct gnet_dump___13 {
	spinlock_t *lock;
	struct sk_buff___18 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___13;

struct Qdisc_ops___13 {
	struct Qdisc_ops___13 *next;
	const struct Qdisc_class_ops___13 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___18 *, struct Qdisc___13 *, struct sk_buff___18 **);
	struct sk_buff___18 * (*dequeue)(struct Qdisc___13 *);
	struct sk_buff___18 * (*peek)(struct Qdisc___13 *);
	int (*init)(struct Qdisc___13 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___13 *);
	void (*destroy)(struct Qdisc___13 *);
	int (*change)(struct Qdisc___13 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___13 *);
	int (*change_tx_queue_len)(struct Qdisc___13 *, unsigned int);
	int (*dump)(struct Qdisc___13 *, struct sk_buff___18 *);
	int (*dump_stats)(struct Qdisc___13 *, struct gnet_dump___13 *);
	void (*ingress_block_set)(struct Qdisc___13 *, u32);
	void (*egress_block_set)(struct Qdisc___13 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___13 *);
	u32 (*egress_block_get)(struct Qdisc___13 *);
	struct module___100 *owner;
};

struct tcf_block___13;

struct Qdisc_class_ops___13 {
	unsigned int flags;
	struct netdev_queue___14 * (*select_queue)(struct Qdisc___13 *, struct tcmsg *);
	int (*graft)(struct Qdisc___13 *, long unsigned int, struct Qdisc___13 *, struct Qdisc___13 **, struct netlink_ext_ack *);
	struct Qdisc___13 * (*leaf)(struct Qdisc___13 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___13 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___13 *, u32);
	int (*change)(struct Qdisc___13 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___13 *, long unsigned int);
	void (*walk)(struct Qdisc___13 *, struct qdisc_walker *);
	struct tcf_block___13 * (*tcf_block)(struct Qdisc___13 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___13 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___13 *, long unsigned int);
	int (*dump)(struct Qdisc___13 *, long unsigned int, struct sk_buff___18 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___13 *, long unsigned int, struct gnet_dump___13 *);
};

struct tcf_chain___13;

struct tcf_block___13 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___24 *net;
	struct Qdisc___13 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___13 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___13;

struct tcf_proto_ops___13;

struct tcf_proto___13 {
	struct tcf_proto___13 *next;
	void *root;
	int (*classify)(struct sk_buff___18 *, const struct tcf_proto___13 *, struct tcf_result___13 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___13 *ops;
	struct tcf_chain___13 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___13 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___13 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___13 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___18 *, const struct tcf_proto___13 *, struct tcf_result___13 *);
	int (*init)(struct tcf_proto___13 *);
	void (*destroy)(struct tcf_proto___13 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___13 *, u32);
	void (*put)(struct tcf_proto___13 *, void *);
	int (*change)(struct net___24 *, struct sk_buff___18 *, struct tcf_proto___13 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___13 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___13 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___13 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___24 *, struct tcf_chain___13 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___24 *, struct tcf_proto___13 *, void *, struct sk_buff___18 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___18 *, struct net___24 *, void *);
	struct module___100 *owner;
	int flags;
};

struct tcf_chain___13 {
	struct mutex filter_chain_lock;
	struct tcf_proto___13 *filter_chain;
	struct list_head list;
	struct tcf_block___13 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___13 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct bpf_redirect_info___13 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___93 *map;
	struct bpf_map___93 *map_to_flush;
	u32 kern_flags;
};

struct node___93 {
	struct device___108 dev;
};

struct perf_cpu_context___74;

struct pmu___74 {
	struct list_head entry;
	struct module___100 *module;
	struct device___108 *dev;
	const struct attribute_group___107 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___74 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___74 *);
	void (*pmu_disable)(struct pmu___74 *);
	int (*event_init)(struct perf_event___74 *);
	void (*event_mapped)(struct perf_event___74 *, struct mm_struct___116 *);
	void (*event_unmapped)(struct perf_event___74 *, struct mm_struct___116 *);
	int (*add)(struct perf_event___74 *, int);
	void (*del)(struct perf_event___74 *, int);
	void (*start)(struct perf_event___74 *, int);
	void (*stop)(struct perf_event___74 *, int);
	void (*read)(struct perf_event___74 *);
	void (*start_txn)(struct pmu___74 *, unsigned int);
	int (*commit_txn)(struct pmu___74 *);
	void (*cancel_txn)(struct pmu___74 *);
	int (*event_idx)(struct perf_event___74 *);
	void (*sched_task)(struct perf_event_context___74 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___74 *);
	int (*filter_match)(struct perf_event___74 *);
	int (*check_period)(struct perf_event___74 *, u64);
};

struct perf_cpu_context___74 {
	struct perf_event_context___74 ctx;
	struct perf_event_context___74 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___74 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___74 {
	struct cgroup_subsys_state___93 css;
	struct perf_cgroup_info *info;
};

enum bpf_lru_list_type {
	BPF_LRU_LIST_T_ACTIVE = 0,
	BPF_LRU_LIST_T_INACTIVE = 1,
	BPF_LRU_LIST_T_FREE = 2,
	BPF_LRU_LOCAL_LIST_T_FREE = 3,
	BPF_LRU_LOCAL_LIST_T_PENDING = 4,
};

struct bpf_lpm_trie_key {
	__u32 prefixlen;
	__u8 data[0];
};

struct module___101;

struct file___118;

struct kiocb___118;

struct iov_iter___47;

struct poll_table_struct___79;

struct vm_area_struct___118;

struct inode___119;

struct file_lock___118;

struct page___118;

struct pipe_inode_info___28;

struct seq_file___108;

struct file_operations___118 {
	struct module___101 *owner;
	loff_t (*llseek)(struct file___118 *, loff_t, int);
	ssize_t (*read)(struct file___118 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___118 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___118 *, struct iov_iter___47 *);
	ssize_t (*write_iter)(struct kiocb___118 *, struct iov_iter___47 *);
	int (*iopoll)(struct kiocb___118 *, bool);
	int (*iterate)(struct file___118 *, struct dir_context *);
	int (*iterate_shared)(struct file___118 *, struct dir_context *);
	__poll_t (*poll)(struct file___118 *, struct poll_table_struct___79 *);
	long int (*unlocked_ioctl)(struct file___118 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___118 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___118 *, struct vm_area_struct___118 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___119 *, struct file___118 *);
	int (*flush)(struct file___118 *, fl_owner_t);
	int (*release)(struct inode___119 *, struct file___118 *);
	int (*fsync)(struct file___118 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___118 *, int);
	int (*lock)(struct file___118 *, int, struct file_lock___118 *);
	ssize_t (*sendpage)(struct file___118 *, struct page___118 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___118 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___118 *, int, struct file_lock___118 *);
	ssize_t (*splice_write)(struct pipe_inode_info___28 *, struct file___118 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___118 *, loff_t *, struct pipe_inode_info___28 *, size_t, unsigned int);
	int (*setlease)(struct file___118 *, long int, struct file_lock___118 **, void **);
	long int (*fallocate)(struct file___118 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___108 *, struct file___118 *);
	ssize_t (*copy_file_range)(struct file___118 *, loff_t, struct file___118 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___118 *, loff_t, struct file___118 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___118 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___117 {
	u64 seqnum;
	struct vm_area_struct___118 *vmas[4];
};

struct page_frag___117 {
	struct page___118 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___117;

struct mem_cgroup___37;

struct cred___113;

struct nsproxy___110;

struct signal_struct___107;

struct bio_list___42;

struct backing_dev_info___42;

struct css_set___94;

struct vm_struct___87;

struct task_struct___118 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___118 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___117 *mm;
	struct mm_struct___117 *active_mm;
	struct vmacache___117 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___118 *real_parent;
	struct task_struct___118 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___118 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___37 *active_memcg;
	long int rh_reserved2;
	struct pid___98 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___98 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___98 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___113 *ptracer_cred;
	const struct cred___113 *real_cred;
	const struct cred___113 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___110 *nsproxy;
	struct signal_struct___107 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___118 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___42 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___42 *backing_dev_info;
	struct io_context___17 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___94 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___28 *splice_pipe;
	struct page_frag___117 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___37 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___118 *oom_reaper_list;
	struct vm_struct___87 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___74 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct secondary_data___118 {
	void *stack;
	struct task_struct___118 *task;
	long int status;
};

struct dentry___118;

struct path___117 {
	struct vfsmount *mnt;
	struct dentry___118 *dentry;
};

struct address_space___117;

struct file___118 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___117 f_path;
	struct inode___119 *f_inode;
	const struct file_operations___118 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___98 f_owner;
	const struct cred___113 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___117 *f_mapping;
	errseq_t f_wb_err;
};

struct bpf_map___94;

struct bpf_map_ops___94 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___94 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___94 *, struct file___118 *);
	void (*map_free)(struct bpf_map___94 *);
	int (*map_get_next_key)(struct bpf_map___94 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___94 *);
	void * (*map_lookup_elem)(struct bpf_map___94 *, void *);
	int (*map_update_elem)(struct bpf_map___94 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___94 *, void *);
	int (*map_push_elem)(struct bpf_map___94 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___94 *, void *);
	int (*map_peek_elem)(struct bpf_map___94 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___94 *, struct file___118 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___94 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___94 *, void *, struct seq_file___108 *);
	int (*map_check_btf)(const struct bpf_map___94 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct user_struct___113;

struct bpf_map___94 {
	const struct bpf_map_ops___94 *ops;
	struct bpf_map___94 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___113 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct seq_operations___106;

struct seq_file___108 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___106 *op;
	int poll_event;
	const struct file___118 *file;
	void *private;
};

struct key___113;

struct user_struct___113 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___113 *uid_keyring;
	struct key___113 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bpf_offloaded_map___15;

struct bpf_map_dev_ops___15 {
	int (*map_get_next_key)(struct bpf_offloaded_map___15 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___15 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___15 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___15 *, void *);
};

struct net_device___20;

struct bpf_offloaded_map___15 {
	struct bpf_map___94 map;
	struct net_device___20 *netdev;
	const struct bpf_map_dev_ops___15 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___19;

typedef rx_handler_result_t rx_handler_func_t___15(struct sk_buff___19 **);

struct net___25;

typedef struct {
	struct net___25 *net;
} possible_net_t___16;

struct kset___111;

struct kobj_type___111;

struct kernfs_node___114;

struct kobject___112 {
	const char *name;
	struct list_head entry;
	struct kobject___112 *parent;
	struct kset___111 *kset;
	struct kobj_type___111 *ktype;
	struct kernfs_node___114 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___109;

struct dev_pm_info___109 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___109 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___109;

struct bus_type___109;

struct device_driver___109;

struct dev_pm_domain___109;

struct dma_map_ops___31;

struct fwnode_handle___81;

struct class___109;

struct attribute_group___108;

struct device___109 {
	struct device___109 *parent;
	struct device_private *p;
	struct kobject___112 kobj;
	const char *init_name;
	const struct device_type___109 *type;
	struct mutex mutex;
	struct bus_type___109 *bus;
	struct device_driver___109 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___109 power;
	struct dev_pm_domain___109 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___31 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___81 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___109 *class;
	const struct attribute_group___108 **groups;
	void (*release)(struct device___109 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct net_device_ops___15;

struct ethtool_ops___15;

struct l3mdev_ops___7;

struct ndisc_ops___4;

struct xfrmdev_ops___15;

struct tlsdev_ops___15;

struct header_ops___15;

struct inet6_dev___4;

struct netdev_rx_queue___15;

struct bpf_prog___14;

struct mini_Qdisc___14;

struct netdev_queue___15;

struct Qdisc___14;

struct rtnl_link_ops___14;

struct dcbnl_rtnl_ops___15;

struct net_device___20 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___15 *netdev_ops;
	const struct ethtool_ops___15 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___7 *l3mdev_ops;
	const struct ndisc_ops___4 *ndisc_ops;
	const struct xfrmdev_ops___15 *xfrmdev_ops;
	const struct tlsdev_ops___15 *tlsdev_ops;
	const struct header_ops___15 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___111 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___4 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___15 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___14 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___15 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___14 *miniq_ingress;
	struct netdev_queue___15 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___15 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___14 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___14 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___15 = 0,
		NETREG_REGISTERED___15 = 1,
		NETREG_UNREGISTERING___15 = 2,
		NETREG_UNREGISTERED___15 = 3,
		NETREG_RELEASED___15 = 4,
		NETREG_DUMMY___15 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___15 = 0,
		RTNL_LINK_INITIALIZING___15 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___20 *);
	struct netpoll_info *npinfo;
	possible_net_t___16 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___109 dev;
	const struct attribute_group___108 *sysfs_groups[4];
	const struct attribute_group___108 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___14 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___15 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct bpf_prog_ops___14 {
	int (*test_run)(struct bpf_prog___14 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_aux___14;

struct bpf_prog___14 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___14 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

struct bpf_verifier_ops___14 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___14 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___14 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___14 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___14 *, u32 *);
};

struct bpf_prog_offload_ops___14 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___14 *);
	int (*translate)(struct bpf_prog___14 *);
	void (*destroy)(struct bpf_prog___14 *);
};

struct bpf_prog_offload___14 {
	struct bpf_prog___14 *prog;
	struct net_device___20 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___14 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___14 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___14 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___14 *ops;
	struct bpf_map___94 **used_maps;
	struct bpf_prog___14 *prog;
	struct user_struct___113 *user;
	u64 load_time;
	struct bpf_map___94 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___14 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___14 {
	struct bpf_prog___14 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___14 {
	struct callback_head rcu;
	struct bpf_prog_array_item___14 items[0];
};

typedef struct page___118 *pgtable_t___117;

struct dev_pagemap___115;

struct page___118 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___117 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___118 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___117 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___117 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___115 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___37 *mem_cgroup;
};

struct pglist_data___117;

struct lruvec___117 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___117 *pgdat;
};

struct zone___117 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___117 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___117 {
	struct zone___117 *zone;
	int zone_idx;
};

struct zonelist___117 {
	struct zoneref___117 _zonerefs[25];
};

struct pglist_data___117 {
	struct zone___117 node_zones[3];
	struct zonelist___117 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___118 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___118 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___117 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___118 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___118 *owner;
};

struct blocking_notifier_head___117 {
	struct rw_semaphore___118 rwsem;
	struct notifier_block *head;
};

struct cgroup___94;

struct cgroup_subsys___94;

struct cgroup_subsys_state___94 {
	struct cgroup___94 *cgroup;
	struct cgroup_subsys___94 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___94 *parent;
};

struct mem_cgroup_id___16 {
	int id;
	union {
		refcount_t ref;
		struct {
			atomic_t ref;
		} __UNIQUE_ID_rh_kabi_hide52;
		union {		};
	};
};

struct cgroup_file___94 {
	struct kernfs_node___114 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___37;

struct mem_cgroup___37 {
	struct cgroup_subsys_state___94 css;
	struct mem_cgroup_id___16 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___94 events_file;
	struct cgroup_file___94 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___118 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___37 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct vm_struct___87 {
	struct vm_struct___87 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___118 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct ucounts___98;

struct user_namespace___98 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___98 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___7 ns;
	long unsigned int flags;
	struct key___113 *persistent_keyring_register;
	struct rw_semaphore___118 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___98 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_operations_struct___115;

struct vm_area_struct___118 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___118 *vm_next;
	struct vm_area_struct___118 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___117 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___115 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___118 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___117;

struct mm_struct___117 {
	struct {
		struct vm_area_struct___118 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___118 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___118 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___117 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___118 *owner;
		struct user_namespace___98 *user_ns;
		struct file___118 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___117 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___113 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___113 *session_keyring;
	struct key___113 *process_keyring;
	struct key___113 *thread_keyring;
	struct key___113 *request_key_auth;
	void *security;
	struct user_struct___113 *user;
	struct user_namespace___98 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___94;

struct nsproxy___110 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net___25 *net_ns;
	struct cgroup_namespace___94 *cgroup_ns;
};

struct signal_struct___107 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___118 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___118 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___98 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___98 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___117 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___98 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___42;

struct bio_list___42 {
	struct bio___42 *head;
	struct bio___42 *tail;
};

struct bdi_writeback_congested___42;

struct bdi_writeback___42 {
	struct backing_dev_info___42 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___42 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___94 *memcg_css;
	struct cgroup_subsys_state___94 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___42 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___42 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___109 *dev;
	struct device___109 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___118 *debug_dir;
	struct dentry___118 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___94 {
	struct cgroup_subsys_state___94 *subsys[13];
	refcount_t refcount;
	struct css_set___94 *dom_cset;
	struct cgroup___94 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___94 *mg_src_cgrp;
	struct cgroup___94 *mg_dst_cgrp;
	struct css_set___94 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___117;

struct pipe_buffer___28;

struct pipe_inode_info___28 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___118 *tmp_page;
	struct fasync_struct___117 *fasync_readers;
	struct fasync_struct___117 *fasync_writers;
	struct pipe_buffer___28 *bufs;
	struct user_struct___113 *user;
};

union thread_union___107 {
	struct task_struct___118 task;
	long unsigned int stack[8192];
};

struct address_space_operations___117;

struct address_space___117 {
	struct inode___119 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___118 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___117 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___115)(struct vm_area_struct___118 *, long unsigned int, const struct page___118 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___115)(struct page___118 *, void *);

struct dev_pagemap___115 {
	dev_page_fault_t___115 page_fault;
	dev_page_free_t___115 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___109 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct vm_fault___115;

struct vm_operations_struct___115 {
	void (*open)(struct vm_area_struct___118 *);
	void (*close)(struct vm_area_struct___118 *);
	int (*split)(struct vm_area_struct___118 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___118 *);
	vm_fault_t (*fault)(struct vm_fault___115 *);
	vm_fault_t (*huge_fault)(struct vm_fault___115 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___115 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___118 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___115 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___115 *);
	int (*access)(struct vm_area_struct___118 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___118 *);
	int (*set_policy)(struct vm_area_struct___118 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___118 *, long unsigned int);
	struct page___118 * (*find_special_page)(struct vm_area_struct___118 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___117 {
	struct task_struct___118 *task;
	struct core_thread___117 *next;
};

struct core_state___117 {
	atomic_t nr_threads;
	struct core_thread___117 dumper;
	struct completion startup;
};

struct vm_fault___115 {
	struct vm_area_struct___118 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___118 *cow_page;
	struct mem_cgroup___37 *memcg;
	struct page___118 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___117 prealloc_pte;
};

struct module_kobject___98 {
	struct kobject___112 kobj;
	struct module___101 *mod;
	struct kobject___112 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___98 {
	struct module___101 *mod;
	struct latch_tree_node node;
};

struct module_layout___98 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___98 mtn;
};

struct module_attribute___98;

struct kernel_param___98;

struct module___101 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___98 mkobj;
	struct module_attribute___98 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___112 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___98 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___98 core_layout;
	struct module_layout___98 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide53;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide54;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bio_vec___42 {
	struct page___118 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___47 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___42 *bvec;
		struct pipe_inode_info___28 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct msghdr___6 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___47 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___118 *msg_iocb;
};

struct kiocb___118 {
	struct file___118 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___118 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dentry_operations___117;

struct super_block___118;

struct dentry___118 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___118 *d_parent;
	struct qstr d_name;
	struct inode___119 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___117 *d_op;
	struct super_block___118 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___117;

struct block_device___118;

struct inode___119 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___117 *i_op;
	struct super_block___118 *i_sb;
	struct address_space___117 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___118 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___42 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___118 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___117 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___28 *i_pipe;
		struct block_device___118 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___117 {
	int (*d_revalidate)(struct dentry___118 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___118 *, unsigned int);
	int (*d_hash)(const struct dentry___118 *, struct qstr *);
	int (*d_compare)(const struct dentry___118 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___118 *);
	int (*d_init)(struct dentry___118 *);
	void (*d_release)(struct dentry___118 *);
	void (*d_prune)(struct dentry___118 *);
	void (*d_iput)(struct dentry___118 *, struct inode___119 *);
	char * (*d_dname)(struct dentry___118 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___117 *);
	int (*d_manage)(const struct path___117 *, bool);
	struct dentry___118 * (*d_real)(struct dentry___118 *, const struct inode___119 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___117;

struct mem_dqinfo___117 {
	struct quota_format_type___117 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___117;

struct quota_info___117 {
	unsigned int flags;
	struct rw_semaphore___118 dqio_sem;
	struct inode___119 *files[3];
	struct mem_dqinfo___117 info[3];
	const struct quota_format_ops___117 *ops[3];
};

struct rcuwait___117 {
	struct task_struct___118 *task;
};

struct percpu_rw_semaphore___117 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___118 rw_sem;
	struct rcuwait___117 writer;
	int readers_block;
};

struct sb_writers___117 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___117 rw_sem[3];
};

struct shrink_control___37;

struct shrinker___37 {
	long unsigned int (*count_objects)(struct shrinker___37 *, struct shrink_control___37 *);
	long unsigned int (*scan_objects)(struct shrinker___37 *, struct shrink_control___37 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___117;

struct super_operations___117;

struct dquot_operations___117;

struct quotactl_ops___117;

struct super_block___118 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___117 *s_type;
	const struct super_operations___117 *s_op;
	const struct dquot_operations___117 *dq_op;
	const struct quotactl_ops___117 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___118 *s_root;
	struct rw_semaphore___118 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___118 *s_bdev;
	struct backing_dev_info___42 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___117 s_dquot;
	struct sb_writers___117 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___117 *s_d_op;
	int cleancache_poolid;
	struct shrinker___37 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___98 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___37 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___37 *memcg;
};

struct iattr___118 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___118 *ia_file;
};

struct dquot___117 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___118 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___117 {
	int qf_fmt_id;
	const struct quota_format_ops___117 *qf_ops;
	struct module___101 *qf_owner;
	struct quota_format_type___117 *qf_next;
};

struct quota_format_ops___117 {
	int (*check_quota_file)(struct super_block___118 *, int);
	int (*read_file_info)(struct super_block___118 *, int);
	int (*write_file_info)(struct super_block___118 *, int);
	int (*free_file_info)(struct super_block___118 *, int);
	int (*read_dqblk)(struct dquot___117 *);
	int (*commit_dqblk)(struct dquot___117 *);
	int (*release_dqblk)(struct dquot___117 *);
	int (*get_next_id)(struct super_block___118 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___117 {
	int (*write_dquot)(struct dquot___117 *);
	struct dquot___117 * (*alloc_dquot)(struct super_block___118 *, int);
	void (*destroy_dquot)(struct dquot___117 *);
	int (*acquire_dquot)(struct dquot___117 *);
	int (*release_dquot)(struct dquot___117 *);
	int (*mark_dirty)(struct dquot___117 *);
	int (*write_info)(struct super_block___118 *, int);
	qsize_t * (*get_reserved_space)(struct inode___119 *);
	int (*get_projid)(struct inode___119 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___119 *, qsize_t *);
	int (*get_next_id)(struct super_block___118 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___117 {
	int (*quota_on)(struct super_block___118 *, int, int, const struct path___117 *);
	int (*quota_off)(struct super_block___118 *, int);
	int (*quota_enable)(struct super_block___118 *, unsigned int);
	int (*quota_disable)(struct super_block___118 *, unsigned int);
	int (*quota_sync)(struct super_block___118 *, int);
	int (*set_info)(struct super_block___118 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___118 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___118 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___118 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___118 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___118 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___39;

struct address_space_operations___117 {
	int (*writepage)(struct page___118 *, struct writeback_control___39 *);
	int (*readpage)(struct file___118 *, struct page___118 *);
	int (*writepages)(struct address_space___117 *, struct writeback_control___39 *);
	int (*set_page_dirty)(struct page___118 *);
	int (*readpages)(struct file___118 *, struct address_space___117 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___118 *, struct address_space___117 *, loff_t, unsigned int, unsigned int, struct page___118 **, void **);
	int (*write_end)(struct file___118 *, struct address_space___117 *, loff_t, unsigned int, unsigned int, struct page___118 *, void *);
	sector_t (*bmap)(struct address_space___117 *, sector_t);
	void (*invalidatepage)(struct page___118 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___118 *, gfp_t);
	void (*freepage)(struct page___118 *);
	ssize_t (*direct_IO)(struct kiocb___118 *, struct iov_iter___47 *);
	int (*migratepage)(struct address_space___117 *, struct page___118 *, struct page___118 *, enum migrate_mode);
	bool (*isolate_page)(struct page___118 *, isolate_mode_t);
	void (*putback_page)(struct page___118 *);
	int (*launder_page)(struct page___118 *);
	int (*is_partially_uptodate)(struct page___118 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___118 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___117 *, struct page___118 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___118 *, sector_t *);
	void (*swap_deactivate)(struct file___118 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___39 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___42 *wb;
	struct inode___119 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___118 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___119 *bd_inode;
	struct super_block___118 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___118 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___42 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___117 {
	struct dentry___118 * (*lookup)(struct inode___119 *, struct dentry___118 *, unsigned int);
	const char * (*get_link)(struct dentry___118 *, struct inode___119 *, struct delayed_call *);
	int (*permission)(struct inode___119 *, int);
	struct posix_acl * (*get_acl)(struct inode___119 *, int);
	int (*readlink)(struct dentry___118 *, char *, int);
	int (*create)(struct inode___119 *, struct dentry___118 *, umode_t, bool);
	int (*link)(struct dentry___118 *, struct inode___119 *, struct dentry___118 *);
	int (*unlink)(struct inode___119 *, struct dentry___118 *);
	int (*symlink)(struct inode___119 *, struct dentry___118 *, const char *);
	int (*mkdir)(struct inode___119 *, struct dentry___118 *, umode_t);
	int (*rmdir)(struct inode___119 *, struct dentry___118 *);
	int (*mknod)(struct inode___119 *, struct dentry___118 *, umode_t, dev_t);
	int (*rename)(struct inode___119 *, struct dentry___118 *, struct inode___119 *, struct dentry___118 *, unsigned int);
	int (*setattr)(struct dentry___118 *, struct iattr___118 *);
	int (*getattr)(const struct path___117 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___118 *, char *, size_t);
	int (*fiemap)(struct inode___119 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___119 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___119 *, struct dentry___118 *, struct file___118 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___119 *, struct dentry___118 *, umode_t);
	int (*set_acl)(struct inode___119 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___117 {
	void (*fl_copy_lock)(struct file_lock___118 *, struct file_lock___118 *);
	void (*fl_release_private)(struct file_lock___118 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___117;

struct file_lock___118 {
	struct file_lock___118 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___118 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___117 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___117 *fl_ops;
	const struct lock_manager_operations___117 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___117 {
	int (*lm_compare_owner)(struct file_lock___118 *, struct file_lock___118 *);
	long unsigned int (*lm_owner_key)(struct file_lock___118 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___118 *);
	int (*lm_grant)(struct file_lock___118 *, int);
	bool (*lm_break)(struct file_lock___118 *);
	int (*lm_change)(struct file_lock___118 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___118 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___117 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___117 *fa_next;
	struct file___118 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___117 {
	const char *name;
	int fs_flags;
	struct dentry___118 * (*mount)(struct file_system_type___117 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___118 *);
	struct module___101 *owner;
	struct file_system_type___117 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___117 {
	struct inode___119 * (*alloc_inode)(struct super_block___118 *);
	void (*destroy_inode)(struct inode___119 *);
	void (*dirty_inode)(struct inode___119 *, int);
	int (*write_inode)(struct inode___119 *, struct writeback_control___39 *);
	int (*drop_inode)(struct inode___119 *);
	void (*evict_inode)(struct inode___119 *);
	void (*put_super)(struct super_block___118 *);
	int (*sync_fs)(struct super_block___118 *, int);
	int (*freeze_super)(struct super_block___118 *);
	int (*freeze_fs)(struct super_block___118 *);
	int (*thaw_super)(struct super_block___118 *);
	int (*unfreeze_fs)(struct super_block___118 *);
	int (*statfs)(struct dentry___118 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___118 *, int *, char *);
	void (*umount_begin)(struct super_block___118 *);
	int (*show_options)(struct seq_file___108 *, struct dentry___118 *);
	int (*show_devname)(struct seq_file___108 *, struct dentry___118 *);
	int (*show_path)(struct seq_file___108 *, struct dentry___118 *);
	int (*show_stats)(struct seq_file___108 *, struct dentry___118 *);
	ssize_t (*quota_read)(struct super_block___118 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___118 *, int, const char *, size_t, loff_t);
	struct dquot___117 ** (*get_dquots)(struct inode___119 *);
	int (*bdev_try_to_free_page)(struct super_block___118 *, struct page___118 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___118 *, struct shrink_control___37 *);
	long int (*free_cached_objects)(struct super_block___118 *, struct shrink_control___37 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___78)(struct file___118 *, wait_queue_head_t *, struct poll_table_struct___79 *);

struct poll_table_struct___79 {
	poll_queue_proc___78 _qproc;
	__poll_t _key;
};

typedef void bio_end_io_t___42(struct bio___42 *);

struct bio_integrity_payload___42;

struct bio_set___42;

struct bio___42 {
	struct bio___42 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___42 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___42 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___42 *bi_io_vec;
	struct bio_set___42 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___42 bi_inline_vecs[0];
};

struct socket_wq___6 {
	wait_queue_head_t wait;
	struct fasync_struct___117 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct sock___9;

struct proto_ops___6;

struct socket___6 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___6 *wq;
	struct file___118 *file;
	struct sock___9 *sk;
	const struct proto_ops___6 *ops;
};

struct proto___6;

struct sock_common___6 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___6 *skc_prot;
	possible_net_t___16 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___9 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff_head___16 {
	struct sk_buff___19 *next;
	struct sk_buff___19 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___6;

struct dst_entry___8;

struct sock___9 {
	struct sock_common___6 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___16 sk_error_queue;
	struct sk_buff_head___16 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___19 *head;
		struct sk_buff___19 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___6 *sk_filter;
	union {
		struct socket_wq___6 *sk_wq;
		struct socket_wq___6 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___8 *sk_rx_dst;
	struct dst_entry___8 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___19 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___16 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___117 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___6 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___98 *sk_peer_pid;
	const struct cred___113 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___6 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___37 *sk_memcg;
	void (*sk_state_change)(struct sock___9 *);
	void (*sk_data_ready)(struct sock___9 *);
	void (*sk_write_space)(struct sock___9 *);
	void (*sk_error_report)(struct sock___9 *);
	int (*sk_backlog_rcv)(struct sock___9 *, struct sk_buff___19 *);
	struct sk_buff___19 * (*sk_validate_xmit_skb)(struct sock___9 *, struct net_device___20 *, struct sk_buff___19 *);
	void (*sk_destruct)(struct sock___9 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

typedef int (*sk_read_actor_t___6)(read_descriptor_t *, struct sk_buff___19 *, unsigned int, size_t);

struct proto_ops___6 {
	int family;
	struct module___101 *owner;
	int (*release)(struct socket___6 *);
	int (*bind)(struct socket___6 *, struct sockaddr *, int);
	int (*connect)(struct socket___6 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___6 *, struct socket___6 *);
	int (*accept)(struct socket___6 *, struct socket___6 *, int, bool);
	int (*getname)(struct socket___6 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___118 *, struct socket___6 *, struct poll_table_struct___79 *);
	int (*ioctl)(struct socket___6 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___6 *, int);
	int (*shutdown)(struct socket___6 *, int);
	int (*setsockopt)(struct socket___6 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___6 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___6 *, struct msghdr___6 *, size_t);
	int (*recvmsg)(struct socket___6 *, struct msghdr___6 *, size_t, int);
	int (*mmap)(struct file___118 *, struct socket___6 *, struct vm_area_struct___118 *);
	ssize_t (*sendpage)(struct socket___6 *, struct page___118 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___6 *, loff_t *, struct pipe_inode_info___28 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___9 *, int);
	int (*peek_len)(struct socket___6 *);
	int (*read_sock)(struct sock___9 *, read_descriptor_t *, sk_read_actor_t___6);
	int (*sendpage_locked)(struct sock___9 *, struct page___118 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___9 *, struct msghdr___6 *, size_t);
	int (*set_rcvlowat)(struct sock___9 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct nf_bridge_info___15;

struct sk_buff___19 {
	union {
		struct {
			struct sk_buff___19 *next;
			struct sk_buff___19 *prev;
			union {
				struct net_device___20 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___9 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___19 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___15 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___15;

struct netns_frags___15 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___15 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_rules_ops___6;

struct fib_notifier_ops___6;

struct netns_ipv4___15 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___6 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___9 *fibnl;
	struct sock___9 **icmp_sk;
	struct sock___9 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___9 **tcp_sk;
	struct netns_frags___15 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___6 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___6 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___6 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___8;

struct dst_ops___23 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___23 *);
	struct dst_entry___8 * (*check)(struct dst_entry___8 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___8 *);
	unsigned int (*mtu)(const struct dst_entry___8 *);
	u32 * (*cow_metrics)(struct dst_entry___8 *, long unsigned int);
	void (*destroy)(struct dst_entry___8 *);
	void (*ifdown)(struct dst_entry___8 *, struct net_device___20 *, int);
	struct dst_entry___8 * (*negative_advice)(struct dst_entry___8 *);
	void (*link_failure)(struct sk_buff___19 *);
	void (*update_pmtu)(struct dst_entry___8 *, struct sock___9 *, struct sk_buff___19 *, u32);
	void (*redirect)(struct dst_entry___8 *, struct sock___9 *, struct sk_buff___19 *);
	int (*local_out)(struct net___25 *, struct sock___9 *, struct sk_buff___19 *);
	struct neighbour___8 * (*neigh_lookup)(const struct dst_entry___8 *, struct sk_buff___19 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___8 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___22 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___15 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___23 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___6 *fib6_rules_ops;
	struct sock___9 **icmp_sk;
	struct sock___9 *ndisc_sk;
	struct sock___9 *tcp_sk;
	struct sock___9 *igmp_sk;
	struct sock___9 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___6 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___6 *notifier_ops;
	struct fib_notifier_ops___6 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___6 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___9 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___15 {
	struct netns_frags___15 frags;
};

struct netns_xfrm___22 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___9 *nlsk;
	struct sock___9 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___23 xfrm4_dst_ops;
	struct dst_ops___23 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct net___25 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___98 *user_ns;
	struct ucounts___98 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___7 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___9 *rtnl;
	struct sock___9 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___20 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___15 ipv4;
	struct netns_ipv6___22 ipv6;
	struct netns_sctp___6 sctp;
	struct netns_nf nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___15 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___9 *nfnl;
	struct sock___9 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___22 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___9 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___14 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kernfs_root___114;

struct kernfs_elem_dir___114 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___114 *root;
};

struct kernfs_syscall_ops___114;

struct kernfs_root___114 {
	struct kernfs_node___114 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___114 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___114 {
	struct kernfs_node___114 *target_kn;
};

struct kernfs_ops___114;

struct kernfs_elem_attr___114 {
	const struct kernfs_ops___114 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___114 *notify_next;
};

struct kernfs_node___114 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___114 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___114 dir;
		struct kernfs_elem_symlink___114 symlink;
		struct kernfs_elem_attr___114 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___114;

struct kernfs_ops___114 {
	int (*open)(struct kernfs_open_file___114 *);
	void (*release)(struct kernfs_open_file___114 *);
	int (*seq_show)(struct seq_file___108 *, void *);
	void * (*seq_start)(struct seq_file___108 *, loff_t *);
	void * (*seq_next)(struct seq_file___108 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___108 *, void *);
	ssize_t (*read)(struct kernfs_open_file___114 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___114 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___114 *, struct vm_area_struct___118 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___114 *, struct poll_table_struct___79 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___114 {
	int (*remount_fs)(struct kernfs_root___114 *, int *, char *);
	int (*show_options)(struct seq_file___108 *, struct kernfs_root___114 *);
	int (*mkdir)(struct kernfs_node___114 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___114 *);
	int (*rename)(struct kernfs_node___114 *, struct kernfs_node___114 *, const char *);
	int (*show_path)(struct seq_file___108 *, struct kernfs_node___114 *, struct kernfs_root___114 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___114 {
	struct kernfs_node___114 *kn;
	struct file___118 *file;
	struct seq_file___108 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___115 *vm_ops;
};

struct kobj_ns_type_operations___6 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___9 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___108;

struct attribute_group___108 {
	const char *name;
	umode_t (*is_visible)(struct kobject___112 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___112 *, struct bin_attribute___108 *, int);
	struct attribute **attrs;
	struct bin_attribute___108 **bin_attrs;
};

struct bin_attribute___108 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___118 *, struct kobject___112 *, struct bin_attribute___108 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___118 *, struct kobject___112 *, struct bin_attribute___108 *, char *, loff_t, size_t);
	int (*mmap)(struct file___118 *, struct kobject___112 *, struct bin_attribute___108 *, struct vm_area_struct___118 *);
};

struct sysfs_ops___111 {
	ssize_t (*show)(struct kobject___112 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___112 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___111;

struct kset___111 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___112 kobj;
	const struct kset_uevent_ops___111 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___111 {
	void (*release)(struct kobject___112 *);
	const struct sysfs_ops___111 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___6 * (*child_ns_type)(struct kobject___112 *);
	const void * (*namespace)(struct kobject___112 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___111 {
	int (* const filter)(struct kset___111 *, struct kobject___112 *);
	const char * (* const name)(struct kset___111 *, struct kobject___112 *);
	int (* const uevent)(struct kset___111 *, struct kobject___112 *, struct kobj_uevent_env *);
};

struct kobj_attribute___112 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___112 *, struct kobj_attribute___112 *, char *);
	ssize_t (*store)(struct kobject___112 *, struct kobj_attribute___112 *, const char *, size_t);
};

struct dev_pm_ops___109 {
	int (*prepare)(struct device___109 *);
	void (*complete)(struct device___109 *);
	int (*suspend)(struct device___109 *);
	int (*resume)(struct device___109 *);
	int (*freeze)(struct device___109 *);
	int (*thaw)(struct device___109 *);
	int (*poweroff)(struct device___109 *);
	int (*restore)(struct device___109 *);
	int (*suspend_late)(struct device___109 *);
	int (*resume_early)(struct device___109 *);
	int (*freeze_late)(struct device___109 *);
	int (*thaw_early)(struct device___109 *);
	int (*poweroff_late)(struct device___109 *);
	int (*restore_early)(struct device___109 *);
	int (*suspend_noirq)(struct device___109 *);
	int (*resume_noirq)(struct device___109 *);
	int (*freeze_noirq)(struct device___109 *);
	int (*thaw_noirq)(struct device___109 *);
	int (*poweroff_noirq)(struct device___109 *);
	int (*restore_noirq)(struct device___109 *);
	int (*runtime_suspend)(struct device___109 *);
	int (*runtime_resume)(struct device___109 *);
	int (*runtime_idle)(struct device___109 *);
};

struct dev_pm_domain___109 {
	struct dev_pm_ops___109 ops;
	void (*detach)(struct device___109 *, bool);
	int (*activate)(struct device___109 *);
	void (*sync)(struct device___109 *);
	void (*dismiss)(struct device___109 *);
};

struct bus_type___109 {
	const char *name;
	const char *dev_name;
	struct device___109 *dev_root;
	const struct attribute_group___108 **bus_groups;
	const struct attribute_group___108 **dev_groups;
	const struct attribute_group___108 **drv_groups;
	int (*match)(struct device___109 *, struct device_driver___109 *);
	int (*uevent)(struct device___109 *, struct kobj_uevent_env *);
	int (*probe)(struct device___109 *);
	int (*remove)(struct device___109 *);
	void (*shutdown)(struct device___109 *);
	int (*online)(struct device___109 *);
	int (*offline)(struct device___109 *);
	int (*suspend)(struct device___109 *, pm_message_t);
	int (*resume)(struct device___109 *);
	int (*num_vf)(struct device___109 *);
	int (*dma_configure)(struct device___109 *);
	const struct dev_pm_ops___109 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___109 {
	const char *name;
	struct bus_type___109 *bus;
	struct module___101 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___109 *);
	int (*remove)(struct device___109 *);
	void (*shutdown)(struct device___109 *);
	int (*suspend)(struct device___109 *, pm_message_t);
	int (*resume)(struct device___109 *);
	const struct attribute_group___108 **groups;
	const struct dev_pm_ops___109 *pm;
	void (*coredump)(struct device___109 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___109 {
	const char *name;
	const struct attribute_group___108 **groups;
	int (*uevent)(struct device___109 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___109 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___109 *);
	const struct dev_pm_ops___109 *pm;
};

struct class___109 {
	const char *name;
	struct module___101 *owner;
	const struct attribute_group___108 **class_groups;
	const struct attribute_group___108 **dev_groups;
	struct kobject___112 *dev_kobj;
	int (*dev_uevent)(struct device___109 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___109 *, umode_t *);
	void (*class_release)(struct class___109 *);
	void (*dev_release)(struct device___109 *);
	int (*shutdown_pre)(struct device___109 *);
	const struct kobj_ns_type_operations___6 *ns_type;
	const void * (*namespace)(struct device___109 *);
	const struct dev_pm_ops___109 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___31 {
	void * (*alloc)(struct device___109 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___109 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___109 *, struct vm_area_struct___118 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___109 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___109 *, struct page___118 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___109 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___109 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___109 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___109 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___109 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___109 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___109 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___109 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___109 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___109 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___109 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___109 *, u64);
	u64 (*get_required_mask)(struct device___109 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___81;

struct fwnode_handle___81 {
	struct fwnode_handle___81 *secondary;
	const struct fwnode_operations___81 *ops;
};

typedef void compound_page_dtor___115(struct page___118 *);

struct fwnode_reference_args___81;

struct fwnode_endpoint___81;

struct fwnode_operations___81 {
	struct fwnode_handle___81 * (*get)(struct fwnode_handle___81 *);
	void (*put)(struct fwnode_handle___81 *);
	bool (*device_is_available)(const struct fwnode_handle___81 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___81 *, const struct device___109 *);
	bool (*property_present)(const struct fwnode_handle___81 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___81 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___81 *, const char *, const char **, size_t);
	struct fwnode_handle___81 * (*get_parent)(const struct fwnode_handle___81 *);
	struct fwnode_handle___81 * (*get_next_child_node)(const struct fwnode_handle___81 *, struct fwnode_handle___81 *);
	struct fwnode_handle___81 * (*get_named_child_node)(const struct fwnode_handle___81 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___81 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___81 *);
	struct fwnode_handle___81 * (*graph_get_next_endpoint)(const struct fwnode_handle___81 *, struct fwnode_handle___81 *);
	struct fwnode_handle___81 * (*graph_get_remote_endpoint)(const struct fwnode_handle___81 *);
	struct fwnode_handle___81 * (*graph_get_port_parent)(struct fwnode_handle___81 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___81 *, struct fwnode_endpoint___81 *);
};

struct fwnode_endpoint___81 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___81 *local_fwnode;
};

struct fwnode_reference_args___81 {
	struct fwnode_handle___81 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___28;

struct pipe_buffer___28 {
	struct page___118 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___28 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___28 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___28 *, struct pipe_buffer___28 *);
	void (*release)(struct pipe_inode_info___28 *, struct pipe_buffer___28 *);
	int (*steal)(struct pipe_inode_info___28 *, struct pipe_buffer___28 *);
	union {
		bool (*get)(struct pipe_inode_info___28 *, struct pipe_buffer___28 *);
		struct {
			void (*get)(struct pipe_inode_info___28 *, struct pipe_buffer___28 *);
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
};

struct nf_bridge_info___15 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___15 = 0,
		BRNF_PROTO_8021Q___15 = 1,
		BRNF_PROTO_PPPOE___15 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___20 *physindev;
	struct net_device___20 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

struct ethtool_ops___15 {
	int (*get_settings)(struct net_device___20 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___20 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___20 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___20 *);
	void (*get_regs)(struct net_device___20 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___20 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___20 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___20 *);
	void (*set_msglevel)(struct net_device___20 *, u32);
	int (*nway_reset)(struct net_device___20 *);
	u32 (*get_link)(struct net_device___20 *);
	int (*get_eeprom_len)(struct net_device___20 *);
	int (*get_eeprom)(struct net_device___20 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___20 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___20 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___20 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___20 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___20 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___20 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___20 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___20 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___20 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___20 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___20 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___20 *);
	void (*complete)(struct net_device___20 *);
	u32 (*get_priv_flags)(struct net_device___20 *);
	int (*set_priv_flags)(struct net_device___20 *, u32);
	int (*get_sset_count)(struct net_device___20 *, int);
	int (*get_rxnfc)(struct net_device___20 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___20 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___20 *, struct ethtool_flash *);
	int (*reset)(struct net_device___20 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___20 *);
	u32 (*get_rxfh_indir_size)(struct net_device___20 *);
	int (*get_rxfh)(struct net_device___20 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___20 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___20 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___20 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___20 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___20 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___20 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___20 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___20 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___20 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___20 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___20 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___20 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___20 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___20 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___20 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___20 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___20 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___20 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___20 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___20 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___20 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	int (*get_fecparam)(struct net_device___20 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___20 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___20 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___20 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___20 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___15;

struct inet_frags___15 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___15 *, const void *);
	void (*destructor)(struct inet_frag_queue___15 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___15 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___19 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___19 *fragments_tail;
	struct sk_buff___19 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___15 *net;
	struct callback_head rcu;
};

struct fib_rule___6;

struct fib_lookup_arg___6;

struct fib_rules_ops___6 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___6 *, struct flowi *, int, struct fib_lookup_arg___6 *);
	bool (*suppress)(struct fib_rule___6 *, struct fib_lookup_arg___6 *);
	int (*match)(struct fib_rule___6 *, struct flowi *, int);
	int (*configure)(struct fib_rule___6 *, struct sk_buff___19 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___6 *);
	int (*compare)(struct fib_rule___6 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___6 *, struct sk_buff___19 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___6 *);
	void (*flush_cache)(struct fib_rules_ops___6 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___101 *owner;
	struct net___25 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___6 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___25 *);
	int (*fib_dump)(struct net___25 *, struct notifier_block *);
	struct module___101 *owner;
	struct callback_head rcu;
};

struct dst_entry___8 {
	struct net_device___20 *dev;
	struct dst_ops___23 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___19 *);
	int (*output)(struct net___25 *, struct sock___9 *, struct sk_buff___19 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___7;

struct neigh_parms___8;

struct neigh_ops___7;

struct neighbour___8 {
	struct neighbour___8 *next;
	struct neigh_table___7 *tbl;
	struct neigh_parms___8 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___16 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___8 *, struct sk_buff___19 *);
	const struct neigh_ops___7 *ops;
	struct callback_head rcu;
	struct net_device___20 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct ucounts___98 {
	struct hlist_node node;
	struct user_namespace___98 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

typedef int (*key_restrict_link_func_t___113)(struct key___113 *, const struct key_type *, const union key_payload *, struct key___113 *);

struct key_restriction___113;

struct key___113 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___118 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___113 *restrict_link;
};

struct key_restriction___113 {
	key_restrict_link_func_t___113 check;
	struct key___113 *key;
	struct key_type *keytype;
};

struct seq_operations___106 {
	void * (*start)(struct seq_file___108 *, loff_t *);
	void (*stop)(struct seq_file___108 *, void *);
	void * (*next)(struct seq_file___108 *, void *, loff_t *);
	int (*show)(struct seq_file___108 *, void *);
};

struct pernet_operations___15 {
	struct list_head list;
	int (*init)(struct net___25 *);
	void (*exit)(struct net___25 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___15 {
	int (*ieee_getets)(struct net_device___20 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___20 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___20 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___20 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___20 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___20 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___20 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___20 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___20 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___20 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___20 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___20 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___20 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___20 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___20 *);
	u8 (*setstate)(struct net_device___20 *, u8);
	void (*getpermhwaddr)(struct net_device___20 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___20 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___20 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___20 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___20 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___20 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___20 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___20 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___20 *, int, u8 *);
	void (*setpfccfg)(struct net_device___20 *, int, u8);
	void (*getpfccfg)(struct net_device___20 *, int, u8 *);
	u8 (*setall)(struct net_device___20 *);
	u8 (*getcap)(struct net_device___20 *, int, u8 *);
	int (*getnumtcs)(struct net_device___20 *, int, u8 *);
	int (*setnumtcs)(struct net_device___20 *, int, u8);
	u8 (*getpfcstate)(struct net_device___20 *);
	void (*setpfcstate)(struct net_device___20 *, u8);
	void (*getbcncfg)(struct net_device___20 *, int, u32 *);
	void (*setbcncfg)(struct net_device___20 *, int, u32);
	void (*getbcnrp)(struct net_device___20 *, int, u8 *);
	void (*setbcnrp)(struct net_device___20 *, int, u8);
	int (*setapp)(struct net_device___20 *, u8, u16, u8);
	int (*getapp)(struct net_device___20 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___20 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___20 *, int, u8);
	u8 (*getdcbx)(struct net_device___20 *);
	u8 (*setdcbx)(struct net_device___20 *, u8);
	int (*peer_getappinfo)(struct net_device___20 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___20 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___20 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___20 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___20 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___20 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___94 {
	refcount_t count;
	struct ns_common___7 ns;
	struct user_namespace___98 *user_ns;
	struct ucounts___98 *ucounts;
	struct css_set___94 *root_cset;
};

struct cgroup_bpf___14 {
	struct bpf_prog_array___14 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___14 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___94;

typedef void (*kthread_work_func_t___94)(struct kthread_work___94 *);

struct kthread_worker___94;

struct kthread_work___94 {
	struct list_head node;
	kthread_work_func_t___94 func;
	struct kthread_worker___94 *worker;
	int canceling;
};

struct kthread_worker___94 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___118 *task;
	struct kthread_work___94 *current_work;
};

struct kthread_delayed_work___94 {
	struct kthread_work___94 work;
	struct timer_list timer;
};

struct psi_group___94 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___94 *poll_kworker;
	struct kthread_delayed_work___94 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___94;

struct cgroup_rstat_cpu___94;

struct cgroup___94 {
	struct cgroup_subsys_state___94 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___114 *kn;
	struct cgroup_file___94 procs_file;
	struct cgroup_file___94 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___94 *subsys[13];
	struct cgroup_root___94 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___94 *dom_cgrp;
	struct cgroup_rstat_cpu___94 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___14 bpf;
	atomic_t congestion_count;
	struct cgroup___94 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___94 psi;
	int ancestor_ids[0];
};

struct cftype___94;

struct cgroup_subsys___94 {
	struct cgroup_subsys_state___94 * (*css_alloc)(struct cgroup_subsys_state___94 *);
	int (*css_online)(struct cgroup_subsys_state___94 *);
	void (*css_offline)(struct cgroup_subsys_state___94 *);
	void (*css_released)(struct cgroup_subsys_state___94 *);
	void (*css_free)(struct cgroup_subsys_state___94 *);
	void (*css_reset)(struct cgroup_subsys_state___94 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___94 *, int);
	int (*css_extra_stat_show)(struct seq_file___108 *, struct cgroup_subsys_state___94 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___118 *);
	void (*cancel_fork)(struct task_struct___118 *);
	void (*fork)(struct task_struct___118 *);
	void (*exit)(struct task_struct___118 *);
	void (*free)(struct task_struct___118 *);
	void (*bind)(struct cgroup_subsys_state___94 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___94 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___94 *dfl_cftypes;
	struct cftype___94 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___94 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___94 *updated_children;
	struct cgroup___94 *updated_next;
};

struct cgroup_root___94 {
	struct kernfs_root___114 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___94 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___94 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___94 *ss;
	struct list_head node;
	struct kernfs_ops___114 *kf_ops;
	int (*open)(struct kernfs_open_file___114 *);
	void (*release)(struct kernfs_open_file___114 *);
	u64 (*read_u64)(struct cgroup_subsys_state___94 *, struct cftype___94 *);
	s64 (*read_s64)(struct cgroup_subsys_state___94 *, struct cftype___94 *);
	int (*seq_show)(struct seq_file___108 *, void *);
	void * (*seq_start)(struct seq_file___108 *, loff_t *);
	void * (*seq_next)(struct seq_file___108 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___108 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___94 *, struct cftype___94 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___94 *, struct cftype___94 *, s64);
	ssize_t (*write)(struct kernfs_open_file___114 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___114 *, struct poll_table_struct___79 *);
};

struct xdp_rxq_info___15 {
	struct net_device___20 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___15 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___20 *dev_rx;
};

struct netlink_callback___15 {
	struct sk_buff___19 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___15 *);
	int (*dump)(struct sk_buff___19 *, struct netlink_callback___15 *);
	int (*done)(struct netlink_callback___15 *);
	void *data;
	struct module___101 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___15 {
	int (*create)(struct sk_buff___19 *, struct net_device___20 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___19 *, unsigned char *);
	int (*cache)(const struct neighbour___8 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___20 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___15 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___15 *, int);
	int poll_owner;
	struct net_device___20 *dev;
	struct sk_buff___19 *gro_list;
	struct sk_buff___19 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___15 {
	struct net_device___20 *dev;
	struct Qdisc___14 *qdisc;
	struct Qdisc___14 *qdisc_sleeping;
	struct kobject___112 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___20 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___14 {
	struct sk_buff___19 *head;
	struct sk_buff___19 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___14;

struct Qdisc___14 {
	int (*enqueue)(struct sk_buff___19 *, struct Qdisc___14 *, struct sk_buff___19 **);
	struct sk_buff___19 * (*dequeue)(struct Qdisc___14 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___14 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___15 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___16 gso_skb;
	struct qdisc_skb_head___14 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___14 *next_sched;
	struct sk_buff_head___16 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___15 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___112 kobj;
	struct net_device___20 *dev;
	long: 64;
	struct xdp_rxq_info___15 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___15)(struct net_device___20 *, struct sk_buff___19 *, struct net_device___20 *);

struct netdev_bpf___15 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___14 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___14 *prog;
			const struct bpf_prog_offload_ops___14 *ops;
		} verifier;
		struct {
			struct bpf_prog___14 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___15 *offmap;
		};
		struct {
			struct xdp_umem *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___15 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___19 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___15 {
	int (*tls_dev_add)(struct net_device___20 *, struct sock___9 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___20 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___20 *, struct sock___9 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___15 {
	int (*ndo_init)(struct net_device___20 *);
	void (*ndo_uninit)(struct net_device___20 *);
	int (*ndo_open)(struct net_device___20 *);
	int (*ndo_stop)(struct net_device___20 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___19 *, struct net_device___20 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___19 *, struct net_device___20 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___20 *, struct sk_buff___19 *, struct net_device___20 *, select_queue_fallback_t___15);
	void (*ndo_change_rx_flags)(struct net_device___20 *, int);
	void (*ndo_set_rx_mode)(struct net_device___20 *);
	int (*ndo_set_mac_address)(struct net_device___20 *, void *);
	int (*ndo_validate_addr)(struct net_device___20 *);
	int (*ndo_do_ioctl)(struct net_device___20 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___20 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___20 *, int);
	int (*ndo_neigh_setup)(struct net_device___20 *, struct neigh_parms___8 *);
	void (*ndo_tx_timeout)(struct net_device___20 *);
	void (*ndo_get_stats64)(struct net_device___20 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___20 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___20 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___20 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___20 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___20 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___20 *);
	int (*ndo_netpoll_setup)(struct net_device___20 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___20 *);
	int (*ndo_set_vf_mac)(struct net_device___20 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___20 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___20 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___20 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___20 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___20 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___20 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___20 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___20 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___20 *, int, struct sk_buff___19 *);
	int (*ndo_set_vf_guid)(struct net_device___20 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___20 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___20 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___20 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___20 *, const struct sk_buff___19 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___20 *, struct net_device___20 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___20 *, struct net_device___20 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___20 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___20 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___20 *, struct neighbour___8 *);
	void (*ndo_neigh_destroy)(struct net_device___20 *, struct neighbour___8 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___20 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___20 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___20 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___19 *, struct netlink_callback___15 *, struct net_device___20 *, struct net_device___20 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___20 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___20 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___19 *, u32, u32, struct net_device___20 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___20 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___20 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___20 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___20 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___20 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___20 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___20 *, struct net_device___20 *);
	void (*ndo_dfwd_del_station)(struct net_device___20 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___20 *);
	int (*ndo_set_tx_maxrate)(struct net_device___20 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___20 *);
	int (*ndo_change_proto_down)(struct net_device___20 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___20 *, struct sk_buff___19 *);
	void (*ndo_set_rx_headroom)(struct net_device___20 *, int);
	int (*ndo_bpf)(struct net_device___20 *, struct netdev_bpf___15 *);
	int (*ndo_xdp_xmit)(struct net_device___20 *, int, struct xdp_frame___15 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___20 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___20 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___8 {
	possible_net_t___16 net;
	struct net_device___20 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___8 *);
	void (*neigh_cleanup)(struct neighbour___8 *);
	struct neigh_table___7 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___7 {
	u32 (*l3mdev_fib_table)(const struct net_device___20 *);
	struct sk_buff___19 * (*l3mdev_l3_rcv)(struct net_device___20 *, struct sk_buff___19 *, u16);
	struct sk_buff___19 * (*l3mdev_l3_out)(struct net_device___20 *, struct sock___9 *, struct sk_buff___19 *, u16);
	struct dst_entry___8 * (*l3mdev_link_scope_lookup)(const struct net_device___20 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct ndisc_ops___4 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___20 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___20 *, struct neighbour___8 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___20 *, u8, struct neighbour___8 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___20 *, struct sk_buff___19 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___25 *, struct net_device___20 *, const struct prefix_info *, struct inet6_dev___4 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___3;

struct inet6_dev___4 {
	struct net_device___20 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___3 *mc_list;
	struct ifmcaddr6___3 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	u8 rndid[8];
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___8 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
};

struct tcf_proto___14;

struct mini_Qdisc___14 {
	struct tcf_proto___14 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___14 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___20 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___25 *, struct net_device___20 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___20 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___20 *, struct list_head *);
	size_t (*get_size)(const struct net_device___20 *);
	int (*fill_info)(struct sk_buff___19 *, const struct net_device___20 *);
	size_t (*get_xstats_size)(const struct net_device___20 *);
	int (*fill_xstats)(struct sk_buff___19 *, const struct net_device___20 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___20 *, struct net_device___20 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___20 *, const struct net_device___20 *);
	int (*fill_slave_info)(struct sk_buff___19 *, const struct net_device___20 *, const struct net_device___20 *);
	struct net___25 * (*get_link_net)(const struct net_device___20 *);
	size_t (*get_linkxstats_size)(const struct net_device___20 *, int);
	int (*fill_linkxstats)(struct sk_buff___19 *, const struct net_device___20 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___15 {
	struct list_head poll_list;
	struct sk_buff_head___16 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___15 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___14 *output_queue;
	struct Qdisc___14 **output_queue_tailp;
	struct sk_buff___19 *completion_queue;
	struct sk_buff_head___16 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___15 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___16 input_pkt_queue;
	struct napi_struct___15 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bdi_writeback_congested___42 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___42 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___42 {
	struct bio___42 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___42 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___42 bip_inline_vecs[0];
};

struct bio_set___42 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___42 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___37 {
	struct mem_cgroup___37 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___37 {
	struct lruvec___117 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___37 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___37 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct kernel_param_ops___98 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___98 *);
	int (*get)(char *, const struct kernel_param___98 *);
	void (*free)(void *);
};

struct kparam_array___98;

struct kernel_param___98 {
	const char *name;
	struct module___101 *mod;
	const struct kernel_param_ops___98 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___98 *arr;
	};
};

struct kparam_array___98 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___98 *ops;
	void *elem;
};

struct module_attribute___98 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___98 *, struct module_kobject___98 *, char *);
	ssize_t (*store)(struct module_attribute___98 *, struct module_kobject___98 *, const char *, size_t);
	void (*setup)(struct module___101 *, const char *);
	int (*test)(struct module___101 *);
	void (*free)(struct module___101 *);
};

struct gnet_dump___14 {
	spinlock_t *lock;
	struct sk_buff___19 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___14;

struct Qdisc_ops___14 {
	struct Qdisc_ops___14 *next;
	const struct Qdisc_class_ops___14 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___19 *, struct Qdisc___14 *, struct sk_buff___19 **);
	struct sk_buff___19 * (*dequeue)(struct Qdisc___14 *);
	struct sk_buff___19 * (*peek)(struct Qdisc___14 *);
	int (*init)(struct Qdisc___14 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___14 *);
	void (*destroy)(struct Qdisc___14 *);
	int (*change)(struct Qdisc___14 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___14 *);
	int (*change_tx_queue_len)(struct Qdisc___14 *, unsigned int);
	int (*dump)(struct Qdisc___14 *, struct sk_buff___19 *);
	int (*dump_stats)(struct Qdisc___14 *, struct gnet_dump___14 *);
	void (*ingress_block_set)(struct Qdisc___14 *, u32);
	void (*egress_block_set)(struct Qdisc___14 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___14 *);
	u32 (*egress_block_get)(struct Qdisc___14 *);
	struct module___101 *owner;
};

struct tcf_block___14;

struct Qdisc_class_ops___14 {
	unsigned int flags;
	struct netdev_queue___15 * (*select_queue)(struct Qdisc___14 *, struct tcmsg *);
	int (*graft)(struct Qdisc___14 *, long unsigned int, struct Qdisc___14 *, struct Qdisc___14 **, struct netlink_ext_ack *);
	struct Qdisc___14 * (*leaf)(struct Qdisc___14 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___14 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___14 *, u32);
	int (*change)(struct Qdisc___14 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___14 *, long unsigned int);
	void (*walk)(struct Qdisc___14 *, struct qdisc_walker *);
	struct tcf_block___14 * (*tcf_block)(struct Qdisc___14 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___14 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___14 *, long unsigned int);
	int (*dump)(struct Qdisc___14 *, long unsigned int, struct sk_buff___19 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___14 *, long unsigned int, struct gnet_dump___14 *);
};

struct tcf_chain___14;

struct tcf_block___14 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___25 *net;
	struct Qdisc___14 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___14 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___14;

struct tcf_proto_ops___14;

struct tcf_proto___14 {
	struct tcf_proto___14 *next;
	void *root;
	int (*classify)(struct sk_buff___19 *, const struct tcf_proto___14 *, struct tcf_result___14 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___14 *ops;
	struct tcf_chain___14 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___14 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___14 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___14 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___19 *, const struct tcf_proto___14 *, struct tcf_result___14 *);
	int (*init)(struct tcf_proto___14 *);
	void (*destroy)(struct tcf_proto___14 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___14 *, u32);
	void (*put)(struct tcf_proto___14 *, void *);
	int (*change)(struct net___25 *, struct sk_buff___19 *, struct tcf_proto___14 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___14 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___14 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___14 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___25 *, struct tcf_chain___14 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___25 *, struct tcf_proto___14 *, void *, struct sk_buff___19 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___19 *, struct net___25 *, void *);
	struct module___101 *owner;
	int flags;
};

struct tcf_chain___14 {
	struct mutex filter_chain_lock;
	struct tcf_proto___14 *filter_chain;
	struct list_head list;
	struct tcf_block___14 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___14 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___6 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___14 *prog;
};

struct bpf_redirect_info___14 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___94 *map;
	struct bpf_map___94 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___6;

struct neigh_hash_table___6;

struct neigh_table___7 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___20 *, __u32 *);
	bool (*key_eq)(const struct neighbour___8 *, const void *);
	int (*constructor)(struct neighbour___8 *);
	int (*pconstructor)(struct pneigh_entry___6 *);
	void (*pdestructor)(struct pneigh_entry___6 *);
	void (*proxy_redo)(struct sk_buff___19 *);
	char *id;
	struct neigh_parms___8 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___16 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___6 *nht;
	struct pneigh_entry___6 **phash_buckets;
};

struct neigh_ops___7 {
	int family;
	void (*solicit)(struct neighbour___8 *, struct sk_buff___19 *);
	void (*error_report)(struct neighbour___8 *, struct sk_buff___19 *);
	int (*output)(struct neighbour___8 *, struct sk_buff___19 *);
	int (*connected_output)(struct neighbour___8 *, struct sk_buff___19 *);
};

struct pneigh_entry___6 {
	struct pneigh_entry___6 *next;
	possible_net_t___16 net;
	struct net_device___20 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___6 {
	struct neighbour___8 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___6 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___6 *ctarget;
	struct net___25 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___6 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___6 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___4;

struct timewait_sock_ops___4;

struct proto___6 {
	void (*close)(struct sock___9 *, long int);
	int (*pre_connect)(struct sock___9 *, struct sockaddr *, int);
	int (*connect)(struct sock___9 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___9 *, int);
	struct sock___9 * (*accept)(struct sock___9 *, int, int *, bool);
	int (*ioctl)(struct sock___9 *, int, long unsigned int);
	int (*init)(struct sock___9 *);
	void (*destroy)(struct sock___9 *);
	void (*shutdown)(struct sock___9 *, int);
	int (*setsockopt)(struct sock___9 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___9 *, int, int, char *, int *);
	void (*keepalive)(struct sock___9 *, int);
	int (*sendmsg)(struct sock___9 *, struct msghdr___6 *, size_t);
	int (*recvmsg)(struct sock___9 *, struct msghdr___6 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___9 *, struct page___118 *, int, size_t, int);
	int (*bind)(struct sock___9 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___9 *, struct sk_buff___19 *);
	void (*release_cb)(struct sock___9 *);
	int (*hash)(struct sock___9 *);
	void (*unhash)(struct sock___9 *);
	void (*rehash)(struct sock___9 *);
	int (*get_port)(struct sock___9 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___9 *);
	bool (*stream_memory_read)(const struct sock___9 *);
	void (*enter_memory_pressure)(struct sock___9 *);
	void (*leave_memory_pressure)(struct sock___9 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___4 *rsk_prot;
	struct timewait_sock_ops___4 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___101 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___9 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct request_sock___3;

struct request_sock_ops___4 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___9 *, struct request_sock___3 *);
	void (*send_ack)(const struct sock___9 *, struct sk_buff___19 *, struct request_sock___3 *);
	void (*send_reset)(const struct sock___9 *, struct sk_buff___19 *);
	void (*destructor)(struct request_sock___3 *);
	void (*syn_ack_timeout)(const struct request_sock___3 *);
};

struct timewait_sock_ops___4 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___9 *, struct sock___9 *, void *);
	void (*twsk_destructor)(struct sock___9 *);
};

struct request_sock___3 {
	struct sock_common___6 __req_common;
	struct request_sock___3 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___4 *rsk_ops;
	struct sock___9 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___3 {
	struct in6_addr mca_addr;
	struct inet6_dev___4 *idev;
	struct ifmcaddr6___3 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ip6_ra_chain___3 {
	struct ip6_ra_chain___3 *next;
	struct sock___9 *sk;
	int sel;
	void (*destructor)(struct sock___9 *);
};

struct lpm_trie_node {
	struct callback_head rcu;
	struct lpm_trie_node *child[2];
	u32 prefixlen;
	u32 flags;
	u8 data[0];
};

struct lpm_trie {
	struct bpf_map___94 map;
	struct lpm_trie_node *root;
	size_t n_entries;
	size_t max_prefixlen;
	size_t data_size;
	raw_spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_cgroup_storage_map {
	struct bpf_map___85 map;
	spinlock_t lock;
	struct bpf_prog___10 *prog;
	struct rb_root root;
	struct list_head list;
	long: 64;
	long: 64;
	long: 64;
};

struct btf_member {
	__u32 name_off;
	__u32 type;
	__u32 offset;
};

struct bpf_queue_stack {
	struct bpf_map___94 map;
	raw_spinlock_t lock;
	u32 head;
	u32 tail;
	u32 size;
	char elements[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct btf_enum {
	__u32 name_off;
	__s32 val;
};

struct btf_array {
	__u32 type;
	__u32 index_type;
	__u32 nelems;
};

struct btf_param {
	__u32 name_off;
	__u32 type;
};

enum verifier_phase {
	CHECK_META = 0,
	CHECK_TYPE = 1,
};

struct resolve_vertex {
	const struct btf_type *t;
	u32 type_id;
	u16 next_member;
};

enum visit_state {
	NOT_VISITED = 0,
	VISITED = 1,
	RESOLVED = 2,
};

enum resolve_mode {
	RESOLVE_TBD = 0,
	RESOLVE_PTR = 1,
	RESOLVE_STRUCT_OR_ARRAY = 2,
};

struct btf_sec_info {
	u32 off;
	u32 len;
};

struct btf_verifier_env {
	struct btf *btf;
	u8 *visit_states;
	struct resolve_vertex stack[32];
	struct bpf_verifier_log log;
	u32 log_type_id;
	u32 top_stack;
	enum verifier_phase phase;
	enum resolve_mode resolve_mode;
};

struct btf_kind_operations {
	s32 (*check_meta)(struct btf_verifier_env *, const struct btf_type *, u32);
	int (*resolve)(struct btf_verifier_env *, const struct resolve_vertex *);
	int (*check_member)(struct btf_verifier_env *, const struct btf_type *, const struct btf_member *, const struct btf_type *);
	int (*check_kflag_member)(struct btf_verifier_env *, const struct btf_type *, const struct btf_member *, const struct btf_type *);
	void (*log_details)(struct btf_verifier_env *, const struct btf_type *);
	void (*seq_show)(const struct btf *, const struct btf_type *, u32, void *, u8, struct seq_file___99 *);
};

enum xdp_mem_type {
	MEM_TYPE_PAGE_SHARED = 0,
	MEM_TYPE_PAGE_ORDER0 = 1,
	MEM_TYPE_PAGE_POOL = 2,
	MEM_TYPE_ZERO_COPY = 3,
	MEM_TYPE_MAX = 4,
};

struct xdp_buff {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	long unsigned int handle;
	struct xdp_rxq_info___11 *rxq;
};

enum net_device_flags {
	IFF_UP = 1,
	IFF_BROADCAST = 2,
	IFF_DEBUG = 4,
	IFF_LOOPBACK = 8,
	IFF_POINTOPOINT = 16,
	IFF_NOTRAILERS = 32,
	IFF_RUNNING = 64,
	IFF_NOARP = 128,
	IFF_PROMISC = 256,
	IFF_ALLMULTI = 512,
	IFF_MASTER = 1024,
	IFF_SLAVE = 2048,
	IFF_MULTICAST = 4096,
	IFF_PORTSEL = 8192,
	IFF_AUTOMEDIA = 16384,
	IFF_DYNAMIC = 32768,
	IFF_LOWER_UP = 65536,
	IFF_DORMANT = 131072,
	IFF_ECHO = 262144,
};

enum netdev_cmd {
	NETDEV_UP = 1,
	NETDEV_DOWN = 2,
	NETDEV_REBOOT = 3,
	NETDEV_CHANGE = 4,
	NETDEV_REGISTER = 5,
	NETDEV_UNREGISTER = 6,
	NETDEV_CHANGEMTU = 7,
	NETDEV_CHANGEADDR = 8,
	NETDEV_PRE_CHANGEADDR = 9,
	NETDEV_GOING_DOWN = 10,
	NETDEV_CHANGENAME = 11,
	NETDEV_FEAT_CHANGE = 12,
	NETDEV_BONDING_FAILOVER = 13,
	NETDEV_PRE_UP = 14,
	NETDEV_PRE_TYPE_CHANGE = 15,
	NETDEV_POST_TYPE_CHANGE = 16,
	NETDEV_POST_INIT = 17,
	NETDEV_RELEASE = 18,
	NETDEV_NOTIFY_PEERS = 19,
	NETDEV_JOIN = 20,
	NETDEV_CHANGEUPPER = 21,
	NETDEV_RESEND_IGMP = 22,
	NETDEV_PRECHANGEMTU = 23,
	NETDEV_CHANGEINFODATA = 24,
	NETDEV_BONDING_INFO = 25,
	NETDEV_PRECHANGEUPPER = 26,
	NETDEV_CHANGELOWERSTATE = 27,
	NETDEV_UDP_TUNNEL_PUSH_INFO = 28,
	NETDEV_UDP_TUNNEL_DROP_INFO = 29,
	NETDEV_CHANGE_TX_QUEUE_LEN = 30,
	NETDEV_CVLAN_FILTER_PUSH_INFO = 31,
	NETDEV_CVLAN_FILTER_DROP_INFO = 32,
	NETDEV_SVLAN_FILTER_PUSH_INFO = 33,
	NETDEV_SVLAN_FILTER_DROP_INFO = 34,
};

struct netdev_notifier_info {
	struct net_device___16 *dev;
	struct netlink_ext_ack *extack;
};

struct xdp_bulk_queue {
	struct xdp_frame___11 *q[16];
	struct net_device___16 *dev_rx;
	unsigned int count;
};

struct bpf_dtab;

struct bpf_dtab_netdev {
	struct net_device___16 *dev;
	struct bpf_dtab *dtab;
	unsigned int bit;
	struct xdp_bulk_queue *bulkq;
	struct callback_head rcu;
};

struct bpf_dtab {
	struct bpf_map___85 map;
	struct bpf_dtab_netdev **netdev_map;
	long unsigned int *flush_needed;
	struct list_head list;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct skb_frag_struct {
	struct {
		struct page___109 *p;
	} page;
	__u32 page_offset;
	__u32 size;
};

typedef struct skb_frag_struct skb_frag_t;

struct skb_shared_hwtstamps {
	ktime_t hwtstamp;
};

struct skb_shared_info {
	__u8 __unused;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___15 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t frags[16];
};

struct ptr_ring {
	int producer;
	spinlock_t producer_lock;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int consumer_head;
	int consumer_tail;
	spinlock_t consumer_lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int size;
	int batch;
	void **queue;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_bulk_queue___2 {
	void *q[8];
	unsigned int count;
};

struct bpf_cpu_map_entry {
	u32 cpu;
	int map_id;
	u32 qsize;
	struct xdp_bulk_queue___2 *bulkq;
	struct ptr_ring *queue;
	struct task_struct___109 *kthread;
	struct work_struct kthread_stop_wq;
	atomic_t refcnt;
	struct callback_head rcu;
};

struct bpf_cpu_map {
	struct bpf_map___85 map;
	struct bpf_cpu_map_entry **cpu_map;
	long unsigned int *flush_needed;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module___102;

struct file___119;

struct kiocb___119;

struct iov_iter___48;

struct poll_table_struct___80;

struct vm_area_struct___119;

struct inode___120;

struct file_lock___119;

struct page___119;

struct pipe_inode_info___29;

struct seq_file___109;

struct file_operations___119 {
	struct module___102 *owner;
	loff_t (*llseek)(struct file___119 *, loff_t, int);
	ssize_t (*read)(struct file___119 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___119 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___119 *, struct iov_iter___48 *);
	ssize_t (*write_iter)(struct kiocb___119 *, struct iov_iter___48 *);
	int (*iopoll)(struct kiocb___119 *, bool);
	int (*iterate)(struct file___119 *, struct dir_context *);
	int (*iterate_shared)(struct file___119 *, struct dir_context *);
	__poll_t (*poll)(struct file___119 *, struct poll_table_struct___80 *);
	long int (*unlocked_ioctl)(struct file___119 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___119 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___119 *, struct vm_area_struct___119 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___120 *, struct file___119 *);
	int (*flush)(struct file___119 *, fl_owner_t);
	int (*release)(struct inode___120 *, struct file___119 *);
	int (*fsync)(struct file___119 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___119 *, int);
	int (*lock)(struct file___119 *, int, struct file_lock___119 *);
	ssize_t (*sendpage)(struct file___119 *, struct page___119 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___119 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___119 *, int, struct file_lock___119 *);
	ssize_t (*splice_write)(struct pipe_inode_info___29 *, struct file___119 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___119 *, loff_t *, struct pipe_inode_info___29 *, size_t, unsigned int);
	int (*setlease)(struct file___119 *, long int, struct file_lock___119 **, void **);
	long int (*fallocate)(struct file___119 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___109 *, struct file___119 *);
	ssize_t (*copy_file_range)(struct file___119 *, loff_t, struct file___119 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___119 *, loff_t, struct file___119 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___119 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___118 {
	u64 seqnum;
	struct vm_area_struct___119 *vmas[4];
};

struct page_frag___118 {
	struct page___119 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___118;

struct mem_cgroup___38;

struct cred___114;

struct nsproxy___111;

struct signal_struct___108;

struct bio_list___43;

struct backing_dev_info___43;

struct css_set___95;

struct vm_struct___88;

struct task_struct___119 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___119 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___118 *mm;
	struct mm_struct___118 *active_mm;
	struct vmacache___118 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___119 *real_parent;
	struct task_struct___119 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___119 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___38 *active_memcg;
	long int rh_reserved2;
	struct pid___98 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___98 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___98 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___114 *ptracer_cred;
	const struct cred___114 *real_cred;
	const struct cred___114 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___111 *nsproxy;
	struct signal_struct___108 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___119 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___43 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___43 *backing_dev_info;
	struct io_context___17 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___95 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___29 *splice_pipe;
	struct page_frag___118 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___38 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___119 *oom_reaper_list;
	struct vm_struct___88 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___74 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct secondary_data___119 {
	void *stack;
	struct task_struct___119 *task;
	long int status;
};

struct dentry___119;

struct path___118 {
	struct vfsmount *mnt;
	struct dentry___119 *dentry;
};

struct address_space___118;

struct file___119 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___118 f_path;
	struct inode___120 *f_inode;
	const struct file_operations___119 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___98 f_owner;
	const struct cred___114 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___118 *f_mapping;
	errseq_t f_wb_err;
};

struct bpf_map___95;

struct bpf_map_ops___95 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___95 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___95 *, struct file___119 *);
	void (*map_free)(struct bpf_map___95 *);
	int (*map_get_next_key)(struct bpf_map___95 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___95 *);
	void * (*map_lookup_elem)(struct bpf_map___95 *, void *);
	int (*map_update_elem)(struct bpf_map___95 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___95 *, void *);
	int (*map_push_elem)(struct bpf_map___95 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___95 *, void *);
	int (*map_peek_elem)(struct bpf_map___95 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___95 *, struct file___119 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___95 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___95 *, void *, struct seq_file___109 *);
	int (*map_check_btf)(const struct bpf_map___95 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct user_struct___114;

struct bpf_map___95 {
	const struct bpf_map_ops___95 *ops;
	struct bpf_map___95 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___114 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct seq_operations___107;

struct seq_file___109 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___107 *op;
	int poll_event;
	const struct file___119 *file;
	void *private;
};

struct key___114;

struct user_struct___114 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___114 *uid_keyring;
	struct key___114 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bpf_offloaded_map___16;

struct bpf_map_dev_ops___16 {
	int (*map_get_next_key)(struct bpf_offloaded_map___16 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___16 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___16 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___16 *, void *);
};

struct net_device___21;

struct bpf_offloaded_map___16 {
	struct bpf_map___95 map;
	struct net_device___21 *netdev;
	const struct bpf_map_dev_ops___16 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___20;

typedef rx_handler_result_t rx_handler_func_t___16(struct sk_buff___20 **);

struct net___26;

typedef struct {
	struct net___26 *net;
} possible_net_t___17;

struct kset___112;

struct kobj_type___112;

struct kernfs_node___115;

struct kobject___113 {
	const char *name;
	struct list_head entry;
	struct kobject___113 *parent;
	struct kset___112 *kset;
	struct kobj_type___112 *ktype;
	struct kernfs_node___115 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___110;

struct dev_pm_info___110 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___110 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___110;

struct bus_type___110;

struct device_driver___110;

struct dev_pm_domain___110;

struct dma_map_ops___32;

struct fwnode_handle___82;

struct class___110;

struct attribute_group___109;

struct device___110 {
	struct device___110 *parent;
	struct device_private *p;
	struct kobject___113 kobj;
	const char *init_name;
	const struct device_type___110 *type;
	struct mutex mutex;
	struct bus_type___110 *bus;
	struct device_driver___110 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___110 power;
	struct dev_pm_domain___110 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___32 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___82 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___110 *class;
	const struct attribute_group___109 **groups;
	void (*release)(struct device___110 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct net_device_ops___16;

struct ethtool_ops___16;

struct l3mdev_ops___8;

struct xfrmdev_ops___16;

struct tlsdev_ops___16;

struct header_ops___16;

struct netdev_rx_queue___16;

struct bpf_prog___15;

struct mini_Qdisc___15;

struct netdev_queue___16;

struct Qdisc___15;

struct rtnl_link_ops___15;

struct dcbnl_rtnl_ops___16;

struct net_device___21 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___16 *netdev_ops;
	const struct ethtool_ops___16 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___8 *l3mdev_ops;
	const struct ndisc_ops___2 *ndisc_ops;
	const struct xfrmdev_ops___16 *xfrmdev_ops;
	const struct tlsdev_ops___16 *tlsdev_ops;
	const struct header_ops___16 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___112 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___2 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___16 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___15 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___16 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___15 *miniq_ingress;
	struct netdev_queue___16 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___16 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___15 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___15 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___16 = 0,
		NETREG_REGISTERED___16 = 1,
		NETREG_UNREGISTERING___16 = 2,
		NETREG_UNREGISTERED___16 = 3,
		NETREG_RELEASED___16 = 4,
		NETREG_DUMMY___16 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___16 = 0,
		RTNL_LINK_INITIALIZING___16 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___21 *);
	struct netpoll_info *npinfo;
	possible_net_t___17 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___110 dev;
	const struct attribute_group___109 *sysfs_groups[4];
	const struct attribute_group___109 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___15 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___16 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct bpf_prog_ops___15 {
	int (*test_run)(struct bpf_prog___15 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_aux___15;

struct bpf_prog___15 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___15 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

struct bpf_verifier_ops___15 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___15 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___15 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___15 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___15 *, u32 *);
};

struct bpf_prog_offload_ops___15 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___15 *);
	int (*translate)(struct bpf_prog___15 *);
	void (*destroy)(struct bpf_prog___15 *);
};

struct bpf_prog_offload___15 {
	struct bpf_prog___15 *prog;
	struct net_device___21 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___15 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___15 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___15 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___15 *ops;
	struct bpf_map___95 **used_maps;
	struct bpf_prog___15 *prog;
	struct user_struct___114 *user;
	u64 load_time;
	struct bpf_map___95 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___15 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___15 {
	struct bpf_prog___15 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___15 {
	struct callback_head rcu;
	struct bpf_prog_array_item___15 items[0];
};

typedef struct page___119 *pgtable_t___118;

struct dev_pagemap___116;

struct page___119 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___118 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___119 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___118 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___118 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___116 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___38 *mem_cgroup;
};

struct pglist_data___118;

struct lruvec___118 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___118 *pgdat;
};

struct zone___118 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___118 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___118 {
	struct zone___118 *zone;
	int zone_idx;
};

struct zonelist___118 {
	struct zoneref___118 _zonerefs[25];
};

struct pglist_data___118 {
	struct zone___118 node_zones[3];
	struct zonelist___118 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___119 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___119 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___118 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___119 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___119 *owner;
};

struct blocking_notifier_head___118 {
	struct rw_semaphore___119 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___116;

struct vm_area_struct___119 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___119 *vm_next;
	struct vm_area_struct___119 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___118 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___116 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___119 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___118;

struct user_namespace___99;

struct mm_struct___118 {
	struct {
		struct vm_area_struct___119 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___119 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___119 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___118 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___119 *owner;
		struct user_namespace___99 *user_ns;
		struct file___119 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___118 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___118;

struct address_space___118 {
	struct inode___120 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___119 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___118 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___116)(struct vm_area_struct___119 *, long unsigned int, const struct page___119 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___116)(struct page___119 *, void *);

struct dev_pagemap___116 {
	dev_page_fault_t___116 page_fault;
	dev_page_free_t___116 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___110 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct cgroup___95;

struct cgroup_subsys___95;

struct cgroup_subsys_state___95 {
	struct cgroup___95 *cgroup;
	struct cgroup_subsys___95 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___95 *parent;
};

struct cgroup_file___95 {
	struct kernfs_node___115 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___38;

struct mem_cgroup___38 {
	struct cgroup_subsys_state___95 css;
	struct mem_cgroup_id___16 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___95 events_file;
	struct cgroup_file___95 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___119 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___38 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct vm_fault___116;

struct vm_operations_struct___116 {
	void (*open)(struct vm_area_struct___119 *);
	void (*close)(struct vm_area_struct___119 *);
	int (*split)(struct vm_area_struct___119 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___119 *);
	vm_fault_t (*fault)(struct vm_fault___116 *);
	vm_fault_t (*huge_fault)(struct vm_fault___116 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___116 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___119 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___116 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___116 *);
	int (*access)(struct vm_area_struct___119 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___119 *);
	int (*set_policy)(struct vm_area_struct___119 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___119 *, long unsigned int);
	struct page___119 * (*find_special_page)(struct vm_area_struct___119 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___118 {
	struct task_struct___119 *task;
	struct core_thread___118 *next;
};

struct core_state___118 {
	atomic_t nr_threads;
	struct core_thread___118 dumper;
	struct completion startup;
};

struct ucounts___99;

struct user_namespace___99 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___99 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___7 ns;
	long unsigned int flags;
	struct key___114 *persistent_keyring_register;
	struct rw_semaphore___119 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___99 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___116 {
	struct vm_area_struct___119 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___119 *cow_page;
	struct mem_cgroup___38 *memcg;
	struct page___119 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___118 prealloc_pte;
};

struct shrink_control___38 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___38 *memcg;
};

struct shrinker___38 {
	long unsigned int (*count_objects)(struct shrinker___38 *, struct shrink_control___38 *);
	long unsigned int (*scan_objects)(struct shrinker___38 *, struct shrink_control___38 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct cred___114 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___114 *session_keyring;
	struct key___114 *process_keyring;
	struct key___114 *thread_keyring;
	struct key___114 *request_key_auth;
	void *security;
	struct user_struct___114 *user;
	struct user_namespace___99 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___95;

struct nsproxy___111 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net___26 *net_ns;
	struct cgroup_namespace___95 *cgroup_ns;
};

struct signal_struct___108 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___119 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___119 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___98 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___98 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___118 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___98 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___43;

struct bio_list___43 {
	struct bio___43 *head;
	struct bio___43 *tail;
};

struct bdi_writeback_congested___43;

struct bdi_writeback___43 {
	struct backing_dev_info___43 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___43 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___95 *memcg_css;
	struct cgroup_subsys_state___95 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___43 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___43 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___110 *dev;
	struct device___110 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___119 *debug_dir;
	struct dentry___119 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___95 {
	struct cgroup_subsys_state___95 *subsys[13];
	refcount_t refcount;
	struct css_set___95 *dom_cset;
	struct cgroup___95 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___95 *mg_src_cgrp;
	struct cgroup___95 *mg_dst_cgrp;
	struct css_set___95 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___118;

struct pipe_buffer___29;

struct pipe_inode_info___29 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___119 *tmp_page;
	struct fasync_struct___118 *fasync_readers;
	struct fasync_struct___118 *fasync_writers;
	struct pipe_buffer___29 *bufs;
	struct user_struct___114 *user;
};

struct vm_struct___88 {
	struct vm_struct___88 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___119 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___108 {
	struct task_struct___119 task;
	long unsigned int stack[8192];
};

struct dentry_operations___118;

struct super_block___119;

struct dentry___119 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___119 *d_parent;
	struct qstr d_name;
	struct inode___120 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___118 *d_op;
	struct super_block___119 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___118;

struct block_device___119;

struct inode___120 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___118 *i_op;
	struct super_block___119 *i_sb;
	struct address_space___118 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___119 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___43 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___119 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___118 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___29 *i_pipe;
		struct block_device___119 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___118 {
	int (*d_revalidate)(struct dentry___119 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___119 *, unsigned int);
	int (*d_hash)(const struct dentry___119 *, struct qstr *);
	int (*d_compare)(const struct dentry___119 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___119 *);
	int (*d_init)(struct dentry___119 *);
	void (*d_release)(struct dentry___119 *);
	void (*d_prune)(struct dentry___119 *);
	void (*d_iput)(struct dentry___119 *, struct inode___120 *);
	char * (*d_dname)(struct dentry___119 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___118 *);
	int (*d_manage)(const struct path___118 *, bool);
	struct dentry___119 * (*d_real)(struct dentry___119 *, const struct inode___120 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___118;

struct mem_dqinfo___118 {
	struct quota_format_type___118 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___118;

struct quota_info___118 {
	unsigned int flags;
	struct rw_semaphore___119 dqio_sem;
	struct inode___120 *files[3];
	struct mem_dqinfo___118 info[3];
	const struct quota_format_ops___118 *ops[3];
};

struct rcuwait___118 {
	struct task_struct___119 *task;
};

struct percpu_rw_semaphore___118 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___119 rw_sem;
	struct rcuwait___118 writer;
	int readers_block;
};

struct sb_writers___118 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___118 rw_sem[3];
};

struct file_system_type___118;

struct super_operations___118;

struct dquot_operations___118;

struct quotactl_ops___118;

struct super_block___119 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___118 *s_type;
	const struct super_operations___118 *s_op;
	const struct dquot_operations___118 *dq_op;
	const struct quotactl_ops___118 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___119 *s_root;
	struct rw_semaphore___119 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___119 *s_bdev;
	struct backing_dev_info___43 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___118 s_dquot;
	struct sb_writers___118 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___118 *s_d_op;
	int cleancache_poolid;
	struct shrinker___38 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___99 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___119 {
	struct file___119 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___119 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___119 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___119 *ia_file;
};

struct dquot___118 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___119 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___118 {
	int qf_fmt_id;
	const struct quota_format_ops___118 *qf_ops;
	struct module___102 *qf_owner;
	struct quota_format_type___118 *qf_next;
};

struct quota_format_ops___118 {
	int (*check_quota_file)(struct super_block___119 *, int);
	int (*read_file_info)(struct super_block___119 *, int);
	int (*write_file_info)(struct super_block___119 *, int);
	int (*free_file_info)(struct super_block___119 *, int);
	int (*read_dqblk)(struct dquot___118 *);
	int (*commit_dqblk)(struct dquot___118 *);
	int (*release_dqblk)(struct dquot___118 *);
	int (*get_next_id)(struct super_block___119 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___118 {
	int (*write_dquot)(struct dquot___118 *);
	struct dquot___118 * (*alloc_dquot)(struct super_block___119 *, int);
	void (*destroy_dquot)(struct dquot___118 *);
	int (*acquire_dquot)(struct dquot___118 *);
	int (*release_dquot)(struct dquot___118 *);
	int (*mark_dirty)(struct dquot___118 *);
	int (*write_info)(struct super_block___119 *, int);
	qsize_t * (*get_reserved_space)(struct inode___120 *);
	int (*get_projid)(struct inode___120 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___120 *, qsize_t *);
	int (*get_next_id)(struct super_block___119 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___118 {
	int (*quota_on)(struct super_block___119 *, int, int, const struct path___118 *);
	int (*quota_off)(struct super_block___119 *, int);
	int (*quota_enable)(struct super_block___119 *, unsigned int);
	int (*quota_disable)(struct super_block___119 *, unsigned int);
	int (*quota_sync)(struct super_block___119 *, int);
	int (*set_info)(struct super_block___119 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___119 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___119 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___119 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___119 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___119 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___99 {
	struct kobject___113 kobj;
	struct module___102 *mod;
	struct kobject___113 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___99 {
	struct module___102 *mod;
	struct latch_tree_node node;
};

struct module_layout___99 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___99 mtn;
};

struct module_attribute___99;

struct kernel_param___99;

struct module___102 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___99 mkobj;
	struct module_attribute___99 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___113 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___99 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___99 core_layout;
	struct module_layout___99 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide53;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide54;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___40;

struct address_space_operations___118 {
	int (*writepage)(struct page___119 *, struct writeback_control___40 *);
	int (*readpage)(struct file___119 *, struct page___119 *);
	int (*writepages)(struct address_space___118 *, struct writeback_control___40 *);
	int (*set_page_dirty)(struct page___119 *);
	int (*readpages)(struct file___119 *, struct address_space___118 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___119 *, struct address_space___118 *, loff_t, unsigned int, unsigned int, struct page___119 **, void **);
	int (*write_end)(struct file___119 *, struct address_space___118 *, loff_t, unsigned int, unsigned int, struct page___119 *, void *);
	sector_t (*bmap)(struct address_space___118 *, sector_t);
	void (*invalidatepage)(struct page___119 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___119 *, gfp_t);
	void (*freepage)(struct page___119 *);
	ssize_t (*direct_IO)(struct kiocb___119 *, struct iov_iter___48 *);
	int (*migratepage)(struct address_space___118 *, struct page___119 *, struct page___119 *, enum migrate_mode);
	bool (*isolate_page)(struct page___119 *, isolate_mode_t);
	void (*putback_page)(struct page___119 *);
	int (*launder_page)(struct page___119 *);
	int (*is_partially_uptodate)(struct page___119 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___119 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___118 *, struct page___119 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___119 *, sector_t *);
	void (*swap_deactivate)(struct file___119 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___40 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___43 *wb;
	struct inode___120 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___43;

struct iov_iter___48 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___43 *bvec;
		struct pipe_inode_info___29 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___119 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___120 *bd_inode;
	struct super_block___119 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___119 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___43 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___118 {
	struct dentry___119 * (*lookup)(struct inode___120 *, struct dentry___119 *, unsigned int);
	const char * (*get_link)(struct dentry___119 *, struct inode___120 *, struct delayed_call *);
	int (*permission)(struct inode___120 *, int);
	struct posix_acl * (*get_acl)(struct inode___120 *, int);
	int (*readlink)(struct dentry___119 *, char *, int);
	int (*create)(struct inode___120 *, struct dentry___119 *, umode_t, bool);
	int (*link)(struct dentry___119 *, struct inode___120 *, struct dentry___119 *);
	int (*unlink)(struct inode___120 *, struct dentry___119 *);
	int (*symlink)(struct inode___120 *, struct dentry___119 *, const char *);
	int (*mkdir)(struct inode___120 *, struct dentry___119 *, umode_t);
	int (*rmdir)(struct inode___120 *, struct dentry___119 *);
	int (*mknod)(struct inode___120 *, struct dentry___119 *, umode_t, dev_t);
	int (*rename)(struct inode___120 *, struct dentry___119 *, struct inode___120 *, struct dentry___119 *, unsigned int);
	int (*setattr)(struct dentry___119 *, struct iattr___119 *);
	int (*getattr)(const struct path___118 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___119 *, char *, size_t);
	int (*fiemap)(struct inode___120 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___120 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___120 *, struct dentry___119 *, struct file___119 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___120 *, struct dentry___119 *, umode_t);
	int (*set_acl)(struct inode___120 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___118 {
	void (*fl_copy_lock)(struct file_lock___119 *, struct file_lock___119 *);
	void (*fl_release_private)(struct file_lock___119 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___118;

struct file_lock___119 {
	struct file_lock___119 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___119 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___118 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___118 *fl_ops;
	const struct lock_manager_operations___118 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___118 {
	int (*lm_compare_owner)(struct file_lock___119 *, struct file_lock___119 *);
	long unsigned int (*lm_owner_key)(struct file_lock___119 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___119 *);
	int (*lm_grant)(struct file_lock___119 *, int);
	bool (*lm_break)(struct file_lock___119 *);
	int (*lm_change)(struct file_lock___119 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___119 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___118 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___118 *fa_next;
	struct file___119 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___118 {
	const char *name;
	int fs_flags;
	struct dentry___119 * (*mount)(struct file_system_type___118 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___119 *);
	struct module___102 *owner;
	struct file_system_type___118 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___118 {
	struct inode___120 * (*alloc_inode)(struct super_block___119 *);
	void (*destroy_inode)(struct inode___120 *);
	void (*dirty_inode)(struct inode___120 *, int);
	int (*write_inode)(struct inode___120 *, struct writeback_control___40 *);
	int (*drop_inode)(struct inode___120 *);
	void (*evict_inode)(struct inode___120 *);
	void (*put_super)(struct super_block___119 *);
	int (*sync_fs)(struct super_block___119 *, int);
	int (*freeze_super)(struct super_block___119 *);
	int (*freeze_fs)(struct super_block___119 *);
	int (*thaw_super)(struct super_block___119 *);
	int (*unfreeze_fs)(struct super_block___119 *);
	int (*statfs)(struct dentry___119 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___119 *, int *, char *);
	void (*umount_begin)(struct super_block___119 *);
	int (*show_options)(struct seq_file___109 *, struct dentry___119 *);
	int (*show_devname)(struct seq_file___109 *, struct dentry___119 *);
	int (*show_path)(struct seq_file___109 *, struct dentry___119 *);
	int (*show_stats)(struct seq_file___109 *, struct dentry___119 *);
	ssize_t (*quota_read)(struct super_block___119 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___119 *, int, const char *, size_t, loff_t);
	struct dquot___118 ** (*get_dquots)(struct inode___120 *);
	int (*bdev_try_to_free_page)(struct super_block___119 *, struct page___119 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___119 *, struct shrink_control___38 *);
	long int (*free_cached_objects)(struct super_block___119 *, struct shrink_control___38 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___79)(struct file___119 *, wait_queue_head_t *, struct poll_table_struct___80 *);

struct poll_table_struct___80 {
	poll_queue_proc___79 _qproc;
	__poll_t _key;
};

typedef void bio_end_io_t___43(struct bio___43 *);

struct bio_vec___43 {
	struct page___119 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___43;

struct bio_set___43;

struct bio___43 {
	struct bio___43 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___43 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___43 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___43 *bi_io_vec;
	struct bio_set___43 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___43 bi_inline_vecs[0];
};

struct kobj_attribute___113 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___113 *, struct kobj_attribute___113 *, char *);
	ssize_t (*store)(struct kobject___113 *, struct kobj_attribute___113 *, const char *, size_t);
};

typedef void compound_page_dtor___116(struct page___119 *);

struct msghdr___7 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___48 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___119 *msg_iocb;
};

struct socket_wq___7 {
	wait_queue_head_t wait;
	struct fasync_struct___118 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct sock___10;

struct proto_ops___7;

struct socket___7 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___7 *wq;
	struct file___119 *file;
	struct sock___10 *sk;
	const struct proto_ops___7 *ops;
};

struct proto___7;

struct sock_common___7 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___7 *skc_prot;
	possible_net_t___17 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___10 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff_head___17 {
	struct sk_buff___20 *next;
	struct sk_buff___20 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___7;

struct dst_entry___9;

struct sock___10 {
	struct sock_common___7 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___17 sk_error_queue;
	struct sk_buff_head___17 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___20 *head;
		struct sk_buff___20 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___7 *sk_filter;
	union {
		struct socket_wq___7 *sk_wq;
		struct socket_wq___7 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___9 *sk_rx_dst;
	struct dst_entry___9 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___20 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___17 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___118 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___7 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___98 *sk_peer_pid;
	const struct cred___114 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___7 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___38 *sk_memcg;
	void (*sk_state_change)(struct sock___10 *);
	void (*sk_data_ready)(struct sock___10 *);
	void (*sk_write_space)(struct sock___10 *);
	void (*sk_error_report)(struct sock___10 *);
	int (*sk_backlog_rcv)(struct sock___10 *, struct sk_buff___20 *);
	struct sk_buff___20 * (*sk_validate_xmit_skb)(struct sock___10 *, struct net_device___21 *, struct sk_buff___20 *);
	void (*sk_destruct)(struct sock___10 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

typedef int (*sk_read_actor_t___7)(read_descriptor_t *, struct sk_buff___20 *, unsigned int, size_t);

struct proto_ops___7 {
	int family;
	struct module___102 *owner;
	int (*release)(struct socket___7 *);
	int (*bind)(struct socket___7 *, struct sockaddr *, int);
	int (*connect)(struct socket___7 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___7 *, struct socket___7 *);
	int (*accept)(struct socket___7 *, struct socket___7 *, int, bool);
	int (*getname)(struct socket___7 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___119 *, struct socket___7 *, struct poll_table_struct___80 *);
	int (*ioctl)(struct socket___7 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___7 *, int);
	int (*shutdown)(struct socket___7 *, int);
	int (*setsockopt)(struct socket___7 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___7 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___7 *, struct msghdr___7 *, size_t);
	int (*recvmsg)(struct socket___7 *, struct msghdr___7 *, size_t, int);
	int (*mmap)(struct file___119 *, struct socket___7 *, struct vm_area_struct___119 *);
	ssize_t (*sendpage)(struct socket___7 *, struct page___119 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___7 *, loff_t *, struct pipe_inode_info___29 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___10 *, int);
	int (*peek_len)(struct socket___7 *);
	int (*read_sock)(struct sock___10 *, read_descriptor_t *, sk_read_actor_t___7);
	int (*sendpage_locked)(struct sock___10 *, struct page___119 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___10 *, struct msghdr___7 *, size_t);
	int (*set_rcvlowat)(struct sock___10 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct nf_bridge_info___16;

struct sk_buff___20 {
	union {
		struct {
			struct sk_buff___20 *next;
			struct sk_buff___20 *prev;
			union {
				struct net_device___21 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___10 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___20 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___16 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___16;

struct netns_frags___16 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___16 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_rules_ops___7;

struct fib_notifier_ops___7;

struct netns_ipv4___16 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___7 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___10 *fibnl;
	struct sock___10 **icmp_sk;
	struct sock___10 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___10 **tcp_sk;
	struct netns_frags___16 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___7 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___7 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___7 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___9;

struct dst_ops___24 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___24 *);
	struct dst_entry___9 * (*check)(struct dst_entry___9 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___9 *);
	unsigned int (*mtu)(const struct dst_entry___9 *);
	u32 * (*cow_metrics)(struct dst_entry___9 *, long unsigned int);
	void (*destroy)(struct dst_entry___9 *);
	void (*ifdown)(struct dst_entry___9 *, struct net_device___21 *, int);
	struct dst_entry___9 * (*negative_advice)(struct dst_entry___9 *);
	void (*link_failure)(struct sk_buff___20 *);
	void (*update_pmtu)(struct dst_entry___9 *, struct sock___10 *, struct sk_buff___20 *, u32);
	void (*redirect)(struct dst_entry___9 *, struct sock___10 *, struct sk_buff___20 *);
	int (*local_out)(struct net___26 *, struct sock___10 *, struct sk_buff___20 *);
	struct neighbour___9 * (*neigh_lookup)(const struct dst_entry___9 *, struct sk_buff___20 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___9 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___23 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___16 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___24 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___7 *fib6_rules_ops;
	struct sock___10 **icmp_sk;
	struct sock___10 *ndisc_sk;
	struct sock___10 *tcp_sk;
	struct sock___10 *igmp_sk;
	struct sock___10 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___7 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___7 *notifier_ops;
	struct fib_notifier_ops___7 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___7 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___10 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___16 {
	struct netns_frags___16 frags;
};

struct netns_xfrm___23 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___10 *nlsk;
	struct sock___10 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___24 xfrm4_dst_ops;
	struct dst_ops___24 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct net___26 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___99 *user_ns;
	struct ucounts___99 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___7 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___10 *rtnl;
	struct sock___10 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___21 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___16 ipv4;
	struct netns_ipv6___23 ipv6;
	struct netns_sctp___7 sctp;
	struct netns_nf nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___16 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___10 *nfnl;
	struct sock___10 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___23 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___10 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___15 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kernfs_root___115;

struct kernfs_elem_dir___115 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___115 *root;
};

struct kernfs_syscall_ops___115;

struct kernfs_root___115 {
	struct kernfs_node___115 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___115 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___115 {
	struct kernfs_node___115 *target_kn;
};

struct kernfs_ops___115;

struct kernfs_elem_attr___115 {
	const struct kernfs_ops___115 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___115 *notify_next;
};

struct kernfs_node___115 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___115 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___115 dir;
		struct kernfs_elem_symlink___115 symlink;
		struct kernfs_elem_attr___115 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___115;

struct kernfs_ops___115 {
	int (*open)(struct kernfs_open_file___115 *);
	void (*release)(struct kernfs_open_file___115 *);
	int (*seq_show)(struct seq_file___109 *, void *);
	void * (*seq_start)(struct seq_file___109 *, loff_t *);
	void * (*seq_next)(struct seq_file___109 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___109 *, void *);
	ssize_t (*read)(struct kernfs_open_file___115 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___115 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___115 *, struct vm_area_struct___119 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___115 *, struct poll_table_struct___80 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___115 {
	int (*remount_fs)(struct kernfs_root___115 *, int *, char *);
	int (*show_options)(struct seq_file___109 *, struct kernfs_root___115 *);
	int (*mkdir)(struct kernfs_node___115 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___115 *);
	int (*rename)(struct kernfs_node___115 *, struct kernfs_node___115 *, const char *);
	int (*show_path)(struct seq_file___109 *, struct kernfs_node___115 *, struct kernfs_root___115 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___115 {
	struct kernfs_node___115 *kn;
	struct file___119 *file;
	struct seq_file___109 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___116 *vm_ops;
};

struct kobj_ns_type_operations___7 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___10 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___109;

struct attribute_group___109 {
	const char *name;
	umode_t (*is_visible)(struct kobject___113 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___113 *, struct bin_attribute___109 *, int);
	struct attribute **attrs;
	struct bin_attribute___109 **bin_attrs;
};

struct bin_attribute___109 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___119 *, struct kobject___113 *, struct bin_attribute___109 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___119 *, struct kobject___113 *, struct bin_attribute___109 *, char *, loff_t, size_t);
	int (*mmap)(struct file___119 *, struct kobject___113 *, struct bin_attribute___109 *, struct vm_area_struct___119 *);
};

struct sysfs_ops___112 {
	ssize_t (*show)(struct kobject___113 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___113 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___112;

struct kset___112 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___113 kobj;
	const struct kset_uevent_ops___112 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___112 {
	void (*release)(struct kobject___113 *);
	const struct sysfs_ops___112 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___7 * (*child_ns_type)(struct kobject___113 *);
	const void * (*namespace)(struct kobject___113 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___112 {
	int (* const filter)(struct kset___112 *, struct kobject___113 *);
	const char * (* const name)(struct kset___112 *, struct kobject___113 *);
	int (* const uevent)(struct kset___112 *, struct kobject___113 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___110 {
	int (*prepare)(struct device___110 *);
	void (*complete)(struct device___110 *);
	int (*suspend)(struct device___110 *);
	int (*resume)(struct device___110 *);
	int (*freeze)(struct device___110 *);
	int (*thaw)(struct device___110 *);
	int (*poweroff)(struct device___110 *);
	int (*restore)(struct device___110 *);
	int (*suspend_late)(struct device___110 *);
	int (*resume_early)(struct device___110 *);
	int (*freeze_late)(struct device___110 *);
	int (*thaw_early)(struct device___110 *);
	int (*poweroff_late)(struct device___110 *);
	int (*restore_early)(struct device___110 *);
	int (*suspend_noirq)(struct device___110 *);
	int (*resume_noirq)(struct device___110 *);
	int (*freeze_noirq)(struct device___110 *);
	int (*thaw_noirq)(struct device___110 *);
	int (*poweroff_noirq)(struct device___110 *);
	int (*restore_noirq)(struct device___110 *);
	int (*runtime_suspend)(struct device___110 *);
	int (*runtime_resume)(struct device___110 *);
	int (*runtime_idle)(struct device___110 *);
};

struct dev_pm_domain___110 {
	struct dev_pm_ops___110 ops;
	void (*detach)(struct device___110 *, bool);
	int (*activate)(struct device___110 *);
	void (*sync)(struct device___110 *);
	void (*dismiss)(struct device___110 *);
};

struct bus_type___110 {
	const char *name;
	const char *dev_name;
	struct device___110 *dev_root;
	const struct attribute_group___109 **bus_groups;
	const struct attribute_group___109 **dev_groups;
	const struct attribute_group___109 **drv_groups;
	int (*match)(struct device___110 *, struct device_driver___110 *);
	int (*uevent)(struct device___110 *, struct kobj_uevent_env *);
	int (*probe)(struct device___110 *);
	int (*remove)(struct device___110 *);
	void (*shutdown)(struct device___110 *);
	int (*online)(struct device___110 *);
	int (*offline)(struct device___110 *);
	int (*suspend)(struct device___110 *, pm_message_t);
	int (*resume)(struct device___110 *);
	int (*num_vf)(struct device___110 *);
	int (*dma_configure)(struct device___110 *);
	const struct dev_pm_ops___110 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___110 {
	const char *name;
	struct bus_type___110 *bus;
	struct module___102 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___110 *);
	int (*remove)(struct device___110 *);
	void (*shutdown)(struct device___110 *);
	int (*suspend)(struct device___110 *, pm_message_t);
	int (*resume)(struct device___110 *);
	const struct attribute_group___109 **groups;
	const struct dev_pm_ops___110 *pm;
	void (*coredump)(struct device___110 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___110 {
	const char *name;
	const struct attribute_group___109 **groups;
	int (*uevent)(struct device___110 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___110 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___110 *);
	const struct dev_pm_ops___110 *pm;
};

struct class___110 {
	const char *name;
	struct module___102 *owner;
	const struct attribute_group___109 **class_groups;
	const struct attribute_group___109 **dev_groups;
	struct kobject___113 *dev_kobj;
	int (*dev_uevent)(struct device___110 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___110 *, umode_t *);
	void (*class_release)(struct class___110 *);
	void (*dev_release)(struct device___110 *);
	int (*shutdown_pre)(struct device___110 *);
	const struct kobj_ns_type_operations___7 *ns_type;
	const void * (*namespace)(struct device___110 *);
	const struct dev_pm_ops___110 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___32 {
	void * (*alloc)(struct device___110 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___110 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___110 *, struct vm_area_struct___119 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___110 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___110 *, struct page___119 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___110 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___110 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___110 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___110 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___110 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___110 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___110 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___110 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___110 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___110 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___110 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___110 *, u64);
	u64 (*get_required_mask)(struct device___110 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___82;

struct fwnode_handle___82 {
	struct fwnode_handle___82 *secondary;
	const struct fwnode_operations___82 *ops;
};

struct fwnode_reference_args___82;

struct fwnode_endpoint___82;

struct fwnode_operations___82 {
	struct fwnode_handle___82 * (*get)(struct fwnode_handle___82 *);
	void (*put)(struct fwnode_handle___82 *);
	bool (*device_is_available)(const struct fwnode_handle___82 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___82 *, const struct device___110 *);
	bool (*property_present)(const struct fwnode_handle___82 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___82 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___82 *, const char *, const char **, size_t);
	struct fwnode_handle___82 * (*get_parent)(const struct fwnode_handle___82 *);
	struct fwnode_handle___82 * (*get_next_child_node)(const struct fwnode_handle___82 *, struct fwnode_handle___82 *);
	struct fwnode_handle___82 * (*get_named_child_node)(const struct fwnode_handle___82 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___82 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___82 *);
	struct fwnode_handle___82 * (*graph_get_next_endpoint)(const struct fwnode_handle___82 *, struct fwnode_handle___82 *);
	struct fwnode_handle___82 * (*graph_get_remote_endpoint)(const struct fwnode_handle___82 *);
	struct fwnode_handle___82 * (*graph_get_port_parent)(struct fwnode_handle___82 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___82 *, struct fwnode_endpoint___82 *);
};

struct fwnode_endpoint___82 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___82 *local_fwnode;
};

struct fwnode_reference_args___82 {
	struct fwnode_handle___82 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___29;

struct pipe_buffer___29 {
	struct page___119 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___29 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___29 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___29 *, struct pipe_buffer___29 *);
	void (*release)(struct pipe_inode_info___29 *, struct pipe_buffer___29 *);
	int (*steal)(struct pipe_inode_info___29 *, struct pipe_buffer___29 *);
	union {
		bool (*get)(struct pipe_inode_info___29 *, struct pipe_buffer___29 *);
		struct {
			void (*get)(struct pipe_inode_info___29 *, struct pipe_buffer___29 *);
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
};

struct nf_bridge_info___16 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___16 = 0,
		BRNF_PROTO_8021Q___16 = 1,
		BRNF_PROTO_PPPOE___16 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___21 *physindev;
	struct net_device___21 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

struct ethtool_ops___16 {
	int (*get_settings)(struct net_device___21 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___21 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___21 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___21 *);
	void (*get_regs)(struct net_device___21 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___21 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___21 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___21 *);
	void (*set_msglevel)(struct net_device___21 *, u32);
	int (*nway_reset)(struct net_device___21 *);
	u32 (*get_link)(struct net_device___21 *);
	int (*get_eeprom_len)(struct net_device___21 *);
	int (*get_eeprom)(struct net_device___21 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___21 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___21 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___21 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___21 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___21 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___21 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___21 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___21 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___21 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___21 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___21 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___21 *);
	void (*complete)(struct net_device___21 *);
	u32 (*get_priv_flags)(struct net_device___21 *);
	int (*set_priv_flags)(struct net_device___21 *, u32);
	int (*get_sset_count)(struct net_device___21 *, int);
	int (*get_rxnfc)(struct net_device___21 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___21 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___21 *, struct ethtool_flash *);
	int (*reset)(struct net_device___21 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___21 *);
	u32 (*get_rxfh_indir_size)(struct net_device___21 *);
	int (*get_rxfh)(struct net_device___21 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___21 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___21 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___21 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___21 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___21 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___21 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___21 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___21 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___21 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___21 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___21 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___21 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___21 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___21 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___21 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___21 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___21 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___21 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___21 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___21 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___21 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	int (*get_fecparam)(struct net_device___21 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___21 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___21 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___21 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___21 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___16;

struct inet_frags___16 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___16 *, const void *);
	void (*destructor)(struct inet_frag_queue___16 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___16 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___20 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___20 *fragments_tail;
	struct sk_buff___20 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___16 *net;
	struct callback_head rcu;
};

struct fib_rule___7;

struct fib_lookup_arg___7;

struct fib_rules_ops___7 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___7 *, struct flowi *, int, struct fib_lookup_arg___7 *);
	bool (*suppress)(struct fib_rule___7 *, struct fib_lookup_arg___7 *);
	int (*match)(struct fib_rule___7 *, struct flowi *, int);
	int (*configure)(struct fib_rule___7 *, struct sk_buff___20 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___7 *);
	int (*compare)(struct fib_rule___7 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___7 *, struct sk_buff___20 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___7 *);
	void (*flush_cache)(struct fib_rules_ops___7 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___102 *owner;
	struct net___26 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___7 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___26 *);
	int (*fib_dump)(struct net___26 *, struct notifier_block *);
	struct module___102 *owner;
	struct callback_head rcu;
};

struct dst_entry___9 {
	struct net_device___21 *dev;
	struct dst_ops___24 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___20 *);
	int (*output)(struct net___26 *, struct sock___10 *, struct sk_buff___20 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___8;

struct neigh_parms___9;

struct neigh_ops___8;

struct neighbour___9 {
	struct neighbour___9 *next;
	struct neigh_table___8 *tbl;
	struct neigh_parms___9 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___17 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___9 *, struct sk_buff___20 *);
	const struct neigh_ops___8 *ops;
	struct callback_head rcu;
	struct net_device___21 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct ucounts___99 {
	struct hlist_node node;
	struct user_namespace___99 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

typedef int (*key_restrict_link_func_t___114)(struct key___114 *, const struct key_type *, const union key_payload *, struct key___114 *);

struct key_restriction___114;

struct key___114 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___119 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___114 *restrict_link;
};

struct key_restriction___114 {
	key_restrict_link_func_t___114 check;
	struct key___114 *key;
	struct key_type *keytype;
};

struct seq_operations___107 {
	void * (*start)(struct seq_file___109 *, loff_t *);
	void (*stop)(struct seq_file___109 *, void *);
	void * (*next)(struct seq_file___109 *, void *, loff_t *);
	int (*show)(struct seq_file___109 *, void *);
};

struct pernet_operations___16 {
	struct list_head list;
	int (*init)(struct net___26 *);
	void (*exit)(struct net___26 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___16 {
	int (*ieee_getets)(struct net_device___21 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___21 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___21 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___21 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___21 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___21 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___21 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___21 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___21 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___21 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___21 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___21 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___21 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___21 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___21 *);
	u8 (*setstate)(struct net_device___21 *, u8);
	void (*getpermhwaddr)(struct net_device___21 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___21 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___21 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___21 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___21 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___21 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___21 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___21 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___21 *, int, u8 *);
	void (*setpfccfg)(struct net_device___21 *, int, u8);
	void (*getpfccfg)(struct net_device___21 *, int, u8 *);
	u8 (*setall)(struct net_device___21 *);
	u8 (*getcap)(struct net_device___21 *, int, u8 *);
	int (*getnumtcs)(struct net_device___21 *, int, u8 *);
	int (*setnumtcs)(struct net_device___21 *, int, u8);
	u8 (*getpfcstate)(struct net_device___21 *);
	void (*setpfcstate)(struct net_device___21 *, u8);
	void (*getbcncfg)(struct net_device___21 *, int, u32 *);
	void (*setbcncfg)(struct net_device___21 *, int, u32);
	void (*getbcnrp)(struct net_device___21 *, int, u8 *);
	void (*setbcnrp)(struct net_device___21 *, int, u8);
	int (*setapp)(struct net_device___21 *, u8, u16, u8);
	int (*getapp)(struct net_device___21 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___21 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___21 *, int, u8);
	u8 (*getdcbx)(struct net_device___21 *);
	u8 (*setdcbx)(struct net_device___21 *, u8);
	int (*peer_getappinfo)(struct net_device___21 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___21 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___21 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___21 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___21 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___21 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___95 {
	refcount_t count;
	struct ns_common___7 ns;
	struct user_namespace___99 *user_ns;
	struct ucounts___99 *ucounts;
	struct css_set___95 *root_cset;
};

struct cgroup_bpf___15 {
	struct bpf_prog_array___15 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___15 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___95;

typedef void (*kthread_work_func_t___95)(struct kthread_work___95 *);

struct kthread_worker___95;

struct kthread_work___95 {
	struct list_head node;
	kthread_work_func_t___95 func;
	struct kthread_worker___95 *worker;
	int canceling;
};

struct kthread_worker___95 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___119 *task;
	struct kthread_work___95 *current_work;
};

struct kthread_delayed_work___95 {
	struct kthread_work___95 work;
	struct timer_list timer;
};

struct psi_group___95 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___95 *poll_kworker;
	struct kthread_delayed_work___95 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___95;

struct cgroup_rstat_cpu___95;

struct cgroup___95 {
	struct cgroup_subsys_state___95 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___115 *kn;
	struct cgroup_file___95 procs_file;
	struct cgroup_file___95 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___95 *subsys[13];
	struct cgroup_root___95 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___95 *dom_cgrp;
	struct cgroup_rstat_cpu___95 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___15 bpf;
	atomic_t congestion_count;
	struct cgroup___95 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___95 psi;
	int ancestor_ids[0];
};

struct cftype___95;

struct cgroup_subsys___95 {
	struct cgroup_subsys_state___95 * (*css_alloc)(struct cgroup_subsys_state___95 *);
	int (*css_online)(struct cgroup_subsys_state___95 *);
	void (*css_offline)(struct cgroup_subsys_state___95 *);
	void (*css_released)(struct cgroup_subsys_state___95 *);
	void (*css_free)(struct cgroup_subsys_state___95 *);
	void (*css_reset)(struct cgroup_subsys_state___95 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___95 *, int);
	int (*css_extra_stat_show)(struct seq_file___109 *, struct cgroup_subsys_state___95 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___119 *);
	void (*cancel_fork)(struct task_struct___119 *);
	void (*fork)(struct task_struct___119 *);
	void (*exit)(struct task_struct___119 *);
	void (*free)(struct task_struct___119 *);
	void (*bind)(struct cgroup_subsys_state___95 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___95 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___95 *dfl_cftypes;
	struct cftype___95 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___95 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___95 *updated_children;
	struct cgroup___95 *updated_next;
};

struct cgroup_root___95 {
	struct kernfs_root___115 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___95 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___95 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___95 *ss;
	struct list_head node;
	struct kernfs_ops___115 *kf_ops;
	int (*open)(struct kernfs_open_file___115 *);
	void (*release)(struct kernfs_open_file___115 *);
	u64 (*read_u64)(struct cgroup_subsys_state___95 *, struct cftype___95 *);
	s64 (*read_s64)(struct cgroup_subsys_state___95 *, struct cftype___95 *);
	int (*seq_show)(struct seq_file___109 *, void *);
	void * (*seq_start)(struct seq_file___109 *, loff_t *);
	void * (*seq_next)(struct seq_file___109 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___109 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___95 *, struct cftype___95 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___95 *, struct cftype___95 *, s64);
	ssize_t (*write)(struct kernfs_open_file___115 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___115 *, struct poll_table_struct___80 *);
};

struct xdp_rxq_info___16 {
	struct net_device___21 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_buff___2 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	long unsigned int handle;
	struct xdp_rxq_info___16 *rxq;
};

struct xdp_frame___16 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___21 *dev_rx;
};

struct netlink_callback___16 {
	struct sk_buff___20 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___16 *);
	int (*dump)(struct sk_buff___20 *, struct netlink_callback___16 *);
	int (*done)(struct netlink_callback___16 *);
	void *data;
	struct module___102 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___16 {
	int (*create)(struct sk_buff___20 *, struct net_device___21 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___20 *, unsigned char *);
	int (*cache)(const struct neighbour___9 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___21 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___16 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___16 *, int);
	int poll_owner;
	struct net_device___21 *dev;
	struct sk_buff___20 *gro_list;
	struct sk_buff___20 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct xsk_queue;

struct xdp_umem_page;

struct xdp_umem_fq_reuse;

struct xdp_umem {
	struct xsk_queue *fq;
	struct xsk_queue *cq;
	struct xdp_umem_page *pages;
	u64 chunk_mask;
	u64 size;
	u32 headroom;
	u32 chunk_size_nohr;
	struct user_struct___114 *user;
	struct pid___98 *pid;
	long unsigned int address;
	refcount_t users;
	struct work_struct work;
	struct page___119 **pgs;
	u32 npgs;
	struct net_device___21 *dev;
	struct xdp_umem_fq_reuse *fq_reuse;
	u16 queue_id;
	bool zc;
	spinlock_t xsk_list_lock;
	struct list_head xsk_list;
};

struct netdev_queue___16 {
	struct net_device___21 *dev;
	struct Qdisc___15 *qdisc;
	struct Qdisc___15 *qdisc_sleeping;
	struct kobject___113 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___21 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___15 {
	struct sk_buff___20 *head;
	struct sk_buff___20 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___15;

struct Qdisc___15 {
	int (*enqueue)(struct sk_buff___20 *, struct Qdisc___15 *, struct sk_buff___20 **);
	struct sk_buff___20 * (*dequeue)(struct Qdisc___15 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___15 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___16 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___17 gso_skb;
	struct qdisc_skb_head___15 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___15 *next_sched;
	struct sk_buff_head___17 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___16 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___113 kobj;
	struct net_device___21 *dev;
	long: 64;
	struct xdp_rxq_info___16 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___16)(struct net_device___21 *, struct sk_buff___20 *, struct net_device___21 *);

struct netdev_bpf___16 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___15 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___15 *prog;
			const struct bpf_prog_offload_ops___15 *ops;
		} verifier;
		struct {
			struct bpf_prog___15 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___16 *offmap;
		};
		struct {
			struct xdp_umem *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___16 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___20 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___16 {
	int (*tls_dev_add)(struct net_device___21 *, struct sock___10 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___21 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___21 *, struct sock___10 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___16 {
	int (*ndo_init)(struct net_device___21 *);
	void (*ndo_uninit)(struct net_device___21 *);
	int (*ndo_open)(struct net_device___21 *);
	int (*ndo_stop)(struct net_device___21 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___20 *, struct net_device___21 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___20 *, struct net_device___21 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___21 *, struct sk_buff___20 *, struct net_device___21 *, select_queue_fallback_t___16);
	void (*ndo_change_rx_flags)(struct net_device___21 *, int);
	void (*ndo_set_rx_mode)(struct net_device___21 *);
	int (*ndo_set_mac_address)(struct net_device___21 *, void *);
	int (*ndo_validate_addr)(struct net_device___21 *);
	int (*ndo_do_ioctl)(struct net_device___21 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___21 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___21 *, int);
	int (*ndo_neigh_setup)(struct net_device___21 *, struct neigh_parms___9 *);
	void (*ndo_tx_timeout)(struct net_device___21 *);
	void (*ndo_get_stats64)(struct net_device___21 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___21 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___21 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___21 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___21 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___21 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___21 *);
	int (*ndo_netpoll_setup)(struct net_device___21 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___21 *);
	int (*ndo_set_vf_mac)(struct net_device___21 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___21 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___21 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___21 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___21 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___21 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___21 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___21 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___21 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___21 *, int, struct sk_buff___20 *);
	int (*ndo_set_vf_guid)(struct net_device___21 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___21 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___21 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___21 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___21 *, const struct sk_buff___20 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___21 *, struct net_device___21 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___21 *, struct net_device___21 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___21 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___21 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___21 *, struct neighbour___9 *);
	void (*ndo_neigh_destroy)(struct net_device___21 *, struct neighbour___9 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___21 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___21 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___21 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___20 *, struct netlink_callback___16 *, struct net_device___21 *, struct net_device___21 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___21 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___21 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___20 *, u32, u32, struct net_device___21 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___21 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___21 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___21 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___21 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___21 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___21 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___21 *, struct net_device___21 *);
	void (*ndo_dfwd_del_station)(struct net_device___21 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___21 *);
	int (*ndo_set_tx_maxrate)(struct net_device___21 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___21 *);
	int (*ndo_change_proto_down)(struct net_device___21 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___21 *, struct sk_buff___20 *);
	void (*ndo_set_rx_headroom)(struct net_device___21 *, int);
	int (*ndo_bpf)(struct net_device___21 *, struct netdev_bpf___16 *);
	int (*ndo_xdp_xmit)(struct net_device___21 *, int, struct xdp_frame___16 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___21 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___21 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___9 {
	possible_net_t___17 net;
	struct net_device___21 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___9 *);
	void (*neigh_cleanup)(struct neighbour___9 *);
	struct neigh_table___8 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___8 {
	u32 (*l3mdev_fib_table)(const struct net_device___21 *);
	struct sk_buff___20 * (*l3mdev_l3_rcv)(struct net_device___21 *, struct sk_buff___20 *, u16);
	struct sk_buff___20 * (*l3mdev_l3_out)(struct net_device___21 *, struct sock___10 *, struct sk_buff___20 *, u16);
	struct dst_entry___9 * (*l3mdev_link_scope_lookup)(const struct net_device___21 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct tcf_proto___15;

struct mini_Qdisc___15 {
	struct tcf_proto___15 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___15 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___21 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___26 *, struct net_device___21 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___21 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___21 *, struct list_head *);
	size_t (*get_size)(const struct net_device___21 *);
	int (*fill_info)(struct sk_buff___20 *, const struct net_device___21 *);
	size_t (*get_xstats_size)(const struct net_device___21 *);
	int (*fill_xstats)(struct sk_buff___20 *, const struct net_device___21 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___21 *, struct net_device___21 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___21 *, const struct net_device___21 *);
	int (*fill_slave_info)(struct sk_buff___20 *, const struct net_device___21 *, const struct net_device___21 *);
	struct net___26 * (*get_link_net)(const struct net_device___21 *);
	size_t (*get_linkxstats_size)(const struct net_device___21 *, int);
	int (*fill_linkxstats)(struct sk_buff___20 *, const struct net_device___21 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___16 {
	struct list_head poll_list;
	struct sk_buff_head___17 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___16 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___15 *output_queue;
	struct Qdisc___15 **output_queue_tailp;
	struct sk_buff___20 *completion_queue;
	struct sk_buff_head___17 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___16 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___17 input_pkt_queue;
	struct napi_struct___16 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bdi_writeback_congested___43 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___43 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___43 {
	struct bio___43 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___43 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___43 bip_inline_vecs[0];
};

struct bio_set___43 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___43 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___38 {
	struct mem_cgroup___38 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___38 {
	struct lruvec___118 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___38 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___38 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct kernel_param_ops___99 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___99 *);
	int (*get)(char *, const struct kernel_param___99 *);
	void (*free)(void *);
};

struct kparam_array___99;

struct kernel_param___99 {
	const char *name;
	struct module___102 *mod;
	const struct kernel_param_ops___99 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___99 *arr;
	};
};

struct kparam_array___99 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___99 *ops;
	void *elem;
};

struct module_attribute___99 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___99 *, struct module_kobject___99 *, char *);
	ssize_t (*store)(struct module_attribute___99 *, struct module_kobject___99 *, const char *, size_t);
	void (*setup)(struct module___102 *, const char *);
	int (*test)(struct module___102 *);
	void (*free)(struct module___102 *);
};

struct gnet_dump___15 {
	spinlock_t *lock;
	struct sk_buff___20 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___15;

struct Qdisc_ops___15 {
	struct Qdisc_ops___15 *next;
	const struct Qdisc_class_ops___15 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___20 *, struct Qdisc___15 *, struct sk_buff___20 **);
	struct sk_buff___20 * (*dequeue)(struct Qdisc___15 *);
	struct sk_buff___20 * (*peek)(struct Qdisc___15 *);
	int (*init)(struct Qdisc___15 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___15 *);
	void (*destroy)(struct Qdisc___15 *);
	int (*change)(struct Qdisc___15 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___15 *);
	int (*change_tx_queue_len)(struct Qdisc___15 *, unsigned int);
	int (*dump)(struct Qdisc___15 *, struct sk_buff___20 *);
	int (*dump_stats)(struct Qdisc___15 *, struct gnet_dump___15 *);
	void (*ingress_block_set)(struct Qdisc___15 *, u32);
	void (*egress_block_set)(struct Qdisc___15 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___15 *);
	u32 (*egress_block_get)(struct Qdisc___15 *);
	struct module___102 *owner;
};

struct tcf_block___15;

struct Qdisc_class_ops___15 {
	unsigned int flags;
	struct netdev_queue___16 * (*select_queue)(struct Qdisc___15 *, struct tcmsg *);
	int (*graft)(struct Qdisc___15 *, long unsigned int, struct Qdisc___15 *, struct Qdisc___15 **, struct netlink_ext_ack *);
	struct Qdisc___15 * (*leaf)(struct Qdisc___15 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___15 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___15 *, u32);
	int (*change)(struct Qdisc___15 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___15 *, long unsigned int);
	void (*walk)(struct Qdisc___15 *, struct qdisc_walker *);
	struct tcf_block___15 * (*tcf_block)(struct Qdisc___15 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___15 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___15 *, long unsigned int);
	int (*dump)(struct Qdisc___15 *, long unsigned int, struct sk_buff___20 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___15 *, long unsigned int, struct gnet_dump___15 *);
};

struct tcf_chain___15;

struct tcf_block___15 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___26 *net;
	struct Qdisc___15 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___15 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___15;

struct tcf_proto_ops___15;

struct tcf_proto___15 {
	struct tcf_proto___15 *next;
	void *root;
	int (*classify)(struct sk_buff___20 *, const struct tcf_proto___15 *, struct tcf_result___15 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___15 *ops;
	struct tcf_chain___15 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___15 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___15 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___15 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___20 *, const struct tcf_proto___15 *, struct tcf_result___15 *);
	int (*init)(struct tcf_proto___15 *);
	void (*destroy)(struct tcf_proto___15 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___15 *, u32);
	void (*put)(struct tcf_proto___15 *, void *);
	int (*change)(struct net___26 *, struct sk_buff___20 *, struct tcf_proto___15 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___15 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___15 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___15 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___26 *, struct tcf_chain___15 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___26 *, struct tcf_proto___15 *, void *, struct sk_buff___20 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___20 *, struct net___26 *, void *);
	struct module___102 *owner;
	int flags;
};

struct tcf_chain___15 {
	struct mutex filter_chain_lock;
	struct tcf_proto___15 *filter_chain;
	struct list_head list;
	struct tcf_block___15 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___15 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___7 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___15 *prog;
};

struct bpf_redirect_info___15 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___95 *map;
	struct bpf_map___95 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___7;

struct neigh_hash_table___7;

struct neigh_table___8 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___21 *, __u32 *);
	bool (*key_eq)(const struct neighbour___9 *, const void *);
	int (*constructor)(struct neighbour___9 *);
	int (*pconstructor)(struct pneigh_entry___7 *);
	void (*pdestructor)(struct pneigh_entry___7 *);
	void (*proxy_redo)(struct sk_buff___20 *);
	char *id;
	struct neigh_parms___9 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___17 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___7 *nht;
	struct pneigh_entry___7 **phash_buckets;
};

struct neigh_ops___8 {
	int family;
	void (*solicit)(struct neighbour___9 *, struct sk_buff___20 *);
	void (*error_report)(struct neighbour___9 *, struct sk_buff___20 *);
	int (*output)(struct neighbour___9 *, struct sk_buff___20 *);
	int (*connected_output)(struct neighbour___9 *, struct sk_buff___20 *);
};

struct pneigh_entry___7 {
	struct pneigh_entry___7 *next;
	possible_net_t___17 net;
	struct net_device___21 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___7 {
	struct neighbour___9 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___7 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___7 *ctarget;
	struct net___26 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___7 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___7 *rule;
	u32 table;
	int flags;
};

struct proto___7 {
	void (*close)(struct sock___10 *, long int);
	int (*pre_connect)(struct sock___10 *, struct sockaddr *, int);
	int (*connect)(struct sock___10 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___10 *, int);
	struct sock___10 * (*accept)(struct sock___10 *, int, int *, bool);
	int (*ioctl)(struct sock___10 *, int, long unsigned int);
	int (*init)(struct sock___10 *);
	void (*destroy)(struct sock___10 *);
	void (*shutdown)(struct sock___10 *, int);
	int (*setsockopt)(struct sock___10 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___10 *, int, int, char *, int *);
	void (*keepalive)(struct sock___10 *, int);
	int (*sendmsg)(struct sock___10 *, struct msghdr___7 *, size_t);
	int (*recvmsg)(struct sock___10 *, struct msghdr___7 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___10 *, struct page___119 *, int, size_t, int);
	int (*bind)(struct sock___10 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___10 *, struct sk_buff___20 *);
	void (*release_cb)(struct sock___10 *);
	int (*hash)(struct sock___10 *);
	void (*unhash)(struct sock___10 *);
	void (*rehash)(struct sock___10 *);
	int (*get_port)(struct sock___10 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___10 *);
	bool (*stream_memory_read)(const struct sock___10 *);
	void (*enter_memory_pressure)(struct sock___10 *);
	void (*leave_memory_pressure)(struct sock___10 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___3 *rsk_prot;
	struct timewait_sock_ops___3 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___102 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___10 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct xdp_umem_page {
	void *addr;
	dma_addr_t dma;
};

struct xdp_umem_fq_reuse {
	u32 nentries;
	u32 length;
	u64 handles[0];
};

struct xdp_sock {
	struct sock___10 sk;
	struct xsk_queue *rx;
	struct net_device___21 *dev;
	struct xdp_umem *umem;
	struct list_head flush_node;
	u16 queue_id;
	long: 48;
	long: 64;
	long: 64;
	long: 64;
	struct xsk_queue *tx;
	struct list_head list;
	bool zc;
	struct mutex mutex;
	spinlock_t tx_completion_lock;
	u64 rx_dropped;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xsk_map {
	struct bpf_map___95 map;
	struct xdp_sock **xsk_map;
	struct list_head *flush_list;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module___103;

struct file___120;

struct kiocb___120;

struct iov_iter___49;

struct vm_area_struct___120;

struct inode___121;

struct file_lock___120;

struct page___120;

struct pipe_inode_info___30;

struct seq_file___110;

struct file_operations___120 {
	struct module___103 *owner;
	loff_t (*llseek)(struct file___120 *, loff_t, int);
	ssize_t (*read)(struct file___120 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___120 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___120 *, struct iov_iter___49 *);
	ssize_t (*write_iter)(struct kiocb___120 *, struct iov_iter___49 *);
	int (*iopoll)(struct kiocb___120 *, bool);
	int (*iterate)(struct file___120 *, struct dir_context *);
	int (*iterate_shared)(struct file___120 *, struct dir_context *);
	__poll_t (*poll)(struct file___120 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___120 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___120 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___120 *, struct vm_area_struct___120 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___121 *, struct file___120 *);
	int (*flush)(struct file___120 *, fl_owner_t);
	int (*release)(struct inode___121 *, struct file___120 *);
	int (*fsync)(struct file___120 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___120 *, int);
	int (*lock)(struct file___120 *, int, struct file_lock___120 *);
	ssize_t (*sendpage)(struct file___120 *, struct page___120 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___120 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___120 *, int, struct file_lock___120 *);
	ssize_t (*splice_write)(struct pipe_inode_info___30 *, struct file___120 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___120 *, loff_t *, struct pipe_inode_info___30 *, size_t, unsigned int);
	int (*setlease)(struct file___120 *, long int, struct file_lock___120 **, void **);
	long int (*fallocate)(struct file___120 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___110 *, struct file___120 *);
	ssize_t (*copy_file_range)(struct file___120 *, loff_t, struct file___120 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___120 *, loff_t, struct file___120 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___120 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___119 {
	u64 seqnum;
	struct vm_area_struct___120 *vmas[4];
};

struct page_frag___119 {
	struct page___120 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___119;

struct cred___115;

struct nsproxy___112;

struct signal_struct___109;

struct css_set___96;

struct vm_struct___89;

struct task_struct___120 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___120 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___119 *mm;
	struct mm_struct___119 *active_mm;
	struct vmacache___119 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___120 *real_parent;
	struct task_struct___120 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___120 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___98 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___98 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___98 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___115 *ptracer_cred;
	const struct cred___115 *real_cred;
	const struct cred___115 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___112 *nsproxy;
	struct signal_struct___109 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___120 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___17 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___96 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___30 *splice_pipe;
	struct page_frag___119 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___120 *oom_reaper_list;
	struct vm_struct___89 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___74 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct secondary_data___120 {
	void *stack;
	struct task_struct___120 *task;
	long int status;
};

struct dentry___120;

struct path___119 {
	struct vfsmount *mnt;
	struct dentry___120 *dentry;
};

struct address_space___119;

struct file___120 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___119 f_path;
	struct inode___121 *f_inode;
	const struct file_operations___120 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___98 f_owner;
	const struct cred___115 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___119 *f_mapping;
	errseq_t f_wb_err;
};

struct bpf_map___96;

struct bpf_map_ops___96 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___96 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___96 *, struct file___120 *);
	void (*map_free)(struct bpf_map___96 *);
	int (*map_get_next_key)(struct bpf_map___96 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___96 *);
	void * (*map_lookup_elem)(struct bpf_map___96 *, void *);
	int (*map_update_elem)(struct bpf_map___96 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___96 *, void *);
	int (*map_push_elem)(struct bpf_map___96 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___96 *, void *);
	int (*map_peek_elem)(struct bpf_map___96 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___96 *, struct file___120 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___96 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___96 *, void *, struct seq_file___110 *);
	int (*map_check_btf)(const struct bpf_map___96 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct user_struct___115;

struct bpf_map___96 {
	const struct bpf_map_ops___96 *ops;
	struct bpf_map___96 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___115 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct seq_operations___108;

struct seq_file___110 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___108 *op;
	int poll_event;
	const struct file___120 *file;
	void *private;
};

struct key___115;

struct user_struct___115 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___115 *uid_keyring;
	struct key___115 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bpf_offloaded_map___17;

struct bpf_map_dev_ops___17 {
	int (*map_get_next_key)(struct bpf_offloaded_map___17 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___17 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___17 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___17 *, void *);
};

struct net_device___22;

struct bpf_offloaded_map___17 {
	struct bpf_map___96 map;
	struct net_device___22 *netdev;
	const struct bpf_map_dev_ops___17 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___21;

typedef rx_handler_result_t rx_handler_func_t___17(struct sk_buff___21 **);

struct net___27;

typedef struct {
	struct net___27 *net;
} possible_net_t___18;

struct kset___113;

struct kobj_type___113;

struct kernfs_node___116;

struct kobject___114 {
	const char *name;
	struct list_head entry;
	struct kobject___114 *parent;
	struct kset___113 *kset;
	struct kobj_type___113 *ktype;
	struct kernfs_node___116 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___111;

struct dev_pm_info___111 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___111 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___111;

struct bus_type___111;

struct device_driver___111;

struct dev_pm_domain___111;

struct dma_map_ops___33;

struct fwnode_handle___83;

struct class___111;

struct attribute_group___110;

struct device___111 {
	struct device___111 *parent;
	struct device_private *p;
	struct kobject___114 kobj;
	const char *init_name;
	const struct device_type___111 *type;
	struct mutex mutex;
	struct bus_type___111 *bus;
	struct device_driver___111 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___111 power;
	struct dev_pm_domain___111 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___33 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___83 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___111 *class;
	const struct attribute_group___110 **groups;
	void (*release)(struct device___111 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct net_device_ops___17;

struct ethtool_ops___17;

struct xfrmdev_ops___17;

struct tlsdev_ops___17;

struct header_ops___17;

struct netdev_rx_queue___17;

struct bpf_prog___16;

struct mini_Qdisc___16;

struct netdev_queue___17;

struct Qdisc___16;

struct rtnl_link_ops___16;

struct dcbnl_rtnl_ops___17;

struct net_device___22 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___17 *netdev_ops;
	const struct ethtool_ops___17 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___2 *l3mdev_ops;
	const struct ndisc_ops___2 *ndisc_ops;
	const struct xfrmdev_ops___17 *xfrmdev_ops;
	const struct tlsdev_ops___17 *tlsdev_ops;
	const struct header_ops___17 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___113 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___2 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___17 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___16 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___17 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___16 *miniq_ingress;
	struct netdev_queue___17 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___17 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___16 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___16 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___17 = 0,
		NETREG_REGISTERED___17 = 1,
		NETREG_UNREGISTERING___17 = 2,
		NETREG_UNREGISTERED___17 = 3,
		NETREG_RELEASED___17 = 4,
		NETREG_DUMMY___17 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___17 = 0,
		RTNL_LINK_INITIALIZING___17 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___22 *);
	struct netpoll_info *npinfo;
	possible_net_t___18 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___111 dev;
	const struct attribute_group___110 *sysfs_groups[4];
	const struct attribute_group___110 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___16 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___17 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide35;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct bpf_prog_ops___16 {
	int (*test_run)(struct bpf_prog___16 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_aux___16;

struct bpf_prog___16 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___16 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

struct bpf_verifier_ops___16 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___16 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___16 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___16 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___16 *, u32 *);
};

struct bpf_verifier_env___2;

struct bpf_prog_offload_ops___16 {
	int (*insn_hook)(struct bpf_verifier_env___2 *, int, int);
	int (*finalize)(struct bpf_verifier_env___2 *);
	int (*prepare)(struct bpf_prog___16 *);
	int (*translate)(struct bpf_prog___16 *);
	void (*destroy)(struct bpf_prog___16 *);
};

struct bpf_verifier_state___2;

struct bpf_verifier_state_list___2;

struct bpf_verifier_env___2 {
	u32 insn_idx;
	u32 prev_insn_idx;
	struct bpf_prog___16 *prog;
	const struct bpf_verifier_ops___16 *ops;
	struct bpf_verifier_stack_elem *head;
	int stack_size;
	bool strict_alignment;
	struct bpf_verifier_state___2 *cur_state;
	struct bpf_verifier_state_list___2 **explored_states;
	struct bpf_map___96 *used_maps[64];
	u32 used_map_cnt;
	u32 id_gen;
	bool allow_ptr_leaks;
	bool seen_direct_write;
	struct bpf_insn_aux_data *insn_aux_data;
	const struct bpf_line_info *prev_linfo;
	struct bpf_verifier_log log;
	struct bpf_subprog_info subprog_info[257];
	u32 subprog_cnt;
};

struct bpf_offload_dev___2;

struct bpf_prog_offload___16 {
	struct bpf_prog___16 *prog;
	struct net_device___22 *netdev;
	struct bpf_offload_dev___2 *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___16 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_offload_dev___2 {
	const struct bpf_prog_offload_ops___16 *ops;
	struct list_head netdevs;
};

struct bpf_prog_aux___16 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___16 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___16 *ops;
	struct bpf_map___96 **used_maps;
	struct bpf_prog___16 *prog;
	struct user_struct___115 *user;
	u64 load_time;
	struct bpf_map___96 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___16 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___16 {
	struct bpf_prog___16 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___16 {
	struct callback_head rcu;
	struct bpf_prog_array_item___16 items[0];
};

struct proc_ns_operations___8;

struct ns_common___8 {
	atomic_long_t stashed;
	const struct proc_ns_operations___8 *ops;
	unsigned int inum;
};

struct rw_semaphore___120 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___120 *owner;
};

struct ucounts___100;

struct user_namespace___100 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___100 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___8 ns;
	long unsigned int flags;
	struct key___115 *persistent_keyring_register;
	struct rw_semaphore___120 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___100 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct rhlist_head {
	struct rhash_head rhead;
	struct rhlist_head *next;
};

struct bucket_table {
	unsigned int size;
	unsigned int nest;
	unsigned int rehash;
	u32 hash_rnd;
	unsigned int locks_mask;
	spinlock_t *locks;
	struct list_head walkers;
	struct callback_head rcu;
	struct bucket_table *future_tbl;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhash_head *buckets[0];
};

typedef struct page___120 *pgtable_t___119;

struct dev_pagemap___117;

struct page___120 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___119 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___120 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___119 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___119 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___117 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___119;

struct lruvec___119 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___119 *pgdat;
};

struct zone___119 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___119 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___119 {
	struct zone___119 *zone;
	int zone_idx;
};

struct zonelist___119 {
	struct zoneref___119 _zonerefs[25];
};

struct pglist_data___119 {
	struct zone___119 node_zones[3];
	struct zonelist___119 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___120 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___120 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___119 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___119 {
	struct rw_semaphore___120 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___117;

struct vm_area_struct___120 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___120 *vm_next;
	struct vm_area_struct___120 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___119 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___117 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___120 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___119;

struct mm_struct___119 {
	struct {
		struct vm_area_struct___120 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___120 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___120 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___119 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___120 *owner;
		struct user_namespace___100 *user_ns;
		struct file___120 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___119 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___115 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___115 *session_keyring;
	struct key___115 *process_keyring;
	struct key___115 *thread_keyring;
	struct key___115 *request_key_auth;
	void *security;
	struct user_struct___115 *user;
	struct user_namespace___100 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___96;

struct nsproxy___112 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net___27 *net_ns;
	struct cgroup_namespace___96 *cgroup_ns;
};

struct signal_struct___109 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___120 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___120 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___98 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___98 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___119 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___98 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___96;

struct cgroup___96;

struct css_set___96 {
	struct cgroup_subsys_state___96 *subsys[13];
	refcount_t refcount;
	struct css_set___96 *dom_cset;
	struct cgroup___96 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___96 *mg_src_cgrp;
	struct cgroup___96 *mg_dst_cgrp;
	struct css_set___96 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___119;

struct pipe_buffer___30;

struct pipe_inode_info___30 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___120 *tmp_page;
	struct fasync_struct___119 *fasync_readers;
	struct fasync_struct___119 *fasync_writers;
	struct pipe_buffer___30 *bufs;
	struct user_struct___115 *user;
};

struct vm_struct___89 {
	struct vm_struct___89 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___120 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___109 {
	struct task_struct___120 task;
	long unsigned int stack[8192];
};

struct address_space_operations___119;

struct address_space___119 {
	struct inode___121 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___120 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___119 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___117)(struct vm_area_struct___120 *, long unsigned int, const struct page___120 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___117)(struct page___120 *, void *);

struct dev_pagemap___117 {
	dev_page_fault_t___117 page_fault;
	dev_page_free_t___117 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___111 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct vm_fault___117;

struct vm_operations_struct___117 {
	void (*open)(struct vm_area_struct___120 *);
	void (*close)(struct vm_area_struct___120 *);
	int (*split)(struct vm_area_struct___120 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___120 *);
	vm_fault_t (*fault)(struct vm_fault___117 *);
	vm_fault_t (*huge_fault)(struct vm_fault___117 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___117 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___120 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___117 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___117 *);
	int (*access)(struct vm_area_struct___120 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___120 *);
	int (*set_policy)(struct vm_area_struct___120 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___120 *, long unsigned int);
	struct page___120 * (*find_special_page)(struct vm_area_struct___120 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___119 {
	struct task_struct___120 *task;
	struct core_thread___119 *next;
};

struct core_state___119 {
	atomic_t nr_threads;
	struct core_thread___119 dumper;
	struct completion startup;
};

struct vm_fault___117 {
	struct vm_area_struct___120 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___120 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___120 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___119 prealloc_pte;
};

struct module_kobject___100 {
	struct kobject___114 kobj;
	struct module___103 *mod;
	struct kobject___114 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___100 {
	struct module___103 *mod;
	struct latch_tree_node node;
};

struct module_layout___100 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___100 mtn;
};

struct module_attribute___100;

struct kernel_param___100;

struct module___103 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___100 mkobj;
	struct module_attribute___100 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___114 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___100 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___100 core_layout;
	struct module_layout___100 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct iov_iter___49 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___3 *bvec;
		struct pipe_inode_info___30 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct kiocb___120 {
	struct file___120 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___120 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dentry_operations___119;

struct super_block___120;

struct dentry___120 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___120 *d_parent;
	struct qstr d_name;
	struct inode___121 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___119 *d_op;
	struct super_block___120 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___119;

struct block_device___120;

struct inode___121 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___119 *i_op;
	struct super_block___120 *i_sb;
	struct address_space___119 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___120 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___120 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___119 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___30 *i_pipe;
		struct block_device___120 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___119 {
	int (*d_revalidate)(struct dentry___120 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___120 *, unsigned int);
	int (*d_hash)(const struct dentry___120 *, struct qstr *);
	int (*d_compare)(const struct dentry___120 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___120 *);
	int (*d_init)(struct dentry___120 *);
	void (*d_release)(struct dentry___120 *);
	void (*d_prune)(struct dentry___120 *);
	void (*d_iput)(struct dentry___120 *, struct inode___121 *);
	char * (*d_dname)(struct dentry___120 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___119 *);
	int (*d_manage)(const struct path___119 *, bool);
	struct dentry___120 * (*d_real)(struct dentry___120 *, const struct inode___121 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___119;

struct mem_dqinfo___119 {
	struct quota_format_type___119 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___119;

struct quota_info___119 {
	unsigned int flags;
	struct rw_semaphore___120 dqio_sem;
	struct inode___121 *files[3];
	struct mem_dqinfo___119 info[3];
	const struct quota_format_ops___119 *ops[3];
};

struct rcuwait___119 {
	struct task_struct___120 *task;
};

struct percpu_rw_semaphore___119 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___120 rw_sem;
	struct rcuwait___119 writer;
	int readers_block;
};

struct sb_writers___119 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___119 rw_sem[3];
};

struct file_system_type___119;

struct super_operations___119;

struct dquot_operations___119;

struct quotactl_ops___119;

struct super_block___120 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___119 *s_type;
	const struct super_operations___119 *s_op;
	const struct dquot_operations___119 *dq_op;
	const struct quotactl_ops___119 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___120 *s_root;
	struct rw_semaphore___120 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___120 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___119 s_dquot;
	struct sb_writers___119 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___119 *s_d_op;
	int cleancache_poolid;
	struct shrinker___38 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___100 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct iattr___120 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___120 *ia_file;
};

struct dquot___119 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___120 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___119 {
	int qf_fmt_id;
	const struct quota_format_ops___119 *qf_ops;
	struct module___103 *qf_owner;
	struct quota_format_type___119 *qf_next;
};

struct quota_format_ops___119 {
	int (*check_quota_file)(struct super_block___120 *, int);
	int (*read_file_info)(struct super_block___120 *, int);
	int (*write_file_info)(struct super_block___120 *, int);
	int (*free_file_info)(struct super_block___120 *, int);
	int (*read_dqblk)(struct dquot___119 *);
	int (*commit_dqblk)(struct dquot___119 *);
	int (*release_dqblk)(struct dquot___119 *);
	int (*get_next_id)(struct super_block___120 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___119 {
	int (*write_dquot)(struct dquot___119 *);
	struct dquot___119 * (*alloc_dquot)(struct super_block___120 *, int);
	void (*destroy_dquot)(struct dquot___119 *);
	int (*acquire_dquot)(struct dquot___119 *);
	int (*release_dquot)(struct dquot___119 *);
	int (*mark_dirty)(struct dquot___119 *);
	int (*write_info)(struct super_block___120 *, int);
	qsize_t * (*get_reserved_space)(struct inode___121 *);
	int (*get_projid)(struct inode___121 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___121 *, qsize_t *);
	int (*get_next_id)(struct super_block___120 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___119 {
	int (*quota_on)(struct super_block___120 *, int, int, const struct path___119 *);
	int (*quota_off)(struct super_block___120 *, int);
	int (*quota_enable)(struct super_block___120 *, unsigned int);
	int (*quota_disable)(struct super_block___120 *, unsigned int);
	int (*quota_sync)(struct super_block___120 *, int);
	int (*set_info)(struct super_block___120 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___120 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___120 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___120 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___120 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___120 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___119 {
	int (*writepage)(struct page___120 *, struct writeback_control___3 *);
	int (*readpage)(struct file___120 *, struct page___120 *);
	int (*writepages)(struct address_space___119 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___120 *);
	int (*readpages)(struct file___120 *, struct address_space___119 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___120 *, struct address_space___119 *, loff_t, unsigned int, unsigned int, struct page___120 **, void **);
	int (*write_end)(struct file___120 *, struct address_space___119 *, loff_t, unsigned int, unsigned int, struct page___120 *, void *);
	sector_t (*bmap)(struct address_space___119 *, sector_t);
	void (*invalidatepage)(struct page___120 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___120 *, gfp_t);
	void (*freepage)(struct page___120 *);
	ssize_t (*direct_IO)(struct kiocb___120 *, struct iov_iter___49 *);
	int (*migratepage)(struct address_space___119 *, struct page___120 *, struct page___120 *, enum migrate_mode);
	bool (*isolate_page)(struct page___120 *, isolate_mode_t);
	void (*putback_page)(struct page___120 *);
	int (*launder_page)(struct page___120 *);
	int (*is_partially_uptodate)(struct page___120 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___120 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___119 *, struct page___120 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___120 *, sector_t *);
	void (*swap_deactivate)(struct file___120 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___120 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___121 *bd_inode;
	struct super_block___120 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___120 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___119 {
	struct dentry___120 * (*lookup)(struct inode___121 *, struct dentry___120 *, unsigned int);
	const char * (*get_link)(struct dentry___120 *, struct inode___121 *, struct delayed_call *);
	int (*permission)(struct inode___121 *, int);
	struct posix_acl * (*get_acl)(struct inode___121 *, int);
	int (*readlink)(struct dentry___120 *, char *, int);
	int (*create)(struct inode___121 *, struct dentry___120 *, umode_t, bool);
	int (*link)(struct dentry___120 *, struct inode___121 *, struct dentry___120 *);
	int (*unlink)(struct inode___121 *, struct dentry___120 *);
	int (*symlink)(struct inode___121 *, struct dentry___120 *, const char *);
	int (*mkdir)(struct inode___121 *, struct dentry___120 *, umode_t);
	int (*rmdir)(struct inode___121 *, struct dentry___120 *);
	int (*mknod)(struct inode___121 *, struct dentry___120 *, umode_t, dev_t);
	int (*rename)(struct inode___121 *, struct dentry___120 *, struct inode___121 *, struct dentry___120 *, unsigned int);
	int (*setattr)(struct dentry___120 *, struct iattr___120 *);
	int (*getattr)(const struct path___119 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___120 *, char *, size_t);
	int (*fiemap)(struct inode___121 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___121 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___121 *, struct dentry___120 *, struct file___120 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___121 *, struct dentry___120 *, umode_t);
	int (*set_acl)(struct inode___121 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___119 {
	void (*fl_copy_lock)(struct file_lock___120 *, struct file_lock___120 *);
	void (*fl_release_private)(struct file_lock___120 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___119;

struct file_lock___120 {
	struct file_lock___120 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___120 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___119 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___119 *fl_ops;
	const struct lock_manager_operations___119 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___119 {
	int (*lm_compare_owner)(struct file_lock___120 *, struct file_lock___120 *);
	long unsigned int (*lm_owner_key)(struct file_lock___120 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___120 *);
	int (*lm_grant)(struct file_lock___120 *, int);
	bool (*lm_break)(struct file_lock___120 *);
	int (*lm_change)(struct file_lock___120 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___120 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___119 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___119 *fa_next;
	struct file___120 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___119 {
	const char *name;
	int fs_flags;
	struct dentry___120 * (*mount)(struct file_system_type___119 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___120 *);
	struct module___103 *owner;
	struct file_system_type___119 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___119 {
	struct inode___121 * (*alloc_inode)(struct super_block___120 *);
	void (*destroy_inode)(struct inode___121 *);
	void (*dirty_inode)(struct inode___121 *, int);
	int (*write_inode)(struct inode___121 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___121 *);
	void (*evict_inode)(struct inode___121 *);
	void (*put_super)(struct super_block___120 *);
	int (*sync_fs)(struct super_block___120 *, int);
	int (*freeze_super)(struct super_block___120 *);
	int (*freeze_fs)(struct super_block___120 *);
	int (*thaw_super)(struct super_block___120 *);
	int (*unfreeze_fs)(struct super_block___120 *);
	int (*statfs)(struct dentry___120 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___120 *, int *, char *);
	void (*umount_begin)(struct super_block___120 *);
	int (*show_options)(struct seq_file___110 *, struct dentry___120 *);
	int (*show_devname)(struct seq_file___110 *, struct dentry___120 *);
	int (*show_path)(struct seq_file___110 *, struct dentry___120 *);
	int (*show_stats)(struct seq_file___110 *, struct dentry___120 *);
	ssize_t (*quota_read)(struct super_block___120 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___120 *, int, const char *, size_t, loff_t);
	struct dquot___119 ** (*get_dquots)(struct inode___121 *);
	int (*bdev_try_to_free_page)(struct super_block___120 *, struct page___120 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___120 *, struct shrink_control___38 *);
	long int (*free_cached_objects)(struct super_block___120 *, struct shrink_control___38 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct nf_bridge_info___17;

struct sk_buff___21 {
	union {
		struct {
			struct sk_buff___21 *next;
			struct sk_buff___21 *prev;
			union {
				struct net_device___22 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___10 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___21 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___17 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___17;

struct netns_frags___17 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___17 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv4___17 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct sock *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock **tcp_sk;
	struct netns_frags___17 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct dst_ops___25 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___25 *);
	struct dst_entry___2 * (*check)(struct dst_entry___2 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___2 *);
	unsigned int (*mtu)(const struct dst_entry___2 *);
	u32 * (*cow_metrics)(struct dst_entry___2 *, long unsigned int);
	void (*destroy)(struct dst_entry___2 *);
	void (*ifdown)(struct dst_entry___2 *, struct net_device___22 *, int);
	struct dst_entry___2 * (*negative_advice)(struct dst_entry___2 *);
	void (*link_failure)(struct sk_buff___21 *);
	void (*update_pmtu)(struct dst_entry___2 *, struct sock *, struct sk_buff___21 *, u32);
	void (*redirect)(struct dst_entry___2 *, struct sock *, struct sk_buff___21 *);
	int (*local_out)(struct net___27 *, struct sock *, struct sk_buff___21 *);
	struct neighbour___2 * (*neigh_lookup)(const struct dst_entry___2 *, struct sk_buff___21 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___2 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___24 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___17 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___25 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct sock *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops *notifier_ops;
	struct fib_notifier_ops *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_nf_frag___17 {
	struct netns_frags___17 frags;
};

struct netns_xfrm___24 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___25 xfrm4_dst_ops;
	struct dst_ops___25 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct net___27 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___100 *user_ns;
	struct ucounts___100 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___8 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___22 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___17 ipv4;
	struct netns_ipv6___24 ipv6;
	struct netns_sctp___7 sctp;
	struct netns_nf nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___17 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock *nfnl;
	struct sock *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___24 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___16 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kernfs_root___116;

struct kernfs_elem_dir___116 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___116 *root;
};

struct kernfs_syscall_ops___116;

struct kernfs_root___116 {
	struct kernfs_node___116 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___116 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___116 {
	struct kernfs_node___116 *target_kn;
};

struct kernfs_ops___116;

struct kernfs_elem_attr___116 {
	const struct kernfs_ops___116 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___116 *notify_next;
};

struct kernfs_node___116 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___116 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___116 dir;
		struct kernfs_elem_symlink___116 symlink;
		struct kernfs_elem_attr___116 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___116;

struct kernfs_ops___116 {
	int (*open)(struct kernfs_open_file___116 *);
	void (*release)(struct kernfs_open_file___116 *);
	int (*seq_show)(struct seq_file___110 *, void *);
	void * (*seq_start)(struct seq_file___110 *, loff_t *);
	void * (*seq_next)(struct seq_file___110 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___110 *, void *);
	ssize_t (*read)(struct kernfs_open_file___116 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___116 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___116 *, struct vm_area_struct___120 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___116 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___116 {
	int (*remount_fs)(struct kernfs_root___116 *, int *, char *);
	int (*show_options)(struct seq_file___110 *, struct kernfs_root___116 *);
	int (*mkdir)(struct kernfs_node___116 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___116 *);
	int (*rename)(struct kernfs_node___116 *, struct kernfs_node___116 *, const char *);
	int (*show_path)(struct seq_file___110 *, struct kernfs_node___116 *, struct kernfs_root___116 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___116 {
	struct kernfs_node___116 *kn;
	struct file___120 *file;
	struct seq_file___110 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___117 *vm_ops;
};

struct bin_attribute___110;

struct attribute_group___110 {
	const char *name;
	umode_t (*is_visible)(struct kobject___114 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___114 *, struct bin_attribute___110 *, int);
	struct attribute **attrs;
	struct bin_attribute___110 **bin_attrs;
};

struct bin_attribute___110 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___120 *, struct kobject___114 *, struct bin_attribute___110 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___120 *, struct kobject___114 *, struct bin_attribute___110 *, char *, loff_t, size_t);
	int (*mmap)(struct file___120 *, struct kobject___114 *, struct bin_attribute___110 *, struct vm_area_struct___120 *);
};

struct sysfs_ops___113 {
	ssize_t (*show)(struct kobject___114 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___114 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___113;

struct kset___113 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___114 kobj;
	const struct kset_uevent_ops___113 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___113 {
	void (*release)(struct kobject___114 *);
	const struct sysfs_ops___113 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___7 * (*child_ns_type)(struct kobject___114 *);
	const void * (*namespace)(struct kobject___114 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___113 {
	int (* const filter)(struct kset___113 *, struct kobject___114 *);
	const char * (* const name)(struct kset___113 *, struct kobject___114 *);
	int (* const uevent)(struct kset___113 *, struct kobject___114 *, struct kobj_uevent_env *);
};

struct kobj_attribute___114 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___114 *, struct kobj_attribute___114 *, char *);
	ssize_t (*store)(struct kobject___114 *, struct kobj_attribute___114 *, const char *, size_t);
};

struct dev_pm_ops___111 {
	int (*prepare)(struct device___111 *);
	void (*complete)(struct device___111 *);
	int (*suspend)(struct device___111 *);
	int (*resume)(struct device___111 *);
	int (*freeze)(struct device___111 *);
	int (*thaw)(struct device___111 *);
	int (*poweroff)(struct device___111 *);
	int (*restore)(struct device___111 *);
	int (*suspend_late)(struct device___111 *);
	int (*resume_early)(struct device___111 *);
	int (*freeze_late)(struct device___111 *);
	int (*thaw_early)(struct device___111 *);
	int (*poweroff_late)(struct device___111 *);
	int (*restore_early)(struct device___111 *);
	int (*suspend_noirq)(struct device___111 *);
	int (*resume_noirq)(struct device___111 *);
	int (*freeze_noirq)(struct device___111 *);
	int (*thaw_noirq)(struct device___111 *);
	int (*poweroff_noirq)(struct device___111 *);
	int (*restore_noirq)(struct device___111 *);
	int (*runtime_suspend)(struct device___111 *);
	int (*runtime_resume)(struct device___111 *);
	int (*runtime_idle)(struct device___111 *);
};

struct dev_pm_domain___111 {
	struct dev_pm_ops___111 ops;
	void (*detach)(struct device___111 *, bool);
	int (*activate)(struct device___111 *);
	void (*sync)(struct device___111 *);
	void (*dismiss)(struct device___111 *);
};

struct bus_type___111 {
	const char *name;
	const char *dev_name;
	struct device___111 *dev_root;
	const struct attribute_group___110 **bus_groups;
	const struct attribute_group___110 **dev_groups;
	const struct attribute_group___110 **drv_groups;
	int (*match)(struct device___111 *, struct device_driver___111 *);
	int (*uevent)(struct device___111 *, struct kobj_uevent_env *);
	int (*probe)(struct device___111 *);
	int (*remove)(struct device___111 *);
	void (*shutdown)(struct device___111 *);
	int (*online)(struct device___111 *);
	int (*offline)(struct device___111 *);
	int (*suspend)(struct device___111 *, pm_message_t);
	int (*resume)(struct device___111 *);
	int (*num_vf)(struct device___111 *);
	int (*dma_configure)(struct device___111 *);
	const struct dev_pm_ops___111 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___111 {
	const char *name;
	struct bus_type___111 *bus;
	struct module___103 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___111 *);
	int (*remove)(struct device___111 *);
	void (*shutdown)(struct device___111 *);
	int (*suspend)(struct device___111 *, pm_message_t);
	int (*resume)(struct device___111 *);
	const struct attribute_group___110 **groups;
	const struct dev_pm_ops___111 *pm;
	void (*coredump)(struct device___111 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___111 {
	const char *name;
	const struct attribute_group___110 **groups;
	int (*uevent)(struct device___111 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___111 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___111 *);
	const struct dev_pm_ops___111 *pm;
};

struct class___111 {
	const char *name;
	struct module___103 *owner;
	const struct attribute_group___110 **class_groups;
	const struct attribute_group___110 **dev_groups;
	struct kobject___114 *dev_kobj;
	int (*dev_uevent)(struct device___111 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___111 *, umode_t *);
	void (*class_release)(struct class___111 *);
	void (*dev_release)(struct device___111 *);
	int (*shutdown_pre)(struct device___111 *);
	const struct kobj_ns_type_operations___7 *ns_type;
	const void * (*namespace)(struct device___111 *);
	const struct dev_pm_ops___111 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___33 {
	void * (*alloc)(struct device___111 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___111 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___111 *, struct vm_area_struct___120 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___111 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___111 *, struct page___120 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___111 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___111 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___111 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___111 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___111 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___111 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___111 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___111 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___111 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___111 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___111 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___111 *, u64);
	u64 (*get_required_mask)(struct device___111 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___83;

struct fwnode_handle___83 {
	struct fwnode_handle___83 *secondary;
	const struct fwnode_operations___83 *ops;
};

typedef void compound_page_dtor___117(struct page___120 *);

struct fwnode_reference_args___83;

struct fwnode_endpoint___83;

struct fwnode_operations___83 {
	struct fwnode_handle___83 * (*get)(struct fwnode_handle___83 *);
	void (*put)(struct fwnode_handle___83 *);
	bool (*device_is_available)(const struct fwnode_handle___83 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___83 *, const struct device___111 *);
	bool (*property_present)(const struct fwnode_handle___83 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___83 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___83 *, const char *, const char **, size_t);
	struct fwnode_handle___83 * (*get_parent)(const struct fwnode_handle___83 *);
	struct fwnode_handle___83 * (*get_next_child_node)(const struct fwnode_handle___83 *, struct fwnode_handle___83 *);
	struct fwnode_handle___83 * (*get_named_child_node)(const struct fwnode_handle___83 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___83 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___83 *);
	struct fwnode_handle___83 * (*graph_get_next_endpoint)(const struct fwnode_handle___83 *, struct fwnode_handle___83 *);
	struct fwnode_handle___83 * (*graph_get_remote_endpoint)(const struct fwnode_handle___83 *);
	struct fwnode_handle___83 * (*graph_get_port_parent)(struct fwnode_handle___83 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___83 *, struct fwnode_endpoint___83 *);
};

struct fwnode_endpoint___83 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___83 *local_fwnode;
};

struct fwnode_reference_args___83 {
	struct fwnode_handle___83 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___30;

struct pipe_buffer___30 {
	struct page___120 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___30 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___30 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___30 *, struct pipe_buffer___30 *);
	void (*release)(struct pipe_inode_info___30 *, struct pipe_buffer___30 *);
	int (*steal)(struct pipe_inode_info___30 *, struct pipe_buffer___30 *);
	union {
		bool (*get)(struct pipe_inode_info___30 *, struct pipe_buffer___30 *);
		struct {
			void (*get)(struct pipe_inode_info___30 *, struct pipe_buffer___30 *);
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
};

struct nf_bridge_info___17 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___17 = 0,
		BRNF_PROTO_8021Q___17 = 1,
		BRNF_PROTO_PPPOE___17 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___22 *physindev;
	struct net_device___22 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

struct sk_buff_head___18 {
	struct sk_buff___21 *next;
	struct sk_buff___21 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct kernel_param_ops___100 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___100 *);
	int (*get)(char *, const struct kernel_param___100 *);
	void (*free)(void *);
};

struct kparam_array___100;

struct kernel_param___100 {
	const char *name;
	struct module___103 *mod;
	const struct kernel_param_ops___100 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___100 *arr;
	};
};

struct kparam_array___100 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___100 *ops;
	void *elem;
};

struct module_attribute___100 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___100 *, struct module_kobject___100 *, char *);
	ssize_t (*store)(struct module_attribute___100 *, struct module_kobject___100 *, const char *, size_t);
	void (*setup)(struct module___103 *, const char *);
	int (*test)(struct module___103 *);
	void (*free)(struct module___103 *);
};

struct ethtool_ops___17 {
	int (*get_settings)(struct net_device___22 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___22 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___22 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___22 *);
	void (*get_regs)(struct net_device___22 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___22 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___22 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___22 *);
	void (*set_msglevel)(struct net_device___22 *, u32);
	int (*nway_reset)(struct net_device___22 *);
	u32 (*get_link)(struct net_device___22 *);
	int (*get_eeprom_len)(struct net_device___22 *);
	int (*get_eeprom)(struct net_device___22 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___22 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___22 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___22 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___22 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___22 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___22 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___22 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___22 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___22 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___22 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___22 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___22 *);
	void (*complete)(struct net_device___22 *);
	u32 (*get_priv_flags)(struct net_device___22 *);
	int (*set_priv_flags)(struct net_device___22 *, u32);
	int (*get_sset_count)(struct net_device___22 *, int);
	int (*get_rxnfc)(struct net_device___22 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___22 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___22 *, struct ethtool_flash *);
	int (*reset)(struct net_device___22 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___22 *);
	u32 (*get_rxfh_indir_size)(struct net_device___22 *);
	int (*get_rxfh)(struct net_device___22 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___22 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___22 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___22 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___22 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___22 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___22 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___22 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___22 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___22 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___22 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___22 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___22 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___22 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___22 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___22 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___22 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___22 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___22 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___22 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___22 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___22 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	int (*get_fecparam)(struct net_device___22 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___22 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___22 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___22 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___22 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___17;

struct inet_frags___17 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___17 *, const void *);
	void (*destructor)(struct inet_frag_queue___17 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___17 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___21 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___21 *fragments_tail;
	struct sk_buff___21 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___17 *net;
	struct callback_head rcu;
};

struct proc_ns_operations___8 {
	const char *name;
	const char *real_ns_name;
	int type;
	struct ns_common___8 * (*get)(struct task_struct___120 *);
	void (*put)(struct ns_common___8 *);
	int (*install)(struct nsproxy___112 *, struct ns_common___8 *);
	struct user_namespace___100 * (*owner)(struct ns_common___8 *);
	struct ns_common___8 * (*get_parent)(struct ns_common___8 *);
};

struct ucounts___100 {
	struct hlist_node node;
	struct user_namespace___100 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

typedef int (*key_restrict_link_func_t___115)(struct key___115 *, const struct key_type *, const union key_payload *, struct key___115 *);

struct key_restriction___115;

struct key___115 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___120 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___115 *restrict_link;
};

struct key_restriction___115 {
	key_restrict_link_func_t___115 check;
	struct key___115 *key;
	struct key_type *keytype;
};

struct seq_operations___108 {
	void * (*start)(struct seq_file___110 *, loff_t *);
	void (*stop)(struct seq_file___110 *, void *);
	void * (*next)(struct seq_file___110 *, void *, loff_t *);
	int (*show)(struct seq_file___110 *, void *);
};

struct pernet_operations___17 {
	struct list_head list;
	int (*init)(struct net___27 *);
	void (*exit)(struct net___27 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___17 {
	int (*ieee_getets)(struct net_device___22 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___22 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___22 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___22 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___22 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___22 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___22 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___22 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___22 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___22 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___22 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___22 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___22 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___22 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___22 *);
	u8 (*setstate)(struct net_device___22 *, u8);
	void (*getpermhwaddr)(struct net_device___22 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___22 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___22 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___22 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___22 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___22 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___22 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___22 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___22 *, int, u8 *);
	void (*setpfccfg)(struct net_device___22 *, int, u8);
	void (*getpfccfg)(struct net_device___22 *, int, u8 *);
	u8 (*setall)(struct net_device___22 *);
	u8 (*getcap)(struct net_device___22 *, int, u8 *);
	int (*getnumtcs)(struct net_device___22 *, int, u8 *);
	int (*setnumtcs)(struct net_device___22 *, int, u8);
	u8 (*getpfcstate)(struct net_device___22 *);
	void (*setpfcstate)(struct net_device___22 *, u8);
	void (*getbcncfg)(struct net_device___22 *, int, u32 *);
	void (*setbcncfg)(struct net_device___22 *, int, u32);
	void (*getbcnrp)(struct net_device___22 *, int, u8 *);
	void (*setbcnrp)(struct net_device___22 *, int, u8);
	int (*setapp)(struct net_device___22 *, u8, u16, u8);
	int (*getapp)(struct net_device___22 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___22 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___22 *, int, u8);
	u8 (*getdcbx)(struct net_device___22 *);
	u8 (*setdcbx)(struct net_device___22 *, u8);
	int (*peer_getappinfo)(struct net_device___22 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___22 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___22 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___22 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___22 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___22 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___96 {
	refcount_t count;
	struct ns_common___8 ns;
	struct user_namespace___100 *user_ns;
	struct ucounts___100 *ucounts;
	struct css_set___96 *root_cset;
};

struct cgroup_bpf___16 {
	struct bpf_prog_array___16 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___16 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___96;

typedef void (*kthread_work_func_t___96)(struct kthread_work___96 *);

struct kthread_worker___96;

struct kthread_work___96 {
	struct list_head node;
	kthread_work_func_t___96 func;
	struct kthread_worker___96 *worker;
	int canceling;
};

struct kthread_worker___96 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___120 *task;
	struct kthread_work___96 *current_work;
};

struct kthread_delayed_work___96 {
	struct kthread_work___96 work;
	struct timer_list timer;
};

struct psi_group___96 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___96 *poll_kworker;
	struct kthread_delayed_work___96 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___96 {
	struct kernfs_node___116 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___96;

struct cgroup_subsys_state___96 {
	struct cgroup___96 *cgroup;
	struct cgroup_subsys___96 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___96 *parent;
};

struct cgroup_root___96;

struct cgroup_rstat_cpu___96;

struct cgroup___96 {
	struct cgroup_subsys_state___96 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___116 *kn;
	struct cgroup_file___96 procs_file;
	struct cgroup_file___96 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___96 *subsys[13];
	struct cgroup_root___96 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___96 *dom_cgrp;
	struct cgroup_rstat_cpu___96 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___16 bpf;
	atomic_t congestion_count;
	struct cgroup___96 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___96 psi;
	int ancestor_ids[0];
};

struct cftype___96;

struct cgroup_subsys___96 {
	struct cgroup_subsys_state___96 * (*css_alloc)(struct cgroup_subsys_state___96 *);
	int (*css_online)(struct cgroup_subsys_state___96 *);
	void (*css_offline)(struct cgroup_subsys_state___96 *);
	void (*css_released)(struct cgroup_subsys_state___96 *);
	void (*css_free)(struct cgroup_subsys_state___96 *);
	void (*css_reset)(struct cgroup_subsys_state___96 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___96 *, int);
	int (*css_extra_stat_show)(struct seq_file___110 *, struct cgroup_subsys_state___96 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___120 *);
	void (*cancel_fork)(struct task_struct___120 *);
	void (*fork)(struct task_struct___120 *);
	void (*exit)(struct task_struct___120 *);
	void (*free)(struct task_struct___120 *);
	void (*bind)(struct cgroup_subsys_state___96 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___96 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___96 *dfl_cftypes;
	struct cftype___96 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___96 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___96 *updated_children;
	struct cgroup___96 *updated_next;
};

struct cgroup_root___96 {
	struct kernfs_root___116 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___96 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___96 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___96 *ss;
	struct list_head node;
	struct kernfs_ops___116 *kf_ops;
	int (*open)(struct kernfs_open_file___116 *);
	void (*release)(struct kernfs_open_file___116 *);
	u64 (*read_u64)(struct cgroup_subsys_state___96 *, struct cftype___96 *);
	s64 (*read_s64)(struct cgroup_subsys_state___96 *, struct cftype___96 *);
	int (*seq_show)(struct seq_file___110 *, void *);
	void * (*seq_start)(struct seq_file___110 *, loff_t *);
	void * (*seq_next)(struct seq_file___110 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___110 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___96 *, struct cftype___96 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___96 *, struct cftype___96 *, s64);
	ssize_t (*write)(struct kernfs_open_file___116 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___116 *, struct poll_table_struct___6 *);
};

struct xdp_rxq_info___17 {
	struct net_device___22 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___17 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___22 *dev_rx;
};

struct netlink_callback___17 {
	struct sk_buff___21 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___17 *);
	int (*dump)(struct sk_buff___21 *, struct netlink_callback___17 *);
	int (*done)(struct netlink_callback___17 *);
	void *data;
	struct module___103 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___17 {
	int (*create)(struct sk_buff___21 *, struct net_device___22 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___21 *, unsigned char *);
	int (*cache)(const struct neighbour___2 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___22 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___17 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___17 *, int);
	int poll_owner;
	struct net_device___22 *dev;
	struct sk_buff___21 *gro_list;
	struct sk_buff___21 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___17 {
	struct net_device___22 *dev;
	struct Qdisc___16 *qdisc;
	struct Qdisc___16 *qdisc_sleeping;
	struct kobject___114 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___22 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___16 {
	struct sk_buff___21 *head;
	struct sk_buff___21 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___16;

struct Qdisc___16 {
	int (*enqueue)(struct sk_buff___21 *, struct Qdisc___16 *, struct sk_buff___21 **);
	struct sk_buff___21 * (*dequeue)(struct Qdisc___16 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___16 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___17 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___18 gso_skb;
	struct qdisc_skb_head___16 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___16 *next_sched;
	struct sk_buff_head___18 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___17 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___114 kobj;
	struct net_device___22 *dev;
	long: 64;
	struct xdp_rxq_info___17 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___17)(struct net_device___22 *, struct sk_buff___21 *, struct net_device___22 *);

struct netdev_bpf___17 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___16 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___16 *prog;
			const struct bpf_prog_offload_ops___16 *ops;
		} verifier;
		struct {
			struct bpf_prog___16 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___17 *offmap;
		};
		struct {
			struct xdp_umem *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___17 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___21 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___17 {
	int (*tls_dev_add)(struct net_device___22 *, struct sock *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___22 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___22 *, struct sock *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___17 {
	int (*ndo_init)(struct net_device___22 *);
	void (*ndo_uninit)(struct net_device___22 *);
	int (*ndo_open)(struct net_device___22 *);
	int (*ndo_stop)(struct net_device___22 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___21 *, struct net_device___22 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___21 *, struct net_device___22 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___22 *, struct sk_buff___21 *, struct net_device___22 *, select_queue_fallback_t___17);
	void (*ndo_change_rx_flags)(struct net_device___22 *, int);
	void (*ndo_set_rx_mode)(struct net_device___22 *);
	int (*ndo_set_mac_address)(struct net_device___22 *, void *);
	int (*ndo_validate_addr)(struct net_device___22 *);
	int (*ndo_do_ioctl)(struct net_device___22 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___22 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___22 *, int);
	int (*ndo_neigh_setup)(struct net_device___22 *, struct neigh_parms___3 *);
	void (*ndo_tx_timeout)(struct net_device___22 *);
	void (*ndo_get_stats64)(struct net_device___22 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___22 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___22 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___22 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___22 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___22 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___22 *);
	int (*ndo_netpoll_setup)(struct net_device___22 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___22 *);
	int (*ndo_set_vf_mac)(struct net_device___22 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___22 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___22 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___22 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___22 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___22 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___22 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___22 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___22 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___22 *, int, struct sk_buff___21 *);
	int (*ndo_set_vf_guid)(struct net_device___22 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___22 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___22 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___22 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___22 *, const struct sk_buff___21 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___22 *, struct net_device___22 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___22 *, struct net_device___22 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___22 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___22 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___22 *, struct neighbour___2 *);
	void (*ndo_neigh_destroy)(struct net_device___22 *, struct neighbour___2 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___22 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___22 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___22 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___21 *, struct netlink_callback___17 *, struct net_device___22 *, struct net_device___22 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___22 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___22 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___21 *, u32, u32, struct net_device___22 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___22 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___22 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___22 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___22 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___22 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___22 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___22 *, struct net_device___22 *);
	void (*ndo_dfwd_del_station)(struct net_device___22 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___22 *);
	int (*ndo_set_tx_maxrate)(struct net_device___22 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___22 *);
	int (*ndo_change_proto_down)(struct net_device___22 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___22 *, struct sk_buff___21 *);
	void (*ndo_set_rx_headroom)(struct net_device___22 *, int);
	int (*ndo_bpf)(struct net_device___22 *, struct netdev_bpf___17 *);
	int (*ndo_xdp_xmit)(struct net_device___22 *, int, struct xdp_frame___17 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___22 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___22 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct tcf_proto___16;

struct mini_Qdisc___16 {
	struct tcf_proto___16 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___16 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___22 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___27 *, struct net_device___22 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___22 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___22 *, struct list_head *);
	size_t (*get_size)(const struct net_device___22 *);
	int (*fill_info)(struct sk_buff___21 *, const struct net_device___22 *);
	size_t (*get_xstats_size)(const struct net_device___22 *);
	int (*fill_xstats)(struct sk_buff___21 *, const struct net_device___22 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___22 *, struct net_device___22 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___22 *, const struct net_device___22 *);
	int (*fill_slave_info)(struct sk_buff___21 *, const struct net_device___22 *, const struct net_device___22 *);
	struct net___27 * (*get_link_net)(const struct net_device___22 *);
	size_t (*get_linkxstats_size)(const struct net_device___22 *, int);
	int (*fill_linkxstats)(struct sk_buff___21 *, const struct net_device___22 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___17 {
	struct list_head poll_list;
	struct sk_buff_head___18 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___17 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___16 *output_queue;
	struct Qdisc___16 **output_queue_tailp;
	struct sk_buff___21 *completion_queue;
	struct sk_buff_head___18 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___17 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___18 input_pkt_queue;
	struct napi_struct___17 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct gnet_dump___16 {
	spinlock_t *lock;
	struct sk_buff___21 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___16;

struct Qdisc_ops___16 {
	struct Qdisc_ops___16 *next;
	const struct Qdisc_class_ops___16 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___21 *, struct Qdisc___16 *, struct sk_buff___21 **);
	struct sk_buff___21 * (*dequeue)(struct Qdisc___16 *);
	struct sk_buff___21 * (*peek)(struct Qdisc___16 *);
	int (*init)(struct Qdisc___16 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___16 *);
	void (*destroy)(struct Qdisc___16 *);
	int (*change)(struct Qdisc___16 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___16 *);
	int (*change_tx_queue_len)(struct Qdisc___16 *, unsigned int);
	int (*dump)(struct Qdisc___16 *, struct sk_buff___21 *);
	int (*dump_stats)(struct Qdisc___16 *, struct gnet_dump___16 *);
	void (*ingress_block_set)(struct Qdisc___16 *, u32);
	void (*egress_block_set)(struct Qdisc___16 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___16 *);
	u32 (*egress_block_get)(struct Qdisc___16 *);
	struct module___103 *owner;
};

struct tcf_block___16;

struct Qdisc_class_ops___16 {
	unsigned int flags;
	struct netdev_queue___17 * (*select_queue)(struct Qdisc___16 *, struct tcmsg *);
	int (*graft)(struct Qdisc___16 *, long unsigned int, struct Qdisc___16 *, struct Qdisc___16 **, struct netlink_ext_ack *);
	struct Qdisc___16 * (*leaf)(struct Qdisc___16 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___16 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___16 *, u32);
	int (*change)(struct Qdisc___16 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___16 *, long unsigned int);
	void (*walk)(struct Qdisc___16 *, struct qdisc_walker *);
	struct tcf_block___16 * (*tcf_block)(struct Qdisc___16 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___16 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___16 *, long unsigned int);
	int (*dump)(struct Qdisc___16 *, long unsigned int, struct sk_buff___21 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___16 *, long unsigned int, struct gnet_dump___16 *);
};

struct tcf_chain___16;

struct tcf_block___16 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___27 *net;
	struct Qdisc___16 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___16 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___16;

struct tcf_proto_ops___16;

struct tcf_proto___16 {
	struct tcf_proto___16 *next;
	void *root;
	int (*classify)(struct sk_buff___21 *, const struct tcf_proto___16 *, struct tcf_result___16 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___16 *ops;
	struct tcf_chain___16 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___16 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___16 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___16 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___21 *, const struct tcf_proto___16 *, struct tcf_result___16 *);
	int (*init)(struct tcf_proto___16 *);
	void (*destroy)(struct tcf_proto___16 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___16 *, u32);
	void (*put)(struct tcf_proto___16 *, void *);
	int (*change)(struct net___27 *, struct sk_buff___21 *, struct tcf_proto___16 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___16 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___16 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___16 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___27 *, struct tcf_chain___16 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___27 *, struct tcf_proto___16 *, void *, struct sk_buff___21 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___21 *, struct net___27 *, void *);
	struct module___103 *owner;
	int flags;
};

struct tcf_chain___16 {
	struct mutex filter_chain_lock;
	struct tcf_proto___16 *filter_chain;
	struct list_head list;
	struct tcf_block___16 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___16 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct bpf_redirect_info___16 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___96 *map;
	struct bpf_map___96 *map_to_flush;
	u32 kern_flags;
};

struct bpf_reg_state___2 {
	enum bpf_reg_type type;
	union {
		u16 range;
		struct bpf_map___96 *map_ptr;
		long unsigned int raw;
	};
	s32 off;
	u32 id;
	struct tnum var_off;
	s64 smin_value;
	s64 smax_value;
	u64 umin_value;
	u64 umax_value;
	struct bpf_reg_state___2 *parent;
	u32 frameno;
	enum bpf_reg_liveness live;
};

struct bpf_stack_state___2 {
	struct bpf_reg_state___2 spilled_ptr;
	u8 slot_type[8];
};

struct bpf_func_state___2 {
	struct bpf_reg_state___2 regs[11];
	int callsite;
	u32 frameno;
	u32 subprogno;
	int acquired_refs;
	struct bpf_reference_state *refs;
	int allocated_stack;
	struct bpf_stack_state___2 *stack;
};

struct bpf_verifier_state___2 {
	struct bpf_func_state___2 *frame[8];
	u32 curframe;
	bool speculative;
};

struct bpf_verifier_state_list___2 {
	struct bpf_verifier_state___2 state;
	struct bpf_verifier_state_list___2 *next;
};

struct bpf_offload_netdev {
	struct rhash_head l;
	struct net_device___22 *netdev;
	struct bpf_offload_dev___2 *offdev;
	struct list_head progs;
	struct list_head maps;
	struct list_head offdev_netdevs;
};

struct ns_get_path_bpf_prog_args {
	struct bpf_prog___16 *prog;
	struct bpf_prog_info *info;
};

struct ns_get_path_bpf_map_args {
	struct bpf_offloaded_map___17 *offmap;
	struct bpf_map_info *info;
};

enum bpf_stack_build_id_status {
	BPF_STACK_BUILD_ID_EMPTY = 0,
	BPF_STACK_BUILD_ID_VALID = 1,
	BPF_STACK_BUILD_ID_IP = 2,
};

struct bpf_stack_build_id {
	__s32 status;
	unsigned char build_id[20];
	union {
		__u64 offset;
		__u64 ip;
	};
};

typedef __u32 Elf32_Addr;

typedef __u16 Elf32_Half;

typedef __u32 Elf32_Off;

typedef __u32 Elf32_Word;

struct elf32_hdr {
	unsigned char e_ident[16];
	Elf32_Half e_type;
	Elf32_Half e_machine;
	Elf32_Word e_version;
	Elf32_Addr e_entry;
	Elf32_Off e_phoff;
	Elf32_Off e_shoff;
	Elf32_Word e_flags;
	Elf32_Half e_ehsize;
	Elf32_Half e_phentsize;
	Elf32_Half e_phnum;
	Elf32_Half e_shentsize;
	Elf32_Half e_shnum;
	Elf32_Half e_shstrndx;
};

typedef struct elf32_hdr Elf32_Ehdr;

struct elf32_phdr {
	Elf32_Word p_type;
	Elf32_Off p_offset;
	Elf32_Addr p_vaddr;
	Elf32_Addr p_paddr;
	Elf32_Word p_filesz;
	Elf32_Word p_memsz;
	Elf32_Word p_flags;
	Elf32_Word p_align;
};

typedef struct elf32_phdr Elf32_Phdr;

struct elf32_note {
	Elf32_Word n_namesz;
	Elf32_Word n_descsz;
	Elf32_Word n_type;
};

typedef struct elf32_note Elf32_Nhdr;

struct stack_map_bucket {
	struct pcpu_freelist_node fnode;
	u32 hash;
	u32 nr;
	u64 data[0];
};

struct bpf_stack_map {
	struct bpf_map___85 map;
	void *elems;
	struct pcpu_freelist freelist;
	u32 n_buckets;
	struct stack_map_bucket *buckets[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct stack_map_irq_work {
	struct irq_work irq_work;
	struct rw_semaphore___109 *sem;
};

struct module___104;

struct file___121;

struct kiocb___121;

struct iov_iter___50;

struct poll_table_struct___81;

struct vm_area_struct___121;

struct inode___122;

struct file_lock___121;

struct page___121;

struct pipe_inode_info___31;

struct seq_file___111;

struct file_operations___121 {
	struct module___104 *owner;
	loff_t (*llseek)(struct file___121 *, loff_t, int);
	ssize_t (*read)(struct file___121 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___121 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___121 *, struct iov_iter___50 *);
	ssize_t (*write_iter)(struct kiocb___121 *, struct iov_iter___50 *);
	int (*iopoll)(struct kiocb___121 *, bool);
	int (*iterate)(struct file___121 *, struct dir_context *);
	int (*iterate_shared)(struct file___121 *, struct dir_context *);
	__poll_t (*poll)(struct file___121 *, struct poll_table_struct___81 *);
	long int (*unlocked_ioctl)(struct file___121 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___121 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___121 *, struct vm_area_struct___121 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___122 *, struct file___121 *);
	int (*flush)(struct file___121 *, fl_owner_t);
	int (*release)(struct inode___122 *, struct file___121 *);
	int (*fsync)(struct file___121 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___121 *, int);
	int (*lock)(struct file___121 *, int, struct file_lock___121 *);
	ssize_t (*sendpage)(struct file___121 *, struct page___121 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___121 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___121 *, int, struct file_lock___121 *);
	ssize_t (*splice_write)(struct pipe_inode_info___31 *, struct file___121 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___121 *, loff_t *, struct pipe_inode_info___31 *, size_t, unsigned int);
	int (*setlease)(struct file___121 *, long int, struct file_lock___121 **, void **);
	long int (*fallocate)(struct file___121 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___111 *, struct file___121 *);
	ssize_t (*copy_file_range)(struct file___121 *, loff_t, struct file___121 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___121 *, loff_t, struct file___121 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___121 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___120 {
	u64 seqnum;
	struct vm_area_struct___121 *vmas[4];
};

struct page_frag___120 {
	struct page___121 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___120;

struct mem_cgroup___39;

struct cred___116;

struct nsproxy___113;

struct signal_struct___110;

struct bio_list___44;

struct backing_dev_info___44;

struct css_set___97;

struct vm_struct___90;

struct task_struct___121 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___121 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___120 *mm;
	struct mm_struct___120 *active_mm;
	struct vmacache___120 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___121 *real_parent;
	struct task_struct___121 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___121 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___39 *active_memcg;
	long int rh_reserved2;
	struct pid___98 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___98 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___98 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___116 *ptracer_cred;
	const struct cred___116 *real_cred;
	const struct cred___116 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___113 *nsproxy;
	struct signal_struct___110 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___121 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___44 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___44 *backing_dev_info;
	struct io_context___17 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___97 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___31 *splice_pipe;
	struct page_frag___120 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___39 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___121 *oom_reaper_list;
	struct vm_struct___90 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___74 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rw_semaphore___121 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___121 *owner;
};

struct key___116;

struct ucounts___101;

struct user_namespace___101 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___101 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___8 ns;
	long unsigned int flags;
	struct key___116 *persistent_keyring_register;
	struct rw_semaphore___121 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___101 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct secondary_data___121 {
	void *stack;
	struct task_struct___121 *task;
	long int status;
};

typedef struct page___121 *pgtable_t___120;

struct address_space___120;

struct dev_pagemap___118;

struct page___121 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___120 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___121 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___120 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___120 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___118 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___39 *mem_cgroup;
};

struct user_struct___116 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___116 *uid_keyring;
	struct key___116 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___118;

struct vm_area_struct___121 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___121 *vm_next;
	struct vm_area_struct___121 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___120 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___118 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___121 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___120;

struct mm_struct___120 {
	struct {
		struct vm_area_struct___121 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___121 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___121 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___120 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___121 *owner;
		struct user_namespace___101 *user_ns;
		struct file___121 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___120 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup___97;

struct cgroup_subsys___97;

struct cgroup_subsys_state___97 {
	struct cgroup___97 *cgroup;
	struct cgroup_subsys___97 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___97 *parent;
};

struct kernfs_node___117;

struct cgroup_file___97 {
	struct kernfs_node___117 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___39;

struct mem_cgroup___39 {
	struct cgroup_subsys_state___97 css;
	struct mem_cgroup_id___16 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___97 events_file;
	struct cgroup_file___97 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___121 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___39 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cred___116 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___116 *session_keyring;
	struct key___116 *process_keyring;
	struct key___116 *thread_keyring;
	struct key___116 *request_key_auth;
	void *security;
	struct user_struct___116 *user;
	struct user_namespace___101 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___28;

struct cgroup_namespace___97;

struct nsproxy___113 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net___28 *net_ns;
	struct cgroup_namespace___97 *cgroup_ns;
};

struct signal_struct___110 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___121 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___121 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___98 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___98 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___120 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___98 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___44;

struct bio_list___44 {
	struct bio___44 *head;
	struct bio___44 *tail;
};

struct bdi_writeback_congested___44;

struct bdi_writeback___44 {
	struct backing_dev_info___44 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___44 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___97 *memcg_css;
	struct cgroup_subsys_state___97 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___112;

struct dentry___121;

struct backing_dev_info___44 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___44 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___112 *dev;
	struct device___112 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___121 *debug_dir;
	struct dentry___121 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___97 {
	struct cgroup_subsys_state___97 *subsys[13];
	refcount_t refcount;
	struct css_set___97 *dom_cset;
	struct cgroup___97 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___97 *mg_src_cgrp;
	struct cgroup___97 *mg_dst_cgrp;
	struct css_set___97 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___120;

struct pipe_buffer___31;

struct pipe_inode_info___31 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___121 *tmp_page;
	struct fasync_struct___120 *fasync_readers;
	struct fasync_struct___120 *fasync_writers;
	struct pipe_buffer___31 *bufs;
	struct user_struct___116 *user;
};

struct vm_struct___90 {
	struct vm_struct___90 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___121 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___110 {
	struct task_struct___121 task;
	long unsigned int stack[8192];
};

struct dentry_operations___120;

struct super_block___121;

struct dentry___121 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___121 *d_parent;
	struct qstr d_name;
	struct inode___122 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___120 *d_op;
	struct super_block___121 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___120;

struct address_space___120 {
	struct inode___122 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___121 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___120 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___120;

struct block_device___121;

struct inode___122 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___120 *i_op;
	struct super_block___121 *i_sb;
	struct address_space___120 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___121 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___44 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___121 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___120 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___31 *i_pipe;
		struct block_device___121 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___120;

struct dentry_operations___120 {
	int (*d_revalidate)(struct dentry___121 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___121 *, unsigned int);
	int (*d_hash)(const struct dentry___121 *, struct qstr *);
	int (*d_compare)(const struct dentry___121 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___121 *);
	int (*d_init)(struct dentry___121 *);
	void (*d_release)(struct dentry___121 *);
	void (*d_prune)(struct dentry___121 *);
	void (*d_iput)(struct dentry___121 *, struct inode___122 *);
	char * (*d_dname)(struct dentry___121 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___120 *);
	int (*d_manage)(const struct path___120 *, bool);
	struct dentry___121 * (*d_real)(struct dentry___121 *, const struct inode___122 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___120;

struct mem_dqinfo___120 {
	struct quota_format_type___120 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___120;

struct quota_info___120 {
	unsigned int flags;
	struct rw_semaphore___121 dqio_sem;
	struct inode___122 *files[3];
	struct mem_dqinfo___120 info[3];
	const struct quota_format_ops___120 *ops[3];
};

struct rcuwait___120 {
	struct task_struct___121 *task;
};

struct percpu_rw_semaphore___120 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___121 rw_sem;
	struct rcuwait___120 writer;
	int readers_block;
};

struct sb_writers___120 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___120 rw_sem[3];
};

struct shrink_control___39;

struct shrinker___39 {
	long unsigned int (*count_objects)(struct shrinker___39 *, struct shrink_control___39 *);
	long unsigned int (*scan_objects)(struct shrinker___39 *, struct shrink_control___39 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___120;

struct super_operations___120;

struct dquot_operations___120;

struct quotactl_ops___120;

struct super_block___121 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___120 *s_type;
	const struct super_operations___120 *s_op;
	const struct dquot_operations___120 *dq_op;
	const struct quotactl_ops___120 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___121 *s_root;
	struct rw_semaphore___121 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___121 *s_bdev;
	struct backing_dev_info___44 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___120 s_dquot;
	struct sb_writers___120 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___120 *s_d_op;
	int cleancache_poolid;
	struct shrinker___39 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___101 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct path___120 {
	struct vfsmount *mnt;
	struct dentry___121 *dentry;
};

struct shrink_control___39 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___39 *memcg;
};

struct pglist_data___120;

struct lruvec___120 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___120 *pgdat;
};

struct zone___120 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___120 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___120 {
	struct zone___120 *zone;
	int zone_idx;
};

struct zonelist___120 {
	struct zoneref___120 _zonerefs[25];
};

struct pglist_data___120 {
	struct zone___120 node_zones[3];
	struct zonelist___120 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___121 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___121 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___120 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___120 {
	struct rw_semaphore___121 rwsem;
	struct notifier_block *head;
};

typedef int (*dev_page_fault_t___118)(struct vm_area_struct___121 *, long unsigned int, const struct page___121 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___118)(struct page___121 *, void *);

struct dev_pagemap___118 {
	dev_page_fault_t___118 page_fault;
	dev_page_free_t___118 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___112 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct file___121 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___120 f_path;
	struct inode___122 *f_inode;
	const struct file_operations___121 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___98 f_owner;
	const struct cred___116 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___120 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___118;

struct vm_operations_struct___118 {
	void (*open)(struct vm_area_struct___121 *);
	void (*close)(struct vm_area_struct___121 *);
	int (*split)(struct vm_area_struct___121 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___121 *);
	vm_fault_t (*fault)(struct vm_fault___118 *);
	vm_fault_t (*huge_fault)(struct vm_fault___118 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___118 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___121 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___118 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___118 *);
	int (*access)(struct vm_area_struct___121 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___121 *);
	int (*set_policy)(struct vm_area_struct___121 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___121 *, long unsigned int);
	struct page___121 * (*find_special_page)(struct vm_area_struct___121 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___120 {
	struct task_struct___121 *task;
	struct core_thread___120 *next;
};

struct core_state___120 {
	atomic_t nr_threads;
	struct core_thread___120 dumper;
	struct completion startup;
};

struct vm_fault___118 {
	struct vm_area_struct___121 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___121 *cow_page;
	struct mem_cgroup___39 *memcg;
	struct page___121 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___120 prealloc_pte;
};

struct kiocb___121 {
	struct file___121 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___121 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___121 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___121 *ia_file;
};

struct dquot___120 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___121 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___120 {
	int qf_fmt_id;
	const struct quota_format_ops___120 *qf_ops;
	struct module___104 *qf_owner;
	struct quota_format_type___120 *qf_next;
};

struct quota_format_ops___120 {
	int (*check_quota_file)(struct super_block___121 *, int);
	int (*read_file_info)(struct super_block___121 *, int);
	int (*write_file_info)(struct super_block___121 *, int);
	int (*free_file_info)(struct super_block___121 *, int);
	int (*read_dqblk)(struct dquot___120 *);
	int (*commit_dqblk)(struct dquot___120 *);
	int (*release_dqblk)(struct dquot___120 *);
	int (*get_next_id)(struct super_block___121 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___120 {
	int (*write_dquot)(struct dquot___120 *);
	struct dquot___120 * (*alloc_dquot)(struct super_block___121 *, int);
	void (*destroy_dquot)(struct dquot___120 *);
	int (*acquire_dquot)(struct dquot___120 *);
	int (*release_dquot)(struct dquot___120 *);
	int (*mark_dirty)(struct dquot___120 *);
	int (*write_info)(struct super_block___121 *, int);
	qsize_t * (*get_reserved_space)(struct inode___122 *);
	int (*get_projid)(struct inode___122 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___122 *, qsize_t *);
	int (*get_next_id)(struct super_block___121 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___120 {
	int (*quota_on)(struct super_block___121 *, int, int, const struct path___120 *);
	int (*quota_off)(struct super_block___121 *, int);
	int (*quota_enable)(struct super_block___121 *, unsigned int);
	int (*quota_disable)(struct super_block___121 *, unsigned int);
	int (*quota_sync)(struct super_block___121 *, int);
	int (*set_info)(struct super_block___121 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___121 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___121 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___121 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___121 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___121 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___114;

struct kobj_type___114;

struct kobject___115 {
	const char *name;
	struct list_head entry;
	struct kobject___115 *parent;
	struct kset___114 *kset;
	struct kobj_type___114 *ktype;
	struct kernfs_node___117 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___101 {
	struct kobject___115 kobj;
	struct module___104 *mod;
	struct kobject___115 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___101 {
	struct module___104 *mod;
	struct latch_tree_node node;
};

struct module_layout___101 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___101 mtn;
};

struct module_attribute___101;

struct kernel_param___101;

struct module___104 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___101 mkobj;
	struct module_attribute___101 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___115 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___101 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___101 core_layout;
	struct module_layout___101 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide53;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide54;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___41;

struct address_space_operations___120 {
	int (*writepage)(struct page___121 *, struct writeback_control___41 *);
	int (*readpage)(struct file___121 *, struct page___121 *);
	int (*writepages)(struct address_space___120 *, struct writeback_control___41 *);
	int (*set_page_dirty)(struct page___121 *);
	int (*readpages)(struct file___121 *, struct address_space___120 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___121 *, struct address_space___120 *, loff_t, unsigned int, unsigned int, struct page___121 **, void **);
	int (*write_end)(struct file___121 *, struct address_space___120 *, loff_t, unsigned int, unsigned int, struct page___121 *, void *);
	sector_t (*bmap)(struct address_space___120 *, sector_t);
	void (*invalidatepage)(struct page___121 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___121 *, gfp_t);
	void (*freepage)(struct page___121 *);
	ssize_t (*direct_IO)(struct kiocb___121 *, struct iov_iter___50 *);
	int (*migratepage)(struct address_space___120 *, struct page___121 *, struct page___121 *, enum migrate_mode);
	bool (*isolate_page)(struct page___121 *, isolate_mode_t);
	void (*putback_page)(struct page___121 *);
	int (*launder_page)(struct page___121 *);
	int (*is_partially_uptodate)(struct page___121 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___121 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___120 *, struct page___121 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___121 *, sector_t *);
	void (*swap_deactivate)(struct file___121 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___41 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___44 *wb;
	struct inode___122 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___44;

struct iov_iter___50 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___44 *bvec;
		struct pipe_inode_info___31 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___121 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___122 *bd_inode;
	struct super_block___121 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___121 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___44 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___120 {
	struct dentry___121 * (*lookup)(struct inode___122 *, struct dentry___121 *, unsigned int);
	const char * (*get_link)(struct dentry___121 *, struct inode___122 *, struct delayed_call *);
	int (*permission)(struct inode___122 *, int);
	struct posix_acl * (*get_acl)(struct inode___122 *, int);
	int (*readlink)(struct dentry___121 *, char *, int);
	int (*create)(struct inode___122 *, struct dentry___121 *, umode_t, bool);
	int (*link)(struct dentry___121 *, struct inode___122 *, struct dentry___121 *);
	int (*unlink)(struct inode___122 *, struct dentry___121 *);
	int (*symlink)(struct inode___122 *, struct dentry___121 *, const char *);
	int (*mkdir)(struct inode___122 *, struct dentry___121 *, umode_t);
	int (*rmdir)(struct inode___122 *, struct dentry___121 *);
	int (*mknod)(struct inode___122 *, struct dentry___121 *, umode_t, dev_t);
	int (*rename)(struct inode___122 *, struct dentry___121 *, struct inode___122 *, struct dentry___121 *, unsigned int);
	int (*setattr)(struct dentry___121 *, struct iattr___121 *);
	int (*getattr)(const struct path___120 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___121 *, char *, size_t);
	int (*fiemap)(struct inode___122 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___122 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___122 *, struct dentry___121 *, struct file___121 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___122 *, struct dentry___121 *, umode_t);
	int (*set_acl)(struct inode___122 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___120 {
	void (*fl_copy_lock)(struct file_lock___121 *, struct file_lock___121 *);
	void (*fl_release_private)(struct file_lock___121 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___120;

struct file_lock___121 {
	struct file_lock___121 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___121 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___120 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___120 *fl_ops;
	const struct lock_manager_operations___120 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___120 {
	int (*lm_compare_owner)(struct file_lock___121 *, struct file_lock___121 *);
	long unsigned int (*lm_owner_key)(struct file_lock___121 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___121 *);
	int (*lm_grant)(struct file_lock___121 *, int);
	bool (*lm_break)(struct file_lock___121 *);
	int (*lm_change)(struct file_lock___121 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___121 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___120 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___120 *fa_next;
	struct file___121 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___120 {
	const char *name;
	int fs_flags;
	struct dentry___121 * (*mount)(struct file_system_type___120 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___121 *);
	struct module___104 *owner;
	struct file_system_type___120 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___120 {
	struct inode___122 * (*alloc_inode)(struct super_block___121 *);
	void (*destroy_inode)(struct inode___122 *);
	void (*dirty_inode)(struct inode___122 *, int);
	int (*write_inode)(struct inode___122 *, struct writeback_control___41 *);
	int (*drop_inode)(struct inode___122 *);
	void (*evict_inode)(struct inode___122 *);
	void (*put_super)(struct super_block___121 *);
	int (*sync_fs)(struct super_block___121 *, int);
	int (*freeze_super)(struct super_block___121 *);
	int (*freeze_fs)(struct super_block___121 *);
	int (*thaw_super)(struct super_block___121 *);
	int (*unfreeze_fs)(struct super_block___121 *);
	int (*statfs)(struct dentry___121 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___121 *, int *, char *);
	void (*umount_begin)(struct super_block___121 *);
	int (*show_options)(struct seq_file___111 *, struct dentry___121 *);
	int (*show_devname)(struct seq_file___111 *, struct dentry___121 *);
	int (*show_path)(struct seq_file___111 *, struct dentry___121 *);
	int (*show_stats)(struct seq_file___111 *, struct dentry___121 *);
	ssize_t (*quota_read)(struct super_block___121 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___121 *, int, const char *, size_t, loff_t);
	struct dquot___120 ** (*get_dquots)(struct inode___122 *);
	int (*bdev_try_to_free_page)(struct super_block___121 *, struct page___121 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___121 *, struct shrink_control___39 *);
	long int (*free_cached_objects)(struct super_block___121 *, struct shrink_control___39 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___80)(struct file___121 *, wait_queue_head_t *, struct poll_table_struct___81 *);

struct poll_table_struct___81 {
	poll_queue_proc___80 _qproc;
	__poll_t _key;
};

struct seq_operations___109;

struct seq_file___111 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___109 *op;
	int poll_event;
	const struct file___121 *file;
	void *private;
};

typedef void bio_end_io_t___44(struct bio___44 *);

struct bio_vec___44 {
	struct page___121 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___44;

struct bio_set___44;

struct bio___44 {
	struct bio___44 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___44 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___44 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___44 *bi_io_vec;
	struct bio_set___44 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___44 bi_inline_vecs[0];
};

typedef int (*key_restrict_link_func_t___116)(struct key___116 *, const struct key_type *, const union key_payload *, struct key___116 *);

struct key_restriction___116;

struct key___116 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___121 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___116 *restrict_link;
};

struct key_restriction___116 {
	key_restrict_link_func_t___116 check;
	struct key___116 *key;
	struct key_type *keytype;
};

struct seq_operations___109 {
	void * (*start)(struct seq_file___111 *, loff_t *);
	void (*stop)(struct seq_file___111 *, void *);
	void * (*next)(struct seq_file___111 *, void *, loff_t *);
	int (*show)(struct seq_file___111 *, void *);
};

struct kernfs_root___117;

struct kernfs_elem_dir___117 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___117 *root;
};

struct kernfs_syscall_ops___117;

struct kernfs_root___117 {
	struct kernfs_node___117 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___117 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___117 {
	struct kernfs_node___117 *target_kn;
};

struct kernfs_ops___117;

struct kernfs_elem_attr___117 {
	const struct kernfs_ops___117 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___117 *notify_next;
};

struct kernfs_node___117 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___117 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___117 dir;
		struct kernfs_elem_symlink___117 symlink;
		struct kernfs_elem_attr___117 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___117;

struct kernfs_ops___117 {
	int (*open)(struct kernfs_open_file___117 *);
	void (*release)(struct kernfs_open_file___117 *);
	int (*seq_show)(struct seq_file___111 *, void *);
	void * (*seq_start)(struct seq_file___111 *, loff_t *);
	void * (*seq_next)(struct seq_file___111 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___111 *, void *);
	ssize_t (*read)(struct kernfs_open_file___117 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___117 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___117 *, struct vm_area_struct___121 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___117 *, struct poll_table_struct___81 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___117 {
	int (*remount_fs)(struct kernfs_root___117 *, int *, char *);
	int (*show_options)(struct seq_file___111 *, struct kernfs_root___117 *);
	int (*mkdir)(struct kernfs_node___117 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___117 *);
	int (*rename)(struct kernfs_node___117 *, struct kernfs_node___117 *, const char *);
	int (*show_path)(struct seq_file___111 *, struct kernfs_node___117 *, struct kernfs_root___117 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___117 {
	struct kernfs_node___117 *kn;
	struct file___121 *file;
	struct seq_file___111 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___118 *vm_ops;
};

struct inet_frags___18;

struct netns_frags___18 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___18 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_rules_ops___8;

struct sock___11;

struct fib_notifier_ops___8;

struct netns_ipv4___18 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___8 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___11 *fibnl;
	struct sock___11 **icmp_sk;
	struct sock___11 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___11 **tcp_sk;
	struct netns_frags___18 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___8 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___8 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___8 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct dst_entry___10;

struct net_device___23;

struct sk_buff___22;

struct neighbour___10;

struct dst_ops___26 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___26 *);
	struct dst_entry___10 * (*check)(struct dst_entry___10 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___10 *);
	unsigned int (*mtu)(const struct dst_entry___10 *);
	u32 * (*cow_metrics)(struct dst_entry___10 *, long unsigned int);
	void (*destroy)(struct dst_entry___10 *);
	void (*ifdown)(struct dst_entry___10 *, struct net_device___23 *, int);
	struct dst_entry___10 * (*negative_advice)(struct dst_entry___10 *);
	void (*link_failure)(struct sk_buff___22 *);
	void (*update_pmtu)(struct dst_entry___10 *, struct sock___11 *, struct sk_buff___22 *, u32);
	void (*redirect)(struct dst_entry___10 *, struct sock___11 *, struct sk_buff___22 *);
	int (*local_out)(struct net___28 *, struct sock___11 *, struct sk_buff___22 *);
	struct neighbour___10 * (*neigh_lookup)(const struct dst_entry___10 *, struct sk_buff___22 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___10 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___25 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___18 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___26 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___8 *fib6_rules_ops;
	struct sock___11 **icmp_sk;
	struct sock___11 *ndisc_sk;
	struct sock___11 *tcp_sk;
	struct sock___11 *igmp_sk;
	struct sock___11 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___8 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___8 *notifier_ops;
	struct fib_notifier_ops___8 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___8 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___11 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___18 {
	struct netns_frags___18 frags;
};

struct netns_xfrm___25 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___11 *nlsk;
	struct sock___11 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___26 xfrm4_dst_ops;
	struct dst_ops___26 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___17;

struct net___28 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___101 *user_ns;
	struct ucounts___101 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___8 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___11 *rtnl;
	struct sock___11 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___23 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___18 ipv4;
	struct netns_ipv6___25 ipv6;
	struct netns_sctp___8 sctp;
	struct netns_nf nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___18 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___11 *nfnl;
	struct sock___11 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___25 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___11 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___17 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cgroup_namespace___97 {
	refcount_t count;
	struct ns_common___8 ns;
	struct user_namespace___101 *user_ns;
	struct ucounts___101 *ucounts;
	struct css_set___97 *root_cset;
};

struct ucounts___101 {
	struct hlist_node node;
	struct user_namespace___101 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_flow_keys {
	__u16 nhoff;
	__u16 thoff;
	__u16 addr_proto;
	__u8 is_frag;
	__u8 is_first_frag;
	__u8 is_encap;
	__u8 ip_proto;
	__be16 n_proto;
	__be16 sport;
	__be16 dport;
	union {
		struct {
			__be32 ipv4_src;
			__be32 ipv4_dst;
		};
		struct {
			__u32 ipv6_src[4];
			__u32 ipv6_dst[4];
		};
	};
};

struct __sk_buff {
	__u32 len;
	__u32 pkt_type;
	__u32 mark;
	__u32 queue_mapping;
	__u32 protocol;
	__u32 vlan_present;
	__u32 vlan_tci;
	__u32 vlan_proto;
	__u32 priority;
	__u32 ingress_ifindex;
	__u32 ifindex;
	__u32 tc_index;
	__u32 cb[5];
	__u32 hash;
	__u32 tc_classid;
	__u32 data;
	__u32 data_end;
	__u32 napi_id;
	__u32 family;
	__u32 remote_ip4;
	__u32 local_ip4;
	__u32 remote_ip6[4];
	__u32 local_ip6[4];
	__u32 remote_port;
	__u32 local_port;
	__u32 data_meta;
	union {
		struct bpf_flow_keys *flow_keys;
	};
	__u64 tstamp;
	__u32 wire_len;
};

struct bpf_cgroup_dev_ctx {
	__u32 access_type;
	__u32 major;
	__u32 minor;
};

struct bpf_map___97;

struct bpf_map_ops___97 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___97 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___97 *, struct file___121 *);
	void (*map_free)(struct bpf_map___97 *);
	int (*map_get_next_key)(struct bpf_map___97 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___97 *);
	void * (*map_lookup_elem)(struct bpf_map___97 *, void *);
	int (*map_update_elem)(struct bpf_map___97 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___97 *, void *);
	int (*map_push_elem)(struct bpf_map___97 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___97 *, void *);
	int (*map_peek_elem)(struct bpf_map___97 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___97 *, struct file___121 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___97 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___97 *, void *, struct seq_file___111 *);
	int (*map_check_btf)(const struct bpf_map___97 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___97 {
	const struct bpf_map_ops___97 *ops;
	struct bpf_map___97 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___116 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___18;

struct bpf_map_dev_ops___18 {
	int (*map_get_next_key)(struct bpf_offloaded_map___18 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___18 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___18 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___18 *, void *);
};

struct bpf_offloaded_map___18 {
	struct bpf_map___97 map;
	struct net_device___23 *netdev;
	const struct bpf_map_dev_ops___18 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

typedef rx_handler_result_t rx_handler_func_t___18(struct sk_buff___22 **);

typedef struct {
	struct net___28 *net;
} possible_net_t___19;

struct dev_pm_info___112 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___112 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___112;

struct bus_type___112;

struct device_driver___112;

struct dev_pm_domain___112;

struct dma_map_ops___34;

struct fwnode_handle___84;

struct class___112;

struct attribute_group___111;

struct device___112 {
	struct device___112 *parent;
	struct device_private *p;
	struct kobject___115 kobj;
	const char *init_name;
	const struct device_type___112 *type;
	struct mutex mutex;
	struct bus_type___112 *bus;
	struct device_driver___112 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___112 power;
	struct dev_pm_domain___112 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___34 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___84 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___112 *class;
	const struct attribute_group___111 **groups;
	void (*release)(struct device___112 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct net_device_ops___18;

struct ethtool_ops___18;

struct l3mdev_ops___9;

struct xfrmdev_ops___18;

struct tlsdev_ops___18;

struct header_ops___18;

struct netdev_rx_queue___18;

struct mini_Qdisc___17;

struct netdev_queue___18;

struct Qdisc___17;

struct rtnl_link_ops___17;

struct dcbnl_rtnl_ops___18;

struct net_device___23 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___18 *netdev_ops;
	const struct ethtool_ops___18 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___9 *l3mdev_ops;
	const struct ndisc_ops___2 *ndisc_ops;
	const struct xfrmdev_ops___18 *xfrmdev_ops;
	const struct tlsdev_ops___18 *tlsdev_ops;
	const struct header_ops___18 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___114 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___2 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___18 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___17 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___18 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___17 *miniq_ingress;
	struct netdev_queue___18 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___18 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___17 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___17 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___18 = 0,
		NETREG_REGISTERED___18 = 1,
		NETREG_UNREGISTERING___18 = 2,
		NETREG_UNREGISTERED___18 = 3,
		NETREG_RELEASED___18 = 4,
		NETREG_DUMMY___18 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___18 = 0,
		RTNL_LINK_INITIALIZING___18 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___23 *);
	struct netpoll_info *npinfo;
	possible_net_t___19 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___112 dev;
	const struct attribute_group___111 *sysfs_groups[4];
	const struct attribute_group___111 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___17 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___18 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct bpf_prog_ops___17 {
	int (*test_run)(struct bpf_prog___17 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_aux___17;

struct bpf_prog___17 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___17 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

struct bpf_verifier_ops___17 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___17 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___17 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___17 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___17 *, u32 *);
};

struct bpf_prog_offload_ops___17 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___17 *);
	int (*translate)(struct bpf_prog___17 *);
	void (*destroy)(struct bpf_prog___17 *);
};

struct bpf_prog_offload___17 {
	struct bpf_prog___17 *prog;
	struct net_device___23 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___17 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___17 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___17 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___17 *ops;
	struct bpf_map___97 **used_maps;
	struct bpf_prog___17 *prog;
	struct user_struct___116 *user;
	u64 load_time;
	struct bpf_map___97 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___17 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___17 {
	struct bpf_prog___17 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___17 {
	struct callback_head rcu;
	struct bpf_prog_array_item___17 items[0];
};

struct bpf_prog_list {
	struct list_head node;
	struct bpf_prog___17 *prog;
	struct bpf_cgroup_storage *storage[2];
};

struct cgroup_bpf___17 {
	struct bpf_prog_array___17 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___17 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___97;

typedef void (*kthread_work_func_t___97)(struct kthread_work___97 *);

struct kthread_worker___97;

struct kthread_work___97 {
	struct list_head node;
	kthread_work_func_t___97 func;
	struct kthread_worker___97 *worker;
	int canceling;
};

struct kthread_worker___97 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___121 *task;
	struct kthread_work___97 *current_work;
};

struct kthread_delayed_work___97 {
	struct kthread_work___97 work;
	struct timer_list timer;
};

struct psi_group___97 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___97 *poll_kworker;
	struct kthread_delayed_work___97 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___97;

struct cgroup_rstat_cpu___97;

struct cgroup___97 {
	struct cgroup_subsys_state___97 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___117 *kn;
	struct cgroup_file___97 procs_file;
	struct cgroup_file___97 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___97 *subsys[13];
	struct cgroup_root___97 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___97 *dom_cgrp;
	struct cgroup_rstat_cpu___97 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___17 bpf;
	atomic_t congestion_count;
	struct cgroup___97 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___97 psi;
	int ancestor_ids[0];
};

struct cftype___97;

struct cgroup_subsys___97 {
	struct cgroup_subsys_state___97 * (*css_alloc)(struct cgroup_subsys_state___97 *);
	int (*css_online)(struct cgroup_subsys_state___97 *);
	void (*css_offline)(struct cgroup_subsys_state___97 *);
	void (*css_released)(struct cgroup_subsys_state___97 *);
	void (*css_free)(struct cgroup_subsys_state___97 *);
	void (*css_reset)(struct cgroup_subsys_state___97 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___97 *, int);
	int (*css_extra_stat_show)(struct seq_file___111 *, struct cgroup_subsys_state___97 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___121 *);
	void (*cancel_fork)(struct task_struct___121 *);
	void (*fork)(struct task_struct___121 *);
	void (*exit)(struct task_struct___121 *);
	void (*free)(struct task_struct___121 *);
	void (*bind)(struct cgroup_subsys_state___97 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___97 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___97 *dfl_cftypes;
	struct cftype___97 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___97 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___97 *updated_children;
	struct cgroup___97 *updated_next;
};

struct cgroup_root___97 {
	struct kernfs_root___117 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___97 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___97 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___97 *ss;
	struct list_head node;
	struct kernfs_ops___117 *kf_ops;
	int (*open)(struct kernfs_open_file___117 *);
	void (*release)(struct kernfs_open_file___117 *);
	u64 (*read_u64)(struct cgroup_subsys_state___97 *, struct cftype___97 *);
	s64 (*read_s64)(struct cgroup_subsys_state___97 *, struct cftype___97 *);
	int (*seq_show)(struct seq_file___111 *, void *);
	void * (*seq_start)(struct seq_file___111 *, loff_t *);
	void * (*seq_next)(struct seq_file___111 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___111 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___97 *, struct cftype___97 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___97 *, struct cftype___97 *, s64);
	ssize_t (*write)(struct kernfs_open_file___117 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___117 *, struct poll_table_struct___81 *);
};

struct msghdr___8 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___50 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___121 *msg_iocb;
};

struct socket_wq___8 {
	wait_queue_head_t wait;
	struct fasync_struct___120 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___8;

struct socket___8 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___8 *wq;
	struct file___121 *file;
	struct sock___11 *sk;
	const struct proto_ops___8 *ops;
};

struct proto___8;

struct sock_common___8 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___8 *skc_prot;
	possible_net_t___19 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___11 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff_head___19 {
	struct sk_buff___22 *next;
	struct sk_buff___22 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___8;

struct sock___11 {
	struct sock_common___8 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___19 sk_error_queue;
	struct sk_buff_head___19 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___22 *head;
		struct sk_buff___22 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___8 *sk_filter;
	union {
		struct socket_wq___8 *sk_wq;
		struct socket_wq___8 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___10 *sk_rx_dst;
	struct dst_entry___10 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___22 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___19 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___120 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___8 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___98 *sk_peer_pid;
	const struct cred___116 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___8 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___39 *sk_memcg;
	void (*sk_state_change)(struct sock___11 *);
	void (*sk_data_ready)(struct sock___11 *);
	void (*sk_write_space)(struct sock___11 *);
	void (*sk_error_report)(struct sock___11 *);
	int (*sk_backlog_rcv)(struct sock___11 *, struct sk_buff___22 *);
	struct sk_buff___22 * (*sk_validate_xmit_skb)(struct sock___11 *, struct net_device___23 *, struct sk_buff___22 *);
	void (*sk_destruct)(struct sock___11 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

typedef int (*sk_read_actor_t___8)(read_descriptor_t *, struct sk_buff___22 *, unsigned int, size_t);

struct proto_ops___8 {
	int family;
	struct module___104 *owner;
	int (*release)(struct socket___8 *);
	int (*bind)(struct socket___8 *, struct sockaddr *, int);
	int (*connect)(struct socket___8 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___8 *, struct socket___8 *);
	int (*accept)(struct socket___8 *, struct socket___8 *, int, bool);
	int (*getname)(struct socket___8 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___121 *, struct socket___8 *, struct poll_table_struct___81 *);
	int (*ioctl)(struct socket___8 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___8 *, int);
	int (*shutdown)(struct socket___8 *, int);
	int (*setsockopt)(struct socket___8 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___8 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___8 *, struct msghdr___8 *, size_t);
	int (*recvmsg)(struct socket___8 *, struct msghdr___8 *, size_t, int);
	int (*mmap)(struct file___121 *, struct socket___8 *, struct vm_area_struct___121 *);
	ssize_t (*sendpage)(struct socket___8 *, struct page___121 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___8 *, loff_t *, struct pipe_inode_info___31 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___11 *, int);
	int (*peek_len)(struct socket___8 *);
	int (*read_sock)(struct sock___11 *, read_descriptor_t *, sk_read_actor_t___8);
	int (*sendpage_locked)(struct sock___11 *, struct page___121 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___11 *, struct msghdr___8 *, size_t);
	int (*set_rcvlowat)(struct sock___11 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct nf_bridge_info___18;

struct sk_buff___22 {
	union {
		struct {
			struct sk_buff___22 *next;
			struct sk_buff___22 *prev;
			union {
				struct net_device___23 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___11 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___22 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___18 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct kobj_ns_type_operations___8 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___11 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___111;

struct attribute_group___111 {
	const char *name;
	umode_t (*is_visible)(struct kobject___115 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___115 *, struct bin_attribute___111 *, int);
	struct attribute **attrs;
	struct bin_attribute___111 **bin_attrs;
};

struct bin_attribute___111 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___121 *, struct kobject___115 *, struct bin_attribute___111 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___121 *, struct kobject___115 *, struct bin_attribute___111 *, char *, loff_t, size_t);
	int (*mmap)(struct file___121 *, struct kobject___115 *, struct bin_attribute___111 *, struct vm_area_struct___121 *);
};

struct sysfs_ops___114 {
	ssize_t (*show)(struct kobject___115 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___115 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___114;

struct kset___114 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___115 kobj;
	const struct kset_uevent_ops___114 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___114 {
	void (*release)(struct kobject___115 *);
	const struct sysfs_ops___114 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___8 * (*child_ns_type)(struct kobject___115 *);
	const void * (*namespace)(struct kobject___115 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___114 {
	int (* const filter)(struct kset___114 *, struct kobject___115 *);
	const char * (* const name)(struct kset___114 *, struct kobject___115 *);
	int (* const uevent)(struct kset___114 *, struct kobject___115 *, struct kobj_uevent_env *);
};

struct kobj_attribute___115 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___115 *, struct kobj_attribute___115 *, char *);
	ssize_t (*store)(struct kobject___115 *, struct kobj_attribute___115 *, const char *, size_t);
};

struct dev_pm_ops___112 {
	int (*prepare)(struct device___112 *);
	void (*complete)(struct device___112 *);
	int (*suspend)(struct device___112 *);
	int (*resume)(struct device___112 *);
	int (*freeze)(struct device___112 *);
	int (*thaw)(struct device___112 *);
	int (*poweroff)(struct device___112 *);
	int (*restore)(struct device___112 *);
	int (*suspend_late)(struct device___112 *);
	int (*resume_early)(struct device___112 *);
	int (*freeze_late)(struct device___112 *);
	int (*thaw_early)(struct device___112 *);
	int (*poweroff_late)(struct device___112 *);
	int (*restore_early)(struct device___112 *);
	int (*suspend_noirq)(struct device___112 *);
	int (*resume_noirq)(struct device___112 *);
	int (*freeze_noirq)(struct device___112 *);
	int (*thaw_noirq)(struct device___112 *);
	int (*poweroff_noirq)(struct device___112 *);
	int (*restore_noirq)(struct device___112 *);
	int (*runtime_suspend)(struct device___112 *);
	int (*runtime_resume)(struct device___112 *);
	int (*runtime_idle)(struct device___112 *);
};

struct dev_pm_domain___112 {
	struct dev_pm_ops___112 ops;
	void (*detach)(struct device___112 *, bool);
	int (*activate)(struct device___112 *);
	void (*sync)(struct device___112 *);
	void (*dismiss)(struct device___112 *);
};

struct bus_type___112 {
	const char *name;
	const char *dev_name;
	struct device___112 *dev_root;
	const struct attribute_group___111 **bus_groups;
	const struct attribute_group___111 **dev_groups;
	const struct attribute_group___111 **drv_groups;
	int (*match)(struct device___112 *, struct device_driver___112 *);
	int (*uevent)(struct device___112 *, struct kobj_uevent_env *);
	int (*probe)(struct device___112 *);
	int (*remove)(struct device___112 *);
	void (*shutdown)(struct device___112 *);
	int (*online)(struct device___112 *);
	int (*offline)(struct device___112 *);
	int (*suspend)(struct device___112 *, pm_message_t);
	int (*resume)(struct device___112 *);
	int (*num_vf)(struct device___112 *);
	int (*dma_configure)(struct device___112 *);
	const struct dev_pm_ops___112 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___112 {
	const char *name;
	struct bus_type___112 *bus;
	struct module___104 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___112 *);
	int (*remove)(struct device___112 *);
	void (*shutdown)(struct device___112 *);
	int (*suspend)(struct device___112 *, pm_message_t);
	int (*resume)(struct device___112 *);
	const struct attribute_group___111 **groups;
	const struct dev_pm_ops___112 *pm;
	void (*coredump)(struct device___112 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___112 {
	const char *name;
	const struct attribute_group___111 **groups;
	int (*uevent)(struct device___112 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___112 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___112 *);
	const struct dev_pm_ops___112 *pm;
};

struct class___112 {
	const char *name;
	struct module___104 *owner;
	const struct attribute_group___111 **class_groups;
	const struct attribute_group___111 **dev_groups;
	struct kobject___115 *dev_kobj;
	int (*dev_uevent)(struct device___112 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___112 *, umode_t *);
	void (*class_release)(struct class___112 *);
	void (*dev_release)(struct device___112 *);
	int (*shutdown_pre)(struct device___112 *);
	const struct kobj_ns_type_operations___8 *ns_type;
	const void * (*namespace)(struct device___112 *);
	const struct dev_pm_ops___112 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___34 {
	void * (*alloc)(struct device___112 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___112 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___112 *, struct vm_area_struct___121 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___112 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___112 *, struct page___121 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___112 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___112 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___112 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___112 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___112 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___112 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___112 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___112 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___112 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___112 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___112 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___112 *, u64);
	u64 (*get_required_mask)(struct device___112 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___84;

struct fwnode_handle___84 {
	struct fwnode_handle___84 *secondary;
	const struct fwnode_operations___84 *ops;
};

typedef void compound_page_dtor___118(struct page___121 *);

struct fwnode_reference_args___84;

struct fwnode_endpoint___84;

struct fwnode_operations___84 {
	struct fwnode_handle___84 * (*get)(struct fwnode_handle___84 *);
	void (*put)(struct fwnode_handle___84 *);
	bool (*device_is_available)(const struct fwnode_handle___84 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___84 *, const struct device___112 *);
	bool (*property_present)(const struct fwnode_handle___84 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___84 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___84 *, const char *, const char **, size_t);
	struct fwnode_handle___84 * (*get_parent)(const struct fwnode_handle___84 *);
	struct fwnode_handle___84 * (*get_next_child_node)(const struct fwnode_handle___84 *, struct fwnode_handle___84 *);
	struct fwnode_handle___84 * (*get_named_child_node)(const struct fwnode_handle___84 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___84 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___84 *);
	struct fwnode_handle___84 * (*graph_get_next_endpoint)(const struct fwnode_handle___84 *, struct fwnode_handle___84 *);
	struct fwnode_handle___84 * (*graph_get_remote_endpoint)(const struct fwnode_handle___84 *);
	struct fwnode_handle___84 * (*graph_get_port_parent)(struct fwnode_handle___84 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___84 *, struct fwnode_endpoint___84 *);
};

struct fwnode_endpoint___84 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___84 *local_fwnode;
};

struct fwnode_reference_args___84 {
	struct fwnode_handle___84 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___31;

struct pipe_buffer___31 {
	struct page___121 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___31 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___31 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___31 *, struct pipe_buffer___31 *);
	void (*release)(struct pipe_inode_info___31 *, struct pipe_buffer___31 *);
	int (*steal)(struct pipe_inode_info___31 *, struct pipe_buffer___31 *);
	union {
		bool (*get)(struct pipe_inode_info___31 *, struct pipe_buffer___31 *);
		struct {
			void (*get)(struct pipe_inode_info___31 *, struct pipe_buffer___31 *);
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
};

struct nf_bridge_info___18 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___18 = 0,
		BRNF_PROTO_8021Q___18 = 1,
		BRNF_PROTO_PPPOE___18 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___23 *physindev;
	struct net_device___23 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

struct ethtool_ops___18 {
	int (*get_settings)(struct net_device___23 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___23 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___23 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___23 *);
	void (*get_regs)(struct net_device___23 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___23 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___23 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___23 *);
	void (*set_msglevel)(struct net_device___23 *, u32);
	int (*nway_reset)(struct net_device___23 *);
	u32 (*get_link)(struct net_device___23 *);
	int (*get_eeprom_len)(struct net_device___23 *);
	int (*get_eeprom)(struct net_device___23 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___23 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___23 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___23 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___23 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___23 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___23 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___23 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___23 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___23 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___23 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___23 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___23 *);
	void (*complete)(struct net_device___23 *);
	u32 (*get_priv_flags)(struct net_device___23 *);
	int (*set_priv_flags)(struct net_device___23 *, u32);
	int (*get_sset_count)(struct net_device___23 *, int);
	int (*get_rxnfc)(struct net_device___23 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___23 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___23 *, struct ethtool_flash *);
	int (*reset)(struct net_device___23 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___23 *);
	u32 (*get_rxfh_indir_size)(struct net_device___23 *);
	int (*get_rxfh)(struct net_device___23 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___23 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___23 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___23 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___23 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___23 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___23 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___23 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___23 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___23 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___23 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___23 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___23 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___23 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___23 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___23 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___23 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___23 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___23 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___23 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___23 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___23 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	int (*get_fecparam)(struct net_device___23 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___23 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___23 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___23 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___23 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___18;

struct inet_frags___18 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___18 *, const void *);
	void (*destructor)(struct inet_frag_queue___18 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___18 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___22 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___22 *fragments_tail;
	struct sk_buff___22 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___18 *net;
	struct callback_head rcu;
};

struct fib_rule___8;

struct fib_lookup_arg___8;

struct fib_rules_ops___8 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___8 *, struct flowi *, int, struct fib_lookup_arg___8 *);
	bool (*suppress)(struct fib_rule___8 *, struct fib_lookup_arg___8 *);
	int (*match)(struct fib_rule___8 *, struct flowi *, int);
	int (*configure)(struct fib_rule___8 *, struct sk_buff___22 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___8 *);
	int (*compare)(struct fib_rule___8 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___8 *, struct sk_buff___22 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___8 *);
	void (*flush_cache)(struct fib_rules_ops___8 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___104 *owner;
	struct net___28 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___8 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___28 *);
	int (*fib_dump)(struct net___28 *, struct notifier_block *);
	struct module___104 *owner;
	struct callback_head rcu;
};

struct dst_entry___10 {
	struct net_device___23 *dev;
	struct dst_ops___26 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___22 *);
	int (*output)(struct net___28 *, struct sock___11 *, struct sk_buff___22 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___9;

struct neigh_parms___10;

struct neigh_ops___9;

struct neighbour___10 {
	struct neighbour___10 *next;
	struct neigh_table___9 *tbl;
	struct neigh_parms___10 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___19 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___10 *, struct sk_buff___22 *);
	const struct neigh_ops___9 *ops;
	struct callback_head rcu;
	struct net_device___23 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct pernet_operations___18 {
	struct list_head list;
	int (*init)(struct net___28 *);
	void (*exit)(struct net___28 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___18 {
	int (*ieee_getets)(struct net_device___23 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___23 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___23 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___23 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___23 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___23 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___23 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___23 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___23 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___23 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___23 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___23 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___23 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___23 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___23 *);
	u8 (*setstate)(struct net_device___23 *, u8);
	void (*getpermhwaddr)(struct net_device___23 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___23 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___23 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___23 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___23 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___23 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___23 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___23 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___23 *, int, u8 *);
	void (*setpfccfg)(struct net_device___23 *, int, u8);
	void (*getpfccfg)(struct net_device___23 *, int, u8 *);
	u8 (*setall)(struct net_device___23 *);
	u8 (*getcap)(struct net_device___23 *, int, u8 *);
	int (*getnumtcs)(struct net_device___23 *, int, u8 *);
	int (*setnumtcs)(struct net_device___23 *, int, u8);
	u8 (*getpfcstate)(struct net_device___23 *);
	void (*setpfcstate)(struct net_device___23 *, u8);
	void (*getbcncfg)(struct net_device___23 *, int, u32 *);
	void (*setbcncfg)(struct net_device___23 *, int, u32);
	void (*getbcnrp)(struct net_device___23 *, int, u8 *);
	void (*setbcnrp)(struct net_device___23 *, int, u8);
	int (*setapp)(struct net_device___23 *, u8, u16, u8);
	int (*getapp)(struct net_device___23 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___23 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___23 *, int, u8);
	u8 (*getdcbx)(struct net_device___23 *);
	u8 (*setdcbx)(struct net_device___23 *, u8);
	int (*peer_getappinfo)(struct net_device___23 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___23 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___23 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___23 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___23 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___23 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct xdp_rxq_info___18 {
	struct net_device___23 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___18 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___23 *dev_rx;
};

struct netlink_callback___18 {
	struct sk_buff___22 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___18 *);
	int (*dump)(struct sk_buff___22 *, struct netlink_callback___18 *);
	int (*done)(struct netlink_callback___18 *);
	void *data;
	struct module___104 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___18 {
	int (*create)(struct sk_buff___22 *, struct net_device___23 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___22 *, unsigned char *);
	int (*cache)(const struct neighbour___10 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___23 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___18 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___18 *, int);
	int poll_owner;
	struct net_device___23 *dev;
	struct sk_buff___22 *gro_list;
	struct sk_buff___22 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___18 {
	struct net_device___23 *dev;
	struct Qdisc___17 *qdisc;
	struct Qdisc___17 *qdisc_sleeping;
	struct kobject___115 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___23 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___17 {
	struct sk_buff___22 *head;
	struct sk_buff___22 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___17;

struct Qdisc___17 {
	int (*enqueue)(struct sk_buff___22 *, struct Qdisc___17 *, struct sk_buff___22 **);
	struct sk_buff___22 * (*dequeue)(struct Qdisc___17 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___17 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___18 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___19 gso_skb;
	struct qdisc_skb_head___17 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___17 *next_sched;
	struct sk_buff_head___19 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___18 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___115 kobj;
	struct net_device___23 *dev;
	long: 64;
	struct xdp_rxq_info___18 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___18)(struct net_device___23 *, struct sk_buff___22 *, struct net_device___23 *);

struct netdev_bpf___18 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___17 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___17 *prog;
			const struct bpf_prog_offload_ops___17 *ops;
		} verifier;
		struct {
			struct bpf_prog___17 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___18 *offmap;
		};
		struct {
			struct xdp_umem *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___18 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___22 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___18 {
	int (*tls_dev_add)(struct net_device___23 *, struct sock___11 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___23 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___23 *, struct sock___11 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___18 {
	int (*ndo_init)(struct net_device___23 *);
	void (*ndo_uninit)(struct net_device___23 *);
	int (*ndo_open)(struct net_device___23 *);
	int (*ndo_stop)(struct net_device___23 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___22 *, struct net_device___23 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___22 *, struct net_device___23 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___23 *, struct sk_buff___22 *, struct net_device___23 *, select_queue_fallback_t___18);
	void (*ndo_change_rx_flags)(struct net_device___23 *, int);
	void (*ndo_set_rx_mode)(struct net_device___23 *);
	int (*ndo_set_mac_address)(struct net_device___23 *, void *);
	int (*ndo_validate_addr)(struct net_device___23 *);
	int (*ndo_do_ioctl)(struct net_device___23 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___23 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___23 *, int);
	int (*ndo_neigh_setup)(struct net_device___23 *, struct neigh_parms___10 *);
	void (*ndo_tx_timeout)(struct net_device___23 *);
	void (*ndo_get_stats64)(struct net_device___23 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___23 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___23 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___23 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___23 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___23 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___23 *);
	int (*ndo_netpoll_setup)(struct net_device___23 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___23 *);
	int (*ndo_set_vf_mac)(struct net_device___23 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___23 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___23 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___23 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___23 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___23 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___23 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___23 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___23 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___23 *, int, struct sk_buff___22 *);
	int (*ndo_set_vf_guid)(struct net_device___23 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___23 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___23 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___23 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___23 *, const struct sk_buff___22 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___23 *, struct net_device___23 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___23 *, struct net_device___23 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___23 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___23 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___23 *, struct neighbour___10 *);
	void (*ndo_neigh_destroy)(struct net_device___23 *, struct neighbour___10 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___23 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___23 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___23 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___22 *, struct netlink_callback___18 *, struct net_device___23 *, struct net_device___23 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___23 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___23 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___22 *, u32, u32, struct net_device___23 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___23 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___23 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___23 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___23 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___23 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___23 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___23 *, struct net_device___23 *);
	void (*ndo_dfwd_del_station)(struct net_device___23 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___23 *);
	int (*ndo_set_tx_maxrate)(struct net_device___23 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___23 *);
	int (*ndo_change_proto_down)(struct net_device___23 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___23 *, struct sk_buff___22 *);
	void (*ndo_set_rx_headroom)(struct net_device___23 *, int);
	int (*ndo_bpf)(struct net_device___23 *, struct netdev_bpf___18 *);
	int (*ndo_xdp_xmit)(struct net_device___23 *, int, struct xdp_frame___18 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___23 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___23 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___10 {
	possible_net_t___19 net;
	struct net_device___23 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___10 *);
	void (*neigh_cleanup)(struct neighbour___10 *);
	struct neigh_table___9 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___9 {
	u32 (*l3mdev_fib_table)(const struct net_device___23 *);
	struct sk_buff___22 * (*l3mdev_l3_rcv)(struct net_device___23 *, struct sk_buff___22 *, u16);
	struct sk_buff___22 * (*l3mdev_l3_out)(struct net_device___23 *, struct sock___11 *, struct sk_buff___22 *, u16);
	struct dst_entry___10 * (*l3mdev_link_scope_lookup)(const struct net_device___23 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct tcf_proto___17;

struct mini_Qdisc___17 {
	struct tcf_proto___17 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___17 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___23 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___28 *, struct net_device___23 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___23 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___23 *, struct list_head *);
	size_t (*get_size)(const struct net_device___23 *);
	int (*fill_info)(struct sk_buff___22 *, const struct net_device___23 *);
	size_t (*get_xstats_size)(const struct net_device___23 *);
	int (*fill_xstats)(struct sk_buff___22 *, const struct net_device___23 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___23 *, struct net_device___23 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___23 *, const struct net_device___23 *);
	int (*fill_slave_info)(struct sk_buff___22 *, const struct net_device___23 *, const struct net_device___23 *);
	struct net___28 * (*get_link_net)(const struct net_device___23 *);
	size_t (*get_linkxstats_size)(const struct net_device___23 *, int);
	int (*fill_linkxstats)(struct sk_buff___22 *, const struct net_device___23 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___18 {
	struct list_head poll_list;
	struct sk_buff_head___19 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___18 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___17 *output_queue;
	struct Qdisc___17 **output_queue_tailp;
	struct sk_buff___22 *completion_queue;
	struct sk_buff_head___19 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___18 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___19 input_pkt_queue;
	struct napi_struct___18 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bdi_writeback_congested___44 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___44 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___44 {
	struct bio___44 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___44 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___44 bip_inline_vecs[0];
};

struct bio_set___44 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___44 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___39 {
	struct mem_cgroup___39 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___39 {
	struct lruvec___120 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___39 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___39 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct kernel_param_ops___101 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___101 *);
	int (*get)(char *, const struct kernel_param___101 *);
	void (*free)(void *);
};

struct kparam_array___101;

struct kernel_param___101 {
	const char *name;
	struct module___104 *mod;
	const struct kernel_param_ops___101 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___101 *arr;
	};
};

struct kparam_array___101 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___101 *ops;
	void *elem;
};

struct module_attribute___101 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___101 *, struct module_kobject___101 *, char *);
	ssize_t (*store)(struct module_attribute___101 *, struct module_kobject___101 *, const char *, size_t);
	void (*setup)(struct module___104 *, const char *);
	int (*test)(struct module___104 *);
	void (*free)(struct module___104 *);
};

struct gnet_dump___17 {
	spinlock_t *lock;
	struct sk_buff___22 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___17;

struct Qdisc_ops___17 {
	struct Qdisc_ops___17 *next;
	const struct Qdisc_class_ops___17 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___22 *, struct Qdisc___17 *, struct sk_buff___22 **);
	struct sk_buff___22 * (*dequeue)(struct Qdisc___17 *);
	struct sk_buff___22 * (*peek)(struct Qdisc___17 *);
	int (*init)(struct Qdisc___17 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___17 *);
	void (*destroy)(struct Qdisc___17 *);
	int (*change)(struct Qdisc___17 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___17 *);
	int (*change_tx_queue_len)(struct Qdisc___17 *, unsigned int);
	int (*dump)(struct Qdisc___17 *, struct sk_buff___22 *);
	int (*dump_stats)(struct Qdisc___17 *, struct gnet_dump___17 *);
	void (*ingress_block_set)(struct Qdisc___17 *, u32);
	void (*egress_block_set)(struct Qdisc___17 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___17 *);
	u32 (*egress_block_get)(struct Qdisc___17 *);
	struct module___104 *owner;
};

struct tcf_block___17;

struct Qdisc_class_ops___17 {
	unsigned int flags;
	struct netdev_queue___18 * (*select_queue)(struct Qdisc___17 *, struct tcmsg *);
	int (*graft)(struct Qdisc___17 *, long unsigned int, struct Qdisc___17 *, struct Qdisc___17 **, struct netlink_ext_ack *);
	struct Qdisc___17 * (*leaf)(struct Qdisc___17 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___17 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___17 *, u32);
	int (*change)(struct Qdisc___17 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___17 *, long unsigned int);
	void (*walk)(struct Qdisc___17 *, struct qdisc_walker *);
	struct tcf_block___17 * (*tcf_block)(struct Qdisc___17 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___17 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___17 *, long unsigned int);
	int (*dump)(struct Qdisc___17 *, long unsigned int, struct sk_buff___22 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___17 *, long unsigned int, struct gnet_dump___17 *);
};

struct tcf_chain___17;

struct tcf_block___17 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___28 *net;
	struct Qdisc___17 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___17 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___17;

struct tcf_proto_ops___17;

struct tcf_proto___17 {
	struct tcf_proto___17 *next;
	void *root;
	int (*classify)(struct sk_buff___22 *, const struct tcf_proto___17 *, struct tcf_result___17 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___17 *ops;
	struct tcf_chain___17 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___17 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___17 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___17 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___22 *, const struct tcf_proto___17 *, struct tcf_result___17 *);
	int (*init)(struct tcf_proto___17 *);
	void (*destroy)(struct tcf_proto___17 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___17 *, u32);
	void (*put)(struct tcf_proto___17 *, void *);
	int (*change)(struct net___28 *, struct sk_buff___22 *, struct tcf_proto___17 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___17 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___17 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___17 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___28 *, struct tcf_chain___17 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___28 *, struct tcf_proto___17 *, void *, struct sk_buff___22 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___22 *, struct net___28 *, void *);
	struct module___104 *owner;
	int flags;
};

struct tcf_chain___17 {
	struct mutex filter_chain_lock;
	struct tcf_proto___17 *filter_chain;
	struct list_head list;
	struct tcf_block___17 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___17 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct qdisc_skb_cb {
	union {
		struct {
			unsigned int pkt_len;
			u16 slave_dev_queue_mapping;
			u16 tc_classid;
		};
		struct bpf_flow_keys *flow_keys;
	};
	unsigned char data[20];
};

struct sk_filter___8 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___17 *prog;
};

struct bpf_skb_data_end {
	struct qdisc_skb_cb qdisc_cb;
	void *data_meta;
	void *data_end;
};

struct bpf_redirect_info___17 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___97 *map;
	struct bpf_map___97 *map_to_flush;
	u32 kern_flags;
};

struct bpf_sock_addr_kern {
	struct sock___11 *sk;
	struct sockaddr *uaddr;
	u64 tmp_reg;
	void *t_ctx;
};

struct bpf_sock_ops_kern {
	struct sock___11 *sk;
	u32 op;
	union {
		u32 args[4];
		u32 reply;
		u32 replylong[4];
	};
	u32 is_fullsock;
	u64 temp;
};

struct pneigh_entry___8;

struct neigh_hash_table___8;

struct neigh_table___9 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___23 *, __u32 *);
	bool (*key_eq)(const struct neighbour___10 *, const void *);
	int (*constructor)(struct neighbour___10 *);
	int (*pconstructor)(struct pneigh_entry___8 *);
	void (*pdestructor)(struct pneigh_entry___8 *);
	void (*proxy_redo)(struct sk_buff___22 *);
	char *id;
	struct neigh_parms___10 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___19 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___8 *nht;
	struct pneigh_entry___8 **phash_buckets;
};

struct neigh_ops___9 {
	int family;
	void (*solicit)(struct neighbour___10 *, struct sk_buff___22 *);
	void (*error_report)(struct neighbour___10 *, struct sk_buff___22 *);
	int (*output)(struct neighbour___10 *, struct sk_buff___22 *);
	int (*connected_output)(struct neighbour___10 *, struct sk_buff___22 *);
};

struct pneigh_entry___8 {
	struct pneigh_entry___8 *next;
	possible_net_t___19 net;
	struct net_device___23 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___8 {
	struct neighbour___10 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

enum {
	TCPF_ESTABLISHED = 2,
	TCPF_SYN_SENT = 4,
	TCPF_SYN_RECV = 8,
	TCPF_FIN_WAIT1 = 16,
	TCPF_FIN_WAIT2 = 32,
	TCPF_TIME_WAIT = 64,
	TCPF_CLOSE = 128,
	TCPF_CLOSE_WAIT = 256,
	TCPF_LAST_ACK = 512,
	TCPF_LISTEN = 1024,
	TCPF_CLOSING = 2048,
	TCPF_NEW_SYN_RECV = 4096,
};

struct fib_rule___8 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___8 *ctarget;
	struct net___28 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___8 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___8 *rule;
	u32 table;
	int flags;
};

struct proto___8 {
	void (*close)(struct sock___11 *, long int);
	int (*pre_connect)(struct sock___11 *, struct sockaddr *, int);
	int (*connect)(struct sock___11 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___11 *, int);
	struct sock___11 * (*accept)(struct sock___11 *, int, int *, bool);
	int (*ioctl)(struct sock___11 *, int, long unsigned int);
	int (*init)(struct sock___11 *);
	void (*destroy)(struct sock___11 *);
	void (*shutdown)(struct sock___11 *, int);
	int (*setsockopt)(struct sock___11 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___11 *, int, int, char *, int *);
	void (*keepalive)(struct sock___11 *, int);
	int (*sendmsg)(struct sock___11 *, struct msghdr___8 *, size_t);
	int (*recvmsg)(struct sock___11 *, struct msghdr___8 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___11 *, struct page___121 *, int, size_t, int);
	int (*bind)(struct sock___11 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___11 *, struct sk_buff___22 *);
	void (*release_cb)(struct sock___11 *);
	int (*hash)(struct sock___11 *);
	void (*unhash)(struct sock___11 *);
	void (*rehash)(struct sock___11 *);
	int (*get_port)(struct sock___11 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___11 *);
	bool (*stream_memory_read)(const struct sock___11 *);
	void (*enter_memory_pressure)(struct sock___11 *);
	void (*leave_memory_pressure)(struct sock___11 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___3 *rsk_prot;
	struct timewait_sock_ops___3 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___104 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___11 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct module___105;

struct file___122;

struct kiocb___122;

struct iov_iter___51;

struct poll_table_struct___82;

struct vm_area_struct___122;

struct inode___123;

struct file_lock___122;

struct page___122;

struct pipe_inode_info___32;

struct seq_file___112;

struct file_operations___122 {
	struct module___105 *owner;
	loff_t (*llseek)(struct file___122 *, loff_t, int);
	ssize_t (*read)(struct file___122 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___122 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___122 *, struct iov_iter___51 *);
	ssize_t (*write_iter)(struct kiocb___122 *, struct iov_iter___51 *);
	int (*iopoll)(struct kiocb___122 *, bool);
	int (*iterate)(struct file___122 *, struct dir_context *);
	int (*iterate_shared)(struct file___122 *, struct dir_context *);
	__poll_t (*poll)(struct file___122 *, struct poll_table_struct___82 *);
	long int (*unlocked_ioctl)(struct file___122 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___122 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___122 *, struct vm_area_struct___122 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___123 *, struct file___122 *);
	int (*flush)(struct file___122 *, fl_owner_t);
	int (*release)(struct inode___123 *, struct file___122 *);
	int (*fsync)(struct file___122 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___122 *, int);
	int (*lock)(struct file___122 *, int, struct file_lock___122 *);
	ssize_t (*sendpage)(struct file___122 *, struct page___122 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___122 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___122 *, int, struct file_lock___122 *);
	ssize_t (*splice_write)(struct pipe_inode_info___32 *, struct file___122 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___122 *, loff_t *, struct pipe_inode_info___32 *, size_t, unsigned int);
	int (*setlease)(struct file___122 *, long int, struct file_lock___122 **, void **);
	long int (*fallocate)(struct file___122 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___112 *, struct file___122 *);
	ssize_t (*copy_file_range)(struct file___122 *, loff_t, struct file___122 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___122 *, loff_t, struct file___122 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___122 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___121 {
	u64 seqnum;
	struct vm_area_struct___122 *vmas[4];
};

struct page_frag___121 {
	struct page___122 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___121;

struct mem_cgroup___40;

struct cred___117;

struct nsproxy___114;

struct signal_struct___111;

struct bio_list___45;

struct backing_dev_info___45;

struct css_set___98;

struct vm_struct___91;

struct task_struct___122 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___122 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___121 *mm;
	struct mm_struct___121 *active_mm;
	struct vmacache___121 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___122 *real_parent;
	struct task_struct___122 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___122 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___40 *active_memcg;
	long int rh_reserved2;
	struct pid___98 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___98 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___98 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___117 *ptracer_cred;
	const struct cred___117 *real_cred;
	const struct cred___117 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___114 *nsproxy;
	struct signal_struct___111 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___122 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___45 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___45 *backing_dev_info;
	struct io_context___17 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___98 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___32 *splice_pipe;
	struct page_frag___121 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___40 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___122 *oom_reaper_list;
	struct vm_struct___91 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___74 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct secondary_data___122 {
	void *stack;
	struct task_struct___122 *task;
	long int status;
};

struct dentry___122;

struct path___121 {
	struct vfsmount *mnt;
	struct dentry___122 *dentry;
};

struct address_space___121;

struct file___122 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___121 f_path;
	struct inode___123 *f_inode;
	const struct file_operations___122 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___98 f_owner;
	const struct cred___117 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___121 *f_mapping;
	errseq_t f_wb_err;
};

struct bpf_map___98;

struct bpf_map_ops___98 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___98 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___98 *, struct file___122 *);
	void (*map_free)(struct bpf_map___98 *);
	int (*map_get_next_key)(struct bpf_map___98 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___98 *);
	void * (*map_lookup_elem)(struct bpf_map___98 *, void *);
	int (*map_update_elem)(struct bpf_map___98 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___98 *, void *);
	int (*map_push_elem)(struct bpf_map___98 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___98 *, void *);
	int (*map_peek_elem)(struct bpf_map___98 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___98 *, struct file___122 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___98 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___98 *, void *, struct seq_file___112 *);
	int (*map_check_btf)(const struct bpf_map___98 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct user_struct___117;

struct bpf_map___98 {
	const struct bpf_map_ops___98 *ops;
	struct bpf_map___98 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___117 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct seq_operations___110;

struct seq_file___112 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___110 *op;
	int poll_event;
	const struct file___122 *file;
	void *private;
};

struct key___117;

struct user_struct___117 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___117 *uid_keyring;
	struct key___117 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bpf_offloaded_map___19;

struct bpf_map_dev_ops___19 {
	int (*map_get_next_key)(struct bpf_offloaded_map___19 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___19 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___19 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___19 *, void *);
};

struct bpf_offloaded_map___19 {
	struct bpf_map___98 map;
	struct net_device___4 *netdev;
	const struct bpf_map_dev_ops___19 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

typedef rx_handler_result_t rx_handler_func_t___19(struct sk_buff___3 **);

typedef struct {
	struct net___4 *net;
} possible_net_t___20;

struct kset___115;

struct kobj_type___115;

struct kernfs_node___118;

struct kobject___116 {
	const char *name;
	struct list_head entry;
	struct kobject___116 *parent;
	struct kset___115 *kset;
	struct kobj_type___115 *ktype;
	struct kernfs_node___118 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___113;

struct dev_pm_info___113 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___113 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___113;

struct bus_type___113;

struct device_driver___113;

struct dev_pm_domain___113;

struct dma_map_ops___35;

struct fwnode_handle___85;

struct class___113;

struct attribute_group___112;

struct device___113 {
	struct device___113 *parent;
	struct device_private *p;
	struct kobject___116 kobj;
	const char *init_name;
	const struct device_type___113 *type;
	struct mutex mutex;
	struct bus_type___113 *bus;
	struct device_driver___113 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___113 power;
	struct dev_pm_domain___113 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___35 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___85 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___113 *class;
	const struct attribute_group___112 **groups;
	void (*release)(struct device___113 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct net_device_ops___19;

struct ethtool_ops___19;

struct l3mdev_ops___10;

struct xfrmdev_ops___19;

struct tlsdev_ops___19;

struct header_ops___19;

struct netdev_rx_queue___19;

struct bpf_prog___18;

struct mini_Qdisc___18;

struct netdev_queue___19;

struct Qdisc___18;

struct rtnl_link_ops___18;

struct dcbnl_rtnl_ops___19;

struct net_device___4 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___19 *netdev_ops;
	const struct ethtool_ops___19 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___10 *l3mdev_ops;
	const struct ndisc_ops___2 *ndisc_ops;
	const struct xfrmdev_ops___19 *xfrmdev_ops;
	const struct tlsdev_ops___19 *tlsdev_ops;
	const struct header_ops___19 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___115 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___2 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___19 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___18 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___19 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___18 *miniq_ingress;
	struct netdev_queue___19 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___19 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___18 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___18 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___19 = 0,
		NETREG_REGISTERED___19 = 1,
		NETREG_UNREGISTERING___19 = 2,
		NETREG_UNREGISTERED___19 = 3,
		NETREG_RELEASED___19 = 4,
		NETREG_DUMMY___19 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___19 = 0,
		RTNL_LINK_INITIALIZING___19 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___4 *);
	struct netpoll_info *npinfo;
	possible_net_t___20 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___113 dev;
	const struct attribute_group___112 *sysfs_groups[4];
	const struct attribute_group___112 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___18 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___19 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct bpf_prog_ops___18 {
	int (*test_run)(struct bpf_prog___18 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_aux___18;

struct bpf_prog___18 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___18 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

struct bpf_verifier_ops___18 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___18 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___18 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___18 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___18 *, u32 *);
};

struct bpf_prog_offload_ops___18 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___18 *);
	int (*translate)(struct bpf_prog___18 *);
	void (*destroy)(struct bpf_prog___18 *);
};

struct bpf_prog_offload___18 {
	struct bpf_prog___18 *prog;
	struct net_device___4 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___18 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___18 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___18 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___18 *ops;
	struct bpf_map___98 **used_maps;
	struct bpf_prog___18 *prog;
	struct user_struct___117 *user;
	u64 load_time;
	struct bpf_map___98 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___18 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___18 {
	struct bpf_prog___18 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___18 {
	struct callback_head rcu;
	struct bpf_prog_array_item___18 items[0];
};

typedef struct page___122 *pgtable_t___121;

struct dev_pagemap___119;

struct page___122 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___121 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___122 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___121 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___121 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___119 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___40 *mem_cgroup;
};

struct pglist_data___121;

struct lruvec___121 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___121 *pgdat;
};

struct zone___121 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___121 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___121 {
	struct zone___121 *zone;
	int zone_idx;
};

struct zonelist___121 {
	struct zoneref___121 _zonerefs[25];
};

struct pglist_data___121 {
	struct zone___121 node_zones[3];
	struct zonelist___121 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___122 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___122 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___121 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___122 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___122 *owner;
};

struct blocking_notifier_head___121 {
	struct rw_semaphore___122 rwsem;
	struct notifier_block *head;
};

struct cgroup___98;

struct cgroup_subsys___98;

struct cgroup_subsys_state___98 {
	struct cgroup___98 *cgroup;
	struct cgroup_subsys___98 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___98 *parent;
};

struct cgroup_file___98 {
	struct kernfs_node___118 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___40;

struct mem_cgroup___40 {
	struct cgroup_subsys_state___98 css;
	struct mem_cgroup_id___16 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___98 events_file;
	struct cgroup_file___98 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___122 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___40 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ucounts___102;

struct user_namespace___102 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___102 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___8 ns;
	long unsigned int flags;
	struct key___117 *persistent_keyring_register;
	struct rw_semaphore___122 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___102 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_operations_struct___119;

struct vm_area_struct___122 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___122 *vm_next;
	struct vm_area_struct___122 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___121 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___119 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___122 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___121;

struct mm_struct___121 {
	struct {
		struct vm_area_struct___122 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___122 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___122 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___121 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___122 *owner;
		struct user_namespace___102 *user_ns;
		struct file___122 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___121 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___117 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___117 *session_keyring;
	struct key___117 *process_keyring;
	struct key___117 *thread_keyring;
	struct key___117 *request_key_auth;
	void *security;
	struct user_struct___117 *user;
	struct user_namespace___102 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___98;

struct nsproxy___114 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net___4 *net_ns;
	struct cgroup_namespace___98 *cgroup_ns;
};

struct signal_struct___111 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___122 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___122 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___98 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___98 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___121 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___98 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___45;

struct bio_list___45 {
	struct bio___45 *head;
	struct bio___45 *tail;
};

struct bdi_writeback_congested___45;

struct bdi_writeback___45 {
	struct backing_dev_info___45 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___45 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___98 *memcg_css;
	struct cgroup_subsys_state___98 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___45 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___45 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___113 *dev;
	struct device___113 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___122 *debug_dir;
	struct dentry___122 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___98 {
	struct cgroup_subsys_state___98 *subsys[13];
	refcount_t refcount;
	struct css_set___98 *dom_cset;
	struct cgroup___98 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___98 *mg_src_cgrp;
	struct cgroup___98 *mg_dst_cgrp;
	struct css_set___98 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___121;

struct pipe_buffer___32;

struct pipe_inode_info___32 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___122 *tmp_page;
	struct fasync_struct___121 *fasync_readers;
	struct fasync_struct___121 *fasync_writers;
	struct pipe_buffer___32 *bufs;
	struct user_struct___117 *user;
};

struct vm_struct___91 {
	struct vm_struct___91 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___122 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___111 {
	struct task_struct___122 task;
	long unsigned int stack[8192];
};

struct address_space_operations___121;

struct address_space___121 {
	struct inode___123 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___122 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___121 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___119)(struct vm_area_struct___122 *, long unsigned int, const struct page___122 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___119)(struct page___122 *, void *);

struct dev_pagemap___119 {
	dev_page_fault_t___119 page_fault;
	dev_page_free_t___119 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___113 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct vm_fault___119;

struct vm_operations_struct___119 {
	void (*open)(struct vm_area_struct___122 *);
	void (*close)(struct vm_area_struct___122 *);
	int (*split)(struct vm_area_struct___122 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___122 *);
	vm_fault_t (*fault)(struct vm_fault___119 *);
	vm_fault_t (*huge_fault)(struct vm_fault___119 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___119 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___122 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___119 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___119 *);
	int (*access)(struct vm_area_struct___122 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___122 *);
	int (*set_policy)(struct vm_area_struct___122 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___122 *, long unsigned int);
	struct page___122 * (*find_special_page)(struct vm_area_struct___122 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___121 {
	struct task_struct___122 *task;
	struct core_thread___121 *next;
};

struct core_state___121 {
	atomic_t nr_threads;
	struct core_thread___121 dumper;
	struct completion startup;
};

struct vm_fault___119 {
	struct vm_area_struct___122 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___122 *cow_page;
	struct mem_cgroup___40 *memcg;
	struct page___122 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___121 prealloc_pte;
};

struct module_kobject___102 {
	struct kobject___116 kobj;
	struct module___105 *mod;
	struct kobject___116 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___102 {
	struct module___105 *mod;
	struct latch_tree_node node;
};

struct module_layout___102 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___102 mtn;
};

struct module_attribute___102;

struct kernel_param___102;

struct module___105 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___102 mkobj;
	struct module_attribute___102 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___116 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___102 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___102 core_layout;
	struct module_layout___102 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide53;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide54;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bio_vec___45 {
	struct page___122 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___51 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___45 *bvec;
		struct pipe_inode_info___32 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct msghdr___9 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___51 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___122 *msg_iocb;
};

struct kiocb___122 {
	struct file___122 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___122 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dentry_operations___121;

struct super_block___122;

struct dentry___122 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___122 *d_parent;
	struct qstr d_name;
	struct inode___123 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___121 *d_op;
	struct super_block___122 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___121;

struct block_device___122;

struct inode___123 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___121 *i_op;
	struct super_block___122 *i_sb;
	struct address_space___121 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___122 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___45 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___122 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___121 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___32 *i_pipe;
		struct block_device___122 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___121 {
	int (*d_revalidate)(struct dentry___122 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___122 *, unsigned int);
	int (*d_hash)(const struct dentry___122 *, struct qstr *);
	int (*d_compare)(const struct dentry___122 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___122 *);
	int (*d_init)(struct dentry___122 *);
	void (*d_release)(struct dentry___122 *);
	void (*d_prune)(struct dentry___122 *);
	void (*d_iput)(struct dentry___122 *, struct inode___123 *);
	char * (*d_dname)(struct dentry___122 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___121 *);
	int (*d_manage)(const struct path___121 *, bool);
	struct dentry___122 * (*d_real)(struct dentry___122 *, const struct inode___123 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___121;

struct mem_dqinfo___121 {
	struct quota_format_type___121 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___121;

struct quota_info___121 {
	unsigned int flags;
	struct rw_semaphore___122 dqio_sem;
	struct inode___123 *files[3];
	struct mem_dqinfo___121 info[3];
	const struct quota_format_ops___121 *ops[3];
};

struct rcuwait___121 {
	struct task_struct___122 *task;
};

struct percpu_rw_semaphore___121 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___122 rw_sem;
	struct rcuwait___121 writer;
	int readers_block;
};

struct sb_writers___121 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___121 rw_sem[3];
};

struct shrink_control___40;

struct shrinker___40 {
	long unsigned int (*count_objects)(struct shrinker___40 *, struct shrink_control___40 *);
	long unsigned int (*scan_objects)(struct shrinker___40 *, struct shrink_control___40 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___121;

struct super_operations___121;

struct dquot_operations___121;

struct quotactl_ops___121;

struct super_block___122 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___121 *s_type;
	const struct super_operations___121 *s_op;
	const struct dquot_operations___121 *dq_op;
	const struct quotactl_ops___121 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___122 *s_root;
	struct rw_semaphore___122 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___122 *s_bdev;
	struct backing_dev_info___45 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___121 s_dquot;
	struct sb_writers___121 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___121 *s_d_op;
	int cleancache_poolid;
	struct shrinker___40 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___102 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___40 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___40 *memcg;
};

struct iattr___122 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___122 *ia_file;
};

struct dquot___121 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___122 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___121 {
	int qf_fmt_id;
	const struct quota_format_ops___121 *qf_ops;
	struct module___105 *qf_owner;
	struct quota_format_type___121 *qf_next;
};

struct quota_format_ops___121 {
	int (*check_quota_file)(struct super_block___122 *, int);
	int (*read_file_info)(struct super_block___122 *, int);
	int (*write_file_info)(struct super_block___122 *, int);
	int (*free_file_info)(struct super_block___122 *, int);
	int (*read_dqblk)(struct dquot___121 *);
	int (*commit_dqblk)(struct dquot___121 *);
	int (*release_dqblk)(struct dquot___121 *);
	int (*get_next_id)(struct super_block___122 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___121 {
	int (*write_dquot)(struct dquot___121 *);
	struct dquot___121 * (*alloc_dquot)(struct super_block___122 *, int);
	void (*destroy_dquot)(struct dquot___121 *);
	int (*acquire_dquot)(struct dquot___121 *);
	int (*release_dquot)(struct dquot___121 *);
	int (*mark_dirty)(struct dquot___121 *);
	int (*write_info)(struct super_block___122 *, int);
	qsize_t * (*get_reserved_space)(struct inode___123 *);
	int (*get_projid)(struct inode___123 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___123 *, qsize_t *);
	int (*get_next_id)(struct super_block___122 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___121 {
	int (*quota_on)(struct super_block___122 *, int, int, const struct path___121 *);
	int (*quota_off)(struct super_block___122 *, int);
	int (*quota_enable)(struct super_block___122 *, unsigned int);
	int (*quota_disable)(struct super_block___122 *, unsigned int);
	int (*quota_sync)(struct super_block___122 *, int);
	int (*set_info)(struct super_block___122 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___122 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___122 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___122 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___122 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___122 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___42;

struct address_space_operations___121 {
	int (*writepage)(struct page___122 *, struct writeback_control___42 *);
	int (*readpage)(struct file___122 *, struct page___122 *);
	int (*writepages)(struct address_space___121 *, struct writeback_control___42 *);
	int (*set_page_dirty)(struct page___122 *);
	int (*readpages)(struct file___122 *, struct address_space___121 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___122 *, struct address_space___121 *, loff_t, unsigned int, unsigned int, struct page___122 **, void **);
	int (*write_end)(struct file___122 *, struct address_space___121 *, loff_t, unsigned int, unsigned int, struct page___122 *, void *);
	sector_t (*bmap)(struct address_space___121 *, sector_t);
	void (*invalidatepage)(struct page___122 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___122 *, gfp_t);
	void (*freepage)(struct page___122 *);
	ssize_t (*direct_IO)(struct kiocb___122 *, struct iov_iter___51 *);
	int (*migratepage)(struct address_space___121 *, struct page___122 *, struct page___122 *, enum migrate_mode);
	bool (*isolate_page)(struct page___122 *, isolate_mode_t);
	void (*putback_page)(struct page___122 *);
	int (*launder_page)(struct page___122 *);
	int (*is_partially_uptodate)(struct page___122 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___122 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___121 *, struct page___122 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___122 *, sector_t *);
	void (*swap_deactivate)(struct file___122 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___42 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___45 *wb;
	struct inode___123 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___122 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___123 *bd_inode;
	struct super_block___122 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___122 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___45 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___121 {
	struct dentry___122 * (*lookup)(struct inode___123 *, struct dentry___122 *, unsigned int);
	const char * (*get_link)(struct dentry___122 *, struct inode___123 *, struct delayed_call *);
	int (*permission)(struct inode___123 *, int);
	struct posix_acl * (*get_acl)(struct inode___123 *, int);
	int (*readlink)(struct dentry___122 *, char *, int);
	int (*create)(struct inode___123 *, struct dentry___122 *, umode_t, bool);
	int (*link)(struct dentry___122 *, struct inode___123 *, struct dentry___122 *);
	int (*unlink)(struct inode___123 *, struct dentry___122 *);
	int (*symlink)(struct inode___123 *, struct dentry___122 *, const char *);
	int (*mkdir)(struct inode___123 *, struct dentry___122 *, umode_t);
	int (*rmdir)(struct inode___123 *, struct dentry___122 *);
	int (*mknod)(struct inode___123 *, struct dentry___122 *, umode_t, dev_t);
	int (*rename)(struct inode___123 *, struct dentry___122 *, struct inode___123 *, struct dentry___122 *, unsigned int);
	int (*setattr)(struct dentry___122 *, struct iattr___122 *);
	int (*getattr)(const struct path___121 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___122 *, char *, size_t);
	int (*fiemap)(struct inode___123 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___123 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___123 *, struct dentry___122 *, struct file___122 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___123 *, struct dentry___122 *, umode_t);
	int (*set_acl)(struct inode___123 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___121 {
	void (*fl_copy_lock)(struct file_lock___122 *, struct file_lock___122 *);
	void (*fl_release_private)(struct file_lock___122 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___121;

struct file_lock___122 {
	struct file_lock___122 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___122 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___121 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___121 *fl_ops;
	const struct lock_manager_operations___121 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___121 {
	int (*lm_compare_owner)(struct file_lock___122 *, struct file_lock___122 *);
	long unsigned int (*lm_owner_key)(struct file_lock___122 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___122 *);
	int (*lm_grant)(struct file_lock___122 *, int);
	bool (*lm_break)(struct file_lock___122 *);
	int (*lm_change)(struct file_lock___122 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___122 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___121 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___121 *fa_next;
	struct file___122 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___121 {
	const char *name;
	int fs_flags;
	struct dentry___122 * (*mount)(struct file_system_type___121 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___122 *);
	struct module___105 *owner;
	struct file_system_type___121 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___121 {
	struct inode___123 * (*alloc_inode)(struct super_block___122 *);
	void (*destroy_inode)(struct inode___123 *);
	void (*dirty_inode)(struct inode___123 *, int);
	int (*write_inode)(struct inode___123 *, struct writeback_control___42 *);
	int (*drop_inode)(struct inode___123 *);
	void (*evict_inode)(struct inode___123 *);
	void (*put_super)(struct super_block___122 *);
	int (*sync_fs)(struct super_block___122 *, int);
	int (*freeze_super)(struct super_block___122 *);
	int (*freeze_fs)(struct super_block___122 *);
	int (*thaw_super)(struct super_block___122 *);
	int (*unfreeze_fs)(struct super_block___122 *);
	int (*statfs)(struct dentry___122 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___122 *, int *, char *);
	void (*umount_begin)(struct super_block___122 *);
	int (*show_options)(struct seq_file___112 *, struct dentry___122 *);
	int (*show_devname)(struct seq_file___112 *, struct dentry___122 *);
	int (*show_path)(struct seq_file___112 *, struct dentry___122 *);
	int (*show_stats)(struct seq_file___112 *, struct dentry___122 *);
	ssize_t (*quota_read)(struct super_block___122 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___122 *, int, const char *, size_t, loff_t);
	struct dquot___121 ** (*get_dquots)(struct inode___123 *);
	int (*bdev_try_to_free_page)(struct super_block___122 *, struct page___122 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___122 *, struct shrink_control___40 *);
	long int (*free_cached_objects)(struct super_block___122 *, struct shrink_control___40 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___81)(struct file___122 *, wait_queue_head_t *, struct poll_table_struct___82 *);

struct poll_table_struct___82 {
	poll_queue_proc___81 _qproc;
	__poll_t _key;
};

typedef void bio_end_io_t___45(struct bio___45 *);

struct bio_integrity_payload___45;

struct bio_set___45;

struct bio___45 {
	struct bio___45 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___45 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___45 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___45 *bi_io_vec;
	struct bio_set___45 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___45 bi_inline_vecs[0];
};

enum sock_type {
	SOCK_STREAM = 1,
	SOCK_DGRAM = 2,
	SOCK_RAW = 3,
	SOCK_RDM = 4,
	SOCK_SEQPACKET = 5,
	SOCK_DCCP = 6,
	SOCK_PACKET = 10,
};

struct socket_wq___9 {
	wait_queue_head_t wait;
	struct fasync_struct___121 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___9;

struct socket___9 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___9 *wq;
	struct file___122 *file;
	struct sock___3 *sk;
	const struct proto_ops___9 *ops;
};

struct proto___9;

struct sock_common___9 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___9 *skc_prot;
	possible_net_t___20 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___3 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_filter___9;

struct sock_reuseport___2;

struct sock___3 {
	struct sock_common___9 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___3 sk_error_queue;
	struct sk_buff_head___3 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___3 *head;
		struct sk_buff___3 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___9 *sk_filter;
	union {
		struct socket_wq___9 *sk_wq;
		struct socket_wq___9 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___2 *sk_rx_dst;
	struct dst_entry___2 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___3 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___3 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___121 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___9 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___98 *sk_peer_pid;
	const struct cred___117 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___9 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___40 *sk_memcg;
	void (*sk_state_change)(struct sock___3 *);
	void (*sk_data_ready)(struct sock___3 *);
	void (*sk_write_space)(struct sock___3 *);
	void (*sk_error_report)(struct sock___3 *);
	int (*sk_backlog_rcv)(struct sock___3 *, struct sk_buff___3 *);
	struct sk_buff___3 * (*sk_validate_xmit_skb)(struct sock___3 *, struct net_device___4 *, struct sk_buff___3 *);
	void (*sk_destruct)(struct sock___3 *);
	struct sock_reuseport___2 *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

typedef int (*sk_read_actor_t___9)(read_descriptor_t *, struct sk_buff___3 *, unsigned int, size_t);

struct proto_ops___9 {
	int family;
	struct module___105 *owner;
	int (*release)(struct socket___9 *);
	int (*bind)(struct socket___9 *, struct sockaddr *, int);
	int (*connect)(struct socket___9 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___9 *, struct socket___9 *);
	int (*accept)(struct socket___9 *, struct socket___9 *, int, bool);
	int (*getname)(struct socket___9 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___122 *, struct socket___9 *, struct poll_table_struct___82 *);
	int (*ioctl)(struct socket___9 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___9 *, int);
	int (*shutdown)(struct socket___9 *, int);
	int (*setsockopt)(struct socket___9 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___9 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___9 *, struct msghdr___9 *, size_t);
	int (*recvmsg)(struct socket___9 *, struct msghdr___9 *, size_t, int);
	int (*mmap)(struct file___122 *, struct socket___9 *, struct vm_area_struct___122 *);
	ssize_t (*sendpage)(struct socket___9 *, struct page___122 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___9 *, loff_t *, struct pipe_inode_info___32 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___3 *, int);
	int (*peek_len)(struct socket___9 *);
	int (*read_sock)(struct sock___3 *, read_descriptor_t *, sk_read_actor_t___9);
	int (*sendpage_locked)(struct sock___3 *, struct page___122 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___3 *, struct msghdr___9 *, size_t);
	int (*set_rcvlowat)(struct sock___3 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct nf_bridge_info___19;

struct sk_buff___3 {
	union {
		struct {
			struct sk_buff___3 *next;
			struct sk_buff___3 *prev;
			union {
				struct net_device___4 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___3 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___3 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___19 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___19;

struct netns_frags___19 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___19 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_rules_ops___9;

struct fib_notifier_ops___9;

struct netns_ipv4___19 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___9 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___3 *fibnl;
	struct sock___3 **icmp_sk;
	struct sock___3 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___3 **tcp_sk;
	struct netns_frags___19 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___9 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___9 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___9 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct dst_ops___3 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___3 *);
	struct dst_entry___2 * (*check)(struct dst_entry___2 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___2 *);
	unsigned int (*mtu)(const struct dst_entry___2 *);
	u32 * (*cow_metrics)(struct dst_entry___2 *, long unsigned int);
	void (*destroy)(struct dst_entry___2 *);
	void (*ifdown)(struct dst_entry___2 *, struct net_device___4 *, int);
	struct dst_entry___2 * (*negative_advice)(struct dst_entry___2 *);
	void (*link_failure)(struct sk_buff___3 *);
	void (*update_pmtu)(struct dst_entry___2 *, struct sock___3 *, struct sk_buff___3 *, u32);
	void (*redirect)(struct dst_entry___2 *, struct sock___3 *, struct sk_buff___3 *);
	int (*local_out)(struct net___4 *, struct sock___3 *, struct sk_buff___3 *);
	struct neighbour___2 * (*neigh_lookup)(const struct dst_entry___2 *, struct sk_buff___3 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___2 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___26 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___19 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___3 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___9 *fib6_rules_ops;
	struct sock___3 **icmp_sk;
	struct sock___3 *ndisc_sk;
	struct sock___3 *tcp_sk;
	struct sock___3 *igmp_sk;
	struct sock___3 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___9 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___9 *notifier_ops;
	struct fib_notifier_ops___9 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___9 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___3 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___19 {
	struct netns_frags___19 frags;
};

struct netns_xfrm___26 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___3 *nlsk;
	struct sock___3 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___3 xfrm4_dst_ops;
	struct dst_ops___3 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct net___4 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___102 *user_ns;
	struct ucounts___102 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___8 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___3 *rtnl;
	struct sock___3 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___4 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___19 ipv4;
	struct netns_ipv6___26 ipv6;
	struct netns_sctp___9 sctp;
	struct netns_nf nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___19 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___3 *nfnl;
	struct sock___3 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___26 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___3 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___18 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kernfs_root___118;

struct kernfs_elem_dir___118 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___118 *root;
};

struct kernfs_syscall_ops___118;

struct kernfs_root___118 {
	struct kernfs_node___118 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___118 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___118 {
	struct kernfs_node___118 *target_kn;
};

struct kernfs_ops___118;

struct kernfs_elem_attr___118 {
	const struct kernfs_ops___118 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___118 *notify_next;
};

struct kernfs_node___118 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___118 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___118 dir;
		struct kernfs_elem_symlink___118 symlink;
		struct kernfs_elem_attr___118 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___118;

struct kernfs_ops___118 {
	int (*open)(struct kernfs_open_file___118 *);
	void (*release)(struct kernfs_open_file___118 *);
	int (*seq_show)(struct seq_file___112 *, void *);
	void * (*seq_start)(struct seq_file___112 *, loff_t *);
	void * (*seq_next)(struct seq_file___112 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___112 *, void *);
	ssize_t (*read)(struct kernfs_open_file___118 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___118 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___118 *, struct vm_area_struct___122 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___118 *, struct poll_table_struct___82 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___118 {
	int (*remount_fs)(struct kernfs_root___118 *, int *, char *);
	int (*show_options)(struct seq_file___112 *, struct kernfs_root___118 *);
	int (*mkdir)(struct kernfs_node___118 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___118 *);
	int (*rename)(struct kernfs_node___118 *, struct kernfs_node___118 *, const char *);
	int (*show_path)(struct seq_file___112 *, struct kernfs_node___118 *, struct kernfs_root___118 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___118 {
	struct kernfs_node___118 *kn;
	struct file___122 *file;
	struct seq_file___112 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___119 *vm_ops;
};

struct kobj_ns_type_operations___9 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___3 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___112;

struct attribute_group___112 {
	const char *name;
	umode_t (*is_visible)(struct kobject___116 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___116 *, struct bin_attribute___112 *, int);
	struct attribute **attrs;
	struct bin_attribute___112 **bin_attrs;
};

struct bin_attribute___112 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___122 *, struct kobject___116 *, struct bin_attribute___112 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___122 *, struct kobject___116 *, struct bin_attribute___112 *, char *, loff_t, size_t);
	int (*mmap)(struct file___122 *, struct kobject___116 *, struct bin_attribute___112 *, struct vm_area_struct___122 *);
};

struct sysfs_ops___115 {
	ssize_t (*show)(struct kobject___116 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___116 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___115;

struct kset___115 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___116 kobj;
	const struct kset_uevent_ops___115 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___115 {
	void (*release)(struct kobject___116 *);
	const struct sysfs_ops___115 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___9 * (*child_ns_type)(struct kobject___116 *);
	const void * (*namespace)(struct kobject___116 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___115 {
	int (* const filter)(struct kset___115 *, struct kobject___116 *);
	const char * (* const name)(struct kset___115 *, struct kobject___116 *);
	int (* const uevent)(struct kset___115 *, struct kobject___116 *, struct kobj_uevent_env *);
};

struct kobj_attribute___116 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___116 *, struct kobj_attribute___116 *, char *);
	ssize_t (*store)(struct kobject___116 *, struct kobj_attribute___116 *, const char *, size_t);
};

struct dev_pm_ops___113 {
	int (*prepare)(struct device___113 *);
	void (*complete)(struct device___113 *);
	int (*suspend)(struct device___113 *);
	int (*resume)(struct device___113 *);
	int (*freeze)(struct device___113 *);
	int (*thaw)(struct device___113 *);
	int (*poweroff)(struct device___113 *);
	int (*restore)(struct device___113 *);
	int (*suspend_late)(struct device___113 *);
	int (*resume_early)(struct device___113 *);
	int (*freeze_late)(struct device___113 *);
	int (*thaw_early)(struct device___113 *);
	int (*poweroff_late)(struct device___113 *);
	int (*restore_early)(struct device___113 *);
	int (*suspend_noirq)(struct device___113 *);
	int (*resume_noirq)(struct device___113 *);
	int (*freeze_noirq)(struct device___113 *);
	int (*thaw_noirq)(struct device___113 *);
	int (*poweroff_noirq)(struct device___113 *);
	int (*restore_noirq)(struct device___113 *);
	int (*runtime_suspend)(struct device___113 *);
	int (*runtime_resume)(struct device___113 *);
	int (*runtime_idle)(struct device___113 *);
};

struct dev_pm_domain___113 {
	struct dev_pm_ops___113 ops;
	void (*detach)(struct device___113 *, bool);
	int (*activate)(struct device___113 *);
	void (*sync)(struct device___113 *);
	void (*dismiss)(struct device___113 *);
};

struct bus_type___113 {
	const char *name;
	const char *dev_name;
	struct device___113 *dev_root;
	const struct attribute_group___112 **bus_groups;
	const struct attribute_group___112 **dev_groups;
	const struct attribute_group___112 **drv_groups;
	int (*match)(struct device___113 *, struct device_driver___113 *);
	int (*uevent)(struct device___113 *, struct kobj_uevent_env *);
	int (*probe)(struct device___113 *);
	int (*remove)(struct device___113 *);
	void (*shutdown)(struct device___113 *);
	int (*online)(struct device___113 *);
	int (*offline)(struct device___113 *);
	int (*suspend)(struct device___113 *, pm_message_t);
	int (*resume)(struct device___113 *);
	int (*num_vf)(struct device___113 *);
	int (*dma_configure)(struct device___113 *);
	const struct dev_pm_ops___113 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___113 {
	const char *name;
	struct bus_type___113 *bus;
	struct module___105 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___113 *);
	int (*remove)(struct device___113 *);
	void (*shutdown)(struct device___113 *);
	int (*suspend)(struct device___113 *, pm_message_t);
	int (*resume)(struct device___113 *);
	const struct attribute_group___112 **groups;
	const struct dev_pm_ops___113 *pm;
	void (*coredump)(struct device___113 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___113 {
	const char *name;
	const struct attribute_group___112 **groups;
	int (*uevent)(struct device___113 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___113 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___113 *);
	const struct dev_pm_ops___113 *pm;
};

struct class___113 {
	const char *name;
	struct module___105 *owner;
	const struct attribute_group___112 **class_groups;
	const struct attribute_group___112 **dev_groups;
	struct kobject___116 *dev_kobj;
	int (*dev_uevent)(struct device___113 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___113 *, umode_t *);
	void (*class_release)(struct class___113 *);
	void (*dev_release)(struct device___113 *);
	int (*shutdown_pre)(struct device___113 *);
	const struct kobj_ns_type_operations___9 *ns_type;
	const void * (*namespace)(struct device___113 *);
	const struct dev_pm_ops___113 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___35 {
	void * (*alloc)(struct device___113 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___113 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___113 *, struct vm_area_struct___122 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___113 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___113 *, struct page___122 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___113 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___113 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___113 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___113 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___113 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___113 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___113 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___113 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___113 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___113 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___113 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___113 *, u64);
	u64 (*get_required_mask)(struct device___113 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___85;

struct fwnode_handle___85 {
	struct fwnode_handle___85 *secondary;
	const struct fwnode_operations___85 *ops;
};

typedef void compound_page_dtor___119(struct page___122 *);

struct fwnode_reference_args___85;

struct fwnode_endpoint___85;

struct fwnode_operations___85 {
	struct fwnode_handle___85 * (*get)(struct fwnode_handle___85 *);
	void (*put)(struct fwnode_handle___85 *);
	bool (*device_is_available)(const struct fwnode_handle___85 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___85 *, const struct device___113 *);
	bool (*property_present)(const struct fwnode_handle___85 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___85 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___85 *, const char *, const char **, size_t);
	struct fwnode_handle___85 * (*get_parent)(const struct fwnode_handle___85 *);
	struct fwnode_handle___85 * (*get_next_child_node)(const struct fwnode_handle___85 *, struct fwnode_handle___85 *);
	struct fwnode_handle___85 * (*get_named_child_node)(const struct fwnode_handle___85 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___85 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___85 *);
	struct fwnode_handle___85 * (*graph_get_next_endpoint)(const struct fwnode_handle___85 *, struct fwnode_handle___85 *);
	struct fwnode_handle___85 * (*graph_get_remote_endpoint)(const struct fwnode_handle___85 *);
	struct fwnode_handle___85 * (*graph_get_port_parent)(struct fwnode_handle___85 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___85 *, struct fwnode_endpoint___85 *);
};

struct fwnode_endpoint___85 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___85 *local_fwnode;
};

struct fwnode_reference_args___85 {
	struct fwnode_handle___85 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___32;

struct pipe_buffer___32 {
	struct page___122 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___32 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___32 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___32 *, struct pipe_buffer___32 *);
	void (*release)(struct pipe_inode_info___32 *, struct pipe_buffer___32 *);
	int (*steal)(struct pipe_inode_info___32 *, struct pipe_buffer___32 *);
	union {
		bool (*get)(struct pipe_inode_info___32 *, struct pipe_buffer___32 *);
		struct {
			void (*get)(struct pipe_inode_info___32 *, struct pipe_buffer___32 *);
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
};

struct nf_bridge_info___19 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___19 = 0,
		BRNF_PROTO_8021Q___19 = 1,
		BRNF_PROTO_PPPOE___19 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___4 *physindev;
	struct net_device___4 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef int (*key_restrict_link_func_t___117)(struct key___117 *, const struct key_type *, const union key_payload *, struct key___117 *);

struct key_restriction___117;

struct key___117 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___122 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___117 *restrict_link;
};

struct key_restriction___117 {
	key_restrict_link_func_t___117 check;
	struct key___117 *key;
	struct key_type *keytype;
};

struct cgroup_namespace___98 {
	refcount_t count;
	struct ns_common___8 ns;
	struct user_namespace___102 *user_ns;
	struct ucounts___102 *ucounts;
	struct css_set___98 *root_cset;
};

struct netlink_callback___19 {
	struct sk_buff___3 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___19 *);
	int (*dump)(struct sk_buff___3 *, struct netlink_callback___19 *);
	int (*done)(struct netlink_callback___19 *);
	void *data;
	struct module___105 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct ucounts___102 {
	struct hlist_node node;
	struct user_namespace___102 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct seq_operations___110 {
	void * (*start)(struct seq_file___112 *, loff_t *);
	void (*stop)(struct seq_file___112 *, void *);
	void * (*next)(struct seq_file___112 *, void *, loff_t *);
	int (*show)(struct seq_file___112 *, void *);
};

struct inet_frag_queue___19;

struct inet_frags___19 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___19 *, const void *);
	void (*destructor)(struct inet_frag_queue___19 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___19 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___3 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___3 *fragments_tail;
	struct sk_buff___3 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___19 *net;
	struct callback_head rcu;
};

struct fib_rule___9;

struct fib_lookup_arg___9;

struct fib_rules_ops___9 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___9 *, struct flowi *, int, struct fib_lookup_arg___9 *);
	bool (*suppress)(struct fib_rule___9 *, struct fib_lookup_arg___9 *);
	int (*match)(struct fib_rule___9 *, struct flowi *, int);
	int (*configure)(struct fib_rule___9 *, struct sk_buff___3 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___9 *);
	int (*compare)(struct fib_rule___9 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___9 *, struct sk_buff___3 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___9 *);
	void (*flush_cache)(struct fib_rules_ops___9 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___105 *owner;
	struct net___4 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___9 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___4 *);
	int (*fib_dump)(struct net___4 *, struct notifier_block *);
	struct module___105 *owner;
	struct callback_head rcu;
};

enum {
	IPPROTO_IP = 0,
	IPPROTO_ICMP = 1,
	IPPROTO_IGMP = 2,
	IPPROTO_IPIP = 4,
	IPPROTO_TCP = 6,
	IPPROTO_EGP = 8,
	IPPROTO_PUP = 12,
	IPPROTO_UDP = 17,
	IPPROTO_IDP = 22,
	IPPROTO_TP = 29,
	IPPROTO_DCCP = 33,
	IPPROTO_IPV6 = 41,
	IPPROTO_RSVP = 46,
	IPPROTO_GRE = 47,
	IPPROTO_ESP = 50,
	IPPROTO_AH = 51,
	IPPROTO_MTP = 92,
	IPPROTO_BEETPH = 94,
	IPPROTO_ENCAP = 98,
	IPPROTO_PIM = 103,
	IPPROTO_COMP = 108,
	IPPROTO_SCTP = 132,
	IPPROTO_UDPLITE = 136,
	IPPROTO_MPLS = 137,
	IPPROTO_RAW = 255,
	IPPROTO_MAX = 256,
};

struct pernet_operations___19 {
	struct list_head list;
	int (*init)(struct net___4 *);
	void (*exit)(struct net___4 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct ethtool_ops___19 {
	int (*get_settings)(struct net_device___4 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___4 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___4 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___4 *);
	void (*get_regs)(struct net_device___4 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___4 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___4 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___4 *);
	void (*set_msglevel)(struct net_device___4 *, u32);
	int (*nway_reset)(struct net_device___4 *);
	u32 (*get_link)(struct net_device___4 *);
	int (*get_eeprom_len)(struct net_device___4 *);
	int (*get_eeprom)(struct net_device___4 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___4 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___4 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___4 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___4 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___4 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___4 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___4 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___4 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___4 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___4 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___4 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___4 *);
	void (*complete)(struct net_device___4 *);
	u32 (*get_priv_flags)(struct net_device___4 *);
	int (*set_priv_flags)(struct net_device___4 *, u32);
	int (*get_sset_count)(struct net_device___4 *, int);
	int (*get_rxnfc)(struct net_device___4 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___4 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___4 *, struct ethtool_flash *);
	int (*reset)(struct net_device___4 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___4 *);
	u32 (*get_rxfh_indir_size)(struct net_device___4 *);
	int (*get_rxfh)(struct net_device___4 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___4 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___4 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___4 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___4 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___4 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___4 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___4 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___4 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___4 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___4 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___4 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___4 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___4 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___4 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___4 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___4 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___4 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___4 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___4 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___4 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___4 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	int (*get_fecparam)(struct net_device___4 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___4 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___4 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___4 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___4 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct dcbnl_rtnl_ops___19 {
	int (*ieee_getets)(struct net_device___4 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___4 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___4 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___4 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___4 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___4 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___4 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___4 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___4 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___4 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___4 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___4 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___4 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___4 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___4 *);
	u8 (*setstate)(struct net_device___4 *, u8);
	void (*getpermhwaddr)(struct net_device___4 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___4 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___4 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___4 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___4 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___4 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___4 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___4 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___4 *, int, u8 *);
	void (*setpfccfg)(struct net_device___4 *, int, u8);
	void (*getpfccfg)(struct net_device___4 *, int, u8 *);
	u8 (*setall)(struct net_device___4 *);
	u8 (*getcap)(struct net_device___4 *, int, u8 *);
	int (*getnumtcs)(struct net_device___4 *, int, u8 *);
	int (*setnumtcs)(struct net_device___4 *, int, u8);
	u8 (*getpfcstate)(struct net_device___4 *);
	void (*setpfcstate)(struct net_device___4 *, u8);
	void (*getbcncfg)(struct net_device___4 *, int, u32 *);
	void (*setbcncfg)(struct net_device___4 *, int, u32);
	void (*getbcnrp)(struct net_device___4 *, int, u8 *);
	void (*setbcnrp)(struct net_device___4 *, int, u8);
	int (*setapp)(struct net_device___4 *, u8, u16, u8);
	int (*getapp)(struct net_device___4 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___4 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___4 *, int, u8);
	u8 (*getdcbx)(struct net_device___4 *);
	u8 (*setdcbx)(struct net_device___4 *, u8);
	int (*peer_getappinfo)(struct net_device___4 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___4 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___4 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___4 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___4 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___4 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_bpf___18 {
	struct bpf_prog_array___18 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___18 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___98;

typedef void (*kthread_work_func_t___98)(struct kthread_work___98 *);

struct kthread_worker___98;

struct kthread_work___98 {
	struct list_head node;
	kthread_work_func_t___98 func;
	struct kthread_worker___98 *worker;
	int canceling;
};

struct kthread_worker___98 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___122 *task;
	struct kthread_work___98 *current_work;
};

struct kthread_delayed_work___98 {
	struct kthread_work___98 work;
	struct timer_list timer;
};

struct psi_group___98 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___98 *poll_kworker;
	struct kthread_delayed_work___98 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___98;

struct cgroup_rstat_cpu___98;

struct cgroup___98 {
	struct cgroup_subsys_state___98 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___118 *kn;
	struct cgroup_file___98 procs_file;
	struct cgroup_file___98 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___98 *subsys[13];
	struct cgroup_root___98 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___98 *dom_cgrp;
	struct cgroup_rstat_cpu___98 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___18 bpf;
	atomic_t congestion_count;
	struct cgroup___98 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___98 psi;
	int ancestor_ids[0];
};

struct cftype___98;

struct cgroup_subsys___98 {
	struct cgroup_subsys_state___98 * (*css_alloc)(struct cgroup_subsys_state___98 *);
	int (*css_online)(struct cgroup_subsys_state___98 *);
	void (*css_offline)(struct cgroup_subsys_state___98 *);
	void (*css_released)(struct cgroup_subsys_state___98 *);
	void (*css_free)(struct cgroup_subsys_state___98 *);
	void (*css_reset)(struct cgroup_subsys_state___98 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___98 *, int);
	int (*css_extra_stat_show)(struct seq_file___112 *, struct cgroup_subsys_state___98 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___122 *);
	void (*cancel_fork)(struct task_struct___122 *);
	void (*fork)(struct task_struct___122 *);
	void (*exit)(struct task_struct___122 *);
	void (*free)(struct task_struct___122 *);
	void (*bind)(struct cgroup_subsys_state___98 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___98 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___98 *dfl_cftypes;
	struct cftype___98 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___98 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___98 *updated_children;
	struct cgroup___98 *updated_next;
};

struct cgroup_root___98 {
	struct kernfs_root___118 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___98 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___98 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___98 *ss;
	struct list_head node;
	struct kernfs_ops___118 *kf_ops;
	int (*open)(struct kernfs_open_file___118 *);
	void (*release)(struct kernfs_open_file___118 *);
	u64 (*read_u64)(struct cgroup_subsys_state___98 *, struct cftype___98 *);
	s64 (*read_s64)(struct cgroup_subsys_state___98 *, struct cftype___98 *);
	int (*seq_show)(struct seq_file___112 *, void *);
	void * (*seq_start)(struct seq_file___112 *, loff_t *);
	void * (*seq_next)(struct seq_file___112 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___112 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___98 *, struct cftype___98 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___98 *, struct cftype___98 *, s64);
	ssize_t (*write)(struct kernfs_open_file___118 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___118 *, struct poll_table_struct___82 *);
};

struct xdp_rxq_info___19 {
	struct net_device___4 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___19 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___4 *dev_rx;
};

struct header_ops___19 {
	int (*create)(struct sk_buff___3 *, struct net_device___4 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___3 *, unsigned char *);
	int (*cache)(const struct neighbour___2 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___4 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___19 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___19 *, int);
	int poll_owner;
	struct net_device___4 *dev;
	struct sk_buff___3 *gro_list;
	struct sk_buff___3 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___19 {
	struct net_device___4 *dev;
	struct Qdisc___18 *qdisc;
	struct Qdisc___18 *qdisc_sleeping;
	struct kobject___116 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___4 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___18 {
	struct sk_buff___3 *head;
	struct sk_buff___3 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___18;

struct Qdisc___18 {
	int (*enqueue)(struct sk_buff___3 *, struct Qdisc___18 *, struct sk_buff___3 **);
	struct sk_buff___3 * (*dequeue)(struct Qdisc___18 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___18 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___19 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___3 gso_skb;
	struct qdisc_skb_head___18 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___18 *next_sched;
	struct sk_buff_head___3 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___19 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___116 kobj;
	struct net_device___4 *dev;
	long: 64;
	struct xdp_rxq_info___19 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___19)(struct net_device___4 *, struct sk_buff___3 *, struct net_device___4 *);

struct netdev_bpf___19 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___18 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___18 *prog;
			const struct bpf_prog_offload_ops___18 *ops;
		} verifier;
		struct {
			struct bpf_prog___18 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___19 *offmap;
		};
		struct {
			struct xdp_umem *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___19 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___3 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___19 {
	int (*tls_dev_add)(struct net_device___4 *, struct sock___3 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___4 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___4 *, struct sock___3 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___19 {
	int (*ndo_init)(struct net_device___4 *);
	void (*ndo_uninit)(struct net_device___4 *);
	int (*ndo_open)(struct net_device___4 *);
	int (*ndo_stop)(struct net_device___4 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___3 *, struct net_device___4 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___3 *, struct net_device___4 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___4 *, struct sk_buff___3 *, struct net_device___4 *, select_queue_fallback_t___19);
	void (*ndo_change_rx_flags)(struct net_device___4 *, int);
	void (*ndo_set_rx_mode)(struct net_device___4 *);
	int (*ndo_set_mac_address)(struct net_device___4 *, void *);
	int (*ndo_validate_addr)(struct net_device___4 *);
	int (*ndo_do_ioctl)(struct net_device___4 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___4 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___4 *, int);
	int (*ndo_neigh_setup)(struct net_device___4 *, struct neigh_parms___2 *);
	void (*ndo_tx_timeout)(struct net_device___4 *);
	void (*ndo_get_stats64)(struct net_device___4 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___4 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___4 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___4 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___4 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___4 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___4 *);
	int (*ndo_netpoll_setup)(struct net_device___4 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___4 *);
	int (*ndo_set_vf_mac)(struct net_device___4 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___4 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___4 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___4 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___4 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___4 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___4 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___4 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___4 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___4 *, int, struct sk_buff___3 *);
	int (*ndo_set_vf_guid)(struct net_device___4 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___4 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___4 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___4 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___4 *, const struct sk_buff___3 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___4 *, struct net_device___4 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___4 *, struct net_device___4 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___4 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___4 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___4 *, struct neighbour___2 *);
	void (*ndo_neigh_destroy)(struct net_device___4 *, struct neighbour___2 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___4 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___4 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___4 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___3 *, struct netlink_callback___19 *, struct net_device___4 *, struct net_device___4 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___4 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___4 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___3 *, u32, u32, struct net_device___4 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___4 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___4 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___4 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___4 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___4 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___4 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___4 *, struct net_device___4 *);
	void (*ndo_dfwd_del_station)(struct net_device___4 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___4 *);
	int (*ndo_set_tx_maxrate)(struct net_device___4 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___4 *);
	int (*ndo_change_proto_down)(struct net_device___4 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___4 *, struct sk_buff___3 *);
	void (*ndo_set_rx_headroom)(struct net_device___4 *, int);
	int (*ndo_bpf)(struct net_device___4 *, struct netdev_bpf___19 *);
	int (*ndo_xdp_xmit)(struct net_device___4 *, int, struct xdp_frame___19 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___4 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___4 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___2 {
	possible_net_t___20 net;
	struct net_device___4 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___2 *);
	void (*neigh_cleanup)(struct neighbour___2 *);
	struct neigh_table___2 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___10 {
	u32 (*l3mdev_fib_table)(const struct net_device___4 *);
	struct sk_buff___3 * (*l3mdev_l3_rcv)(struct net_device___4 *, struct sk_buff___3 *, u16);
	struct sk_buff___3 * (*l3mdev_l3_out)(struct net_device___4 *, struct sock___3 *, struct sk_buff___3 *, u16);
	struct dst_entry___2 * (*l3mdev_link_scope_lookup)(const struct net_device___4 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct tcf_proto___18;

struct mini_Qdisc___18 {
	struct tcf_proto___18 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___18 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___4 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___4 *, struct net_device___4 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___4 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___4 *, struct list_head *);
	size_t (*get_size)(const struct net_device___4 *);
	int (*fill_info)(struct sk_buff___3 *, const struct net_device___4 *);
	size_t (*get_xstats_size)(const struct net_device___4 *);
	int (*fill_xstats)(struct sk_buff___3 *, const struct net_device___4 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___4 *, struct net_device___4 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___4 *, const struct net_device___4 *);
	int (*fill_slave_info)(struct sk_buff___3 *, const struct net_device___4 *, const struct net_device___4 *);
	struct net___4 * (*get_link_net)(const struct net_device___4 *);
	size_t (*get_linkxstats_size)(const struct net_device___4 *, int);
	int (*fill_linkxstats)(struct sk_buff___3 *, const struct net_device___4 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___19 {
	struct list_head poll_list;
	struct sk_buff_head___3 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___19 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___18 *output_queue;
	struct Qdisc___18 **output_queue_tailp;
	struct sk_buff___3 *completion_queue;
	struct sk_buff_head___3 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___19 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___3 input_pkt_queue;
	struct napi_struct___19 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bdi_writeback_congested___45 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___45 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___45 {
	struct bio___45 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___45 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___45 bip_inline_vecs[0];
};

struct bio_set___45 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___45 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___40 {
	struct mem_cgroup___40 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___40 {
	struct lruvec___121 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___40 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___40 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct kernel_param_ops___102 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___102 *);
	int (*get)(char *, const struct kernel_param___102 *);
	void (*free)(void *);
};

struct kparam_array___102;

struct kernel_param___102 {
	const char *name;
	struct module___105 *mod;
	const struct kernel_param_ops___102 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___102 *arr;
	};
};

struct kparam_array___102 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___102 *ops;
	void *elem;
};

struct module_attribute___102 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___102 *, struct module_kobject___102 *, char *);
	ssize_t (*store)(struct module_attribute___102 *, struct module_kobject___102 *, const char *, size_t);
	void (*setup)(struct module___105 *, const char *);
	int (*test)(struct module___105 *);
	void (*free)(struct module___105 *);
};

struct gnet_dump___18 {
	spinlock_t *lock;
	struct sk_buff___3 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___18;

struct Qdisc_ops___18 {
	struct Qdisc_ops___18 *next;
	const struct Qdisc_class_ops___18 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___3 *, struct Qdisc___18 *, struct sk_buff___3 **);
	struct sk_buff___3 * (*dequeue)(struct Qdisc___18 *);
	struct sk_buff___3 * (*peek)(struct Qdisc___18 *);
	int (*init)(struct Qdisc___18 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___18 *);
	void (*destroy)(struct Qdisc___18 *);
	int (*change)(struct Qdisc___18 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___18 *);
	int (*change_tx_queue_len)(struct Qdisc___18 *, unsigned int);
	int (*dump)(struct Qdisc___18 *, struct sk_buff___3 *);
	int (*dump_stats)(struct Qdisc___18 *, struct gnet_dump___18 *);
	void (*ingress_block_set)(struct Qdisc___18 *, u32);
	void (*egress_block_set)(struct Qdisc___18 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___18 *);
	u32 (*egress_block_get)(struct Qdisc___18 *);
	struct module___105 *owner;
};

struct tcf_block___18;

struct Qdisc_class_ops___18 {
	unsigned int flags;
	struct netdev_queue___19 * (*select_queue)(struct Qdisc___18 *, struct tcmsg *);
	int (*graft)(struct Qdisc___18 *, long unsigned int, struct Qdisc___18 *, struct Qdisc___18 **, struct netlink_ext_ack *);
	struct Qdisc___18 * (*leaf)(struct Qdisc___18 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___18 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___18 *, u32);
	int (*change)(struct Qdisc___18 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___18 *, long unsigned int);
	void (*walk)(struct Qdisc___18 *, struct qdisc_walker *);
	struct tcf_block___18 * (*tcf_block)(struct Qdisc___18 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___18 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___18 *, long unsigned int);
	int (*dump)(struct Qdisc___18 *, long unsigned int, struct sk_buff___3 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___18 *, long unsigned int, struct gnet_dump___18 *);
};

struct tcf_chain___18;

struct tcf_block___18 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___4 *net;
	struct Qdisc___18 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___18 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___18;

struct tcf_proto_ops___18;

struct tcf_proto___18 {
	struct tcf_proto___18 *next;
	void *root;
	int (*classify)(struct sk_buff___3 *, const struct tcf_proto___18 *, struct tcf_result___18 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___18 *ops;
	struct tcf_chain___18 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___18 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___18 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___18 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___3 *, const struct tcf_proto___18 *, struct tcf_result___18 *);
	int (*init)(struct tcf_proto___18 *);
	void (*destroy)(struct tcf_proto___18 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___18 *, u32);
	void (*put)(struct tcf_proto___18 *, void *);
	int (*change)(struct net___4 *, struct sk_buff___3 *, struct tcf_proto___18 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___18 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___18 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___18 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___4 *, struct tcf_chain___18 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___4 *, struct tcf_proto___18 *, void *, struct sk_buff___3 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___3 *, struct net___4 *, void *);
	struct module___105 *owner;
	int flags;
};

struct tcf_chain___18 {
	struct mutex filter_chain_lock;
	struct tcf_proto___18 *filter_chain;
	struct list_head list;
	struct tcf_block___18 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___18 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___9 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___18 *prog;
};

struct bpf_redirect_info___18 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___98 *map;
	struct bpf_map___98 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___9;

struct neigh_hash_table___9;

struct neigh_table___2 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___4 *, __u32 *);
	bool (*key_eq)(const struct neighbour___2 *, const void *);
	int (*constructor)(struct neighbour___2 *);
	int (*pconstructor)(struct pneigh_entry___9 *);
	void (*pdestructor)(struct pneigh_entry___9 *);
	void (*proxy_redo)(struct sk_buff___3 *);
	char *id;
	struct neigh_parms___2 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___3 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___9 *nht;
	struct pneigh_entry___9 **phash_buckets;
};

struct neigh_ops___2 {
	int family;
	void (*solicit)(struct neighbour___2 *, struct sk_buff___3 *);
	void (*error_report)(struct neighbour___2 *, struct sk_buff___3 *);
	int (*output)(struct neighbour___2 *, struct sk_buff___3 *);
	int (*connected_output)(struct neighbour___2 *, struct sk_buff___3 *);
};

struct pneigh_entry___9 {
	struct pneigh_entry___9 *next;
	possible_net_t___20 net;
	struct net_device___4 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___9 {
	struct neighbour___2 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___9 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___9 *ctarget;
	struct net___4 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___9 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___9 *rule;
	u32 table;
	int flags;
};

struct proto___9 {
	void (*close)(struct sock___3 *, long int);
	int (*pre_connect)(struct sock___3 *, struct sockaddr *, int);
	int (*connect)(struct sock___3 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___3 *, int);
	struct sock___3 * (*accept)(struct sock___3 *, int, int *, bool);
	int (*ioctl)(struct sock___3 *, int, long unsigned int);
	int (*init)(struct sock___3 *);
	void (*destroy)(struct sock___3 *);
	void (*shutdown)(struct sock___3 *, int);
	int (*setsockopt)(struct sock___3 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___3 *, int, int, char *, int *);
	void (*keepalive)(struct sock___3 *, int);
	int (*sendmsg)(struct sock___3 *, struct msghdr___9 *, size_t);
	int (*recvmsg)(struct sock___3 *, struct msghdr___9 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___3 *, struct page___122 *, int, size_t, int);
	int (*bind)(struct sock___3 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___3 *, struct sk_buff___3 *);
	void (*release_cb)(struct sock___3 *);
	int (*hash)(struct sock___3 *);
	void (*unhash)(struct sock___3 *);
	void (*rehash)(struct sock___3 *);
	int (*get_port)(struct sock___3 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___3 *);
	bool (*stream_memory_read)(const struct sock___3 *);
	void (*enter_memory_pressure)(struct sock___3 *);
	void (*leave_memory_pressure)(struct sock___3 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___3 *rsk_prot;
	struct timewait_sock_ops___3 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___105 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___3 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct sock_reuseport___2 {
	struct callback_head rcu;
	u16 max_socks;
	u16 num_socks;
	unsigned int reuseport_id;
	bool bind_inany;
	struct bpf_prog___18 *prog;
	struct sock___3 *socks[0];
};

enum sock_flags {
	SOCK_DEAD = 0,
	SOCK_DONE = 1,
	SOCK_URGINLINE = 2,
	SOCK_KEEPOPEN = 3,
	SOCK_LINGER = 4,
	SOCK_DESTROY = 5,
	SOCK_BROADCAST = 6,
	SOCK_TIMESTAMP = 7,
	SOCK_ZAPPED = 8,
	SOCK_USE_WRITE_QUEUE = 9,
	SOCK_DBG = 10,
	SOCK_RCVTSTAMP = 11,
	SOCK_RCVTSTAMPNS = 12,
	SOCK_LOCALROUTE = 13,
	SOCK_QUEUE_SHRUNK = 14,
	SOCK_MEMALLOC = 15,
	SOCK_TIMESTAMPING_RX_SOFTWARE = 16,
	SOCK_FASYNC = 17,
	SOCK_RXQ_OVFL = 18,
	SOCK_ZEROCOPY = 19,
	SOCK_WIFI_STATUS = 20,
	SOCK_NOFCS = 21,
	SOCK_FILTER_LOCKED = 22,
	SOCK_SELECT_ERR_QUEUE = 23,
	SOCK_RCU_FREE = 24,
	SOCK_TXTIME = 25,
	SOCK_XDP = 26,
};

struct reuseport_array {
	struct bpf_map___98 map;
	struct sock___3 *ptrs[0];
};

struct module___106;

struct file___123;

struct kiocb___123;

struct iov_iter___52;

struct poll_table_struct___83;

struct vm_area_struct___123;

struct inode___124;

struct file_lock___123;

struct page___123;

struct pipe_inode_info___33;

struct seq_file___113;

struct file_operations___123 {
	struct module___106 *owner;
	loff_t (*llseek)(struct file___123 *, loff_t, int);
	ssize_t (*read)(struct file___123 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___123 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___123 *, struct iov_iter___52 *);
	ssize_t (*write_iter)(struct kiocb___123 *, struct iov_iter___52 *);
	int (*iopoll)(struct kiocb___123 *, bool);
	int (*iterate)(struct file___123 *, struct dir_context *);
	int (*iterate_shared)(struct file___123 *, struct dir_context *);
	__poll_t (*poll)(struct file___123 *, struct poll_table_struct___83 *);
	long int (*unlocked_ioctl)(struct file___123 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___123 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___123 *, struct vm_area_struct___123 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___124 *, struct file___123 *);
	int (*flush)(struct file___123 *, fl_owner_t);
	int (*release)(struct inode___124 *, struct file___123 *);
	int (*fsync)(struct file___123 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___123 *, int);
	int (*lock)(struct file___123 *, int, struct file_lock___123 *);
	ssize_t (*sendpage)(struct file___123 *, struct page___123 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___123 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___123 *, int, struct file_lock___123 *);
	ssize_t (*splice_write)(struct pipe_inode_info___33 *, struct file___123 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___123 *, loff_t *, struct pipe_inode_info___33 *, size_t, unsigned int);
	int (*setlease)(struct file___123 *, long int, struct file_lock___123 **, void **);
	long int (*fallocate)(struct file___123 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___113 *, struct file___123 *);
	ssize_t (*copy_file_range)(struct file___123 *, loff_t, struct file___123 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___123 *, loff_t, struct file___123 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___123 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___122 {
	u64 seqnum;
	struct vm_area_struct___123 *vmas[4];
};

struct page_frag___122 {
	struct page___123 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___75;

struct debug_info___75 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___75 *hbp_break[16];
	struct perf_event___75 *hbp_watch[16];
};

struct thread_struct___75 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___75 debug;
	long: 64;
};

struct mm_struct___122;

struct pid___99;

struct cred___118;

struct nsproxy___115;

struct signal_struct___112;

struct css_set___99;

struct perf_event_context___75;

struct vm_struct___92;

struct task_struct___123 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___123 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___122 *mm;
	struct mm_struct___122 *active_mm;
	struct vmacache___122 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___123 *real_parent;
	struct task_struct___123 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___123 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___99 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___99 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___99 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___118 *ptracer_cred;
	const struct cred___118 *real_cred;
	const struct cred___118 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___115 *nsproxy;
	struct signal_struct___112 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___123 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___17 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___99 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___75 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___33 *splice_pipe;
	struct page_frag___122 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___123 *oom_reaper_list;
	struct vm_struct___92 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___75 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___75 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___123 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___75)(struct perf_event___75 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___75;

struct ring_buffer___2;

struct fasync_struct___122;

struct pid_namespace___99;

struct bpf_prog___19;

struct trace_event_call___69;

struct perf_cgroup___75;

struct perf_event___75 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___75 *group_leader;
	struct pmu___75 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___75 hw;
	struct perf_event_context___75 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___75 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___123 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer___2 *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___122 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___75 *);
	struct callback_head callback_head;
	struct pid_namespace___99 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___75 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___75 orig_overflow_handler;
	struct bpf_prog___19 *prog;
	struct trace_event_call___69 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___75 *cgrp;
	struct list_head sb_list;
};

struct dentry_operations___122;

struct super_block___123;

struct dentry___123 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___123 *d_parent;
	struct qstr d_name;
	struct inode___124 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___122 *d_op;
	struct super_block___123 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct rw_semaphore___123 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___123 *owner;
};

struct address_space_operations___122;

struct address_space___122 {
	struct inode___124 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___123 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___122 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___122;

struct block_device___123;

struct inode___124 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___122 *i_op;
	struct super_block___123 *i_sb;
	struct address_space___122 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___123 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___123 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___122 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___33 *i_pipe;
		struct block_device___123 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vfsmount___18;

struct path___122;

struct dentry_operations___122 {
	int (*d_revalidate)(struct dentry___123 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___123 *, unsigned int);
	int (*d_hash)(const struct dentry___123 *, struct qstr *);
	int (*d_compare)(const struct dentry___123 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___123 *);
	int (*d_init)(struct dentry___123 *);
	void (*d_release)(struct dentry___123 *);
	void (*d_prune)(struct dentry___123 *);
	void (*d_iput)(struct dentry___123 *, struct inode___124 *);
	char * (*d_dname)(struct dentry___123 *, char *, int);
	struct vfsmount___18 * (*d_automount)(struct path___122 *);
	int (*d_manage)(const struct path___122 *, bool);
	struct dentry___123 * (*d_real)(struct dentry___123 *, const struct inode___124 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___122;

struct mem_dqinfo___122 {
	struct quota_format_type___122 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___122;

struct quota_info___122 {
	unsigned int flags;
	struct rw_semaphore___123 dqio_sem;
	struct inode___124 *files[3];
	struct mem_dqinfo___122 info[3];
	const struct quota_format_ops___122 *ops[3];
};

struct rcuwait___122 {
	struct task_struct___123 *task;
};

struct percpu_rw_semaphore___122 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___123 rw_sem;
	struct rcuwait___122 writer;
	int readers_block;
};

struct sb_writers___122 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___122 rw_sem[3];
};

struct file_system_type___122;

struct super_operations___122;

struct dquot_operations___122;

struct quotactl_ops___122;

struct user_namespace___103;

struct super_block___123 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___122 *s_type;
	const struct super_operations___122 *s_op;
	const struct dquot_operations___122 *dq_op;
	const struct quotactl_ops___122 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___123 *s_root;
	struct rw_semaphore___123 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___123 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___122 s_dquot;
	struct sb_writers___122 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___122 *s_d_op;
	int cleancache_poolid;
	struct shrinker___40 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___103 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___18 {
	struct dentry___123 *mnt_root;
	struct super_block___123 *mnt_sb;
	int mnt_flags;
};

struct path___122 {
	struct vfsmount___18 *mnt;
	struct dentry___123 *dentry;
};

struct proc_ns_operations___9;

struct ns_common___9 {
	atomic_long_t stashed;
	const struct proc_ns_operations___9 *ops;
	unsigned int inum;
};

struct key___118;

struct ucounts___103;

struct user_namespace___103 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___103 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___9 ns;
	long unsigned int flags;
	struct key___118 *persistent_keyring_register;
	struct rw_semaphore___123 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___103 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___123 *pgtable_t___122;

struct dev_pagemap___120;

struct page___123 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___122 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___123 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___122 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___122 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___120 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___122;

struct lruvec___122 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___122 *pgdat;
};

struct zone___122 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___122 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___122 {
	struct zone___122 *zone;
	int zone_idx;
};

struct zonelist___122 {
	struct zoneref___122 _zonerefs[25];
};

struct pglist_data___122 {
	struct zone___122 node_zones[3];
	struct zonelist___122 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___123 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___123 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___122 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___123 {
	void *stack;
	struct task_struct___123 *task;
	long int status;
};

struct clock_event_device___16;

struct arch_timer_erratum_workaround___16 {
	enum arch_timer_erratum_match_type match_type;
	const void *id;
	const char *desc;
	u32 (*read_cntp_tval_el0)();
	u32 (*read_cntv_tval_el0)();
	u64 (*read_cntpct_el0)();
	u64 (*read_cntvct_el0)();
	int (*set_next_event_phys)(long unsigned int, struct clock_event_device___16 *);
	int (*set_next_event_virt)(long unsigned int, struct clock_event_device___16 *);
};

struct clock_event_device___16 {
	void (*event_handler)(struct clock_event_device___16 *);
	int (*set_next_event)(long unsigned int, struct clock_event_device___16 *);
	int (*set_next_ktime)(ktime_t, struct clock_event_device___16 *);
	ktime_t next_event;
	u64 max_delta_ns;
	u64 min_delta_ns;
	u32 mult;
	u32 shift;
	enum clock_event_state state_use_accessors;
	unsigned int features;
	long unsigned int retries;
	int (*set_state_periodic)(struct clock_event_device___16 *);
	int (*set_state_oneshot)(struct clock_event_device___16 *);
	int (*set_state_oneshot_stopped)(struct clock_event_device___16 *);
	int (*set_state_shutdown)(struct clock_event_device___16 *);
	int (*tick_resume)(struct clock_event_device___16 *);
	void (*broadcast)(const struct cpumask *);
	void (*suspend)(struct clock_event_device___16 *);
	void (*resume)(struct clock_event_device___16 *);
	long unsigned int min_delta_ticks;
	long unsigned int max_delta_ticks;
	const char *name;
	int rating;
	int irq;
	int bound_on;
	const struct cpumask *cpumask;
	struct list_head list;
	struct module___106 *owner;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct blocking_notifier_head___122 {
	struct rw_semaphore___123 rwsem;
	struct notifier_block *head;
};

struct upid___99 {
	int nr;
	struct pid_namespace___99 *ns;
};

struct pid_namespace___99 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___123 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___99 *parent;
	struct vfsmount___18 *proc_mnt;
	struct dentry___123 *proc_self;
	struct dentry___123 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___103 *user_ns;
	struct ucounts___103 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___9 ns;
};

struct pid___99 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___99 numbers[1];
};

struct vm_operations_struct___120;

struct vm_area_struct___123 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___123 *vm_next;
	struct vm_area_struct___123 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___122 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___120 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___123 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___122;

struct mm_struct___122 {
	struct {
		struct vm_area_struct___123 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___123 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___123 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___122 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___123 *owner;
		struct user_namespace___103 *user_ns;
		struct file___123 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___122 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___120)(struct vm_area_struct___123 *, long unsigned int, const struct page___123 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___120)(struct page___123 *, void *);

struct device___114;

struct dev_pagemap___120 {
	dev_page_fault_t___120 page_fault;
	dev_page_free_t___120 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___114 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct fown_struct___99 {
	rwlock_t lock;
	struct pid___99 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___123 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___122 f_path;
	struct inode___124 *f_inode;
	const struct file_operations___123 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___99 f_owner;
	const struct cred___118 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___122 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___120;

struct vm_operations_struct___120 {
	void (*open)(struct vm_area_struct___123 *);
	void (*close)(struct vm_area_struct___123 *);
	int (*split)(struct vm_area_struct___123 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___123 *);
	vm_fault_t (*fault)(struct vm_fault___120 *);
	vm_fault_t (*huge_fault)(struct vm_fault___120 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___120 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___123 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___120 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___120 *);
	int (*access)(struct vm_area_struct___123 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___123 *);
	int (*set_policy)(struct vm_area_struct___123 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___123 *, long unsigned int);
	struct page___123 * (*find_special_page)(struct vm_area_struct___123 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___122 {
	struct task_struct___123 *task;
	struct core_thread___122 *next;
};

struct core_state___122 {
	atomic_t nr_threads;
	struct core_thread___122 dumper;
	struct completion startup;
};

struct vm_fault___120 {
	struct vm_area_struct___123 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___123 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___123 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___122 prealloc_pte;
};

struct user_struct___118 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___118 *uid_keyring;
	struct key___118 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___118 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___118 *session_keyring;
	struct key___118 *process_keyring;
	struct key___118 *thread_keyring;
	struct key___118 *request_key_auth;
	void *security;
	struct user_struct___118 *user;
	struct user_namespace___103 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___29;

struct cgroup_namespace___99;

struct nsproxy___115 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___99 *pid_ns_for_children;
	struct net___29 *net_ns;
	struct cgroup_namespace___99 *cgroup_ns;
};

struct signal_struct___112 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___123 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___123 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___99 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___99 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___122 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___99 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___99;

struct cgroup___99;

struct css_set___99 {
	struct cgroup_subsys_state___99 *subsys[13];
	refcount_t refcount;
	struct css_set___99 *dom_cset;
	struct cgroup___99 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___99 *mg_src_cgrp;
	struct cgroup___99 *mg_dst_cgrp;
	struct css_set___99 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___75 {
	struct pmu___75 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___123 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___75 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___33;

struct pipe_inode_info___33 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___123 *tmp_page;
	struct fasync_struct___122 *fasync_readers;
	struct fasync_struct___122 *fasync_writers;
	struct pipe_buffer___33 *bufs;
	struct user_struct___118 *user;
};

struct vm_struct___92 {
	struct vm_struct___92 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___123 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___112 {
	struct task_struct___123 task;
	long unsigned int stack[8192];
};

struct kiocb___123 {
	struct file___123 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___123 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___123 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___123 *ia_file;
};

struct dquot___122 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___123 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___122 {
	int qf_fmt_id;
	const struct quota_format_ops___122 *qf_ops;
	struct module___106 *qf_owner;
	struct quota_format_type___122 *qf_next;
};

struct quota_format_ops___122 {
	int (*check_quota_file)(struct super_block___123 *, int);
	int (*read_file_info)(struct super_block___123 *, int);
	int (*write_file_info)(struct super_block___123 *, int);
	int (*free_file_info)(struct super_block___123 *, int);
	int (*read_dqblk)(struct dquot___122 *);
	int (*commit_dqblk)(struct dquot___122 *);
	int (*release_dqblk)(struct dquot___122 *);
	int (*get_next_id)(struct super_block___123 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___122 {
	int (*write_dquot)(struct dquot___122 *);
	struct dquot___122 * (*alloc_dquot)(struct super_block___123 *, int);
	void (*destroy_dquot)(struct dquot___122 *);
	int (*acquire_dquot)(struct dquot___122 *);
	int (*release_dquot)(struct dquot___122 *);
	int (*mark_dirty)(struct dquot___122 *);
	int (*write_info)(struct super_block___123 *, int);
	qsize_t * (*get_reserved_space)(struct inode___124 *);
	int (*get_projid)(struct inode___124 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___124 *, qsize_t *);
	int (*get_next_id)(struct super_block___123 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___122 {
	int (*quota_on)(struct super_block___123 *, int, int, const struct path___122 *);
	int (*quota_off)(struct super_block___123 *, int);
	int (*quota_enable)(struct super_block___123 *, unsigned int);
	int (*quota_disable)(struct super_block___123 *, unsigned int);
	int (*quota_sync)(struct super_block___123 *, int);
	int (*set_info)(struct super_block___123 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___123 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___123 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___123 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___123 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___123 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___116;

struct kobj_type___116;

struct kernfs_node___119;

struct kobject___117 {
	const char *name;
	struct list_head entry;
	struct kobject___117 *parent;
	struct kset___116 *kset;
	struct kobj_type___116 *ktype;
	struct kernfs_node___119 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___103 {
	struct kobject___117 kobj;
	struct module___106 *mod;
	struct kobject___117 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___103 {
	struct module___106 *mod;
	struct latch_tree_node node;
};

struct module_layout___103 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___103 mtn;
};

struct module_attribute___103;

struct kernel_param___103;

struct module___106 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___103 mkobj;
	struct module_attribute___103 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___117 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___103 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___103 core_layout;
	struct module_layout___103 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___69 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___122 {
	int (*writepage)(struct page___123 *, struct writeback_control___3 *);
	int (*readpage)(struct file___123 *, struct page___123 *);
	int (*writepages)(struct address_space___122 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___123 *);
	int (*readpages)(struct file___123 *, struct address_space___122 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___123 *, struct address_space___122 *, loff_t, unsigned int, unsigned int, struct page___123 **, void **);
	int (*write_end)(struct file___123 *, struct address_space___122 *, loff_t, unsigned int, unsigned int, struct page___123 *, void *);
	sector_t (*bmap)(struct address_space___122 *, sector_t);
	void (*invalidatepage)(struct page___123 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___123 *, gfp_t);
	void (*freepage)(struct page___123 *);
	ssize_t (*direct_IO)(struct kiocb___123 *, struct iov_iter___52 *);
	int (*migratepage)(struct address_space___122 *, struct page___123 *, struct page___123 *, enum migrate_mode);
	bool (*isolate_page)(struct page___123 *, isolate_mode_t);
	void (*putback_page)(struct page___123 *);
	int (*launder_page)(struct page___123 *);
	int (*is_partially_uptodate)(struct page___123 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___123 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___122 *, struct page___123 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___123 *, sector_t *);
	void (*swap_deactivate)(struct file___123 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct iov_iter___52 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___3 *bvec;
		struct pipe_inode_info___33 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___123 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___124 *bd_inode;
	struct super_block___123 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___123 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___122 {
	struct dentry___123 * (*lookup)(struct inode___124 *, struct dentry___123 *, unsigned int);
	const char * (*get_link)(struct dentry___123 *, struct inode___124 *, struct delayed_call *);
	int (*permission)(struct inode___124 *, int);
	struct posix_acl * (*get_acl)(struct inode___124 *, int);
	int (*readlink)(struct dentry___123 *, char *, int);
	int (*create)(struct inode___124 *, struct dentry___123 *, umode_t, bool);
	int (*link)(struct dentry___123 *, struct inode___124 *, struct dentry___123 *);
	int (*unlink)(struct inode___124 *, struct dentry___123 *);
	int (*symlink)(struct inode___124 *, struct dentry___123 *, const char *);
	int (*mkdir)(struct inode___124 *, struct dentry___123 *, umode_t);
	int (*rmdir)(struct inode___124 *, struct dentry___123 *);
	int (*mknod)(struct inode___124 *, struct dentry___123 *, umode_t, dev_t);
	int (*rename)(struct inode___124 *, struct dentry___123 *, struct inode___124 *, struct dentry___123 *, unsigned int);
	int (*setattr)(struct dentry___123 *, struct iattr___123 *);
	int (*getattr)(const struct path___122 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___123 *, char *, size_t);
	int (*fiemap)(struct inode___124 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___124 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___124 *, struct dentry___123 *, struct file___123 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___124 *, struct dentry___123 *, umode_t);
	int (*set_acl)(struct inode___124 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___122 {
	void (*fl_copy_lock)(struct file_lock___123 *, struct file_lock___123 *);
	void (*fl_release_private)(struct file_lock___123 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___122;

struct file_lock___123 {
	struct file_lock___123 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___123 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___122 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___122 *fl_ops;
	const struct lock_manager_operations___122 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___122 {
	int (*lm_compare_owner)(struct file_lock___123 *, struct file_lock___123 *);
	long unsigned int (*lm_owner_key)(struct file_lock___123 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___123 *);
	int (*lm_grant)(struct file_lock___123 *, int);
	bool (*lm_break)(struct file_lock___123 *);
	int (*lm_change)(struct file_lock___123 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___123 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___122 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___122 *fa_next;
	struct file___123 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___122 {
	const char *name;
	int fs_flags;
	struct dentry___123 * (*mount)(struct file_system_type___122 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___123 *);
	struct module___106 *owner;
	struct file_system_type___122 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___122 {
	struct inode___124 * (*alloc_inode)(struct super_block___123 *);
	void (*destroy_inode)(struct inode___124 *);
	void (*dirty_inode)(struct inode___124 *, int);
	int (*write_inode)(struct inode___124 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___124 *);
	void (*evict_inode)(struct inode___124 *);
	void (*put_super)(struct super_block___123 *);
	int (*sync_fs)(struct super_block___123 *, int);
	int (*freeze_super)(struct super_block___123 *);
	int (*freeze_fs)(struct super_block___123 *);
	int (*thaw_super)(struct super_block___123 *);
	int (*unfreeze_fs)(struct super_block___123 *);
	int (*statfs)(struct dentry___123 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___123 *, int *, char *);
	void (*umount_begin)(struct super_block___123 *);
	int (*show_options)(struct seq_file___113 *, struct dentry___123 *);
	int (*show_devname)(struct seq_file___113 *, struct dentry___123 *);
	int (*show_path)(struct seq_file___113 *, struct dentry___123 *);
	int (*show_stats)(struct seq_file___113 *, struct dentry___123 *);
	ssize_t (*quota_read)(struct super_block___123 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___123 *, int, const char *, size_t, loff_t);
	struct dquot___122 ** (*get_dquots)(struct inode___124 *);
	int (*bdev_try_to_free_page)(struct super_block___123 *, struct page___123 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___123 *, struct shrink_control___40 *);
	long int (*free_cached_objects)(struct super_block___123 *, struct shrink_control___40 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___82)(struct file___123 *, wait_queue_head_t *, struct poll_table_struct___83 *);

struct poll_table_struct___83 {
	poll_queue_proc___82 _qproc;
	__poll_t _key;
};

struct seq_operations___111;

struct seq_file___113 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___111 *op;
	int poll_event;
	const struct file___123 *file;
	void *private;
};

struct dev_pm_info___114 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___114 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___114;

struct bus_type___114;

struct device_driver___114;

struct dev_pm_domain___114;

struct dma_map_ops___36;

struct device_node___42;

struct fwnode_handle___86;

struct class___114;

struct attribute_group___113;

struct device___114 {
	struct device___114 *parent;
	struct device_private *p;
	struct kobject___117 kobj;
	const char *init_name;
	const struct device_type___114 *type;
	struct mutex mutex;
	struct bus_type___114 *bus;
	struct device_driver___114 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___114 power;
	struct dev_pm_domain___114 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___36 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___42 *of_node;
	struct fwnode_handle___86 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___114 *class;
	const struct attribute_group___113 **groups;
	void (*release)(struct device___114 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct kobj_attribute___117 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___117 *, struct kobj_attribute___117 *, char *);
	ssize_t (*store)(struct kobject___117 *, struct kobj_attribute___117 *, const char *, size_t);
};

typedef void compound_page_dtor___120(struct page___123 *);

struct kernfs_root___119;

struct kernfs_elem_dir___119 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___119 *root;
};

struct kernfs_syscall_ops___119;

struct kernfs_root___119 {
	struct kernfs_node___119 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___119 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___119 {
	struct kernfs_node___119 *target_kn;
};

struct kernfs_ops___119;

struct kernfs_elem_attr___119 {
	const struct kernfs_ops___119 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___119 *notify_next;
};

struct kernfs_node___119 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___119 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___119 dir;
		struct kernfs_elem_symlink___119 symlink;
		struct kernfs_elem_attr___119 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___119;

struct kernfs_ops___119 {
	int (*open)(struct kernfs_open_file___119 *);
	void (*release)(struct kernfs_open_file___119 *);
	int (*seq_show)(struct seq_file___113 *, void *);
	void * (*seq_start)(struct seq_file___113 *, loff_t *);
	void * (*seq_next)(struct seq_file___113 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___113 *, void *);
	ssize_t (*read)(struct kernfs_open_file___119 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___119 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___119 *, struct vm_area_struct___123 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___119 *, struct poll_table_struct___83 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___119 {
	int (*remount_fs)(struct kernfs_root___119 *, int *, char *);
	int (*show_options)(struct seq_file___113 *, struct kernfs_root___119 *);
	int (*mkdir)(struct kernfs_node___119 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___119 *);
	int (*rename)(struct kernfs_node___119 *, struct kernfs_node___119 *, const char *);
	int (*show_path)(struct seq_file___113 *, struct kernfs_node___119 *, struct kernfs_root___119 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___119 {
	struct kernfs_node___119 *kn;
	struct file___123 *file;
	struct seq_file___113 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___120 *vm_ops;
};

struct bin_attribute___113;

struct attribute_group___113 {
	const char *name;
	umode_t (*is_visible)(struct kobject___117 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___117 *, struct bin_attribute___113 *, int);
	struct attribute **attrs;
	struct bin_attribute___113 **bin_attrs;
};

struct bin_attribute___113 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___123 *, struct kobject___117 *, struct bin_attribute___113 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___123 *, struct kobject___117 *, struct bin_attribute___113 *, char *, loff_t, size_t);
	int (*mmap)(struct file___123 *, struct kobject___117 *, struct bin_attribute___113 *, struct vm_area_struct___123 *);
};

struct sysfs_ops___116 {
	ssize_t (*show)(struct kobject___117 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___117 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___116;

struct kset___116 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___117 kobj;
	const struct kset_uevent_ops___116 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___116 {
	void (*release)(struct kobject___117 *);
	const struct sysfs_ops___116 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___9 * (*child_ns_type)(struct kobject___117 *);
	const void * (*namespace)(struct kobject___117 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___116 {
	int (* const filter)(struct kset___116 *, struct kobject___117 *);
	const char * (* const name)(struct kset___116 *, struct kobject___117 *);
	int (* const uevent)(struct kset___116 *, struct kobject___117 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___114 {
	int (*prepare)(struct device___114 *);
	void (*complete)(struct device___114 *);
	int (*suspend)(struct device___114 *);
	int (*resume)(struct device___114 *);
	int (*freeze)(struct device___114 *);
	int (*thaw)(struct device___114 *);
	int (*poweroff)(struct device___114 *);
	int (*restore)(struct device___114 *);
	int (*suspend_late)(struct device___114 *);
	int (*resume_early)(struct device___114 *);
	int (*freeze_late)(struct device___114 *);
	int (*thaw_early)(struct device___114 *);
	int (*poweroff_late)(struct device___114 *);
	int (*restore_early)(struct device___114 *);
	int (*suspend_noirq)(struct device___114 *);
	int (*resume_noirq)(struct device___114 *);
	int (*freeze_noirq)(struct device___114 *);
	int (*thaw_noirq)(struct device___114 *);
	int (*poweroff_noirq)(struct device___114 *);
	int (*restore_noirq)(struct device___114 *);
	int (*runtime_suspend)(struct device___114 *);
	int (*runtime_resume)(struct device___114 *);
	int (*runtime_idle)(struct device___114 *);
};

struct dev_pm_domain___114 {
	struct dev_pm_ops___114 ops;
	void (*detach)(struct device___114 *, bool);
	int (*activate)(struct device___114 *);
	void (*sync)(struct device___114 *);
	void (*dismiss)(struct device___114 *);
};

struct bus_type___114 {
	const char *name;
	const char *dev_name;
	struct device___114 *dev_root;
	const struct attribute_group___113 **bus_groups;
	const struct attribute_group___113 **dev_groups;
	const struct attribute_group___113 **drv_groups;
	int (*match)(struct device___114 *, struct device_driver___114 *);
	int (*uevent)(struct device___114 *, struct kobj_uevent_env *);
	int (*probe)(struct device___114 *);
	int (*remove)(struct device___114 *);
	void (*shutdown)(struct device___114 *);
	int (*online)(struct device___114 *);
	int (*offline)(struct device___114 *);
	int (*suspend)(struct device___114 *, pm_message_t);
	int (*resume)(struct device___114 *);
	int (*num_vf)(struct device___114 *);
	int (*dma_configure)(struct device___114 *);
	const struct dev_pm_ops___114 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___114 {
	const char *name;
	struct bus_type___114 *bus;
	struct module___106 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___114 *);
	int (*remove)(struct device___114 *);
	void (*shutdown)(struct device___114 *);
	int (*suspend)(struct device___114 *, pm_message_t);
	int (*resume)(struct device___114 *);
	const struct attribute_group___113 **groups;
	const struct dev_pm_ops___114 *pm;
	void (*coredump)(struct device___114 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___114 {
	const char *name;
	const struct attribute_group___113 **groups;
	int (*uevent)(struct device___114 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___114 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___114 *);
	const struct dev_pm_ops___114 *pm;
};

struct class___114 {
	const char *name;
	struct module___106 *owner;
	const struct attribute_group___113 **class_groups;
	const struct attribute_group___113 **dev_groups;
	struct kobject___117 *dev_kobj;
	int (*dev_uevent)(struct device___114 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___114 *, umode_t *);
	void (*class_release)(struct class___114 *);
	void (*dev_release)(struct device___114 *);
	int (*shutdown_pre)(struct device___114 *);
	const struct kobj_ns_type_operations___9 *ns_type;
	const void * (*namespace)(struct device___114 *);
	const struct dev_pm_ops___114 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct device_attribute___7 {
	struct attribute attr;
	ssize_t (*show)(struct device___114 *, struct device_attribute___7 *, char *);
	ssize_t (*store)(struct device___114 *, struct device_attribute___7 *, const char *, size_t);
};

struct dma_map_ops___36 {
	void * (*alloc)(struct device___114 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___114 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___114 *, struct vm_area_struct___123 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___114 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___114 *, struct page___123 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___114 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___114 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___114 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___114 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___114 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___114 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide21;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___114 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___114 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___114 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___114 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___114 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___114 *, u64);
	u64 (*get_required_mask)(struct device___114 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___86;

struct fwnode_handle___86 {
	struct fwnode_handle___86 *secondary;
	const struct fwnode_operations___86 *ops;
};

struct property___41;

struct device_node___42 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___86 fwnode;
	struct property___41 *properties;
	struct property___41 *deadprops;
	struct device_node___42 *parent;
	struct device_node___42 *child;
	struct device_node___42 *sibling;
	struct kobject___117 kobj;
	long unsigned int _flags;
	void *data;
};

struct node___94 {
	struct device___114 dev;
};

struct fd___7 {
	struct file___123 *file;
	unsigned int flags;
};

typedef struct poll_table_struct___83 poll_table___9;

struct fwnode_reference_args___86;

struct fwnode_endpoint___86;

struct fwnode_operations___86 {
	struct fwnode_handle___86 * (*get)(struct fwnode_handle___86 *);
	void (*put)(struct fwnode_handle___86 *);
	bool (*device_is_available)(const struct fwnode_handle___86 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___86 *, const struct device___114 *);
	bool (*property_present)(const struct fwnode_handle___86 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___86 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___86 *, const char *, const char **, size_t);
	struct fwnode_handle___86 * (*get_parent)(const struct fwnode_handle___86 *);
	struct fwnode_handle___86 * (*get_next_child_node)(const struct fwnode_handle___86 *, struct fwnode_handle___86 *);
	struct fwnode_handle___86 * (*get_named_child_node)(const struct fwnode_handle___86 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___86 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___86 *);
	struct fwnode_handle___86 * (*graph_get_next_endpoint)(const struct fwnode_handle___86 *, struct fwnode_handle___86 *);
	struct fwnode_handle___86 * (*graph_get_remote_endpoint)(const struct fwnode_handle___86 *);
	struct fwnode_handle___86 * (*graph_get_port_parent)(struct fwnode_handle___86 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___86 *, struct fwnode_endpoint___86 *);
};

struct fwnode_endpoint___86 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___86 *local_fwnode;
};

struct fwnode_reference_args___86 {
	struct fwnode_handle___86 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct property___41 {
	char *name;
	int length;
	void *value;
	struct property___41 *next;
	long unsigned int _flags;
	struct bin_attribute___113 attr;
};

typedef int (*key_restrict_link_func_t___118)(struct key___118 *, const struct key_type *, const union key_payload *, struct key___118 *);

struct key_restriction___118;

struct key___118 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___123 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___118 *restrict_link;
};

struct key_restriction___118 {
	key_restrict_link_func_t___118 check;
	struct key___118 *key;
	struct key_type *keytype;
};

struct inet_frags___20;

struct netns_frags___20 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___20 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv4___20 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct sock *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock **tcp_sk;
	struct netns_frags___20 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct net_device___24;

struct sk_buff___23;

struct dst_ops___27 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___27 *);
	struct dst_entry___2 * (*check)(struct dst_entry___2 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___2 *);
	unsigned int (*mtu)(const struct dst_entry___2 *);
	u32 * (*cow_metrics)(struct dst_entry___2 *, long unsigned int);
	void (*destroy)(struct dst_entry___2 *);
	void (*ifdown)(struct dst_entry___2 *, struct net_device___24 *, int);
	struct dst_entry___2 * (*negative_advice)(struct dst_entry___2 *);
	void (*link_failure)(struct sk_buff___23 *);
	void (*update_pmtu)(struct dst_entry___2 *, struct sock *, struct sk_buff___23 *, u32);
	void (*redirect)(struct dst_entry___2 *, struct sock *, struct sk_buff___23 *);
	int (*local_out)(struct net___29 *, struct sock *, struct sk_buff___23 *);
	struct neighbour___2 * (*neigh_lookup)(const struct dst_entry___2 *, struct sk_buff___23 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___2 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___27 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___20 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___27 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct sock *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops *notifier_ops;
	struct fib_notifier_ops *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_nf_frag___20 {
	struct netns_frags___20 frags;
};

struct netns_xfrm___27 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___27 xfrm4_dst_ops;
	struct dst_ops___27 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct net___29 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___103 *user_ns;
	struct ucounts___103 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___9 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___24 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___20 ipv4;
	struct netns_ipv6___27 ipv6;
	struct netns_sctp___9 sctp;
	struct netns_nf nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___20 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock *nfnl;
	struct sock *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___27 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___19 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cgroup_namespace___99 {
	refcount_t count;
	struct ns_common___9 ns;
	struct user_namespace___103 *user_ns;
	struct ucounts___103 *ucounts;
	struct css_set___99 *root_cset;
};

struct proc_ns_operations___9 {
	const char *name;
	const char *real_ns_name;
	int type;
	struct ns_common___9 * (*get)(struct task_struct___123 *);
	void (*put)(struct ns_common___9 *);
	int (*install)(struct nsproxy___115 *, struct ns_common___9 *);
	struct user_namespace___103 * (*owner)(struct ns_common___9 *);
	struct ns_common___9 * (*get_parent)(struct ns_common___9 *);
};

struct ucounts___103 {
	struct hlist_node node;
	struct user_namespace___103 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct seq_operations___111 {
	void * (*start)(struct seq_file___113 *, loff_t *);
	void (*stop)(struct seq_file___113 *, void *);
	void * (*next)(struct seq_file___113 *, void *, loff_t *);
	int (*show)(struct seq_file___113 *, void *);
};

enum perf_branch_sample_type {
	PERF_SAMPLE_BRANCH_USER = 1,
	PERF_SAMPLE_BRANCH_KERNEL = 2,
	PERF_SAMPLE_BRANCH_HV = 4,
	PERF_SAMPLE_BRANCH_ANY = 8,
	PERF_SAMPLE_BRANCH_ANY_CALL = 16,
	PERF_SAMPLE_BRANCH_ANY_RETURN = 32,
	PERF_SAMPLE_BRANCH_IND_CALL = 64,
	PERF_SAMPLE_BRANCH_ABORT_TX = 128,
	PERF_SAMPLE_BRANCH_IN_TX = 256,
	PERF_SAMPLE_BRANCH_NO_TX = 512,
	PERF_SAMPLE_BRANCH_COND = 1024,
	PERF_SAMPLE_BRANCH_CALL_STACK = 2048,
	PERF_SAMPLE_BRANCH_IND_JUMP = 4096,
	PERF_SAMPLE_BRANCH_CALL = 8192,
	PERF_SAMPLE_BRANCH_NO_FLAGS = 16384,
	PERF_SAMPLE_BRANCH_NO_CYCLES = 32768,
	PERF_SAMPLE_BRANCH_TYPE_SAVE = 65536,
	PERF_SAMPLE_BRANCH_MAX = 131072,
};

enum perf_event_read_format {
	PERF_FORMAT_TOTAL_TIME_ENABLED = 1,
	PERF_FORMAT_TOTAL_TIME_RUNNING = 2,
	PERF_FORMAT_ID = 4,
	PERF_FORMAT_GROUP = 8,
	PERF_FORMAT_MAX = 16,
};

enum perf_event_ioc_flags {
	PERF_IOC_FLAG_GROUP = 1,
};

struct perf_event_header {
	__u32 type;
	__u16 misc;
	__u16 size;
};

struct perf_ns_link_info {
	__u64 dev;
	__u64 ino;
};

enum {
	NET_NS_INDEX = 0,
	UTS_NS_INDEX = 1,
	IPC_NS_INDEX = 2,
	PID_NS_INDEX = 3,
	USER_NS_INDEX = 4,
	MNT_NS_INDEX = 5,
	CGROUP_NS_INDEX = 6,
	NR_NAMESPACES = 7,
};

enum perf_event_type {
	PERF_RECORD_MMAP = 1,
	PERF_RECORD_LOST = 2,
	PERF_RECORD_COMM = 3,
	PERF_RECORD_EXIT = 4,
	PERF_RECORD_THROTTLE = 5,
	PERF_RECORD_UNTHROTTLE = 6,
	PERF_RECORD_FORK = 7,
	PERF_RECORD_READ = 8,
	PERF_RECORD_SAMPLE = 9,
	PERF_RECORD_MMAP2 = 10,
	PERF_RECORD_AUX = 11,
	PERF_RECORD_ITRACE_START = 12,
	PERF_RECORD_LOST_SAMPLES = 13,
	PERF_RECORD_SWITCH = 14,
	PERF_RECORD_SWITCH_CPU_WIDE = 15,
	PERF_RECORD_NAMESPACES = 16,
	PERF_RECORD_MAX = 17,
};

struct kernel_param_ops___103 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___103 *);
	int (*get)(char *, const struct kernel_param___103 *);
	void (*free)(void *);
};

struct kparam_array___103;

struct kernel_param___103 {
	const char *name;
	struct module___106 *mod;
	const struct kernel_param_ops___103 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___103 *arr;
	};
};

struct kparam_array___103 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___103 *ops;
	void *elem;
};

struct module_attribute___103 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___103 *, struct module_kobject___103 *, char *);
	ssize_t (*store)(struct module_attribute___103 *, struct module_kobject___103 *, const char *, size_t);
	void (*setup)(struct module___106 *, const char *);
	int (*test)(struct module___106 *);
	void (*free)(struct module___106 *);
};

struct trace_event_class___69;

struct bpf_prog_array___19;

struct trace_event_call___69 {
	struct list_head list;
	struct trace_event_class___69 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___13 event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___19 *prog_array;
	int (*perf_perm)(struct trace_event_call___69 *, struct perf_event___75 *);
};

struct bpf_map___99;

struct bpf_map_ops___99 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___99 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___99 *, struct file___123 *);
	void (*map_free)(struct bpf_map___99 *);
	int (*map_get_next_key)(struct bpf_map___99 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___99 *);
	void * (*map_lookup_elem)(struct bpf_map___99 *, void *);
	int (*map_update_elem)(struct bpf_map___99 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___99 *, void *);
	int (*map_push_elem)(struct bpf_map___99 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___99 *, void *);
	int (*map_peek_elem)(struct bpf_map___99 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___99 *, struct file___123 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___99 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___99 *, void *, struct seq_file___113 *);
	int (*map_check_btf)(const struct bpf_map___99 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___99 {
	const struct bpf_map_ops___99 *ops;
	struct bpf_map___99 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___118 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___20;

struct bpf_map_dev_ops___20 {
	int (*map_get_next_key)(struct bpf_offloaded_map___20 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___20 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___20 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___20 *, void *);
};

struct bpf_offloaded_map___20 {
	struct bpf_map___99 map;
	struct net_device___24 *netdev;
	const struct bpf_map_dev_ops___20 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

typedef rx_handler_result_t rx_handler_func_t___20(struct sk_buff___23 **);

typedef struct {
	struct net___29 *net;
} possible_net_t___21;

struct net_device_ops___20;

struct ethtool_ops___20;

struct xfrmdev_ops___20;

struct tlsdev_ops___20;

struct header_ops___20;

struct netdev_rx_queue___20;

struct mini_Qdisc___19;

struct netdev_queue___20;

struct Qdisc___19;

struct rtnl_link_ops___19;

struct dcbnl_rtnl_ops___20;

struct net_device___24 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___20 *netdev_ops;
	const struct ethtool_ops___20 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___2 *l3mdev_ops;
	const struct ndisc_ops___2 *ndisc_ops;
	const struct xfrmdev_ops___20 *xfrmdev_ops;
	const struct tlsdev_ops___20 *tlsdev_ops;
	const struct header_ops___20 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___116 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___2 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___20 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___19 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___20 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___19 *miniq_ingress;
	struct netdev_queue___20 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___20 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___19 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___19 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___20 = 0,
		NETREG_REGISTERED___20 = 1,
		NETREG_UNREGISTERING___20 = 2,
		NETREG_UNREGISTERED___20 = 3,
		NETREG_RELEASED___20 = 4,
		NETREG_DUMMY___20 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___20 = 0,
		RTNL_LINK_INITIALIZING___20 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___24 *);
	struct netpoll_info *npinfo;
	possible_net_t___21 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___114 dev;
	const struct attribute_group___113 *sysfs_groups[4];
	const struct attribute_group___113 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___19 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___20 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide37;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct bpf_prog_ops___19 {
	int (*test_run)(struct bpf_prog___19 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_aux___19;

struct bpf_prog___19 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___19 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

struct bpf_verifier_ops___19 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___19 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___19 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___19 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___19 *, u32 *);
};

struct bpf_prog_offload_ops___19 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___19 *);
	int (*translate)(struct bpf_prog___19 *);
	void (*destroy)(struct bpf_prog___19 *);
};

struct bpf_prog_offload___19 {
	struct bpf_prog___19 *prog;
	struct net_device___24 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___19 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___19 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___19 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___19 *ops;
	struct bpf_map___99 **used_maps;
	struct bpf_prog___19 *prog;
	struct user_struct___118 *user;
	u64 load_time;
	struct bpf_map___99 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___19 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___19 {
	struct bpf_prog___19 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___19 {
	struct callback_head rcu;
	struct bpf_prog_array_item___19 items[0];
};

struct cgroup_bpf___19 {
	struct bpf_prog_array___19 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___19 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___99;

typedef void (*kthread_work_func_t___99)(struct kthread_work___99 *);

struct kthread_worker___99;

struct kthread_work___99 {
	struct list_head node;
	kthread_work_func_t___99 func;
	struct kthread_worker___99 *worker;
	int canceling;
};

struct kthread_worker___99 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___123 *task;
	struct kthread_work___99 *current_work;
};

struct kthread_delayed_work___99 {
	struct kthread_work___99 work;
	struct timer_list timer;
};

struct psi_group___99 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___99 *poll_kworker;
	struct kthread_delayed_work___99 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___99 {
	struct kernfs_node___119 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___99;

struct cgroup_subsys_state___99 {
	struct cgroup___99 *cgroup;
	struct cgroup_subsys___99 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___99 *parent;
};

struct cgroup_root___99;

struct cgroup_rstat_cpu___99;

struct cgroup___99 {
	struct cgroup_subsys_state___99 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___119 *kn;
	struct cgroup_file___99 procs_file;
	struct cgroup_file___99 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___99 *subsys[13];
	struct cgroup_root___99 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___99 *dom_cgrp;
	struct cgroup_rstat_cpu___99 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___19 bpf;
	atomic_t congestion_count;
	struct cgroup___99 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___99 psi;
	int ancestor_ids[0];
};

struct cftype___99;

struct cgroup_subsys___99 {
	struct cgroup_subsys_state___99 * (*css_alloc)(struct cgroup_subsys_state___99 *);
	int (*css_online)(struct cgroup_subsys_state___99 *);
	void (*css_offline)(struct cgroup_subsys_state___99 *);
	void (*css_released)(struct cgroup_subsys_state___99 *);
	void (*css_free)(struct cgroup_subsys_state___99 *);
	void (*css_reset)(struct cgroup_subsys_state___99 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___99 *, int);
	int (*css_extra_stat_show)(struct seq_file___113 *, struct cgroup_subsys_state___99 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___123 *);
	void (*cancel_fork)(struct task_struct___123 *);
	void (*fork)(struct task_struct___123 *);
	void (*exit)(struct task_struct___123 *);
	void (*free)(struct task_struct___123 *);
	void (*bind)(struct cgroup_subsys_state___99 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___99 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___99 *dfl_cftypes;
	struct cftype___99 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___99 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___99 *updated_children;
	struct cgroup___99 *updated_next;
};

struct cgroup_root___99 {
	struct kernfs_root___119 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___99 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___99 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___99 *ss;
	struct list_head node;
	struct kernfs_ops___119 *kf_ops;
	int (*open)(struct kernfs_open_file___119 *);
	void (*release)(struct kernfs_open_file___119 *);
	u64 (*read_u64)(struct cgroup_subsys_state___99 *, struct cftype___99 *);
	s64 (*read_s64)(struct cgroup_subsys_state___99 *, struct cftype___99 *);
	int (*seq_show)(struct seq_file___113 *, void *);
	void * (*seq_start)(struct seq_file___113 *, loff_t *);
	void * (*seq_next)(struct seq_file___113 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___113 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___99 *, struct cftype___99 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___99 *, struct cftype___99 *, s64);
	ssize_t (*write)(struct kernfs_open_file___119 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___119 *, struct poll_table_struct___83 *);
};

struct perf_cpu_context___75;

struct pmu___75 {
	struct list_head entry;
	struct module___106 *module;
	struct device___114 *dev;
	const struct attribute_group___113 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___75 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___75 *);
	void (*pmu_disable)(struct pmu___75 *);
	int (*event_init)(struct perf_event___75 *);
	void (*event_mapped)(struct perf_event___75 *, struct mm_struct___122 *);
	void (*event_unmapped)(struct perf_event___75 *, struct mm_struct___122 *);
	int (*add)(struct perf_event___75 *, int);
	void (*del)(struct perf_event___75 *, int);
	void (*start)(struct perf_event___75 *, int);
	void (*stop)(struct perf_event___75 *, int);
	void (*read)(struct perf_event___75 *);
	void (*start_txn)(struct pmu___75 *, unsigned int);
	int (*commit_txn)(struct pmu___75 *);
	void (*cancel_txn)(struct pmu___75 *);
	int (*event_idx)(struct perf_event___75 *);
	void (*sched_task)(struct perf_event_context___75 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___75 *);
	int (*filter_match)(struct perf_event___75 *);
	int (*check_period)(struct perf_event___75 *, u64);
};

struct perf_cpu_context___75 {
	struct perf_event_context___75 ctx;
	struct perf_event_context___75 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___75 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

enum perf_addr_filter_action_t {
	PERF_ADDR_FILTER_ACTION_STOP = 0,
	PERF_ADDR_FILTER_ACTION_START = 1,
	PERF_ADDR_FILTER_ACTION_FILTER = 2,
};

struct perf_addr_filter {
	struct list_head entry;
	struct path___122 path;
	long unsigned int offset;
	long unsigned int size;
	enum perf_addr_filter_action_t action;
};

struct swevent_hlist {
	struct hlist_head heads[256];
	struct callback_head callback_head;
};

struct pmu_event_list {
	raw_spinlock_t lock;
	struct list_head list;
};

struct ring_buffer___2 {
	atomic_t refcount;
	struct callback_head callback_head;
	int nr_pages;
	int overwrite;
	int paused;
	atomic_t poll;
	local_t head;
	local_t nest;
	local_t events;
	local_t wakeup;
	local_t lost;
	long int watermark;
	long int aux_watermark;
	spinlock_t event_lock;
	struct list_head event_list;
	atomic_t mmap_count;
	long unsigned int mmap_locked;
	struct user_struct___118 *mmap_user;
	long int aux_head;
	local_t aux_nest;
	long int aux_wakeup;
	long unsigned int aux_pgoff;
	int aux_nr_pages;
	int aux_overwrite;
	atomic_t aux_mmap_count;
	long unsigned int aux_mmap_locked;
	void (*free_aux)(void *);
	atomic_t aux_refcount;
	void **aux_pages;
	void *aux_priv;
	struct perf_event_mmap_page *user_page;
	void *data_pages[0];
};

struct perf_cgroup___75 {
	struct cgroup_subsys_state___99 css;
	struct perf_cgroup_info *info;
};

struct perf_output_handle {
	struct perf_event___75 *event;
	struct ring_buffer___2 *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct bpf_perf_event_data_kern___2 {
	bpf_user_pt_regs_t *regs;
	struct perf_sample_data *data;
	struct perf_event___75 *event;
};

struct perf_pmu_events_attr___2 {
	struct device_attribute___7 attr;
	u64 id;
	const char *event_str;
};

struct trace_event_class___69 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___69 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___69 *);
	struct list_head * (*get_fields)(struct trace_event_call___69 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___69 *);
};

struct syscall_metadata___26 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___69 *enter_event;
	struct trace_event_call___69 *exit_event;
};

struct nf_bridge_info___20;

struct sk_buff___23 {
	union {
		struct {
			struct sk_buff___23 *next;
			struct sk_buff___23 *prev;
			union {
				struct net_device___24 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___3 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___23 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___20 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct pipe_buf_operations___33;

struct pipe_buffer___33 {
	struct page___123 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___33 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___33 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___33 *, struct pipe_buffer___33 *);
	void (*release)(struct pipe_inode_info___33 *, struct pipe_buffer___33 *);
	int (*steal)(struct pipe_inode_info___33 *, struct pipe_buffer___33 *);
	union {
		bool (*get)(struct pipe_inode_info___33 *, struct pipe_buffer___33 *);
		struct {
			void (*get)(struct pipe_inode_info___33 *, struct pipe_buffer___33 *);
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
};

struct nf_bridge_info___20 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___20 = 0,
		BRNF_PROTO_8021Q___20 = 1,
		BRNF_PROTO_PPPOE___20 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___24 *physindev;
	struct net_device___24 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

struct sk_buff_head___20 {
	struct sk_buff___23 *next;
	struct sk_buff___23 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct ethtool_ops___20 {
	int (*get_settings)(struct net_device___24 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___24 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___24 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___24 *);
	void (*get_regs)(struct net_device___24 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___24 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___24 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___24 *);
	void (*set_msglevel)(struct net_device___24 *, u32);
	int (*nway_reset)(struct net_device___24 *);
	u32 (*get_link)(struct net_device___24 *);
	int (*get_eeprom_len)(struct net_device___24 *);
	int (*get_eeprom)(struct net_device___24 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___24 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___24 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___24 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___24 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___24 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___24 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___24 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___24 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___24 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___24 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___24 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___24 *);
	void (*complete)(struct net_device___24 *);
	u32 (*get_priv_flags)(struct net_device___24 *);
	int (*set_priv_flags)(struct net_device___24 *, u32);
	int (*get_sset_count)(struct net_device___24 *, int);
	int (*get_rxnfc)(struct net_device___24 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___24 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___24 *, struct ethtool_flash *);
	int (*reset)(struct net_device___24 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___24 *);
	u32 (*get_rxfh_indir_size)(struct net_device___24 *);
	int (*get_rxfh)(struct net_device___24 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___24 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___24 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___24 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___24 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___24 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___24 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___24 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___24 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___24 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___24 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___24 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___24 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___24 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___24 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___24 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___24 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___24 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___24 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___24 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___24 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___24 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	int (*get_fecparam)(struct net_device___24 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___24 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___24 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___24 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___24 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___20;

struct inet_frags___20 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___20 *, const void *);
	void (*destructor)(struct inet_frag_queue___20 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___20 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___23 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___23 *fragments_tail;
	struct sk_buff___23 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___20 *net;
	struct callback_head rcu;
};

struct pernet_operations___20 {
	struct list_head list;
	int (*init)(struct net___29 *);
	void (*exit)(struct net___29 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___20 {
	int (*ieee_getets)(struct net_device___24 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___24 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___24 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___24 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___24 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___24 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___24 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___24 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___24 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___24 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___24 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___24 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___24 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___24 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___24 *);
	u8 (*setstate)(struct net_device___24 *, u8);
	void (*getpermhwaddr)(struct net_device___24 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___24 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___24 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___24 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___24 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___24 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___24 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___24 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___24 *, int, u8 *);
	void (*setpfccfg)(struct net_device___24 *, int, u8);
	void (*getpfccfg)(struct net_device___24 *, int, u8 *);
	u8 (*setall)(struct net_device___24 *);
	u8 (*getcap)(struct net_device___24 *, int, u8 *);
	int (*getnumtcs)(struct net_device___24 *, int, u8 *);
	int (*setnumtcs)(struct net_device___24 *, int, u8);
	u8 (*getpfcstate)(struct net_device___24 *);
	void (*setpfcstate)(struct net_device___24 *, u8);
	void (*getbcncfg)(struct net_device___24 *, int, u32 *);
	void (*setbcncfg)(struct net_device___24 *, int, u32);
	void (*getbcnrp)(struct net_device___24 *, int, u8 *);
	void (*setbcnrp)(struct net_device___24 *, int, u8);
	int (*setapp)(struct net_device___24 *, u8, u16, u8);
	int (*getapp)(struct net_device___24 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___24 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___24 *, int, u8);
	u8 (*getdcbx)(struct net_device___24 *);
	u8 (*setdcbx)(struct net_device___24 *, u8);
	int (*peer_getappinfo)(struct net_device___24 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___24 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___24 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___24 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___24 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___24 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct xdp_rxq_info___20 {
	struct net_device___24 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___20 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___24 *dev_rx;
};

struct netlink_callback___20 {
	struct sk_buff___23 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___20 *);
	int (*dump)(struct sk_buff___23 *, struct netlink_callback___20 *);
	int (*done)(struct netlink_callback___20 *);
	void *data;
	struct module___106 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___20 {
	int (*create)(struct sk_buff___23 *, struct net_device___24 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___23 *, unsigned char *);
	int (*cache)(const struct neighbour___2 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___24 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___20 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___20 *, int);
	int poll_owner;
	struct net_device___24 *dev;
	struct sk_buff___23 *gro_list;
	struct sk_buff___23 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___20 {
	struct net_device___24 *dev;
	struct Qdisc___19 *qdisc;
	struct Qdisc___19 *qdisc_sleeping;
	struct kobject___117 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___24 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___19 {
	struct sk_buff___23 *head;
	struct sk_buff___23 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___19;

struct Qdisc___19 {
	int (*enqueue)(struct sk_buff___23 *, struct Qdisc___19 *, struct sk_buff___23 **);
	struct sk_buff___23 * (*dequeue)(struct Qdisc___19 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___19 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___20 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___20 gso_skb;
	struct qdisc_skb_head___19 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___19 *next_sched;
	struct sk_buff_head___20 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___20 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___117 kobj;
	struct net_device___24 *dev;
	long: 64;
	struct xdp_rxq_info___20 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___20)(struct net_device___24 *, struct sk_buff___23 *, struct net_device___24 *);

struct netdev_bpf___20 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___19 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___19 *prog;
			const struct bpf_prog_offload_ops___19 *ops;
		} verifier;
		struct {
			struct bpf_prog___19 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___20 *offmap;
		};
		struct {
			struct xdp_umem *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___20 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___23 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___20 {
	int (*tls_dev_add)(struct net_device___24 *, struct sock *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___24 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___24 *, struct sock *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___20 {
	int (*ndo_init)(struct net_device___24 *);
	void (*ndo_uninit)(struct net_device___24 *);
	int (*ndo_open)(struct net_device___24 *);
	int (*ndo_stop)(struct net_device___24 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___23 *, struct net_device___24 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___23 *, struct net_device___24 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___24 *, struct sk_buff___23 *, struct net_device___24 *, select_queue_fallback_t___20);
	void (*ndo_change_rx_flags)(struct net_device___24 *, int);
	void (*ndo_set_rx_mode)(struct net_device___24 *);
	int (*ndo_set_mac_address)(struct net_device___24 *, void *);
	int (*ndo_validate_addr)(struct net_device___24 *);
	int (*ndo_do_ioctl)(struct net_device___24 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___24 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___24 *, int);
	int (*ndo_neigh_setup)(struct net_device___24 *, struct neigh_parms___3 *);
	void (*ndo_tx_timeout)(struct net_device___24 *);
	void (*ndo_get_stats64)(struct net_device___24 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___24 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___24 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___24 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___24 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___24 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___24 *);
	int (*ndo_netpoll_setup)(struct net_device___24 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___24 *);
	int (*ndo_set_vf_mac)(struct net_device___24 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___24 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___24 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___24 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___24 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___24 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___24 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___24 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___24 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___24 *, int, struct sk_buff___23 *);
	int (*ndo_set_vf_guid)(struct net_device___24 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___24 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___24 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___24 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___24 *, const struct sk_buff___23 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___24 *, struct net_device___24 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___24 *, struct net_device___24 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___24 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___24 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___24 *, struct neighbour___2 *);
	void (*ndo_neigh_destroy)(struct net_device___24 *, struct neighbour___2 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___24 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___24 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___24 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___23 *, struct netlink_callback___20 *, struct net_device___24 *, struct net_device___24 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___24 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___24 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide35;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___23 *, u32, u32, struct net_device___24 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___24 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___24 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___24 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___24 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___24 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___24 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___24 *, struct net_device___24 *);
	void (*ndo_dfwd_del_station)(struct net_device___24 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___24 *);
	int (*ndo_set_tx_maxrate)(struct net_device___24 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___24 *);
	int (*ndo_change_proto_down)(struct net_device___24 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___24 *, struct sk_buff___23 *);
	void (*ndo_set_rx_headroom)(struct net_device___24 *, int);
	int (*ndo_bpf)(struct net_device___24 *, struct netdev_bpf___20 *);
	int (*ndo_xdp_xmit)(struct net_device___24 *, int, struct xdp_frame___20 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___24 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___24 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide36;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct tcf_proto___19;

struct mini_Qdisc___19 {
	struct tcf_proto___19 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___19 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___24 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___29 *, struct net_device___24 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___24 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___24 *, struct list_head *);
	size_t (*get_size)(const struct net_device___24 *);
	int (*fill_info)(struct sk_buff___23 *, const struct net_device___24 *);
	size_t (*get_xstats_size)(const struct net_device___24 *);
	int (*fill_xstats)(struct sk_buff___23 *, const struct net_device___24 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___24 *, struct net_device___24 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___24 *, const struct net_device___24 *);
	int (*fill_slave_info)(struct sk_buff___23 *, const struct net_device___24 *, const struct net_device___24 *);
	struct net___29 * (*get_link_net)(const struct net_device___24 *);
	size_t (*get_linkxstats_size)(const struct net_device___24 *, int);
	int (*fill_linkxstats)(struct sk_buff___23 *, const struct net_device___24 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___20 {
	struct list_head poll_list;
	struct sk_buff_head___20 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___20 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___19 *output_queue;
	struct Qdisc___19 **output_queue_tailp;
	struct sk_buff___23 *completion_queue;
	struct sk_buff_head___20 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___20 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___20 input_pkt_queue;
	struct napi_struct___20 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct gnet_dump___19 {
	spinlock_t *lock;
	struct sk_buff___23 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___19;

struct Qdisc_ops___19 {
	struct Qdisc_ops___19 *next;
	const struct Qdisc_class_ops___19 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___23 *, struct Qdisc___19 *, struct sk_buff___23 **);
	struct sk_buff___23 * (*dequeue)(struct Qdisc___19 *);
	struct sk_buff___23 * (*peek)(struct Qdisc___19 *);
	int (*init)(struct Qdisc___19 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___19 *);
	void (*destroy)(struct Qdisc___19 *);
	int (*change)(struct Qdisc___19 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___19 *);
	int (*change_tx_queue_len)(struct Qdisc___19 *, unsigned int);
	int (*dump)(struct Qdisc___19 *, struct sk_buff___23 *);
	int (*dump_stats)(struct Qdisc___19 *, struct gnet_dump___19 *);
	void (*ingress_block_set)(struct Qdisc___19 *, u32);
	void (*egress_block_set)(struct Qdisc___19 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___19 *);
	u32 (*egress_block_get)(struct Qdisc___19 *);
	struct module___106 *owner;
};

struct tcf_block___19;

struct Qdisc_class_ops___19 {
	unsigned int flags;
	struct netdev_queue___20 * (*select_queue)(struct Qdisc___19 *, struct tcmsg *);
	int (*graft)(struct Qdisc___19 *, long unsigned int, struct Qdisc___19 *, struct Qdisc___19 **, struct netlink_ext_ack *);
	struct Qdisc___19 * (*leaf)(struct Qdisc___19 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___19 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___19 *, u32);
	int (*change)(struct Qdisc___19 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___19 *, long unsigned int);
	void (*walk)(struct Qdisc___19 *, struct qdisc_walker *);
	struct tcf_block___19 * (*tcf_block)(struct Qdisc___19 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___19 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___19 *, long unsigned int);
	int (*dump)(struct Qdisc___19 *, long unsigned int, struct sk_buff___23 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___19 *, long unsigned int, struct gnet_dump___19 *);
};

struct tcf_chain___19;

struct tcf_block___19 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___29 *net;
	struct Qdisc___19 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___19 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___19;

struct tcf_proto_ops___19;

struct tcf_proto___19 {
	struct tcf_proto___19 *next;
	void *root;
	int (*classify)(struct sk_buff___23 *, const struct tcf_proto___19 *, struct tcf_result___19 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___19 *ops;
	struct tcf_chain___19 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___19 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___19 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___19 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___23 *, const struct tcf_proto___19 *, struct tcf_result___19 *);
	int (*init)(struct tcf_proto___19 *);
	void (*destroy)(struct tcf_proto___19 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___19 *, u32);
	void (*put)(struct tcf_proto___19 *, void *);
	int (*change)(struct net___29 *, struct sk_buff___23 *, struct tcf_proto___19 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___19 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___19 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___19 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___29 *, struct tcf_chain___19 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___29 *, struct tcf_proto___19 *, void *, struct sk_buff___23 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___23 *, struct net___29 *, void *);
	struct module___106 *owner;
	int flags;
};

struct tcf_chain___19 {
	struct mutex filter_chain_lock;
	struct tcf_proto___19 *filter_chain;
	struct list_head list;
	struct tcf_block___19 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___19 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct bpf_redirect_info___19 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___99 *map;
	struct bpf_map___99 *map_to_flush;
	u32 kern_flags;
};

typedef int (*remote_function_f)(void *);

struct remote_function_call {
	struct task_struct___123 *p;
	remote_function_f func;
	void *info;
	int ret;
};

typedef void (*event_f)(struct perf_event___75 *, struct perf_cpu_context___75 *, struct perf_event_context___75 *, void *);

struct event_function_struct {
	struct perf_event___75 *event;
	event_f func;
	void *data;
};

enum event_type_t {
	EVENT_FLEXIBLE = 1,
	EVENT_PINNED = 2,
	EVENT_TIME = 4,
	EVENT_CPU = 8,
	EVENT_ALL = 3,
};

struct stop_event_data {
	struct perf_event___75 *event;
	unsigned int restart;
};

struct sched_in_data {
	struct perf_event_context___75 *ctx;
	struct perf_cpu_context___75 *cpuctx;
	int can_add_hw;
};

struct perf_read_data {
	struct perf_event___75 *event;
	bool group;
	int ret;
};

struct perf_read_event {
	struct perf_event_header header;
	u32 pid;
	u32 tid;
};

typedef void perf_iterate_f(struct perf_event___75 *, void *);

struct remote_output {
	struct ring_buffer___2 *rb;
	int err;
};

struct perf_task_event {
	struct task_struct___123 *task;
	struct perf_event_context___75 *task_ctx;
	struct {
		struct perf_event_header header;
		u32 pid;
		u32 ppid;
		u32 tid;
		u32 ptid;
		u64 time;
	} event_id;
};

struct perf_comm_event {
	struct task_struct___123 *task;
	char *comm;
	int comm_size;
	struct {
		struct perf_event_header header;
		u32 pid;
		u32 tid;
	} event_id;
};

struct perf_namespaces_event {
	struct task_struct___123 *task;
	struct {
		struct perf_event_header header;
		u32 pid;
		u32 tid;
		u64 nr_namespaces;
		struct perf_ns_link_info link_info[7];
	} event_id;
};

struct perf_mmap_event {
	struct vm_area_struct___123 *vma;
	const char *file_name;
	int file_size;
	int maj;
	int min;
	u64 ino;
	u64 ino_generation;
	u32 prot;
	u32 flags;
	struct {
		struct perf_event_header header;
		u32 pid;
		u32 tid;
		u64 start;
		u64 len;
		u64 pgoff;
	} event_id;
};

struct perf_switch_event {
	struct task_struct___123 *task;
	struct task_struct___123 *next_prev;
	struct {
		struct perf_event_header header;
		u32 next_prev_pid;
		u32 next_prev_tid;
	} event_id;
};

struct swevent_htable {
	struct swevent_hlist *swevent_hlist;
	struct mutex hlist_mutex;
	int hlist_refcount;
	int recursion[4];
};

enum perf_probe_config {
	PERF_PROBE_CONFIG_IS_RETPROBE = 1,
};

enum {
	IF_ACT_NONE = 4294967295,
	IF_ACT_FILTER = 0,
	IF_ACT_START = 1,
	IF_ACT_STOP = 2,
	IF_SRC_FILE = 3,
	IF_SRC_KERNEL = 4,
	IF_SRC_FILEADDR = 5,
	IF_SRC_KERNELADDR = 6,
};

enum {
	IF_STATE_ACTION = 0,
	IF_STATE_SOURCE = 1,
	IF_STATE_END = 2,
};

struct perf_aux_event {
	struct perf_event_header header;
	u32 pid;
	u32 tid;
};

struct perf_aux_event___2 {
	struct perf_event_header header;
	u64 offset;
	u64 size;
	u64 flags;
};

struct module___107;

struct file___124;

struct kiocb___124;

struct poll_table_struct___84;

struct vm_area_struct___124;

struct inode___125;

struct file_lock___124;

struct page___124;

struct seq_file___114;

struct file_operations___124 {
	struct module___107 *owner;
	loff_t (*llseek)(struct file___124 *, loff_t, int);
	ssize_t (*read)(struct file___124 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___124 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___124 *, struct iov_iter___52 *);
	ssize_t (*write_iter)(struct kiocb___124 *, struct iov_iter___52 *);
	int (*iopoll)(struct kiocb___124 *, bool);
	int (*iterate)(struct file___124 *, struct dir_context *);
	int (*iterate_shared)(struct file___124 *, struct dir_context *);
	__poll_t (*poll)(struct file___124 *, struct poll_table_struct___84 *);
	long int (*unlocked_ioctl)(struct file___124 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___124 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___124 *, struct vm_area_struct___124 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___125 *, struct file___124 *);
	int (*flush)(struct file___124 *, fl_owner_t);
	int (*release)(struct inode___125 *, struct file___124 *);
	int (*fsync)(struct file___124 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___124 *, int);
	int (*lock)(struct file___124 *, int, struct file_lock___124 *);
	ssize_t (*sendpage)(struct file___124 *, struct page___124 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___124 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___124 *, int, struct file_lock___124 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___124 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___124 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___124 *, long int, struct file_lock___124 **, void **);
	long int (*fallocate)(struct file___124 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___114 *, struct file___124 *);
	ssize_t (*copy_file_range)(struct file___124 *, loff_t, struct file___124 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___124 *, loff_t, struct file___124 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___124 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___123 {
	u64 seqnum;
	struct vm_area_struct___124 *vmas[4];
};

struct page_frag___123 {
	struct page___124 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___76;

struct debug_info___76 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___76 *hbp_break[16];
	struct perf_event___76 *hbp_watch[16];
};

struct thread_struct___76 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___76 debug;
	long: 64;
};

struct mm_struct___123;

struct pid___100;

struct cred___119;

struct nsproxy___116;

struct signal_struct___113;

struct css_set___100;

struct perf_event_context___76;

struct vm_struct___93;

struct task_struct___124 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___124 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___123 *mm;
	struct mm_struct___123 *active_mm;
	struct vmacache___123 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___124 *real_parent;
	struct task_struct___124 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___124 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___100 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___100 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___100 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___119 *ptracer_cred;
	const struct cred___119 *real_cred;
	const struct cred___119 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___116 *nsproxy;
	struct signal_struct___113 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___124 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___17 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___100 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___76 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___123 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___124 *oom_reaper_list;
	struct vm_struct___93 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___76 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct secondary_data___124 {
	void *stack;
	struct task_struct___124 *task;
	long int status;
};

struct hw_perf_event___76 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___124 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___76)(struct perf_event___76 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___76;

struct ring_buffer___3;

struct fasync_struct___123;

struct pid_namespace___100;

struct perf_cgroup___76;

struct perf_event___76 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___76 *group_leader;
	struct pmu___76 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___76 hw;
	struct perf_event_context___76 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___76 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___124 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer___3 *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___123 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___76 *);
	struct callback_head callback_head;
	struct pid_namespace___100 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___76 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___76 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___5 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___76 *cgrp;
	struct list_head sb_list;
};

struct dentry_operations___123;

struct super_block___124;

struct dentry___124 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___124 *d_parent;
	struct qstr d_name;
	struct inode___125 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___123 *d_op;
	struct super_block___124 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct rw_semaphore___124 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___124 *owner;
};

struct address_space_operations___123;

struct address_space___123 {
	struct inode___125 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___124 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___123 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___123;

struct block_device___124;

struct inode___125 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___123 *i_op;
	struct super_block___124 *i_sb;
	struct address_space___123 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___124 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___124 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___123 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___124 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___123;

struct dentry_operations___123 {
	int (*d_revalidate)(struct dentry___124 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___124 *, unsigned int);
	int (*d_hash)(const struct dentry___124 *, struct qstr *);
	int (*d_compare)(const struct dentry___124 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___124 *);
	int (*d_init)(struct dentry___124 *);
	void (*d_release)(struct dentry___124 *);
	void (*d_prune)(struct dentry___124 *);
	void (*d_iput)(struct dentry___124 *, struct inode___125 *);
	char * (*d_dname)(struct dentry___124 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___123 *);
	int (*d_manage)(const struct path___123 *, bool);
	struct dentry___124 * (*d_real)(struct dentry___124 *, const struct inode___125 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___123;

struct mem_dqinfo___123 {
	struct quota_format_type___123 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___123;

struct quota_info___123 {
	unsigned int flags;
	struct rw_semaphore___124 dqio_sem;
	struct inode___125 *files[3];
	struct mem_dqinfo___123 info[3];
	const struct quota_format_ops___123 *ops[3];
};

struct rcuwait___123 {
	struct task_struct___124 *task;
};

struct percpu_rw_semaphore___123 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___124 rw_sem;
	struct rcuwait___123 writer;
	int readers_block;
};

struct sb_writers___123 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___123 rw_sem[3];
};

struct file_system_type___123;

struct super_operations___123;

struct dquot_operations___123;

struct quotactl_ops___123;

struct user_namespace___104;

struct super_block___124 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___123 *s_type;
	const struct super_operations___123 *s_op;
	const struct dquot_operations___123 *dq_op;
	const struct quotactl_ops___123 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___124 *s_root;
	struct rw_semaphore___124 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___124 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___123 s_dquot;
	struct sb_writers___123 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___123 *s_d_op;
	int cleancache_poolid;
	struct shrinker___40 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___104 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct path___123 {
	struct vfsmount *mnt;
	struct dentry___124 *dentry;
};

struct key___119;

struct ucounts___104;

struct user_namespace___104 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___104 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___9 ns;
	long unsigned int flags;
	struct key___119 *persistent_keyring_register;
	struct rw_semaphore___124 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___104 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___124 *pgtable_t___123;

struct dev_pagemap___121;

struct page___124 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___123 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___124 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___123 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___123 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___121 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___123;

struct lruvec___123 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___123 *pgdat;
};

struct zone___123 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___123 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___123 {
	struct zone___123 *zone;
	int zone_idx;
};

struct zonelist___123 {
	struct zoneref___123 _zonerefs[25];
};

struct pglist_data___123 {
	struct zone___123 node_zones[3];
	struct zonelist___123 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___124 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___124 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___123 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___123 {
	struct rw_semaphore___124 rwsem;
	struct notifier_block *head;
};

struct upid___100 {
	int nr;
	struct pid_namespace___100 *ns;
};

struct pid_namespace___100 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___124 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___100 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___124 *proc_self;
	struct dentry___124 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___104 *user_ns;
	struct ucounts___104 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___9 ns;
};

struct pid___100 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___100 numbers[1];
};

struct vm_operations_struct___121;

struct vm_area_struct___124 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___124 *vm_next;
	struct vm_area_struct___124 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___123 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___121 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___124 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___123;

struct mm_struct___123 {
	struct {
		struct vm_area_struct___124 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___124 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___124 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___123 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___124 *owner;
		struct user_namespace___104 *user_ns;
		struct file___124 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___123 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___121)(struct vm_area_struct___124 *, long unsigned int, const struct page___124 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___121)(struct page___124 *, void *);

struct device___115;

struct dev_pagemap___121 {
	dev_page_fault_t___121 page_fault;
	dev_page_free_t___121 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___115 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct fown_struct___100 {
	rwlock_t lock;
	struct pid___100 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___124 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___123 f_path;
	struct inode___125 *f_inode;
	const struct file_operations___124 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___100 f_owner;
	const struct cred___119 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___123 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___121;

struct vm_operations_struct___121 {
	void (*open)(struct vm_area_struct___124 *);
	void (*close)(struct vm_area_struct___124 *);
	int (*split)(struct vm_area_struct___124 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___124 *);
	vm_fault_t (*fault)(struct vm_fault___121 *);
	vm_fault_t (*huge_fault)(struct vm_fault___121 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___121 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___124 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___121 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___121 *);
	int (*access)(struct vm_area_struct___124 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___124 *);
	int (*set_policy)(struct vm_area_struct___124 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___124 *, long unsigned int);
	struct page___124 * (*find_special_page)(struct vm_area_struct___124 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___123 {
	struct task_struct___124 *task;
	struct core_thread___123 *next;
};

struct core_state___123 {
	atomic_t nr_threads;
	struct core_thread___123 dumper;
	struct completion startup;
};

struct vm_fault___121 {
	struct vm_area_struct___124 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___124 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___124 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___123 prealloc_pte;
};

struct user_struct___119 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___119 *uid_keyring;
	struct key___119 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___119 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___119 *session_keyring;
	struct key___119 *process_keyring;
	struct key___119 *thread_keyring;
	struct key___119 *request_key_auth;
	void *security;
	struct user_struct___119 *user;
	struct user_namespace___104 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___100;

struct nsproxy___116 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___100 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___100 *cgroup_ns;
};

struct signal_struct___113 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___124 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___124 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___100 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___100 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___123 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___100 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___100;

struct cgroup___100;

struct css_set___100 {
	struct cgroup_subsys_state___100 *subsys[13];
	refcount_t refcount;
	struct css_set___100 *dom_cset;
	struct cgroup___100 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___100 *mg_src_cgrp;
	struct cgroup___100 *mg_dst_cgrp;
	struct css_set___100 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___76 {
	struct pmu___76 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___124 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___76 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___93 {
	struct vm_struct___93 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___124 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___113 {
	struct task_struct___124 task;
	long unsigned int stack[8192];
};

struct kiocb___124 {
	struct file___124 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___124 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___124 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___124 *ia_file;
};

struct dquot___123 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___124 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___123 {
	int qf_fmt_id;
	const struct quota_format_ops___123 *qf_ops;
	struct module___107 *qf_owner;
	struct quota_format_type___123 *qf_next;
};

struct quota_format_ops___123 {
	int (*check_quota_file)(struct super_block___124 *, int);
	int (*read_file_info)(struct super_block___124 *, int);
	int (*write_file_info)(struct super_block___124 *, int);
	int (*free_file_info)(struct super_block___124 *, int);
	int (*read_dqblk)(struct dquot___123 *);
	int (*commit_dqblk)(struct dquot___123 *);
	int (*release_dqblk)(struct dquot___123 *);
	int (*get_next_id)(struct super_block___124 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___123 {
	int (*write_dquot)(struct dquot___123 *);
	struct dquot___123 * (*alloc_dquot)(struct super_block___124 *, int);
	void (*destroy_dquot)(struct dquot___123 *);
	int (*acquire_dquot)(struct dquot___123 *);
	int (*release_dquot)(struct dquot___123 *);
	int (*mark_dirty)(struct dquot___123 *);
	int (*write_info)(struct super_block___124 *, int);
	qsize_t * (*get_reserved_space)(struct inode___125 *);
	int (*get_projid)(struct inode___125 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___125 *, qsize_t *);
	int (*get_next_id)(struct super_block___124 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___123 {
	int (*quota_on)(struct super_block___124 *, int, int, const struct path___123 *);
	int (*quota_off)(struct super_block___124 *, int);
	int (*quota_enable)(struct super_block___124 *, unsigned int);
	int (*quota_disable)(struct super_block___124 *, unsigned int);
	int (*quota_sync)(struct super_block___124 *, int);
	int (*set_info)(struct super_block___124 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___124 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___124 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___124 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___124 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___124 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___117;

struct kobj_type___117;

struct kernfs_node___120;

struct kobject___118 {
	const char *name;
	struct list_head entry;
	struct kobject___118 *parent;
	struct kset___117 *kset;
	struct kobj_type___117 *ktype;
	struct kernfs_node___120 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___104 {
	struct kobject___118 kobj;
	struct module___107 *mod;
	struct kobject___118 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___104 {
	struct module___107 *mod;
	struct latch_tree_node node;
};

struct module_layout___104 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___104 mtn;
};

struct module_attribute___104;

struct kernel_param___104;

struct module___107 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___104 mkobj;
	struct module_attribute___104 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___118 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___104 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___104 core_layout;
	struct module_layout___104 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___123 {
	int (*writepage)(struct page___124 *, struct writeback_control___3 *);
	int (*readpage)(struct file___124 *, struct page___124 *);
	int (*writepages)(struct address_space___123 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___124 *);
	int (*readpages)(struct file___124 *, struct address_space___123 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___124 *, struct address_space___123 *, loff_t, unsigned int, unsigned int, struct page___124 **, void **);
	int (*write_end)(struct file___124 *, struct address_space___123 *, loff_t, unsigned int, unsigned int, struct page___124 *, void *);
	sector_t (*bmap)(struct address_space___123 *, sector_t);
	void (*invalidatepage)(struct page___124 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___124 *, gfp_t);
	void (*freepage)(struct page___124 *);
	ssize_t (*direct_IO)(struct kiocb___124 *, struct iov_iter___52 *);
	int (*migratepage)(struct address_space___123 *, struct page___124 *, struct page___124 *, enum migrate_mode);
	bool (*isolate_page)(struct page___124 *, isolate_mode_t);
	void (*putback_page)(struct page___124 *);
	int (*launder_page)(struct page___124 *);
	int (*is_partially_uptodate)(struct page___124 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___124 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___123 *, struct page___124 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___124 *, sector_t *);
	void (*swap_deactivate)(struct file___124 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___124 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___125 *bd_inode;
	struct super_block___124 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___124 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___123 {
	struct dentry___124 * (*lookup)(struct inode___125 *, struct dentry___124 *, unsigned int);
	const char * (*get_link)(struct dentry___124 *, struct inode___125 *, struct delayed_call *);
	int (*permission)(struct inode___125 *, int);
	struct posix_acl * (*get_acl)(struct inode___125 *, int);
	int (*readlink)(struct dentry___124 *, char *, int);
	int (*create)(struct inode___125 *, struct dentry___124 *, umode_t, bool);
	int (*link)(struct dentry___124 *, struct inode___125 *, struct dentry___124 *);
	int (*unlink)(struct inode___125 *, struct dentry___124 *);
	int (*symlink)(struct inode___125 *, struct dentry___124 *, const char *);
	int (*mkdir)(struct inode___125 *, struct dentry___124 *, umode_t);
	int (*rmdir)(struct inode___125 *, struct dentry___124 *);
	int (*mknod)(struct inode___125 *, struct dentry___124 *, umode_t, dev_t);
	int (*rename)(struct inode___125 *, struct dentry___124 *, struct inode___125 *, struct dentry___124 *, unsigned int);
	int (*setattr)(struct dentry___124 *, struct iattr___124 *);
	int (*getattr)(const struct path___123 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___124 *, char *, size_t);
	int (*fiemap)(struct inode___125 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___125 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___125 *, struct dentry___124 *, struct file___124 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___125 *, struct dentry___124 *, umode_t);
	int (*set_acl)(struct inode___125 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___123 {
	void (*fl_copy_lock)(struct file_lock___124 *, struct file_lock___124 *);
	void (*fl_release_private)(struct file_lock___124 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___123;

struct file_lock___124 {
	struct file_lock___124 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___124 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___123 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___123 *fl_ops;
	const struct lock_manager_operations___123 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___123 {
	int (*lm_compare_owner)(struct file_lock___124 *, struct file_lock___124 *);
	long unsigned int (*lm_owner_key)(struct file_lock___124 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___124 *);
	int (*lm_grant)(struct file_lock___124 *, int);
	bool (*lm_break)(struct file_lock___124 *);
	int (*lm_change)(struct file_lock___124 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___124 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___123 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___123 *fa_next;
	struct file___124 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___123 {
	const char *name;
	int fs_flags;
	struct dentry___124 * (*mount)(struct file_system_type___123 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___124 *);
	struct module___107 *owner;
	struct file_system_type___123 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___123 {
	struct inode___125 * (*alloc_inode)(struct super_block___124 *);
	void (*destroy_inode)(struct inode___125 *);
	void (*dirty_inode)(struct inode___125 *, int);
	int (*write_inode)(struct inode___125 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___125 *);
	void (*evict_inode)(struct inode___125 *);
	void (*put_super)(struct super_block___124 *);
	int (*sync_fs)(struct super_block___124 *, int);
	int (*freeze_super)(struct super_block___124 *);
	int (*freeze_fs)(struct super_block___124 *);
	int (*thaw_super)(struct super_block___124 *);
	int (*unfreeze_fs)(struct super_block___124 *);
	int (*statfs)(struct dentry___124 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___124 *, int *, char *);
	void (*umount_begin)(struct super_block___124 *);
	int (*show_options)(struct seq_file___114 *, struct dentry___124 *);
	int (*show_devname)(struct seq_file___114 *, struct dentry___124 *);
	int (*show_path)(struct seq_file___114 *, struct dentry___124 *);
	int (*show_stats)(struct seq_file___114 *, struct dentry___124 *);
	ssize_t (*quota_read)(struct super_block___124 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___124 *, int, const char *, size_t, loff_t);
	struct dquot___123 ** (*get_dquots)(struct inode___125 *);
	int (*bdev_try_to_free_page)(struct super_block___124 *, struct page___124 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___124 *, struct shrink_control___40 *);
	long int (*free_cached_objects)(struct super_block___124 *, struct shrink_control___40 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___83)(struct file___124 *, wait_queue_head_t *, struct poll_table_struct___84 *);

struct poll_table_struct___84 {
	poll_queue_proc___83 _qproc;
	__poll_t _key;
};

struct seq_operations___112;

struct seq_file___114 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___112 *op;
	int poll_event;
	const struct file___124 *file;
	void *private;
};

struct dev_pm_info___115 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___115 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___115;

struct bus_type___115;

struct device_driver___115;

struct dev_pm_domain___115;

struct class___115;

struct attribute_group___114;

struct device___115 {
	struct device___115 *parent;
	struct device_private *p;
	struct kobject___118 kobj;
	const char *init_name;
	const struct device_type___115 *type;
	struct mutex mutex;
	struct bus_type___115 *bus;
	struct device_driver___115 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___115 power;
	struct dev_pm_domain___115 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___115 *class;
	const struct attribute_group___114 **groups;
	void (*release)(struct device___115 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct kobj_attribute___118 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___118 *, struct kobj_attribute___118 *, char *);
	ssize_t (*store)(struct kobject___118 *, struct kobj_attribute___118 *, const char *, size_t);
};

typedef void compound_page_dtor___121(struct page___124 *);

struct cgroup_namespace___100 {
	refcount_t count;
	struct ns_common___9 ns;
	struct user_namespace___104 *user_ns;
	struct ucounts___104 *ucounts;
	struct css_set___100 *root_cset;
};

struct ucounts___104 {
	struct hlist_node node;
	struct user_namespace___104 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct kernfs_root___120;

struct kernfs_elem_dir___120 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___120 *root;
};

struct kernfs_syscall_ops___120;

struct kernfs_root___120 {
	struct kernfs_node___120 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___120 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___120 {
	struct kernfs_node___120 *target_kn;
};

struct kernfs_ops___120;

struct kernfs_elem_attr___120 {
	const struct kernfs_ops___120 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___120 *notify_next;
};

struct kernfs_node___120 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___120 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___120 dir;
		struct kernfs_elem_symlink___120 symlink;
		struct kernfs_elem_attr___120 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___120;

struct kernfs_ops___120 {
	int (*open)(struct kernfs_open_file___120 *);
	void (*release)(struct kernfs_open_file___120 *);
	int (*seq_show)(struct seq_file___114 *, void *);
	void * (*seq_start)(struct seq_file___114 *, loff_t *);
	void * (*seq_next)(struct seq_file___114 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___114 *, void *);
	ssize_t (*read)(struct kernfs_open_file___120 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___120 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___120 *, struct vm_area_struct___124 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___120 *, struct poll_table_struct___84 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___120 {
	int (*remount_fs)(struct kernfs_root___120 *, int *, char *);
	int (*show_options)(struct seq_file___114 *, struct kernfs_root___120 *);
	int (*mkdir)(struct kernfs_node___120 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___120 *);
	int (*rename)(struct kernfs_node___120 *, struct kernfs_node___120 *, const char *);
	int (*show_path)(struct seq_file___114 *, struct kernfs_node___120 *, struct kernfs_root___120 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___120 {
	struct kernfs_node___120 *kn;
	struct file___124 *file;
	struct seq_file___114 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___121 *vm_ops;
};

struct bin_attribute___114;

struct attribute_group___114 {
	const char *name;
	umode_t (*is_visible)(struct kobject___118 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___118 *, struct bin_attribute___114 *, int);
	struct attribute **attrs;
	struct bin_attribute___114 **bin_attrs;
};

struct bin_attribute___114 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___124 *, struct kobject___118 *, struct bin_attribute___114 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___124 *, struct kobject___118 *, struct bin_attribute___114 *, char *, loff_t, size_t);
	int (*mmap)(struct file___124 *, struct kobject___118 *, struct bin_attribute___114 *, struct vm_area_struct___124 *);
};

struct sysfs_ops___117 {
	ssize_t (*show)(struct kobject___118 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___118 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___117;

struct kset___117 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___118 kobj;
	const struct kset_uevent_ops___117 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___117 {
	void (*release)(struct kobject___118 *);
	const struct sysfs_ops___117 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___9 * (*child_ns_type)(struct kobject___118 *);
	const void * (*namespace)(struct kobject___118 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___117 {
	int (* const filter)(struct kset___117 *, struct kobject___118 *);
	const char * (* const name)(struct kset___117 *, struct kobject___118 *);
	int (* const uevent)(struct kset___117 *, struct kobject___118 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___104 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___104 *);
	int (*get)(char *, const struct kernel_param___104 *);
	void (*free)(void *);
};

struct kparam_array___104;

struct kernel_param___104 {
	const char *name;
	struct module___107 *mod;
	const struct kernel_param_ops___104 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___104 *arr;
	};
};

struct kparam_array___104 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___104 *ops;
	void *elem;
};

struct module_attribute___104 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___104 *, struct module_kobject___104 *, char *);
	ssize_t (*store)(struct module_attribute___104 *, struct module_kobject___104 *, const char *, size_t);
	void (*setup)(struct module___107 *, const char *);
	int (*test)(struct module___107 *);
	void (*free)(struct module___107 *);
};

typedef int (*key_restrict_link_func_t___119)(struct key___119 *, const struct key_type *, const union key_payload *, struct key___119 *);

struct key_restriction___119;

struct key___119 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___124 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___119 *restrict_link;
};

struct key_restriction___119 {
	key_restrict_link_func_t___119 check;
	struct key___119 *key;
	struct key_type *keytype;
};

struct dev_pm_ops___115 {
	int (*prepare)(struct device___115 *);
	void (*complete)(struct device___115 *);
	int (*suspend)(struct device___115 *);
	int (*resume)(struct device___115 *);
	int (*freeze)(struct device___115 *);
	int (*thaw)(struct device___115 *);
	int (*poweroff)(struct device___115 *);
	int (*restore)(struct device___115 *);
	int (*suspend_late)(struct device___115 *);
	int (*resume_early)(struct device___115 *);
	int (*freeze_late)(struct device___115 *);
	int (*thaw_early)(struct device___115 *);
	int (*poweroff_late)(struct device___115 *);
	int (*restore_early)(struct device___115 *);
	int (*suspend_noirq)(struct device___115 *);
	int (*resume_noirq)(struct device___115 *);
	int (*freeze_noirq)(struct device___115 *);
	int (*thaw_noirq)(struct device___115 *);
	int (*poweroff_noirq)(struct device___115 *);
	int (*restore_noirq)(struct device___115 *);
	int (*runtime_suspend)(struct device___115 *);
	int (*runtime_resume)(struct device___115 *);
	int (*runtime_idle)(struct device___115 *);
};

struct dev_pm_domain___115 {
	struct dev_pm_ops___115 ops;
	void (*detach)(struct device___115 *, bool);
	int (*activate)(struct device___115 *);
	void (*sync)(struct device___115 *);
	void (*dismiss)(struct device___115 *);
};

struct bus_type___115 {
	const char *name;
	const char *dev_name;
	struct device___115 *dev_root;
	const struct attribute_group___114 **bus_groups;
	const struct attribute_group___114 **dev_groups;
	const struct attribute_group___114 **drv_groups;
	int (*match)(struct device___115 *, struct device_driver___115 *);
	int (*uevent)(struct device___115 *, struct kobj_uevent_env *);
	int (*probe)(struct device___115 *);
	int (*remove)(struct device___115 *);
	void (*shutdown)(struct device___115 *);
	int (*online)(struct device___115 *);
	int (*offline)(struct device___115 *);
	int (*suspend)(struct device___115 *, pm_message_t);
	int (*resume)(struct device___115 *);
	int (*num_vf)(struct device___115 *);
	int (*dma_configure)(struct device___115 *);
	const struct dev_pm_ops___115 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___115 {
	const char *name;
	struct bus_type___115 *bus;
	struct module___107 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___115 *);
	int (*remove)(struct device___115 *);
	void (*shutdown)(struct device___115 *);
	int (*suspend)(struct device___115 *, pm_message_t);
	int (*resume)(struct device___115 *);
	const struct attribute_group___114 **groups;
	const struct dev_pm_ops___115 *pm;
	void (*coredump)(struct device___115 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___115 {
	const char *name;
	const struct attribute_group___114 **groups;
	int (*uevent)(struct device___115 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___115 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___115 *);
	const struct dev_pm_ops___115 *pm;
};

struct class___115 {
	const char *name;
	struct module___107 *owner;
	const struct attribute_group___114 **class_groups;
	const struct attribute_group___114 **dev_groups;
	struct kobject___118 *dev_kobj;
	int (*dev_uevent)(struct device___115 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___115 *, umode_t *);
	void (*class_release)(struct class___115 *);
	void (*dev_release)(struct device___115 *);
	int (*shutdown_pre)(struct device___115 *);
	const struct kobj_ns_type_operations___9 *ns_type;
	const void * (*namespace)(struct device___115 *);
	const struct dev_pm_ops___115 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___95 {
	struct device___115 dev;
};

struct seq_operations___112 {
	void * (*start)(struct seq_file___114 *, loff_t *);
	void (*stop)(struct seq_file___114 *, void *);
	void * (*next)(struct seq_file___114 *, void *, loff_t *);
	int (*show)(struct seq_file___114 *, void *);
};

struct bpf_map___100;

struct bpf_map_ops___100 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___100 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___100 *, struct file___124 *);
	void (*map_free)(struct bpf_map___100 *);
	int (*map_get_next_key)(struct bpf_map___100 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___100 *);
	void * (*map_lookup_elem)(struct bpf_map___100 *, void *);
	int (*map_update_elem)(struct bpf_map___100 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___100 *, void *);
	int (*map_push_elem)(struct bpf_map___100 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___100 *, void *);
	int (*map_peek_elem)(struct bpf_map___100 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___100 *, struct file___124 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___100 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___100 *, void *, struct seq_file___114 *);
	int (*map_check_btf)(const struct bpf_map___100 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___100 {
	const struct bpf_map_ops___100 *ops;
	struct bpf_map___100 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___119 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___100;

typedef void (*kthread_work_func_t___100)(struct kthread_work___100 *);

struct kthread_worker___100;

struct kthread_work___100 {
	struct list_head node;
	kthread_work_func_t___100 func;
	struct kthread_worker___100 *worker;
	int canceling;
};

struct kthread_worker___100 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___124 *task;
	struct kthread_work___100 *current_work;
};

struct kthread_delayed_work___100 {
	struct kthread_work___100 work;
	struct timer_list timer;
};

struct psi_group___100 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___100 *poll_kworker;
	struct kthread_delayed_work___100 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___100 {
	struct kernfs_node___120 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___100;

struct cgroup_subsys_state___100 {
	struct cgroup___100 *cgroup;
	struct cgroup_subsys___100 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___100 *parent;
};

struct cgroup_root___100;

struct cgroup_rstat_cpu___100;

struct cgroup___100 {
	struct cgroup_subsys_state___100 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___120 *kn;
	struct cgroup_file___100 procs_file;
	struct cgroup_file___100 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___100 *subsys[13];
	struct cgroup_root___100 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___100 *dom_cgrp;
	struct cgroup_rstat_cpu___100 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___19 bpf;
	atomic_t congestion_count;
	struct cgroup___100 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___100 psi;
	int ancestor_ids[0];
};

struct cftype___100;

struct cgroup_subsys___100 {
	struct cgroup_subsys_state___100 * (*css_alloc)(struct cgroup_subsys_state___100 *);
	int (*css_online)(struct cgroup_subsys_state___100 *);
	void (*css_offline)(struct cgroup_subsys_state___100 *);
	void (*css_released)(struct cgroup_subsys_state___100 *);
	void (*css_free)(struct cgroup_subsys_state___100 *);
	void (*css_reset)(struct cgroup_subsys_state___100 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___100 *, int);
	int (*css_extra_stat_show)(struct seq_file___114 *, struct cgroup_subsys_state___100 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___124 *);
	void (*cancel_fork)(struct task_struct___124 *);
	void (*fork)(struct task_struct___124 *);
	void (*exit)(struct task_struct___124 *);
	void (*free)(struct task_struct___124 *);
	void (*bind)(struct cgroup_subsys_state___100 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___100 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___100 *dfl_cftypes;
	struct cftype___100 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___100 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___100 *updated_children;
	struct cgroup___100 *updated_next;
};

struct cgroup_root___100 {
	struct kernfs_root___120 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___100 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___100 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___100 *ss;
	struct list_head node;
	struct kernfs_ops___120 *kf_ops;
	int (*open)(struct kernfs_open_file___120 *);
	void (*release)(struct kernfs_open_file___120 *);
	u64 (*read_u64)(struct cgroup_subsys_state___100 *, struct cftype___100 *);
	s64 (*read_s64)(struct cgroup_subsys_state___100 *, struct cftype___100 *);
	int (*seq_show)(struct seq_file___114 *, void *);
	void * (*seq_start)(struct seq_file___114 *, loff_t *);
	void * (*seq_next)(struct seq_file___114 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___114 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___100 *, struct cftype___100 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___100 *, struct cftype___100 *, s64);
	ssize_t (*write)(struct kernfs_open_file___120 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___120 *, struct poll_table_struct___84 *);
};

struct perf_cpu_context___76;

struct pmu___76 {
	struct list_head entry;
	struct module___107 *module;
	struct device___115 *dev;
	const struct attribute_group___114 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___76 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___76 *);
	void (*pmu_disable)(struct pmu___76 *);
	int (*event_init)(struct perf_event___76 *);
	void (*event_mapped)(struct perf_event___76 *, struct mm_struct___123 *);
	void (*event_unmapped)(struct perf_event___76 *, struct mm_struct___123 *);
	int (*add)(struct perf_event___76 *, int);
	void (*del)(struct perf_event___76 *, int);
	void (*start)(struct perf_event___76 *, int);
	void (*stop)(struct perf_event___76 *, int);
	void (*read)(struct perf_event___76 *);
	void (*start_txn)(struct pmu___76 *, unsigned int);
	int (*commit_txn)(struct pmu___76 *);
	void (*cancel_txn)(struct pmu___76 *);
	int (*event_idx)(struct perf_event___76 *);
	void (*sched_task)(struct perf_event_context___76 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___76 *);
	int (*filter_match)(struct perf_event___76 *);
	int (*check_period)(struct perf_event___76 *, u64);
};

struct perf_cpu_context___76 {
	struct perf_event_context___76 ctx;
	struct perf_event_context___76 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___76 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct ring_buffer___3 {
	atomic_t refcount;
	struct callback_head callback_head;
	int nr_pages;
	int overwrite;
	int paused;
	atomic_t poll;
	local_t head;
	local_t nest;
	local_t events;
	local_t wakeup;
	local_t lost;
	long int watermark;
	long int aux_watermark;
	spinlock_t event_lock;
	struct list_head event_list;
	atomic_t mmap_count;
	long unsigned int mmap_locked;
	struct user_struct___119 *mmap_user;
	long int aux_head;
	local_t aux_nest;
	long int aux_wakeup;
	long unsigned int aux_pgoff;
	int aux_nr_pages;
	int aux_overwrite;
	atomic_t aux_mmap_count;
	long unsigned int aux_mmap_locked;
	void (*free_aux)(void *);
	atomic_t aux_refcount;
	void **aux_pages;
	void *aux_priv;
	struct perf_event_mmap_page *user_page;
	void *data_pages[0];
};

struct perf_cgroup___76 {
	struct cgroup_subsys_state___100 css;
	struct perf_cgroup_info *info;
};

struct perf_output_handle___2 {
	struct perf_event___76 *event;
	struct ring_buffer___3 *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

enum perf_callchain_context {
	PERF_CONTEXT_HV = 4294967264,
	PERF_CONTEXT_KERNEL = 4294967168,
	PERF_CONTEXT_USER = 4294966784,
	PERF_CONTEXT_GUEST = 4294965248,
	PERF_CONTEXT_GUEST_KERNEL = 4294965120,
	PERF_CONTEXT_GUEST_USER = 4294964736,
	PERF_CONTEXT_MAX = 4294963201,
};

struct callchain_cpus_entries {
	struct callback_head callback_head;
	struct perf_callchain_entry *cpu_entries[0];
};

struct bp_cpuinfo {
	unsigned int cpu_pinned;
	unsigned int *tsk_pinned;
	unsigned int flexible;
};

struct bp_busy_slots {
	unsigned int pinned;
	unsigned int flexible;
};

struct file___125;

struct kiocb___125;

struct vm_area_struct___125;

struct inode___126;

struct file_lock___125;

struct page___125;

struct seq_file___115;

struct file_operations___125 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___125 *, loff_t, int);
	ssize_t (*read)(struct file___125 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___125 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___125 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___125 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___125 *, bool);
	int (*iterate)(struct file___125 *, struct dir_context *);
	int (*iterate_shared)(struct file___125 *, struct dir_context *);
	__poll_t (*poll)(struct file___125 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___125 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___125 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___125 *, struct vm_area_struct___125 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___126 *, struct file___125 *);
	int (*flush)(struct file___125 *, fl_owner_t);
	int (*release)(struct inode___126 *, struct file___125 *);
	int (*fsync)(struct file___125 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___125 *, int);
	int (*lock)(struct file___125 *, int, struct file_lock___125 *);
	ssize_t (*sendpage)(struct file___125 *, struct page___125 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___125 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___125 *, int, struct file_lock___125 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___125 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___125 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___125 *, long int, struct file_lock___125 **, void **);
	long int (*fallocate)(struct file___125 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___115 *, struct file___125 *);
	ssize_t (*copy_file_range)(struct file___125 *, loff_t, struct file___125 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___125 *, loff_t, struct file___125 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___125 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___124 {
	u64 seqnum;
	struct vm_area_struct___125 *vmas[4];
};

struct page_frag___124 {
	struct page___125 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___124;

struct mem_cgroup___41;

struct pid___101;

struct cred___120;

struct nsproxy___117;

struct signal_struct___114;

struct bio_list___46;

struct backing_dev_info___46;

struct css_set___101;

struct task_struct___125 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___125 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___124 *mm;
	struct mm_struct___124 *active_mm;
	struct vmacache___124 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___125 *real_parent;
	struct task_struct___125 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___125 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___41 *active_memcg;
	long int rh_reserved2;
	struct pid___101 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___101 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___101 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___120 *ptracer_cred;
	const struct cred___120 *real_cred;
	const struct cred___120 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___117 *nsproxy;
	struct signal_struct___114 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___125 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___46 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___46 *backing_dev_info;
	struct io_context___17 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___101 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___124 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___41 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___125 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___76 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___124;

struct super_block___125;

struct dentry___125 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___125 *d_parent;
	struct qstr d_name;
	struct inode___126 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___124 *d_op;
	struct super_block___125 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct rw_semaphore___125 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___125 *owner;
};

struct address_space_operations___124;

struct address_space___124 {
	struct inode___126 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___125 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___124 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___124;

struct bdi_writeback___46;

struct block_device___125;

struct inode___126 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___124 *i_op;
	struct super_block___125 *i_sb;
	struct address_space___124 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___125 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___46 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___125 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___124 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___125 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___124;

struct dentry_operations___124 {
	int (*d_revalidate)(struct dentry___125 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___125 *, unsigned int);
	int (*d_hash)(const struct dentry___125 *, struct qstr *);
	int (*d_compare)(const struct dentry___125 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___125 *);
	int (*d_init)(struct dentry___125 *);
	void (*d_release)(struct dentry___125 *);
	void (*d_prune)(struct dentry___125 *);
	void (*d_iput)(struct dentry___125 *, struct inode___126 *);
	char * (*d_dname)(struct dentry___125 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___124 *);
	int (*d_manage)(const struct path___124 *, bool);
	struct dentry___125 * (*d_real)(struct dentry___125 *, const struct inode___126 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___124;

struct mem_dqinfo___124 {
	struct quota_format_type___124 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___124;

struct quota_info___124 {
	unsigned int flags;
	struct rw_semaphore___125 dqio_sem;
	struct inode___126 *files[3];
	struct mem_dqinfo___124 info[3];
	const struct quota_format_ops___124 *ops[3];
};

struct rcuwait___124 {
	struct task_struct___125 *task;
};

struct percpu_rw_semaphore___124 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___125 rw_sem;
	struct rcuwait___124 writer;
	int readers_block;
};

struct sb_writers___124 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___124 rw_sem[3];
};

struct shrink_control___41;

struct shrinker___41 {
	long unsigned int (*count_objects)(struct shrinker___41 *, struct shrink_control___41 *);
	long unsigned int (*scan_objects)(struct shrinker___41 *, struct shrink_control___41 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___124;

struct super_operations___124;

struct dquot_operations___124;

struct quotactl_ops___124;

struct xattr_handler___4;

struct user_namespace___105;

struct super_block___125 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___124 *s_type;
	const struct super_operations___124 *s_op;
	const struct dquot_operations___124 *dq_op;
	const struct quotactl_ops___124 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___125 *s_root;
	struct rw_semaphore___125 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___4 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___125 *s_bdev;
	struct backing_dev_info___46 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___124 s_dquot;
	struct sb_writers___124 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___124 *s_d_op;
	int cleancache_poolid;
	struct shrinker___41 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___105 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct path___124 {
	struct vfsmount *mnt;
	struct dentry___125 *dentry;
};

struct key___120;

struct ucounts___105;

struct user_namespace___105 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___105 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___9 ns;
	long unsigned int flags;
	struct key___120 *persistent_keyring_register;
	struct rw_semaphore___125 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___105 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct shrink_control___41 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___41 *memcg;
};

struct cgroup___101;

struct cgroup_subsys___101;

struct cgroup_subsys_state___101 {
	struct cgroup___101 *cgroup;
	struct cgroup_subsys___101 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___101 *parent;
};

struct kernfs_node___121;

struct cgroup_file___101 {
	struct kernfs_node___121 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___41;

struct mem_cgroup___41 {
	struct cgroup_subsys_state___101 css;
	struct mem_cgroup_id___6 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___101 events_file;
	struct cgroup_file___101 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___125 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___41 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___125 *pgtable_t___124;

struct dev_pagemap___122;

struct page___125 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___124 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___125 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___124 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___124 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___122 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___41 *mem_cgroup;
};

struct pglist_data___124;

struct lruvec___124 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___124 *pgdat;
};

struct zone___124 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___124 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___124 {
	struct zone___124 *zone;
	int zone_idx;
};

struct zonelist___124 {
	struct zoneref___124 _zonerefs[25];
};

struct pglist_data___124 {
	struct zone___124 node_zones[3];
	struct zonelist___124 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___125 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___125 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___124 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___125 {
	void *stack;
	struct task_struct___125 *task;
	long int status;
};

struct blocking_notifier_head___124 {
	struct rw_semaphore___125 rwsem;
	struct notifier_block *head;
};

struct pid_namespace___101;

struct upid___101 {
	int nr;
	struct pid_namespace___101 *ns;
};

struct pid_namespace___101 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___125 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___101 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___125 *proc_self;
	struct dentry___125 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___105 *user_ns;
	struct ucounts___105 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___9 ns;
};

struct pid___101 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___101 numbers[1];
};

struct anon_vma___3;

struct vm_operations_struct___122;

struct vm_area_struct___125 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___125 *vm_next;
	struct vm_area_struct___125 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___124 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma___3 *anon_vma;
	const struct vm_operations_struct___122 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___125 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct uprobe_consumer___2 {
	int (*handler)(struct uprobe_consumer___2 *, struct pt_regs *);
	int (*ret_handler)(struct uprobe_consumer___2 *, long unsigned int, struct pt_regs *);
	bool (*filter)(struct uprobe_consumer___2 *, enum uprobe_filter_ctx, struct mm_struct___124 *);
	struct uprobe_consumer___2 *next;
};

struct core_state___124;

struct mm_struct___124 {
	struct {
		struct vm_area_struct___125 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___125 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___125 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___124 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___125 *owner;
		struct user_namespace___105 *user_ns;
		struct file___125 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___124 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef u32 uprobe_opcode_t;

struct uprobe {
	struct rb_node rb_node;
	atomic_t ref;
	struct rw_semaphore___125 register_rwsem;
	struct rw_semaphore___125 consumer_rwsem;
	struct list_head pending_list;
	struct uprobe_consumer___2 *consumers;
	struct inode___126 *inode;
	loff_t offset;
	loff_t ref_ctr_offset;
	long unsigned int flags;
	struct arch_uprobe arch;
};

struct vm_fault___122;

struct vm_special_mapping___2 {
	const char *name;
	struct page___125 **pages;
	vm_fault_t (*fault)(const struct vm_special_mapping___2 *, struct vm_area_struct___125 *, struct vm_fault___122 *);
	int (*mremap)(const struct vm_special_mapping___2 *, struct vm_area_struct___125 *);
};

struct xol_area {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct vm_special_mapping___2 xol_mapping;
	struct page___125 *pages[2];
	long unsigned int vaddr;
};

typedef int (*dev_page_fault_t___122)(struct vm_area_struct___125 *, long unsigned int, const struct page___125 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___122)(struct page___125 *, void *);

struct device___116;

struct dev_pagemap___122 {
	dev_page_fault_t___122 page_fault;
	dev_page_free_t___122 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___116 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

typedef long unsigned int vm_flags_t;

struct fown_struct___101 {
	rwlock_t lock;
	struct pid___101 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___125 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___124 f_path;
	struct inode___126 *f_inode;
	const struct file_operations___125 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___101 f_owner;
	const struct cred___120 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___124 *f_mapping;
	errseq_t f_wb_err;
};

struct anon_vma___3 {
	struct anon_vma___3 *root;
	struct rw_semaphore___125 rwsem;
	atomic_t refcount;
	unsigned int degree;
	struct anon_vma___3 *parent;
	struct rb_root_cached rb_root;
};

struct vm_operations_struct___122 {
	void (*open)(struct vm_area_struct___125 *);
	void (*close)(struct vm_area_struct___125 *);
	int (*split)(struct vm_area_struct___125 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___125 *);
	vm_fault_t (*fault)(struct vm_fault___122 *);
	vm_fault_t (*huge_fault)(struct vm_fault___122 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___122 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___125 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___122 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___122 *);
	int (*access)(struct vm_area_struct___125 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___125 *);
	int (*set_policy)(struct vm_area_struct___125 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___125 *, long unsigned int);
	struct page___125 * (*find_special_page)(struct vm_area_struct___125 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___124 {
	struct task_struct___125 *task;
	struct core_thread___124 *next;
};

struct core_state___124 {
	atomic_t nr_threads;
	struct core_thread___124 dumper;
	struct completion startup;
};

struct vm_fault___122 {
	struct vm_area_struct___125 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___125 *cow_page;
	struct mem_cgroup___41 *memcg;
	struct page___125 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___124 prealloc_pte;
};

struct user_struct___120 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___120 *uid_keyring;
	struct key___120 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___120 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___120 *session_keyring;
	struct key___120 *process_keyring;
	struct key___120 *thread_keyring;
	struct key___120 *request_key_auth;
	void *security;
	struct user_struct___120 *user;
	struct user_namespace___105 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___101;

struct nsproxy___117 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___101 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___101 *cgroup_ns;
};

struct signal_struct___114 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___125 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___125 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___101 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___101 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___124 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___101 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___46;

struct bio_list___46 {
	struct bio___46 *head;
	struct bio___46 *tail;
};

struct bdi_writeback_congested___46;

struct bdi_writeback___46 {
	struct backing_dev_info___46 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___46 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___101 *memcg_css;
	struct cgroup_subsys_state___101 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___46 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___46 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___116 *dev;
	struct device___116 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___125 *debug_dir;
	struct dentry___125 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___101 {
	struct cgroup_subsys_state___101 *subsys[13];
	refcount_t refcount;
	struct css_set___101 *dom_cset;
	struct cgroup___101 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___101 *mg_src_cgrp;
	struct cgroup___101 *mg_dst_cgrp;
	struct css_set___101 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

union thread_union___114 {
	struct task_struct___125 task;
	long unsigned int stack[8192];
};

struct kiocb___125 {
	struct file___125 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___125 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___125 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___125 *ia_file;
};

struct dquot___124 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___125 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___124 {
	int qf_fmt_id;
	const struct quota_format_ops___124 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___124 *qf_next;
};

struct quota_format_ops___124 {
	int (*check_quota_file)(struct super_block___125 *, int);
	int (*read_file_info)(struct super_block___125 *, int);
	int (*write_file_info)(struct super_block___125 *, int);
	int (*free_file_info)(struct super_block___125 *, int);
	int (*read_dqblk)(struct dquot___124 *);
	int (*commit_dqblk)(struct dquot___124 *);
	int (*release_dqblk)(struct dquot___124 *);
	int (*get_next_id)(struct super_block___125 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___124 {
	int (*write_dquot)(struct dquot___124 *);
	struct dquot___124 * (*alloc_dquot)(struct super_block___125 *, int);
	void (*destroy_dquot)(struct dquot___124 *);
	int (*acquire_dquot)(struct dquot___124 *);
	int (*release_dquot)(struct dquot___124 *);
	int (*mark_dirty)(struct dquot___124 *);
	int (*write_info)(struct super_block___125 *, int);
	qsize_t * (*get_reserved_space)(struct inode___126 *);
	int (*get_projid)(struct inode___126 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___126 *, qsize_t *);
	int (*get_next_id)(struct super_block___125 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___124 {
	int (*quota_on)(struct super_block___125 *, int, int, const struct path___124 *);
	int (*quota_off)(struct super_block___125 *, int);
	int (*quota_enable)(struct super_block___125 *, unsigned int);
	int (*quota_disable)(struct super_block___125 *, unsigned int);
	int (*quota_sync)(struct super_block___125 *, int);
	int (*set_info)(struct super_block___125 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___125 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___125 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___125 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___125 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___125 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___43;

struct swap_info_struct___28;

struct address_space_operations___124 {
	int (*writepage)(struct page___125 *, struct writeback_control___43 *);
	int (*readpage)(struct file___125 *, struct page___125 *);
	int (*writepages)(struct address_space___124 *, struct writeback_control___43 *);
	int (*set_page_dirty)(struct page___125 *);
	int (*readpages)(struct file___125 *, struct address_space___124 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___125 *, struct address_space___124 *, loff_t, unsigned int, unsigned int, struct page___125 **, void **);
	int (*write_end)(struct file___125 *, struct address_space___124 *, loff_t, unsigned int, unsigned int, struct page___125 *, void *);
	sector_t (*bmap)(struct address_space___124 *, sector_t);
	void (*invalidatepage)(struct page___125 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___125 *, gfp_t);
	void (*freepage)(struct page___125 *);
	ssize_t (*direct_IO)(struct kiocb___125 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___124 *, struct page___125 *, struct page___125 *, enum migrate_mode);
	bool (*isolate_page)(struct page___125 *, isolate_mode_t);
	void (*putback_page)(struct page___125 *);
	int (*launder_page)(struct page___125 *);
	int (*is_partially_uptodate)(struct page___125 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___125 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___124 *, struct page___125 *);
	int (*swap_activate)(struct swap_info_struct___28 *, struct file___125 *, sector_t *);
	void (*swap_deactivate)(struct file___125 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___43 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___46 *wb;
	struct inode___126 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct swap_info_struct___28 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___125 *bdev;
	struct file___125 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___125 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___126 *bd_inode;
	struct super_block___125 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___125 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___46 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___124 {
	struct dentry___125 * (*lookup)(struct inode___126 *, struct dentry___125 *, unsigned int);
	const char * (*get_link)(struct dentry___125 *, struct inode___126 *, struct delayed_call *);
	int (*permission)(struct inode___126 *, int);
	struct posix_acl * (*get_acl)(struct inode___126 *, int);
	int (*readlink)(struct dentry___125 *, char *, int);
	int (*create)(struct inode___126 *, struct dentry___125 *, umode_t, bool);
	int (*link)(struct dentry___125 *, struct inode___126 *, struct dentry___125 *);
	int (*unlink)(struct inode___126 *, struct dentry___125 *);
	int (*symlink)(struct inode___126 *, struct dentry___125 *, const char *);
	int (*mkdir)(struct inode___126 *, struct dentry___125 *, umode_t);
	int (*rmdir)(struct inode___126 *, struct dentry___125 *);
	int (*mknod)(struct inode___126 *, struct dentry___125 *, umode_t, dev_t);
	int (*rename)(struct inode___126 *, struct dentry___125 *, struct inode___126 *, struct dentry___125 *, unsigned int);
	int (*setattr)(struct dentry___125 *, struct iattr___125 *);
	int (*getattr)(const struct path___124 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___125 *, char *, size_t);
	int (*fiemap)(struct inode___126 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___126 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___126 *, struct dentry___125 *, struct file___125 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___126 *, struct dentry___125 *, umode_t);
	int (*set_acl)(struct inode___126 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___124 {
	void (*fl_copy_lock)(struct file_lock___125 *, struct file_lock___125 *);
	void (*fl_release_private)(struct file_lock___125 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___124;

struct lock_manager_operations___124;

struct file_lock___125 {
	struct file_lock___125 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___125 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___124 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___124 *fl_ops;
	const struct lock_manager_operations___124 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___124 {
	int (*lm_compare_owner)(struct file_lock___125 *, struct file_lock___125 *);
	long unsigned int (*lm_owner_key)(struct file_lock___125 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___125 *);
	int (*lm_grant)(struct file_lock___125 *, int);
	bool (*lm_break)(struct file_lock___125 *);
	int (*lm_change)(struct file_lock___125 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___125 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___124 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___124 *fa_next;
	struct file___125 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___124 {
	const char *name;
	int fs_flags;
	struct dentry___125 * (*mount)(struct file_system_type___124 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___125 *);
	struct module___11 *owner;
	struct file_system_type___124 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___124 {
	struct inode___126 * (*alloc_inode)(struct super_block___125 *);
	void (*destroy_inode)(struct inode___126 *);
	void (*dirty_inode)(struct inode___126 *, int);
	int (*write_inode)(struct inode___126 *, struct writeback_control___43 *);
	int (*drop_inode)(struct inode___126 *);
	void (*evict_inode)(struct inode___126 *);
	void (*put_super)(struct super_block___125 *);
	int (*sync_fs)(struct super_block___125 *, int);
	int (*freeze_super)(struct super_block___125 *);
	int (*freeze_fs)(struct super_block___125 *);
	int (*thaw_super)(struct super_block___125 *);
	int (*unfreeze_fs)(struct super_block___125 *);
	int (*statfs)(struct dentry___125 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___125 *, int *, char *);
	void (*umount_begin)(struct super_block___125 *);
	int (*show_options)(struct seq_file___115 *, struct dentry___125 *);
	int (*show_devname)(struct seq_file___115 *, struct dentry___125 *);
	int (*show_path)(struct seq_file___115 *, struct dentry___125 *);
	int (*show_stats)(struct seq_file___115 *, struct dentry___125 *);
	ssize_t (*quota_read)(struct super_block___125 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___125 *, int, const char *, size_t, loff_t);
	struct dquot___124 ** (*get_dquots)(struct inode___126 *);
	int (*bdev_try_to_free_page)(struct super_block___125 *, struct page___125 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___125 *, struct shrink_control___41 *);
	long int (*free_cached_objects)(struct super_block___125 *, struct shrink_control___41 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct xattr_handler___4 {
	const char *name;
	const char *prefix;
	int flags;
	bool (*list)(struct dentry___125 *);
	int (*get)(const struct xattr_handler___4 *, struct dentry___125 *, struct inode___126 *, const char *, void *, size_t);
	int (*set)(const struct xattr_handler___4 *, struct dentry___125 *, struct inode___126 *, const char *, const void *, size_t, int);
};

struct seq_operations___113;

struct seq_file___115 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___113 *op;
	int poll_event;
	const struct file___125 *file;
	void *private;
};

struct kset___118;

struct kobj_type___118;

struct kobject___119 {
	const char *name;
	struct list_head entry;
	struct kobject___119 *parent;
	struct kset___118 *kset;
	struct kobj_type___118 *ktype;
	struct kernfs_node___121 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___46(struct bio___46 *);

struct bio_vec___46 {
	struct page___125 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___46;

struct bio_set___46;

struct bio___46 {
	struct bio___46 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___46 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___46 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___46 *bi_io_vec;
	struct bio_set___46 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___46 bi_inline_vecs[0];
};

struct dev_pm_info___116 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___116 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___116;

struct bus_type___116;

struct device_driver___116;

struct dev_pm_domain___116;

struct class___116;

struct attribute_group___115;

struct device___116 {
	struct device___116 *parent;
	struct device_private *p;
	struct kobject___119 kobj;
	const char *init_name;
	const struct device_type___116 *type;
	struct mutex mutex;
	struct bus_type___116 *bus;
	struct device_driver___116 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___116 power;
	struct dev_pm_domain___116 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___116 *class;
	const struct attribute_group___115 **groups;
	void (*release)(struct device___116 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct kobj_attribute___119 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___119 *, struct kobj_attribute___119 *, char *);
	ssize_t (*store)(struct kobject___119 *, struct kobj_attribute___119 *, const char *, size_t);
};

typedef void compound_page_dtor___122(struct page___125 *);

typedef int filler_t(void *, struct page___125 *);

typedef int (*key_restrict_link_func_t___120)(struct key___120 *, const struct key_type *, const union key_payload *, struct key___120 *);

struct key_restriction___120;

struct key___120 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___125 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___120 *restrict_link;
};

struct key_restriction___120 {
	key_restrict_link_func_t___120 check;
	struct key___120 *key;
	struct key_type *keytype;
};

struct seq_operations___113 {
	void * (*start)(struct seq_file___115 *, loff_t *);
	void (*stop)(struct seq_file___115 *, void *);
	void * (*next)(struct seq_file___115 *, void *, loff_t *);
	int (*show)(struct seq_file___115 *, void *);
};

struct kernfs_root___121;

struct kernfs_elem_dir___121 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___121 *root;
};

struct kernfs_syscall_ops___121;

struct kernfs_root___121 {
	struct kernfs_node___121 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___121 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___121 {
	struct kernfs_node___121 *target_kn;
};

struct kernfs_ops___121;

struct kernfs_elem_attr___121 {
	const struct kernfs_ops___121 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___121 *notify_next;
};

struct kernfs_node___121 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___121 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___121 dir;
		struct kernfs_elem_symlink___121 symlink;
		struct kernfs_elem_attr___121 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___121;

struct kernfs_ops___121 {
	int (*open)(struct kernfs_open_file___121 *);
	void (*release)(struct kernfs_open_file___121 *);
	int (*seq_show)(struct seq_file___115 *, void *);
	void * (*seq_start)(struct seq_file___115 *, loff_t *);
	void * (*seq_next)(struct seq_file___115 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___115 *, void *);
	ssize_t (*read)(struct kernfs_open_file___121 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___121 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___121 *, struct vm_area_struct___125 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___121 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___121 {
	int (*remount_fs)(struct kernfs_root___121 *, int *, char *);
	int (*show_options)(struct seq_file___115 *, struct kernfs_root___121 *);
	int (*mkdir)(struct kernfs_node___121 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___121 *);
	int (*rename)(struct kernfs_node___121 *, struct kernfs_node___121 *, const char *);
	int (*show_path)(struct seq_file___115 *, struct kernfs_node___121 *, struct kernfs_root___121 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___121 {
	struct kernfs_node___121 *kn;
	struct file___125 *file;
	struct seq_file___115 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___122 *vm_ops;
};

struct cgroup_namespace___101 {
	refcount_t count;
	struct ns_common___9 ns;
	struct user_namespace___105 *user_ns;
	struct ucounts___105 *ucounts;
	struct css_set___101 *root_cset;
};

struct ucounts___105 {
	struct hlist_node node;
	struct user_namespace___105 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___101;

struct bpf_map_ops___101 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___101 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___101 *, struct file___125 *);
	void (*map_free)(struct bpf_map___101 *);
	int (*map_get_next_key)(struct bpf_map___101 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___101 *);
	void * (*map_lookup_elem)(struct bpf_map___101 *, void *);
	int (*map_update_elem)(struct bpf_map___101 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___101 *, void *);
	int (*map_push_elem)(struct bpf_map___101 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___101 *, void *);
	int (*map_peek_elem)(struct bpf_map___101 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___101 *, struct file___125 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___101 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___101 *, void *, struct seq_file___115 *);
	int (*map_check_btf)(const struct bpf_map___101 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___101 {
	const struct bpf_map_ops___101 *ops;
	struct bpf_map___101 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___120 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___101;

typedef void (*kthread_work_func_t___101)(struct kthread_work___101 *);

struct kthread_worker___101;

struct kthread_work___101 {
	struct list_head node;
	kthread_work_func_t___101 func;
	struct kthread_worker___101 *worker;
	int canceling;
};

struct kthread_worker___101 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___125 *task;
	struct kthread_work___101 *current_work;
};

struct kthread_delayed_work___101 {
	struct kthread_work___101 work;
	struct timer_list timer;
};

struct psi_group___101 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___101 *poll_kworker;
	struct kthread_delayed_work___101 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___101;

struct cgroup_rstat_cpu___101;

struct cgroup___101 {
	struct cgroup_subsys_state___101 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___121 *kn;
	struct cgroup_file___101 procs_file;
	struct cgroup_file___101 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___101 *subsys[13];
	struct cgroup_root___101 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___101 *dom_cgrp;
	struct cgroup_rstat_cpu___101 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___19 bpf;
	atomic_t congestion_count;
	struct cgroup___101 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___101 psi;
	int ancestor_ids[0];
};

struct cftype___101;

struct cgroup_subsys___101 {
	struct cgroup_subsys_state___101 * (*css_alloc)(struct cgroup_subsys_state___101 *);
	int (*css_online)(struct cgroup_subsys_state___101 *);
	void (*css_offline)(struct cgroup_subsys_state___101 *);
	void (*css_released)(struct cgroup_subsys_state___101 *);
	void (*css_free)(struct cgroup_subsys_state___101 *);
	void (*css_reset)(struct cgroup_subsys_state___101 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___101 *, int);
	int (*css_extra_stat_show)(struct seq_file___115 *, struct cgroup_subsys_state___101 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___125 *);
	void (*cancel_fork)(struct task_struct___125 *);
	void (*fork)(struct task_struct___125 *);
	void (*exit)(struct task_struct___125 *);
	void (*free)(struct task_struct___125 *);
	void (*bind)(struct cgroup_subsys_state___101 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___101 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___101 *dfl_cftypes;
	struct cftype___101 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___101 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___101 *updated_children;
	struct cgroup___101 *updated_next;
};

struct cgroup_root___101 {
	struct kernfs_root___121 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___101 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___101 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___101 *ss;
	struct list_head node;
	struct kernfs_ops___121 *kf_ops;
	int (*open)(struct kernfs_open_file___121 *);
	void (*release)(struct kernfs_open_file___121 *);
	u64 (*read_u64)(struct cgroup_subsys_state___101 *, struct cftype___101 *);
	s64 (*read_s64)(struct cgroup_subsys_state___101 *, struct cftype___101 *);
	int (*seq_show)(struct seq_file___115 *, void *);
	void * (*seq_start)(struct seq_file___115 *, loff_t *);
	void * (*seq_next)(struct seq_file___115 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___115 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___101 *, struct cftype___101 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___101 *, struct cftype___101 *, s64);
	ssize_t (*write)(struct kernfs_open_file___121 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___121 *, struct poll_table_struct___6 *);
};

struct bdi_writeback_congested___46 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___46 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___46 {
	struct bio___46 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___46 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___46 bip_inline_vecs[0];
};

struct bio_set___46 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___46 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___41 {
	struct mem_cgroup___41 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___41 {
	struct lruvec___124 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___41 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___41 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct page_vma_mapped_walk {
	struct page___125 *page;
	struct vm_area_struct___125 *vma;
	long unsigned int address;
	pmd_t *pmd;
	pte_t *pte;
	spinlock_t *ptl;
	unsigned int flags;
};

struct bin_attribute___115;

struct attribute_group___115 {
	const char *name;
	umode_t (*is_visible)(struct kobject___119 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___119 *, struct bin_attribute___115 *, int);
	struct attribute **attrs;
	struct bin_attribute___115 **bin_attrs;
};

struct bin_attribute___115 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___125 *, struct kobject___119 *, struct bin_attribute___115 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___125 *, struct kobject___119 *, struct bin_attribute___115 *, char *, loff_t, size_t);
	int (*mmap)(struct file___125 *, struct kobject___119 *, struct bin_attribute___115 *, struct vm_area_struct___125 *);
};

struct sysfs_ops___118 {
	ssize_t (*show)(struct kobject___119 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___119 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___118;

struct kset___118 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___119 kobj;
	const struct kset_uevent_ops___118 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___118 {
	void (*release)(struct kobject___119 *);
	const struct sysfs_ops___118 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___9 * (*child_ns_type)(struct kobject___119 *);
	const void * (*namespace)(struct kobject___119 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___118 {
	int (* const filter)(struct kset___118 *, struct kobject___119 *);
	const char * (* const name)(struct kset___118 *, struct kobject___119 *);
	int (* const uevent)(struct kset___118 *, struct kobject___119 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___116 {
	int (*prepare)(struct device___116 *);
	void (*complete)(struct device___116 *);
	int (*suspend)(struct device___116 *);
	int (*resume)(struct device___116 *);
	int (*freeze)(struct device___116 *);
	int (*thaw)(struct device___116 *);
	int (*poweroff)(struct device___116 *);
	int (*restore)(struct device___116 *);
	int (*suspend_late)(struct device___116 *);
	int (*resume_early)(struct device___116 *);
	int (*freeze_late)(struct device___116 *);
	int (*thaw_early)(struct device___116 *);
	int (*poweroff_late)(struct device___116 *);
	int (*restore_early)(struct device___116 *);
	int (*suspend_noirq)(struct device___116 *);
	int (*resume_noirq)(struct device___116 *);
	int (*freeze_noirq)(struct device___116 *);
	int (*thaw_noirq)(struct device___116 *);
	int (*poweroff_noirq)(struct device___116 *);
	int (*restore_noirq)(struct device___116 *);
	int (*runtime_suspend)(struct device___116 *);
	int (*runtime_resume)(struct device___116 *);
	int (*runtime_idle)(struct device___116 *);
};

struct dev_pm_domain___116 {
	struct dev_pm_ops___116 ops;
	void (*detach)(struct device___116 *, bool);
	int (*activate)(struct device___116 *);
	void (*sync)(struct device___116 *);
	void (*dismiss)(struct device___116 *);
};

struct bus_type___116 {
	const char *name;
	const char *dev_name;
	struct device___116 *dev_root;
	const struct attribute_group___115 **bus_groups;
	const struct attribute_group___115 **dev_groups;
	const struct attribute_group___115 **drv_groups;
	int (*match)(struct device___116 *, struct device_driver___116 *);
	int (*uevent)(struct device___116 *, struct kobj_uevent_env *);
	int (*probe)(struct device___116 *);
	int (*remove)(struct device___116 *);
	void (*shutdown)(struct device___116 *);
	int (*online)(struct device___116 *);
	int (*offline)(struct device___116 *);
	int (*suspend)(struct device___116 *, pm_message_t);
	int (*resume)(struct device___116 *);
	int (*num_vf)(struct device___116 *);
	int (*dma_configure)(struct device___116 *);
	const struct dev_pm_ops___116 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___116 {
	const char *name;
	struct bus_type___116 *bus;
	struct module___11 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___116 *);
	int (*remove)(struct device___116 *);
	void (*shutdown)(struct device___116 *);
	int (*suspend)(struct device___116 *, pm_message_t);
	int (*resume)(struct device___116 *);
	const struct attribute_group___115 **groups;
	const struct dev_pm_ops___116 *pm;
	void (*coredump)(struct device___116 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___116 {
	const char *name;
	const struct attribute_group___115 **groups;
	int (*uevent)(struct device___116 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___116 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___116 *);
	const struct dev_pm_ops___116 *pm;
};

struct class___116 {
	const char *name;
	struct module___11 *owner;
	const struct attribute_group___115 **class_groups;
	const struct attribute_group___115 **dev_groups;
	struct kobject___119 *dev_kobj;
	int (*dev_uevent)(struct device___116 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___116 *, umode_t *);
	void (*class_release)(struct class___116 *);
	void (*dev_release)(struct device___116 *);
	int (*shutdown_pre)(struct device___116 *);
	const struct kobj_ns_type_operations___9 *ns_type;
	const void * (*namespace)(struct device___116 *);
	const struct dev_pm_ops___116 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___96 {
	struct device___116 dev;
};

struct delayed_uprobe {
	struct list_head list;
	struct uprobe *uprobe;
	struct mm_struct___124 *mm;
};

struct map_info {
	struct map_info *next;
	struct mm_struct___124 *mm;
	long unsigned int vaddr;
};

struct parallel_data;

struct padata_priv {
	struct list_head list;
	struct parallel_data *pd;
	int cb_cpu;
	int cpu;
	int info;
	void (*parallel)(struct padata_priv *);
	void (*serial)(struct padata_priv *);
};

struct padata_cpumask {
	cpumask_var_t pcpu;
	cpumask_var_t cbcpu;
};

struct padata_instance;

struct padata_parallel_queue;

struct padata_serial_queue;

struct parallel_data {
	struct padata_instance *pinst;
	struct padata_parallel_queue *pqueue;
	struct padata_serial_queue *squeue;
	atomic_t reorder_objects;
	atomic_t refcnt;
	atomic_t seq_nr;
	struct padata_cpumask cpumask;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t lock;
	unsigned int processed;
	struct timer_list timer;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct padata_list {
	struct list_head list;
	spinlock_t lock;
};

struct padata_serial_queue {
	struct padata_list serial;
	struct work_struct work;
	struct parallel_data *pd;
};

struct padata_parallel_queue {
	struct padata_list parallel;
	struct padata_list reorder;
	struct parallel_data *pd;
	struct work_struct work;
	struct work_struct reorder_work;
	atomic_t num_obj;
	int cpu_index;
};

struct padata_instance {
	struct hlist_node node;
	struct workqueue_struct *wq;
	struct parallel_data *pd;
	struct padata_cpumask cpumask;
	struct blocking_notifier_head___99 cpumask_change_notifier;
	struct kobject___108 kobj;
	struct mutex lock;
	u8 flags;
};

struct padata_sysfs_entry {
	struct attribute attr;
	ssize_t (*show)(struct padata_instance *, struct attribute *, char *);
	ssize_t (*store)(struct padata_instance *, struct attribute *, const char *, size_t);
};

struct static_key_mod {
	struct static_key_mod *next;
	struct jump_entry *entries;
	struct module___11 *mod;
};

struct static_key_deferred {
	struct static_key key;
	long unsigned int timeout;
	struct delayed_work work;
};

struct trace_event_raw_context_tracking_user {
	struct trace_entry ent;
	int dummy;
	char __data[0];
};

struct trace_event_data_offsets_context_tracking_user {};

enum rseq_cpu_id_state {
	RSEQ_CPU_ID_UNINITIALIZED = 4294967295,
	RSEQ_CPU_ID_REGISTRATION_FAILED = 4294967294,
};

enum rseq_flags {
	RSEQ_FLAG_UNREGISTER = 1,
};

enum rseq_cs_flags {
	RSEQ_CS_FLAG_NO_RESTART_ON_PREEMPT = 1,
	RSEQ_CS_FLAG_NO_RESTART_ON_SIGNAL = 2,
	RSEQ_CS_FLAG_NO_RESTART_ON_MIGRATE = 4,
};

struct rseq_cs {
	__u32 version;
	__u32 flags;
	__u64 start_ip;
	__u64 post_commit_offset;
	__u64 abort_ip;
};

struct trace_event_buffer___24 {
	struct ring_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___26 *trace_file;
	void *entry;
	long unsigned int flags;
	int pc;
};

struct trace_event_raw_rseq_update {
	struct trace_entry ent;
	s32 cpu_id;
	char __data[0];
};

struct trace_event_raw_rseq_ip_fixup {
	struct trace_entry ent;
	long unsigned int regs_ip;
	long unsigned int start_ip;
	long unsigned int post_commit_offset;
	long unsigned int abort_ip;
	char __data[0];
};

struct trace_event_data_offsets_rseq_update {};

struct trace_event_data_offsets_rseq_ip_fixup {};

struct __key_reference_with_attributes;

typedef struct __key_reference_with_attributes *key_ref_t;

struct pkcs7_message;

struct module___108;

struct file___126;

struct kiocb___126;

struct iov_iter___53;

struct poll_table_struct___85;

struct vm_area_struct___126;

struct inode___127;

struct file_lock___126;

struct page___126;

struct seq_file___116;

struct file_operations___126 {
	struct module___108 *owner;
	loff_t (*llseek)(struct file___126 *, loff_t, int);
	ssize_t (*read)(struct file___126 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___126 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___126 *, struct iov_iter___53 *);
	ssize_t (*write_iter)(struct kiocb___126 *, struct iov_iter___53 *);
	int (*iopoll)(struct kiocb___126 *, bool);
	int (*iterate)(struct file___126 *, struct dir_context *);
	int (*iterate_shared)(struct file___126 *, struct dir_context *);
	__poll_t (*poll)(struct file___126 *, struct poll_table_struct___85 *);
	long int (*unlocked_ioctl)(struct file___126 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___126 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___126 *, struct vm_area_struct___126 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___127 *, struct file___126 *);
	int (*flush)(struct file___126 *, fl_owner_t);
	int (*release)(struct inode___127 *, struct file___126 *);
	int (*fsync)(struct file___126 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___126 *, int);
	int (*lock)(struct file___126 *, int, struct file_lock___126 *);
	ssize_t (*sendpage)(struct file___126 *, struct page___126 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___126 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___126 *, int, struct file_lock___126 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___126 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___126 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___126 *, long int, struct file_lock___126 **, void **);
	long int (*fallocate)(struct file___126 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___116 *, struct file___126 *);
	ssize_t (*copy_file_range)(struct file___126 *, loff_t, struct file___126 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___126 *, loff_t, struct file___126 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___126 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___125 {
	u64 seqnum;
	struct vm_area_struct___126 *vmas[4];
};

struct page_frag___125 {
	struct page___126 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___77;

struct debug_info___77 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___77 *hbp_break[16];
	struct perf_event___77 *hbp_watch[16];
};

struct thread_struct___77 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___77 debug;
	long: 64;
};

struct mm_struct___125;

struct mem_cgroup___42;

struct pid___102;

struct cred___121;

struct nsproxy___118;

struct signal_struct___115;

struct bio_list___47;

struct backing_dev_info___47;

struct io_context___18;

struct css_set___102;

struct perf_event_context___77;

struct request_queue___19;

struct vm_struct___94;

struct task_struct___126 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___126 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___125 *mm;
	struct mm_struct___125 *active_mm;
	struct vmacache___125 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___126 *real_parent;
	struct task_struct___126 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___126 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___42 *active_memcg;
	long int rh_reserved2;
	struct pid___102 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___102 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___102 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___121 *ptracer_cred;
	const struct cred___121 *real_cred;
	const struct cred___121 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___118 *nsproxy;
	struct signal_struct___115 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___126 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___47 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___47 *backing_dev_info;
	struct io_context___18 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___102 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___77 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___125 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___42 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___19 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___126 *oom_reaper_list;
	struct vm_struct___94 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___77 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___77 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___126 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___77)(struct perf_event___77 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___77;

struct fasync_struct___125;

struct pid_namespace___102;

struct trace_event_call___70;

struct perf_cgroup___77;

struct perf_event___77 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___77 *group_leader;
	struct pmu___77 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___77 hw;
	struct perf_event_context___77 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___77 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___126 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___125 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___77 *);
	struct callback_head callback_head;
	struct pid_namespace___102 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___77 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___77 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___70 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___77 *cgrp;
	struct list_head sb_list;
};

struct dentry_operations___125;

struct super_block___126;

struct dentry___126 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___126 *d_parent;
	struct qstr d_name;
	struct inode___127 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___125 *d_op;
	struct super_block___126 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct rw_semaphore___126 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___126 *owner;
};

struct address_space_operations___125;

struct address_space___125 {
	struct inode___127 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___126 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___125 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___125;

struct bdi_writeback___47;

struct block_device___126;

struct inode___127 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___125 *i_op;
	struct super_block___126 *i_sb;
	struct address_space___125 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___126 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___47 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___126 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___125 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___126 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___125;

struct dentry_operations___125 {
	int (*d_revalidate)(struct dentry___126 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___126 *, unsigned int);
	int (*d_hash)(const struct dentry___126 *, struct qstr *);
	int (*d_compare)(const struct dentry___126 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___126 *);
	int (*d_init)(struct dentry___126 *);
	void (*d_release)(struct dentry___126 *);
	void (*d_prune)(struct dentry___126 *);
	void (*d_iput)(struct dentry___126 *, struct inode___127 *);
	char * (*d_dname)(struct dentry___126 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___125 *);
	int (*d_manage)(const struct path___125 *, bool);
	struct dentry___126 * (*d_real)(struct dentry___126 *, const struct inode___127 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___125;

struct mem_dqinfo___125 {
	struct quota_format_type___125 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___125;

struct quota_info___125 {
	unsigned int flags;
	struct rw_semaphore___126 dqio_sem;
	struct inode___127 *files[3];
	struct mem_dqinfo___125 info[3];
	const struct quota_format_ops___125 *ops[3];
};

struct rcuwait___125 {
	struct task_struct___126 *task;
};

struct percpu_rw_semaphore___125 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___126 rw_sem;
	struct rcuwait___125 writer;
	int readers_block;
};

struct sb_writers___125 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___125 rw_sem[3];
};

struct shrink_control___42;

struct shrinker___42 {
	long unsigned int (*count_objects)(struct shrinker___42 *, struct shrink_control___42 *);
	long unsigned int (*scan_objects)(struct shrinker___42 *, struct shrink_control___42 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___125;

struct super_operations___125;

struct dquot_operations___125;

struct quotactl_ops___125;

struct export_operations___2;

struct xattr_handler___5;

struct user_namespace___106;

struct super_block___126 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___125 *s_type;
	const struct super_operations___125 *s_op;
	const struct dquot_operations___125 *dq_op;
	const struct quotactl_ops___125 *s_qcop;
	const struct export_operations___2 *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___126 *s_root;
	struct rw_semaphore___126 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___5 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___126 *s_bdev;
	struct backing_dev_info___47 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___125 s_dquot;
	struct sb_writers___125 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___125 *s_d_op;
	int cleancache_poolid;
	struct shrinker___42 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___106 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct path___125 {
	struct vfsmount *mnt;
	struct dentry___126 *dentry;
};

struct key___121;

struct ucounts___106;

struct user_namespace___106 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___106 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___9 ns;
	long unsigned int flags;
	struct key___121 *persistent_keyring_register;
	struct rw_semaphore___126 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___106 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct shrink_control___42 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___42 *memcg;
};

struct cgroup___102;

struct cgroup_subsys___102;

struct cgroup_subsys_state___102 {
	struct cgroup___102 *cgroup;
	struct cgroup_subsys___102 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___102 *parent;
};

struct kernfs_node___122;

struct cgroup_file___102 {
	struct kernfs_node___122 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___42;

struct mem_cgroup___42 {
	struct cgroup_subsys_state___102 css;
	struct mem_cgroup_id___8 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___102 events_file;
	struct cgroup_file___102 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___126 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___42 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___126 *pgtable_t___125;

struct dev_pagemap___123;

struct page___126 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___125 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___126 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___125 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___125 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___123 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___42 *mem_cgroup;
};

struct pglist_data___125;

struct lruvec___125 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___125 *pgdat;
};

struct zone___125 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___125 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___125 {
	struct zone___125 *zone;
	int zone_idx;
};

struct zonelist___125 {
	struct zoneref___125 _zonerefs[25];
};

struct pglist_data___125 {
	struct zone___125 node_zones[3];
	struct zonelist___125 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___126 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___126 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___125 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

typedef struct pglist_data___125 pg_data_t;

struct secondary_data___126 {
	void *stack;
	struct task_struct___126 *task;
	long int status;
};

struct blocking_notifier_head___125 {
	struct rw_semaphore___126 rwsem;
	struct notifier_block *head;
};

struct xa_node {
	unsigned char shift;
	unsigned char offset;
	unsigned char count;
	unsigned char nr_values;
	struct xa_node *parent;
	struct xarray *array;
	union {
		struct list_head private_list;
		struct callback_head callback_head;
	};
	void *slots[64];
	union {
		long unsigned int tags[3];
		long unsigned int marks[3];
	};
};

struct radix_tree_iter_rh {};

struct radix_tree_iter {
	long unsigned int index;
	long unsigned int next_index;
	long unsigned int tags;
	struct xa_node *node;
	unsigned int shift;
	size_t radix_tree_iter_size_rh;
	struct radix_tree_iter_rh radix_tree_iter_rh;
};

typedef void (*radix_tree_update_node_t)(struct xa_node *);

enum {
	RADIX_TREE_ITER_TAG_MASK = 15,
	RADIX_TREE_ITER_TAGGED = 16,
	RADIX_TREE_ITER_CONTIG = 32,
};

struct upid___102 {
	int nr;
	struct pid_namespace___102 *ns;
};

struct pid_namespace___102 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___126 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___102 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___126 *proc_self;
	struct dentry___126 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___106 *user_ns;
	struct ucounts___106 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___9 ns;
};

struct pid___102 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___102 numbers[1];
};

struct anon_vma___4;

struct vm_operations_struct___123;

struct vm_area_struct___126 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___126 *vm_next;
	struct vm_area_struct___126 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___125 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma___4 *anon_vma;
	const struct vm_operations_struct___123 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___126 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___125;

struct mm_struct___125 {
	struct {
		struct vm_area_struct___126 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___126 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___126 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___125 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___126 *owner;
		struct user_namespace___106 *user_ns;
		struct file___126 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___125 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___123)(struct vm_area_struct___126 *, long unsigned int, const struct page___126 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___123)(struct page___126 *, void *);

struct device___117;

struct dev_pagemap___123 {
	dev_page_fault_t___123 page_fault;
	dev_page_free_t___123 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___117 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct fown_struct___102 {
	rwlock_t lock;
	struct pid___102 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___126 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___125 f_path;
	struct inode___127 *f_inode;
	const struct file_operations___126 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___102 f_owner;
	const struct cred___121 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___125 *f_mapping;
	errseq_t f_wb_err;
};

struct anon_vma___4 {
	struct anon_vma___4 *root;
	struct rw_semaphore___126 rwsem;
	atomic_t refcount;
	unsigned int degree;
	struct anon_vma___4 *parent;
	struct rb_root_cached rb_root;
};

struct vm_fault___123;

struct vm_operations_struct___123 {
	void (*open)(struct vm_area_struct___126 *);
	void (*close)(struct vm_area_struct___126 *);
	int (*split)(struct vm_area_struct___126 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___126 *);
	vm_fault_t (*fault)(struct vm_fault___123 *);
	vm_fault_t (*huge_fault)(struct vm_fault___123 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___123 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___126 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___123 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___123 *);
	int (*access)(struct vm_area_struct___126 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___126 *);
	int (*set_policy)(struct vm_area_struct___126 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___126 *, long unsigned int);
	struct page___126 * (*find_special_page)(struct vm_area_struct___126 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___125 {
	struct task_struct___126 *task;
	struct core_thread___125 *next;
};

struct core_state___125 {
	atomic_t nr_threads;
	struct core_thread___125 dumper;
	struct completion startup;
};

struct vm_fault___123 {
	struct vm_area_struct___126 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___126 *cow_page;
	struct mem_cgroup___42 *memcg;
	struct page___126 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___125 prealloc_pte;
};

struct user_struct___121 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___121 *uid_keyring;
	struct key___121 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___121 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___121 *session_keyring;
	struct key___121 *process_keyring;
	struct key___121 *thread_keyring;
	struct key___121 *request_key_auth;
	void *security;
	struct user_struct___121 *user;
	struct user_namespace___106 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___102;

struct nsproxy___118 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___102 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___102 *cgroup_ns;
};

struct signal_struct___115 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___126 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___126 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___102 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___102 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___125 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___102 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___47;

struct bio_list___47 {
	struct bio___47 *head;
	struct bio___47 *tail;
};

struct bdi_writeback_congested___47;

struct bdi_writeback___47 {
	struct backing_dev_info___47 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___47 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___102 *memcg_css;
	struct cgroup_subsys_state___102 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___47 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___47 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___117 *dev;
	struct device___117 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___126 *debug_dir;
	struct dentry___126 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___18;

struct io_context___18 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___18 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___102 {
	struct cgroup_subsys_state___102 *subsys[13];
	refcount_t refcount;
	struct css_set___102 *dom_cset;
	struct cgroup___102 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___102 *mg_src_cgrp;
	struct cgroup___102 *mg_dst_cgrp;
	struct css_set___102 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___77 {
	struct pmu___77 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___126 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___77 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

typedef blk_qc_t make_request_fn___18(struct request_queue___19 *, struct bio___47 *);

struct request___19;

typedef int dma_drain_needed_fn___18(struct request___19 *);

struct kset___119;

struct kobj_type___119;

struct kobject___120 {
	const char *name;
	struct list_head entry;
	struct kobject___120 *parent;
	struct kset___119 *kset;
	struct kobj_type___119 *ktype;
	struct kernfs_node___122 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___18;

struct bsg_class_device___18 {
	struct device___117 *class_dev;
	int minor;
	struct request_queue___19 *queue;
	const struct bsg_ops___18 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___47 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___47 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___18;

struct blkcg_gq___11;

struct request_queue___19 {
	struct list_head queue_head;
	struct request___19 *last_merge;
	struct elevator_queue___18 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___18 *make_request_fn;
	dma_drain_needed_fn___18 *dma_drain_needed;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___47 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___120 kobj;
	struct kobject___120 *mq_kobj;
	struct blk_integrity integrity;
	struct device___117 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___11 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	struct bsg_class_device___18 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___47 bio_split;
	struct dentry___126 *debugfs_dir;
	struct dentry___126 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___94 {
	struct vm_struct___94 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___126 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___115 {
	struct task_struct___126 task;
	long unsigned int stack[8192];
};

struct io_cq___18 {
	struct request_queue___19 *q;
	struct io_context___18 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___126 {
	struct file___126 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___126 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___126 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___126 *ia_file;
};

struct dquot___125 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___126 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___125 {
	int qf_fmt_id;
	const struct quota_format_ops___125 *qf_ops;
	struct module___108 *qf_owner;
	struct quota_format_type___125 *qf_next;
};

struct quota_format_ops___125 {
	int (*check_quota_file)(struct super_block___126 *, int);
	int (*read_file_info)(struct super_block___126 *, int);
	int (*write_file_info)(struct super_block___126 *, int);
	int (*free_file_info)(struct super_block___126 *, int);
	int (*read_dqblk)(struct dquot___125 *);
	int (*commit_dqblk)(struct dquot___125 *);
	int (*release_dqblk)(struct dquot___125 *);
	int (*get_next_id)(struct super_block___126 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___125 {
	int (*write_dquot)(struct dquot___125 *);
	struct dquot___125 * (*alloc_dquot)(struct super_block___126 *, int);
	void (*destroy_dquot)(struct dquot___125 *);
	int (*acquire_dquot)(struct dquot___125 *);
	int (*release_dquot)(struct dquot___125 *);
	int (*mark_dirty)(struct dquot___125 *);
	int (*write_info)(struct super_block___126 *, int);
	qsize_t * (*get_reserved_space)(struct inode___127 *);
	int (*get_projid)(struct inode___127 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___127 *, qsize_t *);
	int (*get_next_id)(struct super_block___126 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___125 {
	int (*quota_on)(struct super_block___126 *, int, int, const struct path___125 *);
	int (*quota_off)(struct super_block___126 *, int);
	int (*quota_enable)(struct super_block___126 *, unsigned int);
	int (*quota_disable)(struct super_block___126 *, unsigned int);
	int (*quota_sync)(struct super_block___126 *, int);
	int (*set_info)(struct super_block___126 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___126 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___126 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___126 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___126 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___126 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___105 {
	struct kobject___120 kobj;
	struct module___108 *mod;
	struct kobject___120 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___105 {
	struct module___108 *mod;
	struct latch_tree_node node;
};

struct module_layout___105 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___105 mtn;
};

struct module_attribute___105;

struct kernel_param___105;

struct module___108 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___105 mkobj;
	struct module_attribute___105 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___120 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___105 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___105 core_layout;
	struct module_layout___105 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___70 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide48;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide49;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

enum positive_aop_returns {
	AOP_WRITEPAGE_ACTIVATE = 524288,
	AOP_TRUNCATED_PAGE = 524289,
};

struct writeback_control___44;

struct swap_info_struct___29;

struct address_space_operations___125 {
	int (*writepage)(struct page___126 *, struct writeback_control___44 *);
	int (*readpage)(struct file___126 *, struct page___126 *);
	int (*writepages)(struct address_space___125 *, struct writeback_control___44 *);
	int (*set_page_dirty)(struct page___126 *);
	int (*readpages)(struct file___126 *, struct address_space___125 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___126 *, struct address_space___125 *, loff_t, unsigned int, unsigned int, struct page___126 **, void **);
	int (*write_end)(struct file___126 *, struct address_space___125 *, loff_t, unsigned int, unsigned int, struct page___126 *, void *);
	sector_t (*bmap)(struct address_space___125 *, sector_t);
	void (*invalidatepage)(struct page___126 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___126 *, gfp_t);
	void (*freepage)(struct page___126 *);
	ssize_t (*direct_IO)(struct kiocb___126 *, struct iov_iter___53 *);
	int (*migratepage)(struct address_space___125 *, struct page___126 *, struct page___126 *, enum migrate_mode);
	bool (*isolate_page)(struct page___126 *, isolate_mode_t);
	void (*putback_page)(struct page___126 *);
	int (*launder_page)(struct page___126 *);
	int (*is_partially_uptodate)(struct page___126 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___126 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___125 *, struct page___126 *);
	int (*swap_activate)(struct swap_info_struct___29 *, struct file___126 *, sector_t *);
	void (*swap_deactivate)(struct file___126 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___44 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___47 *wb;
	struct inode___127 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___47;

struct iov_iter___53 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___47 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct swap_info_struct___29 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___126 *bdev;
	struct file___126 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct hd_struct___19;

struct gendisk___19;

struct block_device___126 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___127 *bd_inode;
	struct super_block___126 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___126 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___19 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___19 *bd_disk;
	struct request_queue___19 *bd_queue;
	struct backing_dev_info___47 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___117 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___117 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___117;

struct bus_type___117;

struct device_driver___117;

struct dev_pm_domain___117;

struct fwnode_handle___87;

struct class___117;

struct attribute_group___116;

struct device___117 {
	struct device___117 *parent;
	struct device_private *p;
	struct kobject___120 kobj;
	const char *init_name;
	const struct device_type___117 *type;
	struct mutex mutex;
	struct bus_type___117 *bus;
	struct device_driver___117 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___117 power;
	struct dev_pm_domain___117 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___87 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___117 *class;
	const struct attribute_group___116 **groups;
	void (*release)(struct device___117 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___19 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___117 __dev;
	struct kobject___120 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___19;

struct block_device_operations___19;

struct gendisk___19 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___19 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___19 *part_tbl;
	struct hd_struct___19 part0;
	const struct block_device_operations___19 *fops;
	struct request_queue___19 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___126 lookup_sem;
	struct kobject___120 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___120 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___125 {
	struct dentry___126 * (*lookup)(struct inode___127 *, struct dentry___126 *, unsigned int);
	const char * (*get_link)(struct dentry___126 *, struct inode___127 *, struct delayed_call *);
	int (*permission)(struct inode___127 *, int);
	struct posix_acl * (*get_acl)(struct inode___127 *, int);
	int (*readlink)(struct dentry___126 *, char *, int);
	int (*create)(struct inode___127 *, struct dentry___126 *, umode_t, bool);
	int (*link)(struct dentry___126 *, struct inode___127 *, struct dentry___126 *);
	int (*unlink)(struct inode___127 *, struct dentry___126 *);
	int (*symlink)(struct inode___127 *, struct dentry___126 *, const char *);
	int (*mkdir)(struct inode___127 *, struct dentry___126 *, umode_t);
	int (*rmdir)(struct inode___127 *, struct dentry___126 *);
	int (*mknod)(struct inode___127 *, struct dentry___126 *, umode_t, dev_t);
	int (*rename)(struct inode___127 *, struct dentry___126 *, struct inode___127 *, struct dentry___126 *, unsigned int);
	int (*setattr)(struct dentry___126 *, struct iattr___126 *);
	int (*getattr)(const struct path___125 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___126 *, char *, size_t);
	int (*fiemap)(struct inode___127 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___127 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___127 *, struct dentry___126 *, struct file___126 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___127 *, struct dentry___126 *, umode_t);
	int (*set_acl)(struct inode___127 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___125 {
	void (*fl_copy_lock)(struct file_lock___126 *, struct file_lock___126 *);
	void (*fl_release_private)(struct file_lock___126 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___125;

struct file_lock___126 {
	struct file_lock___126 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___126 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___125 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___125 *fl_ops;
	const struct lock_manager_operations___125 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___125 {
	int (*lm_compare_owner)(struct file_lock___126 *, struct file_lock___126 *);
	long unsigned int (*lm_owner_key)(struct file_lock___126 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___126 *);
	int (*lm_grant)(struct file_lock___126 *, int);
	bool (*lm_break)(struct file_lock___126 *);
	int (*lm_change)(struct file_lock___126 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___126 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___125 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___125 *fa_next;
	struct file___126 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___125 {
	const char *name;
	int fs_flags;
	struct dentry___126 * (*mount)(struct file_system_type___125 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___126 *);
	struct module___108 *owner;
	struct file_system_type___125 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___125 {
	struct inode___127 * (*alloc_inode)(struct super_block___126 *);
	void (*destroy_inode)(struct inode___127 *);
	void (*dirty_inode)(struct inode___127 *, int);
	int (*write_inode)(struct inode___127 *, struct writeback_control___44 *);
	int (*drop_inode)(struct inode___127 *);
	void (*evict_inode)(struct inode___127 *);
	void (*put_super)(struct super_block___126 *);
	int (*sync_fs)(struct super_block___126 *, int);
	int (*freeze_super)(struct super_block___126 *);
	int (*freeze_fs)(struct super_block___126 *);
	int (*thaw_super)(struct super_block___126 *);
	int (*unfreeze_fs)(struct super_block___126 *);
	int (*statfs)(struct dentry___126 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___126 *, int *, char *);
	void (*umount_begin)(struct super_block___126 *);
	int (*show_options)(struct seq_file___116 *, struct dentry___126 *);
	int (*show_devname)(struct seq_file___116 *, struct dentry___126 *);
	int (*show_path)(struct seq_file___116 *, struct dentry___126 *);
	int (*show_stats)(struct seq_file___116 *, struct dentry___126 *);
	ssize_t (*quota_read)(struct super_block___126 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___126 *, int, const char *, size_t, loff_t);
	struct dquot___125 ** (*get_dquots)(struct inode___127 *);
	int (*bdev_try_to_free_page)(struct super_block___126 *, struct page___126 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___126 *, struct shrink_control___42 *);
	long int (*free_cached_objects)(struct super_block___126 *, struct shrink_control___42 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct export_operations___2 {
	int (*encode_fh)(struct inode___127 *, __u32 *, int *, struct inode___127 *);
	struct dentry___126 * (*fh_to_dentry)(struct super_block___126 *, struct fid *, int, int);
	struct dentry___126 * (*fh_to_parent)(struct super_block___126 *, struct fid *, int, int);
	int (*get_name)(struct dentry___126 *, char *, struct dentry___126 *);
	struct dentry___126 * (*get_parent)(struct dentry___126 *);
	int (*commit_metadata)(struct inode___127 *);
	int (*get_uuid)(struct super_block___126 *, u8 *, u32 *, u64 *);
	int (*map_blocks)(struct inode___127 *, loff_t, u64, struct iomap *, bool, u32 *);
	int (*commit_blocks)(struct inode___127 *, struct iomap *, int, struct iattr___126 *);
};

struct xattr_handler___5 {
	const char *name;
	const char *prefix;
	int flags;
	bool (*list)(struct dentry___126 *);
	int (*get)(const struct xattr_handler___5 *, struct dentry___126 *, struct inode___127 *, const char *, void *, size_t);
	int (*set)(const struct xattr_handler___5 *, struct dentry___126 *, struct inode___127 *, const char *, const void *, size_t, int);
};

typedef void (*poll_queue_proc___84)(struct file___126 *, wait_queue_head_t *, struct poll_table_struct___85 *);

struct poll_table_struct___85 {
	poll_queue_proc___84 _qproc;
	__poll_t _key;
};

struct seq_operations___114;

struct seq_file___116 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___114 *op;
	int poll_event;
	const struct file___126 *file;
	void *private;
};

typedef void bio_end_io_t___47(struct bio___47 *);

struct bio_vec___47 {
	struct page___126 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___47;

struct bio___47 {
	struct bio___47 *bi_next;
	struct gendisk___19 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___47 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___11 *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___47 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___47 *bi_io_vec;
	struct bio_set___47 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___47 bi_inline_vecs[0];
};

struct kobj_attribute___120 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___120 *, struct kobj_attribute___120 *, char *);
	ssize_t (*store)(struct kobject___120 *, struct kobj_attribute___120 *, const char *, size_t);
};

typedef void compound_page_dtor___123(struct page___126 *);

struct bin_attribute___116;

struct attribute_group___116 {
	const char *name;
	umode_t (*is_visible)(struct kobject___120 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___120 *, struct bin_attribute___116 *, int);
	struct attribute **attrs;
	struct bin_attribute___116 **bin_attrs;
};

typedef int (*key_restrict_link_func_t___121)(struct key___121 *, const struct key_type *, const union key_payload *, struct key___121 *);

struct key_restriction___121;

struct key___121 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___126 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___121 *restrict_link;
};

struct key_restriction___121 {
	key_restrict_link_func_t___121 check;
	struct key___121 *key;
	struct key_type *keytype;
};

struct seq_operations___114 {
	void * (*start)(struct seq_file___116 *, loff_t *);
	void (*stop)(struct seq_file___116 *, void *);
	void * (*next)(struct seq_file___116 *, void *, loff_t *);
	int (*show)(struct seq_file___116 *, void *);
};

struct kernfs_root___122;

struct kernfs_elem_dir___122 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___122 *root;
};

struct kernfs_syscall_ops___122;

struct kernfs_root___122 {
	struct kernfs_node___122 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___122 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___122 {
	struct kernfs_node___122 *target_kn;
};

struct kernfs_ops___122;

struct kernfs_elem_attr___122 {
	const struct kernfs_ops___122 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___122 *notify_next;
};

struct kernfs_node___122 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___122 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___122 dir;
		struct kernfs_elem_symlink___122 symlink;
		struct kernfs_elem_attr___122 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___122;

struct kernfs_ops___122 {
	int (*open)(struct kernfs_open_file___122 *);
	void (*release)(struct kernfs_open_file___122 *);
	int (*seq_show)(struct seq_file___116 *, void *);
	void * (*seq_start)(struct seq_file___116 *, loff_t *);
	void * (*seq_next)(struct seq_file___116 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___116 *, void *);
	ssize_t (*read)(struct kernfs_open_file___122 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___122 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___122 *, struct vm_area_struct___126 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___122 *, struct poll_table_struct___85 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___122 {
	int (*remount_fs)(struct kernfs_root___122 *, int *, char *);
	int (*show_options)(struct seq_file___116 *, struct kernfs_root___122 *);
	int (*mkdir)(struct kernfs_node___122 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___122 *);
	int (*rename)(struct kernfs_node___122 *, struct kernfs_node___122 *, const char *);
	int (*show_path)(struct seq_file___116 *, struct kernfs_node___122 *, struct kernfs_root___122 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___122 {
	struct kernfs_node___122 *kn;
	struct file___126 *file;
	struct seq_file___116 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___123 *vm_ops;
};

struct cgroup_namespace___102 {
	refcount_t count;
	struct ns_common___9 ns;
	struct user_namespace___106 *user_ns;
	struct ucounts___106 *ucounts;
	struct css_set___102 *root_cset;
};

struct ucounts___106 {
	struct hlist_node node;
	struct user_namespace___106 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___102;

struct bpf_map_ops___102 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___102 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___102 *, struct file___126 *);
	void (*map_free)(struct bpf_map___102 *);
	int (*map_get_next_key)(struct bpf_map___102 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___102 *);
	void * (*map_lookup_elem)(struct bpf_map___102 *, void *);
	int (*map_update_elem)(struct bpf_map___102 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___102 *, void *);
	int (*map_push_elem)(struct bpf_map___102 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___102 *, void *);
	int (*map_peek_elem)(struct bpf_map___102 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___102 *, struct file___126 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___102 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___102 *, void *, struct seq_file___116 *);
	int (*map_check_btf)(const struct bpf_map___102 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___102 {
	const struct bpf_map_ops___102 *ops;
	struct bpf_map___102 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___121 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___102;

typedef void (*kthread_work_func_t___102)(struct kthread_work___102 *);

struct kthread_worker___102;

struct kthread_work___102 {
	struct list_head node;
	kthread_work_func_t___102 func;
	struct kthread_worker___102 *worker;
	int canceling;
};

struct kthread_worker___102 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___126 *task;
	struct kthread_work___102 *current_work;
};

struct kthread_delayed_work___102 {
	struct kthread_work___102 work;
	struct timer_list timer;
};

struct psi_group___102 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___102 *poll_kworker;
	struct kthread_delayed_work___102 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___102;

struct cgroup_rstat_cpu___102;

struct cgroup___102 {
	struct cgroup_subsys_state___102 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___122 *kn;
	struct cgroup_file___102 procs_file;
	struct cgroup_file___102 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___102 *subsys[13];
	struct cgroup_root___102 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___102 *dom_cgrp;
	struct cgroup_rstat_cpu___102 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___19 bpf;
	atomic_t congestion_count;
	struct cgroup___102 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___102 psi;
	int ancestor_ids[0];
};

struct cftype___102;

struct cgroup_subsys___102 {
	struct cgroup_subsys_state___102 * (*css_alloc)(struct cgroup_subsys_state___102 *);
	int (*css_online)(struct cgroup_subsys_state___102 *);
	void (*css_offline)(struct cgroup_subsys_state___102 *);
	void (*css_released)(struct cgroup_subsys_state___102 *);
	void (*css_free)(struct cgroup_subsys_state___102 *);
	void (*css_reset)(struct cgroup_subsys_state___102 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___102 *, int);
	int (*css_extra_stat_show)(struct seq_file___116 *, struct cgroup_subsys_state___102 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___126 *);
	void (*cancel_fork)(struct task_struct___126 *);
	void (*fork)(struct task_struct___126 *);
	void (*exit)(struct task_struct___126 *);
	void (*free)(struct task_struct___126 *);
	void (*bind)(struct cgroup_subsys_state___102 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___102 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___102 *dfl_cftypes;
	struct cftype___102 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___102 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___102 *updated_children;
	struct cgroup___102 *updated_next;
};

struct cgroup_root___102 {
	struct kernfs_root___122 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___102 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___102 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___102 *ss;
	struct list_head node;
	struct kernfs_ops___122 *kf_ops;
	int (*open)(struct kernfs_open_file___122 *);
	void (*release)(struct kernfs_open_file___122 *);
	u64 (*read_u64)(struct cgroup_subsys_state___102 *, struct cftype___102 *);
	s64 (*read_s64)(struct cgroup_subsys_state___102 *, struct cftype___102 *);
	int (*seq_show)(struct seq_file___116 *, void *);
	void * (*seq_start)(struct seq_file___116 *, loff_t *);
	void * (*seq_next)(struct seq_file___116 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___116 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___102 *, struct cftype___102 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___102 *, struct cftype___102 *, s64);
	ssize_t (*write)(struct kernfs_open_file___122 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___122 *, struct poll_table_struct___85 *);
};

struct bdi_writeback_congested___47 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___47 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___47 {
	struct bio___47 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___47 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___47 bip_inline_vecs[0];
};

struct blkcg___11;

struct blkg_policy_data___11;

struct blkcg_gq___11 {
	struct request_queue___19 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___11 *blkcg;
	struct bdi_writeback_congested___47 *wb_congested;
	struct blkcg_gq___11 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_rwstat stat_bytes;
	struct blkg_rwstat stat_ios;
	struct blkg_policy_data___11 *pd[5];
	struct callback_head callback_head;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
};

struct mem_cgroup_reclaim_iter___42 {
	struct mem_cgroup___42 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___42 {
	struct lruvec___125 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___42 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___42 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct bin_attribute___116 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___126 *, struct kobject___120 *, struct bin_attribute___116 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___126 *, struct kobject___120 *, struct bin_attribute___116 *, char *, loff_t, size_t);
	int (*mmap)(struct file___126 *, struct kobject___120 *, struct bin_attribute___116 *, struct vm_area_struct___126 *);
};

struct sysfs_ops___119 {
	ssize_t (*show)(struct kobject___120 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___120 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___119;

struct kset___119 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___120 kobj;
	const struct kset_uevent_ops___119 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___119 {
	void (*release)(struct kobject___120 *);
	const struct sysfs_ops___119 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___9 * (*child_ns_type)(struct kobject___120 *);
	const void * (*namespace)(struct kobject___120 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___119 {
	int (* const filter)(struct kset___119 *, struct kobject___120 *);
	const char * (* const name)(struct kset___119 *, struct kobject___120 *);
	int (* const uevent)(struct kset___119 *, struct kobject___120 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___117 {
	int (*prepare)(struct device___117 *);
	void (*complete)(struct device___117 *);
	int (*suspend)(struct device___117 *);
	int (*resume)(struct device___117 *);
	int (*freeze)(struct device___117 *);
	int (*thaw)(struct device___117 *);
	int (*poweroff)(struct device___117 *);
	int (*restore)(struct device___117 *);
	int (*suspend_late)(struct device___117 *);
	int (*resume_early)(struct device___117 *);
	int (*freeze_late)(struct device___117 *);
	int (*thaw_early)(struct device___117 *);
	int (*poweroff_late)(struct device___117 *);
	int (*restore_early)(struct device___117 *);
	int (*suspend_noirq)(struct device___117 *);
	int (*resume_noirq)(struct device___117 *);
	int (*freeze_noirq)(struct device___117 *);
	int (*thaw_noirq)(struct device___117 *);
	int (*poweroff_noirq)(struct device___117 *);
	int (*restore_noirq)(struct device___117 *);
	int (*runtime_suspend)(struct device___117 *);
	int (*runtime_resume)(struct device___117 *);
	int (*runtime_idle)(struct device___117 *);
};

struct dev_pm_domain___117 {
	struct dev_pm_ops___117 ops;
	void (*detach)(struct device___117 *, bool);
	int (*activate)(struct device___117 *);
	void (*sync)(struct device___117 *);
	void (*dismiss)(struct device___117 *);
};

struct bus_type___117 {
	const char *name;
	const char *dev_name;
	struct device___117 *dev_root;
	const struct attribute_group___116 **bus_groups;
	const struct attribute_group___116 **dev_groups;
	const struct attribute_group___116 **drv_groups;
	int (*match)(struct device___117 *, struct device_driver___117 *);
	int (*uevent)(struct device___117 *, struct kobj_uevent_env *);
	int (*probe)(struct device___117 *);
	int (*remove)(struct device___117 *);
	void (*shutdown)(struct device___117 *);
	int (*online)(struct device___117 *);
	int (*offline)(struct device___117 *);
	int (*suspend)(struct device___117 *, pm_message_t);
	int (*resume)(struct device___117 *);
	int (*num_vf)(struct device___117 *);
	int (*dma_configure)(struct device___117 *);
	const struct dev_pm_ops___117 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___117 {
	const char *name;
	struct bus_type___117 *bus;
	struct module___108 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___117 *);
	int (*remove)(struct device___117 *);
	void (*shutdown)(struct device___117 *);
	int (*suspend)(struct device___117 *, pm_message_t);
	int (*resume)(struct device___117 *);
	const struct attribute_group___116 **groups;
	const struct dev_pm_ops___117 *pm;
	void (*coredump)(struct device___117 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___117 {
	const char *name;
	const struct attribute_group___116 **groups;
	int (*uevent)(struct device___117 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___117 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___117 *);
	const struct dev_pm_ops___117 *pm;
};

struct class___117 {
	const char *name;
	struct module___108 *owner;
	const struct attribute_group___116 **class_groups;
	const struct attribute_group___116 **dev_groups;
	struct kobject___120 *dev_kobj;
	int (*dev_uevent)(struct device___117 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___117 *, umode_t *);
	void (*class_release)(struct class___117 *);
	void (*dev_release)(struct device___117 *);
	int (*shutdown_pre)(struct device___117 *);
	const struct kobj_ns_type_operations___9 *ns_type;
	const void * (*namespace)(struct device___117 *);
	const struct dev_pm_ops___117 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct fwnode_operations___87;

struct fwnode_handle___87 {
	struct fwnode_handle___87 *secondary;
	const struct fwnode_operations___87 *ops;
};

struct node___97 {
	struct device___117 dev;
};

enum mapping_flags {
	AS_EIO = 0,
	AS_ENOSPC = 1,
	AS_MM_ALL_LOCKS = 2,
	AS_UNEVICTABLE = 3,
	AS_EXITING = 4,
	AS_NO_WRITEBACK_TAGS = 5,
};

typedef int filler_t___2(void *, struct page___126 *);

enum {
	ITER_IOVEC = 0,
	ITER_KVEC = 2,
	ITER_BVEC = 4,
	ITER_PIPE = 8,
};

struct disk_part_tbl___19 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___19 *last_lookup;
	struct hd_struct___19 *part[0];
};

struct block_device_operations___19 {
	int (*open)(struct block_device___126 *, fmode_t);
	void (*release)(struct gendisk___19 *, fmode_t);
	int (*rw_page)(struct block_device___126 *, sector_t, struct page___126 *, unsigned int);
	int (*ioctl)(struct block_device___126 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___126 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___19 *, unsigned int);
	int (*media_changed)(struct gendisk___19 *);
	void (*unlock_native_capacity)(struct gendisk___19 *);
	int (*revalidate_disk)(struct gendisk___19 *);
	int (*getgeo)(struct block_device___126 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___126 *, long unsigned int);
	int (*report_zones)(struct gendisk___19 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___108 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___18 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___19 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___19 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___19 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___18(struct request___19 *, blk_status_t);

struct request___19 {
	struct request_queue___19 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___47 *bio;
	struct bio___47 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___47 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___18 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___18 *saved_end_io;
		} flush;
	};
	struct gendisk___19 *rq_disk;
	struct hd_struct___19 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___18 *end_io;
	void *end_io_data;
	struct request___19 *next_rq;
};

struct fwnode_reference_args___87;

struct fwnode_endpoint___87;

struct fwnode_operations___87 {
	struct fwnode_handle___87 * (*get)(struct fwnode_handle___87 *);
	void (*put)(struct fwnode_handle___87 *);
	bool (*device_is_available)(const struct fwnode_handle___87 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___87 *, const struct device___117 *);
	bool (*property_present)(const struct fwnode_handle___87 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___87 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___87 *, const char *, const char **, size_t);
	struct fwnode_handle___87 * (*get_parent)(const struct fwnode_handle___87 *);
	struct fwnode_handle___87 * (*get_next_child_node)(const struct fwnode_handle___87 *, struct fwnode_handle___87 *);
	struct fwnode_handle___87 * (*get_named_child_node)(const struct fwnode_handle___87 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___87 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___87 *);
	struct fwnode_handle___87 * (*graph_get_next_endpoint)(const struct fwnode_handle___87 *, struct fwnode_handle___87 *);
	struct fwnode_handle___87 * (*graph_get_remote_endpoint)(const struct fwnode_handle___87 *);
	struct fwnode_handle___87 * (*graph_get_port_parent)(struct fwnode_handle___87 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___87 *, struct fwnode_endpoint___87 *);
};

struct fwnode_endpoint___87 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___87 *local_fwnode;
};

struct fwnode_reference_args___87 {
	struct fwnode_handle___87 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct elevator_type___18;

struct elevator_mq_ops___18 {
	int (*init_sched)(struct request_queue___19 *, struct elevator_type___18 *);
	void (*exit_sched)(struct elevator_queue___18 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	bool (*allow_merge)(struct request_queue___19 *, struct request___19 *, struct bio___47 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx *, struct bio___47 *);
	int (*request_merge)(struct request_queue___19 *, struct request___19 **, struct bio___47 *);
	void (*request_merged)(struct request_queue___19 *, struct request___19 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___19 *, struct request___19 *, struct request___19 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___19 *, struct bio___47 *);
	void (*finish_request)(struct request___19 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___19 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___19 *, u64);
	void (*started_request)(struct request___19 *);
	void (*requeue_request)(struct request___19 *);
	struct request___19 * (*former_request)(struct request_queue___19 *, struct request___19 *);
	struct request___19 * (*next_request)(struct request_queue___19 *, struct request___19 *);
	void (*init_icq)(struct io_cq___18 *);
	void (*exit_icq)(struct io_cq___18 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___18;

struct elevator_type___18 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___18 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___18 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___108 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___18 {
	struct elevator_type___18 *type;
	void *elevator_data;
	struct kobject___120 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___18 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___18 *, char *);
	ssize_t (*store)(struct elevator_queue___18 *, const char *, size_t);
};

struct blkcg_policy_data___11;

struct blkcg___11 {
	struct cgroup_subsys_state___102 css;
	spinlock_t lock;
	struct xarray blkg_tree;
	struct blkcg_gq___11 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___11 *cpd[5];
	struct list_head all_blkcgs_node;
	struct list_head cgwb_list;
	refcount_t cgwb_refcnt;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct blkcg_policy_data___11 {
	struct blkcg___11 *blkcg;
	int plid;
};

struct blkg_policy_data___11 {
	struct blkcg_gq___11 *blkg;
	int plid;
};

struct pagevec {
	unsigned char nr;
	bool percpu_pvec_drained;
	struct page___126 *pages[15];
};

struct hstate___12 {
	int next_nid_to_alloc;
	int next_nid_to_free;
	unsigned int order;
	long unsigned int mask;
	long unsigned int max_huge_pages;
	long unsigned int nr_huge_pages;
	long unsigned int free_huge_pages;
	long unsigned int resv_huge_pages;
	long unsigned int surplus_huge_pages;
	long unsigned int nr_overcommit_huge_pages;
	struct list_head hugepage_activelist;
	struct list_head hugepage_freelists[8];
	unsigned int nr_huge_pages_node[8];
	unsigned int free_huge_pages_node[8];
	unsigned int surplus_huge_pages_node[8];
	struct cftype___102 cgroup_files[5];
	char name[32];
};

struct fid {
	union {
		struct {
			u32 ino;
			u32 gen;
			u32 parent_ino;
			u32 parent_gen;
		} i32;
		struct {
			u32 block;
			u16 partref;
			u16 parent_partref;
			u32 generation;
			u32 parent_block;
			u32 parent_generation;
		} udf;
		__u32 raw[0];
	};
};

struct kernel_param_ops___105 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___105 *);
	int (*get)(char *, const struct kernel_param___105 *);
	void (*free)(void *);
};

struct kparam_array___105;

struct kernel_param___105 {
	const char *name;
	struct module___108 *mod;
	const struct kernel_param_ops___105 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___105 *arr;
	};
};

struct kparam_array___105 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___105 *ops;
	void *elem;
};

struct module_attribute___105 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___105 *, struct module_kobject___105 *, char *);
	ssize_t (*store)(struct module_attribute___105 *, struct module_kobject___105 *, const char *, size_t);
	void (*setup)(struct module___108 *, const char *);
	int (*test)(struct module___108 *);
	void (*free)(struct module___108 *);
};

struct trace_event_class___70;

struct trace_event_call___70 {
	struct list_head list;
	struct trace_event_class___70 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___13 event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___19 *prog_array;
	int (*perf_perm)(struct trace_event_call___70 *, struct perf_event___77 *);
};

struct perf_cpu_context___77;

struct pmu___77 {
	struct list_head entry;
	struct module___108 *module;
	struct device___117 *dev;
	const struct attribute_group___116 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___77 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___77 *);
	void (*pmu_disable)(struct pmu___77 *);
	int (*event_init)(struct perf_event___77 *);
	void (*event_mapped)(struct perf_event___77 *, struct mm_struct___125 *);
	void (*event_unmapped)(struct perf_event___77 *, struct mm_struct___125 *);
	int (*add)(struct perf_event___77 *, int);
	void (*del)(struct perf_event___77 *, int);
	void (*start)(struct perf_event___77 *, int);
	void (*stop)(struct perf_event___77 *, int);
	void (*read)(struct perf_event___77 *);
	void (*start_txn)(struct pmu___77 *, unsigned int);
	int (*commit_txn)(struct pmu___77 *);
	void (*cancel_txn)(struct pmu___77 *);
	int (*event_idx)(struct perf_event___77 *);
	void (*sched_task)(struct perf_event_context___77 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___77 *);
	int (*filter_match)(struct perf_event___77 *);
	int (*check_period)(struct perf_event___77 *, u64);
};

struct perf_cpu_context___77 {
	struct perf_event_context___77 ctx;
	struct perf_event_context___77 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___77 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___77 {
	struct cgroup_subsys_state___102 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___70 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___70 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___70 *);
	struct list_head * (*get_fields)(struct trace_event_call___70 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___70 *);
};

struct trace_event_file___33;

struct trace_event_buffer___25 {
	struct ring_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___33 *trace_file;
	void *entry;
	long unsigned int flags;
	int pc;
};

struct trace_event_file___33 {
	struct list_head list;
	struct trace_event_call___70 *event_call;
	struct event_filter *filter;
	struct dentry___126 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_mm_filemap_op_page_cache {
	struct trace_entry ent;
	long unsigned int pfn;
	long unsigned int i_ino;
	long unsigned int index;
	dev_t s_dev;
	char __data[0];
};

struct trace_event_raw_filemap_set_wb_err {
	struct trace_entry ent;
	long unsigned int i_ino;
	dev_t s_dev;
	errseq_t errseq;
	char __data[0];
};

struct trace_event_raw_file_check_and_advance_wb_err {
	struct trace_entry ent;
	struct file___126 *file;
	long unsigned int i_ino;
	dev_t s_dev;
	errseq_t old;
	errseq_t new;
	char __data[0];
};

struct trace_event_data_offsets_mm_filemap_op_page_cache {};

struct trace_event_data_offsets_filemap_set_wb_err {};

struct trace_event_data_offsets_file_check_and_advance_wb_err {};

struct wait_page_key {
	struct page___126 *page;
	int bit_nr;
	int page_match;
};

struct wait_page_queue {
	struct page___126 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

enum behavior {
	EXCLUSIVE = 0,
	SHARED = 1,
	DROP = 2,
};

struct file___127;

struct kiocb___127;

struct vm_area_struct___127;

struct inode___128;

struct file_lock___127;

struct page___127;

struct seq_file___117;

struct file_operations___127 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___127 *, loff_t, int);
	ssize_t (*read)(struct file___127 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___127 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___127 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___127 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___127 *, bool);
	int (*iterate)(struct file___127 *, struct dir_context *);
	int (*iterate_shared)(struct file___127 *, struct dir_context *);
	__poll_t (*poll)(struct file___127 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___127 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___127 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___127 *, struct vm_area_struct___127 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___128 *, struct file___127 *);
	int (*flush)(struct file___127 *, fl_owner_t);
	int (*release)(struct inode___128 *, struct file___127 *);
	int (*fsync)(struct file___127 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___127 *, int);
	int (*lock)(struct file___127 *, int, struct file_lock___127 *);
	ssize_t (*sendpage)(struct file___127 *, struct page___127 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___127 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___127 *, int, struct file_lock___127 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___127 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___127 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___127 *, long int, struct file_lock___127 **, void **);
	long int (*fallocate)(struct file___127 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___117 *, struct file___127 *);
	ssize_t (*copy_file_range)(struct file___127 *, loff_t, struct file___127 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___127 *, loff_t, struct file___127 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___127 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___126 {
	u64 seqnum;
	struct vm_area_struct___127 *vmas[4];
};

struct page_frag___126 {
	struct page___127 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___126;

struct mem_cgroup___43;

struct cred___122;

struct nsproxy___119;

struct bio_list___48;

struct backing_dev_info___48;

struct io_context___19;

struct css_set___103;

struct request_queue___20;

struct vm_struct___95;

struct task_struct___127 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___127 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___126 *mm;
	struct mm_struct___126 *active_mm;
	struct vmacache___126 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___127 *real_parent;
	struct task_struct___127 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___127 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___43 *active_memcg;
	long int rh_reserved2;
	struct pid___102 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___102 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___102 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___122 *ptracer_cred;
	const struct cred___122 *real_cred;
	const struct cred___122 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___119 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___127 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___48 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___48 *backing_dev_info;
	struct io_context___19 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___103 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___126 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___43 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___20 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___127 *oom_reaper_list;
	struct vm_struct___95 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___77 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___127 *pgtable_t___126;

struct address_space___126;

struct dev_pagemap___124;

struct page___127 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___126 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___127 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___126 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___126 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___124 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___43 *mem_cgroup;
};

struct pglist_data___126;

struct lruvec___126 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___126 *pgdat;
};

struct zone___126 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___126 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___126 {
	struct zone___126 *zone;
	int zone_idx;
};

struct zonelist___126 {
	struct zoneref___126 _zonerefs[25];
};

struct pglist_data___126 {
	struct zone___126 node_zones[3];
	struct zonelist___126 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___127 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___127 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___126 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___127 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___127 *owner;
};

struct secondary_data___127 {
	void *stack;
	struct task_struct___127 *task;
	long int status;
};

struct blocking_notifier_head___126 {
	struct rw_semaphore___127 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___124;

struct vm_area_struct___127 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___127 *vm_next;
	struct vm_area_struct___127 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___126 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___124 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___127 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___126;

struct user_namespace___107;

struct mm_struct___126 {
	struct {
		struct vm_area_struct___127 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___127 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___127 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___126 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___127 *owner;
		struct user_namespace___107 *user_ns;
		struct file___127 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___126 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___126;

struct address_space___126 {
	struct inode___128 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___127 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___126 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kmem_cache_order_objects {
	unsigned int x;
};

struct kset___120;

struct kobj_type___120;

struct kernfs_node___123;

struct kobject___121 {
	const char *name;
	struct list_head entry;
	struct kobject___121 *parent;
	struct kset___120 *kset;
	struct kobj_type___120 *ktype;
	struct kernfs_node___123 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct memcg_cache_array;

struct memcg_cache_params {
	struct kmem_cache *root_cache;
	union {
		struct {
			struct memcg_cache_array *memcg_caches;
			struct list_head __root_caches_node;
			struct list_head children;
			bool dying;
		};
		struct {
			struct mem_cgroup___43 *memcg;
			struct list_head children_node;
			struct list_head kmem_caches_node;
			struct percpu_ref refcnt;
			void (*work_fn)(struct kmem_cache *);
			union {
				struct callback_head callback_head;
				struct work_struct work;
			};
		};
	};
};

struct kmem_cache_cpu;

struct kmem_cache_node;

struct kmem_cache {
	struct kmem_cache_cpu *cpu_slab;
	slab_flags_t flags;
	long unsigned int min_partial;
	unsigned int size;
	unsigned int object_size;
	unsigned int offset;
	unsigned int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	unsigned int inuse;
	unsigned int align;
	unsigned int red_left_pad;
	const char *name;
	struct list_head list;
	struct kobject___121 kobj;
	struct work_struct kobj_remove_work;
	struct memcg_cache_params memcg_params;
	unsigned int max_attr_size;
	struct kset___120 *memcg_kset;
	unsigned int remote_node_defrag_ratio;
	unsigned int *random_seq;
	unsigned int useroffset;
	unsigned int usersize;
	struct kmem_cache_node *node[8];
};

typedef int (*dev_page_fault_t___124)(struct vm_area_struct___127 *, long unsigned int, const struct page___127 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___124)(struct page___127 *, void *);

struct device___118;

struct dev_pagemap___124 {
	dev_page_fault_t___124 page_fault;
	dev_page_free_t___124 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___118 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct cgroup___103;

struct cgroup_subsys___103;

struct cgroup_subsys_state___103 {
	struct cgroup___103 *cgroup;
	struct cgroup_subsys___103 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___103 *parent;
};

struct mem_cgroup_id___17 {
	int id;
	union {
		refcount_t ref;
		struct {
			atomic_t ref;
		} __UNIQUE_ID_rh_kabi_hide40;
		union {		};
	};
};

struct cgroup_file___103 {
	struct kernfs_node___123 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___43;

struct mem_cgroup___43 {
	struct cgroup_subsys_state___103 css;
	struct mem_cgroup_id___17 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___103 events_file;
	struct cgroup_file___103 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___127 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___43 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry___127;

struct path___126 {
	struct vfsmount *mnt;
	struct dentry___127 *dentry;
};

struct file___127 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___126 f_path;
	struct inode___128 *f_inode;
	const struct file_operations___127 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___102 f_owner;
	const struct cred___122 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___126 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___124;

struct vm_operations_struct___124 {
	void (*open)(struct vm_area_struct___127 *);
	void (*close)(struct vm_area_struct___127 *);
	int (*split)(struct vm_area_struct___127 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___127 *);
	vm_fault_t (*fault)(struct vm_fault___124 *);
	vm_fault_t (*huge_fault)(struct vm_fault___124 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___124 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___127 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___124 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___124 *);
	int (*access)(struct vm_area_struct___127 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___127 *);
	int (*set_policy)(struct vm_area_struct___127 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___127 *, long unsigned int);
	struct page___127 * (*find_special_page)(struct vm_area_struct___127 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___126 {
	struct task_struct___127 *task;
	struct core_thread___126 *next;
};

struct core_state___126 {
	atomic_t nr_threads;
	struct core_thread___126 dumper;
	struct completion startup;
};

struct key___122;

struct ucounts___107;

struct user_namespace___107 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___107 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___9 ns;
	long unsigned int flags;
	struct key___122 *persistent_keyring_register;
	struct rw_semaphore___127 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___107 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___124 {
	struct vm_area_struct___127 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___127 *cow_page;
	struct mem_cgroup___43 *memcg;
	struct page___127 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___126 prealloc_pte;
};

struct shrink_control___43 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___43 *memcg;
};

struct shrinker___43 {
	long unsigned int (*count_objects)(struct shrinker___43 *, struct shrink_control___43 *);
	long unsigned int (*scan_objects)(struct shrinker___43 *, struct shrink_control___43 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct user_struct___122 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___122 *uid_keyring;
	struct key___122 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___122 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___122 *session_keyring;
	struct key___122 *process_keyring;
	struct key___122 *thread_keyring;
	struct key___122 *request_key_auth;
	void *security;
	struct user_struct___122 *user;
	struct user_namespace___107 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___103;

struct nsproxy___119 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___103 *cgroup_ns;
};

struct bio___48;

struct bio_list___48 {
	struct bio___48 *head;
	struct bio___48 *tail;
};

struct bdi_writeback_congested___48;

struct bdi_writeback___48 {
	struct backing_dev_info___48 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___48 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___103 *memcg_css;
	struct cgroup_subsys_state___103 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___48 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___48 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___118 *dev;
	struct device___118 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___127 *debug_dir;
	struct dentry___127 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___19;

struct io_context___19 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___19 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___103 {
	struct cgroup_subsys_state___103 *subsys[13];
	refcount_t refcount;
	struct css_set___103 *dom_cset;
	struct cgroup___103 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___103 *mg_src_cgrp;
	struct cgroup___103 *mg_dst_cgrp;
	struct css_set___103 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

typedef blk_qc_t make_request_fn___19(struct request_queue___20 *, struct bio___48 *);

struct request___20;

typedef int dma_drain_needed_fn___19(struct request___20 *);

struct bsg_ops___19;

struct bsg_class_device___19 {
	struct device___118 *class_dev;
	int minor;
	struct request_queue___20 *queue;
	const struct bsg_ops___19 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___48 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___48 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___19;

struct request_queue___20 {
	struct list_head queue_head;
	struct request___20 *last_merge;
	struct elevator_queue___19 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___19 *make_request_fn;
	dma_drain_needed_fn___19 *dma_drain_needed;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___48 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___121 kobj;
	struct kobject___121 *mq_kobj;
	struct blk_integrity integrity;
	struct device___118 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	struct bsg_class_device___19 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___48 bio_split;
	struct dentry___127 *debugfs_dir;
	struct dentry___127 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___95 {
	struct vm_struct___95 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___127 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dev_pm_info___118 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___118 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___118;

struct bus_type___118;

struct device_driver___118;

struct dev_pm_domain___118;

struct fwnode_handle___88;

struct class___118;

struct attribute_group___117;

struct device___118 {
	struct device___118 *parent;
	struct device_private *p;
	struct kobject___121 kobj;
	const char *init_name;
	const struct device_type___118 *type;
	struct mutex mutex;
	struct bus_type___118 *bus;
	struct device_driver___118 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___118 power;
	struct dev_pm_domain___118 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___88 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___118 *class;
	const struct attribute_group___117 **groups;
	void (*release)(struct device___118 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___126;

struct super_block___127;

struct dentry___127 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___127 *d_parent;
	struct qstr d_name;
	struct inode___128 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___126 *d_op;
	struct super_block___127 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___126;

struct block_device___127;

struct inode___128 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___126 *i_op;
	struct super_block___127 *i_sb;
	struct address_space___126 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___127 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___48 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___127 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___126 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___127 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___126 {
	int (*d_revalidate)(struct dentry___127 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___127 *, unsigned int);
	int (*d_hash)(const struct dentry___127 *, struct qstr *);
	int (*d_compare)(const struct dentry___127 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___127 *);
	int (*d_init)(struct dentry___127 *);
	void (*d_release)(struct dentry___127 *);
	void (*d_prune)(struct dentry___127 *);
	void (*d_iput)(struct dentry___127 *, struct inode___128 *);
	char * (*d_dname)(struct dentry___127 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___126 *);
	int (*d_manage)(const struct path___126 *, bool);
	struct dentry___127 * (*d_real)(struct dentry___127 *, const struct inode___128 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___126;

struct mem_dqinfo___126 {
	struct quota_format_type___126 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___126;

struct quota_info___126 {
	unsigned int flags;
	struct rw_semaphore___127 dqio_sem;
	struct inode___128 *files[3];
	struct mem_dqinfo___126 info[3];
	const struct quota_format_ops___126 *ops[3];
};

struct rcuwait___126 {
	struct task_struct___127 *task;
};

struct percpu_rw_semaphore___126 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___127 rw_sem;
	struct rcuwait___126 writer;
	int readers_block;
};

struct sb_writers___126 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___126 rw_sem[3];
};

struct file_system_type___126;

struct super_operations___126;

struct dquot_operations___126;

struct quotactl_ops___126;

struct super_block___127 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___126 *s_type;
	const struct super_operations___126 *s_op;
	const struct dquot_operations___126 *dq_op;
	const struct quotactl_ops___126 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___127 *s_root;
	struct rw_semaphore___127 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___127 *s_bdev;
	struct backing_dev_info___48 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___126 s_dquot;
	struct sb_writers___126 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___126 *s_d_op;
	int cleancache_poolid;
	struct shrinker___43 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___107 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct io_cq___19 {
	struct request_queue___20 *q;
	struct io_context___19 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___127 {
	struct file___127 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___127 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___127 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___127 *ia_file;
};

struct dquot___126 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___127 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___126 {
	int qf_fmt_id;
	const struct quota_format_ops___126 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___126 *qf_next;
};

struct quota_format_ops___126 {
	int (*check_quota_file)(struct super_block___127 *, int);
	int (*read_file_info)(struct super_block___127 *, int);
	int (*write_file_info)(struct super_block___127 *, int);
	int (*free_file_info)(struct super_block___127 *, int);
	int (*read_dqblk)(struct dquot___126 *);
	int (*commit_dqblk)(struct dquot___126 *);
	int (*release_dqblk)(struct dquot___126 *);
	int (*get_next_id)(struct super_block___127 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___126 {
	int (*write_dquot)(struct dquot___126 *);
	struct dquot___126 * (*alloc_dquot)(struct super_block___127 *, int);
	void (*destroy_dquot)(struct dquot___126 *);
	int (*acquire_dquot)(struct dquot___126 *);
	int (*release_dquot)(struct dquot___126 *);
	int (*mark_dirty)(struct dquot___126 *);
	int (*write_info)(struct super_block___127 *, int);
	qsize_t * (*get_reserved_space)(struct inode___128 *);
	int (*get_projid)(struct inode___128 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___128 *, qsize_t *);
	int (*get_next_id)(struct super_block___127 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___126 {
	int (*quota_on)(struct super_block___127 *, int, int, const struct path___126 *);
	int (*quota_off)(struct super_block___127 *, int);
	int (*quota_enable)(struct super_block___127 *, unsigned int);
	int (*quota_disable)(struct super_block___127 *, unsigned int);
	int (*quota_sync)(struct super_block___127 *, int);
	int (*set_info)(struct super_block___127 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___127 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___127 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___127 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___127 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___127 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___45;

struct address_space_operations___126 {
	int (*writepage)(struct page___127 *, struct writeback_control___45 *);
	int (*readpage)(struct file___127 *, struct page___127 *);
	int (*writepages)(struct address_space___126 *, struct writeback_control___45 *);
	int (*set_page_dirty)(struct page___127 *);
	int (*readpages)(struct file___127 *, struct address_space___126 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___127 *, struct address_space___126 *, loff_t, unsigned int, unsigned int, struct page___127 **, void **);
	int (*write_end)(struct file___127 *, struct address_space___126 *, loff_t, unsigned int, unsigned int, struct page___127 *, void *);
	sector_t (*bmap)(struct address_space___126 *, sector_t);
	void (*invalidatepage)(struct page___127 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___127 *, gfp_t);
	void (*freepage)(struct page___127 *);
	ssize_t (*direct_IO)(struct kiocb___127 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___126 *, struct page___127 *, struct page___127 *, enum migrate_mode);
	bool (*isolate_page)(struct page___127 *, isolate_mode_t);
	void (*putback_page)(struct page___127 *);
	int (*launder_page)(struct page___127 *);
	int (*is_partially_uptodate)(struct page___127 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___127 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___126 *, struct page___127 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___127 *, sector_t *);
	void (*swap_deactivate)(struct file___127 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___45 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___48 *wb;
	struct inode___128 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct hd_struct___20;

struct gendisk___20;

struct block_device___127 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___128 *bd_inode;
	struct super_block___127 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___127 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___20 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___20 *bd_disk;
	struct request_queue___20 *bd_queue;
	struct backing_dev_info___48 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct hd_struct___20 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___118 __dev;
	struct kobject___121 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___20;

struct block_device_operations___20;

struct gendisk___20 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___20 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___20 *part_tbl;
	struct hd_struct___20 part0;
	const struct block_device_operations___20 *fops;
	struct request_queue___20 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___127 lookup_sem;
	struct kobject___121 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___121 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___126 {
	struct dentry___127 * (*lookup)(struct inode___128 *, struct dentry___127 *, unsigned int);
	const char * (*get_link)(struct dentry___127 *, struct inode___128 *, struct delayed_call *);
	int (*permission)(struct inode___128 *, int);
	struct posix_acl * (*get_acl)(struct inode___128 *, int);
	int (*readlink)(struct dentry___127 *, char *, int);
	int (*create)(struct inode___128 *, struct dentry___127 *, umode_t, bool);
	int (*link)(struct dentry___127 *, struct inode___128 *, struct dentry___127 *);
	int (*unlink)(struct inode___128 *, struct dentry___127 *);
	int (*symlink)(struct inode___128 *, struct dentry___127 *, const char *);
	int (*mkdir)(struct inode___128 *, struct dentry___127 *, umode_t);
	int (*rmdir)(struct inode___128 *, struct dentry___127 *);
	int (*mknod)(struct inode___128 *, struct dentry___127 *, umode_t, dev_t);
	int (*rename)(struct inode___128 *, struct dentry___127 *, struct inode___128 *, struct dentry___127 *, unsigned int);
	int (*setattr)(struct dentry___127 *, struct iattr___127 *);
	int (*getattr)(const struct path___126 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___127 *, char *, size_t);
	int (*fiemap)(struct inode___128 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___128 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___128 *, struct dentry___127 *, struct file___127 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___128 *, struct dentry___127 *, umode_t);
	int (*set_acl)(struct inode___128 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___126 {
	void (*fl_copy_lock)(struct file_lock___127 *, struct file_lock___127 *);
	void (*fl_release_private)(struct file_lock___127 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___126;

struct lock_manager_operations___126;

struct file_lock___127 {
	struct file_lock___127 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___127 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___126 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___126 *fl_ops;
	const struct lock_manager_operations___126 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___126 {
	int (*lm_compare_owner)(struct file_lock___127 *, struct file_lock___127 *);
	long unsigned int (*lm_owner_key)(struct file_lock___127 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___127 *);
	int (*lm_grant)(struct file_lock___127 *, int);
	bool (*lm_break)(struct file_lock___127 *);
	int (*lm_change)(struct file_lock___127 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___127 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___126 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___126 *fa_next;
	struct file___127 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___126 {
	const char *name;
	int fs_flags;
	struct dentry___127 * (*mount)(struct file_system_type___126 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___127 *);
	struct module___11 *owner;
	struct file_system_type___126 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___126 {
	struct inode___128 * (*alloc_inode)(struct super_block___127 *);
	void (*destroy_inode)(struct inode___128 *);
	void (*dirty_inode)(struct inode___128 *, int);
	int (*write_inode)(struct inode___128 *, struct writeback_control___45 *);
	int (*drop_inode)(struct inode___128 *);
	void (*evict_inode)(struct inode___128 *);
	void (*put_super)(struct super_block___127 *);
	int (*sync_fs)(struct super_block___127 *, int);
	int (*freeze_super)(struct super_block___127 *);
	int (*freeze_fs)(struct super_block___127 *);
	int (*thaw_super)(struct super_block___127 *);
	int (*unfreeze_fs)(struct super_block___127 *);
	int (*statfs)(struct dentry___127 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___127 *, int *, char *);
	void (*umount_begin)(struct super_block___127 *);
	int (*show_options)(struct seq_file___117 *, struct dentry___127 *);
	int (*show_devname)(struct seq_file___117 *, struct dentry___127 *);
	int (*show_path)(struct seq_file___117 *, struct dentry___127 *);
	int (*show_stats)(struct seq_file___117 *, struct dentry___127 *);
	ssize_t (*quota_read)(struct super_block___127 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___127 *, int, const char *, size_t, loff_t);
	struct dquot___126 ** (*get_dquots)(struct inode___128 *);
	int (*bdev_try_to_free_page)(struct super_block___127 *, struct page___127 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___127 *, struct shrink_control___43 *);
	long int (*free_cached_objects)(struct super_block___127 *, struct shrink_control___43 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___115;

struct seq_file___117 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___115 *op;
	int poll_event;
	const struct file___127 *file;
	void *private;
};

typedef void bio_end_io_t___48(struct bio___48 *);

struct bio_vec___48 {
	struct page___127 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___48;

struct bio___48 {
	struct bio___48 *bi_next;
	struct gendisk___20 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___48 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___48 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___48 *bi_io_vec;
	struct bio_set___48 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___48 bi_inline_vecs[0];
};

struct kobj_attribute___121 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___121 *, struct kobj_attribute___121 *, char *);
	ssize_t (*store)(struct kobject___121 *, struct kobj_attribute___121 *, const char *, size_t);
};

typedef void compound_page_dtor___124(struct page___127 *);

struct memcg_cache_array {
	struct callback_head rcu;
	struct kmem_cache *entries[0];
};

struct bio_integrity_payload___48 {
	struct bio___48 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___48 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___48 bip_inline_vecs[0];
};

struct dev_pm_ops___118;

struct device_type___118 {
	const char *name;
	const struct attribute_group___117 **groups;
	int (*uevent)(struct device___118 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___118 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___118 *);
	const struct dev_pm_ops___118 *pm;
};

struct class___118 {
	const char *name;
	struct module___11 *owner;
	const struct attribute_group___117 **class_groups;
	const struct attribute_group___117 **dev_groups;
	struct kobject___121 *dev_kobj;
	int (*dev_uevent)(struct device___118 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___118 *, umode_t *);
	void (*class_release)(struct class___118 *);
	void (*dev_release)(struct device___118 *);
	int (*shutdown_pre)(struct device___118 *);
	const struct kobj_ns_type_operations___9 *ns_type;
	const void * (*namespace)(struct device___118 *);
	const struct dev_pm_ops___118 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct kernfs_root___123;

struct kernfs_elem_dir___123 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___123 *root;
};

struct kernfs_syscall_ops___123;

struct kernfs_root___123 {
	struct kernfs_node___123 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___123 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___123 {
	struct kernfs_node___123 *target_kn;
};

struct kernfs_ops___123;

struct kernfs_elem_attr___123 {
	const struct kernfs_ops___123 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___123 *notify_next;
};

struct kernfs_node___123 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___123 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___123 dir;
		struct kernfs_elem_symlink___123 symlink;
		struct kernfs_elem_attr___123 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___123;

struct kernfs_ops___123 {
	int (*open)(struct kernfs_open_file___123 *);
	void (*release)(struct kernfs_open_file___123 *);
	int (*seq_show)(struct seq_file___117 *, void *);
	void * (*seq_start)(struct seq_file___117 *, loff_t *);
	void * (*seq_next)(struct seq_file___117 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___117 *, void *);
	ssize_t (*read)(struct kernfs_open_file___123 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___123 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___123 *, struct vm_area_struct___127 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___123 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___123 {
	int (*remount_fs)(struct kernfs_root___123 *, int *, char *);
	int (*show_options)(struct seq_file___117 *, struct kernfs_root___123 *);
	int (*mkdir)(struct kernfs_node___123 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___123 *);
	int (*rename)(struct kernfs_node___123 *, struct kernfs_node___123 *, const char *);
	int (*show_path)(struct seq_file___117 *, struct kernfs_node___123 *, struct kernfs_root___123 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___123 {
	struct kernfs_node___123 *kn;
	struct file___127 *file;
	struct seq_file___117 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___124 *vm_ops;
};

struct bin_attribute___117;

struct attribute_group___117 {
	const char *name;
	umode_t (*is_visible)(struct kobject___121 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___121 *, struct bin_attribute___117 *, int);
	struct attribute **attrs;
	struct bin_attribute___117 **bin_attrs;
};

struct bin_attribute___117 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___127 *, struct kobject___121 *, struct bin_attribute___117 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___127 *, struct kobject___121 *, struct bin_attribute___117 *, char *, loff_t, size_t);
	int (*mmap)(struct file___127 *, struct kobject___121 *, struct bin_attribute___117 *, struct vm_area_struct___127 *);
};

struct sysfs_ops___120 {
	ssize_t (*show)(struct kobject___121 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___121 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___120;

struct kset___120 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___121 kobj;
	const struct kset_uevent_ops___120 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___120 {
	void (*release)(struct kobject___121 *);
	const struct sysfs_ops___120 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___9 * (*child_ns_type)(struct kobject___121 *);
	const void * (*namespace)(struct kobject___121 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___120 {
	int (* const filter)(struct kset___120 *, struct kobject___121 *);
	const char * (* const name)(struct kset___120 *, struct kobject___121 *);
	int (* const uevent)(struct kset___120 *, struct kobject___121 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___118 {
	int (*prepare)(struct device___118 *);
	void (*complete)(struct device___118 *);
	int (*suspend)(struct device___118 *);
	int (*resume)(struct device___118 *);
	int (*freeze)(struct device___118 *);
	int (*thaw)(struct device___118 *);
	int (*poweroff)(struct device___118 *);
	int (*restore)(struct device___118 *);
	int (*suspend_late)(struct device___118 *);
	int (*resume_early)(struct device___118 *);
	int (*freeze_late)(struct device___118 *);
	int (*thaw_early)(struct device___118 *);
	int (*poweroff_late)(struct device___118 *);
	int (*restore_early)(struct device___118 *);
	int (*suspend_noirq)(struct device___118 *);
	int (*resume_noirq)(struct device___118 *);
	int (*freeze_noirq)(struct device___118 *);
	int (*thaw_noirq)(struct device___118 *);
	int (*poweroff_noirq)(struct device___118 *);
	int (*restore_noirq)(struct device___118 *);
	int (*runtime_suspend)(struct device___118 *);
	int (*runtime_resume)(struct device___118 *);
	int (*runtime_idle)(struct device___118 *);
};

struct dev_pm_domain___118 {
	struct dev_pm_ops___118 ops;
	void (*detach)(struct device___118 *, bool);
	int (*activate)(struct device___118 *);
	void (*sync)(struct device___118 *);
	void (*dismiss)(struct device___118 *);
};

struct bus_type___118 {
	const char *name;
	const char *dev_name;
	struct device___118 *dev_root;
	const struct attribute_group___117 **bus_groups;
	const struct attribute_group___117 **dev_groups;
	const struct attribute_group___117 **drv_groups;
	int (*match)(struct device___118 *, struct device_driver___118 *);
	int (*uevent)(struct device___118 *, struct kobj_uevent_env *);
	int (*probe)(struct device___118 *);
	int (*remove)(struct device___118 *);
	void (*shutdown)(struct device___118 *);
	int (*online)(struct device___118 *);
	int (*offline)(struct device___118 *);
	int (*suspend)(struct device___118 *, pm_message_t);
	int (*resume)(struct device___118 *);
	int (*num_vf)(struct device___118 *);
	int (*dma_configure)(struct device___118 *);
	const struct dev_pm_ops___118 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___118 {
	const char *name;
	struct bus_type___118 *bus;
	struct module___11 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___118 *);
	int (*remove)(struct device___118 *);
	void (*shutdown)(struct device___118 *);
	int (*suspend)(struct device___118 *, pm_message_t);
	int (*resume)(struct device___118 *);
	const struct attribute_group___117 **groups;
	const struct dev_pm_ops___118 *pm;
	void (*coredump)(struct device___118 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct fwnode_operations___88;

struct fwnode_handle___88 {
	struct fwnode_handle___88 *secondary;
	const struct fwnode_operations___88 *ops;
};

struct disk_part_tbl___20 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___20 *last_lookup;
	struct hd_struct___20 *part[0];
};

struct block_device_operations___20 {
	int (*open)(struct block_device___127 *, fmode_t);
	void (*release)(struct gendisk___20 *, fmode_t);
	int (*rw_page)(struct block_device___127 *, sector_t, struct page___127 *, unsigned int);
	int (*ioctl)(struct block_device___127 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___127 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___20 *, unsigned int);
	int (*media_changed)(struct gendisk___20 *);
	void (*unlock_native_capacity)(struct gendisk___20 *);
	int (*revalidate_disk)(struct gendisk___20 *);
	int (*getgeo)(struct block_device___127 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___127 *, long unsigned int);
	int (*report_zones)(struct gendisk___20 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___11 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bdi_writeback_congested___48 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___48 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bsg_ops___19 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___20 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___20 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___20 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___19(struct request___20 *, blk_status_t);

struct request___20 {
	struct request_queue___20 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___48 *bio;
	struct bio___48 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___48 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___19 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___19 *saved_end_io;
		} flush;
	};
	struct gendisk___20 *rq_disk;
	struct hd_struct___20 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___19 *end_io;
	void *end_io_data;
	struct request___20 *next_rq;
};

struct fwnode_reference_args___88;

struct fwnode_endpoint___88;

struct fwnode_operations___88 {
	struct fwnode_handle___88 * (*get)(struct fwnode_handle___88 *);
	void (*put)(struct fwnode_handle___88 *);
	bool (*device_is_available)(const struct fwnode_handle___88 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___88 *, const struct device___118 *);
	bool (*property_present)(const struct fwnode_handle___88 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___88 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___88 *, const char *, const char **, size_t);
	struct fwnode_handle___88 * (*get_parent)(const struct fwnode_handle___88 *);
	struct fwnode_handle___88 * (*get_next_child_node)(const struct fwnode_handle___88 *, struct fwnode_handle___88 *);
	struct fwnode_handle___88 * (*get_named_child_node)(const struct fwnode_handle___88 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___88 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___88 *);
	struct fwnode_handle___88 * (*graph_get_next_endpoint)(const struct fwnode_handle___88 *, struct fwnode_handle___88 *);
	struct fwnode_handle___88 * (*graph_get_remote_endpoint)(const struct fwnode_handle___88 *);
	struct fwnode_handle___88 * (*graph_get_port_parent)(struct fwnode_handle___88 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___88 *, struct fwnode_endpoint___88 *);
};

struct fwnode_endpoint___88 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___88 *local_fwnode;
};

struct fwnode_reference_args___88 {
	struct fwnode_handle___88 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct elevator_type___19;

struct elevator_mq_ops___19 {
	int (*init_sched)(struct request_queue___20 *, struct elevator_type___19 *);
	void (*exit_sched)(struct elevator_queue___19 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	bool (*allow_merge)(struct request_queue___20 *, struct request___20 *, struct bio___48 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx *, struct bio___48 *);
	int (*request_merge)(struct request_queue___20 *, struct request___20 **, struct bio___48 *);
	void (*request_merged)(struct request_queue___20 *, struct request___20 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___20 *, struct request___20 *, struct request___20 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___20 *, struct bio___48 *);
	void (*finish_request)(struct request___20 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___20 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___20 *, u64);
	void (*started_request)(struct request___20 *);
	void (*requeue_request)(struct request___20 *);
	struct request___20 * (*former_request)(struct request_queue___20 *, struct request___20 *);
	struct request___20 * (*next_request)(struct request_queue___20 *, struct request___20 *);
	void (*init_icq)(struct io_cq___19 *);
	void (*exit_icq)(struct io_cq___19 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___19;

struct elevator_type___19 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___19 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___19 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___11 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___19 {
	struct elevator_type___19 *type;
	void *elevator_data;
	struct kobject___121 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___19 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___19 *, char *);
	ssize_t (*store)(struct elevator_queue___19 *, const char *, size_t);
};

typedef int (*key_restrict_link_func_t___122)(struct key___122 *, const struct key_type *, const union key_payload *, struct key___122 *);

struct key_restriction___122;

struct key___122 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___127 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___122 *restrict_link;
};

struct key_restriction___122 {
	key_restrict_link_func_t___122 check;
	struct key___122 *key;
	struct key_type *keytype;
};

struct seq_operations___115 {
	void * (*start)(struct seq_file___117 *, loff_t *);
	void (*stop)(struct seq_file___117 *, void *);
	void * (*next)(struct seq_file___117 *, void *, loff_t *);
	int (*show)(struct seq_file___117 *, void *);
};

struct cgroup_namespace___103 {
	refcount_t count;
	struct ns_common___9 ns;
	struct user_namespace___107 *user_ns;
	struct ucounts___107 *ucounts;
	struct css_set___103 *root_cset;
};

struct ucounts___107 {
	struct hlist_node node;
	struct user_namespace___107 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___103;

struct bpf_map_ops___103 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___103 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___103 *, struct file___127 *);
	void (*map_free)(struct bpf_map___103 *);
	int (*map_get_next_key)(struct bpf_map___103 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___103 *);
	void * (*map_lookup_elem)(struct bpf_map___103 *, void *);
	int (*map_update_elem)(struct bpf_map___103 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___103 *, void *);
	int (*map_push_elem)(struct bpf_map___103 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___103 *, void *);
	int (*map_peek_elem)(struct bpf_map___103 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___103 *, struct file___127 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___103 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___103 *, void *, struct seq_file___117 *);
	int (*map_check_btf)(const struct bpf_map___103 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___103 {
	const struct bpf_map_ops___103 *ops;
	struct bpf_map___103 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___122 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___103;

typedef void (*kthread_work_func_t___103)(struct kthread_work___103 *);

struct kthread_worker___103;

struct kthread_work___103 {
	struct list_head node;
	kthread_work_func_t___103 func;
	struct kthread_worker___103 *worker;
	int canceling;
};

struct kthread_worker___103 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___127 *task;
	struct kthread_work___103 *current_work;
};

struct kthread_delayed_work___103 {
	struct kthread_work___103 work;
	struct timer_list timer;
};

struct psi_group___103 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___103 *poll_kworker;
	struct kthread_delayed_work___103 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___103;

struct cgroup_rstat_cpu___103;

struct cgroup___103 {
	struct cgroup_subsys_state___103 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___123 *kn;
	struct cgroup_file___103 procs_file;
	struct cgroup_file___103 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___103 *subsys[13];
	struct cgroup_root___103 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___103 *dom_cgrp;
	struct cgroup_rstat_cpu___103 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___19 bpf;
	atomic_t congestion_count;
	struct cgroup___103 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___103 psi;
	int ancestor_ids[0];
};

struct cftype___103;

struct cgroup_subsys___103 {
	struct cgroup_subsys_state___103 * (*css_alloc)(struct cgroup_subsys_state___103 *);
	int (*css_online)(struct cgroup_subsys_state___103 *);
	void (*css_offline)(struct cgroup_subsys_state___103 *);
	void (*css_released)(struct cgroup_subsys_state___103 *);
	void (*css_free)(struct cgroup_subsys_state___103 *);
	void (*css_reset)(struct cgroup_subsys_state___103 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___103 *, int);
	int (*css_extra_stat_show)(struct seq_file___117 *, struct cgroup_subsys_state___103 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___127 *);
	void (*cancel_fork)(struct task_struct___127 *);
	void (*fork)(struct task_struct___127 *);
	void (*exit)(struct task_struct___127 *);
	void (*free)(struct task_struct___127 *);
	void (*bind)(struct cgroup_subsys_state___103 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___103 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___103 *dfl_cftypes;
	struct cftype___103 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___103 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___103 *updated_children;
	struct cgroup___103 *updated_next;
};

struct cgroup_root___103 {
	struct kernfs_root___123 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___103 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___103 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___103 *ss;
	struct list_head node;
	struct kernfs_ops___123 *kf_ops;
	int (*open)(struct kernfs_open_file___123 *);
	void (*release)(struct kernfs_open_file___123 *);
	u64 (*read_u64)(struct cgroup_subsys_state___103 *, struct cftype___103 *);
	s64 (*read_s64)(struct cgroup_subsys_state___103 *, struct cftype___103 *);
	int (*seq_show)(struct seq_file___117 *, void *);
	void * (*seq_start)(struct seq_file___117 *, loff_t *);
	void * (*seq_next)(struct seq_file___117 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___117 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___103 *, struct cftype___103 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___103 *, struct cftype___103 *, s64);
	ssize_t (*write)(struct kernfs_open_file___123 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___123 *, struct poll_table_struct___6 *);
};

struct kmem_cache_cpu {
	void **freelist;
	long unsigned int tid;
	struct page___127 *page;
	struct page___127 *partial;
};

struct kmem_cache_node {
	spinlock_t list_lock;
	long unsigned int nr_partial;
	struct list_head partial;
	atomic_long_t nr_slabs;
	atomic_long_t total_objects;
	struct list_head full;
};

struct mem_cgroup_reclaim_iter___43 {
	struct mem_cgroup___43 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___43 {
	struct lruvec___126 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___43 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___43 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

enum slab_state {
	DOWN = 0,
	PARTIAL = 1,
	PARTIAL_NODE = 2,
	UP = 3,
	FULL = 4,
};

struct kmalloc_info_struct {
	const char *name;
	unsigned int size;
};

struct module___109;

struct file___128;

struct kiocb___128;

struct iov_iter___54;

struct poll_table_struct___86;

struct vm_area_struct___128;

struct inode___129;

struct file_lock___128;

struct page___128;

struct seq_file___118;

struct file_operations___128 {
	struct module___109 *owner;
	loff_t (*llseek)(struct file___128 *, loff_t, int);
	ssize_t (*read)(struct file___128 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___128 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___128 *, struct iov_iter___54 *);
	ssize_t (*write_iter)(struct kiocb___128 *, struct iov_iter___54 *);
	int (*iopoll)(struct kiocb___128 *, bool);
	int (*iterate)(struct file___128 *, struct dir_context *);
	int (*iterate_shared)(struct file___128 *, struct dir_context *);
	__poll_t (*poll)(struct file___128 *, struct poll_table_struct___86 *);
	long int (*unlocked_ioctl)(struct file___128 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___128 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___128 *, struct vm_area_struct___128 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___129 *, struct file___128 *);
	int (*flush)(struct file___128 *, fl_owner_t);
	int (*release)(struct inode___129 *, struct file___128 *);
	int (*fsync)(struct file___128 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___128 *, int);
	int (*lock)(struct file___128 *, int, struct file_lock___128 *);
	ssize_t (*sendpage)(struct file___128 *, struct page___128 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___128 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___128 *, int, struct file_lock___128 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___128 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___128 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___128 *, long int, struct file_lock___128 **, void **);
	long int (*fallocate)(struct file___128 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___118 *, struct file___128 *);
	ssize_t (*copy_file_range)(struct file___128 *, loff_t, struct file___128 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___128 *, loff_t, struct file___128 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___128 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___127 {
	u64 seqnum;
	struct vm_area_struct___128 *vmas[4];
};

struct page_frag___127 {
	struct page___128 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___78;

struct debug_info___78 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___78 *hbp_break[16];
	struct perf_event___78 *hbp_watch[16];
};

struct thread_struct___78 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___78 debug;
	long: 64;
};

struct mm_struct___127;

struct mem_cgroup___44;

struct pid___103;

struct cred___123;

struct nsproxy___120;

struct signal_struct___116;

struct bio_list___49;

struct backing_dev_info___49;

struct io_context___20;

struct css_set___104;

struct perf_event_context___78;

struct vm_struct___96;

struct task_struct___128 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___128 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___127 *mm;
	struct mm_struct___127 *active_mm;
	struct vmacache___127 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___128 *real_parent;
	struct task_struct___128 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___128 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___44 *active_memcg;
	long int rh_reserved2;
	struct pid___103 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___103 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___103 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___123 *ptracer_cred;
	const struct cred___123 *real_cred;
	const struct cred___123 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___120 *nsproxy;
	struct signal_struct___116 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___128 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___49 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___49 *backing_dev_info;
	struct io_context___20 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___104 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___78 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___127 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___44 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___128 *oom_reaper_list;
	struct vm_struct___96 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___78 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___78 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___128 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___78)(struct perf_event___78 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___78;

struct fasync_struct___127;

struct pid_namespace___103;

struct trace_event_call___71;

struct perf_cgroup___78;

struct perf_event___78 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___78 *group_leader;
	struct pmu___78 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___78 hw;
	struct perf_event_context___78 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___78 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___128 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___127 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___78 *);
	struct callback_head callback_head;
	struct pid_namespace___103 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___78 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___78 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___71 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___78 *cgrp;
	struct list_head sb_list;
};

struct key___123;

struct user_struct___123 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___123 *uid_keyring;
	struct key___123 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct kset___121;

struct kobj_type___121;

struct kernfs_node___124;

struct kobject___122 {
	const char *name;
	struct list_head entry;
	struct kobject___122 *parent;
	struct kset___121 *kset;
	struct kobj_type___121 *ktype;
	struct kernfs_node___124 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kmem_cache___2;

struct memcg_cache_array___2;

struct memcg_cache_params___2 {
	struct kmem_cache___2 *root_cache;
	union {
		struct {
			struct memcg_cache_array___2 *memcg_caches;
			struct list_head __root_caches_node;
			struct list_head children;
			bool dying;
		};
		struct {
			struct mem_cgroup___44 *memcg;
			struct list_head children_node;
			struct list_head kmem_caches_node;
			struct percpu_ref refcnt;
			void (*work_fn)(struct kmem_cache___2 *);
			union {
				struct callback_head callback_head;
				struct work_struct work;
			};
		};
	};
};

struct kmem_cache_cpu___2;

struct kmem_cache___2 {
	struct kmem_cache_cpu___2 *cpu_slab;
	slab_flags_t flags;
	long unsigned int min_partial;
	unsigned int size;
	unsigned int object_size;
	unsigned int offset;
	unsigned int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	unsigned int inuse;
	unsigned int align;
	unsigned int red_left_pad;
	const char *name;
	struct list_head list;
	struct kobject___122 kobj;
	struct work_struct kobj_remove_work;
	struct memcg_cache_params___2 memcg_params;
	unsigned int max_attr_size;
	struct kset___121 *memcg_kset;
	unsigned int remote_node_defrag_ratio;
	unsigned int *random_seq;
	unsigned int useroffset;
	unsigned int usersize;
	struct kmem_cache_node *node[8];
};

struct upid___103 {
	int nr;
	struct pid_namespace___103 *ns;
};

struct dentry___128;

struct user_namespace___108;

struct ucounts___108;

struct pid_namespace___103 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___128 *child_reaper;
	struct kmem_cache___2 *pid_cachep;
	unsigned int level;
	struct pid_namespace___103 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___128 *proc_self;
	struct dentry___128 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___108 *user_ns;
	struct ucounts___108 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___4 ns;
};

struct pid___103 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___103 numbers[1];
};

struct rw_semaphore___128 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___128 *owner;
};

struct user_namespace___108 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___108 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___4 ns;
	long unsigned int flags;
	struct key___123 *persistent_keyring_register;
	struct rw_semaphore___128 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___108 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct secondary_data___128 {
	void *stack;
	struct task_struct___128 *task;
	long int status;
};

typedef struct page___128 *pgtable_t___127;

struct address_space___127;

struct dev_pagemap___125;

struct page___128 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___127 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___128 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache___2 *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___127 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___127 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___125 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___44 *mem_cgroup;
};

struct vm_operations_struct___125;

struct vm_area_struct___128 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___128 *vm_next;
	struct vm_area_struct___128 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___127 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___125 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___128 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___127;

struct mm_struct___127 {
	struct {
		struct vm_area_struct___128 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___128 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___128 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___127 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___128 *owner;
		struct user_namespace___108 *user_ns;
		struct file___128 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___127 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup___104;

struct cgroup_subsys___104;

struct cgroup_subsys_state___104 {
	struct cgroup___104 *cgroup;
	struct cgroup_subsys___104 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___104 *parent;
};

struct cgroup_file___104 {
	struct kernfs_node___124 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___44;

struct mem_cgroup___44 {
	struct cgroup_subsys_state___104 css;
	struct mem_cgroup_id___8 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___104 events_file;
	struct cgroup_file___104 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___128 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___44 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cred___123 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___123 *session_keyring;
	struct key___123 *process_keyring;
	struct key___123 *thread_keyring;
	struct key___123 *request_key_auth;
	void *security;
	struct user_struct___123 *user;
	struct user_namespace___108 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___104;

struct nsproxy___120 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___103 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___104 *cgroup_ns;
};

struct signal_struct___116 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___128 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___128 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___103 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___103 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___127 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___103 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___49;

struct bio_list___49 {
	struct bio___49 *head;
	struct bio___49 *tail;
};

struct bdi_writeback_congested___49;

struct bdi_writeback___49 {
	struct backing_dev_info___49 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___49 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___104 *memcg_css;
	struct cgroup_subsys_state___104 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___119;

struct backing_dev_info___49 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___49 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___119 *dev;
	struct device___119 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___128 *debug_dir;
	struct dentry___128 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___20;

struct io_context___20 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___20 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___104 {
	struct cgroup_subsys_state___104 *subsys[13];
	refcount_t refcount;
	struct css_set___104 *dom_cset;
	struct cgroup___104 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___104 *mg_src_cgrp;
	struct cgroup___104 *mg_dst_cgrp;
	struct css_set___104 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___78 {
	struct pmu___78 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___128 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___78 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___96 {
	struct vm_struct___96 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___128 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___116 {
	struct task_struct___128 task;
	long unsigned int stack[8192];
};

typedef int (*key_restrict_link_func_t___123)(struct key___123 *, const struct key_type *, const union key_payload *, struct key___123 *);

struct key_restriction___123;

struct key___123 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___128 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___123 *restrict_link;
};

struct key_restriction___123 {
	key_restrict_link_func_t___123 check;
	struct key___123 *key;
	struct key_type *keytype;
};

struct address_space_operations___127;

struct address_space___127 {
	struct inode___129 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___128 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___127 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___125)(struct vm_area_struct___128 *, long unsigned int, const struct page___128 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___125)(struct page___128 *, void *);

struct dev_pagemap___125 {
	dev_page_fault_t___125 page_fault;
	dev_page_free_t___125 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___119 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___127 {
	struct vfsmount *mnt;
	struct dentry___128 *dentry;
};

struct fown_struct___103 {
	rwlock_t lock;
	struct pid___103 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___128 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___127 f_path;
	struct inode___129 *f_inode;
	const struct file_operations___128 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___103 f_owner;
	const struct cred___123 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___127 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___125;

struct vm_operations_struct___125 {
	void (*open)(struct vm_area_struct___128 *);
	void (*close)(struct vm_area_struct___128 *);
	int (*split)(struct vm_area_struct___128 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___128 *);
	vm_fault_t (*fault)(struct vm_fault___125 *);
	vm_fault_t (*huge_fault)(struct vm_fault___125 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___125 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___128 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___125 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___125 *);
	int (*access)(struct vm_area_struct___128 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___128 *);
	int (*set_policy)(struct vm_area_struct___128 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___128 *, long unsigned int);
	struct page___128 * (*find_special_page)(struct vm_area_struct___128 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___127 {
	struct task_struct___128 *task;
	struct core_thread___127 *next;
};

struct core_state___127 {
	atomic_t nr_threads;
	struct core_thread___127 dumper;
	struct completion startup;
};

struct vm_fault___125 {
	struct vm_area_struct___128 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___128 *cow_page;
	struct mem_cgroup___44 *memcg;
	struct page___128 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___127 prealloc_pte;
};

struct pglist_data___127;

struct lruvec___127 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___127 *pgdat;
};

struct zone___127 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___127 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___127 {
	struct zone___127 *zone;
	int zone_idx;
};

struct zonelist___127 {
	struct zoneref___127 _zonerefs[25];
};

struct pglist_data___127 {
	struct zone___127 node_zones[3];
	struct zonelist___127 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___128 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___128 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___127 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___127 {
	struct rw_semaphore___128 rwsem;
	struct notifier_block *head;
};

struct shrink_control___44 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___44 *memcg;
};

struct shrinker___44 {
	long unsigned int (*count_objects)(struct shrinker___44 *, struct shrink_control___44 *);
	long unsigned int (*scan_objects)(struct shrinker___44 *, struct shrink_control___44 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct dev_pm_info___119 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___119 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___119;

struct bus_type___119;

struct device_driver___119;

struct dev_pm_domain___119;

struct class___119;

struct attribute_group___118;

struct device___119 {
	struct device___119 *parent;
	struct device_private *p;
	struct kobject___122 kobj;
	const char *init_name;
	const struct device_type___119 *type;
	struct mutex mutex;
	struct bus_type___119 *bus;
	struct device_driver___119 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___119 power;
	struct dev_pm_domain___119 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___119 *class;
	const struct attribute_group___118 **groups;
	void (*release)(struct device___119 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___127;

struct super_block___128;

struct dentry___128 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___128 *d_parent;
	struct qstr d_name;
	struct inode___129 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___127 *d_op;
	struct super_block___128 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___127;

struct block_device___128;

struct inode___129 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___127 *i_op;
	struct super_block___128 *i_sb;
	struct address_space___127 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___128 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___49 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___128 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___127 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___128 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___127 {
	int (*d_revalidate)(struct dentry___128 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___128 *, unsigned int);
	int (*d_hash)(const struct dentry___128 *, struct qstr *);
	int (*d_compare)(const struct dentry___128 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___128 *);
	int (*d_init)(struct dentry___128 *);
	void (*d_release)(struct dentry___128 *);
	void (*d_prune)(struct dentry___128 *);
	void (*d_iput)(struct dentry___128 *, struct inode___129 *);
	char * (*d_dname)(struct dentry___128 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___127 *);
	int (*d_manage)(const struct path___127 *, bool);
	struct dentry___128 * (*d_real)(struct dentry___128 *, const struct inode___129 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___127;

struct mem_dqinfo___127 {
	struct quota_format_type___127 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___127;

struct quota_info___127 {
	unsigned int flags;
	struct rw_semaphore___128 dqio_sem;
	struct inode___129 *files[3];
	struct mem_dqinfo___127 info[3];
	const struct quota_format_ops___127 *ops[3];
};

struct rcuwait___127 {
	struct task_struct___128 *task;
};

struct percpu_rw_semaphore___127 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___128 rw_sem;
	struct rcuwait___127 writer;
	int readers_block;
};

struct sb_writers___127 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___127 rw_sem[3];
};

struct file_system_type___127;

struct super_operations___127;

struct dquot_operations___127;

struct quotactl_ops___127;

struct super_block___128 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___127 *s_type;
	const struct super_operations___127 *s_op;
	const struct dquot_operations___127 *dq_op;
	const struct quotactl_ops___127 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___128 *s_root;
	struct rw_semaphore___128 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___128 *s_bdev;
	struct backing_dev_info___49 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___127 s_dquot;
	struct sb_writers___127 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___127 *s_d_op;
	int cleancache_poolid;
	struct shrinker___44 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___108 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct io_cq___20 {
	struct request_queue___3 *q;
	struct io_context___20 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___2 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___128 {
	struct file___128 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___128 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___128 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___128 *ia_file;
};

struct dquot___127 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___128 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___127 {
	int qf_fmt_id;
	const struct quota_format_ops___127 *qf_ops;
	struct module___109 *qf_owner;
	struct quota_format_type___127 *qf_next;
};

struct quota_format_ops___127 {
	int (*check_quota_file)(struct super_block___128 *, int);
	int (*read_file_info)(struct super_block___128 *, int);
	int (*write_file_info)(struct super_block___128 *, int);
	int (*free_file_info)(struct super_block___128 *, int);
	int (*read_dqblk)(struct dquot___127 *);
	int (*commit_dqblk)(struct dquot___127 *);
	int (*release_dqblk)(struct dquot___127 *);
	int (*get_next_id)(struct super_block___128 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___127 {
	int (*write_dquot)(struct dquot___127 *);
	struct dquot___127 * (*alloc_dquot)(struct super_block___128 *, int);
	void (*destroy_dquot)(struct dquot___127 *);
	int (*acquire_dquot)(struct dquot___127 *);
	int (*release_dquot)(struct dquot___127 *);
	int (*mark_dirty)(struct dquot___127 *);
	int (*write_info)(struct super_block___128 *, int);
	qsize_t * (*get_reserved_space)(struct inode___129 *);
	int (*get_projid)(struct inode___129 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___129 *, qsize_t *);
	int (*get_next_id)(struct super_block___128 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___127 {
	int (*quota_on)(struct super_block___128 *, int, int, const struct path___127 *);
	int (*quota_off)(struct super_block___128 *, int);
	int (*quota_enable)(struct super_block___128 *, unsigned int);
	int (*quota_disable)(struct super_block___128 *, unsigned int);
	int (*quota_sync)(struct super_block___128 *, int);
	int (*set_info)(struct super_block___128 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___128 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___128 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___128 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___128 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___128 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___106 {
	struct kobject___122 kobj;
	struct module___109 *mod;
	struct kobject___122 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___106 {
	struct module___109 *mod;
	struct latch_tree_node node;
};

struct module_layout___106 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___106 mtn;
};

struct module_attribute___106;

struct kernel_param___106;

struct module___109 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___106 mkobj;
	struct module_attribute___106 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___122 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___106 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___106 core_layout;
	struct module_layout___106 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___71 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___46;

struct swap_info_struct___30;

struct address_space_operations___127 {
	int (*writepage)(struct page___128 *, struct writeback_control___46 *);
	int (*readpage)(struct file___128 *, struct page___128 *);
	int (*writepages)(struct address_space___127 *, struct writeback_control___46 *);
	int (*set_page_dirty)(struct page___128 *);
	int (*readpages)(struct file___128 *, struct address_space___127 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___128 *, struct address_space___127 *, loff_t, unsigned int, unsigned int, struct page___128 **, void **);
	int (*write_end)(struct file___128 *, struct address_space___127 *, loff_t, unsigned int, unsigned int, struct page___128 *, void *);
	sector_t (*bmap)(struct address_space___127 *, sector_t);
	void (*invalidatepage)(struct page___128 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___128 *, gfp_t);
	void (*freepage)(struct page___128 *);
	ssize_t (*direct_IO)(struct kiocb___128 *, struct iov_iter___54 *);
	int (*migratepage)(struct address_space___127 *, struct page___128 *, struct page___128 *, enum migrate_mode);
	bool (*isolate_page)(struct page___128 *, isolate_mode_t);
	void (*putback_page)(struct page___128 *);
	int (*launder_page)(struct page___128 *);
	int (*is_partially_uptodate)(struct page___128 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___128 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___127 *, struct page___128 *);
	int (*swap_activate)(struct swap_info_struct___30 *, struct file___128 *, sector_t *);
	void (*swap_deactivate)(struct file___128 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___46 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___49 *wb;
	struct inode___129 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___49;

struct iov_iter___54 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___49 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct swap_info_struct___30 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___128 *bdev;
	struct file___128 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___128 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___129 *bd_inode;
	struct super_block___128 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___128 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___49 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___127 {
	struct dentry___128 * (*lookup)(struct inode___129 *, struct dentry___128 *, unsigned int);
	const char * (*get_link)(struct dentry___128 *, struct inode___129 *, struct delayed_call *);
	int (*permission)(struct inode___129 *, int);
	struct posix_acl * (*get_acl)(struct inode___129 *, int);
	int (*readlink)(struct dentry___128 *, char *, int);
	int (*create)(struct inode___129 *, struct dentry___128 *, umode_t, bool);
	int (*link)(struct dentry___128 *, struct inode___129 *, struct dentry___128 *);
	int (*unlink)(struct inode___129 *, struct dentry___128 *);
	int (*symlink)(struct inode___129 *, struct dentry___128 *, const char *);
	int (*mkdir)(struct inode___129 *, struct dentry___128 *, umode_t);
	int (*rmdir)(struct inode___129 *, struct dentry___128 *);
	int (*mknod)(struct inode___129 *, struct dentry___128 *, umode_t, dev_t);
	int (*rename)(struct inode___129 *, struct dentry___128 *, struct inode___129 *, struct dentry___128 *, unsigned int);
	int (*setattr)(struct dentry___128 *, struct iattr___128 *);
	int (*getattr)(const struct path___127 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___128 *, char *, size_t);
	int (*fiemap)(struct inode___129 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___129 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___129 *, struct dentry___128 *, struct file___128 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___129 *, struct dentry___128 *, umode_t);
	int (*set_acl)(struct inode___129 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___127 {
	void (*fl_copy_lock)(struct file_lock___128 *, struct file_lock___128 *);
	void (*fl_release_private)(struct file_lock___128 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___127;

struct file_lock___128 {
	struct file_lock___128 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___128 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___127 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___127 *fl_ops;
	const struct lock_manager_operations___127 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___127 {
	int (*lm_compare_owner)(struct file_lock___128 *, struct file_lock___128 *);
	long unsigned int (*lm_owner_key)(struct file_lock___128 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___128 *);
	int (*lm_grant)(struct file_lock___128 *, int);
	bool (*lm_break)(struct file_lock___128 *);
	int (*lm_change)(struct file_lock___128 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___128 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___127 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___127 *fa_next;
	struct file___128 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___127 {
	const char *name;
	int fs_flags;
	struct dentry___128 * (*mount)(struct file_system_type___127 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___128 *);
	struct module___109 *owner;
	struct file_system_type___127 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___127 {
	struct inode___129 * (*alloc_inode)(struct super_block___128 *);
	void (*destroy_inode)(struct inode___129 *);
	void (*dirty_inode)(struct inode___129 *, int);
	int (*write_inode)(struct inode___129 *, struct writeback_control___46 *);
	int (*drop_inode)(struct inode___129 *);
	void (*evict_inode)(struct inode___129 *);
	void (*put_super)(struct super_block___128 *);
	int (*sync_fs)(struct super_block___128 *, int);
	int (*freeze_super)(struct super_block___128 *);
	int (*freeze_fs)(struct super_block___128 *);
	int (*thaw_super)(struct super_block___128 *);
	int (*unfreeze_fs)(struct super_block___128 *);
	int (*statfs)(struct dentry___128 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___128 *, int *, char *);
	void (*umount_begin)(struct super_block___128 *);
	int (*show_options)(struct seq_file___118 *, struct dentry___128 *);
	int (*show_devname)(struct seq_file___118 *, struct dentry___128 *);
	int (*show_path)(struct seq_file___118 *, struct dentry___128 *);
	int (*show_stats)(struct seq_file___118 *, struct dentry___128 *);
	ssize_t (*quota_read)(struct super_block___128 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___128 *, int, const char *, size_t, loff_t);
	struct dquot___127 ** (*get_dquots)(struct inode___129 *);
	int (*bdev_try_to_free_page)(struct super_block___128 *, struct page___128 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___128 *, struct shrink_control___44 *);
	long int (*free_cached_objects)(struct super_block___128 *, struct shrink_control___44 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___85)(struct file___128 *, wait_queue_head_t *, struct poll_table_struct___86 *);

struct poll_table_struct___86 {
	poll_queue_proc___85 _qproc;
	__poll_t _key;
};

struct seq_operations___116;

struct seq_file___118 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___116 *op;
	int poll_event;
	const struct file___128 *file;
	void *private;
};

typedef void bio_end_io_t___49(struct bio___49 *);

struct bio_vec___49 {
	struct page___128 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___49;

struct bio_set___49;

struct bio___49 {
	struct bio___49 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___49 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___49 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___49 *bi_io_vec;
	struct bio_set___49 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___49 bi_inline_vecs[0];
};

struct kobj_attribute___122 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___122 *, struct kobj_attribute___122 *, char *);
	ssize_t (*store)(struct kobject___122 *, struct kobj_attribute___122 *, const char *, size_t);
};

typedef void compound_page_dtor___125(struct page___128 *);

struct oom_control {
	struct zonelist___127 *zonelist;
	nodemask_t *nodemask;
	struct mem_cgroup___44 *memcg;
	const gfp_t gfp_mask;
	const int order;
	long unsigned int totalpages;
	struct task_struct___128 *chosen;
	long unsigned int chosen_points;
};

struct seq_operations___116 {
	void * (*start)(struct seq_file___118 *, loff_t *);
	void (*stop)(struct seq_file___118 *, void *);
	void * (*next)(struct seq_file___118 *, void *, loff_t *);
	int (*show)(struct seq_file___118 *, void *);
};

struct kernfs_root___124;

struct kernfs_elem_dir___124 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___124 *root;
};

struct kernfs_syscall_ops___124;

struct kernfs_root___124 {
	struct kernfs_node___124 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___124 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___124 {
	struct kernfs_node___124 *target_kn;
};

struct kernfs_ops___124;

struct kernfs_elem_attr___124 {
	const struct kernfs_ops___124 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___124 *notify_next;
};

struct kernfs_node___124 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___124 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___124 dir;
		struct kernfs_elem_symlink___124 symlink;
		struct kernfs_elem_attr___124 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___124;

struct kernfs_ops___124 {
	int (*open)(struct kernfs_open_file___124 *);
	void (*release)(struct kernfs_open_file___124 *);
	int (*seq_show)(struct seq_file___118 *, void *);
	void * (*seq_start)(struct seq_file___118 *, loff_t *);
	void * (*seq_next)(struct seq_file___118 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___118 *, void *);
	ssize_t (*read)(struct kernfs_open_file___124 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___124 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___124 *, struct vm_area_struct___128 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___124 *, struct poll_table_struct___86 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___124 {
	int (*remount_fs)(struct kernfs_root___124 *, int *, char *);
	int (*show_options)(struct seq_file___118 *, struct kernfs_root___124 *);
	int (*mkdir)(struct kernfs_node___124 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___124 *);
	int (*rename)(struct kernfs_node___124 *, struct kernfs_node___124 *, const char *);
	int (*show_path)(struct seq_file___118 *, struct kernfs_node___124 *, struct kernfs_root___124 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___124 {
	struct kernfs_node___124 *kn;
	struct file___128 *file;
	struct seq_file___118 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___125 *vm_ops;
};

struct cgroup_namespace___104 {
	refcount_t count;
	struct ns_common___4 ns;
	struct user_namespace___108 *user_ns;
	struct ucounts___108 *ucounts;
	struct css_set___104 *root_cset;
};

struct ucounts___108 {
	struct hlist_node node;
	struct user_namespace___108 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___104;

struct bpf_map_ops___104 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___104 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___104 *, struct file___128 *);
	void (*map_free)(struct bpf_map___104 *);
	int (*map_get_next_key)(struct bpf_map___104 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___104 *);
	void * (*map_lookup_elem)(struct bpf_map___104 *, void *);
	int (*map_update_elem)(struct bpf_map___104 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___104 *, void *);
	int (*map_push_elem)(struct bpf_map___104 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___104 *, void *);
	int (*map_peek_elem)(struct bpf_map___104 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___104 *, struct file___128 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___104 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___104 *, void *, struct seq_file___118 *);
	int (*map_check_btf)(const struct bpf_map___104 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___104 {
	const struct bpf_map_ops___104 *ops;
	struct bpf_map___104 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___123 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___104;

typedef void (*kthread_work_func_t___104)(struct kthread_work___104 *);

struct kthread_worker___104;

struct kthread_work___104 {
	struct list_head node;
	kthread_work_func_t___104 func;
	struct kthread_worker___104 *worker;
	int canceling;
};

struct kthread_worker___104 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___128 *task;
	struct kthread_work___104 *current_work;
};

struct kthread_delayed_work___104 {
	struct kthread_work___104 work;
	struct timer_list timer;
};

struct psi_group___104 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___104 *poll_kworker;
	struct kthread_delayed_work___104 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___104;

struct cgroup_rstat_cpu___104;

struct cgroup___104 {
	struct cgroup_subsys_state___104 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___124 *kn;
	struct cgroup_file___104 procs_file;
	struct cgroup_file___104 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___104 *subsys[13];
	struct cgroup_root___104 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___104 *dom_cgrp;
	struct cgroup_rstat_cpu___104 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___4 bpf;
	atomic_t congestion_count;
	struct cgroup___104 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___104 psi;
	int ancestor_ids[0];
};

struct cftype___104;

struct cgroup_subsys___104 {
	struct cgroup_subsys_state___104 * (*css_alloc)(struct cgroup_subsys_state___104 *);
	int (*css_online)(struct cgroup_subsys_state___104 *);
	void (*css_offline)(struct cgroup_subsys_state___104 *);
	void (*css_released)(struct cgroup_subsys_state___104 *);
	void (*css_free)(struct cgroup_subsys_state___104 *);
	void (*css_reset)(struct cgroup_subsys_state___104 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___104 *, int);
	int (*css_extra_stat_show)(struct seq_file___118 *, struct cgroup_subsys_state___104 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___128 *);
	void (*cancel_fork)(struct task_struct___128 *);
	void (*fork)(struct task_struct___128 *);
	void (*exit)(struct task_struct___128 *);
	void (*free)(struct task_struct___128 *);
	void (*bind)(struct cgroup_subsys_state___104 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___104 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___104 *dfl_cftypes;
	struct cftype___104 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___104 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___104 *updated_children;
	struct cgroup___104 *updated_next;
};

struct cgroup_root___104 {
	struct kernfs_root___124 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___104 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___104 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___104 *ss;
	struct list_head node;
	struct kernfs_ops___124 *kf_ops;
	int (*open)(struct kernfs_open_file___124 *);
	void (*release)(struct kernfs_open_file___124 *);
	u64 (*read_u64)(struct cgroup_subsys_state___104 *, struct cftype___104 *);
	s64 (*read_s64)(struct cgroup_subsys_state___104 *, struct cftype___104 *);
	int (*seq_show)(struct seq_file___118 *, void *);
	void * (*seq_start)(struct seq_file___118 *, loff_t *);
	void * (*seq_next)(struct seq_file___118 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___118 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___104 *, struct cftype___104 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___104 *, struct cftype___104 *, s64);
	ssize_t (*write)(struct kernfs_open_file___124 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___124 *, struct poll_table_struct___86 *);
};

struct bdi_writeback_congested___49 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___49 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___49 {
	struct bio___49 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___49 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___49 bip_inline_vecs[0];
};

struct bio_set___49 {
	struct kmem_cache___2 *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___49 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___44 {
	struct mem_cgroup___44 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___44 {
	struct lruvec___127 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___44 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___44 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct bin_attribute___118;

struct attribute_group___118 {
	const char *name;
	umode_t (*is_visible)(struct kobject___122 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___122 *, struct bin_attribute___118 *, int);
	struct attribute **attrs;
	struct bin_attribute___118 **bin_attrs;
};

struct bin_attribute___118 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___128 *, struct kobject___122 *, struct bin_attribute___118 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___128 *, struct kobject___122 *, struct bin_attribute___118 *, char *, loff_t, size_t);
	int (*mmap)(struct file___128 *, struct kobject___122 *, struct bin_attribute___118 *, struct vm_area_struct___128 *);
};

struct sysfs_ops___121 {
	ssize_t (*show)(struct kobject___122 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___122 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___121;

struct kset___121 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___122 kobj;
	const struct kset_uevent_ops___121 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___121 {
	void (*release)(struct kobject___122 *);
	const struct sysfs_ops___121 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___2 * (*child_ns_type)(struct kobject___122 *);
	const void * (*namespace)(struct kobject___122 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___121 {
	int (* const filter)(struct kset___121 *, struct kobject___122 *);
	const char * (* const name)(struct kset___121 *, struct kobject___122 *);
	int (* const uevent)(struct kset___121 *, struct kobject___122 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___119 {
	int (*prepare)(struct device___119 *);
	void (*complete)(struct device___119 *);
	int (*suspend)(struct device___119 *);
	int (*resume)(struct device___119 *);
	int (*freeze)(struct device___119 *);
	int (*thaw)(struct device___119 *);
	int (*poweroff)(struct device___119 *);
	int (*restore)(struct device___119 *);
	int (*suspend_late)(struct device___119 *);
	int (*resume_early)(struct device___119 *);
	int (*freeze_late)(struct device___119 *);
	int (*thaw_early)(struct device___119 *);
	int (*poweroff_late)(struct device___119 *);
	int (*restore_early)(struct device___119 *);
	int (*suspend_noirq)(struct device___119 *);
	int (*resume_noirq)(struct device___119 *);
	int (*freeze_noirq)(struct device___119 *);
	int (*thaw_noirq)(struct device___119 *);
	int (*poweroff_noirq)(struct device___119 *);
	int (*restore_noirq)(struct device___119 *);
	int (*runtime_suspend)(struct device___119 *);
	int (*runtime_resume)(struct device___119 *);
	int (*runtime_idle)(struct device___119 *);
};

struct dev_pm_domain___119 {
	struct dev_pm_ops___119 ops;
	void (*detach)(struct device___119 *, bool);
	int (*activate)(struct device___119 *);
	void (*sync)(struct device___119 *);
	void (*dismiss)(struct device___119 *);
};

struct bus_type___119 {
	const char *name;
	const char *dev_name;
	struct device___119 *dev_root;
	const struct attribute_group___118 **bus_groups;
	const struct attribute_group___118 **dev_groups;
	const struct attribute_group___118 **drv_groups;
	int (*match)(struct device___119 *, struct device_driver___119 *);
	int (*uevent)(struct device___119 *, struct kobj_uevent_env *);
	int (*probe)(struct device___119 *);
	int (*remove)(struct device___119 *);
	void (*shutdown)(struct device___119 *);
	int (*online)(struct device___119 *);
	int (*offline)(struct device___119 *);
	int (*suspend)(struct device___119 *, pm_message_t);
	int (*resume)(struct device___119 *);
	int (*num_vf)(struct device___119 *);
	int (*dma_configure)(struct device___119 *);
	const struct dev_pm_ops___119 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___119 {
	const char *name;
	struct bus_type___119 *bus;
	struct module___109 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___119 *);
	int (*remove)(struct device___119 *);
	void (*shutdown)(struct device___119 *);
	int (*suspend)(struct device___119 *, pm_message_t);
	int (*resume)(struct device___119 *);
	const struct attribute_group___118 **groups;
	const struct dev_pm_ops___119 *pm;
	void (*coredump)(struct device___119 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___119 {
	const char *name;
	const struct attribute_group___118 **groups;
	int (*uevent)(struct device___119 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___119 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___119 *);
	const struct dev_pm_ops___119 *pm;
};

struct class___119 {
	const char *name;
	struct module___109 *owner;
	const struct attribute_group___118 **class_groups;
	const struct attribute_group___118 **dev_groups;
	struct kobject___122 *dev_kobj;
	int (*dev_uevent)(struct device___119 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___119 *, umode_t *);
	void (*class_release)(struct class___119 *);
	void (*dev_release)(struct device___119 *);
	int (*shutdown_pre)(struct device___119 *);
	const struct kobj_ns_type_operations___2 *ns_type;
	const void * (*namespace)(struct device___119 *);
	const struct dev_pm_ops___119 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___98 {
	struct device___119 dev;
};

struct memcg_cache_array___2 {
	struct callback_head rcu;
	struct kmem_cache___2 *entries[0];
};

struct kernel_param_ops___106 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___106 *);
	int (*get)(char *, const struct kernel_param___106 *);
	void (*free)(void *);
};

struct kparam_array___106;

struct kernel_param___106 {
	const char *name;
	struct module___109 *mod;
	const struct kernel_param_ops___106 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___106 *arr;
	};
};

struct kparam_array___106 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___106 *ops;
	void *elem;
};

struct module_attribute___106 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___106 *, struct module_kobject___106 *, char *);
	ssize_t (*store)(struct module_attribute___106 *, struct module_kobject___106 *, const char *, size_t);
	void (*setup)(struct module___109 *, const char *);
	int (*test)(struct module___109 *);
	void (*free)(struct module___109 *);
};

struct trace_event_class___71;

struct trace_event_call___71 {
	struct list_head list;
	struct trace_event_class___71 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___4 *prog_array;
	int (*perf_perm)(struct trace_event_call___71 *, struct perf_event___78 *);
};

struct mmu_table_batch {
	struct callback_head rcu;
	unsigned int nr;
	void *tables[0];
};

struct mmu_gather_batch {
	struct mmu_gather_batch *next;
	unsigned int nr;
	unsigned int max;
	struct page___128 *pages[0];
};

struct mmu_gather {
	struct mm_struct___127 *mm;
	struct mmu_table_batch *batch;
	long unsigned int start;
	long unsigned int end;
	unsigned int fullmm: 1;
	unsigned int need_flush_all: 1;
	struct mmu_gather_batch *active;
	struct mmu_gather_batch local;
	struct page___128 *__pages[8];
	unsigned int batch_count;
	int page_size;
};

struct kmem_cache_cpu___2 {
	void **freelist;
	long unsigned int tid;
	struct page___128 *page;
	struct page___128 *partial;
};

enum compact_priority {
	COMPACT_PRIO_SYNC_FULL = 0,
	MIN_COMPACT_PRIORITY = 0,
	COMPACT_PRIO_SYNC_LIGHT = 1,
	MIN_COMPACT_COSTLY_PRIORITY = 1,
	DEF_COMPACT_PRIORITY = 1,
	COMPACT_PRIO_ASYNC = 2,
	INIT_COMPACT_PRIORITY = 2,
};

enum compact_result {
	COMPACT_NOT_SUITABLE_ZONE = 0,
	COMPACT_SKIPPED = 1,
	COMPACT_DEFERRED = 2,
	COMPACT_INACTIVE = 2,
	COMPACT_NO_SUITABLE_PAGE = 3,
	COMPACT_CONTINUE = 4,
	COMPACT_COMPLETE = 5,
	COMPACT_PARTIAL_SKIPPED = 6,
	COMPACT_CONTENDED = 7,
	COMPACT_SUCCESS = 8,
};

struct perf_cpu_context___78;

struct pmu___78 {
	struct list_head entry;
	struct module___109 *module;
	struct device___119 *dev;
	const struct attribute_group___118 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___78 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___78 *);
	void (*pmu_disable)(struct pmu___78 *);
	int (*event_init)(struct perf_event___78 *);
	void (*event_mapped)(struct perf_event___78 *, struct mm_struct___127 *);
	void (*event_unmapped)(struct perf_event___78 *, struct mm_struct___127 *);
	int (*add)(struct perf_event___78 *, int);
	void (*del)(struct perf_event___78 *, int);
	void (*start)(struct perf_event___78 *, int);
	void (*stop)(struct perf_event___78 *, int);
	void (*read)(struct perf_event___78 *);
	void (*start_txn)(struct pmu___78 *, unsigned int);
	int (*commit_txn)(struct pmu___78 *);
	void (*cancel_txn)(struct pmu___78 *);
	int (*event_idx)(struct perf_event___78 *);
	void (*sched_task)(struct perf_event_context___78 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___78 *);
	int (*filter_match)(struct perf_event___78 *);
	int (*check_period)(struct perf_event___78 *, u64);
};

struct perf_cpu_context___78 {
	struct perf_event_context___78 ctx;
	struct perf_event_context___78 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___78 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___78 {
	struct cgroup_subsys_state___104 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___71 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___71 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___71 *);
	struct list_head * (*get_fields)(struct trace_event_call___71 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___71 *);
};

struct trace_event_file___34;

struct trace_event_buffer___26 {
	struct ring_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___34 *trace_file;
	void *entry;
	long unsigned int flags;
	int pc;
};

struct trace_event_file___34 {
	struct list_head list;
	struct trace_event_call___71 *event_call;
	struct event_filter *filter;
	struct dentry___128 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_oom_score_adj_update {
	struct trace_entry ent;
	pid_t pid;
	char comm[16];
	short int oom_score_adj;
	char __data[0];
};

struct trace_event_raw_reclaim_retry_zone {
	struct trace_entry ent;
	int node;
	int zone_idx;
	int order;
	long unsigned int reclaimable;
	long unsigned int available;
	long unsigned int min_wmark;
	int no_progress_loops;
	bool wmark_check;
	char __data[0];
};

struct trace_event_raw_mark_victim {
	struct trace_entry ent;
	int pid;
	char __data[0];
};

struct trace_event_raw_wake_reaper {
	struct trace_entry ent;
	int pid;
	char __data[0];
};

struct trace_event_raw_start_task_reaping {
	struct trace_entry ent;
	int pid;
	char __data[0];
};

struct trace_event_raw_finish_task_reaping {
	struct trace_entry ent;
	int pid;
	char __data[0];
};

struct trace_event_raw_skip_task_reaping {
	struct trace_entry ent;
	int pid;
	char __data[0];
};

struct trace_event_raw_compact_retry {
	struct trace_entry ent;
	int order;
	int priority;
	int result;
	int retries;
	int max_retries;
	bool ret;
	char __data[0];
};

struct trace_event_data_offsets_oom_score_adj_update {};

struct trace_event_data_offsets_reclaim_retry_zone {};

struct trace_event_data_offsets_mark_victim {};

struct trace_event_data_offsets_wake_reaper {};

struct trace_event_data_offsets_start_task_reaping {};

struct trace_event_data_offsets_finish_task_reaping {};

struct trace_event_data_offsets_skip_task_reaping {};

struct trace_event_data_offsets_compact_retry {};

enum oom_constraint {
	CONSTRAINT_NONE = 0,
	CONSTRAINT_CPUSET = 1,
	CONSTRAINT_MEMORY_POLICY = 2,
	CONSTRAINT_MEMCG = 3,
};

struct module___110;

struct file___129;

struct kiocb___129;

struct iov_iter___55;

struct poll_table_struct___87;

struct vm_area_struct___129;

struct inode___130;

struct file_lock___129;

struct page___129;

struct seq_file___119;

struct file_operations___129 {
	struct module___110 *owner;
	loff_t (*llseek)(struct file___129 *, loff_t, int);
	ssize_t (*read)(struct file___129 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___129 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___129 *, struct iov_iter___55 *);
	ssize_t (*write_iter)(struct kiocb___129 *, struct iov_iter___55 *);
	int (*iopoll)(struct kiocb___129 *, bool);
	int (*iterate)(struct file___129 *, struct dir_context *);
	int (*iterate_shared)(struct file___129 *, struct dir_context *);
	__poll_t (*poll)(struct file___129 *, struct poll_table_struct___87 *);
	long int (*unlocked_ioctl)(struct file___129 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___129 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___129 *, struct vm_area_struct___129 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___130 *, struct file___129 *);
	int (*flush)(struct file___129 *, fl_owner_t);
	int (*release)(struct inode___130 *, struct file___129 *);
	int (*fsync)(struct file___129 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___129 *, int);
	int (*lock)(struct file___129 *, int, struct file_lock___129 *);
	ssize_t (*sendpage)(struct file___129 *, struct page___129 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___129 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___129 *, int, struct file_lock___129 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___129 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___129 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___129 *, long int, struct file_lock___129 **, void **);
	long int (*fallocate)(struct file___129 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___119 *, struct file___129 *);
	ssize_t (*copy_file_range)(struct file___129 *, loff_t, struct file___129 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___129 *, loff_t, struct file___129 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___129 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct fd___8 {
	struct file___129 *file;
	unsigned int flags;
};

struct dentry___129;

struct path___128 {
	struct vfsmount *mnt;
	struct dentry___129 *dentry;
};

struct pid___104;

struct fown_struct___104 {
	rwlock_t lock;
	struct pid___104 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct cred___124;

struct address_space___128;

struct file___129 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___128 f_path;
	struct inode___130 *f_inode;
	const struct file_operations___129 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___104 f_owner;
	const struct cred___124 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___128 *f_mapping;
	errseq_t f_wb_err;
};

struct vmacache___128 {
	u64 seqnum;
	struct vm_area_struct___129 *vmas[4];
};

struct page_frag___128 {
	struct page___129 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___79;

struct debug_info___79 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___79 *hbp_break[16];
	struct perf_event___79 *hbp_watch[16];
};

struct thread_struct___79 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___79 debug;
	long: 64;
};

struct mm_struct___128;

struct mem_cgroup___45;

struct nsproxy___121;

struct signal_struct___117;

struct bio_list___50;

struct backing_dev_info___50;

struct io_context___21;

struct css_set___105;

struct perf_event_context___79;

struct request_queue___21;

struct vm_struct___97;

struct task_struct___129 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___129 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___128 *mm;
	struct mm_struct___128 *active_mm;
	struct vmacache___128 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___129 *real_parent;
	struct task_struct___129 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___129 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___45 *active_memcg;
	long int rh_reserved2;
	struct pid___104 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___104 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___104 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___124 *ptracer_cred;
	const struct cred___124 *real_cred;
	const struct cred___124 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___121 *nsproxy;
	struct signal_struct___117 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___129 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___50 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___50 *backing_dev_info;
	struct io_context___21 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___105 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___79 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___128 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___45 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___21 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___129 *oom_reaper_list;
	struct vm_struct___97 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___79 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___79 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___129 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___79)(struct perf_event___79 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___79;

struct fasync_struct___128;

struct pid_namespace___104;

struct trace_event_call___72;

struct perf_cgroup___79;

struct perf_event___79 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___79 *group_leader;
	struct pmu___79 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___79 hw;
	struct perf_event_context___79 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___79 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___129 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___128 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___79 *);
	struct callback_head callback_head;
	struct pid_namespace___104 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___79 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___79 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___72 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___79 *cgrp;
	struct list_head sb_list;
};

struct dentry_operations___128;

struct super_block___129;

struct dentry___129 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___129 *d_parent;
	struct qstr d_name;
	struct inode___130 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___128 *d_op;
	struct super_block___129 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct rw_semaphore___129 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___129 *owner;
};

struct address_space_operations___128;

struct address_space___128 {
	struct inode___130 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___129 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___128 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___128;

struct bdi_writeback___50;

struct block_device___129;

struct inode___130 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___128 *i_op;
	struct super_block___129 *i_sb;
	struct address_space___128 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___129 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___50 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___129 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___128 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___129 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___128 {
	int (*d_revalidate)(struct dentry___129 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___129 *, unsigned int);
	int (*d_hash)(const struct dentry___129 *, struct qstr *);
	int (*d_compare)(const struct dentry___129 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___129 *);
	int (*d_init)(struct dentry___129 *);
	void (*d_release)(struct dentry___129 *);
	void (*d_prune)(struct dentry___129 *);
	void (*d_iput)(struct dentry___129 *, struct inode___130 *);
	char * (*d_dname)(struct dentry___129 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___128 *);
	int (*d_manage)(const struct path___128 *, bool);
	struct dentry___129 * (*d_real)(struct dentry___129 *, const struct inode___130 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___128;

struct mem_dqinfo___128 {
	struct quota_format_type___128 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___128;

struct quota_info___128 {
	unsigned int flags;
	struct rw_semaphore___129 dqio_sem;
	struct inode___130 *files[3];
	struct mem_dqinfo___128 info[3];
	const struct quota_format_ops___128 *ops[3];
};

struct rcuwait___128 {
	struct task_struct___129 *task;
};

struct percpu_rw_semaphore___128 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___129 rw_sem;
	struct rcuwait___128 writer;
	int readers_block;
};

struct sb_writers___128 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___128 rw_sem[3];
};

struct shrink_control___45;

struct shrinker___45 {
	long unsigned int (*count_objects)(struct shrinker___45 *, struct shrink_control___45 *);
	long unsigned int (*scan_objects)(struct shrinker___45 *, struct shrink_control___45 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___128;

struct super_operations___128;

struct dquot_operations___128;

struct quotactl_ops___128;

struct user_namespace___109;

struct super_block___129 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___128 *s_type;
	const struct super_operations___128 *s_op;
	const struct dquot_operations___128 *dq_op;
	const struct quotactl_ops___128 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___129 *s_root;
	struct rw_semaphore___129 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___129 *s_bdev;
	struct backing_dev_info___50 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___128 s_dquot;
	struct sb_writers___128 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___128 *s_d_op;
	int cleancache_poolid;
	struct shrinker___45 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___109 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct key___124;

struct ucounts___109;

struct user_namespace___109 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___109 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___4 ns;
	long unsigned int flags;
	struct key___124 *persistent_keyring_register;
	struct rw_semaphore___129 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___109 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct shrink_control___45 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___45 *memcg;
};

struct cgroup___105;

struct cgroup_subsys___105;

struct cgroup_subsys_state___105 {
	struct cgroup___105 *cgroup;
	struct cgroup_subsys___105 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___105 *parent;
};

struct mem_cgroup_id___18 {
	int id;
	union {
		refcount_t ref;
		struct {
			atomic_t ref;
		} __UNIQUE_ID_rh_kabi_hide47;
		union {		};
	};
};

struct kernfs_node___125;

struct cgroup_file___105 {
	struct kernfs_node___125 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___45;

struct mem_cgroup___45 {
	struct cgroup_subsys_state___105 css;
	struct mem_cgroup_id___18 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___105 events_file;
	struct cgroup_file___105 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___129 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___45 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___129 *pgtable_t___128;

struct dev_pagemap___126;

struct page___129 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___128 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___129 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___128 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___128 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___126 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___45 *mem_cgroup;
};

struct pglist_data___128;

struct lruvec___128 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___128 *pgdat;
};

struct zone___128 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___128 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___128 {
	struct zone___128 *zone;
	int zone_idx;
};

struct zonelist___128 {
	struct zoneref___128 _zonerefs[25];
};

struct pglist_data___128 {
	struct zone___128 node_zones[3];
	struct zonelist___128 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___129 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___129 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___128 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___129 {
	void *stack;
	struct task_struct___129 *task;
	long int status;
};

struct blocking_notifier_head___128 {
	struct rw_semaphore___129 rwsem;
	struct notifier_block *head;
};

struct upid___104 {
	int nr;
	struct pid_namespace___104 *ns;
};

struct pid_namespace___104 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___129 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___104 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___129 *proc_self;
	struct dentry___129 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___109 *user_ns;
	struct ucounts___109 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___4 ns;
};

struct pid___104 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___104 numbers[1];
};

struct vm_operations_struct___126;

struct vm_area_struct___129 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___129 *vm_next;
	struct vm_area_struct___129 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___128 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___126 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___129 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___128;

struct mm_struct___128 {
	struct {
		struct vm_area_struct___129 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___129 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___129 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___128 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___129 *owner;
		struct user_namespace___109 *user_ns;
		struct file___129 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___128 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___126)(struct vm_area_struct___129 *, long unsigned int, const struct page___129 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___126)(struct page___129 *, void *);

struct device___120;

struct dev_pagemap___126 {
	dev_page_fault_t___126 page_fault;
	dev_page_free_t___126 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___120 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct vm_fault___126;

struct vm_operations_struct___126 {
	void (*open)(struct vm_area_struct___129 *);
	void (*close)(struct vm_area_struct___129 *);
	int (*split)(struct vm_area_struct___129 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___129 *);
	vm_fault_t (*fault)(struct vm_fault___126 *);
	vm_fault_t (*huge_fault)(struct vm_fault___126 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___126 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___129 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___126 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___126 *);
	int (*access)(struct vm_area_struct___129 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___129 *);
	int (*set_policy)(struct vm_area_struct___129 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___129 *, long unsigned int);
	struct page___129 * (*find_special_page)(struct vm_area_struct___129 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___128 {
	struct task_struct___129 *task;
	struct core_thread___128 *next;
};

struct core_state___128 {
	atomic_t nr_threads;
	struct core_thread___128 dumper;
	struct completion startup;
};

struct vm_fault___126 {
	struct vm_area_struct___129 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___129 *cow_page;
	struct mem_cgroup___45 *memcg;
	struct page___129 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___128 prealloc_pte;
};

struct user_struct___124 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___124 *uid_keyring;
	struct key___124 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___124 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___124 *session_keyring;
	struct key___124 *process_keyring;
	struct key___124 *thread_keyring;
	struct key___124 *request_key_auth;
	void *security;
	struct user_struct___124 *user;
	struct user_namespace___109 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___105;

struct nsproxy___121 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___104 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___105 *cgroup_ns;
};

struct signal_struct___117 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___129 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___129 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___104 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___104 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___128 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___104 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide44;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___50;

struct bio_list___50 {
	struct bio___50 *head;
	struct bio___50 *tail;
};

struct bdi_writeback_congested___50;

struct bdi_writeback___50 {
	struct backing_dev_info___50 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___50 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___105 *memcg_css;
	struct cgroup_subsys_state___105 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___50 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___50 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___120 *dev;
	struct device___120 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___129 *debug_dir;
	struct dentry___129 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___21;

struct io_context___21 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___21 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___105 {
	struct cgroup_subsys_state___105 *subsys[13];
	refcount_t refcount;
	struct css_set___105 *dom_cset;
	struct cgroup___105 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___105 *mg_src_cgrp;
	struct cgroup___105 *mg_dst_cgrp;
	struct css_set___105 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___79 {
	struct pmu___79 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___129 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___79 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

typedef blk_qc_t make_request_fn___20(struct request_queue___21 *, struct bio___50 *);

struct request___21;

typedef int dma_drain_needed_fn___20(struct request___21 *);

struct kset___122;

struct kobj_type___122;

struct kobject___123 {
	const char *name;
	struct list_head entry;
	struct kobject___123 *parent;
	struct kset___122 *kset;
	struct kobj_type___122 *ktype;
	struct kernfs_node___125 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___20;

struct bsg_class_device___20 {
	struct device___120 *class_dev;
	int minor;
	struct request_queue___21 *queue;
	const struct bsg_ops___20 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___50 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___50 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___20;

struct blkcg_gq___12;

struct request_queue___21 {
	struct list_head queue_head;
	struct request___21 *last_merge;
	struct elevator_queue___20 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___20 *make_request_fn;
	dma_drain_needed_fn___20 *dma_drain_needed;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___50 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___123 kobj;
	struct kobject___123 *mq_kobj;
	struct blk_integrity integrity;
	struct device___120 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___12 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	struct bsg_class_device___20 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___50 bio_split;
	struct dentry___129 *debugfs_dir;
	struct dentry___129 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___97 {
	struct vm_struct___97 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___129 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___117 {
	struct task_struct___129 task;
	long unsigned int stack[8192];
};

struct io_cq___21 {
	struct request_queue___21 *q;
	struct io_context___21 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___2 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___129 {
	struct file___129 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___129 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___129 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___129 *ia_file;
};

struct dquot___128 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___129 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___128 {
	int qf_fmt_id;
	const struct quota_format_ops___128 *qf_ops;
	struct module___110 *qf_owner;
	struct quota_format_type___128 *qf_next;
};

struct quota_format_ops___128 {
	int (*check_quota_file)(struct super_block___129 *, int);
	int (*read_file_info)(struct super_block___129 *, int);
	int (*write_file_info)(struct super_block___129 *, int);
	int (*free_file_info)(struct super_block___129 *, int);
	int (*read_dqblk)(struct dquot___128 *);
	int (*commit_dqblk)(struct dquot___128 *);
	int (*release_dqblk)(struct dquot___128 *);
	int (*get_next_id)(struct super_block___129 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___128 {
	int (*write_dquot)(struct dquot___128 *);
	struct dquot___128 * (*alloc_dquot)(struct super_block___129 *, int);
	void (*destroy_dquot)(struct dquot___128 *);
	int (*acquire_dquot)(struct dquot___128 *);
	int (*release_dquot)(struct dquot___128 *);
	int (*mark_dirty)(struct dquot___128 *);
	int (*write_info)(struct super_block___129 *, int);
	qsize_t * (*get_reserved_space)(struct inode___130 *);
	int (*get_projid)(struct inode___130 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___130 *, qsize_t *);
	int (*get_next_id)(struct super_block___129 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___128 {
	int (*quota_on)(struct super_block___129 *, int, int, const struct path___128 *);
	int (*quota_off)(struct super_block___129 *, int);
	int (*quota_enable)(struct super_block___129 *, unsigned int);
	int (*quota_disable)(struct super_block___129 *, unsigned int);
	int (*quota_sync)(struct super_block___129 *, int);
	int (*set_info)(struct super_block___129 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___129 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___129 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___129 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___129 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___129 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___107 {
	struct kobject___123 kobj;
	struct module___110 *mod;
	struct kobject___123 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___107 {
	struct module___110 *mod;
	struct latch_tree_node node;
};

struct module_layout___107 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___107 mtn;
};

struct module_attribute___107;

struct kernel_param___107;

struct module___110 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___107 mkobj;
	struct module_attribute___107 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___123 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___107 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___107 core_layout;
	struct module_layout___107 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___72 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide42;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide43;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___47;

struct swap_info_struct___31;

struct address_space_operations___128 {
	int (*writepage)(struct page___129 *, struct writeback_control___47 *);
	int (*readpage)(struct file___129 *, struct page___129 *);
	int (*writepages)(struct address_space___128 *, struct writeback_control___47 *);
	int (*set_page_dirty)(struct page___129 *);
	int (*readpages)(struct file___129 *, struct address_space___128 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___129 *, struct address_space___128 *, loff_t, unsigned int, unsigned int, struct page___129 **, void **);
	int (*write_end)(struct file___129 *, struct address_space___128 *, loff_t, unsigned int, unsigned int, struct page___129 *, void *);
	sector_t (*bmap)(struct address_space___128 *, sector_t);
	void (*invalidatepage)(struct page___129 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___129 *, gfp_t);
	void (*freepage)(struct page___129 *);
	ssize_t (*direct_IO)(struct kiocb___129 *, struct iov_iter___55 *);
	int (*migratepage)(struct address_space___128 *, struct page___129 *, struct page___129 *, enum migrate_mode);
	bool (*isolate_page)(struct page___129 *, isolate_mode_t);
	void (*putback_page)(struct page___129 *);
	int (*launder_page)(struct page___129 *);
	int (*is_partially_uptodate)(struct page___129 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___129 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___128 *, struct page___129 *);
	int (*swap_activate)(struct swap_info_struct___31 *, struct file___129 *, sector_t *);
	void (*swap_deactivate)(struct file___129 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___47 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___50 *wb;
	struct inode___130 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___50;

struct iov_iter___55 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___50 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct swap_info_struct___31 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___129 *bdev;
	struct file___129 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct hd_struct___21;

struct gendisk___21;

struct block_device___129 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___130 *bd_inode;
	struct super_block___129 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___129 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___21 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___21 *bd_disk;
	struct request_queue___21 *bd_queue;
	struct backing_dev_info___50 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___120 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___120 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___120;

struct bus_type___120;

struct device_driver___120;

struct dev_pm_domain___120;

struct fwnode_handle___89;

struct class___120;

struct attribute_group___119;

struct device___120 {
	struct device___120 *parent;
	struct device_private *p;
	struct kobject___123 kobj;
	const char *init_name;
	const struct device_type___120 *type;
	struct mutex mutex;
	struct bus_type___120 *bus;
	struct device_driver___120 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___120 power;
	struct dev_pm_domain___120 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___89 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___120 *class;
	const struct attribute_group___119 **groups;
	void (*release)(struct device___120 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___21 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___120 __dev;
	struct kobject___123 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___21;

struct block_device_operations___21;

struct gendisk___21 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___21 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___21 *part_tbl;
	struct hd_struct___21 part0;
	const struct block_device_operations___21 *fops;
	struct request_queue___21 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___129 lookup_sem;
	struct kobject___123 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___123 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___128 {
	struct dentry___129 * (*lookup)(struct inode___130 *, struct dentry___129 *, unsigned int);
	const char * (*get_link)(struct dentry___129 *, struct inode___130 *, struct delayed_call *);
	int (*permission)(struct inode___130 *, int);
	struct posix_acl * (*get_acl)(struct inode___130 *, int);
	int (*readlink)(struct dentry___129 *, char *, int);
	int (*create)(struct inode___130 *, struct dentry___129 *, umode_t, bool);
	int (*link)(struct dentry___129 *, struct inode___130 *, struct dentry___129 *);
	int (*unlink)(struct inode___130 *, struct dentry___129 *);
	int (*symlink)(struct inode___130 *, struct dentry___129 *, const char *);
	int (*mkdir)(struct inode___130 *, struct dentry___129 *, umode_t);
	int (*rmdir)(struct inode___130 *, struct dentry___129 *);
	int (*mknod)(struct inode___130 *, struct dentry___129 *, umode_t, dev_t);
	int (*rename)(struct inode___130 *, struct dentry___129 *, struct inode___130 *, struct dentry___129 *, unsigned int);
	int (*setattr)(struct dentry___129 *, struct iattr___129 *);
	int (*getattr)(const struct path___128 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___129 *, char *, size_t);
	int (*fiemap)(struct inode___130 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___130 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___130 *, struct dentry___129 *, struct file___129 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___130 *, struct dentry___129 *, umode_t);
	int (*set_acl)(struct inode___130 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___128 {
	void (*fl_copy_lock)(struct file_lock___129 *, struct file_lock___129 *);
	void (*fl_release_private)(struct file_lock___129 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___128;

struct file_lock___129 {
	struct file_lock___129 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___129 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___128 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___128 *fl_ops;
	const struct lock_manager_operations___128 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___128 {
	int (*lm_compare_owner)(struct file_lock___129 *, struct file_lock___129 *);
	long unsigned int (*lm_owner_key)(struct file_lock___129 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___129 *);
	int (*lm_grant)(struct file_lock___129 *, int);
	bool (*lm_break)(struct file_lock___129 *);
	int (*lm_change)(struct file_lock___129 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___129 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___128 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___128 *fa_next;
	struct file___129 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___128 {
	const char *name;
	int fs_flags;
	struct dentry___129 * (*mount)(struct file_system_type___128 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___129 *);
	struct module___110 *owner;
	struct file_system_type___128 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___128 {
	struct inode___130 * (*alloc_inode)(struct super_block___129 *);
	void (*destroy_inode)(struct inode___130 *);
	void (*dirty_inode)(struct inode___130 *, int);
	int (*write_inode)(struct inode___130 *, struct writeback_control___47 *);
	int (*drop_inode)(struct inode___130 *);
	void (*evict_inode)(struct inode___130 *);
	void (*put_super)(struct super_block___129 *);
	int (*sync_fs)(struct super_block___129 *, int);
	int (*freeze_super)(struct super_block___129 *);
	int (*freeze_fs)(struct super_block___129 *);
	int (*thaw_super)(struct super_block___129 *);
	int (*unfreeze_fs)(struct super_block___129 *);
	int (*statfs)(struct dentry___129 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___129 *, int *, char *);
	void (*umount_begin)(struct super_block___129 *);
	int (*show_options)(struct seq_file___119 *, struct dentry___129 *);
	int (*show_devname)(struct seq_file___119 *, struct dentry___129 *);
	int (*show_path)(struct seq_file___119 *, struct dentry___129 *);
	int (*show_stats)(struct seq_file___119 *, struct dentry___129 *);
	ssize_t (*quota_read)(struct super_block___129 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___129 *, int, const char *, size_t, loff_t);
	struct dquot___128 ** (*get_dquots)(struct inode___130 *);
	int (*bdev_try_to_free_page)(struct super_block___129 *, struct page___129 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___129 *, struct shrink_control___45 *);
	long int (*free_cached_objects)(struct super_block___129 *, struct shrink_control___45 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___86)(struct file___129 *, wait_queue_head_t *, struct poll_table_struct___87 *);

struct poll_table_struct___87 {
	poll_queue_proc___86 _qproc;
	__poll_t _key;
};

struct seq_operations___117;

struct seq_file___119 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___117 *op;
	int poll_event;
	const struct file___129 *file;
	void *private;
};

typedef void bio_end_io_t___50(struct bio___50 *);

struct bio_vec___50 {
	struct page___129 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___50;

struct bio___50 {
	struct bio___50 *bi_next;
	struct gendisk___21 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___50 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___12 *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___50 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___50 *bi_io_vec;
	struct bio_set___50 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___50 bi_inline_vecs[0];
};

struct kobj_attribute___123 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___123 *, struct kobj_attribute___123 *, char *);
	ssize_t (*store)(struct kobject___123 *, struct kobj_attribute___123 *, const char *, size_t);
};

typedef void compound_page_dtor___126(struct page___129 *);

struct bio_integrity_payload___50 {
	struct bio___50 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___50 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___50 bip_inline_vecs[0];
};

struct blkcg___12;

struct blkg_policy_data___12;

struct blkcg_gq___12 {
	struct request_queue___21 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___12 *blkcg;
	struct bdi_writeback_congested___50 *wb_congested;
	struct blkcg_gq___12 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_rwstat stat_bytes;
	struct blkg_rwstat stat_ios;
	struct blkg_policy_data___12 *pd[5];
	struct callback_head callback_head;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
};

struct dev_pm_ops___120;

struct device_type___120 {
	const char *name;
	const struct attribute_group___119 **groups;
	int (*uevent)(struct device___120 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___120 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___120 *);
	const struct dev_pm_ops___120 *pm;
};

struct class___120 {
	const char *name;
	struct module___110 *owner;
	const struct attribute_group___119 **class_groups;
	const struct attribute_group___119 **dev_groups;
	struct kobject___123 *dev_kobj;
	int (*dev_uevent)(struct device___120 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___120 *, umode_t *);
	void (*class_release)(struct class___120 *);
	void (*dev_release)(struct device___120 *);
	int (*shutdown_pre)(struct device___120 *);
	const struct kobj_ns_type_operations___2 *ns_type;
	const void * (*namespace)(struct device___120 *);
	const struct dev_pm_ops___120 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct kernfs_root___125;

struct kernfs_elem_dir___125 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___125 *root;
};

struct kernfs_syscall_ops___125;

struct kernfs_root___125 {
	struct kernfs_node___125 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___125 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___125 {
	struct kernfs_node___125 *target_kn;
};

struct kernfs_ops___125;

struct kernfs_elem_attr___125 {
	const struct kernfs_ops___125 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___125 *notify_next;
};

struct kernfs_node___125 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___125 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___125 dir;
		struct kernfs_elem_symlink___125 symlink;
		struct kernfs_elem_attr___125 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___125;

struct kernfs_ops___125 {
	int (*open)(struct kernfs_open_file___125 *);
	void (*release)(struct kernfs_open_file___125 *);
	int (*seq_show)(struct seq_file___119 *, void *);
	void * (*seq_start)(struct seq_file___119 *, loff_t *);
	void * (*seq_next)(struct seq_file___119 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___119 *, void *);
	ssize_t (*read)(struct kernfs_open_file___125 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___125 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___125 *, struct vm_area_struct___129 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___125 *, struct poll_table_struct___87 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___125 {
	int (*remount_fs)(struct kernfs_root___125 *, int *, char *);
	int (*show_options)(struct seq_file___119 *, struct kernfs_root___125 *);
	int (*mkdir)(struct kernfs_node___125 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___125 *);
	int (*rename)(struct kernfs_node___125 *, struct kernfs_node___125 *, const char *);
	int (*show_path)(struct seq_file___119 *, struct kernfs_node___125 *, struct kernfs_root___125 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___125 {
	struct kernfs_node___125 *kn;
	struct file___129 *file;
	struct seq_file___119 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___126 *vm_ops;
};

struct bin_attribute___119;

struct attribute_group___119 {
	const char *name;
	umode_t (*is_visible)(struct kobject___123 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___123 *, struct bin_attribute___119 *, int);
	struct attribute **attrs;
	struct bin_attribute___119 **bin_attrs;
};

struct bin_attribute___119 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___129 *, struct kobject___123 *, struct bin_attribute___119 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___129 *, struct kobject___123 *, struct bin_attribute___119 *, char *, loff_t, size_t);
	int (*mmap)(struct file___129 *, struct kobject___123 *, struct bin_attribute___119 *, struct vm_area_struct___129 *);
};

struct sysfs_ops___122 {
	ssize_t (*show)(struct kobject___123 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___123 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___122;

struct kset___122 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___123 kobj;
	const struct kset_uevent_ops___122 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___122 {
	void (*release)(struct kobject___123 *);
	const struct sysfs_ops___122 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___2 * (*child_ns_type)(struct kobject___123 *);
	const void * (*namespace)(struct kobject___123 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___122 {
	int (* const filter)(struct kset___122 *, struct kobject___123 *);
	const char * (* const name)(struct kset___122 *, struct kobject___123 *);
	int (* const uevent)(struct kset___122 *, struct kobject___123 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___120 {
	int (*prepare)(struct device___120 *);
	void (*complete)(struct device___120 *);
	int (*suspend)(struct device___120 *);
	int (*resume)(struct device___120 *);
	int (*freeze)(struct device___120 *);
	int (*thaw)(struct device___120 *);
	int (*poweroff)(struct device___120 *);
	int (*restore)(struct device___120 *);
	int (*suspend_late)(struct device___120 *);
	int (*resume_early)(struct device___120 *);
	int (*freeze_late)(struct device___120 *);
	int (*thaw_early)(struct device___120 *);
	int (*poweroff_late)(struct device___120 *);
	int (*restore_early)(struct device___120 *);
	int (*suspend_noirq)(struct device___120 *);
	int (*resume_noirq)(struct device___120 *);
	int (*freeze_noirq)(struct device___120 *);
	int (*thaw_noirq)(struct device___120 *);
	int (*poweroff_noirq)(struct device___120 *);
	int (*restore_noirq)(struct device___120 *);
	int (*runtime_suspend)(struct device___120 *);
	int (*runtime_resume)(struct device___120 *);
	int (*runtime_idle)(struct device___120 *);
};

struct dev_pm_domain___120 {
	struct dev_pm_ops___120 ops;
	void (*detach)(struct device___120 *, bool);
	int (*activate)(struct device___120 *);
	void (*sync)(struct device___120 *);
	void (*dismiss)(struct device___120 *);
};

struct bus_type___120 {
	const char *name;
	const char *dev_name;
	struct device___120 *dev_root;
	const struct attribute_group___119 **bus_groups;
	const struct attribute_group___119 **dev_groups;
	const struct attribute_group___119 **drv_groups;
	int (*match)(struct device___120 *, struct device_driver___120 *);
	int (*uevent)(struct device___120 *, struct kobj_uevent_env *);
	int (*probe)(struct device___120 *);
	int (*remove)(struct device___120 *);
	void (*shutdown)(struct device___120 *);
	int (*online)(struct device___120 *);
	int (*offline)(struct device___120 *);
	int (*suspend)(struct device___120 *, pm_message_t);
	int (*resume)(struct device___120 *);
	int (*num_vf)(struct device___120 *);
	int (*dma_configure)(struct device___120 *);
	const struct dev_pm_ops___120 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___120 {
	const char *name;
	struct bus_type___120 *bus;
	struct module___110 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___120 *);
	int (*remove)(struct device___120 *);
	void (*shutdown)(struct device___120 *);
	int (*suspend)(struct device___120 *, pm_message_t);
	int (*resume)(struct device___120 *);
	const struct attribute_group___119 **groups;
	const struct dev_pm_ops___120 *pm;
	void (*coredump)(struct device___120 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct fwnode_operations___89;

struct fwnode_handle___89 {
	struct fwnode_handle___89 *secondary;
	const struct fwnode_operations___89 *ops;
};

struct disk_part_tbl___21 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___21 *last_lookup;
	struct hd_struct___21 *part[0];
};

struct block_device_operations___21 {
	int (*open)(struct block_device___129 *, fmode_t);
	void (*release)(struct gendisk___21 *, fmode_t);
	int (*rw_page)(struct block_device___129 *, sector_t, struct page___129 *, unsigned int);
	int (*ioctl)(struct block_device___129 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___129 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___21 *, unsigned int);
	int (*media_changed)(struct gendisk___21 *);
	void (*unlock_native_capacity)(struct gendisk___21 *);
	int (*revalidate_disk)(struct gendisk___21 *);
	int (*getgeo)(struct block_device___129 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___129 *, long unsigned int);
	int (*report_zones)(struct gendisk___21 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___110 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

enum wb_congested_state {
	WB_async_congested = 0,
	WB_sync_congested = 1,
};

struct bdi_writeback_congested___50 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___50 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bsg_ops___20 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___21 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___21 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___21 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___20(struct request___21 *, blk_status_t);

struct request___21 {
	struct request_queue___21 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___50 *bio;
	struct bio___50 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___50 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___21 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___20 *saved_end_io;
		} flush;
	};
	struct gendisk___21 *rq_disk;
	struct hd_struct___21 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___20 *end_io;
	void *end_io_data;
	struct request___21 *next_rq;
};

struct fwnode_reference_args___89;

struct fwnode_endpoint___89;

struct fwnode_operations___89 {
	struct fwnode_handle___89 * (*get)(struct fwnode_handle___89 *);
	void (*put)(struct fwnode_handle___89 *);
	bool (*device_is_available)(const struct fwnode_handle___89 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___89 *, const struct device___120 *);
	bool (*property_present)(const struct fwnode_handle___89 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___89 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___89 *, const char *, const char **, size_t);
	struct fwnode_handle___89 * (*get_parent)(const struct fwnode_handle___89 *);
	struct fwnode_handle___89 * (*get_next_child_node)(const struct fwnode_handle___89 *, struct fwnode_handle___89 *);
	struct fwnode_handle___89 * (*get_named_child_node)(const struct fwnode_handle___89 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___89 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___89 *);
	struct fwnode_handle___89 * (*graph_get_next_endpoint)(const struct fwnode_handle___89 *, struct fwnode_handle___89 *);
	struct fwnode_handle___89 * (*graph_get_remote_endpoint)(const struct fwnode_handle___89 *);
	struct fwnode_handle___89 * (*graph_get_port_parent)(struct fwnode_handle___89 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___89 *, struct fwnode_endpoint___89 *);
};

struct fwnode_endpoint___89 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___89 *local_fwnode;
};

struct fwnode_reference_args___89 {
	struct fwnode_handle___89 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct elevator_type___20;

struct elevator_mq_ops___20 {
	int (*init_sched)(struct request_queue___21 *, struct elevator_type___20 *);
	void (*exit_sched)(struct elevator_queue___20 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	bool (*allow_merge)(struct request_queue___21 *, struct request___21 *, struct bio___50 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx *, struct bio___50 *);
	int (*request_merge)(struct request_queue___21 *, struct request___21 **, struct bio___50 *);
	void (*request_merged)(struct request_queue___21 *, struct request___21 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___21 *, struct request___21 *, struct request___21 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___21 *, struct bio___50 *);
	void (*finish_request)(struct request___21 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___21 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___21 *, u64);
	void (*started_request)(struct request___21 *);
	void (*requeue_request)(struct request___21 *);
	struct request___21 * (*former_request)(struct request_queue___21 *, struct request___21 *);
	struct request___21 * (*next_request)(struct request_queue___21 *, struct request___21 *);
	void (*init_icq)(struct io_cq___21 *);
	void (*exit_icq)(struct io_cq___21 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___20;

struct elevator_type___20 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___20 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___20 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___110 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___20 {
	struct elevator_type___20 *type;
	void *elevator_data;
	struct kobject___123 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___20 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___20 *, char *);
	ssize_t (*store)(struct elevator_queue___20 *, const char *, size_t);
};

typedef int (*key_restrict_link_func_t___124)(struct key___124 *, const struct key_type *, const union key_payload *, struct key___124 *);

struct key_restriction___124;

struct key___124 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___129 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___124 *restrict_link;
};

struct key_restriction___124 {
	key_restrict_link_func_t___124 check;
	struct key___124 *key;
	struct key_type *keytype;
};

struct seq_operations___117 {
	void * (*start)(struct seq_file___119 *, loff_t *);
	void (*stop)(struct seq_file___119 *, void *);
	void * (*next)(struct seq_file___119 *, void *, loff_t *);
	int (*show)(struct seq_file___119 *, void *);
};

struct cgroup_namespace___105 {
	refcount_t count;
	struct ns_common___4 ns;
	struct user_namespace___109 *user_ns;
	struct ucounts___109 *ucounts;
	struct css_set___105 *root_cset;
};

struct ucounts___109 {
	struct hlist_node node;
	struct user_namespace___109 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___105;

struct bpf_map_ops___105 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___105 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___105 *, struct file___129 *);
	void (*map_free)(struct bpf_map___105 *);
	int (*map_get_next_key)(struct bpf_map___105 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___105 *);
	void * (*map_lookup_elem)(struct bpf_map___105 *, void *);
	int (*map_update_elem)(struct bpf_map___105 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___105 *, void *);
	int (*map_push_elem)(struct bpf_map___105 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___105 *, void *);
	int (*map_peek_elem)(struct bpf_map___105 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___105 *, struct file___129 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___105 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___105 *, void *, struct seq_file___119 *);
	int (*map_check_btf)(const struct bpf_map___105 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___105 {
	const struct bpf_map_ops___105 *ops;
	struct bpf_map___105 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___124 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___105;

typedef void (*kthread_work_func_t___105)(struct kthread_work___105 *);

struct kthread_worker___105;

struct kthread_work___105 {
	struct list_head node;
	kthread_work_func_t___105 func;
	struct kthread_worker___105 *worker;
	int canceling;
};

struct kthread_worker___105 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___129 *task;
	struct kthread_work___105 *current_work;
};

struct kthread_delayed_work___105 {
	struct kthread_work___105 work;
	struct timer_list timer;
};

struct psi_group___105 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___105 *poll_kworker;
	struct kthread_delayed_work___105 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___105;

struct cgroup_rstat_cpu___105;

struct cgroup___105 {
	struct cgroup_subsys_state___105 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___125 *kn;
	struct cgroup_file___105 procs_file;
	struct cgroup_file___105 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___105 *subsys[13];
	struct cgroup_root___105 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___105 *dom_cgrp;
	struct cgroup_rstat_cpu___105 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___4 bpf;
	atomic_t congestion_count;
	struct cgroup___105 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___105 psi;
	int ancestor_ids[0];
};

struct cftype___105;

struct cgroup_subsys___105 {
	struct cgroup_subsys_state___105 * (*css_alloc)(struct cgroup_subsys_state___105 *);
	int (*css_online)(struct cgroup_subsys_state___105 *);
	void (*css_offline)(struct cgroup_subsys_state___105 *);
	void (*css_released)(struct cgroup_subsys_state___105 *);
	void (*css_free)(struct cgroup_subsys_state___105 *);
	void (*css_reset)(struct cgroup_subsys_state___105 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___105 *, int);
	int (*css_extra_stat_show)(struct seq_file___119 *, struct cgroup_subsys_state___105 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___129 *);
	void (*cancel_fork)(struct task_struct___129 *);
	void (*fork)(struct task_struct___129 *);
	void (*exit)(struct task_struct___129 *);
	void (*free)(struct task_struct___129 *);
	void (*bind)(struct cgroup_subsys_state___105 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___105 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___105 *dfl_cftypes;
	struct cftype___105 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___105 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___105 *updated_children;
	struct cgroup___105 *updated_next;
};

struct cgroup_root___105 {
	struct kernfs_root___125 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___105 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___105 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___105 *ss;
	struct list_head node;
	struct kernfs_ops___125 *kf_ops;
	int (*open)(struct kernfs_open_file___125 *);
	void (*release)(struct kernfs_open_file___125 *);
	u64 (*read_u64)(struct cgroup_subsys_state___105 *, struct cftype___105 *);
	s64 (*read_s64)(struct cgroup_subsys_state___105 *, struct cftype___105 *);
	int (*seq_show)(struct seq_file___119 *, void *);
	void * (*seq_start)(struct seq_file___119 *, loff_t *);
	void * (*seq_next)(struct seq_file___119 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___119 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___105 *, struct cftype___105 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___105 *, struct cftype___105 *, s64);
	ssize_t (*write)(struct kernfs_open_file___125 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___125 *, struct poll_table_struct___87 *);
};

struct blkcg_policy_data___12;

struct blkcg___12 {
	struct cgroup_subsys_state___105 css;
	spinlock_t lock;
	struct xarray blkg_tree;
	struct blkcg_gq___12 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___12 *cpd[5];
	struct list_head all_blkcgs_node;
	struct list_head cgwb_list;
	refcount_t cgwb_refcnt;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct blkcg_policy_data___12 {
	struct blkcg___12 *blkcg;
	int plid;
};

struct blkg_policy_data___12 {
	struct blkcg_gq___12 *blkg;
	int plid;
};

struct kernel_param_ops___107 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___107 *);
	int (*get)(char *, const struct kernel_param___107 *);
	void (*free)(void *);
};

struct kparam_array___107;

struct kernel_param___107 {
	const char *name;
	struct module___110 *mod;
	const struct kernel_param_ops___107 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___107 *arr;
	};
};

struct kparam_array___107 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___107 *ops;
	void *elem;
};

struct module_attribute___107 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___107 *, struct module_kobject___107 *, char *);
	ssize_t (*store)(struct module_attribute___107 *, struct module_kobject___107 *, const char *, size_t);
	void (*setup)(struct module___110 *, const char *);
	int (*test)(struct module___110 *);
	void (*free)(struct module___110 *);
};

struct trace_event_class___72;

struct trace_event_call___72 {
	struct list_head list;
	struct trace_event_class___72 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___4 *prog_array;
	int (*perf_perm)(struct trace_event_call___72 *, struct perf_event___79 *);
};

struct node___99 {
	struct device___120 dev;
};

struct perf_cpu_context___79;

struct pmu___79 {
	struct list_head entry;
	struct module___110 *module;
	struct device___120 *dev;
	const struct attribute_group___119 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___79 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___79 *);
	void (*pmu_disable)(struct pmu___79 *);
	int (*event_init)(struct perf_event___79 *);
	void (*event_mapped)(struct perf_event___79 *, struct mm_struct___128 *);
	void (*event_unmapped)(struct perf_event___79 *, struct mm_struct___128 *);
	int (*add)(struct perf_event___79 *, int);
	void (*del)(struct perf_event___79 *, int);
	void (*start)(struct perf_event___79 *, int);
	void (*stop)(struct perf_event___79 *, int);
	void (*read)(struct perf_event___79 *);
	void (*start_txn)(struct pmu___79 *, unsigned int);
	int (*commit_txn)(struct pmu___79 *);
	void (*cancel_txn)(struct pmu___79 *);
	int (*event_idx)(struct perf_event___79 *);
	void (*sched_task)(struct perf_event_context___79 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___79 *);
	int (*filter_match)(struct perf_event___79 *);
	int (*check_period)(struct perf_event___79 *, u64);
};

struct perf_cpu_context___79 {
	struct perf_event_context___79 ctx;
	struct perf_event_context___79 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___79 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___79 {
	struct cgroup_subsys_state___105 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___72 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___72 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___72 *);
	struct list_head * (*get_fields)(struct trace_event_call___72 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___72 *);
};

struct syscall_metadata___27 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___72 *enter_event;
	struct trace_event_call___72 *exit_event;
};

struct mem_cgroup_reclaim_iter___45 {
	struct mem_cgroup___45 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___45 {
	struct lruvec___128 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___45 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___45 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct module___111;

struct file___130;

struct kiocb___130;

struct iov_iter___56;

struct poll_table_struct___88;

struct vm_area_struct___130;

struct inode___131;

struct file_lock___130;

struct page___130;

struct seq_file___120;

struct file_operations___130 {
	struct module___111 *owner;
	loff_t (*llseek)(struct file___130 *, loff_t, int);
	ssize_t (*read)(struct file___130 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___130 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___130 *, struct iov_iter___56 *);
	ssize_t (*write_iter)(struct kiocb___130 *, struct iov_iter___56 *);
	int (*iopoll)(struct kiocb___130 *, bool);
	int (*iterate)(struct file___130 *, struct dir_context *);
	int (*iterate_shared)(struct file___130 *, struct dir_context *);
	__poll_t (*poll)(struct file___130 *, struct poll_table_struct___88 *);
	long int (*unlocked_ioctl)(struct file___130 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___130 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___130 *, struct vm_area_struct___130 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___131 *, struct file___130 *);
	int (*flush)(struct file___130 *, fl_owner_t);
	int (*release)(struct inode___131 *, struct file___130 *);
	int (*fsync)(struct file___130 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___130 *, int);
	int (*lock)(struct file___130 *, int, struct file_lock___130 *);
	ssize_t (*sendpage)(struct file___130 *, struct page___130 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___130 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___130 *, int, struct file_lock___130 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___130 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___130 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___130 *, long int, struct file_lock___130 **, void **);
	long int (*fallocate)(struct file___130 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___120 *, struct file___130 *);
	ssize_t (*copy_file_range)(struct file___130 *, loff_t, struct file___130 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___130 *, loff_t, struct file___130 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___130 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___129 {
	u64 seqnum;
	struct vm_area_struct___130 *vmas[4];
};

struct page_frag___129 {
	struct page___130 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___129;

struct mem_cgroup___46;

struct pid___105;

struct cred___125;

struct nsproxy___122;

struct signal_struct___118;

struct bio_list___51;

struct backing_dev_info___51;

struct io_context___22;

struct css_set___106;

struct request_queue___22;

struct vm_struct___98;

struct task_struct___130 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___130 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___129 *mm;
	struct mm_struct___129 *active_mm;
	struct vmacache___129 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___130 *real_parent;
	struct task_struct___130 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___130 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___46 *active_memcg;
	long int rh_reserved2;
	struct pid___105 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___105 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___105 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___125 *ptracer_cred;
	const struct cred___125 *real_cred;
	const struct cred___125 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___122 *nsproxy;
	struct signal_struct___118 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___130 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___51 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___51 *backing_dev_info;
	struct io_context___22 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___106 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___129 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___46 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___22 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___130 *oom_reaper_list;
	struct vm_struct___98 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___79 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

enum pageblock_bits {
	PB_migrate = 0,
	PB_migrate_end = 2,
	PB_migrate_skip = 3,
	NR_PAGEBLOCK_BITS = 4,
};

typedef struct page___130 *pgtable_t___129;

struct address_space___129;

struct dev_pagemap___127;

struct page___130 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___129 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___130 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___129 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___129 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___127 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___46 *mem_cgroup;
};

struct pglist_data___129;

struct lruvec___129 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___129 *pgdat;
};

struct zone___129 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___129 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___129 {
	struct zone___129 *zone;
	int zone_idx;
};

struct zonelist___129 {
	struct zoneref___129 _zonerefs[25];
};

struct pglist_data___129 {
	struct zone___129 node_zones[3];
	struct zonelist___129 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___130 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___130 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___129 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

typedef struct pglist_data___129 pg_data_t___2;

struct rw_semaphore___130 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___130 *owner;
};

struct secondary_data___130 {
	void *stack;
	struct task_struct___130 *task;
	long int status;
};

struct blocking_notifier_head___129 {
	struct rw_semaphore___130 rwsem;
	struct notifier_block *head;
};

enum memmap_context {
	MEMMAP_EARLY = 0,
	MEMMAP_HOTPLUG = 1,
};

struct mminit_pfnnid_cache {
	long unsigned int last_start;
	long unsigned int last_end;
	int last_nid;
};

struct vm_operations_struct___127;

struct vm_area_struct___130 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___130 *vm_next;
	struct vm_area_struct___130 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___129 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___127 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___130 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___129;

struct user_namespace___110;

struct mm_struct___129 {
	struct {
		struct vm_area_struct___130 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___130 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___130 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___129 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___130 *owner;
		struct user_namespace___110 *user_ns;
		struct file___130 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___129 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___129;

struct address_space___129 {
	struct inode___131 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___130 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___129 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___127)(struct vm_area_struct___130 *, long unsigned int, const struct page___130 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___127)(struct page___130 *, void *);

struct device___121;

struct dev_pagemap___127 {
	dev_page_fault_t___127 page_fault;
	dev_page_free_t___127 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___121 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct cgroup___106;

struct cgroup_subsys___106;

struct cgroup_subsys_state___106 {
	struct cgroup___106 *cgroup;
	struct cgroup_subsys___106 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___106 *parent;
};

struct kernfs_node___126;

struct cgroup_file___106 {
	struct kernfs_node___126 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___46;

struct mem_cgroup___46 {
	struct cgroup_subsys_state___106 css;
	struct mem_cgroup_id___6 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___106 events_file;
	struct cgroup_file___106 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___130 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___46 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct page_frag_cache {
	void *va;
	__u32 offset;
	unsigned int pagecnt_bias;
	bool pfmemalloc;
};

struct dentry___130;

struct path___129 {
	struct vfsmount *mnt;
	struct dentry___130 *dentry;
};

struct fown_struct___105 {
	rwlock_t lock;
	struct pid___105 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___130 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___129 f_path;
	struct inode___131 *f_inode;
	const struct file_operations___130 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___105 f_owner;
	const struct cred___125 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___129 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___127;

struct vm_operations_struct___127 {
	void (*open)(struct vm_area_struct___130 *);
	void (*close)(struct vm_area_struct___130 *);
	int (*split)(struct vm_area_struct___130 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___130 *);
	vm_fault_t (*fault)(struct vm_fault___127 *);
	vm_fault_t (*huge_fault)(struct vm_fault___127 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___127 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___130 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___127 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___127 *);
	int (*access)(struct vm_area_struct___130 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___130 *);
	int (*set_policy)(struct vm_area_struct___130 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___130 *, long unsigned int);
	struct page___130 * (*find_special_page)(struct vm_area_struct___130 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___129 {
	struct task_struct___130 *task;
	struct core_thread___129 *next;
};

struct core_state___129 {
	atomic_t nr_threads;
	struct core_thread___129 dumper;
	struct completion startup;
};

struct key___125;

struct ucounts___110;

struct user_namespace___110 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___110 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___4 ns;
	long unsigned int flags;
	struct key___125 *persistent_keyring_register;
	struct rw_semaphore___130 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___110 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___127 {
	struct vm_area_struct___130 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___130 *cow_page;
	struct mem_cgroup___46 *memcg;
	struct page___130 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___129 prealloc_pte;
};

struct shrink_control___46 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___46 *memcg;
};

struct shrinker___46 {
	long unsigned int (*count_objects)(struct shrinker___46 *, struct shrink_control___46 *);
	long unsigned int (*scan_objects)(struct shrinker___46 *, struct shrink_control___46 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct pid_namespace___105;

struct upid___105 {
	int nr;
	struct pid_namespace___105 *ns;
};

struct pid_namespace___105 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___130 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___105 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___130 *proc_self;
	struct dentry___130 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___110 *user_ns;
	struct ucounts___110 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___4 ns;
};

struct pid___105 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___105 numbers[1];
};

struct user_struct___125 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___125 *uid_keyring;
	struct key___125 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___125 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___125 *session_keyring;
	struct key___125 *process_keyring;
	struct key___125 *thread_keyring;
	struct key___125 *request_key_auth;
	void *security;
	struct user_struct___125 *user;
	struct user_namespace___110 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___106;

struct nsproxy___122 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___105 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___106 *cgroup_ns;
};

struct signal_struct___118 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___130 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___130 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___105 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___105 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___129 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___105 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide43;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___51;

struct bio_list___51 {
	struct bio___51 *head;
	struct bio___51 *tail;
};

struct bdi_writeback_congested___51;

struct bdi_writeback___51 {
	struct backing_dev_info___51 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___51 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___106 *memcg_css;
	struct cgroup_subsys_state___106 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___51 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___51 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___121 *dev;
	struct device___121 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___130 *debug_dir;
	struct dentry___130 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___22;

struct io_context___22 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___22 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___106 {
	struct cgroup_subsys_state___106 *subsys[13];
	refcount_t refcount;
	struct css_set___106 *dom_cset;
	struct cgroup___106 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___106 *mg_src_cgrp;
	struct cgroup___106 *mg_dst_cgrp;
	struct css_set___106 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

typedef blk_qc_t make_request_fn___21(struct request_queue___22 *, struct bio___51 *);

struct request___22;

typedef int dma_drain_needed_fn___21(struct request___22 *);

struct kset___123;

struct kobj_type___123;

struct kobject___124 {
	const char *name;
	struct list_head entry;
	struct kobject___124 *parent;
	struct kset___123 *kset;
	struct kobj_type___123 *ktype;
	struct kernfs_node___126 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___21;

struct bsg_class_device___21 {
	struct device___121 *class_dev;
	int minor;
	struct request_queue___22 *queue;
	const struct bsg_ops___21 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___51 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___51 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___21;

struct blkcg_gq___13;

struct request_queue___22 {
	struct list_head queue_head;
	struct request___22 *last_merge;
	struct elevator_queue___21 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___21 *make_request_fn;
	dma_drain_needed_fn___21 *dma_drain_needed;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___51 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___124 kobj;
	struct kobject___124 *mq_kobj;
	struct blk_integrity integrity;
	struct device___121 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___13 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	struct bsg_class_device___21 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___51 bio_split;
	struct dentry___130 *debugfs_dir;
	struct dentry___130 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___98 {
	struct vm_struct___98 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___130 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___118 {
	struct task_struct___130 task;
	long unsigned int stack[8192];
};

struct dev_pm_info___121 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___121 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___121;

struct bus_type___121;

struct device_driver___121;

struct dev_pm_domain___121;

struct fwnode_handle___90;

struct class___121;

struct attribute_group___120;

struct device___121 {
	struct device___121 *parent;
	struct device_private *p;
	struct kobject___124 kobj;
	const char *init_name;
	const struct device_type___121 *type;
	struct mutex mutex;
	struct bus_type___121 *bus;
	struct device_driver___121 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___121 power;
	struct dev_pm_domain___121 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___90 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___121 *class;
	const struct attribute_group___120 **groups;
	void (*release)(struct device___121 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___129;

struct super_block___130;

struct dentry___130 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___130 *d_parent;
	struct qstr d_name;
	struct inode___131 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___129 *d_op;
	struct super_block___130 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___129;

struct block_device___130;

struct inode___131 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___129 *i_op;
	struct super_block___130 *i_sb;
	struct address_space___129 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___130 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___51 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___130 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___129 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___130 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___129 {
	int (*d_revalidate)(struct dentry___130 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___130 *, unsigned int);
	int (*d_hash)(const struct dentry___130 *, struct qstr *);
	int (*d_compare)(const struct dentry___130 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___130 *);
	int (*d_init)(struct dentry___130 *);
	void (*d_release)(struct dentry___130 *);
	void (*d_prune)(struct dentry___130 *);
	void (*d_iput)(struct dentry___130 *, struct inode___131 *);
	char * (*d_dname)(struct dentry___130 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___129 *);
	int (*d_manage)(const struct path___129 *, bool);
	struct dentry___130 * (*d_real)(struct dentry___130 *, const struct inode___131 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___129;

struct mem_dqinfo___129 {
	struct quota_format_type___129 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___129;

struct quota_info___129 {
	unsigned int flags;
	struct rw_semaphore___130 dqio_sem;
	struct inode___131 *files[3];
	struct mem_dqinfo___129 info[3];
	const struct quota_format_ops___129 *ops[3];
};

struct rcuwait___129 {
	struct task_struct___130 *task;
};

struct percpu_rw_semaphore___129 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___130 rw_sem;
	struct rcuwait___129 writer;
	int readers_block;
};

struct sb_writers___129 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___129 rw_sem[3];
};

struct file_system_type___129;

struct super_operations___129;

struct dquot_operations___129;

struct quotactl_ops___129;

struct super_block___130 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___129 *s_type;
	const struct super_operations___129 *s_op;
	const struct dquot_operations___129 *dq_op;
	const struct quotactl_ops___129 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___130 *s_root;
	struct rw_semaphore___130 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___130 *s_bdev;
	struct backing_dev_info___51 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___129 s_dquot;
	struct sb_writers___129 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___129 *s_d_op;
	int cleancache_poolid;
	struct shrinker___46 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___110 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct io_cq___22 {
	struct request_queue___22 *q;
	struct io_context___22 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___2 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___130 {
	struct file___130 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___130 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___130 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___130 *ia_file;
};

struct dquot___129 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___130 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___129 {
	int qf_fmt_id;
	const struct quota_format_ops___129 *qf_ops;
	struct module___111 *qf_owner;
	struct quota_format_type___129 *qf_next;
};

struct quota_format_ops___129 {
	int (*check_quota_file)(struct super_block___130 *, int);
	int (*read_file_info)(struct super_block___130 *, int);
	int (*write_file_info)(struct super_block___130 *, int);
	int (*free_file_info)(struct super_block___130 *, int);
	int (*read_dqblk)(struct dquot___129 *);
	int (*commit_dqblk)(struct dquot___129 *);
	int (*release_dqblk)(struct dquot___129 *);
	int (*get_next_id)(struct super_block___130 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___129 {
	int (*write_dquot)(struct dquot___129 *);
	struct dquot___129 * (*alloc_dquot)(struct super_block___130 *, int);
	void (*destroy_dquot)(struct dquot___129 *);
	int (*acquire_dquot)(struct dquot___129 *);
	int (*release_dquot)(struct dquot___129 *);
	int (*mark_dirty)(struct dquot___129 *);
	int (*write_info)(struct super_block___130 *, int);
	qsize_t * (*get_reserved_space)(struct inode___131 *);
	int (*get_projid)(struct inode___131 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___131 *, qsize_t *);
	int (*get_next_id)(struct super_block___130 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___129 {
	int (*quota_on)(struct super_block___130 *, int, int, const struct path___129 *);
	int (*quota_off)(struct super_block___130 *, int);
	int (*quota_enable)(struct super_block___130 *, unsigned int);
	int (*quota_disable)(struct super_block___130 *, unsigned int);
	int (*quota_sync)(struct super_block___130 *, int);
	int (*set_info)(struct super_block___130 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___130 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___130 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___130 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___130 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___130 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___108 {
	struct kobject___124 kobj;
	struct module___111 *mod;
	struct kobject___124 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___108 {
	struct module___111 *mod;
	struct latch_tree_node node;
};

struct module_layout___108 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___108 mtn;
};

struct module_attribute___108;

struct kernel_param___108;

struct module___111 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___108 mkobj;
	struct module_attribute___108 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___124 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___108 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___108 core_layout;
	struct module_layout___108 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___48;

struct swap_info_struct___32;

struct address_space_operations___129 {
	int (*writepage)(struct page___130 *, struct writeback_control___48 *);
	int (*readpage)(struct file___130 *, struct page___130 *);
	int (*writepages)(struct address_space___129 *, struct writeback_control___48 *);
	int (*set_page_dirty)(struct page___130 *);
	int (*readpages)(struct file___130 *, struct address_space___129 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___130 *, struct address_space___129 *, loff_t, unsigned int, unsigned int, struct page___130 **, void **);
	int (*write_end)(struct file___130 *, struct address_space___129 *, loff_t, unsigned int, unsigned int, struct page___130 *, void *);
	sector_t (*bmap)(struct address_space___129 *, sector_t);
	void (*invalidatepage)(struct page___130 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___130 *, gfp_t);
	void (*freepage)(struct page___130 *);
	ssize_t (*direct_IO)(struct kiocb___130 *, struct iov_iter___56 *);
	int (*migratepage)(struct address_space___129 *, struct page___130 *, struct page___130 *, enum migrate_mode);
	bool (*isolate_page)(struct page___130 *, isolate_mode_t);
	void (*putback_page)(struct page___130 *);
	int (*launder_page)(struct page___130 *);
	int (*is_partially_uptodate)(struct page___130 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___130 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___129 *, struct page___130 *);
	int (*swap_activate)(struct swap_info_struct___32 *, struct file___130 *, sector_t *);
	void (*swap_deactivate)(struct file___130 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___48 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___51 *wb;
	struct inode___131 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___51;

struct iov_iter___56 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___51 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct swap_info_struct___32 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___130 *bdev;
	struct file___130 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct hd_struct___22;

struct gendisk___22;

struct block_device___130 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___131 *bd_inode;
	struct super_block___130 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___130 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___22 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___22 *bd_disk;
	struct request_queue___22 *bd_queue;
	struct backing_dev_info___51 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct hd_struct___22 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___121 __dev;
	struct kobject___124 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___22;

struct block_device_operations___22;

struct gendisk___22 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___22 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___22 *part_tbl;
	struct hd_struct___22 part0;
	const struct block_device_operations___22 *fops;
	struct request_queue___22 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___130 lookup_sem;
	struct kobject___124 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___124 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___129 {
	struct dentry___130 * (*lookup)(struct inode___131 *, struct dentry___130 *, unsigned int);
	const char * (*get_link)(struct dentry___130 *, struct inode___131 *, struct delayed_call *);
	int (*permission)(struct inode___131 *, int);
	struct posix_acl * (*get_acl)(struct inode___131 *, int);
	int (*readlink)(struct dentry___130 *, char *, int);
	int (*create)(struct inode___131 *, struct dentry___130 *, umode_t, bool);
	int (*link)(struct dentry___130 *, struct inode___131 *, struct dentry___130 *);
	int (*unlink)(struct inode___131 *, struct dentry___130 *);
	int (*symlink)(struct inode___131 *, struct dentry___130 *, const char *);
	int (*mkdir)(struct inode___131 *, struct dentry___130 *, umode_t);
	int (*rmdir)(struct inode___131 *, struct dentry___130 *);
	int (*mknod)(struct inode___131 *, struct dentry___130 *, umode_t, dev_t);
	int (*rename)(struct inode___131 *, struct dentry___130 *, struct inode___131 *, struct dentry___130 *, unsigned int);
	int (*setattr)(struct dentry___130 *, struct iattr___130 *);
	int (*getattr)(const struct path___129 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___130 *, char *, size_t);
	int (*fiemap)(struct inode___131 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___131 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___131 *, struct dentry___130 *, struct file___130 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___131 *, struct dentry___130 *, umode_t);
	int (*set_acl)(struct inode___131 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___129 {
	void (*fl_copy_lock)(struct file_lock___130 *, struct file_lock___130 *);
	void (*fl_release_private)(struct file_lock___130 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___129;

struct lock_manager_operations___129;

struct file_lock___130 {
	struct file_lock___130 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___130 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___129 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___129 *fl_ops;
	const struct lock_manager_operations___129 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___129 {
	int (*lm_compare_owner)(struct file_lock___130 *, struct file_lock___130 *);
	long unsigned int (*lm_owner_key)(struct file_lock___130 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___130 *);
	int (*lm_grant)(struct file_lock___130 *, int);
	bool (*lm_break)(struct file_lock___130 *);
	int (*lm_change)(struct file_lock___130 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___130 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___129 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___129 *fa_next;
	struct file___130 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___129 {
	const char *name;
	int fs_flags;
	struct dentry___130 * (*mount)(struct file_system_type___129 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___130 *);
	struct module___111 *owner;
	struct file_system_type___129 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___129 {
	struct inode___131 * (*alloc_inode)(struct super_block___130 *);
	void (*destroy_inode)(struct inode___131 *);
	void (*dirty_inode)(struct inode___131 *, int);
	int (*write_inode)(struct inode___131 *, struct writeback_control___48 *);
	int (*drop_inode)(struct inode___131 *);
	void (*evict_inode)(struct inode___131 *);
	void (*put_super)(struct super_block___130 *);
	int (*sync_fs)(struct super_block___130 *, int);
	int (*freeze_super)(struct super_block___130 *);
	int (*freeze_fs)(struct super_block___130 *);
	int (*thaw_super)(struct super_block___130 *);
	int (*unfreeze_fs)(struct super_block___130 *);
	int (*statfs)(struct dentry___130 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___130 *, int *, char *);
	void (*umount_begin)(struct super_block___130 *);
	int (*show_options)(struct seq_file___120 *, struct dentry___130 *);
	int (*show_devname)(struct seq_file___120 *, struct dentry___130 *);
	int (*show_path)(struct seq_file___120 *, struct dentry___130 *);
	int (*show_stats)(struct seq_file___120 *, struct dentry___130 *);
	ssize_t (*quota_read)(struct super_block___130 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___130 *, int, const char *, size_t, loff_t);
	struct dquot___129 ** (*get_dquots)(struct inode___131 *);
	int (*bdev_try_to_free_page)(struct super_block___130 *, struct page___130 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___130 *, struct shrink_control___46 *);
	long int (*free_cached_objects)(struct super_block___130 *, struct shrink_control___46 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___87)(struct file___130 *, wait_queue_head_t *, struct poll_table_struct___88 *);

struct poll_table_struct___88 {
	poll_queue_proc___87 _qproc;
	__poll_t _key;
};

struct seq_operations___118;

struct seq_file___120 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___118 *op;
	int poll_event;
	const struct file___130 *file;
	void *private;
};

typedef void bio_end_io_t___51(struct bio___51 *);

struct bio_vec___51 {
	struct page___130 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___51;

struct bio___51 {
	struct bio___51 *bi_next;
	struct gendisk___22 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___51 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___13 *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___51 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___51 *bi_io_vec;
	struct bio_set___51 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___51 bi_inline_vecs[0];
};

struct kobj_attribute___124 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___124 *, struct kobj_attribute___124 *, char *);
	ssize_t (*store)(struct kobject___124 *, struct kobj_attribute___124 *, const char *, size_t);
};

typedef void compound_page_dtor___127(struct page___130 *);

typedef int (*key_restrict_link_func_t___125)(struct key___125 *, const struct key_type *, const union key_payload *, struct key___125 *);

struct key_restriction___125;

struct key___125 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___130 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___125 *restrict_link;
};

struct key_restriction___125 {
	key_restrict_link_func_t___125 check;
	struct key___125 *key;
	struct key_type *keytype;
};

struct seq_operations___118 {
	void * (*start)(struct seq_file___120 *, loff_t *);
	void (*stop)(struct seq_file___120 *, void *);
	void * (*next)(struct seq_file___120 *, void *, loff_t *);
	int (*show)(struct seq_file___120 *, void *);
};

struct kernfs_root___126;

struct kernfs_elem_dir___126 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___126 *root;
};

struct kernfs_syscall_ops___126;

struct kernfs_root___126 {
	struct kernfs_node___126 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___126 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___126 {
	struct kernfs_node___126 *target_kn;
};

struct kernfs_ops___126;

struct kernfs_elem_attr___126 {
	const struct kernfs_ops___126 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___126 *notify_next;
};

struct kernfs_node___126 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___126 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___126 dir;
		struct kernfs_elem_symlink___126 symlink;
		struct kernfs_elem_attr___126 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___126;

struct kernfs_ops___126 {
	int (*open)(struct kernfs_open_file___126 *);
	void (*release)(struct kernfs_open_file___126 *);
	int (*seq_show)(struct seq_file___120 *, void *);
	void * (*seq_start)(struct seq_file___120 *, loff_t *);
	void * (*seq_next)(struct seq_file___120 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___120 *, void *);
	ssize_t (*read)(struct kernfs_open_file___126 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___126 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___126 *, struct vm_area_struct___130 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___126 *, struct poll_table_struct___88 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___126 {
	int (*remount_fs)(struct kernfs_root___126 *, int *, char *);
	int (*show_options)(struct seq_file___120 *, struct kernfs_root___126 *);
	int (*mkdir)(struct kernfs_node___126 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___126 *);
	int (*rename)(struct kernfs_node___126 *, struct kernfs_node___126 *, const char *);
	int (*show_path)(struct seq_file___120 *, struct kernfs_node___126 *, struct kernfs_root___126 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___126 {
	struct kernfs_node___126 *kn;
	struct file___130 *file;
	struct seq_file___120 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___127 *vm_ops;
};

struct cgroup_namespace___106 {
	refcount_t count;
	struct ns_common___4 ns;
	struct user_namespace___110 *user_ns;
	struct ucounts___110 *ucounts;
	struct css_set___106 *root_cset;
};

struct ucounts___110 {
	struct hlist_node node;
	struct user_namespace___110 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___106;

struct bpf_map_ops___106 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___106 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___106 *, struct file___130 *);
	void (*map_free)(struct bpf_map___106 *);
	int (*map_get_next_key)(struct bpf_map___106 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___106 *);
	void * (*map_lookup_elem)(struct bpf_map___106 *, void *);
	int (*map_update_elem)(struct bpf_map___106 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___106 *, void *);
	int (*map_push_elem)(struct bpf_map___106 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___106 *, void *);
	int (*map_peek_elem)(struct bpf_map___106 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___106 *, struct file___130 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___106 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___106 *, void *, struct seq_file___120 *);
	int (*map_check_btf)(const struct bpf_map___106 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___106 {
	const struct bpf_map_ops___106 *ops;
	struct bpf_map___106 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___125 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___106;

typedef void (*kthread_work_func_t___106)(struct kthread_work___106 *);

struct kthread_worker___106;

struct kthread_work___106 {
	struct list_head node;
	kthread_work_func_t___106 func;
	struct kthread_worker___106 *worker;
	int canceling;
};

struct kthread_worker___106 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___130 *task;
	struct kthread_work___106 *current_work;
};

struct kthread_delayed_work___106 {
	struct kthread_work___106 work;
	struct timer_list timer;
};

struct psi_group___106 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___106 *poll_kworker;
	struct kthread_delayed_work___106 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___106;

struct cgroup_rstat_cpu___106;

struct cgroup___106 {
	struct cgroup_subsys_state___106 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___126 *kn;
	struct cgroup_file___106 procs_file;
	struct cgroup_file___106 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___106 *subsys[13];
	struct cgroup_root___106 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___106 *dom_cgrp;
	struct cgroup_rstat_cpu___106 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___4 bpf;
	atomic_t congestion_count;
	struct cgroup___106 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___106 psi;
	int ancestor_ids[0];
};

struct cftype___106;

struct cgroup_subsys___106 {
	struct cgroup_subsys_state___106 * (*css_alloc)(struct cgroup_subsys_state___106 *);
	int (*css_online)(struct cgroup_subsys_state___106 *);
	void (*css_offline)(struct cgroup_subsys_state___106 *);
	void (*css_released)(struct cgroup_subsys_state___106 *);
	void (*css_free)(struct cgroup_subsys_state___106 *);
	void (*css_reset)(struct cgroup_subsys_state___106 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___106 *, int);
	int (*css_extra_stat_show)(struct seq_file___120 *, struct cgroup_subsys_state___106 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___130 *);
	void (*cancel_fork)(struct task_struct___130 *);
	void (*fork)(struct task_struct___130 *);
	void (*exit)(struct task_struct___130 *);
	void (*free)(struct task_struct___130 *);
	void (*bind)(struct cgroup_subsys_state___106 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___106 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___106 *dfl_cftypes;
	struct cftype___106 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___106 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___106 *updated_children;
	struct cgroup___106 *updated_next;
};

struct cgroup_root___106 {
	struct kernfs_root___126 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___106 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___106 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___106 *ss;
	struct list_head node;
	struct kernfs_ops___126 *kf_ops;
	int (*open)(struct kernfs_open_file___126 *);
	void (*release)(struct kernfs_open_file___126 *);
	u64 (*read_u64)(struct cgroup_subsys_state___106 *, struct cftype___106 *);
	s64 (*read_s64)(struct cgroup_subsys_state___106 *, struct cftype___106 *);
	int (*seq_show)(struct seq_file___120 *, void *);
	void * (*seq_start)(struct seq_file___120 *, loff_t *);
	void * (*seq_next)(struct seq_file___120 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___120 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___106 *, struct cftype___106 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___106 *, struct cftype___106 *, s64);
	ssize_t (*write)(struct kernfs_open_file___126 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___126 *, struct poll_table_struct___88 *);
};

struct bdi_writeback_congested___51 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___51 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

enum {
	BLK_RW_ASYNC = 0,
	BLK_RW_SYNC = 1,
};

struct bio_integrity_payload___51 {
	struct bio___51 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___51 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___51 bip_inline_vecs[0];
};

struct blkcg___13;

struct blkg_policy_data___13;

struct blkcg_gq___13 {
	struct request_queue___22 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___13 *blkcg;
	struct bdi_writeback_congested___51 *wb_congested;
	struct blkcg_gq___13 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_rwstat stat_bytes;
	struct blkg_rwstat stat_ios;
	struct blkg_policy_data___13 *pd[5];
	struct callback_head callback_head;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
};

struct mem_cgroup_reclaim_iter___46 {
	struct mem_cgroup___46 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___46 {
	struct lruvec___129 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___46 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___46 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct bin_attribute___120;

struct attribute_group___120 {
	const char *name;
	umode_t (*is_visible)(struct kobject___124 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___124 *, struct bin_attribute___120 *, int);
	struct attribute **attrs;
	struct bin_attribute___120 **bin_attrs;
};

struct bin_attribute___120 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___130 *, struct kobject___124 *, struct bin_attribute___120 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___130 *, struct kobject___124 *, struct bin_attribute___120 *, char *, loff_t, size_t);
	int (*mmap)(struct file___130 *, struct kobject___124 *, struct bin_attribute___120 *, struct vm_area_struct___130 *);
};

struct sysfs_ops___123 {
	ssize_t (*show)(struct kobject___124 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___124 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___123;

struct kset___123 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___124 kobj;
	const struct kset_uevent_ops___123 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___123 {
	void (*release)(struct kobject___124 *);
	const struct sysfs_ops___123 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___2 * (*child_ns_type)(struct kobject___124 *);
	const void * (*namespace)(struct kobject___124 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___123 {
	int (* const filter)(struct kset___123 *, struct kobject___124 *);
	const char * (* const name)(struct kset___123 *, struct kobject___124 *);
	int (* const uevent)(struct kset___123 *, struct kobject___124 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___121 {
	int (*prepare)(struct device___121 *);
	void (*complete)(struct device___121 *);
	int (*suspend)(struct device___121 *);
	int (*resume)(struct device___121 *);
	int (*freeze)(struct device___121 *);
	int (*thaw)(struct device___121 *);
	int (*poweroff)(struct device___121 *);
	int (*restore)(struct device___121 *);
	int (*suspend_late)(struct device___121 *);
	int (*resume_early)(struct device___121 *);
	int (*freeze_late)(struct device___121 *);
	int (*thaw_early)(struct device___121 *);
	int (*poweroff_late)(struct device___121 *);
	int (*restore_early)(struct device___121 *);
	int (*suspend_noirq)(struct device___121 *);
	int (*resume_noirq)(struct device___121 *);
	int (*freeze_noirq)(struct device___121 *);
	int (*thaw_noirq)(struct device___121 *);
	int (*poweroff_noirq)(struct device___121 *);
	int (*restore_noirq)(struct device___121 *);
	int (*runtime_suspend)(struct device___121 *);
	int (*runtime_resume)(struct device___121 *);
	int (*runtime_idle)(struct device___121 *);
};

struct dev_pm_domain___121 {
	struct dev_pm_ops___121 ops;
	void (*detach)(struct device___121 *, bool);
	int (*activate)(struct device___121 *);
	void (*sync)(struct device___121 *);
	void (*dismiss)(struct device___121 *);
};

struct bus_type___121 {
	const char *name;
	const char *dev_name;
	struct device___121 *dev_root;
	const struct attribute_group___120 **bus_groups;
	const struct attribute_group___120 **dev_groups;
	const struct attribute_group___120 **drv_groups;
	int (*match)(struct device___121 *, struct device_driver___121 *);
	int (*uevent)(struct device___121 *, struct kobj_uevent_env *);
	int (*probe)(struct device___121 *);
	int (*remove)(struct device___121 *);
	void (*shutdown)(struct device___121 *);
	int (*online)(struct device___121 *);
	int (*offline)(struct device___121 *);
	int (*suspend)(struct device___121 *, pm_message_t);
	int (*resume)(struct device___121 *);
	int (*num_vf)(struct device___121 *);
	int (*dma_configure)(struct device___121 *);
	const struct dev_pm_ops___121 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___121 {
	const char *name;
	struct bus_type___121 *bus;
	struct module___111 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___121 *);
	int (*remove)(struct device___121 *);
	void (*shutdown)(struct device___121 *);
	int (*suspend)(struct device___121 *, pm_message_t);
	int (*resume)(struct device___121 *);
	const struct attribute_group___120 **groups;
	const struct dev_pm_ops___121 *pm;
	void (*coredump)(struct device___121 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___121 {
	const char *name;
	const struct attribute_group___120 **groups;
	int (*uevent)(struct device___121 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___121 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___121 *);
	const struct dev_pm_ops___121 *pm;
};

struct class___121 {
	const char *name;
	struct module___111 *owner;
	const struct attribute_group___120 **class_groups;
	const struct attribute_group___120 **dev_groups;
	struct kobject___124 *dev_kobj;
	int (*dev_uevent)(struct device___121 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___121 *, umode_t *);
	void (*class_release)(struct class___121 *);
	void (*dev_release)(struct device___121 *);
	int (*shutdown_pre)(struct device___121 *);
	const struct kobj_ns_type_operations___2 *ns_type;
	const void * (*namespace)(struct device___121 *);
	const struct dev_pm_ops___121 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct fwnode_operations___90;

struct fwnode_handle___90 {
	struct fwnode_handle___90 *secondary;
	const struct fwnode_operations___90 *ops;
};

struct node___100 {
	struct device___121 dev;
};

struct kernel_param_ops___108 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___108 *);
	int (*get)(char *, const struct kernel_param___108 *);
	void (*free)(void *);
};

struct kparam_array___108;

struct kernel_param___108 {
	const char *name;
	struct module___111 *mod;
	const struct kernel_param_ops___108 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___108 *arr;
	};
};

struct kparam_array___108 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___108 *ops;
	void *elem;
};

struct module_attribute___108 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___108 *, struct module_kobject___108 *, char *);
	ssize_t (*store)(struct module_attribute___108 *, struct module_kobject___108 *, const char *, size_t);
	void (*setup)(struct module___111 *, const char *);
	int (*test)(struct module___111 *);
	void (*free)(struct module___111 *);
};

struct disk_part_tbl___22 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___22 *last_lookup;
	struct hd_struct___22 *part[0];
};

struct block_device_operations___22 {
	int (*open)(struct block_device___130 *, fmode_t);
	void (*release)(struct gendisk___22 *, fmode_t);
	int (*rw_page)(struct block_device___130 *, sector_t, struct page___130 *, unsigned int);
	int (*ioctl)(struct block_device___130 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___130 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___22 *, unsigned int);
	int (*media_changed)(struct gendisk___22 *);
	void (*unlock_native_capacity)(struct gendisk___22 *);
	int (*revalidate_disk)(struct gendisk___22 *);
	int (*getgeo)(struct block_device___130 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___130 *, long unsigned int);
	int (*report_zones)(struct gendisk___22 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___111 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___21 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___22 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___22 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___22 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___21(struct request___22 *, blk_status_t);

struct request___22 {
	struct request_queue___22 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___51 *bio;
	struct bio___51 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___51 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___22 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___21 *saved_end_io;
		} flush;
	};
	struct gendisk___22 *rq_disk;
	struct hd_struct___22 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___21 *end_io;
	void *end_io_data;
	struct request___22 *next_rq;
};

struct fwnode_reference_args___90;

struct fwnode_endpoint___90;

struct fwnode_operations___90 {
	struct fwnode_handle___90 * (*get)(struct fwnode_handle___90 *);
	void (*put)(struct fwnode_handle___90 *);
	bool (*device_is_available)(const struct fwnode_handle___90 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___90 *, const struct device___121 *);
	bool (*property_present)(const struct fwnode_handle___90 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___90 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___90 *, const char *, const char **, size_t);
	struct fwnode_handle___90 * (*get_parent)(const struct fwnode_handle___90 *);
	struct fwnode_handle___90 * (*get_next_child_node)(const struct fwnode_handle___90 *, struct fwnode_handle___90 *);
	struct fwnode_handle___90 * (*get_named_child_node)(const struct fwnode_handle___90 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___90 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___90 *);
	struct fwnode_handle___90 * (*graph_get_next_endpoint)(const struct fwnode_handle___90 *, struct fwnode_handle___90 *);
	struct fwnode_handle___90 * (*graph_get_remote_endpoint)(const struct fwnode_handle___90 *);
	struct fwnode_handle___90 * (*graph_get_port_parent)(struct fwnode_handle___90 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___90 *, struct fwnode_endpoint___90 *);
};

struct fwnode_endpoint___90 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___90 *local_fwnode;
};

struct fwnode_reference_args___90 {
	struct fwnode_handle___90 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct elevator_type___21;

struct elevator_mq_ops___21 {
	int (*init_sched)(struct request_queue___22 *, struct elevator_type___21 *);
	void (*exit_sched)(struct elevator_queue___21 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	bool (*allow_merge)(struct request_queue___22 *, struct request___22 *, struct bio___51 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx *, struct bio___51 *);
	int (*request_merge)(struct request_queue___22 *, struct request___22 **, struct bio___51 *);
	void (*request_merged)(struct request_queue___22 *, struct request___22 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___22 *, struct request___22 *, struct request___22 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___22 *, struct bio___51 *);
	void (*finish_request)(struct request___22 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___22 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___22 *, u64);
	void (*started_request)(struct request___22 *);
	void (*requeue_request)(struct request___22 *);
	struct request___22 * (*former_request)(struct request_queue___22 *, struct request___22 *);
	struct request___22 * (*next_request)(struct request_queue___22 *, struct request___22 *);
	void (*init_icq)(struct io_cq___22 *);
	void (*exit_icq)(struct io_cq___22 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___21;

struct elevator_type___21 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___21 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___21 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___111 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___21 {
	struct elevator_type___21 *type;
	void *elevator_data;
	struct kobject___124 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___21 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___21 *, char *);
	ssize_t (*store)(struct elevator_queue___21 *, const char *, size_t);
};

struct oom_control___2 {
	struct zonelist___129 *zonelist;
	nodemask_t *nodemask;
	struct mem_cgroup___46 *memcg;
	const gfp_t gfp_mask;
	const int order;
	long unsigned int totalpages;
	struct task_struct___130 *chosen;
	long unsigned int chosen_points;
};

struct blkcg_policy_data___13;

struct blkcg___13 {
	struct cgroup_subsys_state___106 css;
	spinlock_t lock;
	struct xarray blkg_tree;
	struct blkcg_gq___13 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___13 *cpd[5];
	struct list_head all_blkcgs_node;
	struct list_head cgwb_list;
	refcount_t cgwb_refcnt;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct blkcg_policy_data___13 {
	struct blkcg___13 *blkcg;
	int plid;
};

struct blkg_policy_data___13 {
	struct blkcg_gq___13 *blkg;
	int plid;
};

struct hstate___13 {
	int next_nid_to_alloc;
	int next_nid_to_free;
	unsigned int order;
	long unsigned int mask;
	long unsigned int max_huge_pages;
	long unsigned int nr_huge_pages;
	long unsigned int free_huge_pages;
	long unsigned int resv_huge_pages;
	long unsigned int surplus_huge_pages;
	long unsigned int nr_overcommit_huge_pages;
	struct list_head hugepage_activelist;
	struct list_head hugepage_freelists[8];
	unsigned int nr_huge_pages_node[8];
	unsigned int free_huge_pages_node[8];
	unsigned int surplus_huge_pages_node[8];
	struct cftype___106 cgroup_files[5];
	char name[32];
};

struct alloc_context {
	struct zonelist___129 *zonelist;
	nodemask_t *nodemask;
	struct zoneref___129 *preferred_zoneref;
	int migratetype;
	enum zone_type high_zoneidx;
	bool spread_dirty_pages;
};

struct compact_control {
	struct list_head freepages;
	struct list_head migratepages;
	struct zone___129 *zone;
	long unsigned int nr_freepages;
	long unsigned int nr_migratepages;
	long unsigned int total_migrate_scanned;
	long unsigned int total_free_scanned;
	long unsigned int free_pfn;
	long unsigned int migrate_pfn;
	long unsigned int last_migrated_pfn;
	const gfp_t gfp_mask;
	int order;
	int migratetype;
	const unsigned int alloc_flags;
	const int classzone_idx;
	enum migrate_mode mode;
	bool ignore_skip_hint;
	bool no_set_skip_hint;
	bool ignore_block_suitable;
	bool direct_compaction;
	bool whole_zone;
	bool contended;
	bool finishing_block;
};

enum mminit_level {
	MMINIT_WARNING = 0,
	MMINIT_VERIFY = 1,
	MMINIT_TRACE = 2,
};

struct module___112;

struct file___131;

struct kiocb___131;

struct iov_iter___57;

struct poll_table_struct___89;

struct vm_area_struct___131;

struct inode___132;

struct file_lock___131;

struct page___131;

struct seq_file___121;

struct file_operations___131 {
	struct module___112 *owner;
	loff_t (*llseek)(struct file___131 *, loff_t, int);
	ssize_t (*read)(struct file___131 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___131 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___131 *, struct iov_iter___57 *);
	ssize_t (*write_iter)(struct kiocb___131 *, struct iov_iter___57 *);
	int (*iopoll)(struct kiocb___131 *, bool);
	int (*iterate)(struct file___131 *, struct dir_context *);
	int (*iterate_shared)(struct file___131 *, struct dir_context *);
	__poll_t (*poll)(struct file___131 *, struct poll_table_struct___89 *);
	long int (*unlocked_ioctl)(struct file___131 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___131 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___131 *, struct vm_area_struct___131 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___132 *, struct file___131 *);
	int (*flush)(struct file___131 *, fl_owner_t);
	int (*release)(struct inode___132 *, struct file___131 *);
	int (*fsync)(struct file___131 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___131 *, int);
	int (*lock)(struct file___131 *, int, struct file_lock___131 *);
	ssize_t (*sendpage)(struct file___131 *, struct page___131 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___131 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___131 *, int, struct file_lock___131 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___131 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___131 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___131 *, long int, struct file_lock___131 **, void **);
	long int (*fallocate)(struct file___131 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___121 *, struct file___131 *);
	ssize_t (*copy_file_range)(struct file___131 *, loff_t, struct file___131 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___131 *, loff_t, struct file___131 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___131 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___130 {
	u64 seqnum;
	struct vm_area_struct___131 *vmas[4];
};

struct page_frag___130 {
	struct page___131 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___80;

struct debug_info___80 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___80 *hbp_break[16];
	struct perf_event___80 *hbp_watch[16];
};

struct thread_struct___80 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___80 debug;
	long: 64;
};

struct mm_struct___130;

struct mem_cgroup___47;

struct pid___106;

struct cred___126;

struct nsproxy___123;

struct signal_struct___119;

struct bio_list___52;

struct backing_dev_info___52;

struct io_context___23;

struct css_set___107;

struct perf_event_context___80;

struct request_queue___23;

struct vm_struct___99;

struct task_struct___131 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___131 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___130 *mm;
	struct mm_struct___130 *active_mm;
	struct vmacache___130 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___131 *real_parent;
	struct task_struct___131 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___131 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___47 *active_memcg;
	long int rh_reserved2;
	struct pid___106 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___106 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___106 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___126 *ptracer_cred;
	const struct cred___126 *real_cred;
	const struct cred___126 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___123 *nsproxy;
	struct signal_struct___119 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___131 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___52 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___52 *backing_dev_info;
	struct io_context___23 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___107 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___80 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___130 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___47 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___23 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___131 *oom_reaper_list;
	struct vm_struct___99 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___80 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___80 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___131 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___80)(struct perf_event___80 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___80;

struct fasync_struct___130;

struct pid_namespace___106;

struct trace_event_call___73;

struct perf_cgroup___80;

struct perf_event___80 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___80 *group_leader;
	struct pmu___80 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___80 hw;
	struct perf_event_context___80 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___80 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___131 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___130 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___80 *);
	struct callback_head callback_head;
	struct pid_namespace___106 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___80 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___80 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___73 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___80 *cgrp;
	struct list_head sb_list;
};

struct dentry_operations___130;

struct super_block___131;

struct dentry___131 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___131 *d_parent;
	struct qstr d_name;
	struct inode___132 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___130 *d_op;
	struct super_block___131 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct rw_semaphore___131 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___131 *owner;
};

struct address_space_operations___130;

struct address_space___130 {
	struct inode___132 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___131 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___130 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___130;

struct bdi_writeback___52;

struct block_device___131;

struct inode___132 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___130 *i_op;
	struct super_block___131 *i_sb;
	struct address_space___130 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___131 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___52 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___131 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___130 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___131 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___130;

struct dentry_operations___130 {
	int (*d_revalidate)(struct dentry___131 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___131 *, unsigned int);
	int (*d_hash)(const struct dentry___131 *, struct qstr *);
	int (*d_compare)(const struct dentry___131 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___131 *);
	int (*d_init)(struct dentry___131 *);
	void (*d_release)(struct dentry___131 *);
	void (*d_prune)(struct dentry___131 *);
	void (*d_iput)(struct dentry___131 *, struct inode___132 *);
	char * (*d_dname)(struct dentry___131 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___130 *);
	int (*d_manage)(const struct path___130 *, bool);
	struct dentry___131 * (*d_real)(struct dentry___131 *, const struct inode___132 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___130;

struct mem_dqinfo___130 {
	struct quota_format_type___130 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___130;

struct quota_info___130 {
	unsigned int flags;
	struct rw_semaphore___131 dqio_sem;
	struct inode___132 *files[3];
	struct mem_dqinfo___130 info[3];
	const struct quota_format_ops___130 *ops[3];
};

struct rcuwait___130 {
	struct task_struct___131 *task;
};

struct percpu_rw_semaphore___130 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___131 rw_sem;
	struct rcuwait___130 writer;
	int readers_block;
};

struct sb_writers___130 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___130 rw_sem[3];
};

struct shrink_control___47;

struct shrinker___47 {
	long unsigned int (*count_objects)(struct shrinker___47 *, struct shrink_control___47 *);
	long unsigned int (*scan_objects)(struct shrinker___47 *, struct shrink_control___47 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___130;

struct super_operations___130;

struct dquot_operations___130;

struct quotactl_ops___130;

struct user_namespace___111;

struct super_block___131 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___130 *s_type;
	const struct super_operations___130 *s_op;
	const struct dquot_operations___130 *dq_op;
	const struct quotactl_ops___130 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___131 *s_root;
	struct rw_semaphore___131 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___131 *s_bdev;
	struct backing_dev_info___52 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___130 s_dquot;
	struct sb_writers___130 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___130 *s_d_op;
	int cleancache_poolid;
	struct shrinker___47 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___111 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct path___130 {
	struct vfsmount *mnt;
	struct dentry___131 *dentry;
};

struct key___126;

struct ucounts___111;

struct user_namespace___111 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___111 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___4 ns;
	long unsigned int flags;
	struct key___126 *persistent_keyring_register;
	struct rw_semaphore___131 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___111 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct shrink_control___47 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___47 *memcg;
};

struct cgroup___107;

struct cgroup_subsys___107;

struct cgroup_subsys_state___107 {
	struct cgroup___107 *cgroup;
	struct cgroup_subsys___107 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___107 *parent;
};

struct kernfs_node___127;

struct cgroup_file___107 {
	struct kernfs_node___127 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___47;

struct mem_cgroup___47 {
	struct cgroup_subsys_state___107 css;
	struct mem_cgroup_id___6 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___107 events_file;
	struct cgroup_file___107 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___131 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___47 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___131 *pgtable_t___130;

struct dev_pagemap___128;

struct page___131 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___130 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___131 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___130 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___130 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___128 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___47 *mem_cgroup;
};

struct pglist_data___130;

struct lruvec___130 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___130 *pgdat;
};

struct zone___130 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___130 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___130 {
	struct zone___130 *zone;
	int zone_idx;
};

struct zonelist___130 {
	struct zoneref___130 _zonerefs[25];
};

struct pglist_data___130 {
	struct zone___130 node_zones[3];
	struct zonelist___130 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___131 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___131 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___130 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

typedef struct pglist_data___130 pg_data_t___3;

struct secondary_data___131 {
	void *stack;
	struct task_struct___131 *task;
	long int status;
};

struct blocking_notifier_head___130 {
	struct rw_semaphore___131 rwsem;
	struct notifier_block *head;
};

struct upid___106 {
	int nr;
	struct pid_namespace___106 *ns;
};

struct pid_namespace___106 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___131 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___106 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___131 *proc_self;
	struct dentry___131 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___111 *user_ns;
	struct ucounts___111 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___4 ns;
};

struct pid___106 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___106 numbers[1];
};

struct anon_vma___5;

struct vm_operations_struct___128;

struct vm_area_struct___131 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___131 *vm_next;
	struct vm_area_struct___131 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___130 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma___5 *anon_vma;
	const struct vm_operations_struct___128 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___131 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___130;

struct mm_struct___130 {
	struct {
		struct vm_area_struct___131 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___131 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___131 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___130 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___131 *owner;
		struct user_namespace___111 *user_ns;
		struct file___131 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___130 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___128)(struct vm_area_struct___131 *, long unsigned int, const struct page___131 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___128)(struct page___131 *, void *);

struct device___122;

struct dev_pagemap___128 {
	dev_page_fault_t___128 page_fault;
	dev_page_free_t___128 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___122 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct fown_struct___106 {
	rwlock_t lock;
	struct pid___106 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___131 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___130 f_path;
	struct inode___132 *f_inode;
	const struct file_operations___131 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___106 f_owner;
	const struct cred___126 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___130 *f_mapping;
	errseq_t f_wb_err;
};

struct anon_vma___5 {
	struct anon_vma___5 *root;
	struct rw_semaphore___131 rwsem;
	atomic_t refcount;
	unsigned int degree;
	struct anon_vma___5 *parent;
	struct rb_root_cached rb_root;
};

struct vm_fault___128;

struct vm_operations_struct___128 {
	void (*open)(struct vm_area_struct___131 *);
	void (*close)(struct vm_area_struct___131 *);
	int (*split)(struct vm_area_struct___131 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___131 *);
	vm_fault_t (*fault)(struct vm_fault___128 *);
	vm_fault_t (*huge_fault)(struct vm_fault___128 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___128 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___131 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___128 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___128 *);
	int (*access)(struct vm_area_struct___131 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___131 *);
	int (*set_policy)(struct vm_area_struct___131 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___131 *, long unsigned int);
	struct page___131 * (*find_special_page)(struct vm_area_struct___131 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___130 {
	struct task_struct___131 *task;
	struct core_thread___130 *next;
};

struct core_state___130 {
	atomic_t nr_threads;
	struct core_thread___130 dumper;
	struct completion startup;
};

struct vm_fault___128 {
	struct vm_area_struct___131 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___131 *cow_page;
	struct mem_cgroup___47 *memcg;
	struct page___131 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___130 prealloc_pte;
};

struct user_struct___126 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___126 *uid_keyring;
	struct key___126 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___126 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___126 *session_keyring;
	struct key___126 *process_keyring;
	struct key___126 *thread_keyring;
	struct key___126 *request_key_auth;
	void *security;
	struct user_struct___126 *user;
	struct user_namespace___111 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___107;

struct nsproxy___123 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___106 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___107 *cgroup_ns;
};

struct signal_struct___119 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___131 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___131 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___106 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___106 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___130 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___106 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide45;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___52;

struct bio_list___52 {
	struct bio___52 *head;
	struct bio___52 *tail;
};

struct bdi_writeback_congested___52;

struct bdi_writeback___52 {
	struct backing_dev_info___52 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___52 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___107 *memcg_css;
	struct cgroup_subsys_state___107 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___52 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___52 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___122 *dev;
	struct device___122 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___131 *debug_dir;
	struct dentry___131 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___23;

struct io_context___23 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___23 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___107 {
	struct cgroup_subsys_state___107 *subsys[13];
	refcount_t refcount;
	struct css_set___107 *dom_cset;
	struct cgroup___107 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___107 *mg_src_cgrp;
	struct cgroup___107 *mg_dst_cgrp;
	struct css_set___107 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___80 {
	struct pmu___80 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___131 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___80 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

typedef blk_qc_t make_request_fn___22(struct request_queue___23 *, struct bio___52 *);

struct request___23;

typedef int dma_drain_needed_fn___22(struct request___23 *);

struct kset___124;

struct kobj_type___124;

struct kobject___125 {
	const char *name;
	struct list_head entry;
	struct kobject___125 *parent;
	struct kset___124 *kset;
	struct kobj_type___124 *ktype;
	struct kernfs_node___127 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___22;

struct bsg_class_device___22 {
	struct device___122 *class_dev;
	int minor;
	struct request_queue___23 *queue;
	const struct bsg_ops___22 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___52 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___52 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___22;

struct blkcg_gq___14;

struct request_queue___23 {
	struct list_head queue_head;
	struct request___23 *last_merge;
	struct elevator_queue___22 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___22 *make_request_fn;
	dma_drain_needed_fn___22 *dma_drain_needed;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___52 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___125 kobj;
	struct kobject___125 *mq_kobj;
	struct blk_integrity integrity;
	struct device___122 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___14 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	struct bsg_class_device___22 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___52 bio_split;
	struct dentry___131 *debugfs_dir;
	struct dentry___131 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___99 {
	struct vm_struct___99 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___131 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___119 {
	struct task_struct___131 task;
	long unsigned int stack[8192];
};

struct io_cq___23 {
	struct request_queue___23 *q;
	struct io_context___23 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___2 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___131 {
	struct file___131 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___131 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___131 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___131 *ia_file;
};

struct dquot___130 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___131 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___130 {
	int qf_fmt_id;
	const struct quota_format_ops___130 *qf_ops;
	struct module___112 *qf_owner;
	struct quota_format_type___130 *qf_next;
};

struct quota_format_ops___130 {
	int (*check_quota_file)(struct super_block___131 *, int);
	int (*read_file_info)(struct super_block___131 *, int);
	int (*write_file_info)(struct super_block___131 *, int);
	int (*free_file_info)(struct super_block___131 *, int);
	int (*read_dqblk)(struct dquot___130 *);
	int (*commit_dqblk)(struct dquot___130 *);
	int (*release_dqblk)(struct dquot___130 *);
	int (*get_next_id)(struct super_block___131 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___130 {
	int (*write_dquot)(struct dquot___130 *);
	struct dquot___130 * (*alloc_dquot)(struct super_block___131 *, int);
	void (*destroy_dquot)(struct dquot___130 *);
	int (*acquire_dquot)(struct dquot___130 *);
	int (*release_dquot)(struct dquot___130 *);
	int (*mark_dirty)(struct dquot___130 *);
	int (*write_info)(struct super_block___131 *, int);
	qsize_t * (*get_reserved_space)(struct inode___132 *);
	int (*get_projid)(struct inode___132 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___132 *, qsize_t *);
	int (*get_next_id)(struct super_block___131 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___130 {
	int (*quota_on)(struct super_block___131 *, int, int, const struct path___130 *);
	int (*quota_off)(struct super_block___131 *, int);
	int (*quota_enable)(struct super_block___131 *, unsigned int);
	int (*quota_disable)(struct super_block___131 *, unsigned int);
	int (*quota_sync)(struct super_block___131 *, int);
	int (*set_info)(struct super_block___131 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___131 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___131 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___131 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___131 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___131 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___109 {
	struct kobject___125 kobj;
	struct module___112 *mod;
	struct kobject___125 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___109 {
	struct module___112 *mod;
	struct latch_tree_node node;
};

struct module_layout___109 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___109 mtn;
};

struct module_attribute___109;

struct kernel_param___109;

struct module___112 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___109 mkobj;
	struct module_attribute___109 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___125 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___109 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___109 core_layout;
	struct module_layout___109 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___73 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide43;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide44;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___49;

struct swap_info_struct___33;

struct address_space_operations___130 {
	int (*writepage)(struct page___131 *, struct writeback_control___49 *);
	int (*readpage)(struct file___131 *, struct page___131 *);
	int (*writepages)(struct address_space___130 *, struct writeback_control___49 *);
	int (*set_page_dirty)(struct page___131 *);
	int (*readpages)(struct file___131 *, struct address_space___130 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___131 *, struct address_space___130 *, loff_t, unsigned int, unsigned int, struct page___131 **, void **);
	int (*write_end)(struct file___131 *, struct address_space___130 *, loff_t, unsigned int, unsigned int, struct page___131 *, void *);
	sector_t (*bmap)(struct address_space___130 *, sector_t);
	void (*invalidatepage)(struct page___131 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___131 *, gfp_t);
	void (*freepage)(struct page___131 *);
	ssize_t (*direct_IO)(struct kiocb___131 *, struct iov_iter___57 *);
	int (*migratepage)(struct address_space___130 *, struct page___131 *, struct page___131 *, enum migrate_mode);
	bool (*isolate_page)(struct page___131 *, isolate_mode_t);
	void (*putback_page)(struct page___131 *);
	int (*launder_page)(struct page___131 *);
	int (*is_partially_uptodate)(struct page___131 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___131 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___130 *, struct page___131 *);
	int (*swap_activate)(struct swap_info_struct___33 *, struct file___131 *, sector_t *);
	void (*swap_deactivate)(struct file___131 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___49 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___52 *wb;
	struct inode___132 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___52;

struct iov_iter___57 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___52 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct swap_info_struct___33 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___131 *bdev;
	struct file___131 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct hd_struct___23;

struct gendisk___23;

struct block_device___131 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___132 *bd_inode;
	struct super_block___131 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___131 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___23 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___23 *bd_disk;
	struct request_queue___23 *bd_queue;
	struct backing_dev_info___52 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___122 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___122 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___122;

struct bus_type___122;

struct device_driver___122;

struct dev_pm_domain___122;

struct fwnode_handle___91;

struct class___122;

struct attribute_group___121;

struct device___122 {
	struct device___122 *parent;
	struct device_private *p;
	struct kobject___125 kobj;
	const char *init_name;
	const struct device_type___122 *type;
	struct mutex mutex;
	struct bus_type___122 *bus;
	struct device_driver___122 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___122 power;
	struct dev_pm_domain___122 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___91 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___122 *class;
	const struct attribute_group___121 **groups;
	void (*release)(struct device___122 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___23 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___122 __dev;
	struct kobject___125 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___23;

struct block_device_operations___23;

struct gendisk___23 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___23 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___23 *part_tbl;
	struct hd_struct___23 part0;
	const struct block_device_operations___23 *fops;
	struct request_queue___23 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___131 lookup_sem;
	struct kobject___125 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___125 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___130 {
	struct dentry___131 * (*lookup)(struct inode___132 *, struct dentry___131 *, unsigned int);
	const char * (*get_link)(struct dentry___131 *, struct inode___132 *, struct delayed_call *);
	int (*permission)(struct inode___132 *, int);
	struct posix_acl * (*get_acl)(struct inode___132 *, int);
	int (*readlink)(struct dentry___131 *, char *, int);
	int (*create)(struct inode___132 *, struct dentry___131 *, umode_t, bool);
	int (*link)(struct dentry___131 *, struct inode___132 *, struct dentry___131 *);
	int (*unlink)(struct inode___132 *, struct dentry___131 *);
	int (*symlink)(struct inode___132 *, struct dentry___131 *, const char *);
	int (*mkdir)(struct inode___132 *, struct dentry___131 *, umode_t);
	int (*rmdir)(struct inode___132 *, struct dentry___131 *);
	int (*mknod)(struct inode___132 *, struct dentry___131 *, umode_t, dev_t);
	int (*rename)(struct inode___132 *, struct dentry___131 *, struct inode___132 *, struct dentry___131 *, unsigned int);
	int (*setattr)(struct dentry___131 *, struct iattr___131 *);
	int (*getattr)(const struct path___130 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___131 *, char *, size_t);
	int (*fiemap)(struct inode___132 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___132 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___132 *, struct dentry___131 *, struct file___131 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___132 *, struct dentry___131 *, umode_t);
	int (*set_acl)(struct inode___132 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___130 {
	void (*fl_copy_lock)(struct file_lock___131 *, struct file_lock___131 *);
	void (*fl_release_private)(struct file_lock___131 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___130;

struct file_lock___131 {
	struct file_lock___131 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___131 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___130 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___130 *fl_ops;
	const struct lock_manager_operations___130 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___130 {
	int (*lm_compare_owner)(struct file_lock___131 *, struct file_lock___131 *);
	long unsigned int (*lm_owner_key)(struct file_lock___131 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___131 *);
	int (*lm_grant)(struct file_lock___131 *, int);
	bool (*lm_break)(struct file_lock___131 *);
	int (*lm_change)(struct file_lock___131 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___131 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___130 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___130 *fa_next;
	struct file___131 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___130 {
	const char *name;
	int fs_flags;
	struct dentry___131 * (*mount)(struct file_system_type___130 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___131 *);
	struct module___112 *owner;
	struct file_system_type___130 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___130 {
	struct inode___132 * (*alloc_inode)(struct super_block___131 *);
	void (*destroy_inode)(struct inode___132 *);
	void (*dirty_inode)(struct inode___132 *, int);
	int (*write_inode)(struct inode___132 *, struct writeback_control___49 *);
	int (*drop_inode)(struct inode___132 *);
	void (*evict_inode)(struct inode___132 *);
	void (*put_super)(struct super_block___131 *);
	int (*sync_fs)(struct super_block___131 *, int);
	int (*freeze_super)(struct super_block___131 *);
	int (*freeze_fs)(struct super_block___131 *);
	int (*thaw_super)(struct super_block___131 *);
	int (*unfreeze_fs)(struct super_block___131 *);
	int (*statfs)(struct dentry___131 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___131 *, int *, char *);
	void (*umount_begin)(struct super_block___131 *);
	int (*show_options)(struct seq_file___121 *, struct dentry___131 *);
	int (*show_devname)(struct seq_file___121 *, struct dentry___131 *);
	int (*show_path)(struct seq_file___121 *, struct dentry___131 *);
	int (*show_stats)(struct seq_file___121 *, struct dentry___131 *);
	ssize_t (*quota_read)(struct super_block___131 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___131 *, int, const char *, size_t, loff_t);
	struct dquot___130 ** (*get_dquots)(struct inode___132 *);
	int (*bdev_try_to_free_page)(struct super_block___131 *, struct page___131 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___131 *, struct shrink_control___47 *);
	long int (*free_cached_objects)(struct super_block___131 *, struct shrink_control___47 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___88)(struct file___131 *, wait_queue_head_t *, struct poll_table_struct___89 *);

struct poll_table_struct___89 {
	poll_queue_proc___88 _qproc;
	__poll_t _key;
};

struct seq_operations___119;

struct seq_file___121 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___119 *op;
	int poll_event;
	const struct file___131 *file;
	void *private;
};

typedef void bio_end_io_t___52(struct bio___52 *);

struct bio_vec___52 {
	struct page___131 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___52;

struct bio___52 {
	struct bio___52 *bi_next;
	struct gendisk___23 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___52 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___14 *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___52 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___52 *bi_io_vec;
	struct bio_set___52 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___52 bi_inline_vecs[0];
};

struct kobj_attribute___125 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___125 *, struct kobj_attribute___125 *, char *);
	ssize_t (*store)(struct kobject___125 *, struct kobj_attribute___125 *, const char *, size_t);
};

typedef void compound_page_dtor___128(struct page___131 *);

typedef int (*key_restrict_link_func_t___126)(struct key___126 *, const struct key_type *, const union key_payload *, struct key___126 *);

struct key_restriction___126;

struct key___126 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___131 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___126 *restrict_link;
};

struct key_restriction___126 {
	key_restrict_link_func_t___126 check;
	struct key___126 *key;
	struct key_type *keytype;
};

struct seq_operations___119 {
	void * (*start)(struct seq_file___121 *, loff_t *);
	void (*stop)(struct seq_file___121 *, void *);
	void * (*next)(struct seq_file___121 *, void *, loff_t *);
	int (*show)(struct seq_file___121 *, void *);
};

struct kernfs_root___127;

struct kernfs_elem_dir___127 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___127 *root;
};

struct kernfs_syscall_ops___127;

struct kernfs_root___127 {
	struct kernfs_node___127 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___127 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___127 {
	struct kernfs_node___127 *target_kn;
};

struct kernfs_ops___127;

struct kernfs_elem_attr___127 {
	const struct kernfs_ops___127 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___127 *notify_next;
};

struct kernfs_node___127 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___127 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___127 dir;
		struct kernfs_elem_symlink___127 symlink;
		struct kernfs_elem_attr___127 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___127;

struct kernfs_ops___127 {
	int (*open)(struct kernfs_open_file___127 *);
	void (*release)(struct kernfs_open_file___127 *);
	int (*seq_show)(struct seq_file___121 *, void *);
	void * (*seq_start)(struct seq_file___121 *, loff_t *);
	void * (*seq_next)(struct seq_file___121 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___121 *, void *);
	ssize_t (*read)(struct kernfs_open_file___127 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___127 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___127 *, struct vm_area_struct___131 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___127 *, struct poll_table_struct___89 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___127 {
	int (*remount_fs)(struct kernfs_root___127 *, int *, char *);
	int (*show_options)(struct seq_file___121 *, struct kernfs_root___127 *);
	int (*mkdir)(struct kernfs_node___127 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___127 *);
	int (*rename)(struct kernfs_node___127 *, struct kernfs_node___127 *, const char *);
	int (*show_path)(struct seq_file___121 *, struct kernfs_node___127 *, struct kernfs_root___127 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___127 {
	struct kernfs_node___127 *kn;
	struct file___131 *file;
	struct seq_file___121 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___128 *vm_ops;
};

struct cgroup_namespace___107 {
	refcount_t count;
	struct ns_common___4 ns;
	struct user_namespace___111 *user_ns;
	struct ucounts___111 *ucounts;
	struct css_set___107 *root_cset;
};

struct ucounts___111 {
	struct hlist_node node;
	struct user_namespace___111 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___107;

struct bpf_map_ops___107 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___107 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___107 *, struct file___131 *);
	void (*map_free)(struct bpf_map___107 *);
	int (*map_get_next_key)(struct bpf_map___107 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___107 *);
	void * (*map_lookup_elem)(struct bpf_map___107 *, void *);
	int (*map_update_elem)(struct bpf_map___107 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___107 *, void *);
	int (*map_push_elem)(struct bpf_map___107 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___107 *, void *);
	int (*map_peek_elem)(struct bpf_map___107 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___107 *, struct file___131 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___107 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___107 *, void *, struct seq_file___121 *);
	int (*map_check_btf)(const struct bpf_map___107 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___107 {
	const struct bpf_map_ops___107 *ops;
	struct bpf_map___107 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___126 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___107;

typedef void (*kthread_work_func_t___107)(struct kthread_work___107 *);

struct kthread_worker___107;

struct kthread_work___107 {
	struct list_head node;
	kthread_work_func_t___107 func;
	struct kthread_worker___107 *worker;
	int canceling;
};

struct kthread_worker___107 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___131 *task;
	struct kthread_work___107 *current_work;
};

struct kthread_delayed_work___107 {
	struct kthread_work___107 work;
	struct timer_list timer;
};

struct psi_group___107 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___107 *poll_kworker;
	struct kthread_delayed_work___107 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___107;

struct cgroup_rstat_cpu___107;

struct cgroup___107 {
	struct cgroup_subsys_state___107 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___127 *kn;
	struct cgroup_file___107 procs_file;
	struct cgroup_file___107 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___107 *subsys[13];
	struct cgroup_root___107 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___107 *dom_cgrp;
	struct cgroup_rstat_cpu___107 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___4 bpf;
	atomic_t congestion_count;
	struct cgroup___107 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___107 psi;
	int ancestor_ids[0];
};

struct cftype___107;

struct cgroup_subsys___107 {
	struct cgroup_subsys_state___107 * (*css_alloc)(struct cgroup_subsys_state___107 *);
	int (*css_online)(struct cgroup_subsys_state___107 *);
	void (*css_offline)(struct cgroup_subsys_state___107 *);
	void (*css_released)(struct cgroup_subsys_state___107 *);
	void (*css_free)(struct cgroup_subsys_state___107 *);
	void (*css_reset)(struct cgroup_subsys_state___107 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___107 *, int);
	int (*css_extra_stat_show)(struct seq_file___121 *, struct cgroup_subsys_state___107 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___131 *);
	void (*cancel_fork)(struct task_struct___131 *);
	void (*fork)(struct task_struct___131 *);
	void (*exit)(struct task_struct___131 *);
	void (*free)(struct task_struct___131 *);
	void (*bind)(struct cgroup_subsys_state___107 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___107 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___107 *dfl_cftypes;
	struct cftype___107 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___107 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___107 *updated_children;
	struct cgroup___107 *updated_next;
};

struct cgroup_root___107 {
	struct kernfs_root___127 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___107 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___107 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___107 *ss;
	struct list_head node;
	struct kernfs_ops___127 *kf_ops;
	int (*open)(struct kernfs_open_file___127 *);
	void (*release)(struct kernfs_open_file___127 *);
	u64 (*read_u64)(struct cgroup_subsys_state___107 *, struct cftype___107 *);
	s64 (*read_s64)(struct cgroup_subsys_state___107 *, struct cftype___107 *);
	int (*seq_show)(struct seq_file___121 *, void *);
	void * (*seq_start)(struct seq_file___121 *, loff_t *);
	void * (*seq_next)(struct seq_file___121 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___121 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___107 *, struct cftype___107 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___107 *, struct cftype___107 *, s64);
	ssize_t (*write)(struct kernfs_open_file___127 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___127 *, struct poll_table_struct___89 *);
};

enum wb_state {
	WB_registered = 0,
	WB_writeback_running = 1,
	WB_has_dirty_io = 2,
	WB_start_all = 3,
};

struct bdi_writeback_congested___52 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___52 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct wb_lock_cookie {
	bool locked;
	long unsigned int flags;
};

struct bio_integrity_payload___52 {
	struct bio___52 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___52 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___52 bip_inline_vecs[0];
};

struct blkcg___14;

struct blkg_policy_data___14;

struct blkcg_gq___14 {
	struct request_queue___23 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___14 *blkcg;
	struct bdi_writeback_congested___52 *wb_congested;
	struct blkcg_gq___14 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_rwstat stat_bytes;
	struct blkg_rwstat stat_ios;
	struct blkg_policy_data___14 *pd[5];
	struct callback_head callback_head;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
};

typedef int (*writepage_t)(struct page___131 *, struct writeback_control___49 *, void *);

struct mem_cgroup_reclaim_iter___47 {
	struct mem_cgroup___47 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___47 {
	struct lruvec___130 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___47 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___47 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct bin_attribute___121;

struct attribute_group___121 {
	const char *name;
	umode_t (*is_visible)(struct kobject___125 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___125 *, struct bin_attribute___121 *, int);
	struct attribute **attrs;
	struct bin_attribute___121 **bin_attrs;
};

struct bin_attribute___121 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___131 *, struct kobject___125 *, struct bin_attribute___121 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___131 *, struct kobject___125 *, struct bin_attribute___121 *, char *, loff_t, size_t);
	int (*mmap)(struct file___131 *, struct kobject___125 *, struct bin_attribute___121 *, struct vm_area_struct___131 *);
};

struct sysfs_ops___124 {
	ssize_t (*show)(struct kobject___125 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___125 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___124;

struct kset___124 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___125 kobj;
	const struct kset_uevent_ops___124 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___124 {
	void (*release)(struct kobject___125 *);
	const struct sysfs_ops___124 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___2 * (*child_ns_type)(struct kobject___125 *);
	const void * (*namespace)(struct kobject___125 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___124 {
	int (* const filter)(struct kset___124 *, struct kobject___125 *);
	const char * (* const name)(struct kset___124 *, struct kobject___125 *);
	int (* const uevent)(struct kset___124 *, struct kobject___125 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___122 {
	int (*prepare)(struct device___122 *);
	void (*complete)(struct device___122 *);
	int (*suspend)(struct device___122 *);
	int (*resume)(struct device___122 *);
	int (*freeze)(struct device___122 *);
	int (*thaw)(struct device___122 *);
	int (*poweroff)(struct device___122 *);
	int (*restore)(struct device___122 *);
	int (*suspend_late)(struct device___122 *);
	int (*resume_early)(struct device___122 *);
	int (*freeze_late)(struct device___122 *);
	int (*thaw_early)(struct device___122 *);
	int (*poweroff_late)(struct device___122 *);
	int (*restore_early)(struct device___122 *);
	int (*suspend_noirq)(struct device___122 *);
	int (*resume_noirq)(struct device___122 *);
	int (*freeze_noirq)(struct device___122 *);
	int (*thaw_noirq)(struct device___122 *);
	int (*poweroff_noirq)(struct device___122 *);
	int (*restore_noirq)(struct device___122 *);
	int (*runtime_suspend)(struct device___122 *);
	int (*runtime_resume)(struct device___122 *);
	int (*runtime_idle)(struct device___122 *);
};

struct dev_pm_domain___122 {
	struct dev_pm_ops___122 ops;
	void (*detach)(struct device___122 *, bool);
	int (*activate)(struct device___122 *);
	void (*sync)(struct device___122 *);
	void (*dismiss)(struct device___122 *);
};

struct bus_type___122 {
	const char *name;
	const char *dev_name;
	struct device___122 *dev_root;
	const struct attribute_group___121 **bus_groups;
	const struct attribute_group___121 **dev_groups;
	const struct attribute_group___121 **drv_groups;
	int (*match)(struct device___122 *, struct device_driver___122 *);
	int (*uevent)(struct device___122 *, struct kobj_uevent_env *);
	int (*probe)(struct device___122 *);
	int (*remove)(struct device___122 *);
	void (*shutdown)(struct device___122 *);
	int (*online)(struct device___122 *);
	int (*offline)(struct device___122 *);
	int (*suspend)(struct device___122 *, pm_message_t);
	int (*resume)(struct device___122 *);
	int (*num_vf)(struct device___122 *);
	int (*dma_configure)(struct device___122 *);
	const struct dev_pm_ops___122 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___122 {
	const char *name;
	struct bus_type___122 *bus;
	struct module___112 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___122 *);
	int (*remove)(struct device___122 *);
	void (*shutdown)(struct device___122 *);
	int (*suspend)(struct device___122 *, pm_message_t);
	int (*resume)(struct device___122 *);
	const struct attribute_group___121 **groups;
	const struct dev_pm_ops___122 *pm;
	void (*coredump)(struct device___122 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___122 {
	const char *name;
	const struct attribute_group___121 **groups;
	int (*uevent)(struct device___122 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___122 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___122 *);
	const struct dev_pm_ops___122 *pm;
};

struct class___122 {
	const char *name;
	struct module___112 *owner;
	const struct attribute_group___121 **class_groups;
	const struct attribute_group___121 **dev_groups;
	struct kobject___125 *dev_kobj;
	int (*dev_uevent)(struct device___122 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___122 *, umode_t *);
	void (*class_release)(struct class___122 *);
	void (*dev_release)(struct device___122 *);
	int (*shutdown_pre)(struct device___122 *);
	const struct kobj_ns_type_operations___2 *ns_type;
	const void * (*namespace)(struct device___122 *);
	const struct dev_pm_ops___122 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct fwnode_operations___91;

struct fwnode_handle___91 {
	struct fwnode_handle___91 *secondary;
	const struct fwnode_operations___91 *ops;
};

struct node___101 {
	struct device___122 dev;
};

struct disk_part_tbl___23 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___23 *last_lookup;
	struct hd_struct___23 *part[0];
};

struct block_device_operations___23 {
	int (*open)(struct block_device___131 *, fmode_t);
	void (*release)(struct gendisk___23 *, fmode_t);
	int (*rw_page)(struct block_device___131 *, sector_t, struct page___131 *, unsigned int);
	int (*ioctl)(struct block_device___131 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___131 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___23 *, unsigned int);
	int (*media_changed)(struct gendisk___23 *);
	void (*unlock_native_capacity)(struct gendisk___23 *);
	int (*revalidate_disk)(struct gendisk___23 *);
	int (*getgeo)(struct block_device___131 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___131 *, long unsigned int);
	int (*report_zones)(struct gendisk___23 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___112 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___22 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___23 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___23 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___23 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___22(struct request___23 *, blk_status_t);

struct request___23 {
	struct request_queue___23 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___52 *bio;
	struct bio___52 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___52 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___23 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___22 *saved_end_io;
		} flush;
	};
	struct gendisk___23 *rq_disk;
	struct hd_struct___23 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___22 *end_io;
	void *end_io_data;
	struct request___23 *next_rq;
};

struct fwnode_reference_args___91;

struct fwnode_endpoint___91;

struct fwnode_operations___91 {
	struct fwnode_handle___91 * (*get)(struct fwnode_handle___91 *);
	void (*put)(struct fwnode_handle___91 *);
	bool (*device_is_available)(const struct fwnode_handle___91 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___91 *, const struct device___122 *);
	bool (*property_present)(const struct fwnode_handle___91 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___91 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___91 *, const char *, const char **, size_t);
	struct fwnode_handle___91 * (*get_parent)(const struct fwnode_handle___91 *);
	struct fwnode_handle___91 * (*get_next_child_node)(const struct fwnode_handle___91 *, struct fwnode_handle___91 *);
	struct fwnode_handle___91 * (*get_named_child_node)(const struct fwnode_handle___91 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___91 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___91 *);
	struct fwnode_handle___91 * (*graph_get_next_endpoint)(const struct fwnode_handle___91 *, struct fwnode_handle___91 *);
	struct fwnode_handle___91 * (*graph_get_remote_endpoint)(const struct fwnode_handle___91 *);
	struct fwnode_handle___91 * (*graph_get_port_parent)(struct fwnode_handle___91 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___91 *, struct fwnode_endpoint___91 *);
};

struct fwnode_endpoint___91 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___91 *local_fwnode;
};

struct fwnode_reference_args___91 {
	struct fwnode_handle___91 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct elevator_type___22;

struct elevator_mq_ops___22 {
	int (*init_sched)(struct request_queue___23 *, struct elevator_type___22 *);
	void (*exit_sched)(struct elevator_queue___22 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	bool (*allow_merge)(struct request_queue___23 *, struct request___23 *, struct bio___52 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx *, struct bio___52 *);
	int (*request_merge)(struct request_queue___23 *, struct request___23 **, struct bio___52 *);
	void (*request_merged)(struct request_queue___23 *, struct request___23 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___23 *, struct request___23 *, struct request___23 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___23 *, struct bio___52 *);
	void (*finish_request)(struct request___23 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___23 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___23 *, u64);
	void (*started_request)(struct request___23 *);
	void (*requeue_request)(struct request___23 *);
	struct request___23 * (*former_request)(struct request_queue___23 *, struct request___23 *);
	struct request___23 * (*next_request)(struct request_queue___23 *, struct request___23 *);
	void (*init_icq)(struct io_cq___23 *);
	void (*exit_icq)(struct io_cq___23 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___22;

struct elevator_type___22 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___22 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___22 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___112 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___22 {
	struct elevator_type___22 *type;
	void *elevator_data;
	struct kobject___125 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___22 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___22 *, char *);
	ssize_t (*store)(struct elevator_queue___22 *, const char *, size_t);
};

struct blkcg_policy_data___14;

struct blkcg___14 {
	struct cgroup_subsys_state___107 css;
	spinlock_t lock;
	struct xarray blkg_tree;
	struct blkcg_gq___14 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___14 *cpd[5];
	struct list_head all_blkcgs_node;
	struct list_head cgwb_list;
	refcount_t cgwb_refcnt;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct blkcg_policy_data___14 {
	struct blkcg___14 *blkcg;
	int plid;
};

struct blkg_policy_data___14 {
	struct blkcg_gq___14 *blkg;
	int plid;
};

struct kernel_param_ops___109 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___109 *);
	int (*get)(char *, const struct kernel_param___109 *);
	void (*free)(void *);
};

struct kparam_array___109;

struct kernel_param___109 {
	const char *name;
	struct module___112 *mod;
	const struct kernel_param_ops___109 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___109 *arr;
	};
};

struct kparam_array___109 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___109 *ops;
	void *elem;
};

struct module_attribute___109 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___109 *, struct module_kobject___109 *, char *);
	ssize_t (*store)(struct module_attribute___109 *, struct module_kobject___109 *, const char *, size_t);
	void (*setup)(struct module___112 *, const char *);
	int (*test)(struct module___112 *);
	void (*free)(struct module___112 *);
};

struct trace_event_class___73;

struct trace_event_call___73 {
	struct list_head list;
	struct trace_event_class___73 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___4 *prog_array;
	int (*perf_perm)(struct trace_event_call___73 *, struct perf_event___80 *);
};

struct perf_cpu_context___80;

struct pmu___80 {
	struct list_head entry;
	struct module___112 *module;
	struct device___122 *dev;
	const struct attribute_group___121 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___80 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___80 *);
	void (*pmu_disable)(struct pmu___80 *);
	int (*event_init)(struct perf_event___80 *);
	void (*event_mapped)(struct perf_event___80 *, struct mm_struct___130 *);
	void (*event_unmapped)(struct perf_event___80 *, struct mm_struct___130 *);
	int (*add)(struct perf_event___80 *, int);
	void (*del)(struct perf_event___80 *, int);
	void (*start)(struct perf_event___80 *, int);
	void (*stop)(struct perf_event___80 *, int);
	void (*read)(struct perf_event___80 *);
	void (*start_txn)(struct pmu___80 *, unsigned int);
	int (*commit_txn)(struct pmu___80 *);
	void (*cancel_txn)(struct pmu___80 *);
	int (*event_idx)(struct perf_event___80 *);
	void (*sched_task)(struct perf_event_context___80 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___80 *);
	int (*filter_match)(struct perf_event___80 *);
	int (*check_period)(struct perf_event___80 *, u64);
};

struct perf_cpu_context___80 {
	struct perf_event_context___80 ctx;
	struct perf_event_context___80 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___80 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___80 {
	struct cgroup_subsys_state___107 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___73 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___73 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___73 *);
	struct list_head * (*get_fields)(struct trace_event_call___73 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___73 *);
};

struct pagevec___2 {
	unsigned char nr;
	bool percpu_pvec_drained;
	struct page___131 *pages[15];
};

struct dirty_throttle_control {
	struct wb_domain *dom;
	struct dirty_throttle_control *gdtc;
	struct bdi_writeback___52 *wb;
	struct fprop_local_percpu *wb_completions;
	long unsigned int avail;
	long unsigned int dirty;
	long unsigned int thresh;
	long unsigned int bg_thresh;
	long unsigned int wb_dirty;
	long unsigned int wb_thresh;
	long unsigned int wb_bg_thresh;
	long unsigned int pos_ratio;
};

struct module___113;

struct file___132;

struct kiocb___132;

struct iov_iter___58;

struct poll_table_struct___90;

struct vm_area_struct___132;

struct inode___133;

struct file_lock___132;

struct page___132;

struct seq_file___122;

struct file_operations___132 {
	struct module___113 *owner;
	loff_t (*llseek)(struct file___132 *, loff_t, int);
	ssize_t (*read)(struct file___132 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___132 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___132 *, struct iov_iter___58 *);
	ssize_t (*write_iter)(struct kiocb___132 *, struct iov_iter___58 *);
	int (*iopoll)(struct kiocb___132 *, bool);
	int (*iterate)(struct file___132 *, struct dir_context *);
	int (*iterate_shared)(struct file___132 *, struct dir_context *);
	__poll_t (*poll)(struct file___132 *, struct poll_table_struct___90 *);
	long int (*unlocked_ioctl)(struct file___132 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___132 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___132 *, struct vm_area_struct___132 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___133 *, struct file___132 *);
	int (*flush)(struct file___132 *, fl_owner_t);
	int (*release)(struct inode___133 *, struct file___132 *);
	int (*fsync)(struct file___132 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___132 *, int);
	int (*lock)(struct file___132 *, int, struct file_lock___132 *);
	ssize_t (*sendpage)(struct file___132 *, struct page___132 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___132 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___132 *, int, struct file_lock___132 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___132 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___132 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___132 *, long int, struct file_lock___132 **, void **);
	long int (*fallocate)(struct file___132 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___122 *, struct file___132 *);
	ssize_t (*copy_file_range)(struct file___132 *, loff_t, struct file___132 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___132 *, loff_t, struct file___132 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___132 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___131 {
	u64 seqnum;
	struct vm_area_struct___132 *vmas[4];
};

struct page_frag___131 {
	struct page___132 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___81;

struct debug_info___81 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___81 *hbp_break[16];
	struct perf_event___81 *hbp_watch[16];
};

struct thread_struct___81 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___81 debug;
	long: 64;
};

struct mm_struct___131;

struct mem_cgroup___48;

struct pid___107;

struct cred___127;

struct nsproxy___124;

struct signal_struct___120;

struct bio_list___53;

struct backing_dev_info___53;

struct io_context___24;

struct css_set___108;

struct perf_event_context___81;

struct request_queue___24;

struct vm_struct___100;

struct task_struct___132 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___132 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___131 *mm;
	struct mm_struct___131 *active_mm;
	struct vmacache___131 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___132 *real_parent;
	struct task_struct___132 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___132 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___48 *active_memcg;
	long int rh_reserved2;
	struct pid___107 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___107 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___107 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___127 *ptracer_cred;
	const struct cred___127 *real_cred;
	const struct cred___127 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___124 *nsproxy;
	struct signal_struct___120 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___132 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___53 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___53 *backing_dev_info;
	struct io_context___24 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___108 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___81 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___131 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___48 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___24 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___132 *oom_reaper_list;
	struct vm_struct___100 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___81 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___81 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___132 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___81)(struct perf_event___81 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___81;

struct fasync_struct___131;

struct pid_namespace___107;

struct trace_event_call___74;

struct perf_cgroup___81;

struct perf_event___81 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___81 *group_leader;
	struct pmu___81 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___81 hw;
	struct perf_event_context___81 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___81 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___132 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___131 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___81 *);
	struct callback_head callback_head;
	struct pid_namespace___107 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___81 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___81 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___74 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___81 *cgrp;
	struct list_head sb_list;
};

typedef struct page___132 *pgtable_t___131;

struct address_space___131;

struct dev_pagemap___129;

struct page___132 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___131 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___132 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___131 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___131 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___129 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___48 *mem_cgroup;
};

struct pglist_data___131;

struct lruvec___131 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___131 *pgdat;
};

struct zone___131 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___131 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___131 {
	struct zone___131 *zone;
	int zone_idx;
};

struct zonelist___131 {
	struct zoneref___131 _zonerefs[25];
};

struct pglist_data___131 {
	struct zone___131 node_zones[3];
	struct zonelist___131 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___132 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___132 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___131 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

typedef struct pglist_data___131 pg_data_t___4;

struct rw_semaphore___132 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___132 *owner;
};

struct secondary_data___132 {
	void *stack;
	struct task_struct___132 *task;
	long int status;
};

struct blocking_notifier_head___131 {
	struct rw_semaphore___132 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___129;

struct vm_area_struct___132 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___132 *vm_next;
	struct vm_area_struct___132 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___131 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___129 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___132 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___131;

struct user_namespace___112;

struct mm_struct___131 {
	struct {
		struct vm_area_struct___132 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___132 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___132 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___131 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___132 *owner;
		struct user_namespace___112 *user_ns;
		struct file___132 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___131 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___131;

struct address_space___131 {
	struct inode___133 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___132 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___131 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___129)(struct vm_area_struct___132 *, long unsigned int, const struct page___132 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___129)(struct page___132 *, void *);

struct device___123;

struct dev_pagemap___129 {
	dev_page_fault_t___129 page_fault;
	dev_page_free_t___129 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___123 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct cgroup___108;

struct cgroup_subsys___108;

struct cgroup_subsys_state___108 {
	struct cgroup___108 *cgroup;
	struct cgroup_subsys___108 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___108 *parent;
};

struct kernfs_node___128;

struct cgroup_file___108 {
	struct kernfs_node___128 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___48;

struct mem_cgroup___48 {
	struct cgroup_subsys_state___108 css;
	struct mem_cgroup_id___6 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___108 events_file;
	struct cgroup_file___108 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___132 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___48 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry___132;

struct path___131 {
	struct vfsmount *mnt;
	struct dentry___132 *dentry;
};

struct fown_struct___107 {
	rwlock_t lock;
	struct pid___107 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___132 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___131 f_path;
	struct inode___133 *f_inode;
	const struct file_operations___132 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___107 f_owner;
	const struct cred___127 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___131 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___129;

struct vm_operations_struct___129 {
	void (*open)(struct vm_area_struct___132 *);
	void (*close)(struct vm_area_struct___132 *);
	int (*split)(struct vm_area_struct___132 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___132 *);
	vm_fault_t (*fault)(struct vm_fault___129 *);
	vm_fault_t (*huge_fault)(struct vm_fault___129 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___129 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___132 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___129 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___129 *);
	int (*access)(struct vm_area_struct___132 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___132 *);
	int (*set_policy)(struct vm_area_struct___132 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___132 *, long unsigned int);
	struct page___132 * (*find_special_page)(struct vm_area_struct___132 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___131 {
	struct task_struct___132 *task;
	struct core_thread___131 *next;
};

struct core_state___131 {
	atomic_t nr_threads;
	struct core_thread___131 dumper;
	struct completion startup;
};

struct key___127;

struct ucounts___112;

struct user_namespace___112 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___112 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___4 ns;
	long unsigned int flags;
	struct key___127 *persistent_keyring_register;
	struct rw_semaphore___132 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___112 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___129 {
	struct vm_area_struct___132 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___132 *cow_page;
	struct mem_cgroup___48 *memcg;
	struct page___132 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___131 prealloc_pte;
};

struct shrink_control___48 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___48 *memcg;
};

struct shrinker___48 {
	long unsigned int (*count_objects)(struct shrinker___48 *, struct shrink_control___48 *);
	long unsigned int (*scan_objects)(struct shrinker___48 *, struct shrink_control___48 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct upid___107 {
	int nr;
	struct pid_namespace___107 *ns;
};

struct pid_namespace___107 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___132 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___107 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___132 *proc_self;
	struct dentry___132 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___112 *user_ns;
	struct ucounts___112 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___4 ns;
};

struct pid___107 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___107 numbers[1];
};

struct user_struct___127 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___127 *uid_keyring;
	struct key___127 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___127 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___127 *session_keyring;
	struct key___127 *process_keyring;
	struct key___127 *thread_keyring;
	struct key___127 *request_key_auth;
	void *security;
	struct user_struct___127 *user;
	struct user_namespace___112 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___108;

struct nsproxy___124 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___107 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___108 *cgroup_ns;
};

struct signal_struct___120 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___132 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___132 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___107 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___107 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___131 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___107 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide49;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___53;

struct bio_list___53 {
	struct bio___53 *head;
	struct bio___53 *tail;
};

struct bdi_writeback_congested___53;

struct bdi_writeback___53 {
	struct backing_dev_info___53 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___53 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___108 *memcg_css;
	struct cgroup_subsys_state___108 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___53 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___53 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___123 *dev;
	struct device___123 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___132 *debug_dir;
	struct dentry___132 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___24;

struct io_context___24 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___24 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___108 {
	struct cgroup_subsys_state___108 *subsys[13];
	refcount_t refcount;
	struct css_set___108 *dom_cset;
	struct cgroup___108 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___108 *mg_src_cgrp;
	struct cgroup___108 *mg_dst_cgrp;
	struct css_set___108 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___81 {
	struct pmu___81 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___132 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___81 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

typedef blk_qc_t make_request_fn___23(struct request_queue___24 *, struct bio___53 *);

struct request___24;

typedef int dma_drain_needed_fn___23(struct request___24 *);

struct kset___125;

struct kobj_type___125;

struct kobject___126 {
	const char *name;
	struct list_head entry;
	struct kobject___126 *parent;
	struct kset___125 *kset;
	struct kobj_type___125 *ktype;
	struct kernfs_node___128 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___23;

struct bsg_class_device___23 {
	struct device___123 *class_dev;
	int minor;
	struct request_queue___24 *queue;
	const struct bsg_ops___23 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___53 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___53 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___23;

struct blkcg_gq___15;

struct request_queue___24 {
	struct list_head queue_head;
	struct request___24 *last_merge;
	struct elevator_queue___23 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___23 *make_request_fn;
	dma_drain_needed_fn___23 *dma_drain_needed;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___53 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___126 kobj;
	struct kobject___126 *mq_kobj;
	struct blk_integrity integrity;
	struct device___123 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___15 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	struct bsg_class_device___23 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___53 bio_split;
	struct dentry___132 *debugfs_dir;
	struct dentry___132 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___100 {
	struct vm_struct___100 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___132 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___120 {
	struct task_struct___132 task;
	long unsigned int stack[8192];
};

struct dev_pm_info___123 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___123 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___123;

struct bus_type___123;

struct device_driver___123;

struct dev_pm_domain___123;

struct fwnode_handle___92;

struct class___123;

struct attribute_group___122;

struct device___123 {
	struct device___123 *parent;
	struct device_private *p;
	struct kobject___126 kobj;
	const char *init_name;
	const struct device_type___123 *type;
	struct mutex mutex;
	struct bus_type___123 *bus;
	struct device_driver___123 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___123 power;
	struct dev_pm_domain___123 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___92 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___123 *class;
	const struct attribute_group___122 **groups;
	void (*release)(struct device___123 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___131;

struct super_block___132;

struct dentry___132 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___132 *d_parent;
	struct qstr d_name;
	struct inode___133 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___131 *d_op;
	struct super_block___132 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___131;

struct block_device___132;

struct inode___133 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___131 *i_op;
	struct super_block___132 *i_sb;
	struct address_space___131 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___132 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___53 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___132 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___131 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___132 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___131 {
	int (*d_revalidate)(struct dentry___132 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___132 *, unsigned int);
	int (*d_hash)(const struct dentry___132 *, struct qstr *);
	int (*d_compare)(const struct dentry___132 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___132 *);
	int (*d_init)(struct dentry___132 *);
	void (*d_release)(struct dentry___132 *);
	void (*d_prune)(struct dentry___132 *);
	void (*d_iput)(struct dentry___132 *, struct inode___133 *);
	char * (*d_dname)(struct dentry___132 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___131 *);
	int (*d_manage)(const struct path___131 *, bool);
	struct dentry___132 * (*d_real)(struct dentry___132 *, const struct inode___133 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___131;

struct mem_dqinfo___131 {
	struct quota_format_type___131 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___131;

struct quota_info___131 {
	unsigned int flags;
	struct rw_semaphore___132 dqio_sem;
	struct inode___133 *files[3];
	struct mem_dqinfo___131 info[3];
	const struct quota_format_ops___131 *ops[3];
};

struct rcuwait___131 {
	struct task_struct___132 *task;
};

struct percpu_rw_semaphore___131 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___132 rw_sem;
	struct rcuwait___131 writer;
	int readers_block;
};

struct sb_writers___131 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___131 rw_sem[3];
};

struct file_system_type___131;

struct super_operations___131;

struct dquot_operations___131;

struct quotactl_ops___131;

struct super_block___132 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___131 *s_type;
	const struct super_operations___131 *s_op;
	const struct dquot_operations___131 *dq_op;
	const struct quotactl_ops___131 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___132 *s_root;
	struct rw_semaphore___132 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___132 *s_bdev;
	struct backing_dev_info___53 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___131 s_dquot;
	struct sb_writers___131 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___131 *s_d_op;
	int cleancache_poolid;
	struct shrinker___48 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___112 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct io_cq___24 {
	struct request_queue___24 *q;
	struct io_context___24 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___2 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___132 {
	struct file___132 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___132 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___132 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___132 *ia_file;
};

struct dquot___131 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___132 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___131 {
	int qf_fmt_id;
	const struct quota_format_ops___131 *qf_ops;
	struct module___113 *qf_owner;
	struct quota_format_type___131 *qf_next;
};

struct quota_format_ops___131 {
	int (*check_quota_file)(struct super_block___132 *, int);
	int (*read_file_info)(struct super_block___132 *, int);
	int (*write_file_info)(struct super_block___132 *, int);
	int (*free_file_info)(struct super_block___132 *, int);
	int (*read_dqblk)(struct dquot___131 *);
	int (*commit_dqblk)(struct dquot___131 *);
	int (*release_dqblk)(struct dquot___131 *);
	int (*get_next_id)(struct super_block___132 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___131 {
	int (*write_dquot)(struct dquot___131 *);
	struct dquot___131 * (*alloc_dquot)(struct super_block___132 *, int);
	void (*destroy_dquot)(struct dquot___131 *);
	int (*acquire_dquot)(struct dquot___131 *);
	int (*release_dquot)(struct dquot___131 *);
	int (*mark_dirty)(struct dquot___131 *);
	int (*write_info)(struct super_block___132 *, int);
	qsize_t * (*get_reserved_space)(struct inode___133 *);
	int (*get_projid)(struct inode___133 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___133 *, qsize_t *);
	int (*get_next_id)(struct super_block___132 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___131 {
	int (*quota_on)(struct super_block___132 *, int, int, const struct path___131 *);
	int (*quota_off)(struct super_block___132 *, int);
	int (*quota_enable)(struct super_block___132 *, unsigned int);
	int (*quota_disable)(struct super_block___132 *, unsigned int);
	int (*quota_sync)(struct super_block___132 *, int);
	int (*set_info)(struct super_block___132 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___132 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___132 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___132 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___132 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___132 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___110 {
	struct kobject___126 kobj;
	struct module___113 *mod;
	struct kobject___126 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___110 {
	struct module___113 *mod;
	struct latch_tree_node node;
};

struct module_layout___110 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___110 mtn;
};

struct module_attribute___110;

struct kernel_param___110;

struct module___113 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___110 mkobj;
	struct module_attribute___110 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___126 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___110 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___110 core_layout;
	struct module_layout___110 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___74 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide47;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide48;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___50;

struct swap_info_struct___34;

struct address_space_operations___131 {
	int (*writepage)(struct page___132 *, struct writeback_control___50 *);
	int (*readpage)(struct file___132 *, struct page___132 *);
	int (*writepages)(struct address_space___131 *, struct writeback_control___50 *);
	int (*set_page_dirty)(struct page___132 *);
	int (*readpages)(struct file___132 *, struct address_space___131 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___132 *, struct address_space___131 *, loff_t, unsigned int, unsigned int, struct page___132 **, void **);
	int (*write_end)(struct file___132 *, struct address_space___131 *, loff_t, unsigned int, unsigned int, struct page___132 *, void *);
	sector_t (*bmap)(struct address_space___131 *, sector_t);
	void (*invalidatepage)(struct page___132 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___132 *, gfp_t);
	void (*freepage)(struct page___132 *);
	ssize_t (*direct_IO)(struct kiocb___132 *, struct iov_iter___58 *);
	int (*migratepage)(struct address_space___131 *, struct page___132 *, struct page___132 *, enum migrate_mode);
	bool (*isolate_page)(struct page___132 *, isolate_mode_t);
	void (*putback_page)(struct page___132 *);
	int (*launder_page)(struct page___132 *);
	int (*is_partially_uptodate)(struct page___132 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___132 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___131 *, struct page___132 *);
	int (*swap_activate)(struct swap_info_struct___34 *, struct file___132 *, sector_t *);
	void (*swap_deactivate)(struct file___132 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___50 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___53 *wb;
	struct inode___133 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___53;

struct iov_iter___58 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___53 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct swap_info_struct___34 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___132 *bdev;
	struct file___132 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct hd_struct___24;

struct gendisk___24;

struct block_device___132 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___133 *bd_inode;
	struct super_block___132 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___132 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___24 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___24 *bd_disk;
	struct request_queue___24 *bd_queue;
	struct backing_dev_info___53 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct hd_struct___24 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___123 __dev;
	struct kobject___126 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___24;

struct block_device_operations___24;

struct gendisk___24 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___24 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___24 *part_tbl;
	struct hd_struct___24 part0;
	const struct block_device_operations___24 *fops;
	struct request_queue___24 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___132 lookup_sem;
	struct kobject___126 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___126 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___131 {
	struct dentry___132 * (*lookup)(struct inode___133 *, struct dentry___132 *, unsigned int);
	const char * (*get_link)(struct dentry___132 *, struct inode___133 *, struct delayed_call *);
	int (*permission)(struct inode___133 *, int);
	struct posix_acl * (*get_acl)(struct inode___133 *, int);
	int (*readlink)(struct dentry___132 *, char *, int);
	int (*create)(struct inode___133 *, struct dentry___132 *, umode_t, bool);
	int (*link)(struct dentry___132 *, struct inode___133 *, struct dentry___132 *);
	int (*unlink)(struct inode___133 *, struct dentry___132 *);
	int (*symlink)(struct inode___133 *, struct dentry___132 *, const char *);
	int (*mkdir)(struct inode___133 *, struct dentry___132 *, umode_t);
	int (*rmdir)(struct inode___133 *, struct dentry___132 *);
	int (*mknod)(struct inode___133 *, struct dentry___132 *, umode_t, dev_t);
	int (*rename)(struct inode___133 *, struct dentry___132 *, struct inode___133 *, struct dentry___132 *, unsigned int);
	int (*setattr)(struct dentry___132 *, struct iattr___132 *);
	int (*getattr)(const struct path___131 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___132 *, char *, size_t);
	int (*fiemap)(struct inode___133 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___133 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___133 *, struct dentry___132 *, struct file___132 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___133 *, struct dentry___132 *, umode_t);
	int (*set_acl)(struct inode___133 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___131 {
	void (*fl_copy_lock)(struct file_lock___132 *, struct file_lock___132 *);
	void (*fl_release_private)(struct file_lock___132 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___131;

struct file_lock___132 {
	struct file_lock___132 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___132 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___131 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___131 *fl_ops;
	const struct lock_manager_operations___131 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___131 {
	int (*lm_compare_owner)(struct file_lock___132 *, struct file_lock___132 *);
	long unsigned int (*lm_owner_key)(struct file_lock___132 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___132 *);
	int (*lm_grant)(struct file_lock___132 *, int);
	bool (*lm_break)(struct file_lock___132 *);
	int (*lm_change)(struct file_lock___132 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___132 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___131 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___131 *fa_next;
	struct file___132 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___131 {
	const char *name;
	int fs_flags;
	struct dentry___132 * (*mount)(struct file_system_type___131 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___132 *);
	struct module___113 *owner;
	struct file_system_type___131 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___131 {
	struct inode___133 * (*alloc_inode)(struct super_block___132 *);
	void (*destroy_inode)(struct inode___133 *);
	void (*dirty_inode)(struct inode___133 *, int);
	int (*write_inode)(struct inode___133 *, struct writeback_control___50 *);
	int (*drop_inode)(struct inode___133 *);
	void (*evict_inode)(struct inode___133 *);
	void (*put_super)(struct super_block___132 *);
	int (*sync_fs)(struct super_block___132 *, int);
	int (*freeze_super)(struct super_block___132 *);
	int (*freeze_fs)(struct super_block___132 *);
	int (*thaw_super)(struct super_block___132 *);
	int (*unfreeze_fs)(struct super_block___132 *);
	int (*statfs)(struct dentry___132 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___132 *, int *, char *);
	void (*umount_begin)(struct super_block___132 *);
	int (*show_options)(struct seq_file___122 *, struct dentry___132 *);
	int (*show_devname)(struct seq_file___122 *, struct dentry___132 *);
	int (*show_path)(struct seq_file___122 *, struct dentry___132 *);
	int (*show_stats)(struct seq_file___122 *, struct dentry___132 *);
	ssize_t (*quota_read)(struct super_block___132 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___132 *, int, const char *, size_t, loff_t);
	struct dquot___131 ** (*get_dquots)(struct inode___133 *);
	int (*bdev_try_to_free_page)(struct super_block___132 *, struct page___132 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___132 *, struct shrink_control___48 *);
	long int (*free_cached_objects)(struct super_block___132 *, struct shrink_control___48 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___89)(struct file___132 *, wait_queue_head_t *, struct poll_table_struct___90 *);

struct poll_table_struct___90 {
	poll_queue_proc___89 _qproc;
	__poll_t _key;
};

struct seq_operations___120;

struct seq_file___122 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___120 *op;
	int poll_event;
	const struct file___132 *file;
	void *private;
};

typedef void bio_end_io_t___53(struct bio___53 *);

struct bio_vec___53 {
	struct page___132 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___53;

struct bio___53 {
	struct bio___53 *bi_next;
	struct gendisk___24 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___53 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___15 *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___53 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___53 *bi_io_vec;
	struct bio_set___53 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___53 bi_inline_vecs[0];
};

struct kobj_attribute___126 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___126 *, struct kobj_attribute___126 *, char *);
	ssize_t (*store)(struct kobject___126 *, struct kobj_attribute___126 *, const char *, size_t);
};

typedef void compound_page_dtor___129(struct page___132 *);

typedef int (*key_restrict_link_func_t___127)(struct key___127 *, const struct key_type *, const union key_payload *, struct key___127 *);

struct key_restriction___127;

struct key___127 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___132 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___127 *restrict_link;
};

struct key_restriction___127 {
	key_restrict_link_func_t___127 check;
	struct key___127 *key;
	struct key_type *keytype;
};

struct seq_operations___120 {
	void * (*start)(struct seq_file___122 *, loff_t *);
	void (*stop)(struct seq_file___122 *, void *);
	void * (*next)(struct seq_file___122 *, void *, loff_t *);
	int (*show)(struct seq_file___122 *, void *);
};

struct kernfs_root___128;

struct kernfs_elem_dir___128 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___128 *root;
};

struct kernfs_syscall_ops___128;

struct kernfs_root___128 {
	struct kernfs_node___128 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___128 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___128 {
	struct kernfs_node___128 *target_kn;
};

struct kernfs_ops___128;

struct kernfs_elem_attr___128 {
	const struct kernfs_ops___128 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___128 *notify_next;
};

struct kernfs_node___128 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___128 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___128 dir;
		struct kernfs_elem_symlink___128 symlink;
		struct kernfs_elem_attr___128 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___128;

struct kernfs_ops___128 {
	int (*open)(struct kernfs_open_file___128 *);
	void (*release)(struct kernfs_open_file___128 *);
	int (*seq_show)(struct seq_file___122 *, void *);
	void * (*seq_start)(struct seq_file___122 *, loff_t *);
	void * (*seq_next)(struct seq_file___122 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___122 *, void *);
	ssize_t (*read)(struct kernfs_open_file___128 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___128 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___128 *, struct vm_area_struct___132 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___128 *, struct poll_table_struct___90 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___128 {
	int (*remount_fs)(struct kernfs_root___128 *, int *, char *);
	int (*show_options)(struct seq_file___122 *, struct kernfs_root___128 *);
	int (*mkdir)(struct kernfs_node___128 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___128 *);
	int (*rename)(struct kernfs_node___128 *, struct kernfs_node___128 *, const char *);
	int (*show_path)(struct seq_file___122 *, struct kernfs_node___128 *, struct kernfs_root___128 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___128 {
	struct kernfs_node___128 *kn;
	struct file___132 *file;
	struct seq_file___122 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___129 *vm_ops;
};

struct cgroup_namespace___108 {
	refcount_t count;
	struct ns_common___4 ns;
	struct user_namespace___112 *user_ns;
	struct ucounts___112 *ucounts;
	struct css_set___108 *root_cset;
};

struct ucounts___112 {
	struct hlist_node node;
	struct user_namespace___112 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___108;

struct bpf_map_ops___108 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___108 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___108 *, struct file___132 *);
	void (*map_free)(struct bpf_map___108 *);
	int (*map_get_next_key)(struct bpf_map___108 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___108 *);
	void * (*map_lookup_elem)(struct bpf_map___108 *, void *);
	int (*map_update_elem)(struct bpf_map___108 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___108 *, void *);
	int (*map_push_elem)(struct bpf_map___108 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___108 *, void *);
	int (*map_peek_elem)(struct bpf_map___108 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___108 *, struct file___132 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___108 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___108 *, void *, struct seq_file___122 *);
	int (*map_check_btf)(const struct bpf_map___108 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___108 {
	const struct bpf_map_ops___108 *ops;
	struct bpf_map___108 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___127 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___108;

typedef void (*kthread_work_func_t___108)(struct kthread_work___108 *);

struct kthread_worker___108;

struct kthread_work___108 {
	struct list_head node;
	kthread_work_func_t___108 func;
	struct kthread_worker___108 *worker;
	int canceling;
};

struct kthread_worker___108 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___132 *task;
	struct kthread_work___108 *current_work;
};

struct kthread_delayed_work___108 {
	struct kthread_work___108 work;
	struct timer_list timer;
};

struct psi_group___108 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___108 *poll_kworker;
	struct kthread_delayed_work___108 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___108;

struct cgroup_rstat_cpu___108;

struct cgroup___108 {
	struct cgroup_subsys_state___108 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___128 *kn;
	struct cgroup_file___108 procs_file;
	struct cgroup_file___108 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___108 *subsys[13];
	struct cgroup_root___108 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___108 *dom_cgrp;
	struct cgroup_rstat_cpu___108 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___4 bpf;
	atomic_t congestion_count;
	struct cgroup___108 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___108 psi;
	int ancestor_ids[0];
};

struct cftype___108;

struct cgroup_subsys___108 {
	struct cgroup_subsys_state___108 * (*css_alloc)(struct cgroup_subsys_state___108 *);
	int (*css_online)(struct cgroup_subsys_state___108 *);
	void (*css_offline)(struct cgroup_subsys_state___108 *);
	void (*css_released)(struct cgroup_subsys_state___108 *);
	void (*css_free)(struct cgroup_subsys_state___108 *);
	void (*css_reset)(struct cgroup_subsys_state___108 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___108 *, int);
	int (*css_extra_stat_show)(struct seq_file___122 *, struct cgroup_subsys_state___108 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___132 *);
	void (*cancel_fork)(struct task_struct___132 *);
	void (*fork)(struct task_struct___132 *);
	void (*exit)(struct task_struct___132 *);
	void (*free)(struct task_struct___132 *);
	void (*bind)(struct cgroup_subsys_state___108 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___108 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___108 *dfl_cftypes;
	struct cftype___108 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___108 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___108 *updated_children;
	struct cgroup___108 *updated_next;
};

struct cgroup_root___108 {
	struct kernfs_root___128 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___108 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___108 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___108 *ss;
	struct list_head node;
	struct kernfs_ops___128 *kf_ops;
	int (*open)(struct kernfs_open_file___128 *);
	void (*release)(struct kernfs_open_file___128 *);
	u64 (*read_u64)(struct cgroup_subsys_state___108 *, struct cftype___108 *);
	s64 (*read_s64)(struct cgroup_subsys_state___108 *, struct cftype___108 *);
	int (*seq_show)(struct seq_file___122 *, void *);
	void * (*seq_start)(struct seq_file___122 *, loff_t *);
	void * (*seq_next)(struct seq_file___122 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___122 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___108 *, struct cftype___108 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___108 *, struct cftype___108 *, s64);
	ssize_t (*write)(struct kernfs_open_file___128 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___128 *, struct poll_table_struct___90 *);
};

struct bdi_writeback_congested___53 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___53 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___53 {
	struct bio___53 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___53 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___53 bip_inline_vecs[0];
};

struct blkcg___15;

struct blkg_policy_data___15;

struct blkcg_gq___15 {
	struct request_queue___24 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___15 *blkcg;
	struct bdi_writeback_congested___53 *wb_congested;
	struct blkcg_gq___15 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_rwstat stat_bytes;
	struct blkg_rwstat stat_ios;
	struct blkg_policy_data___15 *pd[5];
	struct callback_head callback_head;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
};

struct mem_cgroup_reclaim_iter___48 {
	struct mem_cgroup___48 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___48 {
	struct lruvec___131 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___48 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___48 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct bin_attribute___122;

struct attribute_group___122 {
	const char *name;
	umode_t (*is_visible)(struct kobject___126 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___126 *, struct bin_attribute___122 *, int);
	struct attribute **attrs;
	struct bin_attribute___122 **bin_attrs;
};

struct bin_attribute___122 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___132 *, struct kobject___126 *, struct bin_attribute___122 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___132 *, struct kobject___126 *, struct bin_attribute___122 *, char *, loff_t, size_t);
	int (*mmap)(struct file___132 *, struct kobject___126 *, struct bin_attribute___122 *, struct vm_area_struct___132 *);
};

struct sysfs_ops___125 {
	ssize_t (*show)(struct kobject___126 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___126 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___125;

struct kset___125 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___126 kobj;
	const struct kset_uevent_ops___125 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___125 {
	void (*release)(struct kobject___126 *);
	const struct sysfs_ops___125 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___2 * (*child_ns_type)(struct kobject___126 *);
	const void * (*namespace)(struct kobject___126 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___125 {
	int (* const filter)(struct kset___125 *, struct kobject___126 *);
	const char * (* const name)(struct kset___125 *, struct kobject___126 *);
	int (* const uevent)(struct kset___125 *, struct kobject___126 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___123 {
	int (*prepare)(struct device___123 *);
	void (*complete)(struct device___123 *);
	int (*suspend)(struct device___123 *);
	int (*resume)(struct device___123 *);
	int (*freeze)(struct device___123 *);
	int (*thaw)(struct device___123 *);
	int (*poweroff)(struct device___123 *);
	int (*restore)(struct device___123 *);
	int (*suspend_late)(struct device___123 *);
	int (*resume_early)(struct device___123 *);
	int (*freeze_late)(struct device___123 *);
	int (*thaw_early)(struct device___123 *);
	int (*poweroff_late)(struct device___123 *);
	int (*restore_early)(struct device___123 *);
	int (*suspend_noirq)(struct device___123 *);
	int (*resume_noirq)(struct device___123 *);
	int (*freeze_noirq)(struct device___123 *);
	int (*thaw_noirq)(struct device___123 *);
	int (*poweroff_noirq)(struct device___123 *);
	int (*restore_noirq)(struct device___123 *);
	int (*runtime_suspend)(struct device___123 *);
	int (*runtime_resume)(struct device___123 *);
	int (*runtime_idle)(struct device___123 *);
};

struct dev_pm_domain___123 {
	struct dev_pm_ops___123 ops;
	void (*detach)(struct device___123 *, bool);
	int (*activate)(struct device___123 *);
	void (*sync)(struct device___123 *);
	void (*dismiss)(struct device___123 *);
};

struct bus_type___123 {
	const char *name;
	const char *dev_name;
	struct device___123 *dev_root;
	const struct attribute_group___122 **bus_groups;
	const struct attribute_group___122 **dev_groups;
	const struct attribute_group___122 **drv_groups;
	int (*match)(struct device___123 *, struct device_driver___123 *);
	int (*uevent)(struct device___123 *, struct kobj_uevent_env *);
	int (*probe)(struct device___123 *);
	int (*remove)(struct device___123 *);
	void (*shutdown)(struct device___123 *);
	int (*online)(struct device___123 *);
	int (*offline)(struct device___123 *);
	int (*suspend)(struct device___123 *, pm_message_t);
	int (*resume)(struct device___123 *);
	int (*num_vf)(struct device___123 *);
	int (*dma_configure)(struct device___123 *);
	const struct dev_pm_ops___123 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___123 {
	const char *name;
	struct bus_type___123 *bus;
	struct module___113 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___123 *);
	int (*remove)(struct device___123 *);
	void (*shutdown)(struct device___123 *);
	int (*suspend)(struct device___123 *, pm_message_t);
	int (*resume)(struct device___123 *);
	const struct attribute_group___122 **groups;
	const struct dev_pm_ops___123 *pm;
	void (*coredump)(struct device___123 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___123 {
	const char *name;
	const struct attribute_group___122 **groups;
	int (*uevent)(struct device___123 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___123 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___123 *);
	const struct dev_pm_ops___123 *pm;
};

struct class___123 {
	const char *name;
	struct module___113 *owner;
	const struct attribute_group___122 **class_groups;
	const struct attribute_group___122 **dev_groups;
	struct kobject___126 *dev_kobj;
	int (*dev_uevent)(struct device___123 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___123 *, umode_t *);
	void (*class_release)(struct class___123 *);
	void (*dev_release)(struct device___123 *);
	int (*shutdown_pre)(struct device___123 *);
	const struct kobj_ns_type_operations___2 *ns_type;
	const void * (*namespace)(struct device___123 *);
	const struct dev_pm_ops___123 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct fwnode_operations___92;

struct fwnode_handle___92 {
	struct fwnode_handle___92 *secondary;
	const struct fwnode_operations___92 *ops;
};

struct node___102 {
	struct device___123 dev;
};

struct pagevec___3 {
	unsigned char nr;
	bool percpu_pvec_drained;
	struct page___132 *pages[15];
};

struct disk_part_tbl___24 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___24 *last_lookup;
	struct hd_struct___24 *part[0];
};

struct block_device_operations___24 {
	int (*open)(struct block_device___132 *, fmode_t);
	void (*release)(struct gendisk___24 *, fmode_t);
	int (*rw_page)(struct block_device___132 *, sector_t, struct page___132 *, unsigned int);
	int (*ioctl)(struct block_device___132 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___132 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___24 *, unsigned int);
	int (*media_changed)(struct gendisk___24 *);
	void (*unlock_native_capacity)(struct gendisk___24 *);
	int (*revalidate_disk)(struct gendisk___24 *);
	int (*getgeo)(struct block_device___132 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___132 *, long unsigned int);
	int (*report_zones)(struct gendisk___24 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___113 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___23 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___24 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___24 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___24 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___23(struct request___24 *, blk_status_t);

struct request___24 {
	struct request_queue___24 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___53 *bio;
	struct bio___53 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___53 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___24 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___23 *saved_end_io;
		} flush;
	};
	struct gendisk___24 *rq_disk;
	struct hd_struct___24 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___23 *end_io;
	void *end_io_data;
	struct request___24 *next_rq;
};

struct fwnode_reference_args___92;

struct fwnode_endpoint___92;

struct fwnode_operations___92 {
	struct fwnode_handle___92 * (*get)(struct fwnode_handle___92 *);
	void (*put)(struct fwnode_handle___92 *);
	bool (*device_is_available)(const struct fwnode_handle___92 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___92 *, const struct device___123 *);
	bool (*property_present)(const struct fwnode_handle___92 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___92 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___92 *, const char *, const char **, size_t);
	struct fwnode_handle___92 * (*get_parent)(const struct fwnode_handle___92 *);
	struct fwnode_handle___92 * (*get_next_child_node)(const struct fwnode_handle___92 *, struct fwnode_handle___92 *);
	struct fwnode_handle___92 * (*get_named_child_node)(const struct fwnode_handle___92 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___92 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___92 *);
	struct fwnode_handle___92 * (*graph_get_next_endpoint)(const struct fwnode_handle___92 *, struct fwnode_handle___92 *);
	struct fwnode_handle___92 * (*graph_get_remote_endpoint)(const struct fwnode_handle___92 *);
	struct fwnode_handle___92 * (*graph_get_port_parent)(struct fwnode_handle___92 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___92 *, struct fwnode_endpoint___92 *);
};

struct fwnode_endpoint___92 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___92 *local_fwnode;
};

struct fwnode_reference_args___92 {
	struct fwnode_handle___92 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct elevator_type___23;

struct elevator_mq_ops___23 {
	int (*init_sched)(struct request_queue___24 *, struct elevator_type___23 *);
	void (*exit_sched)(struct elevator_queue___23 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	bool (*allow_merge)(struct request_queue___24 *, struct request___24 *, struct bio___53 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx *, struct bio___53 *);
	int (*request_merge)(struct request_queue___24 *, struct request___24 **, struct bio___53 *);
	void (*request_merged)(struct request_queue___24 *, struct request___24 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___24 *, struct request___24 *, struct request___24 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___24 *, struct bio___53 *);
	void (*finish_request)(struct request___24 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___24 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___24 *, u64);
	void (*started_request)(struct request___24 *);
	void (*requeue_request)(struct request___24 *);
	struct request___24 * (*former_request)(struct request_queue___24 *, struct request___24 *);
	struct request___24 * (*next_request)(struct request_queue___24 *, struct request___24 *);
	void (*init_icq)(struct io_cq___24 *);
	void (*exit_icq)(struct io_cq___24 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___23;

struct elevator_type___23 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___23 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___23 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___113 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___23 {
	struct elevator_type___23 *type;
	void *elevator_data;
	struct kobject___126 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___23 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___23 *, char *);
	ssize_t (*store)(struct elevator_queue___23 *, const char *, size_t);
};

struct blkcg_policy_data___15;

struct blkcg___15 {
	struct cgroup_subsys_state___108 css;
	spinlock_t lock;
	struct xarray blkg_tree;
	struct blkcg_gq___15 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___15 *cpd[5];
	struct list_head all_blkcgs_node;
	struct list_head cgwb_list;
	refcount_t cgwb_refcnt;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct blkcg_policy_data___15 {
	struct blkcg___15 *blkcg;
	int plid;
};

struct blkg_policy_data___15 {
	struct blkcg_gq___15 *blkg;
	int plid;
};

struct hstate___14 {
	int next_nid_to_alloc;
	int next_nid_to_free;
	unsigned int order;
	long unsigned int mask;
	long unsigned int max_huge_pages;
	long unsigned int nr_huge_pages;
	long unsigned int free_huge_pages;
	long unsigned int resv_huge_pages;
	long unsigned int surplus_huge_pages;
	long unsigned int nr_overcommit_huge_pages;
	struct list_head hugepage_activelist;
	struct list_head hugepage_freelists[8];
	unsigned int nr_huge_pages_node[8];
	unsigned int free_huge_pages_node[8];
	unsigned int surplus_huge_pages_node[8];
	struct cftype___108 cgroup_files[5];
	char name[32];
};

struct kernel_param_ops___110 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___110 *);
	int (*get)(char *, const struct kernel_param___110 *);
	void (*free)(void *);
};

struct kparam_array___110;

struct kernel_param___110 {
	const char *name;
	struct module___113 *mod;
	const struct kernel_param_ops___110 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___110 *arr;
	};
};

struct kparam_array___110 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___110 *ops;
	void *elem;
};

struct module_attribute___110 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___110 *, struct module_kobject___110 *, char *);
	ssize_t (*store)(struct module_attribute___110 *, struct module_kobject___110 *, const char *, size_t);
	void (*setup)(struct module___113 *, const char *);
	int (*test)(struct module___113 *);
	void (*free)(struct module___113 *);
};

struct trace_event_class___74;

struct trace_event_call___74 {
	struct list_head list;
	struct trace_event_class___74 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___4 *prog_array;
	int (*perf_perm)(struct trace_event_call___74 *, struct perf_event___81 *);
};

struct perf_cpu_context___81;

struct pmu___81 {
	struct list_head entry;
	struct module___113 *module;
	struct device___123 *dev;
	const struct attribute_group___122 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___81 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___81 *);
	void (*pmu_disable)(struct pmu___81 *);
	int (*event_init)(struct perf_event___81 *);
	void (*event_mapped)(struct perf_event___81 *, struct mm_struct___131 *);
	void (*event_unmapped)(struct perf_event___81 *, struct mm_struct___131 *);
	int (*add)(struct perf_event___81 *, int);
	void (*del)(struct perf_event___81 *, int);
	void (*start)(struct perf_event___81 *, int);
	void (*stop)(struct perf_event___81 *, int);
	void (*read)(struct perf_event___81 *);
	void (*start_txn)(struct pmu___81 *, unsigned int);
	int (*commit_txn)(struct pmu___81 *);
	void (*cancel_txn)(struct pmu___81 *);
	int (*event_idx)(struct perf_event___81 *);
	void (*sched_task)(struct perf_event_context___81 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___81 *);
	int (*filter_match)(struct perf_event___81 *);
	int (*check_period)(struct perf_event___81 *, u64);
};

struct perf_cpu_context___81 {
	struct perf_event_context___81 ctx;
	struct perf_event_context___81 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___81 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___81 {
	struct cgroup_subsys_state___108 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___74 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___74 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___74 *);
	struct list_head * (*get_fields)(struct trace_event_call___74 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___74 *);
};

struct trace_event_file___35;

struct trace_event_buffer___27 {
	struct ring_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___35 *trace_file;
	void *entry;
	long unsigned int flags;
	int pc;
};

struct trace_event_file___35 {
	struct list_head list;
	struct trace_event_call___74 *event_call;
	struct event_filter *filter;
	struct dentry___132 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_mm_lru_insertion {
	struct trace_entry ent;
	struct page___132 *page;
	long unsigned int pfn;
	int lru;
	long unsigned int flags;
	char __data[0];
};

struct trace_event_raw_mm_lru_activate {
	struct trace_entry ent;
	struct page___132 *page;
	long unsigned int pfn;
	char __data[0];
};

struct trace_event_data_offsets_mm_lru_insertion {};

struct trace_event_data_offsets_mm_lru_activate {};

struct file___133;

struct kiocb___133;

struct vm_area_struct___133;

struct inode___134;

struct file_lock___133;

struct page___133;

struct seq_file___123;

struct file_operations___133 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___133 *, loff_t, int);
	ssize_t (*read)(struct file___133 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___133 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___133 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___133 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___133 *, bool);
	int (*iterate)(struct file___133 *, struct dir_context *);
	int (*iterate_shared)(struct file___133 *, struct dir_context *);
	__poll_t (*poll)(struct file___133 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___133 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___133 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___133 *, struct vm_area_struct___133 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___134 *, struct file___133 *);
	int (*flush)(struct file___133 *, fl_owner_t);
	int (*release)(struct inode___134 *, struct file___133 *);
	int (*fsync)(struct file___133 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___133 *, int);
	int (*lock)(struct file___133 *, int, struct file_lock___133 *);
	ssize_t (*sendpage)(struct file___133 *, struct page___133 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___133 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___133 *, int, struct file_lock___133 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___133 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___133 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___133 *, long int, struct file_lock___133 **, void **);
	long int (*fallocate)(struct file___133 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___123 *, struct file___133 *);
	ssize_t (*copy_file_range)(struct file___133 *, loff_t, struct file___133 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___133 *, loff_t, struct file___133 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___133 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___132 {
	u64 seqnum;
	struct vm_area_struct___133 *vmas[4];
};

struct page_frag___132 {
	struct page___133 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___132;

struct mem_cgroup___49;

struct cred___128;

struct nsproxy___125;

struct bio_list___54;

struct backing_dev_info___54;

struct io_context___25;

struct css_set___109;

struct request_queue___25;

struct vm_struct___101;

struct task_struct___133 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___133 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___132 *mm;
	struct mm_struct___132 *active_mm;
	struct vmacache___132 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___133 *real_parent;
	struct task_struct___133 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___133 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___49 *active_memcg;
	long int rh_reserved2;
	struct pid___107 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___107 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___107 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___128 *ptracer_cred;
	const struct cred___128 *real_cred;
	const struct cred___128 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___125 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___133 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___54 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___54 *backing_dev_info;
	struct io_context___25 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___109 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___132 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___49 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___25 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___133 *oom_reaper_list;
	struct vm_struct___101 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___81 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___132;

struct super_block___133;

struct dentry___133 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___133 *d_parent;
	struct qstr d_name;
	struct inode___134 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___132 *d_op;
	struct super_block___133 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct rw_semaphore___133 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___133 *owner;
};

struct address_space_operations___132;

struct address_space___132 {
	struct inode___134 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___133 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___132 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___132;

struct bdi_writeback___54;

struct block_device___133;

struct inode___134 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___132 *i_op;
	struct super_block___133 *i_sb;
	struct address_space___132 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___133 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___54 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___133 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___132 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___133 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___132;

struct dentry_operations___132 {
	int (*d_revalidate)(struct dentry___133 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___133 *, unsigned int);
	int (*d_hash)(const struct dentry___133 *, struct qstr *);
	int (*d_compare)(const struct dentry___133 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___133 *);
	int (*d_init)(struct dentry___133 *);
	void (*d_release)(struct dentry___133 *);
	void (*d_prune)(struct dentry___133 *);
	void (*d_iput)(struct dentry___133 *, struct inode___134 *);
	char * (*d_dname)(struct dentry___133 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___132 *);
	int (*d_manage)(const struct path___132 *, bool);
	struct dentry___133 * (*d_real)(struct dentry___133 *, const struct inode___134 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___132;

struct mem_dqinfo___132 {
	struct quota_format_type___132 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___132;

struct quota_info___132 {
	unsigned int flags;
	struct rw_semaphore___133 dqio_sem;
	struct inode___134 *files[3];
	struct mem_dqinfo___132 info[3];
	const struct quota_format_ops___132 *ops[3];
};

struct rcuwait___132 {
	struct task_struct___133 *task;
};

struct percpu_rw_semaphore___132 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___133 rw_sem;
	struct rcuwait___132 writer;
	int readers_block;
};

struct sb_writers___132 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___132 rw_sem[3];
};

struct shrink_control___49;

struct shrinker___49 {
	long unsigned int (*count_objects)(struct shrinker___49 *, struct shrink_control___49 *);
	long unsigned int (*scan_objects)(struct shrinker___49 *, struct shrink_control___49 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___132;

struct super_operations___132;

struct dquot_operations___132;

struct quotactl_ops___132;

struct export_operations___3;

struct xattr_handler___6;

struct user_namespace___113;

struct super_block___133 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___132 *s_type;
	const struct super_operations___132 *s_op;
	const struct dquot_operations___132 *dq_op;
	const struct quotactl_ops___132 *s_qcop;
	const struct export_operations___3 *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___133 *s_root;
	struct rw_semaphore___133 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___6 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___133 *s_bdev;
	struct backing_dev_info___54 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___132 s_dquot;
	struct sb_writers___132 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___132 *s_d_op;
	int cleancache_poolid;
	struct shrinker___49 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___113 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct path___132 {
	struct vfsmount *mnt;
	struct dentry___133 *dentry;
};

struct key___128;

struct ucounts___113;

struct user_namespace___113 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___113 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___4 ns;
	long unsigned int flags;
	struct key___128 *persistent_keyring_register;
	struct rw_semaphore___133 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___113 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct shrink_control___49 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___49 *memcg;
};

struct cgroup___109;

struct cgroup_subsys___109;

struct cgroup_subsys_state___109 {
	struct cgroup___109 *cgroup;
	struct cgroup_subsys___109 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___109 *parent;
};

struct kernfs_node___129;

struct cgroup_file___109 {
	struct kernfs_node___129 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___49;

struct mem_cgroup___49 {
	struct cgroup_subsys_state___109 css;
	struct mem_cgroup_id___17 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___109 events_file;
	struct cgroup_file___109 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___133 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___49 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___133 *pgtable_t___132;

struct dev_pagemap___130;

struct page___133 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___132 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___133 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___132 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___132 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___130 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___49 *mem_cgroup;
};

struct pglist_data___132;

struct lruvec___132 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___132 *pgdat;
};

struct zone___132 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___132 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___132 {
	struct zone___132 *zone;
	int zone_idx;
};

struct zonelist___132 {
	struct zoneref___132 _zonerefs[25];
};

struct pglist_data___132 {
	struct zone___132 node_zones[3];
	struct zonelist___132 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___133 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___133 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___132 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___133 {
	void *stack;
	struct task_struct___133 *task;
	long int status;
};

struct blocking_notifier_head___132 {
	struct rw_semaphore___133 rwsem;
	struct notifier_block *head;
};

struct anon_vma___6;

struct vm_operations_struct___130;

struct vm_area_struct___133 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___133 *vm_next;
	struct vm_area_struct___133 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___132 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma___6 *anon_vma;
	const struct vm_operations_struct___130 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___133 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___132;

struct mm_struct___132 {
	struct {
		struct vm_area_struct___133 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___133 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___133 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___132 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___133 *owner;
		struct user_namespace___113 *user_ns;
		struct file___133 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___132 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___130)(struct vm_area_struct___133 *, long unsigned int, const struct page___133 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___130)(struct page___133 *, void *);

struct device___124;

struct dev_pagemap___130 {
	dev_page_fault_t___130 page_fault;
	dev_page_free_t___130 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___124 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct file___133 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___132 f_path;
	struct inode___134 *f_inode;
	const struct file_operations___133 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___107 f_owner;
	const struct cred___128 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___132 *f_mapping;
	errseq_t f_wb_err;
};

struct anon_vma___6 {
	struct anon_vma___6 *root;
	struct rw_semaphore___133 rwsem;
	atomic_t refcount;
	unsigned int degree;
	struct anon_vma___6 *parent;
	struct rb_root_cached rb_root;
};

struct vm_fault___130;

struct vm_operations_struct___130 {
	void (*open)(struct vm_area_struct___133 *);
	void (*close)(struct vm_area_struct___133 *);
	int (*split)(struct vm_area_struct___133 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___133 *);
	vm_fault_t (*fault)(struct vm_fault___130 *);
	vm_fault_t (*huge_fault)(struct vm_fault___130 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___130 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___133 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___130 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___130 *);
	int (*access)(struct vm_area_struct___133 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___133 *);
	int (*set_policy)(struct vm_area_struct___133 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___133 *, long unsigned int);
	struct page___133 * (*find_special_page)(struct vm_area_struct___133 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___132 {
	struct task_struct___133 *task;
	struct core_thread___132 *next;
};

struct core_state___132 {
	atomic_t nr_threads;
	struct core_thread___132 dumper;
	struct completion startup;
};

struct vm_fault___130 {
	struct vm_area_struct___133 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___133 *cow_page;
	struct mem_cgroup___49 *memcg;
	struct page___133 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___132 prealloc_pte;
};

struct user_struct___128 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___128 *uid_keyring;
	struct key___128 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___128 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___128 *session_keyring;
	struct key___128 *process_keyring;
	struct key___128 *thread_keyring;
	struct key___128 *request_key_auth;
	void *security;
	struct user_struct___128 *user;
	struct user_namespace___113 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___109;

struct nsproxy___125 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___109 *cgroup_ns;
};

struct bio___54;

struct bio_list___54 {
	struct bio___54 *head;
	struct bio___54 *tail;
};

struct bdi_writeback_congested___54;

struct bdi_writeback___54 {
	struct backing_dev_info___54 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___54 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___109 *memcg_css;
	struct cgroup_subsys_state___109 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___54 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___54 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___124 *dev;
	struct device___124 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___133 *debug_dir;
	struct dentry___133 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___25;

struct io_context___25 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___25 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___109 {
	struct cgroup_subsys_state___109 *subsys[13];
	refcount_t refcount;
	struct css_set___109 *dom_cset;
	struct cgroup___109 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___109 *mg_src_cgrp;
	struct cgroup___109 *mg_dst_cgrp;
	struct css_set___109 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

typedef blk_qc_t make_request_fn___24(struct request_queue___25 *, struct bio___54 *);

struct request___25;

typedef int dma_drain_needed_fn___24(struct request___25 *);

struct kset___126;

struct kobj_type___126;

struct kobject___127 {
	const char *name;
	struct list_head entry;
	struct kobject___127 *parent;
	struct kset___126 *kset;
	struct kobj_type___126 *ktype;
	struct kernfs_node___129 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___24;

struct bsg_class_device___24 {
	struct device___124 *class_dev;
	int minor;
	struct request_queue___25 *queue;
	const struct bsg_ops___24 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___54 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___54 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___24;

struct blkcg_gq___16;

struct request_queue___25 {
	struct list_head queue_head;
	struct request___25 *last_merge;
	struct elevator_queue___24 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___24 *make_request_fn;
	dma_drain_needed_fn___24 *dma_drain_needed;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___54 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___127 kobj;
	struct kobject___127 *mq_kobj;
	struct blk_integrity integrity;
	struct device___124 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___16 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	struct bsg_class_device___24 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___54 bio_split;
	struct dentry___133 *debugfs_dir;
	struct dentry___133 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___101 {
	struct vm_struct___101 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___133 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct io_cq___25 {
	struct request_queue___25 *q;
	struct io_context___25 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___2 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___133 {
	struct file___133 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___133 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___133 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___133 *ia_file;
};

struct dquot___132 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___133 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___132 {
	int qf_fmt_id;
	const struct quota_format_ops___132 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___132 *qf_next;
};

struct quota_format_ops___132 {
	int (*check_quota_file)(struct super_block___133 *, int);
	int (*read_file_info)(struct super_block___133 *, int);
	int (*write_file_info)(struct super_block___133 *, int);
	int (*free_file_info)(struct super_block___133 *, int);
	int (*read_dqblk)(struct dquot___132 *);
	int (*commit_dqblk)(struct dquot___132 *);
	int (*release_dqblk)(struct dquot___132 *);
	int (*get_next_id)(struct super_block___133 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___132 {
	int (*write_dquot)(struct dquot___132 *);
	struct dquot___132 * (*alloc_dquot)(struct super_block___133 *, int);
	void (*destroy_dquot)(struct dquot___132 *);
	int (*acquire_dquot)(struct dquot___132 *);
	int (*release_dquot)(struct dquot___132 *);
	int (*mark_dirty)(struct dquot___132 *);
	int (*write_info)(struct super_block___133 *, int);
	qsize_t * (*get_reserved_space)(struct inode___134 *);
	int (*get_projid)(struct inode___134 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___134 *, qsize_t *);
	int (*get_next_id)(struct super_block___133 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___132 {
	int (*quota_on)(struct super_block___133 *, int, int, const struct path___132 *);
	int (*quota_off)(struct super_block___133 *, int);
	int (*quota_enable)(struct super_block___133 *, unsigned int);
	int (*quota_disable)(struct super_block___133 *, unsigned int);
	int (*quota_sync)(struct super_block___133 *, int);
	int (*set_info)(struct super_block___133 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___133 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___133 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___133 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___133 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___133 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___51;

struct swap_info_struct___35;

struct address_space_operations___132 {
	int (*writepage)(struct page___133 *, struct writeback_control___51 *);
	int (*readpage)(struct file___133 *, struct page___133 *);
	int (*writepages)(struct address_space___132 *, struct writeback_control___51 *);
	int (*set_page_dirty)(struct page___133 *);
	int (*readpages)(struct file___133 *, struct address_space___132 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___133 *, struct address_space___132 *, loff_t, unsigned int, unsigned int, struct page___133 **, void **);
	int (*write_end)(struct file___133 *, struct address_space___132 *, loff_t, unsigned int, unsigned int, struct page___133 *, void *);
	sector_t (*bmap)(struct address_space___132 *, sector_t);
	void (*invalidatepage)(struct page___133 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___133 *, gfp_t);
	void (*freepage)(struct page___133 *);
	ssize_t (*direct_IO)(struct kiocb___133 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___132 *, struct page___133 *, struct page___133 *, enum migrate_mode);
	bool (*isolate_page)(struct page___133 *, isolate_mode_t);
	void (*putback_page)(struct page___133 *);
	int (*launder_page)(struct page___133 *);
	int (*is_partially_uptodate)(struct page___133 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___133 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___132 *, struct page___133 *);
	int (*swap_activate)(struct swap_info_struct___35 *, struct file___133 *, sector_t *);
	void (*swap_deactivate)(struct file___133 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___51 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___54 *wb;
	struct inode___134 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct swap_info_struct___35 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___133 *bdev;
	struct file___133 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct hd_struct___25;

struct gendisk___25;

struct block_device___133 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___134 *bd_inode;
	struct super_block___133 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___133 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___25 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___25 *bd_disk;
	struct request_queue___25 *bd_queue;
	struct backing_dev_info___54 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___124 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___124 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___124;

struct bus_type___124;

struct device_driver___124;

struct dev_pm_domain___124;

struct fwnode_handle___93;

struct class___124;

struct attribute_group___123;

struct device___124 {
	struct device___124 *parent;
	struct device_private *p;
	struct kobject___127 kobj;
	const char *init_name;
	const struct device_type___124 *type;
	struct mutex mutex;
	struct bus_type___124 *bus;
	struct device_driver___124 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___124 power;
	struct dev_pm_domain___124 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___93 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___124 *class;
	const struct attribute_group___123 **groups;
	void (*release)(struct device___124 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___25 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___124 __dev;
	struct kobject___127 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___25;

struct block_device_operations___25;

struct gendisk___25 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___25 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___25 *part_tbl;
	struct hd_struct___25 part0;
	const struct block_device_operations___25 *fops;
	struct request_queue___25 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___133 lookup_sem;
	struct kobject___127 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___127 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___132 {
	struct dentry___133 * (*lookup)(struct inode___134 *, struct dentry___133 *, unsigned int);
	const char * (*get_link)(struct dentry___133 *, struct inode___134 *, struct delayed_call *);
	int (*permission)(struct inode___134 *, int);
	struct posix_acl * (*get_acl)(struct inode___134 *, int);
	int (*readlink)(struct dentry___133 *, char *, int);
	int (*create)(struct inode___134 *, struct dentry___133 *, umode_t, bool);
	int (*link)(struct dentry___133 *, struct inode___134 *, struct dentry___133 *);
	int (*unlink)(struct inode___134 *, struct dentry___133 *);
	int (*symlink)(struct inode___134 *, struct dentry___133 *, const char *);
	int (*mkdir)(struct inode___134 *, struct dentry___133 *, umode_t);
	int (*rmdir)(struct inode___134 *, struct dentry___133 *);
	int (*mknod)(struct inode___134 *, struct dentry___133 *, umode_t, dev_t);
	int (*rename)(struct inode___134 *, struct dentry___133 *, struct inode___134 *, struct dentry___133 *, unsigned int);
	int (*setattr)(struct dentry___133 *, struct iattr___133 *);
	int (*getattr)(const struct path___132 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___133 *, char *, size_t);
	int (*fiemap)(struct inode___134 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___134 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___134 *, struct dentry___133 *, struct file___133 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___134 *, struct dentry___133 *, umode_t);
	int (*set_acl)(struct inode___134 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___132 {
	void (*fl_copy_lock)(struct file_lock___133 *, struct file_lock___133 *);
	void (*fl_release_private)(struct file_lock___133 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___132;

struct lock_manager_operations___132;

struct file_lock___133 {
	struct file_lock___133 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___133 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___132 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___132 *fl_ops;
	const struct lock_manager_operations___132 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___132 {
	int (*lm_compare_owner)(struct file_lock___133 *, struct file_lock___133 *);
	long unsigned int (*lm_owner_key)(struct file_lock___133 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___133 *);
	int (*lm_grant)(struct file_lock___133 *, int);
	bool (*lm_break)(struct file_lock___133 *);
	int (*lm_change)(struct file_lock___133 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___133 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___132 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___132 *fa_next;
	struct file___133 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___132 {
	const char *name;
	int fs_flags;
	struct dentry___133 * (*mount)(struct file_system_type___132 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___133 *);
	struct module___11 *owner;
	struct file_system_type___132 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___132 {
	struct inode___134 * (*alloc_inode)(struct super_block___133 *);
	void (*destroy_inode)(struct inode___134 *);
	void (*dirty_inode)(struct inode___134 *, int);
	int (*write_inode)(struct inode___134 *, struct writeback_control___51 *);
	int (*drop_inode)(struct inode___134 *);
	void (*evict_inode)(struct inode___134 *);
	void (*put_super)(struct super_block___133 *);
	int (*sync_fs)(struct super_block___133 *, int);
	int (*freeze_super)(struct super_block___133 *);
	int (*freeze_fs)(struct super_block___133 *);
	int (*thaw_super)(struct super_block___133 *);
	int (*unfreeze_fs)(struct super_block___133 *);
	int (*statfs)(struct dentry___133 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___133 *, int *, char *);
	void (*umount_begin)(struct super_block___133 *);
	int (*show_options)(struct seq_file___123 *, struct dentry___133 *);
	int (*show_devname)(struct seq_file___123 *, struct dentry___133 *);
	int (*show_path)(struct seq_file___123 *, struct dentry___133 *);
	int (*show_stats)(struct seq_file___123 *, struct dentry___133 *);
	ssize_t (*quota_read)(struct super_block___133 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___133 *, int, const char *, size_t, loff_t);
	struct dquot___132 ** (*get_dquots)(struct inode___134 *);
	int (*bdev_try_to_free_page)(struct super_block___133 *, struct page___133 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___133 *, struct shrink_control___49 *);
	long int (*free_cached_objects)(struct super_block___133 *, struct shrink_control___49 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct export_operations___3 {
	int (*encode_fh)(struct inode___134 *, __u32 *, int *, struct inode___134 *);
	struct dentry___133 * (*fh_to_dentry)(struct super_block___133 *, struct fid *, int, int);
	struct dentry___133 * (*fh_to_parent)(struct super_block___133 *, struct fid *, int, int);
	int (*get_name)(struct dentry___133 *, char *, struct dentry___133 *);
	struct dentry___133 * (*get_parent)(struct dentry___133 *);
	int (*commit_metadata)(struct inode___134 *);
	int (*get_uuid)(struct super_block___133 *, u8 *, u32 *, u64 *);
	int (*map_blocks)(struct inode___134 *, loff_t, u64, struct iomap *, bool, u32 *);
	int (*commit_blocks)(struct inode___134 *, struct iomap *, int, struct iattr___133 *);
};

struct xattr_handler___6 {
	const char *name;
	const char *prefix;
	int flags;
	bool (*list)(struct dentry___133 *);
	int (*get)(const struct xattr_handler___6 *, struct dentry___133 *, struct inode___134 *, const char *, void *, size_t);
	int (*set)(const struct xattr_handler___6 *, struct dentry___133 *, struct inode___134 *, const char *, const void *, size_t, int);
};

struct seq_operations___121;

struct seq_file___123 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___121 *op;
	int poll_event;
	const struct file___133 *file;
	void *private;
};

typedef void bio_end_io_t___54(struct bio___54 *);

struct bio_vec___54 {
	struct page___133 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___54;

struct bio___54 {
	struct bio___54 *bi_next;
	struct gendisk___25 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___54 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___16 *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___54 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___54 *bi_io_vec;
	struct bio_set___54 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___54 bi_inline_vecs[0];
};

struct bio_integrity_payload___54 {
	struct bio___54 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___54 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___54 bip_inline_vecs[0];
};

struct blkcg___16;

struct blkg_policy_data___16;

struct blkcg_gq___16 {
	struct request_queue___25 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___16 *blkcg;
	struct bdi_writeback_congested___54 *wb_congested;
	struct blkcg_gq___16 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_rwstat stat_bytes;
	struct blkg_rwstat stat_ios;
	struct blkg_policy_data___16 *pd[5];
	struct callback_head callback_head;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
};

struct dev_pm_ops___124;

struct device_type___124 {
	const char *name;
	const struct attribute_group___123 **groups;
	int (*uevent)(struct device___124 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___124 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___124 *);
	const struct dev_pm_ops___124 *pm;
};

struct class___124 {
	const char *name;
	struct module___11 *owner;
	const struct attribute_group___123 **class_groups;
	const struct attribute_group___123 **dev_groups;
	struct kobject___127 *dev_kobj;
	int (*dev_uevent)(struct device___124 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___124 *, umode_t *);
	void (*class_release)(struct class___124 *);
	void (*dev_release)(struct device___124 *);
	int (*shutdown_pre)(struct device___124 *);
	const struct kobj_ns_type_operations___2 *ns_type;
	const void * (*namespace)(struct device___124 *);
	const struct dev_pm_ops___124 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct kernfs_root___129;

struct kernfs_elem_dir___129 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___129 *root;
};

struct kernfs_syscall_ops___129;

struct kernfs_root___129 {
	struct kernfs_node___129 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___129 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___129 {
	struct kernfs_node___129 *target_kn;
};

struct kernfs_ops___129;

struct kernfs_elem_attr___129 {
	const struct kernfs_ops___129 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___129 *notify_next;
};

struct kernfs_node___129 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___129 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___129 dir;
		struct kernfs_elem_symlink___129 symlink;
		struct kernfs_elem_attr___129 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___129;

struct kernfs_ops___129 {
	int (*open)(struct kernfs_open_file___129 *);
	void (*release)(struct kernfs_open_file___129 *);
	int (*seq_show)(struct seq_file___123 *, void *);
	void * (*seq_start)(struct seq_file___123 *, loff_t *);
	void * (*seq_next)(struct seq_file___123 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___123 *, void *);
	ssize_t (*read)(struct kernfs_open_file___129 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___129 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___129 *, struct vm_area_struct___133 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___129 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___129 {
	int (*remount_fs)(struct kernfs_root___129 *, int *, char *);
	int (*show_options)(struct seq_file___123 *, struct kernfs_root___129 *);
	int (*mkdir)(struct kernfs_node___129 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___129 *);
	int (*rename)(struct kernfs_node___129 *, struct kernfs_node___129 *, const char *);
	int (*show_path)(struct seq_file___123 *, struct kernfs_node___129 *, struct kernfs_root___129 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___129 {
	struct kernfs_node___129 *kn;
	struct file___133 *file;
	struct seq_file___123 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___130 *vm_ops;
};

struct bin_attribute___123;

struct attribute_group___123 {
	const char *name;
	umode_t (*is_visible)(struct kobject___127 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___127 *, struct bin_attribute___123 *, int);
	struct attribute **attrs;
	struct bin_attribute___123 **bin_attrs;
};

struct bin_attribute___123 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___133 *, struct kobject___127 *, struct bin_attribute___123 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___133 *, struct kobject___127 *, struct bin_attribute___123 *, char *, loff_t, size_t);
	int (*mmap)(struct file___133 *, struct kobject___127 *, struct bin_attribute___123 *, struct vm_area_struct___133 *);
};

struct sysfs_ops___126 {
	ssize_t (*show)(struct kobject___127 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___127 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___126;

struct kset___126 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___127 kobj;
	const struct kset_uevent_ops___126 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___126 {
	void (*release)(struct kobject___127 *);
	const struct sysfs_ops___126 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___2 * (*child_ns_type)(struct kobject___127 *);
	const void * (*namespace)(struct kobject___127 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___126 {
	int (* const filter)(struct kset___126 *, struct kobject___127 *);
	const char * (* const name)(struct kset___126 *, struct kobject___127 *);
	int (* const uevent)(struct kset___126 *, struct kobject___127 *, struct kobj_uevent_env *);
};

struct kobj_attribute___127 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___127 *, struct kobj_attribute___127 *, char *);
	ssize_t (*store)(struct kobject___127 *, struct kobj_attribute___127 *, const char *, size_t);
};

struct dev_pm_ops___124 {
	int (*prepare)(struct device___124 *);
	void (*complete)(struct device___124 *);
	int (*suspend)(struct device___124 *);
	int (*resume)(struct device___124 *);
	int (*freeze)(struct device___124 *);
	int (*thaw)(struct device___124 *);
	int (*poweroff)(struct device___124 *);
	int (*restore)(struct device___124 *);
	int (*suspend_late)(struct device___124 *);
	int (*resume_early)(struct device___124 *);
	int (*freeze_late)(struct device___124 *);
	int (*thaw_early)(struct device___124 *);
	int (*poweroff_late)(struct device___124 *);
	int (*restore_early)(struct device___124 *);
	int (*suspend_noirq)(struct device___124 *);
	int (*resume_noirq)(struct device___124 *);
	int (*freeze_noirq)(struct device___124 *);
	int (*thaw_noirq)(struct device___124 *);
	int (*poweroff_noirq)(struct device___124 *);
	int (*restore_noirq)(struct device___124 *);
	int (*runtime_suspend)(struct device___124 *);
	int (*runtime_resume)(struct device___124 *);
	int (*runtime_idle)(struct device___124 *);
};

struct dev_pm_domain___124 {
	struct dev_pm_ops___124 ops;
	void (*detach)(struct device___124 *, bool);
	int (*activate)(struct device___124 *);
	void (*sync)(struct device___124 *);
	void (*dismiss)(struct device___124 *);
};

struct bus_type___124 {
	const char *name;
	const char *dev_name;
	struct device___124 *dev_root;
	const struct attribute_group___123 **bus_groups;
	const struct attribute_group___123 **dev_groups;
	const struct attribute_group___123 **drv_groups;
	int (*match)(struct device___124 *, struct device_driver___124 *);
	int (*uevent)(struct device___124 *, struct kobj_uevent_env *);
	int (*probe)(struct device___124 *);
	int (*remove)(struct device___124 *);
	void (*shutdown)(struct device___124 *);
	int (*online)(struct device___124 *);
	int (*offline)(struct device___124 *);
	int (*suspend)(struct device___124 *, pm_message_t);
	int (*resume)(struct device___124 *);
	int (*num_vf)(struct device___124 *);
	int (*dma_configure)(struct device___124 *);
	const struct dev_pm_ops___124 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___124 {
	const char *name;
	struct bus_type___124 *bus;
	struct module___11 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___124 *);
	int (*remove)(struct device___124 *);
	void (*shutdown)(struct device___124 *);
	int (*suspend)(struct device___124 *, pm_message_t);
	int (*resume)(struct device___124 *);
	const struct attribute_group___123 **groups;
	const struct dev_pm_ops___124 *pm;
	void (*coredump)(struct device___124 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct fwnode_operations___93;

struct fwnode_handle___93 {
	struct fwnode_handle___93 *secondary;
	const struct fwnode_operations___93 *ops;
};

struct disk_part_tbl___25 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___25 *last_lookup;
	struct hd_struct___25 *part[0];
};

struct block_device_operations___25 {
	int (*open)(struct block_device___133 *, fmode_t);
	void (*release)(struct gendisk___25 *, fmode_t);
	int (*rw_page)(struct block_device___133 *, sector_t, struct page___133 *, unsigned int);
	int (*ioctl)(struct block_device___133 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___133 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___25 *, unsigned int);
	int (*media_changed)(struct gendisk___25 *);
	void (*unlock_native_capacity)(struct gendisk___25 *);
	int (*revalidate_disk)(struct gendisk___25 *);
	int (*getgeo)(struct block_device___133 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___133 *, long unsigned int);
	int (*report_zones)(struct gendisk___25 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___11 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___130(struct page___133 *);

struct bdi_writeback_congested___54 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___54 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bsg_ops___24 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___25 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___25 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___25 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___24(struct request___25 *, blk_status_t);

struct request___25 {
	struct request_queue___25 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___54 *bio;
	struct bio___54 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___54 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___25 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___24 *saved_end_io;
		} flush;
	};
	struct gendisk___25 *rq_disk;
	struct hd_struct___25 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___24 *end_io;
	void *end_io_data;
	struct request___25 *next_rq;
};

struct fwnode_reference_args___93;

struct fwnode_endpoint___93;

struct fwnode_operations___93 {
	struct fwnode_handle___93 * (*get)(struct fwnode_handle___93 *);
	void (*put)(struct fwnode_handle___93 *);
	bool (*device_is_available)(const struct fwnode_handle___93 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___93 *, const struct device___124 *);
	bool (*property_present)(const struct fwnode_handle___93 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___93 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___93 *, const char *, const char **, size_t);
	struct fwnode_handle___93 * (*get_parent)(const struct fwnode_handle___93 *);
	struct fwnode_handle___93 * (*get_next_child_node)(const struct fwnode_handle___93 *, struct fwnode_handle___93 *);
	struct fwnode_handle___93 * (*get_named_child_node)(const struct fwnode_handle___93 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___93 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___93 *);
	struct fwnode_handle___93 * (*graph_get_next_endpoint)(const struct fwnode_handle___93 *, struct fwnode_handle___93 *);
	struct fwnode_handle___93 * (*graph_get_remote_endpoint)(const struct fwnode_handle___93 *);
	struct fwnode_handle___93 * (*graph_get_port_parent)(struct fwnode_handle___93 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___93 *, struct fwnode_endpoint___93 *);
};

struct fwnode_endpoint___93 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___93 *local_fwnode;
};

struct fwnode_reference_args___93 {
	struct fwnode_handle___93 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct elevator_type___24;

struct elevator_mq_ops___24 {
	int (*init_sched)(struct request_queue___25 *, struct elevator_type___24 *);
	void (*exit_sched)(struct elevator_queue___24 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	bool (*allow_merge)(struct request_queue___25 *, struct request___25 *, struct bio___54 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx *, struct bio___54 *);
	int (*request_merge)(struct request_queue___25 *, struct request___25 **, struct bio___54 *);
	void (*request_merged)(struct request_queue___25 *, struct request___25 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___25 *, struct request___25 *, struct request___25 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___25 *, struct bio___54 *);
	void (*finish_request)(struct request___25 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___25 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___25 *, u64);
	void (*started_request)(struct request___25 *);
	void (*requeue_request)(struct request___25 *);
	struct request___25 * (*former_request)(struct request_queue___25 *, struct request___25 *);
	struct request___25 * (*next_request)(struct request_queue___25 *, struct request___25 *);
	void (*init_icq)(struct io_cq___25 *);
	void (*exit_icq)(struct io_cq___25 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___24;

struct elevator_type___24 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___24 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___24 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___11 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___24 {
	struct elevator_type___24 *type;
	void *elevator_data;
	struct kobject___127 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___24 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___24 *, char *);
	ssize_t (*store)(struct elevator_queue___24 *, const char *, size_t);
};

typedef int (*key_restrict_link_func_t___128)(struct key___128 *, const struct key_type *, const union key_payload *, struct key___128 *);

struct key_restriction___128;

struct key___128 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___133 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___128 *restrict_link;
};

struct key_restriction___128 {
	key_restrict_link_func_t___128 check;
	struct key___128 *key;
	struct key_type *keytype;
};

struct seq_operations___121 {
	void * (*start)(struct seq_file___123 *, loff_t *);
	void (*stop)(struct seq_file___123 *, void *);
	void * (*next)(struct seq_file___123 *, void *, loff_t *);
	int (*show)(struct seq_file___123 *, void *);
};

struct cgroup_namespace___109 {
	refcount_t count;
	struct ns_common___4 ns;
	struct user_namespace___113 *user_ns;
	struct ucounts___113 *ucounts;
	struct css_set___109 *root_cset;
};

struct ucounts___113 {
	struct hlist_node node;
	struct user_namespace___113 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___109;

struct bpf_map_ops___109 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___109 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___109 *, struct file___133 *);
	void (*map_free)(struct bpf_map___109 *);
	int (*map_get_next_key)(struct bpf_map___109 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___109 *);
	void * (*map_lookup_elem)(struct bpf_map___109 *, void *);
	int (*map_update_elem)(struct bpf_map___109 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___109 *, void *);
	int (*map_push_elem)(struct bpf_map___109 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___109 *, void *);
	int (*map_peek_elem)(struct bpf_map___109 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___109 *, struct file___133 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___109 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___109 *, void *, struct seq_file___123 *);
	int (*map_check_btf)(const struct bpf_map___109 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___109 {
	const struct bpf_map_ops___109 *ops;
	struct bpf_map___109 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___128 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___109;

typedef void (*kthread_work_func_t___109)(struct kthread_work___109 *);

struct kthread_worker___109;

struct kthread_work___109 {
	struct list_head node;
	kthread_work_func_t___109 func;
	struct kthread_worker___109 *worker;
	int canceling;
};

struct kthread_worker___109 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___133 *task;
	struct kthread_work___109 *current_work;
};

struct kthread_delayed_work___109 {
	struct kthread_work___109 work;
	struct timer_list timer;
};

struct psi_group___109 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___109 *poll_kworker;
	struct kthread_delayed_work___109 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___109;

struct cgroup_rstat_cpu___109;

struct cgroup___109 {
	struct cgroup_subsys_state___109 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___129 *kn;
	struct cgroup_file___109 procs_file;
	struct cgroup_file___109 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___109 *subsys[13];
	struct cgroup_root___109 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___109 *dom_cgrp;
	struct cgroup_rstat_cpu___109 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___4 bpf;
	atomic_t congestion_count;
	struct cgroup___109 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___109 psi;
	int ancestor_ids[0];
};

struct cftype___109;

struct cgroup_subsys___109 {
	struct cgroup_subsys_state___109 * (*css_alloc)(struct cgroup_subsys_state___109 *);
	int (*css_online)(struct cgroup_subsys_state___109 *);
	void (*css_offline)(struct cgroup_subsys_state___109 *);
	void (*css_released)(struct cgroup_subsys_state___109 *);
	void (*css_free)(struct cgroup_subsys_state___109 *);
	void (*css_reset)(struct cgroup_subsys_state___109 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___109 *, int);
	int (*css_extra_stat_show)(struct seq_file___123 *, struct cgroup_subsys_state___109 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___133 *);
	void (*cancel_fork)(struct task_struct___133 *);
	void (*fork)(struct task_struct___133 *);
	void (*exit)(struct task_struct___133 *);
	void (*free)(struct task_struct___133 *);
	void (*bind)(struct cgroup_subsys_state___109 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___109 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___109 *dfl_cftypes;
	struct cftype___109 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___109 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___109 *updated_children;
	struct cgroup___109 *updated_next;
};

struct cgroup_root___109 {
	struct kernfs_root___129 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___109 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___109 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___109 *ss;
	struct list_head node;
	struct kernfs_ops___129 *kf_ops;
	int (*open)(struct kernfs_open_file___129 *);
	void (*release)(struct kernfs_open_file___129 *);
	u64 (*read_u64)(struct cgroup_subsys_state___109 *, struct cftype___109 *);
	s64 (*read_s64)(struct cgroup_subsys_state___109 *, struct cftype___109 *);
	int (*seq_show)(struct seq_file___123 *, void *);
	void * (*seq_start)(struct seq_file___123 *, loff_t *);
	void * (*seq_next)(struct seq_file___123 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___123 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___109 *, struct cftype___109 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___109 *, struct cftype___109 *, s64);
	ssize_t (*write)(struct kernfs_open_file___129 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___129 *, struct poll_table_struct___6 *);
};

struct blkcg_policy_data___16;

struct blkcg___16 {
	struct cgroup_subsys_state___109 css;
	spinlock_t lock;
	struct xarray blkg_tree;
	struct blkcg_gq___16 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___16 *cpd[5];
	struct list_head all_blkcgs_node;
	struct list_head cgwb_list;
	refcount_t cgwb_refcnt;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct blkcg_policy_data___16 {
	struct blkcg___16 *blkcg;
	int plid;
};

struct blkg_policy_data___16 {
	struct blkcg_gq___16 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___49 {
	struct mem_cgroup___49 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___49 {
	struct lruvec___132 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___49 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___49 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct node___103 {
	struct device___124 dev;
};

struct pagevec___4 {
	unsigned char nr;
	bool percpu_pvec_drained;
	struct page___133 *pages[15];
};

struct module___114;

struct file___134;

struct kiocb___134;

struct iov_iter___59;

struct poll_table_struct___91;

struct vm_area_struct___134;

struct inode___135;

struct file_lock___134;

struct page___134;

struct seq_file___124;

struct file_operations___134 {
	struct module___114 *owner;
	loff_t (*llseek)(struct file___134 *, loff_t, int);
	ssize_t (*read)(struct file___134 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___134 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___134 *, struct iov_iter___59 *);
	ssize_t (*write_iter)(struct kiocb___134 *, struct iov_iter___59 *);
	int (*iopoll)(struct kiocb___134 *, bool);
	int (*iterate)(struct file___134 *, struct dir_context *);
	int (*iterate_shared)(struct file___134 *, struct dir_context *);
	__poll_t (*poll)(struct file___134 *, struct poll_table_struct___91 *);
	long int (*unlocked_ioctl)(struct file___134 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___134 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___134 *, struct vm_area_struct___134 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___135 *, struct file___134 *);
	int (*flush)(struct file___134 *, fl_owner_t);
	int (*release)(struct inode___135 *, struct file___134 *);
	int (*fsync)(struct file___134 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___134 *, int);
	int (*lock)(struct file___134 *, int, struct file_lock___134 *);
	ssize_t (*sendpage)(struct file___134 *, struct page___134 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___134 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___134 *, int, struct file_lock___134 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___134 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___134 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___134 *, long int, struct file_lock___134 **, void **);
	long int (*fallocate)(struct file___134 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___124 *, struct file___134 *);
	ssize_t (*copy_file_range)(struct file___134 *, loff_t, struct file___134 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___134 *, loff_t, struct file___134 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___134 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___133 {
	u64 seqnum;
	struct vm_area_struct___134 *vmas[4];
};

struct page_frag___133 {
	struct page___134 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___82;

struct debug_info___82 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___82 *hbp_break[16];
	struct perf_event___82 *hbp_watch[16];
};

struct thread_struct___82 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___82 debug;
	long: 64;
};

struct mm_struct___133;

struct mem_cgroup___50;

struct pid___108;

struct cred___129;

struct nsproxy___126;

struct signal_struct___121;

struct bio_list___55;

struct backing_dev_info___55;

struct io_context___26;

struct css_set___110;

struct perf_event_context___82;

struct request_queue___26;

struct vm_struct___102;

struct task_struct___134 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___134 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___133 *mm;
	struct mm_struct___133 *active_mm;
	struct vmacache___133 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___134 *real_parent;
	struct task_struct___134 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___134 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___50 *active_memcg;
	long int rh_reserved2;
	struct pid___108 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___108 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___108 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___129 *ptracer_cred;
	const struct cred___129 *real_cred;
	const struct cred___129 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___126 *nsproxy;
	struct signal_struct___121 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___134 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___55 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___55 *backing_dev_info;
	struct io_context___26 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___110 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___82 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___133 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___50 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___26 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___134 *oom_reaper_list;
	struct vm_struct___102 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___82 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___82 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___134 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___82)(struct perf_event___82 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___82;

struct fasync_struct___133;

struct pid_namespace___108;

struct trace_event_call___75;

struct perf_cgroup___82;

struct perf_event___82 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___82 *group_leader;
	struct pmu___82 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___82 hw;
	struct perf_event_context___82 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___82 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___134 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___133 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___82 *);
	struct callback_head callback_head;
	struct pid_namespace___108 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___82 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___82 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___75 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___82 *cgrp;
	struct list_head sb_list;
};

typedef struct page___134 *pgtable_t___133;

struct address_space___133;

struct dev_pagemap___131;

struct page___134 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___133 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___134 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___133 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___133 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___131 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___50 *mem_cgroup;
};

struct pglist_data___133;

struct lruvec___133 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___133 *pgdat;
};

struct zone___133 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___133 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___133 {
	struct zone___133 *zone;
	int zone_idx;
};

struct zonelist___133 {
	struct zoneref___133 _zonerefs[25];
};

struct pglist_data___133 {
	struct zone___133 node_zones[3];
	struct zonelist___133 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___134 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___134 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___133 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

enum pgdat_flags {
	PGDAT_CONGESTED = 0,
	PGDAT_DIRTY = 1,
	PGDAT_WRITEBACK = 2,
	PGDAT_RECLAIM_LOCKED = 3,
};

typedef struct pglist_data___133 pg_data_t___5;

struct rw_semaphore___134 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___134 *owner;
};

struct secondary_data___134 {
	void *stack;
	struct task_struct___134 *task;
	long int status;
};

struct blocking_notifier_head___133 {
	struct rw_semaphore___134 rwsem;
	struct notifier_block *head;
};

struct anon_vma___7;

struct vm_operations_struct___131;

struct vm_area_struct___134 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___134 *vm_next;
	struct vm_area_struct___134 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___133 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma___7 *anon_vma;
	const struct vm_operations_struct___131 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___134 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___133;

struct user_namespace___114;

struct mm_struct___133 {
	struct {
		struct vm_area_struct___134 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___134 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___134 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___133 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___134 *owner;
		struct user_namespace___114 *user_ns;
		struct file___134 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___133 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___133;

struct address_space___133 {
	struct inode___135 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___134 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___133 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___131)(struct vm_area_struct___134 *, long unsigned int, const struct page___134 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___131)(struct page___134 *, void *);

struct device___125;

struct dev_pagemap___131 {
	dev_page_fault_t___131 page_fault;
	dev_page_free_t___131 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___125 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct cgroup___110;

struct cgroup_subsys___110;

struct cgroup_subsys_state___110 {
	struct cgroup___110 *cgroup;
	struct cgroup_subsys___110 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___110 *parent;
};

struct kernfs_node___130;

struct cgroup_file___110 {
	struct kernfs_node___130 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___50;

struct mem_cgroup___50 {
	struct cgroup_subsys_state___110 css;
	struct mem_cgroup_id___2 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___110 events_file;
	struct cgroup_file___110 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___134 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___50 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry___134;

struct path___133 {
	struct vfsmount *mnt;
	struct dentry___134 *dentry;
};

struct fown_struct___108 {
	rwlock_t lock;
	struct pid___108 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___134 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___133 f_path;
	struct inode___135 *f_inode;
	const struct file_operations___134 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___108 f_owner;
	const struct cred___129 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___133 *f_mapping;
	errseq_t f_wb_err;
};

struct anon_vma___7 {
	struct anon_vma___7 *root;
	struct rw_semaphore___134 rwsem;
	atomic_t refcount;
	unsigned int degree;
	struct anon_vma___7 *parent;
	struct rb_root_cached rb_root;
};

struct vm_fault___131;

struct vm_operations_struct___131 {
	void (*open)(struct vm_area_struct___134 *);
	void (*close)(struct vm_area_struct___134 *);
	int (*split)(struct vm_area_struct___134 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___134 *);
	vm_fault_t (*fault)(struct vm_fault___131 *);
	vm_fault_t (*huge_fault)(struct vm_fault___131 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___131 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___134 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___131 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___131 *);
	int (*access)(struct vm_area_struct___134 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___134 *);
	int (*set_policy)(struct vm_area_struct___134 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___134 *, long unsigned int);
	struct page___134 * (*find_special_page)(struct vm_area_struct___134 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___133 {
	struct task_struct___134 *task;
	struct core_thread___133 *next;
};

struct core_state___133 {
	atomic_t nr_threads;
	struct core_thread___133 dumper;
	struct completion startup;
};

struct key___129;

struct ucounts___114;

struct user_namespace___114 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___114 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___4 ns;
	long unsigned int flags;
	struct key___129 *persistent_keyring_register;
	struct rw_semaphore___134 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___114 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___131 {
	struct vm_area_struct___134 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___134 *cow_page;
	struct mem_cgroup___50 *memcg;
	struct page___134 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___133 prealloc_pte;
};

struct shrink_control___50 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___50 *memcg;
};

struct shrinker___50 {
	long unsigned int (*count_objects)(struct shrinker___50 *, struct shrink_control___50 *);
	long unsigned int (*scan_objects)(struct shrinker___50 *, struct shrink_control___50 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct upid___108 {
	int nr;
	struct pid_namespace___108 *ns;
};

struct pid_namespace___108 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___134 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___108 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___134 *proc_self;
	struct dentry___134 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___114 *user_ns;
	struct ucounts___114 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___4 ns;
};

struct pid___108 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___108 numbers[1];
};

struct user_struct___129 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___129 *uid_keyring;
	struct key___129 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___129 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___129 *session_keyring;
	struct key___129 *process_keyring;
	struct key___129 *thread_keyring;
	struct key___129 *request_key_auth;
	void *security;
	struct user_struct___129 *user;
	struct user_namespace___114 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___110;

struct nsproxy___126 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___108 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___110 *cgroup_ns;
};

struct signal_struct___121 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___134 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___134 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___108 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___108 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___133 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___108 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide43;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___55;

struct bio_list___55 {
	struct bio___55 *head;
	struct bio___55 *tail;
};

struct bdi_writeback_congested___55;

struct bdi_writeback___55 {
	struct backing_dev_info___55 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___55 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___110 *memcg_css;
	struct cgroup_subsys_state___110 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___55 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___55 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___125 *dev;
	struct device___125 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___134 *debug_dir;
	struct dentry___134 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___26;

struct io_context___26 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___26 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___110 {
	struct cgroup_subsys_state___110 *subsys[13];
	refcount_t refcount;
	struct css_set___110 *dom_cset;
	struct cgroup___110 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___110 *mg_src_cgrp;
	struct cgroup___110 *mg_dst_cgrp;
	struct css_set___110 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___82 {
	struct pmu___82 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___134 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___82 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

typedef blk_qc_t make_request_fn___25(struct request_queue___26 *, struct bio___55 *);

struct request___26;

typedef int dma_drain_needed_fn___25(struct request___26 *);

struct kset___127;

struct kobj_type___127;

struct kobject___128 {
	const char *name;
	struct list_head entry;
	struct kobject___128 *parent;
	struct kset___127 *kset;
	struct kobj_type___127 *ktype;
	struct kernfs_node___130 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___25;

struct bsg_class_device___25 {
	struct device___125 *class_dev;
	int minor;
	struct request_queue___26 *queue;
	const struct bsg_ops___25 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___55 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___55 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___25;

struct blkcg_gq___17;

struct request_queue___26 {
	struct list_head queue_head;
	struct request___26 *last_merge;
	struct elevator_queue___25 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___25 *make_request_fn;
	dma_drain_needed_fn___25 *dma_drain_needed;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___55 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___128 kobj;
	struct kobject___128 *mq_kobj;
	struct blk_integrity integrity;
	struct device___125 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___17 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	struct bsg_class_device___25 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___55 bio_split;
	struct dentry___134 *debugfs_dir;
	struct dentry___134 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___102 {
	struct vm_struct___102 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___134 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___121 {
	struct task_struct___134 task;
	long unsigned int stack[8192];
};

struct dev_pm_info___125 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___125 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___125;

struct bus_type___125;

struct device_driver___125;

struct dev_pm_domain___125;

struct fwnode_handle___94;

struct class___125;

struct attribute_group___124;

struct device___125 {
	struct device___125 *parent;
	struct device_private *p;
	struct kobject___128 kobj;
	const char *init_name;
	const struct device_type___125 *type;
	struct mutex mutex;
	struct bus_type___125 *bus;
	struct device_driver___125 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___125 power;
	struct dev_pm_domain___125 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___94 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___125 *class;
	const struct attribute_group___124 **groups;
	void (*release)(struct device___125 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___133;

struct super_block___134;

struct dentry___134 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___134 *d_parent;
	struct qstr d_name;
	struct inode___135 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___133 *d_op;
	struct super_block___134 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___133;

struct block_device___134;

struct inode___135 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___133 *i_op;
	struct super_block___134 *i_sb;
	struct address_space___133 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___134 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___55 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___134 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___133 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___134 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___133 {
	int (*d_revalidate)(struct dentry___134 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___134 *, unsigned int);
	int (*d_hash)(const struct dentry___134 *, struct qstr *);
	int (*d_compare)(const struct dentry___134 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___134 *);
	int (*d_init)(struct dentry___134 *);
	void (*d_release)(struct dentry___134 *);
	void (*d_prune)(struct dentry___134 *);
	void (*d_iput)(struct dentry___134 *, struct inode___135 *);
	char * (*d_dname)(struct dentry___134 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___133 *);
	int (*d_manage)(const struct path___133 *, bool);
	struct dentry___134 * (*d_real)(struct dentry___134 *, const struct inode___135 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___133;

struct mem_dqinfo___133 {
	struct quota_format_type___133 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___133;

struct quota_info___133 {
	unsigned int flags;
	struct rw_semaphore___134 dqio_sem;
	struct inode___135 *files[3];
	struct mem_dqinfo___133 info[3];
	const struct quota_format_ops___133 *ops[3];
};

struct rcuwait___133 {
	struct task_struct___134 *task;
};

struct percpu_rw_semaphore___133 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___134 rw_sem;
	struct rcuwait___133 writer;
	int readers_block;
};

struct sb_writers___133 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___133 rw_sem[3];
};

struct file_system_type___133;

struct super_operations___133;

struct dquot_operations___133;

struct quotactl_ops___133;

struct super_block___134 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___133 *s_type;
	const struct super_operations___133 *s_op;
	const struct dquot_operations___133 *dq_op;
	const struct quotactl_ops___133 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___134 *s_root;
	struct rw_semaphore___134 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___134 *s_bdev;
	struct backing_dev_info___55 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___133 s_dquot;
	struct sb_writers___133 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___133 *s_d_op;
	int cleancache_poolid;
	struct shrinker___50 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___114 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct io_cq___26 {
	struct request_queue___26 *q;
	struct io_context___26 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___2 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___134 {
	struct file___134 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___134 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___134 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___134 *ia_file;
};

struct dquot___133 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___134 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___133 {
	int qf_fmt_id;
	const struct quota_format_ops___133 *qf_ops;
	struct module___114 *qf_owner;
	struct quota_format_type___133 *qf_next;
};

struct quota_format_ops___133 {
	int (*check_quota_file)(struct super_block___134 *, int);
	int (*read_file_info)(struct super_block___134 *, int);
	int (*write_file_info)(struct super_block___134 *, int);
	int (*free_file_info)(struct super_block___134 *, int);
	int (*read_dqblk)(struct dquot___133 *);
	int (*commit_dqblk)(struct dquot___133 *);
	int (*release_dqblk)(struct dquot___133 *);
	int (*get_next_id)(struct super_block___134 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___133 {
	int (*write_dquot)(struct dquot___133 *);
	struct dquot___133 * (*alloc_dquot)(struct super_block___134 *, int);
	void (*destroy_dquot)(struct dquot___133 *);
	int (*acquire_dquot)(struct dquot___133 *);
	int (*release_dquot)(struct dquot___133 *);
	int (*mark_dirty)(struct dquot___133 *);
	int (*write_info)(struct super_block___134 *, int);
	qsize_t * (*get_reserved_space)(struct inode___135 *);
	int (*get_projid)(struct inode___135 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___135 *, qsize_t *);
	int (*get_next_id)(struct super_block___134 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___133 {
	int (*quota_on)(struct super_block___134 *, int, int, const struct path___133 *);
	int (*quota_off)(struct super_block___134 *, int);
	int (*quota_enable)(struct super_block___134 *, unsigned int);
	int (*quota_disable)(struct super_block___134 *, unsigned int);
	int (*quota_sync)(struct super_block___134 *, int);
	int (*set_info)(struct super_block___134 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___134 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___134 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___134 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___134 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___134 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___111 {
	struct kobject___128 kobj;
	struct module___114 *mod;
	struct kobject___128 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___111 {
	struct module___114 *mod;
	struct latch_tree_node node;
};

struct module_layout___111 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___111 mtn;
};

struct module_attribute___111;

struct kernel_param___111;

struct module___114 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___111 mkobj;
	struct module_attribute___111 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___128 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___111 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___111 core_layout;
	struct module_layout___111 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___75 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___52;

struct swap_info_struct___36;

struct address_space_operations___133 {
	int (*writepage)(struct page___134 *, struct writeback_control___52 *);
	int (*readpage)(struct file___134 *, struct page___134 *);
	int (*writepages)(struct address_space___133 *, struct writeback_control___52 *);
	int (*set_page_dirty)(struct page___134 *);
	int (*readpages)(struct file___134 *, struct address_space___133 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___134 *, struct address_space___133 *, loff_t, unsigned int, unsigned int, struct page___134 **, void **);
	int (*write_end)(struct file___134 *, struct address_space___133 *, loff_t, unsigned int, unsigned int, struct page___134 *, void *);
	sector_t (*bmap)(struct address_space___133 *, sector_t);
	void (*invalidatepage)(struct page___134 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___134 *, gfp_t);
	void (*freepage)(struct page___134 *);
	ssize_t (*direct_IO)(struct kiocb___134 *, struct iov_iter___59 *);
	int (*migratepage)(struct address_space___133 *, struct page___134 *, struct page___134 *, enum migrate_mode);
	bool (*isolate_page)(struct page___134 *, isolate_mode_t);
	void (*putback_page)(struct page___134 *);
	int (*launder_page)(struct page___134 *);
	int (*is_partially_uptodate)(struct page___134 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___134 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___133 *, struct page___134 *);
	int (*swap_activate)(struct swap_info_struct___36 *, struct file___134 *, sector_t *);
	void (*swap_deactivate)(struct file___134 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___52 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___55 *wb;
	struct inode___135 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___55;

struct iov_iter___59 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___55 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct swap_info_struct___36 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___134 *bdev;
	struct file___134 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct hd_struct___26;

struct gendisk___26;

struct block_device___134 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___135 *bd_inode;
	struct super_block___134 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___134 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___26 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___26 *bd_disk;
	struct request_queue___26 *bd_queue;
	struct backing_dev_info___55 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct hd_struct___26 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___125 __dev;
	struct kobject___128 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___26;

struct block_device_operations___26;

struct gendisk___26 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___26 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___26 *part_tbl;
	struct hd_struct___26 part0;
	const struct block_device_operations___26 *fops;
	struct request_queue___26 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___134 lookup_sem;
	struct kobject___128 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___128 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___133 {
	struct dentry___134 * (*lookup)(struct inode___135 *, struct dentry___134 *, unsigned int);
	const char * (*get_link)(struct dentry___134 *, struct inode___135 *, struct delayed_call *);
	int (*permission)(struct inode___135 *, int);
	struct posix_acl * (*get_acl)(struct inode___135 *, int);
	int (*readlink)(struct dentry___134 *, char *, int);
	int (*create)(struct inode___135 *, struct dentry___134 *, umode_t, bool);
	int (*link)(struct dentry___134 *, struct inode___135 *, struct dentry___134 *);
	int (*unlink)(struct inode___135 *, struct dentry___134 *);
	int (*symlink)(struct inode___135 *, struct dentry___134 *, const char *);
	int (*mkdir)(struct inode___135 *, struct dentry___134 *, umode_t);
	int (*rmdir)(struct inode___135 *, struct dentry___134 *);
	int (*mknod)(struct inode___135 *, struct dentry___134 *, umode_t, dev_t);
	int (*rename)(struct inode___135 *, struct dentry___134 *, struct inode___135 *, struct dentry___134 *, unsigned int);
	int (*setattr)(struct dentry___134 *, struct iattr___134 *);
	int (*getattr)(const struct path___133 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___134 *, char *, size_t);
	int (*fiemap)(struct inode___135 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___135 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___135 *, struct dentry___134 *, struct file___134 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___135 *, struct dentry___134 *, umode_t);
	int (*set_acl)(struct inode___135 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___133 {
	void (*fl_copy_lock)(struct file_lock___134 *, struct file_lock___134 *);
	void (*fl_release_private)(struct file_lock___134 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___133;

struct file_lock___134 {
	struct file_lock___134 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___134 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___133 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___133 *fl_ops;
	const struct lock_manager_operations___133 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___133 {
	int (*lm_compare_owner)(struct file_lock___134 *, struct file_lock___134 *);
	long unsigned int (*lm_owner_key)(struct file_lock___134 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___134 *);
	int (*lm_grant)(struct file_lock___134 *, int);
	bool (*lm_break)(struct file_lock___134 *);
	int (*lm_change)(struct file_lock___134 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___134 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___133 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___133 *fa_next;
	struct file___134 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___133 {
	const char *name;
	int fs_flags;
	struct dentry___134 * (*mount)(struct file_system_type___133 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___134 *);
	struct module___114 *owner;
	struct file_system_type___133 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___133 {
	struct inode___135 * (*alloc_inode)(struct super_block___134 *);
	void (*destroy_inode)(struct inode___135 *);
	void (*dirty_inode)(struct inode___135 *, int);
	int (*write_inode)(struct inode___135 *, struct writeback_control___52 *);
	int (*drop_inode)(struct inode___135 *);
	void (*evict_inode)(struct inode___135 *);
	void (*put_super)(struct super_block___134 *);
	int (*sync_fs)(struct super_block___134 *, int);
	int (*freeze_super)(struct super_block___134 *);
	int (*freeze_fs)(struct super_block___134 *);
	int (*thaw_super)(struct super_block___134 *);
	int (*unfreeze_fs)(struct super_block___134 *);
	int (*statfs)(struct dentry___134 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___134 *, int *, char *);
	void (*umount_begin)(struct super_block___134 *);
	int (*show_options)(struct seq_file___124 *, struct dentry___134 *);
	int (*show_devname)(struct seq_file___124 *, struct dentry___134 *);
	int (*show_path)(struct seq_file___124 *, struct dentry___134 *);
	int (*show_stats)(struct seq_file___124 *, struct dentry___134 *);
	ssize_t (*quota_read)(struct super_block___134 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___134 *, int, const char *, size_t, loff_t);
	struct dquot___133 ** (*get_dquots)(struct inode___135 *);
	int (*bdev_try_to_free_page)(struct super_block___134 *, struct page___134 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___134 *, struct shrink_control___50 *);
	long int (*free_cached_objects)(struct super_block___134 *, struct shrink_control___50 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___90)(struct file___134 *, wait_queue_head_t *, struct poll_table_struct___91 *);

struct poll_table_struct___91 {
	poll_queue_proc___90 _qproc;
	__poll_t _key;
};

struct seq_operations___122;

struct seq_file___124 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___122 *op;
	int poll_event;
	const struct file___134 *file;
	void *private;
};

typedef void bio_end_io_t___55(struct bio___55 *);

struct bio_vec___55 {
	struct page___134 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___55;

struct bio___55 {
	struct bio___55 *bi_next;
	struct gendisk___26 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___55 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___17 *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___55 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___55 *bi_io_vec;
	struct bio_set___55 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___55 bi_inline_vecs[0];
};

struct kobj_attribute___128 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___128 *, struct kobj_attribute___128 *, char *);
	ssize_t (*store)(struct kobject___128 *, struct kobj_attribute___128 *, const char *, size_t);
};

typedef void compound_page_dtor___131(struct page___134 *);

struct reclaim_stat {
	unsigned int nr_dirty;
	unsigned int nr_unqueued_dirty;
	unsigned int nr_congested;
	unsigned int nr_writeback;
	unsigned int nr_immediate;
	unsigned int nr_activate;
	unsigned int nr_ref_keep;
	unsigned int nr_unmap_fail;
};

struct kernfs_root___130;

struct kernfs_elem_dir___130 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___130 *root;
};

struct kernfs_syscall_ops___130;

struct kernfs_root___130 {
	struct kernfs_node___130 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___130 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___130 {
	struct kernfs_node___130 *target_kn;
};

struct kernfs_ops___130;

struct kernfs_elem_attr___130 {
	const struct kernfs_ops___130 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___130 *notify_next;
};

struct kernfs_node___130 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___130 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___130 dir;
		struct kernfs_elem_symlink___130 symlink;
		struct kernfs_elem_attr___130 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___130;

struct kernfs_ops___130 {
	int (*open)(struct kernfs_open_file___130 *);
	void (*release)(struct kernfs_open_file___130 *);
	int (*seq_show)(struct seq_file___124 *, void *);
	void * (*seq_start)(struct seq_file___124 *, loff_t *);
	void * (*seq_next)(struct seq_file___124 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___124 *, void *);
	ssize_t (*read)(struct kernfs_open_file___130 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___130 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___130 *, struct vm_area_struct___134 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___130 *, struct poll_table_struct___91 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___130 {
	int (*remount_fs)(struct kernfs_root___130 *, int *, char *);
	int (*show_options)(struct seq_file___124 *, struct kernfs_root___130 *);
	int (*mkdir)(struct kernfs_node___130 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___130 *);
	int (*rename)(struct kernfs_node___130 *, struct kernfs_node___130 *, const char *);
	int (*show_path)(struct seq_file___124 *, struct kernfs_node___130 *, struct kernfs_root___130 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___130 {
	struct kernfs_node___130 *kn;
	struct file___134 *file;
	struct seq_file___124 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___131 *vm_ops;
};

struct bin_attribute___124;

struct attribute_group___124 {
	const char *name;
	umode_t (*is_visible)(struct kobject___128 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___128 *, struct bin_attribute___124 *, int);
	struct attribute **attrs;
	struct bin_attribute___124 **bin_attrs;
};

struct bin_attribute___124 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___134 *, struct kobject___128 *, struct bin_attribute___124 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___134 *, struct kobject___128 *, struct bin_attribute___124 *, char *, loff_t, size_t);
	int (*mmap)(struct file___134 *, struct kobject___128 *, struct bin_attribute___124 *, struct vm_area_struct___134 *);
};

struct sysfs_ops___127 {
	ssize_t (*show)(struct kobject___128 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___128 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___127;

struct kset___127 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___128 kobj;
	const struct kset_uevent_ops___127 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___127 {
	void (*release)(struct kobject___128 *);
	const struct sysfs_ops___127 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___2 * (*child_ns_type)(struct kobject___128 *);
	const void * (*namespace)(struct kobject___128 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___127 {
	int (* const filter)(struct kset___127 *, struct kobject___128 *);
	const char * (* const name)(struct kset___127 *, struct kobject___128 *);
	int (* const uevent)(struct kset___127 *, struct kobject___128 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___111 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___111 *);
	int (*get)(char *, const struct kernel_param___111 *);
	void (*free)(void *);
};

struct kparam_array___111;

struct kernel_param___111 {
	const char *name;
	struct module___114 *mod;
	const struct kernel_param_ops___111 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___111 *arr;
	};
};

struct kparam_array___111 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___111 *ops;
	void *elem;
};

struct module_attribute___111 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___111 *, struct module_kobject___111 *, char *);
	ssize_t (*store)(struct module_attribute___111 *, struct module_kobject___111 *, const char *, size_t);
	void (*setup)(struct module___114 *, const char *);
	int (*test)(struct module___114 *);
	void (*free)(struct module___114 *);
};

struct trace_event_class___75;

struct trace_event_call___75 {
	struct list_head list;
	struct trace_event_class___75 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___4 *prog_array;
	int (*perf_perm)(struct trace_event_call___75 *, struct perf_event___82 *);
};

typedef int (*key_restrict_link_func_t___129)(struct key___129 *, const struct key_type *, const union key_payload *, struct key___129 *);

struct key_restriction___129;

struct key___129 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___134 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___129 *restrict_link;
};

struct key_restriction___129 {
	key_restrict_link_func_t___129 check;
	struct key___129 *key;
	struct key_type *keytype;
};

struct seq_operations___122 {
	void * (*start)(struct seq_file___124 *, loff_t *);
	void (*stop)(struct seq_file___124 *, void *);
	void * (*next)(struct seq_file___124 *, void *, loff_t *);
	int (*show)(struct seq_file___124 *, void *);
};

struct cgroup_namespace___110 {
	refcount_t count;
	struct ns_common___4 ns;
	struct user_namespace___114 *user_ns;
	struct ucounts___114 *ucounts;
	struct css_set___110 *root_cset;
};

struct ucounts___114 {
	struct hlist_node node;
	struct user_namespace___114 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___110;

struct bpf_map_ops___110 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___110 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___110 *, struct file___134 *);
	void (*map_free)(struct bpf_map___110 *);
	int (*map_get_next_key)(struct bpf_map___110 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___110 *);
	void * (*map_lookup_elem)(struct bpf_map___110 *, void *);
	int (*map_update_elem)(struct bpf_map___110 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___110 *, void *);
	int (*map_push_elem)(struct bpf_map___110 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___110 *, void *);
	int (*map_peek_elem)(struct bpf_map___110 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___110 *, struct file___134 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___110 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___110 *, void *, struct seq_file___124 *);
	int (*map_check_btf)(const struct bpf_map___110 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___110 {
	const struct bpf_map_ops___110 *ops;
	struct bpf_map___110 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___129 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___110;

typedef void (*kthread_work_func_t___110)(struct kthread_work___110 *);

struct kthread_worker___110;

struct kthread_work___110 {
	struct list_head node;
	kthread_work_func_t___110 func;
	struct kthread_worker___110 *worker;
	int canceling;
};

struct kthread_worker___110 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___134 *task;
	struct kthread_work___110 *current_work;
};

struct kthread_delayed_work___110 {
	struct kthread_work___110 work;
	struct timer_list timer;
};

struct psi_group___110 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___110 *poll_kworker;
	struct kthread_delayed_work___110 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___110;

struct cgroup_rstat_cpu___110;

struct cgroup___110 {
	struct cgroup_subsys_state___110 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___130 *kn;
	struct cgroup_file___110 procs_file;
	struct cgroup_file___110 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___110 *subsys[13];
	struct cgroup_root___110 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___110 *dom_cgrp;
	struct cgroup_rstat_cpu___110 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___4 bpf;
	atomic_t congestion_count;
	struct cgroup___110 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___110 psi;
	int ancestor_ids[0];
};

struct cftype___110;

struct cgroup_subsys___110 {
	struct cgroup_subsys_state___110 * (*css_alloc)(struct cgroup_subsys_state___110 *);
	int (*css_online)(struct cgroup_subsys_state___110 *);
	void (*css_offline)(struct cgroup_subsys_state___110 *);
	void (*css_released)(struct cgroup_subsys_state___110 *);
	void (*css_free)(struct cgroup_subsys_state___110 *);
	void (*css_reset)(struct cgroup_subsys_state___110 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___110 *, int);
	int (*css_extra_stat_show)(struct seq_file___124 *, struct cgroup_subsys_state___110 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___134 *);
	void (*cancel_fork)(struct task_struct___134 *);
	void (*fork)(struct task_struct___134 *);
	void (*exit)(struct task_struct___134 *);
	void (*free)(struct task_struct___134 *);
	void (*bind)(struct cgroup_subsys_state___110 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___110 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___110 *dfl_cftypes;
	struct cftype___110 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___110 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___110 *updated_children;
	struct cgroup___110 *updated_next;
};

struct cgroup_root___110 {
	struct kernfs_root___130 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___110 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___110 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___110 *ss;
	struct list_head node;
	struct kernfs_ops___130 *kf_ops;
	int (*open)(struct kernfs_open_file___130 *);
	void (*release)(struct kernfs_open_file___130 *);
	u64 (*read_u64)(struct cgroup_subsys_state___110 *, struct cftype___110 *);
	s64 (*read_s64)(struct cgroup_subsys_state___110 *, struct cftype___110 *);
	int (*seq_show)(struct seq_file___124 *, void *);
	void * (*seq_start)(struct seq_file___124 *, loff_t *);
	void * (*seq_next)(struct seq_file___124 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___124 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___110 *, struct cftype___110 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___110 *, struct cftype___110 *, s64);
	ssize_t (*write)(struct kernfs_open_file___130 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___130 *, struct poll_table_struct___91 *);
};

struct bdi_writeback_congested___55 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___55 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___55 {
	struct bio___55 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___55 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___55 bip_inline_vecs[0];
};

struct blkcg___17;

struct blkg_policy_data___17;

struct blkcg_gq___17 {
	struct request_queue___26 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___17 *blkcg;
	struct bdi_writeback_congested___55 *wb_congested;
	struct blkcg_gq___17 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_rwstat stat_bytes;
	struct blkg_rwstat stat_ios;
	struct blkg_policy_data___17 *pd[5];
	struct callback_head callback_head;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
};

enum mem_cgroup_protection {
	MEMCG_PROT_NONE = 0,
	MEMCG_PROT_LOW = 1,
	MEMCG_PROT_MIN = 2,
};

struct mem_cgroup_reclaim_cookie {
	pg_data_t___5 *pgdat;
	int priority;
	unsigned int generation;
};

struct mem_cgroup_reclaim_iter___50 {
	struct mem_cgroup___50 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___50 {
	struct lruvec___133 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___50 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___50 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct dev_pm_ops___125 {
	int (*prepare)(struct device___125 *);
	void (*complete)(struct device___125 *);
	int (*suspend)(struct device___125 *);
	int (*resume)(struct device___125 *);
	int (*freeze)(struct device___125 *);
	int (*thaw)(struct device___125 *);
	int (*poweroff)(struct device___125 *);
	int (*restore)(struct device___125 *);
	int (*suspend_late)(struct device___125 *);
	int (*resume_early)(struct device___125 *);
	int (*freeze_late)(struct device___125 *);
	int (*thaw_early)(struct device___125 *);
	int (*poweroff_late)(struct device___125 *);
	int (*restore_early)(struct device___125 *);
	int (*suspend_noirq)(struct device___125 *);
	int (*resume_noirq)(struct device___125 *);
	int (*freeze_noirq)(struct device___125 *);
	int (*thaw_noirq)(struct device___125 *);
	int (*poweroff_noirq)(struct device___125 *);
	int (*restore_noirq)(struct device___125 *);
	int (*runtime_suspend)(struct device___125 *);
	int (*runtime_resume)(struct device___125 *);
	int (*runtime_idle)(struct device___125 *);
};

struct dev_pm_domain___125 {
	struct dev_pm_ops___125 ops;
	void (*detach)(struct device___125 *, bool);
	int (*activate)(struct device___125 *);
	void (*sync)(struct device___125 *);
	void (*dismiss)(struct device___125 *);
};

struct bus_type___125 {
	const char *name;
	const char *dev_name;
	struct device___125 *dev_root;
	const struct attribute_group___124 **bus_groups;
	const struct attribute_group___124 **dev_groups;
	const struct attribute_group___124 **drv_groups;
	int (*match)(struct device___125 *, struct device_driver___125 *);
	int (*uevent)(struct device___125 *, struct kobj_uevent_env *);
	int (*probe)(struct device___125 *);
	int (*remove)(struct device___125 *);
	void (*shutdown)(struct device___125 *);
	int (*online)(struct device___125 *);
	int (*offline)(struct device___125 *);
	int (*suspend)(struct device___125 *, pm_message_t);
	int (*resume)(struct device___125 *);
	int (*num_vf)(struct device___125 *);
	int (*dma_configure)(struct device___125 *);
	const struct dev_pm_ops___125 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___125 {
	const char *name;
	struct bus_type___125 *bus;
	struct module___114 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___125 *);
	int (*remove)(struct device___125 *);
	void (*shutdown)(struct device___125 *);
	int (*suspend)(struct device___125 *, pm_message_t);
	int (*resume)(struct device___125 *);
	const struct attribute_group___124 **groups;
	const struct dev_pm_ops___125 *pm;
	void (*coredump)(struct device___125 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___125 {
	const char *name;
	const struct attribute_group___124 **groups;
	int (*uevent)(struct device___125 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___125 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___125 *);
	const struct dev_pm_ops___125 *pm;
};

struct class___125 {
	const char *name;
	struct module___114 *owner;
	const struct attribute_group___124 **class_groups;
	const struct attribute_group___124 **dev_groups;
	struct kobject___128 *dev_kobj;
	int (*dev_uevent)(struct device___125 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___125 *, umode_t *);
	void (*class_release)(struct class___125 *);
	void (*dev_release)(struct device___125 *);
	int (*shutdown_pre)(struct device___125 *);
	const struct kobj_ns_type_operations___2 *ns_type;
	const void * (*namespace)(struct device___125 *);
	const struct dev_pm_ops___125 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct fwnode_operations___94;

struct fwnode_handle___94 {
	struct fwnode_handle___94 *secondary;
	const struct fwnode_operations___94 *ops;
};

struct node___104 {
	struct device___125 dev;
};

struct disk_part_tbl___26 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___26 *last_lookup;
	struct hd_struct___26 *part[0];
};

struct block_device_operations___26 {
	int (*open)(struct block_device___134 *, fmode_t);
	void (*release)(struct gendisk___26 *, fmode_t);
	int (*rw_page)(struct block_device___134 *, sector_t, struct page___134 *, unsigned int);
	int (*ioctl)(struct block_device___134 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___134 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___26 *, unsigned int);
	int (*media_changed)(struct gendisk___26 *);
	void (*unlock_native_capacity)(struct gendisk___26 *);
	int (*revalidate_disk)(struct gendisk___26 *);
	int (*getgeo)(struct block_device___134 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___134 *, long unsigned int);
	int (*report_zones)(struct gendisk___26 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___114 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___25 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___26 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___26 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___26 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___25(struct request___26 *, blk_status_t);

struct request___26 {
	struct request_queue___26 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___55 *bio;
	struct bio___55 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___55 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___26 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___25 *saved_end_io;
		} flush;
	};
	struct gendisk___26 *rq_disk;
	struct hd_struct___26 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___25 *end_io;
	void *end_io_data;
	struct request___26 *next_rq;
};

struct fwnode_reference_args___94;

struct fwnode_endpoint___94;

struct fwnode_operations___94 {
	struct fwnode_handle___94 * (*get)(struct fwnode_handle___94 *);
	void (*put)(struct fwnode_handle___94 *);
	bool (*device_is_available)(const struct fwnode_handle___94 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___94 *, const struct device___125 *);
	bool (*property_present)(const struct fwnode_handle___94 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___94 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___94 *, const char *, const char **, size_t);
	struct fwnode_handle___94 * (*get_parent)(const struct fwnode_handle___94 *);
	struct fwnode_handle___94 * (*get_next_child_node)(const struct fwnode_handle___94 *, struct fwnode_handle___94 *);
	struct fwnode_handle___94 * (*get_named_child_node)(const struct fwnode_handle___94 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___94 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___94 *);
	struct fwnode_handle___94 * (*graph_get_next_endpoint)(const struct fwnode_handle___94 *, struct fwnode_handle___94 *);
	struct fwnode_handle___94 * (*graph_get_remote_endpoint)(const struct fwnode_handle___94 *);
	struct fwnode_handle___94 * (*graph_get_port_parent)(struct fwnode_handle___94 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___94 *, struct fwnode_endpoint___94 *);
};

struct fwnode_endpoint___94 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___94 *local_fwnode;
};

struct fwnode_reference_args___94 {
	struct fwnode_handle___94 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct elevator_type___25;

struct elevator_mq_ops___25 {
	int (*init_sched)(struct request_queue___26 *, struct elevator_type___25 *);
	void (*exit_sched)(struct elevator_queue___25 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	bool (*allow_merge)(struct request_queue___26 *, struct request___26 *, struct bio___55 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx *, struct bio___55 *);
	int (*request_merge)(struct request_queue___26 *, struct request___26 **, struct bio___55 *);
	void (*request_merged)(struct request_queue___26 *, struct request___26 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___26 *, struct request___26 *, struct request___26 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___26 *, struct bio___55 *);
	void (*finish_request)(struct request___26 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___26 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___26 *, u64);
	void (*started_request)(struct request___26 *);
	void (*requeue_request)(struct request___26 *);
	struct request___26 * (*former_request)(struct request_queue___26 *, struct request___26 *);
	struct request___26 * (*next_request)(struct request_queue___26 *, struct request___26 *);
	void (*init_icq)(struct io_cq___26 *);
	void (*exit_icq)(struct io_cq___26 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___25;

struct elevator_type___25 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___25 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___25 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___114 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___25 {
	struct elevator_type___25 *type;
	void *elevator_data;
	struct kobject___128 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___25 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___25 *, char *);
	ssize_t (*store)(struct elevator_queue___25 *, const char *, size_t);
};

struct blkcg_policy_data___17;

struct blkcg___17 {
	struct cgroup_subsys_state___110 css;
	spinlock_t lock;
	struct xarray blkg_tree;
	struct blkcg_gq___17 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___17 *cpd[5];
	struct list_head all_blkcgs_node;
	struct list_head cgwb_list;
	refcount_t cgwb_refcnt;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct blkcg_policy_data___17 {
	struct blkcg___17 *blkcg;
	int plid;
};

struct blkg_policy_data___17 {
	struct blkcg_gq___17 *blkg;
	int plid;
};

enum ttu_flags {
	TTU_MIGRATION = 1,
	TTU_MUNLOCK = 2,
	TTU_SPLIT_HUGE_PMD = 4,
	TTU_IGNORE_MLOCK = 8,
	TTU_IGNORE_ACCESS = 16,
	TTU_IGNORE_HWPOISON = 32,
	TTU_BATCH_FLUSH = 64,
	TTU_RMAP_LOCKED = 128,
	TTU_SPLIT_FREEZE = 256,
};

struct pagevec___5 {
	unsigned char nr;
	bool percpu_pvec_drained;
	struct page___134 *pages[15];
};

struct hstate___15 {
	int next_nid_to_alloc;
	int next_nid_to_free;
	unsigned int order;
	long unsigned int mask;
	long unsigned int max_huge_pages;
	long unsigned int nr_huge_pages;
	long unsigned int free_huge_pages;
	long unsigned int resv_huge_pages;
	long unsigned int surplus_huge_pages;
	long unsigned int nr_overcommit_huge_pages;
	struct list_head hugepage_activelist;
	struct list_head hugepage_freelists[8];
	unsigned int nr_huge_pages_node[8];
	unsigned int free_huge_pages_node[8];
	unsigned int surplus_huge_pages_node[8];
	struct cftype___110 cgroup_files[5];
	char name[32];
};

struct perf_cpu_context___82;

struct pmu___82 {
	struct list_head entry;
	struct module___114 *module;
	struct device___125 *dev;
	const struct attribute_group___124 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___82 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___82 *);
	void (*pmu_disable)(struct pmu___82 *);
	int (*event_init)(struct perf_event___82 *);
	void (*event_mapped)(struct perf_event___82 *, struct mm_struct___133 *);
	void (*event_unmapped)(struct perf_event___82 *, struct mm_struct___133 *);
	int (*add)(struct perf_event___82 *, int);
	void (*del)(struct perf_event___82 *, int);
	void (*start)(struct perf_event___82 *, int);
	void (*stop)(struct perf_event___82 *, int);
	void (*read)(struct perf_event___82 *);
	void (*start_txn)(struct pmu___82 *, unsigned int);
	int (*commit_txn)(struct pmu___82 *);
	void (*cancel_txn)(struct pmu___82 *);
	int (*event_idx)(struct perf_event___82 *);
	void (*sched_task)(struct perf_event_context___82 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___82 *);
	int (*filter_match)(struct perf_event___82 *);
	int (*check_period)(struct perf_event___82 *, u64);
};

struct perf_cpu_context___82 {
	struct perf_event_context___82 ctx;
	struct perf_event_context___82 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___82 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___82 {
	struct cgroup_subsys_state___110 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___75 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___75 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___75 *);
	struct list_head * (*get_fields)(struct trace_event_call___75 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___75 *);
};

struct trace_event_file___36;

struct trace_event_buffer___28 {
	struct ring_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___36 *trace_file;
	void *entry;
	long unsigned int flags;
	int pc;
};

struct trace_event_file___36 {
	struct list_head list;
	struct trace_event_call___75 *event_call;
	struct event_filter *filter;
	struct dentry___134 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_mm_vmscan_kswapd_sleep {
	struct trace_entry ent;
	int nid;
	char __data[0];
};

struct trace_event_raw_mm_vmscan_kswapd_wake {
	struct trace_entry ent;
	int nid;
	int zid;
	int order;
	char __data[0];
};

struct trace_event_raw_mm_vmscan_wakeup_kswapd {
	struct trace_entry ent;
	int nid;
	int zid;
	int order;
	gfp_t gfp_flags;
	char __data[0];
};

struct trace_event_raw_mm_vmscan_direct_reclaim_begin_template {
	struct trace_entry ent;
	int order;
	int may_writepage;
	gfp_t gfp_flags;
	int classzone_idx;
	char __data[0];
};

struct trace_event_raw_mm_vmscan_direct_reclaim_end_template {
	struct trace_entry ent;
	long unsigned int nr_reclaimed;
	char __data[0];
};

struct trace_event_raw_mm_shrink_slab_start {
	struct trace_entry ent;
	struct shrinker___50 *shr;
	void *shrink;
	int nid;
	long int nr_objects_to_shrink;
	gfp_t gfp_flags;
	long unsigned int cache_items;
	long long unsigned int delta;
	long unsigned int total_scan;
	int priority;
	char __data[0];
};

struct trace_event_raw_mm_shrink_slab_end {
	struct trace_entry ent;
	struct shrinker___50 *shr;
	int nid;
	void *shrink;
	long int unused_scan;
	long int new_scan;
	int retval;
	long int total_scan;
	char __data[0];
};

struct trace_event_raw_mm_vmscan_lru_isolate {
	struct trace_entry ent;
	int classzone_idx;
	int order;
	long unsigned int nr_requested;
	long unsigned int nr_scanned;
	long unsigned int nr_skipped;
	long unsigned int nr_taken;
	isolate_mode_t isolate_mode;
	int lru;
	char __data[0];
};

struct trace_event_raw_mm_vmscan_writepage {
	struct trace_entry ent;
	long unsigned int pfn;
	int reclaim_flags;
	char __data[0];
};

struct trace_event_raw_mm_vmscan_lru_shrink_inactive {
	struct trace_entry ent;
	int nid;
	long unsigned int nr_scanned;
	long unsigned int nr_reclaimed;
	long unsigned int nr_dirty;
	long unsigned int nr_writeback;
	long unsigned int nr_congested;
	long unsigned int nr_immediate;
	long unsigned int nr_activate;
	long unsigned int nr_ref_keep;
	long unsigned int nr_unmap_fail;
	int priority;
	int reclaim_flags;
	char __data[0];
};

struct trace_event_raw_mm_vmscan_lru_shrink_active {
	struct trace_entry ent;
	int nid;
	long unsigned int nr_taken;
	long unsigned int nr_active;
	long unsigned int nr_deactivated;
	long unsigned int nr_referenced;
	int priority;
	int reclaim_flags;
	char __data[0];
};

struct trace_event_raw_mm_vmscan_inactive_list_is_low {
	struct trace_entry ent;
	int nid;
	int reclaim_idx;
	long unsigned int total_inactive;
	long unsigned int inactive;
	long unsigned int total_active;
	long unsigned int active;
	long unsigned int ratio;
	int reclaim_flags;
	char __data[0];
};

struct trace_event_data_offsets_mm_vmscan_kswapd_sleep {};

struct trace_event_data_offsets_mm_vmscan_kswapd_wake {};

struct trace_event_data_offsets_mm_vmscan_wakeup_kswapd {};

struct trace_event_data_offsets_mm_vmscan_direct_reclaim_begin_template {};

struct trace_event_data_offsets_mm_vmscan_direct_reclaim_end_template {};

struct trace_event_data_offsets_mm_shrink_slab_start {};

struct trace_event_data_offsets_mm_shrink_slab_end {};

struct trace_event_data_offsets_mm_vmscan_lru_isolate {};

struct trace_event_data_offsets_mm_vmscan_writepage {};

struct trace_event_data_offsets_mm_vmscan_lru_shrink_inactive {};

struct trace_event_data_offsets_mm_vmscan_lru_shrink_active {};

struct trace_event_data_offsets_mm_vmscan_inactive_list_is_low {};

struct scan_control {
	long unsigned int nr_to_reclaim;
	gfp_t gfp_mask;
	int order;
	nodemask_t *nodemask;
	struct mem_cgroup___50 *target_mem_cgroup;
	int priority;
	enum zone_type reclaim_idx;
	unsigned int may_writepage: 1;
	unsigned int may_unmap: 1;
	unsigned int may_swap: 1;
	unsigned int memcg_low_reclaim: 1;
	unsigned int memcg_low_skipped: 1;
	unsigned int hibernation_mode: 1;
	unsigned int compaction_ready: 1;
	long unsigned int nr_scanned;
	long unsigned int nr_reclaimed;
	struct {
		unsigned int dirty;
		unsigned int unqueued_dirty;
		unsigned int congested;
		unsigned int writeback;
		unsigned int immediate;
		unsigned int file_taken;
		unsigned int taken;
	} nr;
};

typedef enum {
	PAGE_KEEP = 0,
	PAGE_ACTIVATE = 1,
	PAGE_SUCCESS = 2,
	PAGE_CLEAN = 3,
} pageout_t;

enum page_references {
	PAGEREF_RECLAIM = 0,
	PAGEREF_RECLAIM_CLEAN = 1,
	PAGEREF_KEEP = 2,
	PAGEREF_ACTIVATE = 3,
};

enum scan_balance {
	SCAN_EQUAL = 0,
	SCAN_FRACT = 1,
	SCAN_ANON = 2,
	SCAN_FILE = 3,
};

struct module___115;

struct file___135;

struct kiocb___135;

struct iov_iter___60;

struct poll_table_struct___92;

struct vm_area_struct___135;

struct file_lock___135;

struct page___135;

struct pipe_inode_info___34;

struct seq_file___125;

struct file_operations___135 {
	struct module___115 *owner;
	loff_t (*llseek)(struct file___135 *, loff_t, int);
	ssize_t (*read)(struct file___135 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___135 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___135 *, struct iov_iter___60 *);
	ssize_t (*write_iter)(struct kiocb___135 *, struct iov_iter___60 *);
	int (*iopoll)(struct kiocb___135 *, bool);
	int (*iterate)(struct file___135 *, struct dir_context *);
	int (*iterate_shared)(struct file___135 *, struct dir_context *);
	__poll_t (*poll)(struct file___135 *, struct poll_table_struct___92 *);
	long int (*unlocked_ioctl)(struct file___135 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___135 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___135 *, struct vm_area_struct___135 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___2 *, struct file___135 *);
	int (*flush)(struct file___135 *, fl_owner_t);
	int (*release)(struct inode___2 *, struct file___135 *);
	int (*fsync)(struct file___135 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___135 *, int);
	int (*lock)(struct file___135 *, int, struct file_lock___135 *);
	ssize_t (*sendpage)(struct file___135 *, struct page___135 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___135 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___135 *, int, struct file_lock___135 *);
	ssize_t (*splice_write)(struct pipe_inode_info___34 *, struct file___135 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___135 *, loff_t *, struct pipe_inode_info___34 *, size_t, unsigned int);
	int (*setlease)(struct file___135 *, long int, struct file_lock___135 **, void **);
	long int (*fallocate)(struct file___135 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___125 *, struct file___135 *);
	ssize_t (*copy_file_range)(struct file___135 *, loff_t, struct file___135 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___135 *, loff_t, struct file___135 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___135 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___134 {
	u64 seqnum;
	struct vm_area_struct___135 *vmas[4];
};

struct page_frag___134 {
	struct page___135 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___83;

struct debug_info___83 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___83 *hbp_break[16];
	struct perf_event___83 *hbp_watch[16];
};

struct thread_struct___83 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___83 debug;
	long: 64;
};

struct mm_struct___134;

struct mem_cgroup___51;

struct pid___109;

struct cred___130;

struct nsproxy___127;

struct signal_struct___122;

struct bio_list___56;

struct backing_dev_info___56;

struct io_context___27;

struct css_set___111;

struct perf_event_context___83;

struct request_queue___27;

struct vm_struct___103;

struct task_struct___135 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___135 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___134 *mm;
	struct mm_struct___134 *active_mm;
	struct vmacache___134 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___135 *real_parent;
	struct task_struct___135 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___135 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___51 *active_memcg;
	long int rh_reserved2;
	struct pid___109 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___109 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___109 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___130 *ptracer_cred;
	const struct cred___130 *real_cred;
	const struct cred___130 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___127 *nsproxy;
	struct signal_struct___122 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___135 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___56 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___56 *backing_dev_info;
	struct io_context___27 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___111 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___83 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___34 *splice_pipe;
	struct page_frag___134 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___51 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___27 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___135 *oom_reaper_list;
	struct vm_struct___103 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___83 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___83 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___135 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___83)(struct perf_event___83 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___83;

struct fasync_struct___134;

struct pid_namespace___109;

struct trace_event_call___76;

struct perf_cgroup___83;

struct perf_event___83 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___83 *group_leader;
	struct pmu___83 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___83 hw;
	struct perf_event_context___83 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___83 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___135 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___134 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___83 *);
	struct callback_head callback_head;
	struct pid_namespace___109 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___83 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___83 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___76 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___83 *cgrp;
	struct list_head sb_list;
};

struct dentry_operations___134;

struct dentry___2 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___2 *d_parent;
	struct qstr d_name;
	struct inode___2 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___134 *d_op;
	struct super_block___2 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct rw_semaphore___135 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___135 *owner;
};

struct address_space_operations___134;

struct address_space___134 {
	struct inode___2 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___135 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___134 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___134;

struct bdi_writeback___56;

struct block_device___135;

struct inode___2 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___134 *i_op;
	struct super_block___2 *i_sb;
	struct address_space___134 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___135 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___56 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___135 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___134 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___34 *i_pipe;
		struct block_device___135 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vfsmount___19;

struct path___134;

struct dentry_operations___134 {
	int (*d_revalidate)(struct dentry___2 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___2 *, unsigned int);
	int (*d_hash)(const struct dentry___2 *, struct qstr *);
	int (*d_compare)(const struct dentry___2 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___2 *);
	int (*d_init)(struct dentry___2 *);
	void (*d_release)(struct dentry___2 *);
	void (*d_prune)(struct dentry___2 *);
	void (*d_iput)(struct dentry___2 *, struct inode___2 *);
	char * (*d_dname)(struct dentry___2 *, char *, int);
	struct vfsmount___19 * (*d_automount)(struct path___134 *);
	int (*d_manage)(const struct path___134 *, bool);
	struct dentry___2 * (*d_real)(struct dentry___2 *, const struct inode___2 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___134;

struct mem_dqinfo___134 {
	struct quota_format_type___134 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___134;

struct quota_info___134 {
	unsigned int flags;
	struct rw_semaphore___135 dqio_sem;
	struct inode___2 *files[3];
	struct mem_dqinfo___134 info[3];
	const struct quota_format_ops___134 *ops[3];
};

struct rcuwait___134 {
	struct task_struct___135 *task;
};

struct percpu_rw_semaphore___134 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___135 rw_sem;
	struct rcuwait___134 writer;
	int readers_block;
};

struct sb_writers___134 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___134 rw_sem[3];
};

struct shrink_control___51;

struct shrinker___51 {
	long unsigned int (*count_objects)(struct shrinker___51 *, struct shrink_control___51 *);
	long unsigned int (*scan_objects)(struct shrinker___51 *, struct shrink_control___51 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___134;

struct super_operations___134;

struct dquot_operations___134;

struct quotactl_ops___134;

struct xattr_handler___7;

struct user_namespace___115;

struct super_block___2 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___134 *s_type;
	const struct super_operations___134 *s_op;
	const struct dquot_operations___134 *dq_op;
	const struct quotactl_ops___134 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___2 *s_root;
	struct rw_semaphore___135 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___7 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___135 *s_bdev;
	struct backing_dev_info___56 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___134 s_dquot;
	struct sb_writers___134 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___134 *s_d_op;
	int cleancache_poolid;
	struct shrinker___51 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___115 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___19 {
	struct dentry___2 *mnt_root;
	struct super_block___2 *mnt_sb;
	int mnt_flags;
};

struct path___134 {
	struct vfsmount___19 *mnt;
	struct dentry___2 *dentry;
};

struct key___130;

struct ucounts___115;

struct user_namespace___115 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___115 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___4 ns;
	long unsigned int flags;
	struct key___130 *persistent_keyring_register;
	struct rw_semaphore___135 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___115 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct shrink_control___51 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___51 *memcg;
};

struct cgroup___111;

struct cgroup_subsys___111;

struct cgroup_subsys_state___111 {
	struct cgroup___111 *cgroup;
	struct cgroup_subsys___111 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___111 *parent;
};

struct kernfs_node___131;

struct cgroup_file___111 {
	struct kernfs_node___131 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___51;

struct mem_cgroup___51 {
	struct cgroup_subsys_state___111 css;
	struct mem_cgroup_id___8 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___111 events_file;
	struct cgroup_file___111 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___135 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___51 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___135 *pgtable_t___134;

struct dev_pagemap___132;

struct page___135 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___134 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___135 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___134 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___134 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___132 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___51 *mem_cgroup;
};

struct pglist_data___134;

struct lruvec___134 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___134 *pgdat;
};

struct zone___134 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___134 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___134 {
	struct zone___134 *zone;
	int zone_idx;
};

struct zonelist___134 {
	struct zoneref___134 _zonerefs[25];
};

struct pglist_data___134 {
	struct zone___134 node_zones[3];
	struct zonelist___134 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___135 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___135 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___134 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

typedef struct pglist_data___134 pg_data_t___6;

struct secondary_data___135 {
	void *stack;
	struct task_struct___135 *task;
	long int status;
};

struct blocking_notifier_head___134 {
	struct rw_semaphore___135 rwsem;
	struct notifier_block *head;
};

struct upid___109 {
	int nr;
	struct pid_namespace___109 *ns;
};

struct pid_namespace___109 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___135 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___109 *parent;
	struct vfsmount___19 *proc_mnt;
	struct dentry___2 *proc_self;
	struct dentry___2 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___115 *user_ns;
	struct ucounts___115 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___4 ns;
};

struct pid___109 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___109 numbers[1];
};

struct anon_vma___8;

struct vm_operations_struct___132;

struct vm_area_struct___135 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___135 *vm_next;
	struct vm_area_struct___135 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___134 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma___8 *anon_vma;
	const struct vm_operations_struct___132 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___135 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___134;

struct mm_struct___134 {
	struct {
		struct vm_area_struct___135 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___135 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___135 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___134 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___135 *owner;
		struct user_namespace___115 *user_ns;
		struct file___135 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___134 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___132)(struct vm_area_struct___135 *, long unsigned int, const struct page___135 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___132)(struct page___135 *, void *);

struct device___126;

struct dev_pagemap___132 {
	dev_page_fault_t___132 page_fault;
	dev_page_free_t___132 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___126 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct fown_struct___109 {
	rwlock_t lock;
	struct pid___109 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___135 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___134 f_path;
	struct inode___2 *f_inode;
	const struct file_operations___135 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___109 f_owner;
	const struct cred___130 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___134 *f_mapping;
	errseq_t f_wb_err;
};

struct anon_vma___8 {
	struct anon_vma___8 *root;
	struct rw_semaphore___135 rwsem;
	atomic_t refcount;
	unsigned int degree;
	struct anon_vma___8 *parent;
	struct rb_root_cached rb_root;
};

struct vm_fault___132;

struct vm_operations_struct___132 {
	void (*open)(struct vm_area_struct___135 *);
	void (*close)(struct vm_area_struct___135 *);
	int (*split)(struct vm_area_struct___135 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___135 *);
	vm_fault_t (*fault)(struct vm_fault___132 *);
	vm_fault_t (*huge_fault)(struct vm_fault___132 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___132 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___135 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___132 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___132 *);
	int (*access)(struct vm_area_struct___135 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___135 *);
	int (*set_policy)(struct vm_area_struct___135 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___135 *, long unsigned int);
	struct page___135 * (*find_special_page)(struct vm_area_struct___135 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___134 {
	struct task_struct___135 *task;
	struct core_thread___134 *next;
};

struct core_state___134 {
	atomic_t nr_threads;
	struct core_thread___134 dumper;
	struct completion startup;
};

struct vm_fault___132 {
	struct vm_area_struct___135 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___135 *cow_page;
	struct mem_cgroup___51 *memcg;
	struct page___135 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___134 prealloc_pte;
};

struct user_struct___130 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___130 *uid_keyring;
	struct key___130 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___130 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___130 *session_keyring;
	struct key___130 *process_keyring;
	struct key___130 *thread_keyring;
	struct key___130 *request_key_auth;
	void *security;
	struct user_struct___130 *user;
	struct user_namespace___115 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___111;

struct nsproxy___127 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___109 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___111 *cgroup_ns;
};

struct signal_struct___122 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___135 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___135 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___109 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___109 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___134 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___109 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___56;

struct bio_list___56 {
	struct bio___56 *head;
	struct bio___56 *tail;
};

struct bdi_writeback_congested___56;

struct bdi_writeback___56 {
	struct backing_dev_info___56 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___56 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___111 *memcg_css;
	struct cgroup_subsys_state___111 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___56 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___56 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___126 *dev;
	struct device___126 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___2 *debug_dir;
	struct dentry___2 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___27;

struct io_context___27 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___27 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___111 {
	struct cgroup_subsys_state___111 *subsys[13];
	refcount_t refcount;
	struct css_set___111 *dom_cset;
	struct cgroup___111 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___111 *mg_src_cgrp;
	struct cgroup___111 *mg_dst_cgrp;
	struct css_set___111 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___83 {
	struct pmu___83 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___135 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___83 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___34;

struct pipe_inode_info___34 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___135 *tmp_page;
	struct fasync_struct___134 *fasync_readers;
	struct fasync_struct___134 *fasync_writers;
	struct pipe_buffer___34 *bufs;
	struct user_struct___130 *user;
};

typedef blk_qc_t make_request_fn___26(struct request_queue___27 *, struct bio___56 *);

struct request___27;

typedef int dma_drain_needed_fn___26(struct request___27 *);

struct kset___128;

struct kobj_type___128;

struct kobject___129 {
	const char *name;
	struct list_head entry;
	struct kobject___129 *parent;
	struct kset___128 *kset;
	struct kobj_type___128 *ktype;
	struct kernfs_node___131 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___26;

struct bsg_class_device___26 {
	struct device___126 *class_dev;
	int minor;
	struct request_queue___27 *queue;
	const struct bsg_ops___26 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___56 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___56 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___26;

struct blkcg_gq___18;

struct request_queue___27 {
	struct list_head queue_head;
	struct request___27 *last_merge;
	struct elevator_queue___26 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___26 *make_request_fn;
	dma_drain_needed_fn___26 *dma_drain_needed;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___56 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___129 kobj;
	struct kobject___129 *mq_kobj;
	struct blk_integrity integrity;
	struct device___126 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___18 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	struct bsg_class_device___26 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___56 bio_split;
	struct dentry___2 *debugfs_dir;
	struct dentry___2 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___103 {
	struct vm_struct___103 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___135 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___122 {
	struct task_struct___135 task;
	long unsigned int stack[8192];
};

struct io_cq___27 {
	struct request_queue___27 *q;
	struct io_context___27 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___2 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___135 {
	struct file___135 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___135 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___2 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___135 *ia_file;
};

struct dquot___134 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___2 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___134 {
	int qf_fmt_id;
	const struct quota_format_ops___134 *qf_ops;
	struct module___115 *qf_owner;
	struct quota_format_type___134 *qf_next;
};

struct quota_format_ops___134 {
	int (*check_quota_file)(struct super_block___2 *, int);
	int (*read_file_info)(struct super_block___2 *, int);
	int (*write_file_info)(struct super_block___2 *, int);
	int (*free_file_info)(struct super_block___2 *, int);
	int (*read_dqblk)(struct dquot___134 *);
	int (*commit_dqblk)(struct dquot___134 *);
	int (*release_dqblk)(struct dquot___134 *);
	int (*get_next_id)(struct super_block___2 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___134 {
	int (*write_dquot)(struct dquot___134 *);
	struct dquot___134 * (*alloc_dquot)(struct super_block___2 *, int);
	void (*destroy_dquot)(struct dquot___134 *);
	int (*acquire_dquot)(struct dquot___134 *);
	int (*release_dquot)(struct dquot___134 *);
	int (*mark_dirty)(struct dquot___134 *);
	int (*write_info)(struct super_block___2 *, int);
	qsize_t * (*get_reserved_space)(struct inode___2 *);
	int (*get_projid)(struct inode___2 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___2 *, qsize_t *);
	int (*get_next_id)(struct super_block___2 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___134 {
	int (*quota_on)(struct super_block___2 *, int, int, const struct path___134 *);
	int (*quota_off)(struct super_block___2 *, int);
	int (*quota_enable)(struct super_block___2 *, unsigned int);
	int (*quota_disable)(struct super_block___2 *, unsigned int);
	int (*quota_sync)(struct super_block___2 *, int);
	int (*set_info)(struct super_block___2 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___2 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___2 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___2 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___2 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___2 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___112 {
	struct kobject___129 kobj;
	struct module___115 *mod;
	struct kobject___129 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___112 {
	struct module___115 *mod;
	struct latch_tree_node node;
};

struct module_layout___112 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___112 mtn;
};

struct module_attribute___112;

struct kernel_param___112;

struct module___115 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___112 mkobj;
	struct module_attribute___112 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___129 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___112 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___112 core_layout;
	struct module_layout___112 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___76 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide49;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide50;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___53;

struct swap_info_struct___37;

struct address_space_operations___134 {
	int (*writepage)(struct page___135 *, struct writeback_control___53 *);
	int (*readpage)(struct file___135 *, struct page___135 *);
	int (*writepages)(struct address_space___134 *, struct writeback_control___53 *);
	int (*set_page_dirty)(struct page___135 *);
	int (*readpages)(struct file___135 *, struct address_space___134 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___135 *, struct address_space___134 *, loff_t, unsigned int, unsigned int, struct page___135 **, void **);
	int (*write_end)(struct file___135 *, struct address_space___134 *, loff_t, unsigned int, unsigned int, struct page___135 *, void *);
	sector_t (*bmap)(struct address_space___134 *, sector_t);
	void (*invalidatepage)(struct page___135 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___135 *, gfp_t);
	void (*freepage)(struct page___135 *);
	ssize_t (*direct_IO)(struct kiocb___135 *, struct iov_iter___60 *);
	int (*migratepage)(struct address_space___134 *, struct page___135 *, struct page___135 *, enum migrate_mode);
	bool (*isolate_page)(struct page___135 *, isolate_mode_t);
	void (*putback_page)(struct page___135 *);
	int (*launder_page)(struct page___135 *);
	int (*is_partially_uptodate)(struct page___135 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___135 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___134 *, struct page___135 *);
	int (*swap_activate)(struct swap_info_struct___37 *, struct file___135 *, sector_t *);
	void (*swap_deactivate)(struct file___135 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___53 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___56 *wb;
	struct inode___2 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___56;

struct iov_iter___60 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___56 *bvec;
		struct pipe_inode_info___34 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct swap_info_struct___37 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___135 *bdev;
	struct file___135 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct hd_struct___27;

struct gendisk___27;

struct block_device___135 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___2 *bd_inode;
	struct super_block___2 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___135 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___27 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___27 *bd_disk;
	struct request_queue___27 *bd_queue;
	struct backing_dev_info___56 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___126 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___126 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___126;

struct bus_type___126;

struct device_driver___126;

struct dev_pm_domain___126;

struct fwnode_handle___95;

struct class___126;

struct attribute_group___125;

struct device___126 {
	struct device___126 *parent;
	struct device_private *p;
	struct kobject___129 kobj;
	const char *init_name;
	const struct device_type___126 *type;
	struct mutex mutex;
	struct bus_type___126 *bus;
	struct device_driver___126 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___126 power;
	struct dev_pm_domain___126 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___95 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___126 *class;
	const struct attribute_group___125 **groups;
	void (*release)(struct device___126 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___27 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___126 __dev;
	struct kobject___129 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___27;

struct block_device_operations___27;

struct gendisk___27 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___27 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___27 *part_tbl;
	struct hd_struct___27 part0;
	const struct block_device_operations___27 *fops;
	struct request_queue___27 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___135 lookup_sem;
	struct kobject___129 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___129 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___134 {
	struct dentry___2 * (*lookup)(struct inode___2 *, struct dentry___2 *, unsigned int);
	const char * (*get_link)(struct dentry___2 *, struct inode___2 *, struct delayed_call *);
	int (*permission)(struct inode___2 *, int);
	struct posix_acl * (*get_acl)(struct inode___2 *, int);
	int (*readlink)(struct dentry___2 *, char *, int);
	int (*create)(struct inode___2 *, struct dentry___2 *, umode_t, bool);
	int (*link)(struct dentry___2 *, struct inode___2 *, struct dentry___2 *);
	int (*unlink)(struct inode___2 *, struct dentry___2 *);
	int (*symlink)(struct inode___2 *, struct dentry___2 *, const char *);
	int (*mkdir)(struct inode___2 *, struct dentry___2 *, umode_t);
	int (*rmdir)(struct inode___2 *, struct dentry___2 *);
	int (*mknod)(struct inode___2 *, struct dentry___2 *, umode_t, dev_t);
	int (*rename)(struct inode___2 *, struct dentry___2 *, struct inode___2 *, struct dentry___2 *, unsigned int);
	int (*setattr)(struct dentry___2 *, struct iattr___2 *);
	int (*getattr)(const struct path___134 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___2 *, char *, size_t);
	int (*fiemap)(struct inode___2 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___2 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___2 *, struct dentry___2 *, struct file___135 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___2 *, struct dentry___2 *, umode_t);
	int (*set_acl)(struct inode___2 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___134 {
	void (*fl_copy_lock)(struct file_lock___135 *, struct file_lock___135 *);
	void (*fl_release_private)(struct file_lock___135 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___134;

struct file_lock___135 {
	struct file_lock___135 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___135 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___134 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___134 *fl_ops;
	const struct lock_manager_operations___134 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___134 {
	int (*lm_compare_owner)(struct file_lock___135 *, struct file_lock___135 *);
	long unsigned int (*lm_owner_key)(struct file_lock___135 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___135 *);
	int (*lm_grant)(struct file_lock___135 *, int);
	bool (*lm_break)(struct file_lock___135 *);
	int (*lm_change)(struct file_lock___135 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___135 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___134 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___134 *fa_next;
	struct file___135 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___134 {
	const char *name;
	int fs_flags;
	struct dentry___2 * (*mount)(struct file_system_type___134 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___2 *);
	struct module___115 *owner;
	struct file_system_type___134 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___134 {
	struct inode___2 * (*alloc_inode)(struct super_block___2 *);
	void (*destroy_inode)(struct inode___2 *);
	void (*dirty_inode)(struct inode___2 *, int);
	int (*write_inode)(struct inode___2 *, struct writeback_control___53 *);
	int (*drop_inode)(struct inode___2 *);
	void (*evict_inode)(struct inode___2 *);
	void (*put_super)(struct super_block___2 *);
	int (*sync_fs)(struct super_block___2 *, int);
	int (*freeze_super)(struct super_block___2 *);
	int (*freeze_fs)(struct super_block___2 *);
	int (*thaw_super)(struct super_block___2 *);
	int (*unfreeze_fs)(struct super_block___2 *);
	int (*statfs)(struct dentry___2 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___2 *, int *, char *);
	void (*umount_begin)(struct super_block___2 *);
	int (*show_options)(struct seq_file___125 *, struct dentry___2 *);
	int (*show_devname)(struct seq_file___125 *, struct dentry___2 *);
	int (*show_path)(struct seq_file___125 *, struct dentry___2 *);
	int (*show_stats)(struct seq_file___125 *, struct dentry___2 *);
	ssize_t (*quota_read)(struct super_block___2 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___2 *, int, const char *, size_t, loff_t);
	struct dquot___134 ** (*get_dquots)(struct inode___2 *);
	int (*bdev_try_to_free_page)(struct super_block___2 *, struct page___135 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___2 *, struct shrink_control___51 *);
	long int (*free_cached_objects)(struct super_block___2 *, struct shrink_control___51 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct xattr_handler___7 {
	const char *name;
	const char *prefix;
	int flags;
	bool (*list)(struct dentry___2 *);
	int (*get)(const struct xattr_handler___7 *, struct dentry___2 *, struct inode___2 *, const char *, void *, size_t);
	int (*set)(const struct xattr_handler___7 *, struct dentry___2 *, struct inode___2 *, const char *, const void *, size_t, int);
};

typedef void (*poll_queue_proc___91)(struct file___135 *, wait_queue_head_t *, struct poll_table_struct___92 *);

struct poll_table_struct___92 {
	poll_queue_proc___91 _qproc;
	__poll_t _key;
};

struct seq_operations___123;

struct seq_file___125 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___123 *op;
	int poll_event;
	const struct file___135 *file;
	void *private;
};

typedef void bio_end_io_t___56(struct bio___56 *);

struct bio_vec___56 {
	struct page___135 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___56;

struct bio___56 {
	struct bio___56 *bi_next;
	struct gendisk___27 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___56 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___18 *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___56 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___56 *bi_io_vec;
	struct bio_set___56 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___56 bi_inline_vecs[0];
};

enum transparent_hugepage_flag {
	TRANSPARENT_HUGEPAGE_FLAG = 0,
	TRANSPARENT_HUGEPAGE_REQ_MADV_FLAG = 1,
	TRANSPARENT_HUGEPAGE_DEFRAG_DIRECT_FLAG = 2,
	TRANSPARENT_HUGEPAGE_DEFRAG_KSWAPD_FLAG = 3,
	TRANSPARENT_HUGEPAGE_DEFRAG_KSWAPD_OR_MADV_FLAG = 4,
	TRANSPARENT_HUGEPAGE_DEFRAG_REQ_MADV_FLAG = 5,
	TRANSPARENT_HUGEPAGE_DEFRAG_KHUGEPAGED_FLAG = 6,
	TRANSPARENT_HUGEPAGE_USE_ZERO_PAGE_FLAG = 7,
};

struct kobj_attribute___129 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___129 *, struct kobj_attribute___129 *, char *);
	ssize_t (*store)(struct kobject___129 *, struct kobj_attribute___129 *, const char *, size_t);
};

typedef void compound_page_dtor___132(struct page___135 *);

typedef int (*key_restrict_link_func_t___130)(struct key___130 *, const struct key_type *, const union key_payload *, struct key___130 *);

struct key_restriction___130;

struct key___130 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___135 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___130 *restrict_link;
};

struct key_restriction___130 {
	key_restrict_link_func_t___130 check;
	struct key___130 *key;
	struct key_type *keytype;
};

struct seq_operations___123 {
	void * (*start)(struct seq_file___125 *, loff_t *);
	void (*stop)(struct seq_file___125 *, void *);
	void * (*next)(struct seq_file___125 *, void *, loff_t *);
	int (*show)(struct seq_file___125 *, void *);
};

struct kernfs_root___131;

struct kernfs_elem_dir___131 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___131 *root;
};

struct kernfs_syscall_ops___131;

struct kernfs_root___131 {
	struct kernfs_node___131 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___131 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___131 {
	struct kernfs_node___131 *target_kn;
};

struct kernfs_ops___131;

struct kernfs_elem_attr___131 {
	const struct kernfs_ops___131 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___131 *notify_next;
};

struct kernfs_node___131 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___131 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___131 dir;
		struct kernfs_elem_symlink___131 symlink;
		struct kernfs_elem_attr___131 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___131;

struct kernfs_ops___131 {
	int (*open)(struct kernfs_open_file___131 *);
	void (*release)(struct kernfs_open_file___131 *);
	int (*seq_show)(struct seq_file___125 *, void *);
	void * (*seq_start)(struct seq_file___125 *, loff_t *);
	void * (*seq_next)(struct seq_file___125 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___125 *, void *);
	ssize_t (*read)(struct kernfs_open_file___131 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___131 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___131 *, struct vm_area_struct___135 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___131 *, struct poll_table_struct___92 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___131 {
	int (*remount_fs)(struct kernfs_root___131 *, int *, char *);
	int (*show_options)(struct seq_file___125 *, struct kernfs_root___131 *);
	int (*mkdir)(struct kernfs_node___131 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___131 *);
	int (*rename)(struct kernfs_node___131 *, struct kernfs_node___131 *, const char *);
	int (*show_path)(struct seq_file___125 *, struct kernfs_node___131 *, struct kernfs_root___131 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___131 {
	struct kernfs_node___131 *kn;
	struct file___135 *file;
	struct seq_file___125 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___132 *vm_ops;
};

struct cgroup_namespace___111 {
	refcount_t count;
	struct ns_common___4 ns;
	struct user_namespace___115 *user_ns;
	struct ucounts___115 *ucounts;
	struct css_set___111 *root_cset;
};

struct ucounts___115 {
	struct hlist_node node;
	struct user_namespace___115 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___111;

struct bpf_map_ops___111 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___111 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___111 *, struct file___135 *);
	void (*map_free)(struct bpf_map___111 *);
	int (*map_get_next_key)(struct bpf_map___111 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___111 *);
	void * (*map_lookup_elem)(struct bpf_map___111 *, void *);
	int (*map_update_elem)(struct bpf_map___111 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___111 *, void *);
	int (*map_push_elem)(struct bpf_map___111 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___111 *, void *);
	int (*map_peek_elem)(struct bpf_map___111 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___111 *, struct file___135 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___111 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___111 *, void *, struct seq_file___125 *);
	int (*map_check_btf)(const struct bpf_map___111 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___111 {
	const struct bpf_map_ops___111 *ops;
	struct bpf_map___111 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___130 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___111;

typedef void (*kthread_work_func_t___111)(struct kthread_work___111 *);

struct kthread_worker___111;

struct kthread_work___111 {
	struct list_head node;
	kthread_work_func_t___111 func;
	struct kthread_worker___111 *worker;
	int canceling;
};

struct kthread_worker___111 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___135 *task;
	struct kthread_work___111 *current_work;
};

struct kthread_delayed_work___111 {
	struct kthread_work___111 work;
	struct timer_list timer;
};

struct psi_group___111 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___111 *poll_kworker;
	struct kthread_delayed_work___111 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___111;

struct cgroup_rstat_cpu___111;

struct cgroup___111 {
	struct cgroup_subsys_state___111 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___131 *kn;
	struct cgroup_file___111 procs_file;
	struct cgroup_file___111 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___111 *subsys[13];
	struct cgroup_root___111 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___111 *dom_cgrp;
	struct cgroup_rstat_cpu___111 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___4 bpf;
	atomic_t congestion_count;
	struct cgroup___111 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___111 psi;
	int ancestor_ids[0];
};

struct cftype___111;

struct cgroup_subsys___111 {
	struct cgroup_subsys_state___111 * (*css_alloc)(struct cgroup_subsys_state___111 *);
	int (*css_online)(struct cgroup_subsys_state___111 *);
	void (*css_offline)(struct cgroup_subsys_state___111 *);
	void (*css_released)(struct cgroup_subsys_state___111 *);
	void (*css_free)(struct cgroup_subsys_state___111 *);
	void (*css_reset)(struct cgroup_subsys_state___111 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___111 *, int);
	int (*css_extra_stat_show)(struct seq_file___125 *, struct cgroup_subsys_state___111 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___135 *);
	void (*cancel_fork)(struct task_struct___135 *);
	void (*fork)(struct task_struct___135 *);
	void (*exit)(struct task_struct___135 *);
	void (*free)(struct task_struct___135 *);
	void (*bind)(struct cgroup_subsys_state___111 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___111 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___111 *dfl_cftypes;
	struct cftype___111 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___111 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___111 *updated_children;
	struct cgroup___111 *updated_next;
};

struct cgroup_root___111 {
	struct kernfs_root___131 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___111 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___111 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___111 *ss;
	struct list_head node;
	struct kernfs_ops___131 *kf_ops;
	int (*open)(struct kernfs_open_file___131 *);
	void (*release)(struct kernfs_open_file___131 *);
	u64 (*read_u64)(struct cgroup_subsys_state___111 *, struct cftype___111 *);
	s64 (*read_s64)(struct cgroup_subsys_state___111 *, struct cftype___111 *);
	int (*seq_show)(struct seq_file___125 *, void *);
	void * (*seq_start)(struct seq_file___125 *, loff_t *);
	void * (*seq_next)(struct seq_file___125 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___125 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___111 *, struct cftype___111 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___111 *, struct cftype___111 *, s64);
	ssize_t (*write)(struct kernfs_open_file___131 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___131 *, struct poll_table_struct___92 *);
};

struct bdi_writeback_congested___56 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___56 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___56 {
	struct bio___56 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___56 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___56 bip_inline_vecs[0];
};

struct blkcg___18;

struct blkg_policy_data___18;

struct blkcg_gq___18 {
	struct request_queue___27 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___18 *blkcg;
	struct bdi_writeback_congested___56 *wb_congested;
	struct blkcg_gq___18 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_rwstat stat_bytes;
	struct blkg_rwstat stat_ios;
	struct blkg_policy_data___18 *pd[5];
	struct callback_head callback_head;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
};

struct mem_cgroup_reclaim_iter___51 {
	struct mem_cgroup___51 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___51 {
	struct lruvec___134 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___51 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___51 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct bin_attribute___125;

struct attribute_group___125 {
	const char *name;
	umode_t (*is_visible)(struct kobject___129 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___129 *, struct bin_attribute___125 *, int);
	struct attribute **attrs;
	struct bin_attribute___125 **bin_attrs;
};

struct bin_attribute___125 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___135 *, struct kobject___129 *, struct bin_attribute___125 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___135 *, struct kobject___129 *, struct bin_attribute___125 *, char *, loff_t, size_t);
	int (*mmap)(struct file___135 *, struct kobject___129 *, struct bin_attribute___125 *, struct vm_area_struct___135 *);
};

struct sysfs_ops___128 {
	ssize_t (*show)(struct kobject___129 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___129 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___128;

struct kset___128 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___129 kobj;
	const struct kset_uevent_ops___128 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___128 {
	void (*release)(struct kobject___129 *);
	const struct sysfs_ops___128 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___2 * (*child_ns_type)(struct kobject___129 *);
	const void * (*namespace)(struct kobject___129 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___128 {
	int (* const filter)(struct kset___128 *, struct kobject___129 *);
	const char * (* const name)(struct kset___128 *, struct kobject___129 *);
	int (* const uevent)(struct kset___128 *, struct kobject___129 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___126 {
	int (*prepare)(struct device___126 *);
	void (*complete)(struct device___126 *);
	int (*suspend)(struct device___126 *);
	int (*resume)(struct device___126 *);
	int (*freeze)(struct device___126 *);
	int (*thaw)(struct device___126 *);
	int (*poweroff)(struct device___126 *);
	int (*restore)(struct device___126 *);
	int (*suspend_late)(struct device___126 *);
	int (*resume_early)(struct device___126 *);
	int (*freeze_late)(struct device___126 *);
	int (*thaw_early)(struct device___126 *);
	int (*poweroff_late)(struct device___126 *);
	int (*restore_early)(struct device___126 *);
	int (*suspend_noirq)(struct device___126 *);
	int (*resume_noirq)(struct device___126 *);
	int (*freeze_noirq)(struct device___126 *);
	int (*thaw_noirq)(struct device___126 *);
	int (*poweroff_noirq)(struct device___126 *);
	int (*restore_noirq)(struct device___126 *);
	int (*runtime_suspend)(struct device___126 *);
	int (*runtime_resume)(struct device___126 *);
	int (*runtime_idle)(struct device___126 *);
};

struct dev_pm_domain___126 {
	struct dev_pm_ops___126 ops;
	void (*detach)(struct device___126 *, bool);
	int (*activate)(struct device___126 *);
	void (*sync)(struct device___126 *);
	void (*dismiss)(struct device___126 *);
};

struct bus_type___126 {
	const char *name;
	const char *dev_name;
	struct device___126 *dev_root;
	const struct attribute_group___125 **bus_groups;
	const struct attribute_group___125 **dev_groups;
	const struct attribute_group___125 **drv_groups;
	int (*match)(struct device___126 *, struct device_driver___126 *);
	int (*uevent)(struct device___126 *, struct kobj_uevent_env *);
	int (*probe)(struct device___126 *);
	int (*remove)(struct device___126 *);
	void (*shutdown)(struct device___126 *);
	int (*online)(struct device___126 *);
	int (*offline)(struct device___126 *);
	int (*suspend)(struct device___126 *, pm_message_t);
	int (*resume)(struct device___126 *);
	int (*num_vf)(struct device___126 *);
	int (*dma_configure)(struct device___126 *);
	const struct dev_pm_ops___126 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___126 {
	const char *name;
	struct bus_type___126 *bus;
	struct module___115 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___126 *);
	int (*remove)(struct device___126 *);
	void (*shutdown)(struct device___126 *);
	int (*suspend)(struct device___126 *, pm_message_t);
	int (*resume)(struct device___126 *);
	const struct attribute_group___125 **groups;
	const struct dev_pm_ops___126 *pm;
	void (*coredump)(struct device___126 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___126 {
	const char *name;
	const struct attribute_group___125 **groups;
	int (*uevent)(struct device___126 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___126 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___126 *);
	const struct dev_pm_ops___126 *pm;
};

struct class___126 {
	const char *name;
	struct module___115 *owner;
	const struct attribute_group___125 **class_groups;
	const struct attribute_group___125 **dev_groups;
	struct kobject___129 *dev_kobj;
	int (*dev_uevent)(struct device___126 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___126 *, umode_t *);
	void (*class_release)(struct class___126 *);
	void (*dev_release)(struct device___126 *);
	int (*shutdown_pre)(struct device___126 *);
	const struct kobj_ns_type_operations___2 *ns_type;
	const void * (*namespace)(struct device___126 *);
	const struct dev_pm_ops___126 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct fwnode_operations___95;

struct fwnode_handle___95 {
	struct fwnode_handle___95 *secondary;
	const struct fwnode_operations___95 *ops;
};

struct node___105 {
	struct device___126 dev;
};

enum {
	MPOL_DEFAULT = 0,
	MPOL_PREFERRED = 1,
	MPOL_BIND = 2,
	MPOL_INTERLEAVE = 3,
	MPOL_LOCAL = 4,
	MPOL_MAX = 5,
};

struct shared_policy {
	struct rb_root root;
	rwlock_t lock;
};

struct hstate___16 {
	int next_nid_to_alloc;
	int next_nid_to_free;
	unsigned int order;
	long unsigned int mask;
	long unsigned int max_huge_pages;
	long unsigned int nr_huge_pages;
	long unsigned int free_huge_pages;
	long unsigned int resv_huge_pages;
	long unsigned int surplus_huge_pages;
	long unsigned int nr_overcommit_huge_pages;
	struct list_head hugepage_activelist;
	struct list_head hugepage_freelists[8];
	unsigned int nr_huge_pages_node[8];
	unsigned int free_huge_pages_node[8];
	unsigned int surplus_huge_pages_node[8];
	struct cftype___111 cgroup_files[5];
	char name[32];
};

struct xattr {
	const char *name;
	void *value;
	size_t value_len;
};

struct simple_xattrs {
	struct list_head head;
	spinlock_t lock;
};

struct simple_xattr {
	struct list_head list;
	char *name;
	size_t size;
	char value[0];
};

enum fid_type {
	FILEID_ROOT = 0,
	FILEID_INO32_GEN = 1,
	FILEID_INO32_GEN_PARENT = 2,
	FILEID_BTRFS_WITHOUT_PARENT = 77,
	FILEID_BTRFS_WITH_PARENT = 78,
	FILEID_BTRFS_WITH_PARENT_ROOT = 79,
	FILEID_UDF_WITHOUT_PARENT = 81,
	FILEID_UDF_WITH_PARENT = 82,
	FILEID_NILFS_WITHOUT_PARENT = 97,
	FILEID_NILFS_WITH_PARENT = 98,
	FILEID_FAT_WITHOUT_PARENT = 113,
	FILEID_FAT_WITH_PARENT = 114,
	FILEID_LUSTRE = 151,
	FILEID_INVALID = 255,
};

struct disk_part_tbl___27 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___27 *last_lookup;
	struct hd_struct___27 *part[0];
};

struct block_device_operations___27 {
	int (*open)(struct block_device___135 *, fmode_t);
	void (*release)(struct gendisk___27 *, fmode_t);
	int (*rw_page)(struct block_device___135 *, sector_t, struct page___135 *, unsigned int);
	int (*ioctl)(struct block_device___135 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___135 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___27 *, unsigned int);
	int (*media_changed)(struct gendisk___27 *);
	void (*unlock_native_capacity)(struct gendisk___27 *);
	int (*revalidate_disk)(struct gendisk___27 *);
	int (*getgeo)(struct block_device___135 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___135 *, long unsigned int);
	int (*report_zones)(struct gendisk___27 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___115 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___26 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___27 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___27 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___27 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___26(struct request___27 *, blk_status_t);

struct request___27 {
	struct request_queue___27 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___56 *bio;
	struct bio___56 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___56 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___27 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___26 *saved_end_io;
		} flush;
	};
	struct gendisk___27 *rq_disk;
	struct hd_struct___27 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___26 *end_io;
	void *end_io_data;
	struct request___27 *next_rq;
};

struct fwnode_reference_args___95;

struct fwnode_endpoint___95;

struct fwnode_operations___95 {
	struct fwnode_handle___95 * (*get)(struct fwnode_handle___95 *);
	void (*put)(struct fwnode_handle___95 *);
	bool (*device_is_available)(const struct fwnode_handle___95 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___95 *, const struct device___126 *);
	bool (*property_present)(const struct fwnode_handle___95 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___95 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___95 *, const char *, const char **, size_t);
	struct fwnode_handle___95 * (*get_parent)(const struct fwnode_handle___95 *);
	struct fwnode_handle___95 * (*get_next_child_node)(const struct fwnode_handle___95 *, struct fwnode_handle___95 *);
	struct fwnode_handle___95 * (*get_named_child_node)(const struct fwnode_handle___95 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___95 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___95 *);
	struct fwnode_handle___95 * (*graph_get_next_endpoint)(const struct fwnode_handle___95 *, struct fwnode_handle___95 *);
	struct fwnode_handle___95 * (*graph_get_remote_endpoint)(const struct fwnode_handle___95 *);
	struct fwnode_handle___95 * (*graph_get_port_parent)(struct fwnode_handle___95 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___95 *, struct fwnode_endpoint___95 *);
};

struct fwnode_endpoint___95 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___95 *local_fwnode;
};

struct fwnode_reference_args___95 {
	struct fwnode_handle___95 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct elevator_type___26;

struct elevator_mq_ops___26 {
	int (*init_sched)(struct request_queue___27 *, struct elevator_type___26 *);
	void (*exit_sched)(struct elevator_queue___26 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	bool (*allow_merge)(struct request_queue___27 *, struct request___27 *, struct bio___56 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx *, struct bio___56 *);
	int (*request_merge)(struct request_queue___27 *, struct request___27 **, struct bio___56 *);
	void (*request_merged)(struct request_queue___27 *, struct request___27 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___27 *, struct request___27 *, struct request___27 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___27 *, struct bio___56 *);
	void (*finish_request)(struct request___27 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___27 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___27 *, u64);
	void (*started_request)(struct request___27 *);
	void (*requeue_request)(struct request___27 *);
	struct request___27 * (*former_request)(struct request_queue___27 *, struct request___27 *);
	struct request___27 * (*next_request)(struct request_queue___27 *, struct request___27 *);
	void (*init_icq)(struct io_cq___27 *);
	void (*exit_icq)(struct io_cq___27 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___26;

struct elevator_type___26 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___26 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___26 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___115 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___26 {
	struct elevator_type___26 *type;
	void *elevator_data;
	struct kobject___129 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___26 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___26 *, char *);
	ssize_t (*store)(struct elevator_queue___26 *, const char *, size_t);
};

struct blkcg_policy_data___18;

struct blkcg___18 {
	struct cgroup_subsys_state___111 css;
	spinlock_t lock;
	struct xarray blkg_tree;
	struct blkcg_gq___18 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___18 *cpd[5];
	struct list_head all_blkcgs_node;
	struct list_head cgwb_list;
	refcount_t cgwb_refcnt;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct blkcg_policy_data___18 {
	struct blkcg___18 *blkcg;
	int plid;
};

struct blkg_policy_data___18 {
	struct blkcg_gq___18 *blkg;
	int plid;
};

struct shmem_inode_info {
	spinlock_t lock;
	unsigned int seals;
	long unsigned int flags;
	long unsigned int alloced;
	long unsigned int swapped;
	struct list_head shrinklist;
	struct list_head swaplist;
	struct shared_policy policy;
	struct simple_xattrs xattrs;
	struct inode___2 vfs_inode;
};

struct shmem_sb_info {
	long unsigned int max_blocks;
	struct percpu_counter used_blocks;
	long unsigned int max_inodes;
	long unsigned int free_inodes;
	spinlock_t stat_lock;
	umode_t mode;
	unsigned char huge;
	kuid_t uid;
	kgid_t gid;
	struct mempolicy *mpol;
	spinlock_t shrinklist_lock;
	struct list_head shrinklist;
	long unsigned int shrinklist_len;
};

enum sgp_type {
	SGP_READ = 0,
	SGP_CACHE = 1,
	SGP_NOHUGE = 2,
	SGP_HUGE = 3,
	SGP_WRITE = 4,
	SGP_FALLOC = 5,
};

struct pagevec___6 {
	unsigned char nr;
	bool percpu_pvec_drained;
	struct page___135 *pages[15];
};

struct pipe_buf_operations___34;

struct pipe_buffer___34 {
	struct page___135 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___34 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___34 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___34 *, struct pipe_buffer___34 *);
	void (*release)(struct pipe_inode_info___34 *, struct pipe_buffer___34 *);
	int (*steal)(struct pipe_inode_info___34 *, struct pipe_buffer___34 *);
	union {
		bool (*get)(struct pipe_inode_info___34 *, struct pipe_buffer___34 *);
		struct {
			void (*get)(struct pipe_inode_info___34 *, struct pipe_buffer___34 *);
		} __UNIQUE_ID_rh_kabi_hide44;
		union {		};
	};
};

struct kernel_param_ops___112 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___112 *);
	int (*get)(char *, const struct kernel_param___112 *);
	void (*free)(void *);
};

struct kparam_array___112;

struct kernel_param___112 {
	const char *name;
	struct module___115 *mod;
	const struct kernel_param_ops___112 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___112 *arr;
	};
};

struct kparam_array___112 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___112 *ops;
	void *elem;
};

struct module_attribute___112 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___112 *, struct module_kobject___112 *, char *);
	ssize_t (*store)(struct module_attribute___112 *, struct module_kobject___112 *, const char *, size_t);
	void (*setup)(struct module___115 *, const char *);
	int (*test)(struct module___115 *);
	void (*free)(struct module___115 *);
};

struct trace_event_class___76;

struct trace_event_call___76 {
	struct list_head list;
	struct trace_event_class___76 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___4 *prog_array;
	int (*perf_perm)(struct trace_event_call___76 *, struct perf_event___83 *);
};

struct perf_cpu_context___83;

struct pmu___83 {
	struct list_head entry;
	struct module___115 *module;
	struct device___126 *dev;
	const struct attribute_group___125 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___83 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___83 *);
	void (*pmu_disable)(struct pmu___83 *);
	int (*event_init)(struct perf_event___83 *);
	void (*event_mapped)(struct perf_event___83 *, struct mm_struct___134 *);
	void (*event_unmapped)(struct perf_event___83 *, struct mm_struct___134 *);
	int (*add)(struct perf_event___83 *, int);
	void (*del)(struct perf_event___83 *, int);
	void (*start)(struct perf_event___83 *, int);
	void (*stop)(struct perf_event___83 *, int);
	void (*read)(struct perf_event___83 *);
	void (*start_txn)(struct pmu___83 *, unsigned int);
	int (*commit_txn)(struct pmu___83 *);
	void (*cancel_txn)(struct pmu___83 *);
	int (*event_idx)(struct perf_event___83 *);
	void (*sched_task)(struct perf_event_context___83 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___83 *);
	int (*filter_match)(struct perf_event___83 *);
	int (*check_period)(struct perf_event___83 *, u64);
};

struct perf_cpu_context___83 {
	struct perf_event_context___83 ctx;
	struct perf_event_context___83 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___83 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___83 {
	struct cgroup_subsys_state___111 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___76 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___76 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___76 *);
	struct list_head * (*get_fields)(struct trace_event_call___76 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___76 *);
};

struct shmem_falloc {
	wait_queue_head_t *waitq;
	long unsigned int start;
	long unsigned int next;
	long unsigned int nr_falloced;
	long unsigned int nr_unswapped;
};

struct contig_page_info {
	long unsigned int free_pages;
	long unsigned int free_blocks_total;
	long unsigned int free_blocks_suitable;
};

enum writeback_stat_item {
	NR_DIRTY_THRESHOLD = 0,
	NR_DIRTY_BG_THRESHOLD = 1,
	NR_VM_WRITEBACK_STAT_ITEMS = 2,
};

struct module___116;

struct file___136;

struct kiocb___136;

struct vm_area_struct___136;

struct inode___136;

struct file_lock___136;

struct page___136;

struct seq_file___126;

struct file_operations___136 {
	struct module___116 *owner;
	loff_t (*llseek)(struct file___136 *, loff_t, int);
	ssize_t (*read)(struct file___136 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___136 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___136 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___136 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___136 *, bool);
	int (*iterate)(struct file___136 *, struct dir_context *);
	int (*iterate_shared)(struct file___136 *, struct dir_context *);
	__poll_t (*poll)(struct file___136 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___136 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___136 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___136 *, struct vm_area_struct___136 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___136 *, struct file___136 *);
	int (*flush)(struct file___136 *, fl_owner_t);
	int (*release)(struct inode___136 *, struct file___136 *);
	int (*fsync)(struct file___136 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___136 *, int);
	int (*lock)(struct file___136 *, int, struct file_lock___136 *);
	ssize_t (*sendpage)(struct file___136 *, struct page___136 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___136 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___136 *, int, struct file_lock___136 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___136 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___136 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___136 *, long int, struct file_lock___136 **, void **);
	long int (*fallocate)(struct file___136 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___126 *, struct file___136 *);
	ssize_t (*copy_file_range)(struct file___136 *, loff_t, struct file___136 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___136 *, loff_t, struct file___136 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___136 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___135 {
	u64 seqnum;
	struct vm_area_struct___136 *vmas[4];
};

struct page_frag___135 {
	struct page___136 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___135;

struct mem_cgroup___52;

struct cred___131;

struct nsproxy___128;

struct bio_list___57;

struct backing_dev_info___57;

struct io_context___28;

struct css_set___112;

struct request_queue___28;

struct vm_struct___104;

struct task_struct___136 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___136 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___135 *mm;
	struct mm_struct___135 *active_mm;
	struct vmacache___135 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___136 *real_parent;
	struct task_struct___136 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___136 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___52 *active_memcg;
	long int rh_reserved2;
	struct pid___109 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___109 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___109 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___131 *ptracer_cred;
	const struct cred___131 *real_cred;
	const struct cred___131 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___128 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___136 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___57 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___57 *backing_dev_info;
	struct io_context___28 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___112 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___135 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___52 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___28 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___136 *oom_reaper_list;
	struct vm_struct___104 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___83 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___135;

struct super_block___135;

struct dentry___135 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___135 *d_parent;
	struct qstr d_name;
	struct inode___136 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___135 *d_op;
	struct super_block___135 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct rw_semaphore___136 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___136 *owner;
};

struct address_space_operations___135;

struct address_space___135 {
	struct inode___136 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___136 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___135 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___135;

struct bdi_writeback___57;

struct block_device___136;

struct inode___136 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___135 *i_op;
	struct super_block___135 *i_sb;
	struct address_space___135 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___136 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___57 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___136 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___135 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___136 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___135;

struct dentry_operations___135 {
	int (*d_revalidate)(struct dentry___135 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___135 *, unsigned int);
	int (*d_hash)(const struct dentry___135 *, struct qstr *);
	int (*d_compare)(const struct dentry___135 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___135 *);
	int (*d_init)(struct dentry___135 *);
	void (*d_release)(struct dentry___135 *);
	void (*d_prune)(struct dentry___135 *);
	void (*d_iput)(struct dentry___135 *, struct inode___136 *);
	char * (*d_dname)(struct dentry___135 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___135 *);
	int (*d_manage)(const struct path___135 *, bool);
	struct dentry___135 * (*d_real)(struct dentry___135 *, const struct inode___136 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___135;

struct mem_dqinfo___135 {
	struct quota_format_type___135 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___135;

struct quota_info___135 {
	unsigned int flags;
	struct rw_semaphore___136 dqio_sem;
	struct inode___136 *files[3];
	struct mem_dqinfo___135 info[3];
	const struct quota_format_ops___135 *ops[3];
};

struct rcuwait___135 {
	struct task_struct___136 *task;
};

struct percpu_rw_semaphore___135 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___136 rw_sem;
	struct rcuwait___135 writer;
	int readers_block;
};

struct sb_writers___135 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___135 rw_sem[3];
};

struct shrink_control___52;

struct shrinker___52 {
	long unsigned int (*count_objects)(struct shrinker___52 *, struct shrink_control___52 *);
	long unsigned int (*scan_objects)(struct shrinker___52 *, struct shrink_control___52 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___135;

struct super_operations___135;

struct dquot_operations___135;

struct quotactl_ops___135;

struct user_namespace___116;

struct super_block___135 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___135 *s_type;
	const struct super_operations___135 *s_op;
	const struct dquot_operations___135 *dq_op;
	const struct quotactl_ops___135 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___135 *s_root;
	struct rw_semaphore___136 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___136 *s_bdev;
	struct backing_dev_info___57 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___135 s_dquot;
	struct sb_writers___135 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___135 *s_d_op;
	int cleancache_poolid;
	struct shrinker___52 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___116 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct path___135 {
	struct vfsmount *mnt;
	struct dentry___135 *dentry;
};

struct key___131;

struct ucounts___116;

struct user_namespace___116 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___116 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___4 ns;
	long unsigned int flags;
	struct key___131 *persistent_keyring_register;
	struct rw_semaphore___136 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___116 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct shrink_control___52 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___52 *memcg;
};

struct cgroup___112;

struct cgroup_subsys___112;

struct cgroup_subsys_state___112 {
	struct cgroup___112 *cgroup;
	struct cgroup_subsys___112 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___112 *parent;
};

struct kernfs_node___132;

struct cgroup_file___112 {
	struct kernfs_node___132 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___52;

struct mem_cgroup___52 {
	struct cgroup_subsys_state___112 css;
	struct mem_cgroup_id___12 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___112 events_file;
	struct cgroup_file___112 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___136 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___52 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___136 *pgtable_t___135;

struct dev_pagemap___133;

struct page___136 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___135 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___136 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___135 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___135 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___133 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___52 *mem_cgroup;
};

struct pglist_data___135;

struct lruvec___135 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___135 *pgdat;
};

struct zone___135 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___135 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___135 {
	struct zone___135 *zone;
	int zone_idx;
};

struct zonelist___135 {
	struct zoneref___135 _zonerefs[25];
};

struct pglist_data___135 {
	struct zone___135 node_zones[3];
	struct zonelist___135 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___136 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___136 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___135 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___136 {
	void *stack;
	struct task_struct___136 *task;
	long int status;
};

struct blocking_notifier_head___135 {
	struct rw_semaphore___136 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___133;

struct vm_area_struct___136 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___136 *vm_next;
	struct vm_area_struct___136 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___135 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___133 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___136 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___135;

struct mm_struct___135 {
	struct {
		struct vm_area_struct___136 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___136 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___136 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___135 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___136 *owner;
		struct user_namespace___116 *user_ns;
		struct file___136 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___135 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___133)(struct vm_area_struct___136 *, long unsigned int, const struct page___136 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___133)(struct page___136 *, void *);

struct device___127;

struct dev_pagemap___133 {
	dev_page_fault_t___133 page_fault;
	dev_page_free_t___133 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___127 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct file___136 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___135 f_path;
	struct inode___136 *f_inode;
	const struct file_operations___136 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___109 f_owner;
	const struct cred___131 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___135 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___133;

struct vm_operations_struct___133 {
	void (*open)(struct vm_area_struct___136 *);
	void (*close)(struct vm_area_struct___136 *);
	int (*split)(struct vm_area_struct___136 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___136 *);
	vm_fault_t (*fault)(struct vm_fault___133 *);
	vm_fault_t (*huge_fault)(struct vm_fault___133 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___133 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___136 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___133 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___133 *);
	int (*access)(struct vm_area_struct___136 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___136 *);
	int (*set_policy)(struct vm_area_struct___136 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___136 *, long unsigned int);
	struct page___136 * (*find_special_page)(struct vm_area_struct___136 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___135 {
	struct task_struct___136 *task;
	struct core_thread___135 *next;
};

struct core_state___135 {
	atomic_t nr_threads;
	struct core_thread___135 dumper;
	struct completion startup;
};

struct vm_fault___133 {
	struct vm_area_struct___136 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___136 *cow_page;
	struct mem_cgroup___52 *memcg;
	struct page___136 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___135 prealloc_pte;
};

struct user_struct___131 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___131 *uid_keyring;
	struct key___131 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___131 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___131 *session_keyring;
	struct key___131 *process_keyring;
	struct key___131 *thread_keyring;
	struct key___131 *request_key_auth;
	void *security;
	struct user_struct___131 *user;
	struct user_namespace___116 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___112;

struct nsproxy___128 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___112 *cgroup_ns;
};

struct bio___57;

struct bio_list___57 {
	struct bio___57 *head;
	struct bio___57 *tail;
};

struct bdi_writeback_congested___57;

struct bdi_writeback___57 {
	struct backing_dev_info___57 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___57 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___112 *memcg_css;
	struct cgroup_subsys_state___112 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___57 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___57 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___127 *dev;
	struct device___127 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___135 *debug_dir;
	struct dentry___135 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___28;

struct io_context___28 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___28 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___112 {
	struct cgroup_subsys_state___112 *subsys[13];
	refcount_t refcount;
	struct css_set___112 *dom_cset;
	struct cgroup___112 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___112 *mg_src_cgrp;
	struct cgroup___112 *mg_dst_cgrp;
	struct css_set___112 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

typedef blk_qc_t make_request_fn___27(struct request_queue___28 *, struct bio___57 *);

struct request___28;

typedef int dma_drain_needed_fn___27(struct request___28 *);

struct kset___129;

struct kobj_type___129;

struct kobject___130 {
	const char *name;
	struct list_head entry;
	struct kobject___130 *parent;
	struct kset___129 *kset;
	struct kobj_type___129 *ktype;
	struct kernfs_node___132 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___27;

struct bsg_class_device___27 {
	struct device___127 *class_dev;
	int minor;
	struct request_queue___28 *queue;
	const struct bsg_ops___27 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___57 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___57 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___27;

struct blkcg_gq___19;

struct request_queue___28 {
	struct list_head queue_head;
	struct request___28 *last_merge;
	struct elevator_queue___27 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___27 *make_request_fn;
	dma_drain_needed_fn___27 *dma_drain_needed;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___57 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___130 kobj;
	struct kobject___130 *mq_kobj;
	struct blk_integrity integrity;
	struct device___127 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___19 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	struct bsg_class_device___27 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___57 bio_split;
	struct dentry___135 *debugfs_dir;
	struct dentry___135 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___104 {
	struct vm_struct___104 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___136 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct io_cq___28 {
	struct request_queue___28 *q;
	struct io_context___28 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___2 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___136 {
	struct file___136 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___136 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___135 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___136 *ia_file;
};

struct dquot___135 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___135 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___135 {
	int qf_fmt_id;
	const struct quota_format_ops___135 *qf_ops;
	struct module___116 *qf_owner;
	struct quota_format_type___135 *qf_next;
};

struct quota_format_ops___135 {
	int (*check_quota_file)(struct super_block___135 *, int);
	int (*read_file_info)(struct super_block___135 *, int);
	int (*write_file_info)(struct super_block___135 *, int);
	int (*free_file_info)(struct super_block___135 *, int);
	int (*read_dqblk)(struct dquot___135 *);
	int (*commit_dqblk)(struct dquot___135 *);
	int (*release_dqblk)(struct dquot___135 *);
	int (*get_next_id)(struct super_block___135 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___135 {
	int (*write_dquot)(struct dquot___135 *);
	struct dquot___135 * (*alloc_dquot)(struct super_block___135 *, int);
	void (*destroy_dquot)(struct dquot___135 *);
	int (*acquire_dquot)(struct dquot___135 *);
	int (*release_dquot)(struct dquot___135 *);
	int (*mark_dirty)(struct dquot___135 *);
	int (*write_info)(struct super_block___135 *, int);
	qsize_t * (*get_reserved_space)(struct inode___136 *);
	int (*get_projid)(struct inode___136 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___136 *, qsize_t *);
	int (*get_next_id)(struct super_block___135 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___135 {
	int (*quota_on)(struct super_block___135 *, int, int, const struct path___135 *);
	int (*quota_off)(struct super_block___135 *, int);
	int (*quota_enable)(struct super_block___135 *, unsigned int);
	int (*quota_disable)(struct super_block___135 *, unsigned int);
	int (*quota_sync)(struct super_block___135 *, int);
	int (*set_info)(struct super_block___135 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___135 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___135 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___135 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___135 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___135 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___113 {
	struct kobject___130 kobj;
	struct module___116 *mod;
	struct kobject___130 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___113 {
	struct module___116 *mod;
	struct latch_tree_node node;
};

struct module_layout___113 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___113 mtn;
};

struct module_attribute___113;

struct kernel_param___113;

struct module___116 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___113 mkobj;
	struct module_attribute___113 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___130 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___113 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___113 core_layout;
	struct module_layout___113 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide40;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide41;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___54;

struct address_space_operations___135 {
	int (*writepage)(struct page___136 *, struct writeback_control___54 *);
	int (*readpage)(struct file___136 *, struct page___136 *);
	int (*writepages)(struct address_space___135 *, struct writeback_control___54 *);
	int (*set_page_dirty)(struct page___136 *);
	int (*readpages)(struct file___136 *, struct address_space___135 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___136 *, struct address_space___135 *, loff_t, unsigned int, unsigned int, struct page___136 **, void **);
	int (*write_end)(struct file___136 *, struct address_space___135 *, loff_t, unsigned int, unsigned int, struct page___136 *, void *);
	sector_t (*bmap)(struct address_space___135 *, sector_t);
	void (*invalidatepage)(struct page___136 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___136 *, gfp_t);
	void (*freepage)(struct page___136 *);
	ssize_t (*direct_IO)(struct kiocb___136 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___135 *, struct page___136 *, struct page___136 *, enum migrate_mode);
	bool (*isolate_page)(struct page___136 *, isolate_mode_t);
	void (*putback_page)(struct page___136 *);
	int (*launder_page)(struct page___136 *);
	int (*is_partially_uptodate)(struct page___136 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___136 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___135 *, struct page___136 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___136 *, sector_t *);
	void (*swap_deactivate)(struct file___136 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___54 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___57 *wb;
	struct inode___136 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct hd_struct___28;

struct gendisk___28;

struct block_device___136 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___136 *bd_inode;
	struct super_block___135 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___136 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___28 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___28 *bd_disk;
	struct request_queue___28 *bd_queue;
	struct backing_dev_info___57 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___127 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___127 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___127;

struct bus_type___127;

struct device_driver___127;

struct dev_pm_domain___127;

struct fwnode_handle___96;

struct class___127;

struct attribute_group___126;

struct device___127 {
	struct device___127 *parent;
	struct device_private *p;
	struct kobject___130 kobj;
	const char *init_name;
	const struct device_type___127 *type;
	struct mutex mutex;
	struct bus_type___127 *bus;
	struct device_driver___127 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___127 power;
	struct dev_pm_domain___127 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___96 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___127 *class;
	const struct attribute_group___126 **groups;
	void (*release)(struct device___127 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___28 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___127 __dev;
	struct kobject___130 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___28;

struct block_device_operations___28;

struct gendisk___28 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___28 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___28 *part_tbl;
	struct hd_struct___28 part0;
	const struct block_device_operations___28 *fops;
	struct request_queue___28 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___136 lookup_sem;
	struct kobject___130 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___130 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___135 {
	struct dentry___135 * (*lookup)(struct inode___136 *, struct dentry___135 *, unsigned int);
	const char * (*get_link)(struct dentry___135 *, struct inode___136 *, struct delayed_call *);
	int (*permission)(struct inode___136 *, int);
	struct posix_acl * (*get_acl)(struct inode___136 *, int);
	int (*readlink)(struct dentry___135 *, char *, int);
	int (*create)(struct inode___136 *, struct dentry___135 *, umode_t, bool);
	int (*link)(struct dentry___135 *, struct inode___136 *, struct dentry___135 *);
	int (*unlink)(struct inode___136 *, struct dentry___135 *);
	int (*symlink)(struct inode___136 *, struct dentry___135 *, const char *);
	int (*mkdir)(struct inode___136 *, struct dentry___135 *, umode_t);
	int (*rmdir)(struct inode___136 *, struct dentry___135 *);
	int (*mknod)(struct inode___136 *, struct dentry___135 *, umode_t, dev_t);
	int (*rename)(struct inode___136 *, struct dentry___135 *, struct inode___136 *, struct dentry___135 *, unsigned int);
	int (*setattr)(struct dentry___135 *, struct iattr___135 *);
	int (*getattr)(const struct path___135 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___135 *, char *, size_t);
	int (*fiemap)(struct inode___136 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___136 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___136 *, struct dentry___135 *, struct file___136 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___136 *, struct dentry___135 *, umode_t);
	int (*set_acl)(struct inode___136 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___135 {
	void (*fl_copy_lock)(struct file_lock___136 *, struct file_lock___136 *);
	void (*fl_release_private)(struct file_lock___136 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___135;

struct lock_manager_operations___135;

struct file_lock___136 {
	struct file_lock___136 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___136 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___135 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___135 *fl_ops;
	const struct lock_manager_operations___135 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___135 {
	int (*lm_compare_owner)(struct file_lock___136 *, struct file_lock___136 *);
	long unsigned int (*lm_owner_key)(struct file_lock___136 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___136 *);
	int (*lm_grant)(struct file_lock___136 *, int);
	bool (*lm_break)(struct file_lock___136 *);
	int (*lm_change)(struct file_lock___136 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___136 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___135 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___135 *fa_next;
	struct file___136 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___135 {
	const char *name;
	int fs_flags;
	struct dentry___135 * (*mount)(struct file_system_type___135 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___135 *);
	struct module___116 *owner;
	struct file_system_type___135 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___135 {
	struct inode___136 * (*alloc_inode)(struct super_block___135 *);
	void (*destroy_inode)(struct inode___136 *);
	void (*dirty_inode)(struct inode___136 *, int);
	int (*write_inode)(struct inode___136 *, struct writeback_control___54 *);
	int (*drop_inode)(struct inode___136 *);
	void (*evict_inode)(struct inode___136 *);
	void (*put_super)(struct super_block___135 *);
	int (*sync_fs)(struct super_block___135 *, int);
	int (*freeze_super)(struct super_block___135 *);
	int (*freeze_fs)(struct super_block___135 *);
	int (*thaw_super)(struct super_block___135 *);
	int (*unfreeze_fs)(struct super_block___135 *);
	int (*statfs)(struct dentry___135 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___135 *, int *, char *);
	void (*umount_begin)(struct super_block___135 *);
	int (*show_options)(struct seq_file___126 *, struct dentry___135 *);
	int (*show_devname)(struct seq_file___126 *, struct dentry___135 *);
	int (*show_path)(struct seq_file___126 *, struct dentry___135 *);
	int (*show_stats)(struct seq_file___126 *, struct dentry___135 *);
	ssize_t (*quota_read)(struct super_block___135 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___135 *, int, const char *, size_t, loff_t);
	struct dquot___135 ** (*get_dquots)(struct inode___136 *);
	int (*bdev_try_to_free_page)(struct super_block___135 *, struct page___136 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___135 *, struct shrink_control___52 *);
	long int (*free_cached_objects)(struct super_block___135 *, struct shrink_control___52 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___124;

struct seq_file___126 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___124 *op;
	int poll_event;
	const struct file___136 *file;
	void *private;
};

typedef void bio_end_io_t___57(struct bio___57 *);

struct bio_vec___57 {
	struct page___136 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___57;

struct bio___57 {
	struct bio___57 *bi_next;
	struct gendisk___28 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___57 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___19 *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___57 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___57 *bi_io_vec;
	struct bio_set___57 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___57 bi_inline_vecs[0];
};

struct bio_integrity_payload___57 {
	struct bio___57 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___57 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___57 bip_inline_vecs[0];
};

struct blkcg___19;

struct blkg_policy_data___19;

struct blkcg_gq___19 {
	struct request_queue___28 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___19 *blkcg;
	struct bdi_writeback_congested___57 *wb_congested;
	struct blkcg_gq___19 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_rwstat stat_bytes;
	struct blkg_rwstat stat_ios;
	struct blkg_policy_data___19 *pd[5];
	struct callback_head callback_head;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
};

struct dev_pm_ops___127;

struct device_type___127 {
	const char *name;
	const struct attribute_group___126 **groups;
	int (*uevent)(struct device___127 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___127 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___127 *);
	const struct dev_pm_ops___127 *pm;
};

struct class___127 {
	const char *name;
	struct module___116 *owner;
	const struct attribute_group___126 **class_groups;
	const struct attribute_group___126 **dev_groups;
	struct kobject___130 *dev_kobj;
	int (*dev_uevent)(struct device___127 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___127 *, umode_t *);
	void (*class_release)(struct class___127 *);
	void (*dev_release)(struct device___127 *);
	int (*shutdown_pre)(struct device___127 *);
	const struct kobj_ns_type_operations___2 *ns_type;
	const void * (*namespace)(struct device___127 *);
	const struct dev_pm_ops___127 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct kernfs_root___132;

struct kernfs_elem_dir___132 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___132 *root;
};

struct kernfs_syscall_ops___132;

struct kernfs_root___132 {
	struct kernfs_node___132 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___132 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___132 {
	struct kernfs_node___132 *target_kn;
};

struct kernfs_ops___132;

struct kernfs_elem_attr___132 {
	const struct kernfs_ops___132 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___132 *notify_next;
};

struct kernfs_node___132 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___132 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___132 dir;
		struct kernfs_elem_symlink___132 symlink;
		struct kernfs_elem_attr___132 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___132;

struct kernfs_ops___132 {
	int (*open)(struct kernfs_open_file___132 *);
	void (*release)(struct kernfs_open_file___132 *);
	int (*seq_show)(struct seq_file___126 *, void *);
	void * (*seq_start)(struct seq_file___126 *, loff_t *);
	void * (*seq_next)(struct seq_file___126 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___126 *, void *);
	ssize_t (*read)(struct kernfs_open_file___132 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___132 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___132 *, struct vm_area_struct___136 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___132 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___132 {
	int (*remount_fs)(struct kernfs_root___132 *, int *, char *);
	int (*show_options)(struct seq_file___126 *, struct kernfs_root___132 *);
	int (*mkdir)(struct kernfs_node___132 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___132 *);
	int (*rename)(struct kernfs_node___132 *, struct kernfs_node___132 *, const char *);
	int (*show_path)(struct seq_file___126 *, struct kernfs_node___132 *, struct kernfs_root___132 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___132 {
	struct kernfs_node___132 *kn;
	struct file___136 *file;
	struct seq_file___126 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___133 *vm_ops;
};

struct bin_attribute___126;

struct attribute_group___126 {
	const char *name;
	umode_t (*is_visible)(struct kobject___130 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___130 *, struct bin_attribute___126 *, int);
	struct attribute **attrs;
	struct bin_attribute___126 **bin_attrs;
};

struct bin_attribute___126 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___136 *, struct kobject___130 *, struct bin_attribute___126 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___136 *, struct kobject___130 *, struct bin_attribute___126 *, char *, loff_t, size_t);
	int (*mmap)(struct file___136 *, struct kobject___130 *, struct bin_attribute___126 *, struct vm_area_struct___136 *);
};

struct sysfs_ops___129 {
	ssize_t (*show)(struct kobject___130 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___130 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___129;

struct kset___129 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___130 kobj;
	const struct kset_uevent_ops___129 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___129 {
	void (*release)(struct kobject___130 *);
	const struct sysfs_ops___129 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___2 * (*child_ns_type)(struct kobject___130 *);
	const void * (*namespace)(struct kobject___130 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___129 {
	int (* const filter)(struct kset___129 *, struct kobject___130 *);
	const char * (* const name)(struct kset___129 *, struct kobject___130 *);
	int (* const uevent)(struct kset___129 *, struct kobject___130 *, struct kobj_uevent_env *);
};

struct kobj_attribute___130 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___130 *, struct kobj_attribute___130 *, char *);
	ssize_t (*store)(struct kobject___130 *, struct kobj_attribute___130 *, const char *, size_t);
};

struct dev_pm_ops___127 {
	int (*prepare)(struct device___127 *);
	void (*complete)(struct device___127 *);
	int (*suspend)(struct device___127 *);
	int (*resume)(struct device___127 *);
	int (*freeze)(struct device___127 *);
	int (*thaw)(struct device___127 *);
	int (*poweroff)(struct device___127 *);
	int (*restore)(struct device___127 *);
	int (*suspend_late)(struct device___127 *);
	int (*resume_early)(struct device___127 *);
	int (*freeze_late)(struct device___127 *);
	int (*thaw_early)(struct device___127 *);
	int (*poweroff_late)(struct device___127 *);
	int (*restore_early)(struct device___127 *);
	int (*suspend_noirq)(struct device___127 *);
	int (*resume_noirq)(struct device___127 *);
	int (*freeze_noirq)(struct device___127 *);
	int (*thaw_noirq)(struct device___127 *);
	int (*poweroff_noirq)(struct device___127 *);
	int (*restore_noirq)(struct device___127 *);
	int (*runtime_suspend)(struct device___127 *);
	int (*runtime_resume)(struct device___127 *);
	int (*runtime_idle)(struct device___127 *);
};

struct dev_pm_domain___127 {
	struct dev_pm_ops___127 ops;
	void (*detach)(struct device___127 *, bool);
	int (*activate)(struct device___127 *);
	void (*sync)(struct device___127 *);
	void (*dismiss)(struct device___127 *);
};

struct bus_type___127 {
	const char *name;
	const char *dev_name;
	struct device___127 *dev_root;
	const struct attribute_group___126 **bus_groups;
	const struct attribute_group___126 **dev_groups;
	const struct attribute_group___126 **drv_groups;
	int (*match)(struct device___127 *, struct device_driver___127 *);
	int (*uevent)(struct device___127 *, struct kobj_uevent_env *);
	int (*probe)(struct device___127 *);
	int (*remove)(struct device___127 *);
	void (*shutdown)(struct device___127 *);
	int (*online)(struct device___127 *);
	int (*offline)(struct device___127 *);
	int (*suspend)(struct device___127 *, pm_message_t);
	int (*resume)(struct device___127 *);
	int (*num_vf)(struct device___127 *);
	int (*dma_configure)(struct device___127 *);
	const struct dev_pm_ops___127 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___127 {
	const char *name;
	struct bus_type___127 *bus;
	struct module___116 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___127 *);
	int (*remove)(struct device___127 *);
	void (*shutdown)(struct device___127 *);
	int (*suspend)(struct device___127 *, pm_message_t);
	int (*resume)(struct device___127 *);
	const struct attribute_group___126 **groups;
	const struct dev_pm_ops___127 *pm;
	void (*coredump)(struct device___127 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_attribute___8 {
	struct attribute attr;
	ssize_t (*show)(struct device___127 *, struct device_attribute___8 *, char *);
	ssize_t (*store)(struct device___127 *, struct device_attribute___8 *, const char *, size_t);
};

struct fwnode_operations___96;

struct fwnode_handle___96 {
	struct fwnode_handle___96 *secondary;
	const struct fwnode_operations___96 *ops;
};

struct disk_part_tbl___28 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___28 *last_lookup;
	struct hd_struct___28 *part[0];
};

struct block_device_operations___28 {
	int (*open)(struct block_device___136 *, fmode_t);
	void (*release)(struct gendisk___28 *, fmode_t);
	int (*rw_page)(struct block_device___136 *, sector_t, struct page___136 *, unsigned int);
	int (*ioctl)(struct block_device___136 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___136 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___28 *, unsigned int);
	int (*media_changed)(struct gendisk___28 *);
	void (*unlock_native_capacity)(struct gendisk___28 *);
	int (*revalidate_disk)(struct gendisk___28 *);
	int (*getgeo)(struct block_device___136 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___136 *, long unsigned int);
	int (*report_zones)(struct gendisk___28 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___116 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___133(struct page___136 *);

struct bdi_writeback_congested___57 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___57 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bsg_ops___27 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___28 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___28 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___28 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___27(struct request___28 *, blk_status_t);

struct request___28 {
	struct request_queue___28 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___57 *bio;
	struct bio___57 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___57 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___28 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___27 *saved_end_io;
		} flush;
	};
	struct gendisk___28 *rq_disk;
	struct hd_struct___28 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___27 *end_io;
	void *end_io_data;
	struct request___28 *next_rq;
};

struct fwnode_reference_args___96;

struct fwnode_endpoint___96;

struct fwnode_operations___96 {
	struct fwnode_handle___96 * (*get)(struct fwnode_handle___96 *);
	void (*put)(struct fwnode_handle___96 *);
	bool (*device_is_available)(const struct fwnode_handle___96 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___96 *, const struct device___127 *);
	bool (*property_present)(const struct fwnode_handle___96 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___96 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___96 *, const char *, const char **, size_t);
	struct fwnode_handle___96 * (*get_parent)(const struct fwnode_handle___96 *);
	struct fwnode_handle___96 * (*get_next_child_node)(const struct fwnode_handle___96 *, struct fwnode_handle___96 *);
	struct fwnode_handle___96 * (*get_named_child_node)(const struct fwnode_handle___96 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___96 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___96 *);
	struct fwnode_handle___96 * (*graph_get_next_endpoint)(const struct fwnode_handle___96 *, struct fwnode_handle___96 *);
	struct fwnode_handle___96 * (*graph_get_remote_endpoint)(const struct fwnode_handle___96 *);
	struct fwnode_handle___96 * (*graph_get_port_parent)(struct fwnode_handle___96 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___96 *, struct fwnode_endpoint___96 *);
};

struct fwnode_endpoint___96 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___96 *local_fwnode;
};

struct fwnode_reference_args___96 {
	struct fwnode_handle___96 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct elevator_type___27;

struct elevator_mq_ops___27 {
	int (*init_sched)(struct request_queue___28 *, struct elevator_type___27 *);
	void (*exit_sched)(struct elevator_queue___27 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	bool (*allow_merge)(struct request_queue___28 *, struct request___28 *, struct bio___57 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx *, struct bio___57 *);
	int (*request_merge)(struct request_queue___28 *, struct request___28 **, struct bio___57 *);
	void (*request_merged)(struct request_queue___28 *, struct request___28 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___28 *, struct request___28 *, struct request___28 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___28 *, struct bio___57 *);
	void (*finish_request)(struct request___28 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___28 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___28 *, u64);
	void (*started_request)(struct request___28 *);
	void (*requeue_request)(struct request___28 *);
	struct request___28 * (*former_request)(struct request_queue___28 *, struct request___28 *);
	struct request___28 * (*next_request)(struct request_queue___28 *, struct request___28 *);
	void (*init_icq)(struct io_cq___28 *);
	void (*exit_icq)(struct io_cq___28 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___27;

struct elevator_type___27 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___27 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___27 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___116 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___27 {
	struct elevator_type___27 *type;
	void *elevator_data;
	struct kobject___130 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___27 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___27 *, char *);
	ssize_t (*store)(struct elevator_queue___27 *, const char *, size_t);
};

typedef int (*key_restrict_link_func_t___131)(struct key___131 *, const struct key_type *, const union key_payload *, struct key___131 *);

struct key_restriction___131;

struct key___131 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___136 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___131 *restrict_link;
};

struct key_restriction___131 {
	key_restrict_link_func_t___131 check;
	struct key___131 *key;
	struct key_type *keytype;
};

struct seq_operations___124 {
	void * (*start)(struct seq_file___126 *, loff_t *);
	void (*stop)(struct seq_file___126 *, void *);
	void * (*next)(struct seq_file___126 *, void *, loff_t *);
	int (*show)(struct seq_file___126 *, void *);
};

struct cgroup_namespace___112 {
	refcount_t count;
	struct ns_common___4 ns;
	struct user_namespace___116 *user_ns;
	struct ucounts___116 *ucounts;
	struct css_set___112 *root_cset;
};

struct ucounts___116 {
	struct hlist_node node;
	struct user_namespace___116 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___112;

struct bpf_map_ops___112 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___112 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___112 *, struct file___136 *);
	void (*map_free)(struct bpf_map___112 *);
	int (*map_get_next_key)(struct bpf_map___112 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___112 *);
	void * (*map_lookup_elem)(struct bpf_map___112 *, void *);
	int (*map_update_elem)(struct bpf_map___112 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___112 *, void *);
	int (*map_push_elem)(struct bpf_map___112 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___112 *, void *);
	int (*map_peek_elem)(struct bpf_map___112 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___112 *, struct file___136 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___112 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___112 *, void *, struct seq_file___126 *);
	int (*map_check_btf)(const struct bpf_map___112 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___112 {
	const struct bpf_map_ops___112 *ops;
	struct bpf_map___112 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___131 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___112;

typedef void (*kthread_work_func_t___112)(struct kthread_work___112 *);

struct kthread_worker___112;

struct kthread_work___112 {
	struct list_head node;
	kthread_work_func_t___112 func;
	struct kthread_worker___112 *worker;
	int canceling;
};

struct kthread_worker___112 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___136 *task;
	struct kthread_work___112 *current_work;
};

struct kthread_delayed_work___112 {
	struct kthread_work___112 work;
	struct timer_list timer;
};

struct psi_group___112 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___112 *poll_kworker;
	struct kthread_delayed_work___112 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___112;

struct cgroup_rstat_cpu___112;

struct cgroup___112 {
	struct cgroup_subsys_state___112 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___132 *kn;
	struct cgroup_file___112 procs_file;
	struct cgroup_file___112 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___112 *subsys[13];
	struct cgroup_root___112 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___112 *dom_cgrp;
	struct cgroup_rstat_cpu___112 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___4 bpf;
	atomic_t congestion_count;
	struct cgroup___112 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___112 psi;
	int ancestor_ids[0];
};

struct cftype___112;

struct cgroup_subsys___112 {
	struct cgroup_subsys_state___112 * (*css_alloc)(struct cgroup_subsys_state___112 *);
	int (*css_online)(struct cgroup_subsys_state___112 *);
	void (*css_offline)(struct cgroup_subsys_state___112 *);
	void (*css_released)(struct cgroup_subsys_state___112 *);
	void (*css_free)(struct cgroup_subsys_state___112 *);
	void (*css_reset)(struct cgroup_subsys_state___112 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___112 *, int);
	int (*css_extra_stat_show)(struct seq_file___126 *, struct cgroup_subsys_state___112 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___136 *);
	void (*cancel_fork)(struct task_struct___136 *);
	void (*fork)(struct task_struct___136 *);
	void (*exit)(struct task_struct___136 *);
	void (*free)(struct task_struct___136 *);
	void (*bind)(struct cgroup_subsys_state___112 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___112 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___112 *dfl_cftypes;
	struct cftype___112 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___112 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___112 *updated_children;
	struct cgroup___112 *updated_next;
};

struct cgroup_root___112 {
	struct kernfs_root___132 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___112 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___112 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___112 *ss;
	struct list_head node;
	struct kernfs_ops___132 *kf_ops;
	int (*open)(struct kernfs_open_file___132 *);
	void (*release)(struct kernfs_open_file___132 *);
	u64 (*read_u64)(struct cgroup_subsys_state___112 *, struct cftype___112 *);
	s64 (*read_s64)(struct cgroup_subsys_state___112 *, struct cftype___112 *);
	int (*seq_show)(struct seq_file___126 *, void *);
	void * (*seq_start)(struct seq_file___126 *, loff_t *);
	void * (*seq_next)(struct seq_file___126 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___126 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___112 *, struct cftype___112 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___112 *, struct cftype___112 *, s64);
	ssize_t (*write)(struct kernfs_open_file___132 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___132 *, struct poll_table_struct___6 *);
};

struct blkcg_policy_data___19;

struct blkcg___19 {
	struct cgroup_subsys_state___112 css;
	spinlock_t lock;
	struct xarray blkg_tree;
	struct blkcg_gq___19 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___19 *cpd[5];
	struct list_head all_blkcgs_node;
	struct list_head cgwb_list;
	refcount_t cgwb_refcnt;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct blkcg_policy_data___19 {
	struct blkcg___19 *blkcg;
	int plid;
};

struct blkg_policy_data___19 {
	struct blkcg_gq___19 *blkg;
	int plid;
};

struct kernel_param_ops___113 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___113 *);
	int (*get)(char *, const struct kernel_param___113 *);
	void (*free)(void *);
};

struct kparam_array___113;

struct kernel_param___113 {
	const char *name;
	struct module___116 *mod;
	const struct kernel_param_ops___113 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___113 *arr;
	};
};

struct kparam_array___113 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___113 *ops;
	void *elem;
};

struct module_attribute___113 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___113 *, struct module_kobject___113 *, char *);
	ssize_t (*store)(struct module_attribute___113 *, struct module_kobject___113 *, const char *, size_t);
	void (*setup)(struct module___116 *, const char *);
	int (*test)(struct module___116 *);
	void (*free)(struct module___116 *);
};

struct mem_cgroup_reclaim_iter___52 {
	struct mem_cgroup___52 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___52 {
	struct lruvec___135 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___52 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___52 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

typedef struct pglist_data___55 pg_data_t___7;

struct module___117;

struct file___137;

struct kiocb___137;

struct poll_table_struct___93;

struct vm_area_struct___137;

struct inode___137;

struct file_lock___137;

struct page___137;

struct seq_file___127;

struct file_operations___137 {
	struct module___117 *owner;
	loff_t (*llseek)(struct file___137 *, loff_t, int);
	ssize_t (*read)(struct file___137 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___137 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___137 *, struct iov_iter___60 *);
	ssize_t (*write_iter)(struct kiocb___137 *, struct iov_iter___60 *);
	int (*iopoll)(struct kiocb___137 *, bool);
	int (*iterate)(struct file___137 *, struct dir_context *);
	int (*iterate_shared)(struct file___137 *, struct dir_context *);
	__poll_t (*poll)(struct file___137 *, struct poll_table_struct___93 *);
	long int (*unlocked_ioctl)(struct file___137 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___137 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___137 *, struct vm_area_struct___137 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___137 *, struct file___137 *);
	int (*flush)(struct file___137 *, fl_owner_t);
	int (*release)(struct inode___137 *, struct file___137 *);
	int (*fsync)(struct file___137 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___137 *, int);
	int (*lock)(struct file___137 *, int, struct file_lock___137 *);
	ssize_t (*sendpage)(struct file___137 *, struct page___137 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___137 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___137 *, int, struct file_lock___137 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___137 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___137 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___137 *, long int, struct file_lock___137 **, void **);
	long int (*fallocate)(struct file___137 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___127 *, struct file___137 *);
	ssize_t (*copy_file_range)(struct file___137 *, loff_t, struct file___137 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___137 *, loff_t, struct file___137 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___137 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___136 {
	u64 seqnum;
	struct vm_area_struct___137 *vmas[4];
};

struct page_frag___136 {
	struct page___137 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___84;

struct debug_info___84 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___84 *hbp_break[16];
	struct perf_event___84 *hbp_watch[16];
};

struct thread_struct___84 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___84 debug;
	long: 64;
};

struct mm_struct___136;

struct pid___110;

struct cred___132;

struct nsproxy___129;

struct signal_struct___123;

struct css_set___113;

struct perf_event_context___84;

struct vm_struct___105;

struct task_struct___137 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___137 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___136 *mm;
	struct mm_struct___136 *active_mm;
	struct vmacache___136 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___137 *real_parent;
	struct task_struct___137 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___137 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___110 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___110 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___110 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___132 *ptracer_cred;
	const struct cred___132 *real_cred;
	const struct cred___132 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___129 *nsproxy;
	struct signal_struct___123 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___137 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___28 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___113 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___84 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___136 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___137 *oom_reaper_list;
	struct vm_struct___105 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___84 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___84 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___137 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___84)(struct perf_event___84 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___84;

struct fasync_struct___136;

struct pid_namespace___110;

struct trace_event_call___77;

struct perf_cgroup___84;

struct perf_event___84 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___84 *group_leader;
	struct pmu___84 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___84 hw;
	struct perf_event_context___84 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___84 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___137 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___136 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___84 *);
	struct callback_head callback_head;
	struct pid_namespace___110 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___84 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___84 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___77 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___84 *cgrp;
	struct list_head sb_list;
};

typedef struct page___137 *pgtable_t___136;

struct address_space___136;

struct dev_pagemap___134;

struct page___137 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___136 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___137 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___136 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___136 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___134 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___136;

struct lruvec___136 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___136 *pgdat;
};

struct zone___136 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___136 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___136 {
	struct zone___136 *zone;
	int zone_idx;
};

struct zonelist___136 {
	struct zoneref___136 _zonerefs[25];
};

struct pglist_data___136 {
	struct zone___136 node_zones[3];
	struct zonelist___136 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___137 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___137 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___136 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___137 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___137 *owner;
};

struct secondary_data___137 {
	void *stack;
	struct task_struct___137 *task;
	long int status;
};

struct blocking_notifier_head___136 {
	struct rw_semaphore___137 rwsem;
	struct notifier_block *head;
};

struct pcpu_group_info {
	int nr_units;
	long unsigned int base_offset;
	unsigned int *cpu_map;
};

struct pcpu_alloc_info {
	size_t static_size;
	size_t reserved_size;
	size_t dyn_size;
	size_t unit_size;
	size_t atom_size;
	size_t alloc_size;
	size_t __ai_size;
	int nr_groups;
	struct pcpu_group_info groups[0];
};

typedef void * (*pcpu_fc_alloc_fn_t)(unsigned int, size_t, size_t);

typedef void (*pcpu_fc_free_fn_t)(void *, size_t);

typedef int pcpu_fc_cpu_distance_fn_t(unsigned int, unsigned int);

struct vm_operations_struct___134;

struct vm_area_struct___137 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___137 *vm_next;
	struct vm_area_struct___137 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___136 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___134 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___137 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___136;

struct user_namespace___117;

struct mm_struct___136 {
	struct {
		struct vm_area_struct___137 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___137 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___137 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___136 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___137 *owner;
		struct user_namespace___117 *user_ns;
		struct file___137 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___136 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___136;

struct address_space___136 {
	struct inode___137 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___137 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___136 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___134)(struct vm_area_struct___137 *, long unsigned int, const struct page___137 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___134)(struct page___137 *, void *);

struct device___128;

struct dev_pagemap___134 {
	dev_page_fault_t___134 page_fault;
	dev_page_free_t___134 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___128 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct dentry___136;

struct path___136 {
	struct vfsmount *mnt;
	struct dentry___136 *dentry;
};

struct fown_struct___110 {
	rwlock_t lock;
	struct pid___110 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___137 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___136 f_path;
	struct inode___137 *f_inode;
	const struct file_operations___137 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___110 f_owner;
	const struct cred___132 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___136 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___134;

struct vm_operations_struct___134 {
	void (*open)(struct vm_area_struct___137 *);
	void (*close)(struct vm_area_struct___137 *);
	int (*split)(struct vm_area_struct___137 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___137 *);
	vm_fault_t (*fault)(struct vm_fault___134 *);
	vm_fault_t (*huge_fault)(struct vm_fault___134 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___134 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___137 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___134 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___134 *);
	int (*access)(struct vm_area_struct___137 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___137 *);
	int (*set_policy)(struct vm_area_struct___137 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___137 *, long unsigned int);
	struct page___137 * (*find_special_page)(struct vm_area_struct___137 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___136 {
	struct task_struct___137 *task;
	struct core_thread___136 *next;
};

struct core_state___136 {
	atomic_t nr_threads;
	struct core_thread___136 dumper;
	struct completion startup;
};

struct key___132;

struct ucounts___117;

struct user_namespace___117 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___117 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___4 ns;
	long unsigned int flags;
	struct key___132 *persistent_keyring_register;
	struct rw_semaphore___137 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___117 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___134 {
	struct vm_area_struct___137 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___137 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___137 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___136 prealloc_pte;
};

struct upid___110 {
	int nr;
	struct pid_namespace___110 *ns;
};

struct pid_namespace___110 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___137 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___110 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___136 *proc_self;
	struct dentry___136 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___117 *user_ns;
	struct ucounts___117 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___4 ns;
};

struct pid___110 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___110 numbers[1];
};

struct user_struct___132 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___132 *uid_keyring;
	struct key___132 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___132 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___132 *session_keyring;
	struct key___132 *process_keyring;
	struct key___132 *thread_keyring;
	struct key___132 *request_key_auth;
	void *security;
	struct user_struct___132 *user;
	struct user_namespace___117 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___113;

struct nsproxy___129 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___110 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___113 *cgroup_ns;
};

struct signal_struct___123 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___137 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___137 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___110 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___110 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___136 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___110 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___113;

struct cgroup___113;

struct css_set___113 {
	struct cgroup_subsys_state___113 *subsys[13];
	refcount_t refcount;
	struct css_set___113 *dom_cset;
	struct cgroup___113 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___113 *mg_src_cgrp;
	struct cgroup___113 *mg_dst_cgrp;
	struct css_set___113 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___84 {
	struct pmu___84 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___137 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___84 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___105 {
	struct vm_struct___105 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___137 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___123 {
	struct task_struct___137 task;
	long unsigned int stack[8192];
};

struct kset___130;

struct kobj_type___130;

struct kernfs_node___133;

struct kobject___131 {
	const char *name;
	struct list_head entry;
	struct kobject___131 *parent;
	struct kset___130 *kset;
	struct kobj_type___130 *ktype;
	struct kernfs_node___133 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___128 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___128 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___128;

struct bus_type___128;

struct device_driver___128;

struct dev_pm_domain___128;

struct fwnode_handle___97;

struct class___128;

struct attribute_group___127;

struct device___128 {
	struct device___128 *parent;
	struct device_private *p;
	struct kobject___131 kobj;
	const char *init_name;
	const struct device_type___128 *type;
	struct mutex mutex;
	struct bus_type___128 *bus;
	struct device_driver___128 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___128 power;
	struct dev_pm_domain___128 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___97 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___128 *class;
	const struct attribute_group___127 **groups;
	void (*release)(struct device___128 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___136;

struct super_block___136;

struct dentry___136 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___136 *d_parent;
	struct qstr d_name;
	struct inode___137 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___136 *d_op;
	struct super_block___136 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___136;

struct block_device___137;

struct inode___137 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___136 *i_op;
	struct super_block___136 *i_sb;
	struct address_space___136 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___137 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___137 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___136 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___137 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___136 {
	int (*d_revalidate)(struct dentry___136 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___136 *, unsigned int);
	int (*d_hash)(const struct dentry___136 *, struct qstr *);
	int (*d_compare)(const struct dentry___136 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___136 *);
	int (*d_init)(struct dentry___136 *);
	void (*d_release)(struct dentry___136 *);
	void (*d_prune)(struct dentry___136 *);
	void (*d_iput)(struct dentry___136 *, struct inode___137 *);
	char * (*d_dname)(struct dentry___136 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___136 *);
	int (*d_manage)(const struct path___136 *, bool);
	struct dentry___136 * (*d_real)(struct dentry___136 *, const struct inode___137 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___136;

struct mem_dqinfo___136 {
	struct quota_format_type___136 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___136;

struct quota_info___136 {
	unsigned int flags;
	struct rw_semaphore___137 dqio_sem;
	struct inode___137 *files[3];
	struct mem_dqinfo___136 info[3];
	const struct quota_format_ops___136 *ops[3];
};

struct rcuwait___136 {
	struct task_struct___137 *task;
};

struct percpu_rw_semaphore___136 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___137 rw_sem;
	struct rcuwait___136 writer;
	int readers_block;
};

struct sb_writers___136 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___136 rw_sem[3];
};

struct file_system_type___136;

struct super_operations___136;

struct dquot_operations___136;

struct quotactl_ops___136;

struct super_block___136 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___136 *s_type;
	const struct super_operations___136 *s_op;
	const struct dquot_operations___136 *dq_op;
	const struct quotactl_ops___136 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___136 *s_root;
	struct rw_semaphore___137 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___137 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___136 s_dquot;
	struct sb_writers___136 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___136 *s_d_op;
	int cleancache_poolid;
	struct shrinker___52 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___117 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___137 {
	struct file___137 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___137 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___136 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___137 *ia_file;
};

struct dquot___136 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___136 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___136 {
	int qf_fmt_id;
	const struct quota_format_ops___136 *qf_ops;
	struct module___117 *qf_owner;
	struct quota_format_type___136 *qf_next;
};

struct quota_format_ops___136 {
	int (*check_quota_file)(struct super_block___136 *, int);
	int (*read_file_info)(struct super_block___136 *, int);
	int (*write_file_info)(struct super_block___136 *, int);
	int (*free_file_info)(struct super_block___136 *, int);
	int (*read_dqblk)(struct dquot___136 *);
	int (*commit_dqblk)(struct dquot___136 *);
	int (*release_dqblk)(struct dquot___136 *);
	int (*get_next_id)(struct super_block___136 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___136 {
	int (*write_dquot)(struct dquot___136 *);
	struct dquot___136 * (*alloc_dquot)(struct super_block___136 *, int);
	void (*destroy_dquot)(struct dquot___136 *);
	int (*acquire_dquot)(struct dquot___136 *);
	int (*release_dquot)(struct dquot___136 *);
	int (*mark_dirty)(struct dquot___136 *);
	int (*write_info)(struct super_block___136 *, int);
	qsize_t * (*get_reserved_space)(struct inode___137 *);
	int (*get_projid)(struct inode___137 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___137 *, qsize_t *);
	int (*get_next_id)(struct super_block___136 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___136 {
	int (*quota_on)(struct super_block___136 *, int, int, const struct path___136 *);
	int (*quota_off)(struct super_block___136 *, int);
	int (*quota_enable)(struct super_block___136 *, unsigned int);
	int (*quota_disable)(struct super_block___136 *, unsigned int);
	int (*quota_sync)(struct super_block___136 *, int);
	int (*set_info)(struct super_block___136 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___136 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___136 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___136 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___136 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___136 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___114 {
	struct kobject___131 kobj;
	struct module___117 *mod;
	struct kobject___131 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___114 {
	struct module___117 *mod;
	struct latch_tree_node node;
};

struct module_layout___114 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___114 mtn;
};

struct module_attribute___114;

struct kernel_param___114;

struct module___117 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___114 mkobj;
	struct module_attribute___114 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___131 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___114 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___114 core_layout;
	struct module_layout___114 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___77 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___136 {
	int (*writepage)(struct page___137 *, struct writeback_control___3 *);
	int (*readpage)(struct file___137 *, struct page___137 *);
	int (*writepages)(struct address_space___136 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___137 *);
	int (*readpages)(struct file___137 *, struct address_space___136 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___137 *, struct address_space___136 *, loff_t, unsigned int, unsigned int, struct page___137 **, void **);
	int (*write_end)(struct file___137 *, struct address_space___136 *, loff_t, unsigned int, unsigned int, struct page___137 *, void *);
	sector_t (*bmap)(struct address_space___136 *, sector_t);
	void (*invalidatepage)(struct page___137 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___137 *, gfp_t);
	void (*freepage)(struct page___137 *);
	ssize_t (*direct_IO)(struct kiocb___137 *, struct iov_iter___60 *);
	int (*migratepage)(struct address_space___136 *, struct page___137 *, struct page___137 *, enum migrate_mode);
	bool (*isolate_page)(struct page___137 *, isolate_mode_t);
	void (*putback_page)(struct page___137 *);
	int (*launder_page)(struct page___137 *);
	int (*is_partially_uptodate)(struct page___137 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___137 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___136 *, struct page___137 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___137 *, sector_t *);
	void (*swap_deactivate)(struct file___137 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___137 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___137 *bd_inode;
	struct super_block___136 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___137 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___136 {
	struct dentry___136 * (*lookup)(struct inode___137 *, struct dentry___136 *, unsigned int);
	const char * (*get_link)(struct dentry___136 *, struct inode___137 *, struct delayed_call *);
	int (*permission)(struct inode___137 *, int);
	struct posix_acl * (*get_acl)(struct inode___137 *, int);
	int (*readlink)(struct dentry___136 *, char *, int);
	int (*create)(struct inode___137 *, struct dentry___136 *, umode_t, bool);
	int (*link)(struct dentry___136 *, struct inode___137 *, struct dentry___136 *);
	int (*unlink)(struct inode___137 *, struct dentry___136 *);
	int (*symlink)(struct inode___137 *, struct dentry___136 *, const char *);
	int (*mkdir)(struct inode___137 *, struct dentry___136 *, umode_t);
	int (*rmdir)(struct inode___137 *, struct dentry___136 *);
	int (*mknod)(struct inode___137 *, struct dentry___136 *, umode_t, dev_t);
	int (*rename)(struct inode___137 *, struct dentry___136 *, struct inode___137 *, struct dentry___136 *, unsigned int);
	int (*setattr)(struct dentry___136 *, struct iattr___136 *);
	int (*getattr)(const struct path___136 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___136 *, char *, size_t);
	int (*fiemap)(struct inode___137 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___137 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___137 *, struct dentry___136 *, struct file___137 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___137 *, struct dentry___136 *, umode_t);
	int (*set_acl)(struct inode___137 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___136 {
	void (*fl_copy_lock)(struct file_lock___137 *, struct file_lock___137 *);
	void (*fl_release_private)(struct file_lock___137 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___136;

struct file_lock___137 {
	struct file_lock___137 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___137 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___136 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___136 *fl_ops;
	const struct lock_manager_operations___136 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___136 {
	int (*lm_compare_owner)(struct file_lock___137 *, struct file_lock___137 *);
	long unsigned int (*lm_owner_key)(struct file_lock___137 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___137 *);
	int (*lm_grant)(struct file_lock___137 *, int);
	bool (*lm_break)(struct file_lock___137 *);
	int (*lm_change)(struct file_lock___137 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___137 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___136 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___136 *fa_next;
	struct file___137 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___136 {
	const char *name;
	int fs_flags;
	struct dentry___136 * (*mount)(struct file_system_type___136 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___136 *);
	struct module___117 *owner;
	struct file_system_type___136 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___136 {
	struct inode___137 * (*alloc_inode)(struct super_block___136 *);
	void (*destroy_inode)(struct inode___137 *);
	void (*dirty_inode)(struct inode___137 *, int);
	int (*write_inode)(struct inode___137 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___137 *);
	void (*evict_inode)(struct inode___137 *);
	void (*put_super)(struct super_block___136 *);
	int (*sync_fs)(struct super_block___136 *, int);
	int (*freeze_super)(struct super_block___136 *);
	int (*freeze_fs)(struct super_block___136 *);
	int (*thaw_super)(struct super_block___136 *);
	int (*unfreeze_fs)(struct super_block___136 *);
	int (*statfs)(struct dentry___136 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___136 *, int *, char *);
	void (*umount_begin)(struct super_block___136 *);
	int (*show_options)(struct seq_file___127 *, struct dentry___136 *);
	int (*show_devname)(struct seq_file___127 *, struct dentry___136 *);
	int (*show_path)(struct seq_file___127 *, struct dentry___136 *);
	int (*show_stats)(struct seq_file___127 *, struct dentry___136 *);
	ssize_t (*quota_read)(struct super_block___136 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___136 *, int, const char *, size_t, loff_t);
	struct dquot___136 ** (*get_dquots)(struct inode___137 *);
	int (*bdev_try_to_free_page)(struct super_block___136 *, struct page___137 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___136 *, struct shrink_control___52 *);
	long int (*free_cached_objects)(struct super_block___136 *, struct shrink_control___52 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___92)(struct file___137 *, wait_queue_head_t *, struct poll_table_struct___93 *);

struct poll_table_struct___93 {
	poll_queue_proc___92 _qproc;
	__poll_t _key;
};

struct seq_operations___125;

struct seq_file___127 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___125 *op;
	int poll_event;
	const struct file___137 *file;
	void *private;
};

struct kobj_attribute___131 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___131 *, struct kobj_attribute___131 *, char *);
	ssize_t (*store)(struct kobject___131 *, struct kobj_attribute___131 *, const char *, size_t);
};

typedef void compound_page_dtor___134(struct page___137 *);

struct kernfs_root___133;

struct kernfs_elem_dir___133 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___133 *root;
};

struct kernfs_syscall_ops___133;

struct kernfs_root___133 {
	struct kernfs_node___133 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___133 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___133 {
	struct kernfs_node___133 *target_kn;
};

struct kernfs_ops___133;

struct kernfs_elem_attr___133 {
	const struct kernfs_ops___133 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___133 *notify_next;
};

struct kernfs_node___133 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___133 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___133 dir;
		struct kernfs_elem_symlink___133 symlink;
		struct kernfs_elem_attr___133 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___133;

struct kernfs_ops___133 {
	int (*open)(struct kernfs_open_file___133 *);
	void (*release)(struct kernfs_open_file___133 *);
	int (*seq_show)(struct seq_file___127 *, void *);
	void * (*seq_start)(struct seq_file___127 *, loff_t *);
	void * (*seq_next)(struct seq_file___127 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___127 *, void *);
	ssize_t (*read)(struct kernfs_open_file___133 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___133 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___133 *, struct vm_area_struct___137 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___133 *, struct poll_table_struct___93 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___133 {
	int (*remount_fs)(struct kernfs_root___133 *, int *, char *);
	int (*show_options)(struct seq_file___127 *, struct kernfs_root___133 *);
	int (*mkdir)(struct kernfs_node___133 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___133 *);
	int (*rename)(struct kernfs_node___133 *, struct kernfs_node___133 *, const char *);
	int (*show_path)(struct seq_file___127 *, struct kernfs_node___133 *, struct kernfs_root___133 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___133 {
	struct kernfs_node___133 *kn;
	struct file___137 *file;
	struct seq_file___127 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___134 *vm_ops;
};

struct bin_attribute___127;

struct attribute_group___127 {
	const char *name;
	umode_t (*is_visible)(struct kobject___131 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___131 *, struct bin_attribute___127 *, int);
	struct attribute **attrs;
	struct bin_attribute___127 **bin_attrs;
};

struct bin_attribute___127 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___137 *, struct kobject___131 *, struct bin_attribute___127 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___137 *, struct kobject___131 *, struct bin_attribute___127 *, char *, loff_t, size_t);
	int (*mmap)(struct file___137 *, struct kobject___131 *, struct bin_attribute___127 *, struct vm_area_struct___137 *);
};

struct sysfs_ops___130 {
	ssize_t (*show)(struct kobject___131 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___131 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___130;

struct kset___130 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___131 kobj;
	const struct kset_uevent_ops___130 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___130 {
	void (*release)(struct kobject___131 *);
	const struct sysfs_ops___130 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___2 * (*child_ns_type)(struct kobject___131 *);
	const void * (*namespace)(struct kobject___131 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___130 {
	int (* const filter)(struct kset___130 *, struct kobject___131 *);
	const char * (* const name)(struct kset___130 *, struct kobject___131 *);
	int (* const uevent)(struct kset___130 *, struct kobject___131 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___114 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___114 *);
	int (*get)(char *, const struct kernel_param___114 *);
	void (*free)(void *);
};

struct kparam_array___114;

struct kernel_param___114 {
	const char *name;
	struct module___117 *mod;
	const struct kernel_param_ops___114 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___114 *arr;
	};
};

struct kparam_array___114 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___114 *ops;
	void *elem;
};

struct module_attribute___114 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___114 *, struct module_kobject___114 *, char *);
	ssize_t (*store)(struct module_attribute___114 *, struct module_kobject___114 *, const char *, size_t);
	void (*setup)(struct module___117 *, const char *);
	int (*test)(struct module___117 *);
	void (*free)(struct module___117 *);
};

struct trace_event_class___77;

struct trace_event_call___77 {
	struct list_head list;
	struct trace_event_class___77 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___4 *prog_array;
	int (*perf_perm)(struct trace_event_call___77 *, struct perf_event___84 *);
};

struct fwnode_operations___97;

struct fwnode_handle___97 {
	struct fwnode_handle___97 *secondary;
	const struct fwnode_operations___97 *ops;
};

struct fwnode_reference_args___97;

struct fwnode_endpoint___97;

struct fwnode_operations___97 {
	struct fwnode_handle___97 * (*get)(struct fwnode_handle___97 *);
	void (*put)(struct fwnode_handle___97 *);
	bool (*device_is_available)(const struct fwnode_handle___97 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___97 *, const struct device___128 *);
	bool (*property_present)(const struct fwnode_handle___97 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___97 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___97 *, const char *, const char **, size_t);
	struct fwnode_handle___97 * (*get_parent)(const struct fwnode_handle___97 *);
	struct fwnode_handle___97 * (*get_next_child_node)(const struct fwnode_handle___97 *, struct fwnode_handle___97 *);
	struct fwnode_handle___97 * (*get_named_child_node)(const struct fwnode_handle___97 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___97 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___97 *);
	struct fwnode_handle___97 * (*graph_get_next_endpoint)(const struct fwnode_handle___97 *, struct fwnode_handle___97 *);
	struct fwnode_handle___97 * (*graph_get_remote_endpoint)(const struct fwnode_handle___97 *);
	struct fwnode_handle___97 * (*graph_get_port_parent)(struct fwnode_handle___97 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___97 *, struct fwnode_endpoint___97 *);
};

struct fwnode_endpoint___97 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___97 *local_fwnode;
};

struct fwnode_reference_args___97 {
	struct fwnode_handle___97 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

typedef int (*key_restrict_link_func_t___132)(struct key___132 *, const struct key_type *, const union key_payload *, struct key___132 *);

struct key_restriction___132;

struct key___132 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___137 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___132 *restrict_link;
};

struct key_restriction___132 {
	key_restrict_link_func_t___132 check;
	struct key___132 *key;
	struct key_type *keytype;
};

struct seq_operations___125 {
	void * (*start)(struct seq_file___127 *, loff_t *);
	void (*stop)(struct seq_file___127 *, void *);
	void * (*next)(struct seq_file___127 *, void *, loff_t *);
	int (*show)(struct seq_file___127 *, void *);
};

struct cgroup_namespace___113 {
	refcount_t count;
	struct ns_common___4 ns;
	struct user_namespace___117 *user_ns;
	struct ucounts___117 *ucounts;
	struct css_set___113 *root_cset;
};

struct ucounts___117 {
	struct hlist_node node;
	struct user_namespace___117 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct dev_pm_ops___128 {
	int (*prepare)(struct device___128 *);
	void (*complete)(struct device___128 *);
	int (*suspend)(struct device___128 *);
	int (*resume)(struct device___128 *);
	int (*freeze)(struct device___128 *);
	int (*thaw)(struct device___128 *);
	int (*poweroff)(struct device___128 *);
	int (*restore)(struct device___128 *);
	int (*suspend_late)(struct device___128 *);
	int (*resume_early)(struct device___128 *);
	int (*freeze_late)(struct device___128 *);
	int (*thaw_early)(struct device___128 *);
	int (*poweroff_late)(struct device___128 *);
	int (*restore_early)(struct device___128 *);
	int (*suspend_noirq)(struct device___128 *);
	int (*resume_noirq)(struct device___128 *);
	int (*freeze_noirq)(struct device___128 *);
	int (*thaw_noirq)(struct device___128 *);
	int (*poweroff_noirq)(struct device___128 *);
	int (*restore_noirq)(struct device___128 *);
	int (*runtime_suspend)(struct device___128 *);
	int (*runtime_resume)(struct device___128 *);
	int (*runtime_idle)(struct device___128 *);
};

struct dev_pm_domain___128 {
	struct dev_pm_ops___128 ops;
	void (*detach)(struct device___128 *, bool);
	int (*activate)(struct device___128 *);
	void (*sync)(struct device___128 *);
	void (*dismiss)(struct device___128 *);
};

struct bus_type___128 {
	const char *name;
	const char *dev_name;
	struct device___128 *dev_root;
	const struct attribute_group___127 **bus_groups;
	const struct attribute_group___127 **dev_groups;
	const struct attribute_group___127 **drv_groups;
	int (*match)(struct device___128 *, struct device_driver___128 *);
	int (*uevent)(struct device___128 *, struct kobj_uevent_env *);
	int (*probe)(struct device___128 *);
	int (*remove)(struct device___128 *);
	void (*shutdown)(struct device___128 *);
	int (*online)(struct device___128 *);
	int (*offline)(struct device___128 *);
	int (*suspend)(struct device___128 *, pm_message_t);
	int (*resume)(struct device___128 *);
	int (*num_vf)(struct device___128 *);
	int (*dma_configure)(struct device___128 *);
	const struct dev_pm_ops___128 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___128 {
	const char *name;
	struct bus_type___128 *bus;
	struct module___117 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___128 *);
	int (*remove)(struct device___128 *);
	void (*shutdown)(struct device___128 *);
	int (*suspend)(struct device___128 *, pm_message_t);
	int (*resume)(struct device___128 *);
	const struct attribute_group___127 **groups;
	const struct dev_pm_ops___128 *pm;
	void (*coredump)(struct device___128 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___128 {
	const char *name;
	const struct attribute_group___127 **groups;
	int (*uevent)(struct device___128 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___128 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___128 *);
	const struct dev_pm_ops___128 *pm;
};

struct class___128 {
	const char *name;
	struct module___117 *owner;
	const struct attribute_group___127 **class_groups;
	const struct attribute_group___127 **dev_groups;
	struct kobject___131 *dev_kobj;
	int (*dev_uevent)(struct device___128 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___128 *, umode_t *);
	void (*class_release)(struct class___128 *);
	void (*dev_release)(struct device___128 *);
	int (*shutdown_pre)(struct device___128 *);
	const struct kobj_ns_type_operations___2 *ns_type;
	const void * (*namespace)(struct device___128 *);
	const struct dev_pm_ops___128 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___106 {
	struct device___128 dev;
};

struct bpf_map___113;

struct bpf_map_ops___113 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___113 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___113 *, struct file___137 *);
	void (*map_free)(struct bpf_map___113 *);
	int (*map_get_next_key)(struct bpf_map___113 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___113 *);
	void * (*map_lookup_elem)(struct bpf_map___113 *, void *);
	int (*map_update_elem)(struct bpf_map___113 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___113 *, void *);
	int (*map_push_elem)(struct bpf_map___113 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___113 *, void *);
	int (*map_peek_elem)(struct bpf_map___113 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___113 *, struct file___137 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___113 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___113 *, void *, struct seq_file___127 *);
	int (*map_check_btf)(const struct bpf_map___113 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___113 {
	const struct bpf_map_ops___113 *ops;
	struct bpf_map___113 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___132 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___113;

typedef void (*kthread_work_func_t___113)(struct kthread_work___113 *);

struct kthread_worker___113;

struct kthread_work___113 {
	struct list_head node;
	kthread_work_func_t___113 func;
	struct kthread_worker___113 *worker;
	int canceling;
};

struct kthread_worker___113 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___137 *task;
	struct kthread_work___113 *current_work;
};

struct kthread_delayed_work___113 {
	struct kthread_work___113 work;
	struct timer_list timer;
};

struct psi_group___113 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___113 *poll_kworker;
	struct kthread_delayed_work___113 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___113 {
	struct kernfs_node___133 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___113;

struct cgroup_subsys_state___113 {
	struct cgroup___113 *cgroup;
	struct cgroup_subsys___113 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___113 *parent;
};

struct cgroup_root___113;

struct cgroup_rstat_cpu___113;

struct cgroup___113 {
	struct cgroup_subsys_state___113 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___133 *kn;
	struct cgroup_file___113 procs_file;
	struct cgroup_file___113 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___113 *subsys[13];
	struct cgroup_root___113 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___113 *dom_cgrp;
	struct cgroup_rstat_cpu___113 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___4 bpf;
	atomic_t congestion_count;
	struct cgroup___113 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___113 psi;
	int ancestor_ids[0];
};

struct cftype___113;

struct cgroup_subsys___113 {
	struct cgroup_subsys_state___113 * (*css_alloc)(struct cgroup_subsys_state___113 *);
	int (*css_online)(struct cgroup_subsys_state___113 *);
	void (*css_offline)(struct cgroup_subsys_state___113 *);
	void (*css_released)(struct cgroup_subsys_state___113 *);
	void (*css_free)(struct cgroup_subsys_state___113 *);
	void (*css_reset)(struct cgroup_subsys_state___113 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___113 *, int);
	int (*css_extra_stat_show)(struct seq_file___127 *, struct cgroup_subsys_state___113 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___137 *);
	void (*cancel_fork)(struct task_struct___137 *);
	void (*fork)(struct task_struct___137 *);
	void (*exit)(struct task_struct___137 *);
	void (*free)(struct task_struct___137 *);
	void (*bind)(struct cgroup_subsys_state___113 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___113 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___113 *dfl_cftypes;
	struct cftype___113 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___113 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___113 *updated_children;
	struct cgroup___113 *updated_next;
};

struct cgroup_root___113 {
	struct kernfs_root___133 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___113 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___113 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___113 *ss;
	struct list_head node;
	struct kernfs_ops___133 *kf_ops;
	int (*open)(struct kernfs_open_file___133 *);
	void (*release)(struct kernfs_open_file___133 *);
	u64 (*read_u64)(struct cgroup_subsys_state___113 *, struct cftype___113 *);
	s64 (*read_s64)(struct cgroup_subsys_state___113 *, struct cftype___113 *);
	int (*seq_show)(struct seq_file___127 *, void *);
	void * (*seq_start)(struct seq_file___127 *, loff_t *);
	void * (*seq_next)(struct seq_file___127 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___127 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___113 *, struct cftype___113 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___113 *, struct cftype___113 *, s64);
	ssize_t (*write)(struct kernfs_open_file___133 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___133 *, struct poll_table_struct___93 *);
};

struct perf_cpu_context___84;

struct pmu___84 {
	struct list_head entry;
	struct module___117 *module;
	struct device___128 *dev;
	const struct attribute_group___127 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___84 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___84 *);
	void (*pmu_disable)(struct pmu___84 *);
	int (*event_init)(struct perf_event___84 *);
	void (*event_mapped)(struct perf_event___84 *, struct mm_struct___136 *);
	void (*event_unmapped)(struct perf_event___84 *, struct mm_struct___136 *);
	int (*add)(struct perf_event___84 *, int);
	void (*del)(struct perf_event___84 *, int);
	void (*start)(struct perf_event___84 *, int);
	void (*stop)(struct perf_event___84 *, int);
	void (*read)(struct perf_event___84 *);
	void (*start_txn)(struct pmu___84 *, unsigned int);
	int (*commit_txn)(struct pmu___84 *);
	void (*cancel_txn)(struct pmu___84 *);
	int (*event_idx)(struct perf_event___84 *);
	void (*sched_task)(struct perf_event_context___84 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___84 *);
	int (*filter_match)(struct perf_event___84 *);
	int (*check_period)(struct perf_event___84 *, u64);
};

struct perf_cpu_context___84 {
	struct perf_event_context___84 ctx;
	struct perf_event_context___84 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___84 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___84 {
	struct cgroup_subsys_state___113 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___77 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___77 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___77 *);
	struct list_head * (*get_fields)(struct trace_event_call___77 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___77 *);
};

struct trace_event_file___37;

struct trace_event_buffer___29 {
	struct ring_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___37 *trace_file;
	void *entry;
	long unsigned int flags;
	int pc;
};

struct trace_event_file___37 {
	struct list_head list;
	struct trace_event_call___77 *event_call;
	struct event_filter *filter;
	struct dentry___136 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_percpu_alloc_percpu {
	struct trace_entry ent;
	bool reserved;
	bool is_atomic;
	size_t size;
	size_t align;
	void *base_addr;
	int off;
	void *ptr;
	char __data[0];
};

struct trace_event_raw_percpu_free_percpu {
	struct trace_entry ent;
	void *base_addr;
	int off;
	void *ptr;
	char __data[0];
};

struct trace_event_raw_percpu_alloc_percpu_fail {
	struct trace_entry ent;
	bool reserved;
	bool is_atomic;
	size_t size;
	size_t align;
	char __data[0];
};

struct trace_event_raw_percpu_create_chunk {
	struct trace_entry ent;
	void *base_addr;
	char __data[0];
};

struct trace_event_raw_percpu_destroy_chunk {
	struct trace_entry ent;
	void *base_addr;
	char __data[0];
};

struct trace_event_data_offsets_percpu_alloc_percpu {};

struct trace_event_data_offsets_percpu_free_percpu {};

struct trace_event_data_offsets_percpu_alloc_percpu_fail {};

struct trace_event_data_offsets_percpu_create_chunk {};

struct trace_event_data_offsets_percpu_destroy_chunk {};

struct pcpu_block_md {
	int contig_hint;
	int contig_hint_start;
	int left_free;
	int right_free;
	int first_free;
};

struct pcpu_chunk {
	struct list_head list;
	int free_bytes;
	int contig_bits;
	int contig_bits_start;
	void *base_addr;
	long unsigned int *alloc_map;
	long unsigned int *bound_map;
	struct pcpu_block_md *md_blocks;
	void *data;
	int first_bit;
	bool immutable;
	int start_offset;
	int end_offset;
	int nr_pages;
	int nr_populated;
	int nr_empty_pop_pages;
	long unsigned int populated[0];
};

struct module___118;

struct file___138;

struct kiocb___138;

struct iov_iter___61;

struct poll_table_struct___94;

struct vm_area_struct___138;

struct inode___138;

struct file_lock___138;

struct page___138;

struct seq_file___128;

struct file_operations___138 {
	struct module___118 *owner;
	loff_t (*llseek)(struct file___138 *, loff_t, int);
	ssize_t (*read)(struct file___138 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___138 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___138 *, struct iov_iter___61 *);
	ssize_t (*write_iter)(struct kiocb___138 *, struct iov_iter___61 *);
	int (*iopoll)(struct kiocb___138 *, bool);
	int (*iterate)(struct file___138 *, struct dir_context *);
	int (*iterate_shared)(struct file___138 *, struct dir_context *);
	__poll_t (*poll)(struct file___138 *, struct poll_table_struct___94 *);
	long int (*unlocked_ioctl)(struct file___138 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___138 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___138 *, struct vm_area_struct___138 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___138 *, struct file___138 *);
	int (*flush)(struct file___138 *, fl_owner_t);
	int (*release)(struct inode___138 *, struct file___138 *);
	int (*fsync)(struct file___138 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___138 *, int);
	int (*lock)(struct file___138 *, int, struct file_lock___138 *);
	ssize_t (*sendpage)(struct file___138 *, struct page___138 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___138 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___138 *, int, struct file_lock___138 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___138 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___138 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___138 *, long int, struct file_lock___138 **, void **);
	long int (*fallocate)(struct file___138 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___128 *, struct file___138 *);
	ssize_t (*copy_file_range)(struct file___138 *, loff_t, struct file___138 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___138 *, loff_t, struct file___138 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___138 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___137 {
	u64 seqnum;
	struct vm_area_struct___138 *vmas[4];
};

struct page_frag___137 {
	struct page___138 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___85;

struct debug_info___85 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___85 *hbp_break[16];
	struct perf_event___85 *hbp_watch[16];
};

struct thread_struct___85 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___85 debug;
	long: 64;
};

struct mm_struct___137;

struct mem_cgroup___53;

struct pid___111;

struct cred___133;

struct nsproxy___130;

struct signal_struct___124;

struct bio_list___58;

struct backing_dev_info___58;

struct io_context___29;

struct css_set___114;

struct perf_event_context___85;

struct vm_struct___106;

struct task_struct___138 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___138 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___137 *mm;
	struct mm_struct___137 *active_mm;
	struct vmacache___137 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___138 *real_parent;
	struct task_struct___138 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___138 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___53 *active_memcg;
	long int rh_reserved2;
	struct pid___111 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___111 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___111 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___133 *ptracer_cred;
	const struct cred___133 *real_cred;
	const struct cred___133 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___130 *nsproxy;
	struct signal_struct___124 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___138 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___58 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___58 *backing_dev_info;
	struct io_context___29 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___114 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___85 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___137 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___53 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___138 *oom_reaper_list;
	struct vm_struct___106 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___85 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___85 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___138 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___85)(struct perf_event___85 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___85;

struct fasync_struct___137;

struct pid_namespace___111;

struct trace_event_call___78;

struct perf_cgroup___85;

struct perf_event___85 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___85 *group_leader;
	struct pmu___85 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___85 hw;
	struct perf_event_context___85 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___85 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___138 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___137 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___85 *);
	struct callback_head callback_head;
	struct pid_namespace___111 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___85 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___85 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___78 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___85 *cgrp;
	struct list_head sb_list;
};

typedef struct page___138 *pgtable_t___137;

struct address_space___137;

struct kmem_cache___3;

struct dev_pagemap___135;

struct page___138 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___137 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___138 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache___3 *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___137 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___137 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___135 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___53 *mem_cgroup;
};

struct pglist_data___137;

struct lruvec___137 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___137 *pgdat;
};

struct zone___137 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___137 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___137 {
	struct zone___137 *zone;
	int zone_idx;
};

struct zonelist___137 {
	struct zoneref___137 _zonerefs[25];
};

struct pglist_data___137 {
	struct zone___137 node_zones[3];
	struct zonelist___137 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___138 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___138 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___137 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___138 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___138 *owner;
};

struct secondary_data___138 {
	void *stack;
	struct task_struct___138 *task;
	long int status;
};

struct blocking_notifier_head___137 {
	struct rw_semaphore___138 rwsem;
	struct notifier_block *head;
};

struct kset___131;

struct kobj_type___131;

struct kernfs_node___134;

struct kobject___132 {
	const char *name;
	struct list_head entry;
	struct kobject___132 *parent;
	struct kset___131 *kset;
	struct kobj_type___131 *ktype;
	struct kernfs_node___134 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct memcg_cache_array___3;

struct memcg_cache_params___3 {
	struct kmem_cache___3 *root_cache;
	union {
		struct {
			struct memcg_cache_array___3 *memcg_caches;
			struct list_head __root_caches_node;
			struct list_head children;
			bool dying;
		};
		struct {
			struct mem_cgroup___53 *memcg;
			struct list_head children_node;
			struct list_head kmem_caches_node;
			struct percpu_ref refcnt;
			void (*work_fn)(struct kmem_cache___3 *);
			union {
				struct callback_head callback_head;
				struct work_struct work;
			};
		};
	};
};

struct kmem_cache_cpu___3;

struct kmem_cache___3 {
	struct kmem_cache_cpu___3 *cpu_slab;
	slab_flags_t flags;
	long unsigned int min_partial;
	unsigned int size;
	unsigned int object_size;
	unsigned int offset;
	unsigned int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	unsigned int inuse;
	unsigned int align;
	unsigned int red_left_pad;
	const char *name;
	struct list_head list;
	struct kobject___132 kobj;
	struct work_struct kobj_remove_work;
	struct memcg_cache_params___3 memcg_params;
	unsigned int max_attr_size;
	struct kset___131 *memcg_kset;
	unsigned int remote_node_defrag_ratio;
	unsigned int *random_seq;
	unsigned int useroffset;
	unsigned int usersize;
	struct kmem_cache_node *node[8];
};

struct memcg_cache_array___3 {
	struct callback_head rcu;
	struct kmem_cache___3 *entries[0];
};

struct cgroup___114;

struct cgroup_subsys___114;

struct cgroup_subsys_state___114 {
	struct cgroup___114 *cgroup;
	struct cgroup_subsys___114 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___114 *parent;
};

struct cgroup_file___114 {
	struct kernfs_node___134 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___53;

struct mem_cgroup___53 {
	struct cgroup_subsys_state___114 css;
	struct mem_cgroup_id___2 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___114 events_file;
	struct cgroup_file___114 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___138 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___53 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct vm_operations_struct___135;

struct vm_area_struct___138 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___138 *vm_next;
	struct vm_area_struct___138 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___137 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___135 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___138 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___137;

struct user_namespace___118;

struct mm_struct___137 {
	struct {
		struct vm_area_struct___138 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___138 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___138 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___137 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___138 *owner;
		struct user_namespace___118 *user_ns;
		struct file___138 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___137 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___137;

struct address_space___137 {
	struct inode___138 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___138 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___137 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___135)(struct vm_area_struct___138 *, long unsigned int, const struct page___138 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___135)(struct page___138 *, void *);

struct device___129;

struct dev_pagemap___135 {
	dev_page_fault_t___135 page_fault;
	dev_page_free_t___135 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___129 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct dentry___137;

struct path___137 {
	struct vfsmount *mnt;
	struct dentry___137 *dentry;
};

struct fown_struct___111 {
	rwlock_t lock;
	struct pid___111 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___138 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___137 f_path;
	struct inode___138 *f_inode;
	const struct file_operations___138 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___111 f_owner;
	const struct cred___133 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___137 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___135;

struct vm_operations_struct___135 {
	void (*open)(struct vm_area_struct___138 *);
	void (*close)(struct vm_area_struct___138 *);
	int (*split)(struct vm_area_struct___138 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___138 *);
	vm_fault_t (*fault)(struct vm_fault___135 *);
	vm_fault_t (*huge_fault)(struct vm_fault___135 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___135 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___138 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___135 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___135 *);
	int (*access)(struct vm_area_struct___138 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___138 *);
	int (*set_policy)(struct vm_area_struct___138 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___138 *, long unsigned int);
	struct page___138 * (*find_special_page)(struct vm_area_struct___138 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___137 {
	struct task_struct___138 *task;
	struct core_thread___137 *next;
};

struct core_state___137 {
	atomic_t nr_threads;
	struct core_thread___137 dumper;
	struct completion startup;
};

struct key___133;

struct ucounts___118;

struct user_namespace___118 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___118 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___4 ns;
	long unsigned int flags;
	struct key___133 *persistent_keyring_register;
	struct rw_semaphore___138 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___118 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___135 {
	struct vm_area_struct___138 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___138 *cow_page;
	struct mem_cgroup___53 *memcg;
	struct page___138 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___137 prealloc_pte;
};

struct shrink_control___53 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___53 *memcg;
};

struct shrinker___53 {
	long unsigned int (*count_objects)(struct shrinker___53 *, struct shrink_control___53 *);
	long unsigned int (*scan_objects)(struct shrinker___53 *, struct shrink_control___53 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct upid___111 {
	int nr;
	struct pid_namespace___111 *ns;
};

struct pid_namespace___111 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___138 *child_reaper;
	struct kmem_cache___3 *pid_cachep;
	unsigned int level;
	struct pid_namespace___111 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___137 *proc_self;
	struct dentry___137 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___118 *user_ns;
	struct ucounts___118 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___4 ns;
};

struct pid___111 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___111 numbers[1];
};

struct user_struct___133 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___133 *uid_keyring;
	struct key___133 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___133 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___133 *session_keyring;
	struct key___133 *process_keyring;
	struct key___133 *thread_keyring;
	struct key___133 *request_key_auth;
	void *security;
	struct user_struct___133 *user;
	struct user_namespace___118 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___114;

struct nsproxy___130 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___111 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___114 *cgroup_ns;
};

struct signal_struct___124 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___138 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___138 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___111 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___111 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___137 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___111 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___58;

struct bio_list___58 {
	struct bio___58 *head;
	struct bio___58 *tail;
};

struct bdi_writeback_congested___58;

struct bdi_writeback___58 {
	struct backing_dev_info___58 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___58 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___114 *memcg_css;
	struct cgroup_subsys_state___114 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___58 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___58 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___129 *dev;
	struct device___129 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___137 *debug_dir;
	struct dentry___137 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___29;

struct io_context___29 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___29 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___114 {
	struct cgroup_subsys_state___114 *subsys[13];
	refcount_t refcount;
	struct css_set___114 *dom_cset;
	struct cgroup___114 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___114 *mg_src_cgrp;
	struct cgroup___114 *mg_dst_cgrp;
	struct css_set___114 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___85 {
	struct pmu___85 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___138 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___85 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___106 {
	struct vm_struct___106 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___138 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___124 {
	struct task_struct___138 task;
	long unsigned int stack[8192];
};

struct dev_pm_info___129 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___129 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___129;

struct bus_type___129;

struct device_driver___129;

struct dev_pm_domain___129;

struct class___129;

struct attribute_group___128;

struct device___129 {
	struct device___129 *parent;
	struct device_private *p;
	struct kobject___132 kobj;
	const char *init_name;
	const struct device_type___129 *type;
	struct mutex mutex;
	struct bus_type___129 *bus;
	struct device_driver___129 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___129 power;
	struct dev_pm_domain___129 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___129 *class;
	const struct attribute_group___128 **groups;
	void (*release)(struct device___129 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___137;

struct super_block___137;

struct dentry___137 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___137 *d_parent;
	struct qstr d_name;
	struct inode___138 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___137 *d_op;
	struct super_block___137 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___137;

struct block_device___138;

struct inode___138 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___137 *i_op;
	struct super_block___137 *i_sb;
	struct address_space___137 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___138 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___58 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___138 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___137 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___138 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___137 {
	int (*d_revalidate)(struct dentry___137 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___137 *, unsigned int);
	int (*d_hash)(const struct dentry___137 *, struct qstr *);
	int (*d_compare)(const struct dentry___137 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___137 *);
	int (*d_init)(struct dentry___137 *);
	void (*d_release)(struct dentry___137 *);
	void (*d_prune)(struct dentry___137 *);
	void (*d_iput)(struct dentry___137 *, struct inode___138 *);
	char * (*d_dname)(struct dentry___137 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___137 *);
	int (*d_manage)(const struct path___137 *, bool);
	struct dentry___137 * (*d_real)(struct dentry___137 *, const struct inode___138 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___137;

struct mem_dqinfo___137 {
	struct quota_format_type___137 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___137;

struct quota_info___137 {
	unsigned int flags;
	struct rw_semaphore___138 dqio_sem;
	struct inode___138 *files[3];
	struct mem_dqinfo___137 info[3];
	const struct quota_format_ops___137 *ops[3];
};

struct rcuwait___137 {
	struct task_struct___138 *task;
};

struct percpu_rw_semaphore___137 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___138 rw_sem;
	struct rcuwait___137 writer;
	int readers_block;
};

struct sb_writers___137 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___137 rw_sem[3];
};

struct file_system_type___137;

struct super_operations___137;

struct dquot_operations___137;

struct quotactl_ops___137;

struct super_block___137 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___137 *s_type;
	const struct super_operations___137 *s_op;
	const struct dquot_operations___137 *dq_op;
	const struct quotactl_ops___137 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___137 *s_root;
	struct rw_semaphore___138 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___138 *s_bdev;
	struct backing_dev_info___58 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___137 s_dquot;
	struct sb_writers___137 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___137 *s_d_op;
	int cleancache_poolid;
	struct shrinker___53 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___118 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct io_cq___29 {
	struct request_queue___3 *q;
	struct io_context___29 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___3 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___138 {
	struct file___138 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___138 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___137 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___138 *ia_file;
};

struct dquot___137 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___137 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___137 {
	int qf_fmt_id;
	const struct quota_format_ops___137 *qf_ops;
	struct module___118 *qf_owner;
	struct quota_format_type___137 *qf_next;
};

struct quota_format_ops___137 {
	int (*check_quota_file)(struct super_block___137 *, int);
	int (*read_file_info)(struct super_block___137 *, int);
	int (*write_file_info)(struct super_block___137 *, int);
	int (*free_file_info)(struct super_block___137 *, int);
	int (*read_dqblk)(struct dquot___137 *);
	int (*commit_dqblk)(struct dquot___137 *);
	int (*release_dqblk)(struct dquot___137 *);
	int (*get_next_id)(struct super_block___137 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___137 {
	int (*write_dquot)(struct dquot___137 *);
	struct dquot___137 * (*alloc_dquot)(struct super_block___137 *, int);
	void (*destroy_dquot)(struct dquot___137 *);
	int (*acquire_dquot)(struct dquot___137 *);
	int (*release_dquot)(struct dquot___137 *);
	int (*mark_dirty)(struct dquot___137 *);
	int (*write_info)(struct super_block___137 *, int);
	qsize_t * (*get_reserved_space)(struct inode___138 *);
	int (*get_projid)(struct inode___138 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___138 *, qsize_t *);
	int (*get_next_id)(struct super_block___137 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___137 {
	int (*quota_on)(struct super_block___137 *, int, int, const struct path___137 *);
	int (*quota_off)(struct super_block___137 *, int);
	int (*quota_enable)(struct super_block___137 *, unsigned int);
	int (*quota_disable)(struct super_block___137 *, unsigned int);
	int (*quota_sync)(struct super_block___137 *, int);
	int (*set_info)(struct super_block___137 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___137 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___137 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___137 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___137 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___137 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___115 {
	struct kobject___132 kobj;
	struct module___118 *mod;
	struct kobject___132 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___115 {
	struct module___118 *mod;
	struct latch_tree_node node;
};

struct module_layout___115 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___115 mtn;
};

struct module_attribute___115;

struct kernel_param___115;

struct module___118 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___115 mkobj;
	struct module_attribute___115 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___132 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___115 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___115 core_layout;
	struct module_layout___115 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___78 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___55;

struct address_space_operations___137 {
	int (*writepage)(struct page___138 *, struct writeback_control___55 *);
	int (*readpage)(struct file___138 *, struct page___138 *);
	int (*writepages)(struct address_space___137 *, struct writeback_control___55 *);
	int (*set_page_dirty)(struct page___138 *);
	int (*readpages)(struct file___138 *, struct address_space___137 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___138 *, struct address_space___137 *, loff_t, unsigned int, unsigned int, struct page___138 **, void **);
	int (*write_end)(struct file___138 *, struct address_space___137 *, loff_t, unsigned int, unsigned int, struct page___138 *, void *);
	sector_t (*bmap)(struct address_space___137 *, sector_t);
	void (*invalidatepage)(struct page___138 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___138 *, gfp_t);
	void (*freepage)(struct page___138 *);
	ssize_t (*direct_IO)(struct kiocb___138 *, struct iov_iter___61 *);
	int (*migratepage)(struct address_space___137 *, struct page___138 *, struct page___138 *, enum migrate_mode);
	bool (*isolate_page)(struct page___138 *, isolate_mode_t);
	void (*putback_page)(struct page___138 *);
	int (*launder_page)(struct page___138 *);
	int (*is_partially_uptodate)(struct page___138 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___138 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___137 *, struct page___138 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___138 *, sector_t *);
	void (*swap_deactivate)(struct file___138 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___55 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___58 *wb;
	struct inode___138 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___58;

struct iov_iter___61 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___58 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___138 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___138 *bd_inode;
	struct super_block___137 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___138 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___58 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___137 {
	struct dentry___137 * (*lookup)(struct inode___138 *, struct dentry___137 *, unsigned int);
	const char * (*get_link)(struct dentry___137 *, struct inode___138 *, struct delayed_call *);
	int (*permission)(struct inode___138 *, int);
	struct posix_acl * (*get_acl)(struct inode___138 *, int);
	int (*readlink)(struct dentry___137 *, char *, int);
	int (*create)(struct inode___138 *, struct dentry___137 *, umode_t, bool);
	int (*link)(struct dentry___137 *, struct inode___138 *, struct dentry___137 *);
	int (*unlink)(struct inode___138 *, struct dentry___137 *);
	int (*symlink)(struct inode___138 *, struct dentry___137 *, const char *);
	int (*mkdir)(struct inode___138 *, struct dentry___137 *, umode_t);
	int (*rmdir)(struct inode___138 *, struct dentry___137 *);
	int (*mknod)(struct inode___138 *, struct dentry___137 *, umode_t, dev_t);
	int (*rename)(struct inode___138 *, struct dentry___137 *, struct inode___138 *, struct dentry___137 *, unsigned int);
	int (*setattr)(struct dentry___137 *, struct iattr___137 *);
	int (*getattr)(const struct path___137 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___137 *, char *, size_t);
	int (*fiemap)(struct inode___138 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___138 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___138 *, struct dentry___137 *, struct file___138 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___138 *, struct dentry___137 *, umode_t);
	int (*set_acl)(struct inode___138 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___137 {
	void (*fl_copy_lock)(struct file_lock___138 *, struct file_lock___138 *);
	void (*fl_release_private)(struct file_lock___138 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___137;

struct file_lock___138 {
	struct file_lock___138 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___138 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___137 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___137 *fl_ops;
	const struct lock_manager_operations___137 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___137 {
	int (*lm_compare_owner)(struct file_lock___138 *, struct file_lock___138 *);
	long unsigned int (*lm_owner_key)(struct file_lock___138 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___138 *);
	int (*lm_grant)(struct file_lock___138 *, int);
	bool (*lm_break)(struct file_lock___138 *);
	int (*lm_change)(struct file_lock___138 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___138 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___137 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___137 *fa_next;
	struct file___138 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___137 {
	const char *name;
	int fs_flags;
	struct dentry___137 * (*mount)(struct file_system_type___137 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___137 *);
	struct module___118 *owner;
	struct file_system_type___137 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___137 {
	struct inode___138 * (*alloc_inode)(struct super_block___137 *);
	void (*destroy_inode)(struct inode___138 *);
	void (*dirty_inode)(struct inode___138 *, int);
	int (*write_inode)(struct inode___138 *, struct writeback_control___55 *);
	int (*drop_inode)(struct inode___138 *);
	void (*evict_inode)(struct inode___138 *);
	void (*put_super)(struct super_block___137 *);
	int (*sync_fs)(struct super_block___137 *, int);
	int (*freeze_super)(struct super_block___137 *);
	int (*freeze_fs)(struct super_block___137 *);
	int (*thaw_super)(struct super_block___137 *);
	int (*unfreeze_fs)(struct super_block___137 *);
	int (*statfs)(struct dentry___137 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___137 *, int *, char *);
	void (*umount_begin)(struct super_block___137 *);
	int (*show_options)(struct seq_file___128 *, struct dentry___137 *);
	int (*show_devname)(struct seq_file___128 *, struct dentry___137 *);
	int (*show_path)(struct seq_file___128 *, struct dentry___137 *);
	int (*show_stats)(struct seq_file___128 *, struct dentry___137 *);
	ssize_t (*quota_read)(struct super_block___137 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___137 *, int, const char *, size_t, loff_t);
	struct dquot___137 ** (*get_dquots)(struct inode___138 *);
	int (*bdev_try_to_free_page)(struct super_block___137 *, struct page___138 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___137 *, struct shrink_control___53 *);
	long int (*free_cached_objects)(struct super_block___137 *, struct shrink_control___53 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___93)(struct file___138 *, wait_queue_head_t *, struct poll_table_struct___94 *);

struct poll_table_struct___94 {
	poll_queue_proc___93 _qproc;
	__poll_t _key;
};

struct seq_operations___126;

struct seq_file___128 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___126 *op;
	int poll_event;
	const struct file___138 *file;
	void *private;
};

typedef void bio_end_io_t___58(struct bio___58 *);

struct bio_vec___58 {
	struct page___138 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___58;

struct bio_set___58;

struct bio___58 {
	struct bio___58 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___58 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___58 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___58 *bi_io_vec;
	struct bio_set___58 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___58 bi_inline_vecs[0];
};

struct kobj_attribute___132 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___132 *, struct kobj_attribute___132 *, char *);
	ssize_t (*store)(struct kobject___132 *, struct kobj_attribute___132 *, const char *, size_t);
};

typedef void compound_page_dtor___135(struct page___138 *);

struct kernfs_root___134;

struct kernfs_elem_dir___134 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___134 *root;
};

struct kernfs_syscall_ops___134;

struct kernfs_root___134 {
	struct kernfs_node___134 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___134 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___134 {
	struct kernfs_node___134 *target_kn;
};

struct kernfs_ops___134;

struct kernfs_elem_attr___134 {
	const struct kernfs_ops___134 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___134 *notify_next;
};

struct kernfs_node___134 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___134 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___134 dir;
		struct kernfs_elem_symlink___134 symlink;
		struct kernfs_elem_attr___134 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___134;

struct kernfs_ops___134 {
	int (*open)(struct kernfs_open_file___134 *);
	void (*release)(struct kernfs_open_file___134 *);
	int (*seq_show)(struct seq_file___128 *, void *);
	void * (*seq_start)(struct seq_file___128 *, loff_t *);
	void * (*seq_next)(struct seq_file___128 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___128 *, void *);
	ssize_t (*read)(struct kernfs_open_file___134 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___134 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___134 *, struct vm_area_struct___138 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___134 *, struct poll_table_struct___94 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___134 {
	int (*remount_fs)(struct kernfs_root___134 *, int *, char *);
	int (*show_options)(struct seq_file___128 *, struct kernfs_root___134 *);
	int (*mkdir)(struct kernfs_node___134 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___134 *);
	int (*rename)(struct kernfs_node___134 *, struct kernfs_node___134 *, const char *);
	int (*show_path)(struct seq_file___128 *, struct kernfs_node___134 *, struct kernfs_root___134 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___134 {
	struct kernfs_node___134 *kn;
	struct file___138 *file;
	struct seq_file___128 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___135 *vm_ops;
};

struct bin_attribute___128;

struct attribute_group___128 {
	const char *name;
	umode_t (*is_visible)(struct kobject___132 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___132 *, struct bin_attribute___128 *, int);
	struct attribute **attrs;
	struct bin_attribute___128 **bin_attrs;
};

struct bin_attribute___128 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___138 *, struct kobject___132 *, struct bin_attribute___128 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___138 *, struct kobject___132 *, struct bin_attribute___128 *, char *, loff_t, size_t);
	int (*mmap)(struct file___138 *, struct kobject___132 *, struct bin_attribute___128 *, struct vm_area_struct___138 *);
};

struct sysfs_ops___131 {
	ssize_t (*show)(struct kobject___132 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___132 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___131;

struct kset___131 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___132 kobj;
	const struct kset_uevent_ops___131 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___131 {
	void (*release)(struct kobject___132 *);
	const struct sysfs_ops___131 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___2 * (*child_ns_type)(struct kobject___132 *);
	const void * (*namespace)(struct kobject___132 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___131 {
	int (* const filter)(struct kset___131 *, struct kobject___132 *);
	const char * (* const name)(struct kset___131 *, struct kobject___132 *);
	int (* const uevent)(struct kset___131 *, struct kobject___132 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___129 {
	int (*prepare)(struct device___129 *);
	void (*complete)(struct device___129 *);
	int (*suspend)(struct device___129 *);
	int (*resume)(struct device___129 *);
	int (*freeze)(struct device___129 *);
	int (*thaw)(struct device___129 *);
	int (*poweroff)(struct device___129 *);
	int (*restore)(struct device___129 *);
	int (*suspend_late)(struct device___129 *);
	int (*resume_early)(struct device___129 *);
	int (*freeze_late)(struct device___129 *);
	int (*thaw_early)(struct device___129 *);
	int (*poweroff_late)(struct device___129 *);
	int (*restore_early)(struct device___129 *);
	int (*suspend_noirq)(struct device___129 *);
	int (*resume_noirq)(struct device___129 *);
	int (*freeze_noirq)(struct device___129 *);
	int (*thaw_noirq)(struct device___129 *);
	int (*poweroff_noirq)(struct device___129 *);
	int (*restore_noirq)(struct device___129 *);
	int (*runtime_suspend)(struct device___129 *);
	int (*runtime_resume)(struct device___129 *);
	int (*runtime_idle)(struct device___129 *);
};

struct dev_pm_domain___129 {
	struct dev_pm_ops___129 ops;
	void (*detach)(struct device___129 *, bool);
	int (*activate)(struct device___129 *);
	void (*sync)(struct device___129 *);
	void (*dismiss)(struct device___129 *);
};

struct bus_type___129 {
	const char *name;
	const char *dev_name;
	struct device___129 *dev_root;
	const struct attribute_group___128 **bus_groups;
	const struct attribute_group___128 **dev_groups;
	const struct attribute_group___128 **drv_groups;
	int (*match)(struct device___129 *, struct device_driver___129 *);
	int (*uevent)(struct device___129 *, struct kobj_uevent_env *);
	int (*probe)(struct device___129 *);
	int (*remove)(struct device___129 *);
	void (*shutdown)(struct device___129 *);
	int (*online)(struct device___129 *);
	int (*offline)(struct device___129 *);
	int (*suspend)(struct device___129 *, pm_message_t);
	int (*resume)(struct device___129 *);
	int (*num_vf)(struct device___129 *);
	int (*dma_configure)(struct device___129 *);
	const struct dev_pm_ops___129 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___129 {
	const char *name;
	struct bus_type___129 *bus;
	struct module___118 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___129 *);
	int (*remove)(struct device___129 *);
	void (*shutdown)(struct device___129 *);
	int (*suspend)(struct device___129 *, pm_message_t);
	int (*resume)(struct device___129 *);
	const struct attribute_group___128 **groups;
	const struct dev_pm_ops___129 *pm;
	void (*coredump)(struct device___129 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___129 {
	const char *name;
	const struct attribute_group___128 **groups;
	int (*uevent)(struct device___129 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___129 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___129 *);
	const struct dev_pm_ops___129 *pm;
};

struct class___129 {
	const char *name;
	struct module___118 *owner;
	const struct attribute_group___128 **class_groups;
	const struct attribute_group___128 **dev_groups;
	struct kobject___132 *dev_kobj;
	int (*dev_uevent)(struct device___129 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___129 *, umode_t *);
	void (*class_release)(struct class___129 *);
	void (*dev_release)(struct device___129 *);
	int (*shutdown_pre)(struct device___129 *);
	const struct kobj_ns_type_operations___2 *ns_type;
	const void * (*namespace)(struct device___129 *);
	const struct dev_pm_ops___129 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___107 {
	struct device___129 dev;
};

struct kernel_param_ops___115 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___115 *);
	int (*get)(char *, const struct kernel_param___115 *);
	void (*free)(void *);
};

struct kparam_array___115;

struct kernel_param___115 {
	const char *name;
	struct module___118 *mod;
	const struct kernel_param_ops___115 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___115 *arr;
	};
};

struct kparam_array___115 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___115 *ops;
	void *elem;
};

struct module_attribute___115 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___115 *, struct module_kobject___115 *, char *);
	ssize_t (*store)(struct module_attribute___115 *, struct module_kobject___115 *, const char *, size_t);
	void (*setup)(struct module___118 *, const char *);
	int (*test)(struct module___118 *);
	void (*free)(struct module___118 *);
};

struct trace_event_class___78;

struct trace_event_call___78 {
	struct list_head list;
	struct trace_event_class___78 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___4 *prog_array;
	int (*perf_perm)(struct trace_event_call___78 *, struct perf_event___85 *);
};

typedef int (*key_restrict_link_func_t___133)(struct key___133 *, const struct key_type *, const union key_payload *, struct key___133 *);

struct key_restriction___133;

struct key___133 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___138 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___133 *restrict_link;
};

struct key_restriction___133 {
	key_restrict_link_func_t___133 check;
	struct key___133 *key;
	struct key_type *keytype;
};

struct seq_operations___126 {
	void * (*start)(struct seq_file___128 *, loff_t *);
	void (*stop)(struct seq_file___128 *, void *);
	void * (*next)(struct seq_file___128 *, void *, loff_t *);
	int (*show)(struct seq_file___128 *, void *);
};

struct cgroup_namespace___114 {
	refcount_t count;
	struct ns_common___4 ns;
	struct user_namespace___118 *user_ns;
	struct ucounts___118 *ucounts;
	struct css_set___114 *root_cset;
};

struct ucounts___118 {
	struct hlist_node node;
	struct user_namespace___118 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___114;

struct bpf_map_ops___114 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___114 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___114 *, struct file___138 *);
	void (*map_free)(struct bpf_map___114 *);
	int (*map_get_next_key)(struct bpf_map___114 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___114 *);
	void * (*map_lookup_elem)(struct bpf_map___114 *, void *);
	int (*map_update_elem)(struct bpf_map___114 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___114 *, void *);
	int (*map_push_elem)(struct bpf_map___114 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___114 *, void *);
	int (*map_peek_elem)(struct bpf_map___114 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___114 *, struct file___138 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___114 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___114 *, void *, struct seq_file___128 *);
	int (*map_check_btf)(const struct bpf_map___114 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___114 {
	const struct bpf_map_ops___114 *ops;
	struct bpf_map___114 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___133 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___114;

typedef void (*kthread_work_func_t___114)(struct kthread_work___114 *);

struct kthread_worker___114;

struct kthread_work___114 {
	struct list_head node;
	kthread_work_func_t___114 func;
	struct kthread_worker___114 *worker;
	int canceling;
};

struct kthread_worker___114 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___138 *task;
	struct kthread_work___114 *current_work;
};

struct kthread_delayed_work___114 {
	struct kthread_work___114 work;
	struct timer_list timer;
};

struct psi_group___114 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___114 *poll_kworker;
	struct kthread_delayed_work___114 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___114;

struct cgroup_rstat_cpu___114;

struct cgroup___114 {
	struct cgroup_subsys_state___114 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___134 *kn;
	struct cgroup_file___114 procs_file;
	struct cgroup_file___114 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___114 *subsys[13];
	struct cgroup_root___114 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___114 *dom_cgrp;
	struct cgroup_rstat_cpu___114 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___4 bpf;
	atomic_t congestion_count;
	struct cgroup___114 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___114 psi;
	int ancestor_ids[0];
};

struct cftype___114;

struct cgroup_subsys___114 {
	struct cgroup_subsys_state___114 * (*css_alloc)(struct cgroup_subsys_state___114 *);
	int (*css_online)(struct cgroup_subsys_state___114 *);
	void (*css_offline)(struct cgroup_subsys_state___114 *);
	void (*css_released)(struct cgroup_subsys_state___114 *);
	void (*css_free)(struct cgroup_subsys_state___114 *);
	void (*css_reset)(struct cgroup_subsys_state___114 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___114 *, int);
	int (*css_extra_stat_show)(struct seq_file___128 *, struct cgroup_subsys_state___114 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___138 *);
	void (*cancel_fork)(struct task_struct___138 *);
	void (*fork)(struct task_struct___138 *);
	void (*exit)(struct task_struct___138 *);
	void (*free)(struct task_struct___138 *);
	void (*bind)(struct cgroup_subsys_state___114 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___114 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___114 *dfl_cftypes;
	struct cftype___114 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___114 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___114 *updated_children;
	struct cgroup___114 *updated_next;
};

struct cgroup_root___114 {
	struct kernfs_root___134 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___114 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___114 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___114 *ss;
	struct list_head node;
	struct kernfs_ops___134 *kf_ops;
	int (*open)(struct kernfs_open_file___134 *);
	void (*release)(struct kernfs_open_file___134 *);
	u64 (*read_u64)(struct cgroup_subsys_state___114 *, struct cftype___114 *);
	s64 (*read_s64)(struct cgroup_subsys_state___114 *, struct cftype___114 *);
	int (*seq_show)(struct seq_file___128 *, void *);
	void * (*seq_start)(struct seq_file___128 *, loff_t *);
	void * (*seq_next)(struct seq_file___128 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___128 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___114 *, struct cftype___114 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___114 *, struct cftype___114 *, s64);
	ssize_t (*write)(struct kernfs_open_file___134 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___134 *, struct poll_table_struct___94 *);
};

struct bdi_writeback_congested___58 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___58 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___58 {
	struct bio___58 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___58 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___58 bip_inline_vecs[0];
};

struct bio_set___58 {
	struct kmem_cache___3 *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___58 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___53 {
	struct mem_cgroup___53 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___53 {
	struct lruvec___137 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___53 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___53 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct perf_cpu_context___85;

struct pmu___85 {
	struct list_head entry;
	struct module___118 *module;
	struct device___129 *dev;
	const struct attribute_group___128 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___85 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___85 *);
	void (*pmu_disable)(struct pmu___85 *);
	int (*event_init)(struct perf_event___85 *);
	void (*event_mapped)(struct perf_event___85 *, struct mm_struct___137 *);
	void (*event_unmapped)(struct perf_event___85 *, struct mm_struct___137 *);
	int (*add)(struct perf_event___85 *, int);
	void (*del)(struct perf_event___85 *, int);
	void (*start)(struct perf_event___85 *, int);
	void (*stop)(struct perf_event___85 *, int);
	void (*read)(struct perf_event___85 *);
	void (*start_txn)(struct pmu___85 *, unsigned int);
	int (*commit_txn)(struct pmu___85 *);
	void (*cancel_txn)(struct pmu___85 *);
	int (*event_idx)(struct perf_event___85 *);
	void (*sched_task)(struct perf_event_context___85 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___85 *);
	int (*filter_match)(struct perf_event___85 *);
	int (*check_period)(struct perf_event___85 *, u64);
};

struct perf_cpu_context___85 {
	struct perf_event_context___85 ctx;
	struct perf_event_context___85 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___85 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___85 {
	struct cgroup_subsys_state___114 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___78 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___78 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___78 *);
	struct list_head * (*get_fields)(struct trace_event_call___78 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___78 *);
};

struct trace_event_file___38;

struct trace_event_buffer___30 {
	struct ring_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___38 *trace_file;
	void *entry;
	long unsigned int flags;
	int pc;
};

struct trace_event_file___38 {
	struct list_head list;
	struct trace_event_call___78 *event_call;
	struct event_filter *filter;
	struct dentry___137 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_kmem_alloc {
	struct trace_entry ent;
	long unsigned int call_site;
	const void *ptr;
	size_t bytes_req;
	size_t bytes_alloc;
	gfp_t gfp_flags;
	char __data[0];
};

struct trace_event_raw_kmem_alloc_node {
	struct trace_entry ent;
	long unsigned int call_site;
	const void *ptr;
	size_t bytes_req;
	size_t bytes_alloc;
	gfp_t gfp_flags;
	int node;
	char __data[0];
};

struct trace_event_raw_kmem_free {
	struct trace_entry ent;
	long unsigned int call_site;
	const void *ptr;
	char __data[0];
};

struct trace_event_raw_mm_page_free {
	struct trace_entry ent;
	long unsigned int pfn;
	unsigned int order;
	char __data[0];
};

struct trace_event_raw_mm_page_free_batched {
	struct trace_entry ent;
	long unsigned int pfn;
	char __data[0];
};

struct trace_event_raw_mm_page_alloc {
	struct trace_entry ent;
	long unsigned int pfn;
	unsigned int order;
	gfp_t gfp_flags;
	int migratetype;
	char __data[0];
};

struct trace_event_raw_mm_page {
	struct trace_entry ent;
	long unsigned int pfn;
	unsigned int order;
	int migratetype;
	char __data[0];
};

struct trace_event_raw_mm_page_pcpu_drain {
	struct trace_entry ent;
	long unsigned int pfn;
	unsigned int order;
	int migratetype;
	char __data[0];
};

struct trace_event_raw_mm_page_alloc_extfrag {
	struct trace_entry ent;
	long unsigned int pfn;
	int alloc_order;
	int fallback_order;
	int alloc_migratetype;
	int fallback_migratetype;
	int change_ownership;
	char __data[0];
};

struct trace_event_data_offsets_kmem_alloc {};

struct trace_event_data_offsets_kmem_alloc_node {};

struct trace_event_data_offsets_kmem_free {};

struct trace_event_data_offsets_mm_page_free {};

struct trace_event_data_offsets_mm_page_free_batched {};

struct trace_event_data_offsets_mm_page_alloc {};

struct trace_event_data_offsets_mm_page {};

struct trace_event_data_offsets_mm_page_pcpu_drain {};

struct trace_event_data_offsets_mm_page_alloc_extfrag {};

struct kmem_cache_cpu___3 {
	void **freelist;
	long unsigned int tid;
	struct page___138 *page;
	struct page___138 *partial;
};

struct slabinfo {
	long unsigned int active_objs;
	long unsigned int num_objs;
	long unsigned int active_slabs;
	long unsigned int num_slabs;
	long unsigned int shared_avail;
	unsigned int limit;
	unsigned int batchcount;
	unsigned int shared;
	unsigned int objects_per_slab;
	unsigned int cache_order;
};

struct module___119;

struct file___139;

struct kiocb___139;

struct iov_iter___62;

struct poll_table_struct___95;

struct vm_area_struct___139;

struct inode___139;

struct file_lock___139;

struct page___139;

struct seq_file___129;

struct file_operations___139 {
	struct module___119 *owner;
	loff_t (*llseek)(struct file___139 *, loff_t, int);
	ssize_t (*read)(struct file___139 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___139 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___139 *, struct iov_iter___62 *);
	ssize_t (*write_iter)(struct kiocb___139 *, struct iov_iter___62 *);
	int (*iopoll)(struct kiocb___139 *, bool);
	int (*iterate)(struct file___139 *, struct dir_context *);
	int (*iterate_shared)(struct file___139 *, struct dir_context *);
	__poll_t (*poll)(struct file___139 *, struct poll_table_struct___95 *);
	long int (*unlocked_ioctl)(struct file___139 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___139 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___139 *, struct vm_area_struct___139 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___139 *, struct file___139 *);
	int (*flush)(struct file___139 *, fl_owner_t);
	int (*release)(struct inode___139 *, struct file___139 *);
	int (*fsync)(struct file___139 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___139 *, int);
	int (*lock)(struct file___139 *, int, struct file_lock___139 *);
	ssize_t (*sendpage)(struct file___139 *, struct page___139 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___139 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___139 *, int, struct file_lock___139 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___139 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___139 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___139 *, long int, struct file_lock___139 **, void **);
	long int (*fallocate)(struct file___139 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___129 *, struct file___139 *);
	ssize_t (*copy_file_range)(struct file___139 *, loff_t, struct file___139 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___139 *, loff_t, struct file___139 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___139 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct perf_event___86;

struct debug_info___86 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___86 *hbp_break[16];
	struct perf_event___86 *hbp_watch[16];
};

struct task_struct___139;

struct hw_perf_event___86 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___139 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___86)(struct perf_event___86 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___86;

struct perf_event_context___86;

struct fasync_struct___138;

struct pid_namespace___112;

struct trace_event_call___79;

struct perf_cgroup___86;

struct perf_event___86 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___86 *group_leader;
	struct pmu___86 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___86 hw;
	struct perf_event_context___86 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___86 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___139 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___138 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___86 *);
	struct callback_head callback_head;
	struct pid_namespace___112 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___86 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___86 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___79 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___86 *cgrp;
	struct list_head sb_list;
};

struct thread_struct___86 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___86 debug;
	long: 64;
};

struct vmacache___138 {
	u64 seqnum;
	struct vm_area_struct___139 *vmas[4];
};

struct page_frag___138 {
	struct page___139 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___138;

struct mem_cgroup___54;

struct pid___112;

struct cred___134;

struct nsproxy___131;

struct signal_struct___125;

struct bio_list___59;

struct backing_dev_info___59;

struct io_context___30;

struct css_set___115;

struct request_queue___29;

struct vm_struct___107;

struct task_struct___139 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___139 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___138 *mm;
	struct mm_struct___138 *active_mm;
	struct vmacache___138 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___139 *real_parent;
	struct task_struct___139 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___139 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___54 *active_memcg;
	long int rh_reserved2;
	struct pid___112 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___112 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___112 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___134 *ptracer_cred;
	const struct cred___134 *real_cred;
	const struct cred___134 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___131 *nsproxy;
	struct signal_struct___125 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___139 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___59 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___59 *backing_dev_info;
	struct io_context___30 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___115 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___86 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___138 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___54 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___29 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___139 *oom_reaper_list;
	struct vm_struct___107 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___86 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___139 *pgtable_t___138;

struct address_space___138;

struct dev_pagemap___136;

struct page___139 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___138 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___139 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___138 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___138 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___136 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___54 *mem_cgroup;
};

struct pglist_data___138;

struct lruvec___138 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___138 *pgdat;
};

struct zone___138 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___138 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___138 {
	struct zone___138 *zone;
	int zone_idx;
};

struct zonelist___138 {
	struct zoneref___138 _zonerefs[25];
};

struct pglist_data___138 {
	struct zone___138 node_zones[3];
	struct zonelist___138 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___139 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___139 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___138 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

typedef struct pglist_data___138 pg_data_t___8;

struct rw_semaphore___139 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___139 *owner;
};

struct secondary_data___139 {
	void *stack;
	struct task_struct___139 *task;
	long int status;
};

struct blocking_notifier_head___138 {
	struct rw_semaphore___139 rwsem;
	struct notifier_block *head;
};

struct key___134;

struct ucounts___119;

struct user_namespace___119 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___119 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___4 ns;
	long unsigned int flags;
	struct key___134 *persistent_keyring_register;
	struct rw_semaphore___139 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___119 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_root___135;

struct kernfs_elem_dir___135 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___135 *root;
};

struct kernfs_node___135;

struct kernfs_syscall_ops___135;

struct kernfs_root___135 {
	struct kernfs_node___135 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___135 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___135 {
	struct kernfs_node___135 *target_kn;
};

struct kernfs_ops___135;

struct kernfs_elem_attr___135 {
	const struct kernfs_ops___135 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___135 *notify_next;
};

struct kernfs_node___135 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___135 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___135 dir;
		struct kernfs_elem_symlink___135 symlink;
		struct kernfs_elem_attr___135 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___135;

struct kernfs_ops___135 {
	int (*open)(struct kernfs_open_file___135 *);
	void (*release)(struct kernfs_open_file___135 *);
	int (*seq_show)(struct seq_file___129 *, void *);
	void * (*seq_start)(struct seq_file___129 *, loff_t *);
	void * (*seq_next)(struct seq_file___129 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___129 *, void *);
	ssize_t (*read)(struct kernfs_open_file___135 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___135 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___135 *, struct vm_area_struct___139 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___135 *, struct poll_table_struct___95 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___135 {
	int (*remount_fs)(struct kernfs_root___135 *, int *, char *);
	int (*show_options)(struct seq_file___129 *, struct kernfs_root___135 *);
	int (*mkdir)(struct kernfs_node___135 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___135 *);
	int (*rename)(struct kernfs_node___135 *, struct kernfs_node___135 *, const char *);
	int (*show_path)(struct seq_file___129 *, struct kernfs_node___135 *, struct kernfs_root___135 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___127;

struct seq_file___129 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___127 *op;
	int poll_event;
	const struct file___139 *file;
	void *private;
};

struct vm_operations_struct___136;

struct kernfs_open_file___135 {
	struct kernfs_node___135 *kn;
	struct file___139 *file;
	struct seq_file___129 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___136 *vm_ops;
};

struct dentry___138;

struct path___138 {
	struct vfsmount *mnt;
	struct dentry___138 *dentry;
};

struct fown_struct___112 {
	rwlock_t lock;
	struct pid___112 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___139 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___138 f_path;
	struct inode___139 *f_inode;
	const struct file_operations___139 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___112 f_owner;
	const struct cred___134 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___138 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___136;

struct vm_operations_struct___136 {
	void (*open)(struct vm_area_struct___139 *);
	void (*close)(struct vm_area_struct___139 *);
	int (*split)(struct vm_area_struct___139 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___139 *);
	vm_fault_t (*fault)(struct vm_fault___136 *);
	vm_fault_t (*huge_fault)(struct vm_fault___136 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___136 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___139 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___136 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___136 *);
	int (*access)(struct vm_area_struct___139 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___139 *);
	int (*set_policy)(struct vm_area_struct___139 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___139 *, long unsigned int);
	struct page___139 * (*find_special_page)(struct vm_area_struct___139 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___94)(struct file___139 *, wait_queue_head_t *, struct poll_table_struct___95 *);

struct poll_table_struct___95 {
	poll_queue_proc___94 _qproc;
	__poll_t _key;
};

struct vm_area_struct___139 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___139 *vm_next;
	struct vm_area_struct___139 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___138 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___136 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___139 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___133;

struct bin_attribute___129;

struct attribute_group___129 {
	const char *name;
	umode_t (*is_visible)(struct kobject___133 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___133 *, struct bin_attribute___129 *, int);
	struct attribute **attrs;
	struct bin_attribute___129 **bin_attrs;
};

struct kset___132;

struct kobj_type___132;

struct kobject___133 {
	const char *name;
	struct list_head entry;
	struct kobject___133 *parent;
	struct kset___132 *kset;
	struct kobj_type___132 *ktype;
	struct kernfs_node___135 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___129 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___139 *, struct kobject___133 *, struct bin_attribute___129 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___139 *, struct kobject___133 *, struct bin_attribute___129 *, char *, loff_t, size_t);
	int (*mmap)(struct file___139 *, struct kobject___133 *, struct bin_attribute___129 *, struct vm_area_struct___139 *);
};

struct sysfs_ops___132 {
	ssize_t (*show)(struct kobject___133 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___133 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___132;

struct kset___132 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___133 kobj;
	const struct kset_uevent_ops___132 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___132 {
	void (*release)(struct kobject___133 *);
	const struct sysfs_ops___132 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___2 * (*child_ns_type)(struct kobject___133 *);
	const void * (*namespace)(struct kobject___133 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___132 {
	int (* const filter)(struct kset___132 *, struct kobject___133 *);
	const char * (* const name)(struct kset___132 *, struct kobject___133 *);
	int (* const uevent)(struct kset___132 *, struct kobject___133 *, struct kobj_uevent_env *);
};

struct kobj_attribute___133 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___133 *, struct kobj_attribute___133 *, char *);
	ssize_t (*store)(struct kobject___133 *, struct kobj_attribute___133 *, const char *, size_t);
};

struct device___130;

struct dev_pm_ops___130 {
	int (*prepare)(struct device___130 *);
	void (*complete)(struct device___130 *);
	int (*suspend)(struct device___130 *);
	int (*resume)(struct device___130 *);
	int (*freeze)(struct device___130 *);
	int (*thaw)(struct device___130 *);
	int (*poweroff)(struct device___130 *);
	int (*restore)(struct device___130 *);
	int (*suspend_late)(struct device___130 *);
	int (*resume_early)(struct device___130 *);
	int (*freeze_late)(struct device___130 *);
	int (*thaw_early)(struct device___130 *);
	int (*poweroff_late)(struct device___130 *);
	int (*restore_early)(struct device___130 *);
	int (*suspend_noirq)(struct device___130 *);
	int (*resume_noirq)(struct device___130 *);
	int (*freeze_noirq)(struct device___130 *);
	int (*thaw_noirq)(struct device___130 *);
	int (*poweroff_noirq)(struct device___130 *);
	int (*restore_noirq)(struct device___130 *);
	int (*runtime_suspend)(struct device___130 *);
	int (*runtime_resume)(struct device___130 *);
	int (*runtime_idle)(struct device___130 *);
};

struct dev_pm_info___130 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___130 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___130;

struct bus_type___130;

struct device_driver___130;

struct dev_pm_domain___130;

struct fwnode_handle___98;

struct class___130;

struct device___130 {
	struct device___130 *parent;
	struct device_private *p;
	struct kobject___133 kobj;
	const char *init_name;
	const struct device_type___130 *type;
	struct mutex mutex;
	struct bus_type___130 *bus;
	struct device_driver___130 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___130 power;
	struct dev_pm_domain___130 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___98 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___130 *class;
	const struct attribute_group___129 **groups;
	void (*release)(struct device___130 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___130 {
	struct dev_pm_ops___130 ops;
	void (*detach)(struct device___130 *, bool);
	int (*activate)(struct device___130 *);
	void (*sync)(struct device___130 *);
	void (*dismiss)(struct device___130 *);
};

struct upid___112 {
	int nr;
	struct pid_namespace___112 *ns;
};

struct pid_namespace___112 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___139 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___112 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___138 *proc_self;
	struct dentry___138 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___119 *user_ns;
	struct ucounts___119 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___4 ns;
};

struct pid___112 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___112 numbers[1];
};

struct user_struct___134 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___134 *uid_keyring;
	struct key___134 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___138;

struct mm_struct___138 {
	struct {
		struct vm_area_struct___139 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___139 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___139 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___138 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___139 *owner;
		struct user_namespace___119 *user_ns;
		struct file___139 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___138 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup___115;

struct cgroup_subsys___115;

struct cgroup_subsys_state___115 {
	struct cgroup___115 *cgroup;
	struct cgroup_subsys___115 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___115 *parent;
};

struct cgroup_file___115 {
	struct kernfs_node___135 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___54;

struct mem_cgroup___54 {
	struct cgroup_subsys_state___115 css;
	struct mem_cgroup_id___6 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___115 events_file;
	struct cgroup_file___115 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___139 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___54 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cred___134 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___134 *session_keyring;
	struct key___134 *process_keyring;
	struct key___134 *thread_keyring;
	struct key___134 *request_key_auth;
	void *security;
	struct user_struct___134 *user;
	struct user_namespace___119 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___115;

struct nsproxy___131 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___112 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___115 *cgroup_ns;
};

struct signal_struct___125 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___139 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___139 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___112 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___112 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___138 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___112 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___59;

struct bio_list___59 {
	struct bio___59 *head;
	struct bio___59 *tail;
};

struct bdi_writeback_congested___59;

struct bdi_writeback___59 {
	struct backing_dev_info___59 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___59 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___115 *memcg_css;
	struct cgroup_subsys_state___115 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___59 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___59 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___130 *dev;
	struct device___130 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___138 *debug_dir;
	struct dentry___138 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___30;

struct io_context___30 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___30 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___115 {
	struct cgroup_subsys_state___115 *subsys[13];
	refcount_t refcount;
	struct css_set___115 *dom_cset;
	struct cgroup___115 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___115 *mg_src_cgrp;
	struct cgroup___115 *mg_dst_cgrp;
	struct css_set___115 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___86 {
	struct pmu___86 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___139 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___86 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

typedef blk_qc_t make_request_fn___28(struct request_queue___29 *, struct bio___59 *);

struct request___29;

typedef int dma_drain_needed_fn___28(struct request___29 *);

struct bsg_ops___28;

struct bsg_class_device___28 {
	struct device___130 *class_dev;
	int minor;
	struct request_queue___29 *queue;
	const struct bsg_ops___28 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___59 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___59 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___28;

struct blkcg_gq___20;

struct request_queue___29 {
	struct list_head queue_head;
	struct request___29 *last_merge;
	struct elevator_queue___28 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___28 *make_request_fn;
	dma_drain_needed_fn___28 *dma_drain_needed;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___59 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___133 kobj;
	struct kobject___133 *mq_kobj;
	struct blk_integrity integrity;
	struct device___130 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___20 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	struct bsg_class_device___28 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___59 bio_split;
	struct dentry___138 *debugfs_dir;
	struct dentry___138 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___107 {
	struct vm_struct___107 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___139 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___125 {
	struct task_struct___139 task;
	long unsigned int stack[8192];
};

struct bus_type___130 {
	const char *name;
	const char *dev_name;
	struct device___130 *dev_root;
	const struct attribute_group___129 **bus_groups;
	const struct attribute_group___129 **dev_groups;
	const struct attribute_group___129 **drv_groups;
	int (*match)(struct device___130 *, struct device_driver___130 *);
	int (*uevent)(struct device___130 *, struct kobj_uevent_env *);
	int (*probe)(struct device___130 *);
	int (*remove)(struct device___130 *);
	void (*shutdown)(struct device___130 *);
	int (*online)(struct device___130 *);
	int (*offline)(struct device___130 *);
	int (*suspend)(struct device___130 *, pm_message_t);
	int (*resume)(struct device___130 *);
	int (*num_vf)(struct device___130 *);
	int (*dma_configure)(struct device___130 *);
	const struct dev_pm_ops___130 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___130 {
	const char *name;
	struct bus_type___130 *bus;
	struct module___119 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___130 *);
	int (*remove)(struct device___130 *);
	void (*shutdown)(struct device___130 *);
	int (*suspend)(struct device___130 *, pm_message_t);
	int (*resume)(struct device___130 *);
	const struct attribute_group___129 **groups;
	const struct dev_pm_ops___130 *pm;
	void (*coredump)(struct device___130 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___130 {
	const char *name;
	const struct attribute_group___129 **groups;
	int (*uevent)(struct device___130 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___130 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___130 *);
	const struct dev_pm_ops___130 *pm;
};

struct module_kobject___116 {
	struct kobject___133 kobj;
	struct module___119 *mod;
	struct kobject___133 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___116 {
	struct module___119 *mod;
	struct latch_tree_node node;
};

struct module_layout___116 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___116 mtn;
};

struct module_attribute___116;

struct kernel_param___116;

struct module___119 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___116 mkobj;
	struct module_attribute___116 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___133 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___116 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___116 core_layout;
	struct module_layout___116 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___79 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide46;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide47;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct class___130 {
	const char *name;
	struct module___119 *owner;
	const struct attribute_group___129 **class_groups;
	const struct attribute_group___129 **dev_groups;
	struct kobject___133 *dev_kobj;
	int (*dev_uevent)(struct device___130 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___130 *, umode_t *);
	void (*class_release)(struct class___130 *);
	void (*dev_release)(struct device___130 *);
	int (*shutdown_pre)(struct device___130 *);
	const struct kobj_ns_type_operations___2 *ns_type;
	const void * (*namespace)(struct device___130 *);
	const struct dev_pm_ops___130 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct device_attribute___9 {
	struct attribute attr;
	ssize_t (*show)(struct device___130 *, struct device_attribute___9 *, char *);
	ssize_t (*store)(struct device___130 *, struct device_attribute___9 *, const char *, size_t);
};

struct fwnode_operations___98;

struct fwnode_handle___98 {
	struct fwnode_handle___98 *secondary;
	const struct fwnode_operations___98 *ops;
};

struct node___108 {
	struct device___130 dev;
};

struct dentry_operations___138;

struct super_block___138;

struct dentry___138 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___138 *d_parent;
	struct qstr d_name;
	struct inode___139 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___138 *d_op;
	struct super_block___138 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___138;

struct address_space___138 {
	struct inode___139 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___139 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___138 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___138;

struct block_device___139;

struct inode___139 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___138 *i_op;
	struct super_block___138 *i_sb;
	struct address_space___138 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___139 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___59 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___139 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___138 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___139 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___138 {
	int (*d_revalidate)(struct dentry___138 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___138 *, unsigned int);
	int (*d_hash)(const struct dentry___138 *, struct qstr *);
	int (*d_compare)(const struct dentry___138 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___138 *);
	int (*d_init)(struct dentry___138 *);
	void (*d_release)(struct dentry___138 *);
	void (*d_prune)(struct dentry___138 *);
	void (*d_iput)(struct dentry___138 *, struct inode___139 *);
	char * (*d_dname)(struct dentry___138 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___138 *);
	int (*d_manage)(const struct path___138 *, bool);
	struct dentry___138 * (*d_real)(struct dentry___138 *, const struct inode___139 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___138;

struct mem_dqinfo___138 {
	struct quota_format_type___138 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___138;

struct quota_info___138 {
	unsigned int flags;
	struct rw_semaphore___139 dqio_sem;
	struct inode___139 *files[3];
	struct mem_dqinfo___138 info[3];
	const struct quota_format_ops___138 *ops[3];
};

struct rcuwait___138 {
	struct task_struct___139 *task;
};

struct percpu_rw_semaphore___138 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___139 rw_sem;
	struct rcuwait___138 writer;
	int readers_block;
};

struct sb_writers___138 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___138 rw_sem[3];
};

struct shrink_control___54;

struct shrinker___54 {
	long unsigned int (*count_objects)(struct shrinker___54 *, struct shrink_control___54 *);
	long unsigned int (*scan_objects)(struct shrinker___54 *, struct shrink_control___54 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___138;

struct super_operations___138;

struct dquot_operations___138;

struct quotactl_ops___138;

struct super_block___138 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___138 *s_type;
	const struct super_operations___138 *s_op;
	const struct dquot_operations___138 *dq_op;
	const struct quotactl_ops___138 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___138 *s_root;
	struct rw_semaphore___139 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___139 *s_bdev;
	struct backing_dev_info___59 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___138 s_dquot;
	struct sb_writers___138 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___138 *s_d_op;
	int cleancache_poolid;
	struct shrinker___54 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___119 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___54 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___54 *memcg;
};

typedef int (*dev_page_fault_t___136)(struct vm_area_struct___139 *, long unsigned int, const struct page___139 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___136)(struct page___139 *, void *);

struct dev_pagemap___136 {
	dev_page_fault_t___136 page_fault;
	dev_page_free_t___136 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___130 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___138 {
	struct task_struct___139 *task;
	struct core_thread___138 *next;
};

struct core_state___138 {
	atomic_t nr_threads;
	struct core_thread___138 dumper;
	struct completion startup;
};

struct vm_fault___136 {
	struct vm_area_struct___139 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___139 *cow_page;
	struct mem_cgroup___54 *memcg;
	struct page___139 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___138 prealloc_pte;
};

struct io_cq___30 {
	struct request_queue___29 *q;
	struct io_context___30 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___3 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___139 {
	struct file___139 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___139 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___138 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___139 *ia_file;
};

struct dquot___138 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___138 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___138 {
	int qf_fmt_id;
	const struct quota_format_ops___138 *qf_ops;
	struct module___119 *qf_owner;
	struct quota_format_type___138 *qf_next;
};

struct quota_format_ops___138 {
	int (*check_quota_file)(struct super_block___138 *, int);
	int (*read_file_info)(struct super_block___138 *, int);
	int (*write_file_info)(struct super_block___138 *, int);
	int (*free_file_info)(struct super_block___138 *, int);
	int (*read_dqblk)(struct dquot___138 *);
	int (*commit_dqblk)(struct dquot___138 *);
	int (*release_dqblk)(struct dquot___138 *);
	int (*get_next_id)(struct super_block___138 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___138 {
	int (*write_dquot)(struct dquot___138 *);
	struct dquot___138 * (*alloc_dquot)(struct super_block___138 *, int);
	void (*destroy_dquot)(struct dquot___138 *);
	int (*acquire_dquot)(struct dquot___138 *);
	int (*release_dquot)(struct dquot___138 *);
	int (*mark_dirty)(struct dquot___138 *);
	int (*write_info)(struct super_block___138 *, int);
	qsize_t * (*get_reserved_space)(struct inode___139 *);
	int (*get_projid)(struct inode___139 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___139 *, qsize_t *);
	int (*get_next_id)(struct super_block___138 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___138 {
	int (*quota_on)(struct super_block___138 *, int, int, const struct path___138 *);
	int (*quota_off)(struct super_block___138 *, int);
	int (*quota_enable)(struct super_block___138 *, unsigned int);
	int (*quota_disable)(struct super_block___138 *, unsigned int);
	int (*quota_sync)(struct super_block___138 *, int);
	int (*set_info)(struct super_block___138 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___138 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___138 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___138 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___138 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___138 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___56;

struct swap_info_struct___38;

struct address_space_operations___138 {
	int (*writepage)(struct page___139 *, struct writeback_control___56 *);
	int (*readpage)(struct file___139 *, struct page___139 *);
	int (*writepages)(struct address_space___138 *, struct writeback_control___56 *);
	int (*set_page_dirty)(struct page___139 *);
	int (*readpages)(struct file___139 *, struct address_space___138 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___139 *, struct address_space___138 *, loff_t, unsigned int, unsigned int, struct page___139 **, void **);
	int (*write_end)(struct file___139 *, struct address_space___138 *, loff_t, unsigned int, unsigned int, struct page___139 *, void *);
	sector_t (*bmap)(struct address_space___138 *, sector_t);
	void (*invalidatepage)(struct page___139 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___139 *, gfp_t);
	void (*freepage)(struct page___139 *);
	ssize_t (*direct_IO)(struct kiocb___139 *, struct iov_iter___62 *);
	int (*migratepage)(struct address_space___138 *, struct page___139 *, struct page___139 *, enum migrate_mode);
	bool (*isolate_page)(struct page___139 *, isolate_mode_t);
	void (*putback_page)(struct page___139 *);
	int (*launder_page)(struct page___139 *);
	int (*is_partially_uptodate)(struct page___139 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___139 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___138 *, struct page___139 *);
	int (*swap_activate)(struct swap_info_struct___38 *, struct file___139 *, sector_t *);
	void (*swap_deactivate)(struct file___139 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___56 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___59 *wb;
	struct inode___139 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___59;

struct iov_iter___62 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___59 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct swap_info_struct___38 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___139 *bdev;
	struct file___139 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct hd_struct___29;

struct gendisk___29;

struct block_device___139 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___139 *bd_inode;
	struct super_block___138 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___139 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___29 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___29 *bd_disk;
	struct request_queue___29 *bd_queue;
	struct backing_dev_info___59 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct hd_struct___29 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___130 __dev;
	struct kobject___133 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___29;

struct block_device_operations___29;

struct gendisk___29 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___29 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___29 *part_tbl;
	struct hd_struct___29 part0;
	const struct block_device_operations___29 *fops;
	struct request_queue___29 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___139 lookup_sem;
	struct kobject___133 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___133 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___138 {
	struct dentry___138 * (*lookup)(struct inode___139 *, struct dentry___138 *, unsigned int);
	const char * (*get_link)(struct dentry___138 *, struct inode___139 *, struct delayed_call *);
	int (*permission)(struct inode___139 *, int);
	struct posix_acl * (*get_acl)(struct inode___139 *, int);
	int (*readlink)(struct dentry___138 *, char *, int);
	int (*create)(struct inode___139 *, struct dentry___138 *, umode_t, bool);
	int (*link)(struct dentry___138 *, struct inode___139 *, struct dentry___138 *);
	int (*unlink)(struct inode___139 *, struct dentry___138 *);
	int (*symlink)(struct inode___139 *, struct dentry___138 *, const char *);
	int (*mkdir)(struct inode___139 *, struct dentry___138 *, umode_t);
	int (*rmdir)(struct inode___139 *, struct dentry___138 *);
	int (*mknod)(struct inode___139 *, struct dentry___138 *, umode_t, dev_t);
	int (*rename)(struct inode___139 *, struct dentry___138 *, struct inode___139 *, struct dentry___138 *, unsigned int);
	int (*setattr)(struct dentry___138 *, struct iattr___138 *);
	int (*getattr)(const struct path___138 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___138 *, char *, size_t);
	int (*fiemap)(struct inode___139 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___139 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___139 *, struct dentry___138 *, struct file___139 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___139 *, struct dentry___138 *, umode_t);
	int (*set_acl)(struct inode___139 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___138 {
	void (*fl_copy_lock)(struct file_lock___139 *, struct file_lock___139 *);
	void (*fl_release_private)(struct file_lock___139 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___138;

struct file_lock___139 {
	struct file_lock___139 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___139 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___138 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___138 *fl_ops;
	const struct lock_manager_operations___138 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___138 {
	int (*lm_compare_owner)(struct file_lock___139 *, struct file_lock___139 *);
	long unsigned int (*lm_owner_key)(struct file_lock___139 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___139 *);
	int (*lm_grant)(struct file_lock___139 *, int);
	bool (*lm_break)(struct file_lock___139 *);
	int (*lm_change)(struct file_lock___139 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___139 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___138 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___138 *fa_next;
	struct file___139 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___138 {
	const char *name;
	int fs_flags;
	struct dentry___138 * (*mount)(struct file_system_type___138 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___138 *);
	struct module___119 *owner;
	struct file_system_type___138 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___138 {
	struct inode___139 * (*alloc_inode)(struct super_block___138 *);
	void (*destroy_inode)(struct inode___139 *);
	void (*dirty_inode)(struct inode___139 *, int);
	int (*write_inode)(struct inode___139 *, struct writeback_control___56 *);
	int (*drop_inode)(struct inode___139 *);
	void (*evict_inode)(struct inode___139 *);
	void (*put_super)(struct super_block___138 *);
	int (*sync_fs)(struct super_block___138 *, int);
	int (*freeze_super)(struct super_block___138 *);
	int (*freeze_fs)(struct super_block___138 *);
	int (*thaw_super)(struct super_block___138 *);
	int (*unfreeze_fs)(struct super_block___138 *);
	int (*statfs)(struct dentry___138 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___138 *, int *, char *);
	void (*umount_begin)(struct super_block___138 *);
	int (*show_options)(struct seq_file___129 *, struct dentry___138 *);
	int (*show_devname)(struct seq_file___129 *, struct dentry___138 *);
	int (*show_path)(struct seq_file___129 *, struct dentry___138 *);
	int (*show_stats)(struct seq_file___129 *, struct dentry___138 *);
	ssize_t (*quota_read)(struct super_block___138 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___138 *, int, const char *, size_t, loff_t);
	struct dquot___138 ** (*get_dquots)(struct inode___139 *);
	int (*bdev_try_to_free_page)(struct super_block___138 *, struct page___139 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___138 *, struct shrink_control___54 *);
	long int (*free_cached_objects)(struct super_block___138 *, struct shrink_control___54 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___59(struct bio___59 *);

struct bio_vec___59 {
	struct page___139 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___59;

struct bio___59 {
	struct bio___59 *bi_next;
	struct gendisk___29 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___59 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___20 *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___59 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___59 *bi_io_vec;
	struct bio_set___59 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___59 bi_inline_vecs[0];
};

typedef int (*key_restrict_link_func_t___134)(struct key___134 *, const struct key_type *, const union key_payload *, struct key___134 *);

struct key_restriction___134;

struct key___134 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___139 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___134 *restrict_link;
};

struct key_restriction___134 {
	key_restrict_link_func_t___134 check;
	struct key___134 *key;
	struct key_type *keytype;
};

struct seq_operations___127 {
	void * (*start)(struct seq_file___129 *, loff_t *);
	void (*stop)(struct seq_file___129 *, void *);
	void * (*next)(struct seq_file___129 *, void *, loff_t *);
	int (*show)(struct seq_file___129 *, void *);
};

struct cgroup_namespace___115 {
	refcount_t count;
	struct ns_common___4 ns;
	struct user_namespace___119 *user_ns;
	struct ucounts___119 *ucounts;
	struct css_set___115 *root_cset;
};

struct ucounts___119 {
	struct hlist_node node;
	struct user_namespace___119 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___115;

struct bpf_map_ops___115 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___115 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___115 *, struct file___139 *);
	void (*map_free)(struct bpf_map___115 *);
	int (*map_get_next_key)(struct bpf_map___115 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___115 *);
	void * (*map_lookup_elem)(struct bpf_map___115 *, void *);
	int (*map_update_elem)(struct bpf_map___115 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___115 *, void *);
	int (*map_push_elem)(struct bpf_map___115 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___115 *, void *);
	int (*map_peek_elem)(struct bpf_map___115 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___115 *, struct file___139 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___115 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___115 *, void *, struct seq_file___129 *);
	int (*map_check_btf)(const struct bpf_map___115 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___115 {
	const struct bpf_map_ops___115 *ops;
	struct bpf_map___115 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___134 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___115;

typedef void (*kthread_work_func_t___115)(struct kthread_work___115 *);

struct kthread_worker___115;

struct kthread_work___115 {
	struct list_head node;
	kthread_work_func_t___115 func;
	struct kthread_worker___115 *worker;
	int canceling;
};

struct kthread_worker___115 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___139 *task;
	struct kthread_work___115 *current_work;
};

struct kthread_delayed_work___115 {
	struct kthread_work___115 work;
	struct timer_list timer;
};

struct psi_group___115 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___115 *poll_kworker;
	struct kthread_delayed_work___115 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___115;

struct cgroup_rstat_cpu___115;

struct cgroup___115 {
	struct cgroup_subsys_state___115 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___135 *kn;
	struct cgroup_file___115 procs_file;
	struct cgroup_file___115 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___115 *subsys[13];
	struct cgroup_root___115 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___115 *dom_cgrp;
	struct cgroup_rstat_cpu___115 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___4 bpf;
	atomic_t congestion_count;
	struct cgroup___115 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___115 psi;
	int ancestor_ids[0];
};

struct cftype___115;

struct cgroup_subsys___115 {
	struct cgroup_subsys_state___115 * (*css_alloc)(struct cgroup_subsys_state___115 *);
	int (*css_online)(struct cgroup_subsys_state___115 *);
	void (*css_offline)(struct cgroup_subsys_state___115 *);
	void (*css_released)(struct cgroup_subsys_state___115 *);
	void (*css_free)(struct cgroup_subsys_state___115 *);
	void (*css_reset)(struct cgroup_subsys_state___115 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___115 *, int);
	int (*css_extra_stat_show)(struct seq_file___129 *, struct cgroup_subsys_state___115 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___139 *);
	void (*cancel_fork)(struct task_struct___139 *);
	void (*fork)(struct task_struct___139 *);
	void (*exit)(struct task_struct___139 *);
	void (*free)(struct task_struct___139 *);
	void (*bind)(struct cgroup_subsys_state___115 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___115 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___115 *dfl_cftypes;
	struct cftype___115 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___115 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___115 *updated_children;
	struct cgroup___115 *updated_next;
};

struct cgroup_root___115 {
	struct kernfs_root___135 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___115 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___115 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___115 *ss;
	struct list_head node;
	struct kernfs_ops___135 *kf_ops;
	int (*open)(struct kernfs_open_file___135 *);
	void (*release)(struct kernfs_open_file___135 *);
	u64 (*read_u64)(struct cgroup_subsys_state___115 *, struct cftype___115 *);
	s64 (*read_s64)(struct cgroup_subsys_state___115 *, struct cftype___115 *);
	int (*seq_show)(struct seq_file___129 *, void *);
	void * (*seq_start)(struct seq_file___129 *, loff_t *);
	void * (*seq_next)(struct seq_file___129 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___129 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___115 *, struct cftype___115 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___115 *, struct cftype___115 *, s64);
	ssize_t (*write)(struct kernfs_open_file___135 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___135 *, struct poll_table_struct___95 *);
};

typedef void compound_page_dtor___136(struct page___139 *);

struct bdi_writeback_congested___59 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___59 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___59 {
	struct bio___59 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___59 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___59 bip_inline_vecs[0];
};

struct blkcg___20;

struct blkg_policy_data___20;

struct blkcg_gq___20 {
	struct request_queue___29 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___20 *blkcg;
	struct bdi_writeback_congested___59 *wb_congested;
	struct blkcg_gq___20 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_rwstat stat_bytes;
	struct blkg_rwstat stat_ios;
	struct blkg_policy_data___20 *pd[5];
	struct callback_head callback_head;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
};

struct mem_cgroup_reclaim_iter___54 {
	struct mem_cgroup___54 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___54 {
	struct lruvec___138 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___54 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___54 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct hstate___17 {
	int next_nid_to_alloc;
	int next_nid_to_free;
	unsigned int order;
	long unsigned int mask;
	long unsigned int max_huge_pages;
	long unsigned int nr_huge_pages;
	long unsigned int free_huge_pages;
	long unsigned int resv_huge_pages;
	long unsigned int surplus_huge_pages;
	long unsigned int nr_overcommit_huge_pages;
	struct list_head hugepage_activelist;
	struct list_head hugepage_freelists[8];
	unsigned int nr_huge_pages_node[8];
	unsigned int free_huge_pages_node[8];
	unsigned int surplus_huge_pages_node[8];
	struct cftype___115 cgroup_files[5];
	char name[32];
};

struct disk_part_tbl___29 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___29 *last_lookup;
	struct hd_struct___29 *part[0];
};

struct block_device_operations___29 {
	int (*open)(struct block_device___139 *, fmode_t);
	void (*release)(struct gendisk___29 *, fmode_t);
	int (*rw_page)(struct block_device___139 *, sector_t, struct page___139 *, unsigned int);
	int (*ioctl)(struct block_device___139 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___139 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___29 *, unsigned int);
	int (*media_changed)(struct gendisk___29 *);
	void (*unlock_native_capacity)(struct gendisk___29 *);
	int (*revalidate_disk)(struct gendisk___29 *);
	int (*getgeo)(struct block_device___139 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___139 *, long unsigned int);
	int (*report_zones)(struct gendisk___29 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___119 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___28 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___29 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___29 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___29 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___28(struct request___29 *, blk_status_t);

struct request___29 {
	struct request_queue___29 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___59 *bio;
	struct bio___59 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___59 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___30 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___28 *saved_end_io;
		} flush;
	};
	struct gendisk___29 *rq_disk;
	struct hd_struct___29 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___28 *end_io;
	void *end_io_data;
	struct request___29 *next_rq;
};

struct fwnode_reference_args___98;

struct fwnode_endpoint___98;

struct fwnode_operations___98 {
	struct fwnode_handle___98 * (*get)(struct fwnode_handle___98 *);
	void (*put)(struct fwnode_handle___98 *);
	bool (*device_is_available)(const struct fwnode_handle___98 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___98 *, const struct device___130 *);
	bool (*property_present)(const struct fwnode_handle___98 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___98 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___98 *, const char *, const char **, size_t);
	struct fwnode_handle___98 * (*get_parent)(const struct fwnode_handle___98 *);
	struct fwnode_handle___98 * (*get_next_child_node)(const struct fwnode_handle___98 *, struct fwnode_handle___98 *);
	struct fwnode_handle___98 * (*get_named_child_node)(const struct fwnode_handle___98 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___98 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___98 *);
	struct fwnode_handle___98 * (*graph_get_next_endpoint)(const struct fwnode_handle___98 *, struct fwnode_handle___98 *);
	struct fwnode_handle___98 * (*graph_get_remote_endpoint)(const struct fwnode_handle___98 *);
	struct fwnode_handle___98 * (*graph_get_port_parent)(struct fwnode_handle___98 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___98 *, struct fwnode_endpoint___98 *);
};

struct fwnode_endpoint___98 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___98 *local_fwnode;
};

struct fwnode_reference_args___98 {
	struct fwnode_handle___98 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct elevator_type___28;

struct elevator_mq_ops___28 {
	int (*init_sched)(struct request_queue___29 *, struct elevator_type___28 *);
	void (*exit_sched)(struct elevator_queue___28 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	bool (*allow_merge)(struct request_queue___29 *, struct request___29 *, struct bio___59 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx *, struct bio___59 *);
	int (*request_merge)(struct request_queue___29 *, struct request___29 **, struct bio___59 *);
	void (*request_merged)(struct request_queue___29 *, struct request___29 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___29 *, struct request___29 *, struct request___29 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___29 *, struct bio___59 *);
	void (*finish_request)(struct request___29 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___29 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___29 *, u64);
	void (*started_request)(struct request___29 *);
	void (*requeue_request)(struct request___29 *);
	struct request___29 * (*former_request)(struct request_queue___29 *, struct request___29 *);
	struct request___29 * (*next_request)(struct request_queue___29 *, struct request___29 *);
	void (*init_icq)(struct io_cq___30 *);
	void (*exit_icq)(struct io_cq___30 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___28;

struct elevator_type___28 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___28 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___28 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___119 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___28 {
	struct elevator_type___28 *type;
	void *elevator_data;
	struct kobject___133 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___28 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___28 *, char *);
	ssize_t (*store)(struct elevator_queue___28 *, const char *, size_t);
};

struct blkcg_policy_data___20;

struct blkcg___20 {
	struct cgroup_subsys_state___115 css;
	spinlock_t lock;
	struct xarray blkg_tree;
	struct blkcg_gq___20 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___20 *cpd[5];
	struct list_head all_blkcgs_node;
	struct list_head cgwb_list;
	refcount_t cgwb_refcnt;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct blkcg_policy_data___20 {
	struct blkcg___20 *blkcg;
	int plid;
};

struct blkg_policy_data___20 {
	struct blkcg_gq___20 *blkg;
	int plid;
};

struct alloc_context___2 {
	struct zonelist___138 *zonelist;
	nodemask_t *nodemask;
	struct zoneref___138 *preferred_zoneref;
	int migratetype;
	enum zone_type high_zoneidx;
	bool spread_dirty_pages;
};

struct compact_control___2 {
	struct list_head freepages;
	struct list_head migratepages;
	struct zone___138 *zone;
	long unsigned int nr_freepages;
	long unsigned int nr_migratepages;
	long unsigned int total_migrate_scanned;
	long unsigned int total_free_scanned;
	long unsigned int free_pfn;
	long unsigned int migrate_pfn;
	long unsigned int last_migrated_pfn;
	const gfp_t gfp_mask;
	int order;
	int migratetype;
	const unsigned int alloc_flags;
	const int classzone_idx;
	enum migrate_mode mode;
	bool ignore_skip_hint;
	bool no_set_skip_hint;
	bool ignore_block_suitable;
	bool direct_compaction;
	bool whole_zone;
	bool contended;
	bool finishing_block;
};

struct kernel_param_ops___116 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___116 *);
	int (*get)(char *, const struct kernel_param___116 *);
	void (*free)(void *);
};

struct kparam_array___116;

struct kernel_param___116 {
	const char *name;
	struct module___119 *mod;
	const struct kernel_param_ops___116 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___116 *arr;
	};
};

struct kparam_array___116 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___116 *ops;
	void *elem;
};

struct module_attribute___116 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___116 *, struct module_kobject___116 *, char *);
	ssize_t (*store)(struct module_attribute___116 *, struct module_kobject___116 *, const char *, size_t);
	void (*setup)(struct module___119 *, const char *);
	int (*test)(struct module___119 *);
	void (*free)(struct module___119 *);
};

struct trace_event_class___79;

struct trace_event_call___79 {
	struct list_head list;
	struct trace_event_class___79 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___4 *prog_array;
	int (*perf_perm)(struct trace_event_call___79 *, struct perf_event___86 *);
};

struct perf_cpu_context___86;

struct pmu___86 {
	struct list_head entry;
	struct module___119 *module;
	struct device___130 *dev;
	const struct attribute_group___129 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___86 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___86 *);
	void (*pmu_disable)(struct pmu___86 *);
	int (*event_init)(struct perf_event___86 *);
	void (*event_mapped)(struct perf_event___86 *, struct mm_struct___138 *);
	void (*event_unmapped)(struct perf_event___86 *, struct mm_struct___138 *);
	int (*add)(struct perf_event___86 *, int);
	void (*del)(struct perf_event___86 *, int);
	void (*start)(struct perf_event___86 *, int);
	void (*stop)(struct perf_event___86 *, int);
	void (*read)(struct perf_event___86 *);
	void (*start_txn)(struct pmu___86 *, unsigned int);
	int (*commit_txn)(struct pmu___86 *);
	void (*cancel_txn)(struct pmu___86 *);
	int (*event_idx)(struct perf_event___86 *);
	void (*sched_task)(struct perf_event_context___86 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___86 *);
	int (*filter_match)(struct perf_event___86 *);
	int (*check_period)(struct perf_event___86 *, u64);
};

struct perf_cpu_context___86 {
	struct perf_event_context___86 ctx;
	struct perf_event_context___86 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___86 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___86 {
	struct cgroup_subsys_state___115 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___79 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___79 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___79 *);
	struct list_head * (*get_fields)(struct trace_event_call___79 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___79 *);
};

struct trace_event_file___39;

struct trace_event_buffer___31 {
	struct ring_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___39 *trace_file;
	void *entry;
	long unsigned int flags;
	int pc;
};

struct trace_event_file___39 {
	struct list_head list;
	struct trace_event_call___79 *event_call;
	struct event_filter *filter;
	struct dentry___138 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_mm_compaction_isolate_template {
	struct trace_entry ent;
	long unsigned int start_pfn;
	long unsigned int end_pfn;
	long unsigned int nr_scanned;
	long unsigned int nr_taken;
	char __data[0];
};

struct trace_event_raw_mm_compaction_migratepages {
	struct trace_entry ent;
	long unsigned int nr_migrated;
	long unsigned int nr_failed;
	char __data[0];
};

struct trace_event_raw_mm_compaction_begin {
	struct trace_entry ent;
	long unsigned int zone_start;
	long unsigned int migrate_pfn;
	long unsigned int free_pfn;
	long unsigned int zone_end;
	bool sync;
	char __data[0];
};

struct trace_event_raw_mm_compaction_end {
	struct trace_entry ent;
	long unsigned int zone_start;
	long unsigned int migrate_pfn;
	long unsigned int free_pfn;
	long unsigned int zone_end;
	bool sync;
	int status;
	char __data[0];
};

struct trace_event_raw_mm_compaction_try_to_compact_pages {
	struct trace_entry ent;
	int order;
	gfp_t gfp_mask;
	int prio;
	char __data[0];
};

struct trace_event_raw_mm_compaction_suitable_template {
	struct trace_entry ent;
	int nid;
	enum zone_type idx;
	int order;
	int ret;
	char __data[0];
};

struct trace_event_raw_mm_compaction_defer_template {
	struct trace_entry ent;
	int nid;
	enum zone_type idx;
	int order;
	unsigned int considered;
	unsigned int defer_shift;
	int order_failed;
	char __data[0];
};

struct trace_event_raw_mm_compaction_kcompactd_sleep {
	struct trace_entry ent;
	int nid;
	char __data[0];
};

struct trace_event_raw_kcompactd_wake_template {
	struct trace_entry ent;
	int nid;
	int order;
	enum zone_type classzone_idx;
	char __data[0];
};

struct trace_event_data_offsets_mm_compaction_isolate_template {};

struct trace_event_data_offsets_mm_compaction_migratepages {};

struct trace_event_data_offsets_mm_compaction_begin {};

struct trace_event_data_offsets_mm_compaction_end {};

struct trace_event_data_offsets_mm_compaction_try_to_compact_pages {};

struct trace_event_data_offsets_mm_compaction_suitable_template {};

struct trace_event_data_offsets_mm_compaction_defer_template {};

struct trace_event_data_offsets_mm_compaction_kcompactd_sleep {};

struct trace_event_data_offsets_kcompactd_wake_template {};

typedef enum {
	ISOLATE_ABORT = 0,
	ISOLATE_NONE = 1,
	ISOLATE_SUCCESS = 2,
} isolate_migrate_t;

struct anon_vma_chain {
	struct vm_area_struct___131 *vma;
	struct anon_vma___5 *anon_vma;
	struct list_head same_vma;
	struct rb_node rb;
	long unsigned int rb_subtree_last;
};

struct rb_augment_callbacks {
	void (*propagate)(struct rb_node *, struct rb_node *);
	void (*copy)(struct rb_node *, struct rb_node *);
	void (*rotate)(struct rb_node *, struct rb_node *);
};

struct module___120;

struct file___140;

struct kiocb___140;

struct vm_area_struct___140;

struct inode___140;

struct file_lock___140;

struct page___140;

struct seq_file___130;

struct file_operations___140 {
	struct module___120 *owner;
	loff_t (*llseek)(struct file___140 *, loff_t, int);
	ssize_t (*read)(struct file___140 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___140 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___140 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___140 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___140 *, bool);
	int (*iterate)(struct file___140 *, struct dir_context *);
	int (*iterate_shared)(struct file___140 *, struct dir_context *);
	__poll_t (*poll)(struct file___140 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___140 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___140 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___140 *, struct vm_area_struct___140 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___140 *, struct file___140 *);
	int (*flush)(struct file___140 *, fl_owner_t);
	int (*release)(struct inode___140 *, struct file___140 *);
	int (*fsync)(struct file___140 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___140 *, int);
	int (*lock)(struct file___140 *, int, struct file_lock___140 *);
	ssize_t (*sendpage)(struct file___140 *, struct page___140 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___140 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___140 *, int, struct file_lock___140 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___140 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___140 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___140 *, long int, struct file_lock___140 **, void **);
	long int (*fallocate)(struct file___140 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___130 *, struct file___140 *);
	ssize_t (*copy_file_range)(struct file___140 *, loff_t, struct file___140 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___140 *, loff_t, struct file___140 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___140 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___139 {
	u64 seqnum;
	struct vm_area_struct___140 *vmas[4];
};

struct page_frag___139 {
	struct page___140 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___139;

struct mem_cgroup___55;

struct cred___135;

struct nsproxy___132;

struct bio_list___60;

struct backing_dev_info___60;

struct io_context___31;

struct css_set___116;

struct vm_struct___108;

struct task_struct___140 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___140 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___139 *mm;
	struct mm_struct___139 *active_mm;
	struct vmacache___139 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___140 *real_parent;
	struct task_struct___140 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___140 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___55 *active_memcg;
	long int rh_reserved2;
	struct pid___112 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___112 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___112 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___135 *ptracer_cred;
	const struct cred___135 *real_cred;
	const struct cred___135 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___132 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___140 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___60 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___60 *backing_dev_info;
	struct io_context___31 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___116 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___139 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___55 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___140 *oom_reaper_list;
	struct vm_struct___108 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___86 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rw_semaphore___140 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___140 *owner;
};

struct key___135;

struct ucounts___120;

struct user_namespace___120 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___120 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___4 ns;
	long unsigned int flags;
	struct key___135 *persistent_keyring_register;
	struct rw_semaphore___140 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___120 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___140 *pgtable_t___139;

struct address_space___139;

struct kmem_cache___4;

struct dev_pagemap___137;

struct page___140 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___139 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___140 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache___4 *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___139 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___139 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___137 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___55 *mem_cgroup;
};

struct pglist_data___139;

struct lruvec___139 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___139 *pgdat;
};

struct zone___139 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___139 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___139 {
	struct zone___139 *zone;
	int zone_idx;
};

struct zonelist___139 {
	struct zoneref___139 _zonerefs[25];
};

struct pglist_data___139 {
	struct zone___139 node_zones[3];
	struct zonelist___139 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___140 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___140 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___139 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___140 {
	void *stack;
	struct task_struct___140 *task;
	long int status;
};

struct blocking_notifier_head___139 {
	struct rw_semaphore___140 rwsem;
	struct notifier_block *head;
};

struct dentry___139;

struct path___139 {
	struct vfsmount *mnt;
	struct dentry___139 *dentry;
};

struct file___140 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___139 f_path;
	struct inode___140 *f_inode;
	const struct file_operations___140 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___112 f_owner;
	const struct cred___135 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___139 *f_mapping;
	errseq_t f_wb_err;
};

struct user_struct___135;

struct cred___135 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___135 *session_keyring;
	struct key___135 *process_keyring;
	struct key___135 *thread_keyring;
	struct key___135 *request_key_auth;
	void *security;
	struct user_struct___135 *user;
	struct user_namespace___120 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___136;

struct kernfs_elem_dir___136 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___136 *root;
};

struct kernfs_node___136;

struct kernfs_syscall_ops___136;

struct kernfs_root___136 {
	struct kernfs_node___136 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___136 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___136 {
	struct kernfs_node___136 *target_kn;
};

struct kernfs_ops___136;

struct kernfs_elem_attr___136 {
	const struct kernfs_ops___136 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___136 *notify_next;
};

struct kernfs_node___136 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___136 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___136 dir;
		struct kernfs_elem_symlink___136 symlink;
		struct kernfs_elem_attr___136 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___136;

struct kernfs_ops___136 {
	int (*open)(struct kernfs_open_file___136 *);
	void (*release)(struct kernfs_open_file___136 *);
	int (*seq_show)(struct seq_file___130 *, void *);
	void * (*seq_start)(struct seq_file___130 *, loff_t *);
	void * (*seq_next)(struct seq_file___130 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___130 *, void *);
	ssize_t (*read)(struct kernfs_open_file___136 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___136 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___136 *, struct vm_area_struct___140 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___136 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___136 {
	int (*remount_fs)(struct kernfs_root___136 *, int *, char *);
	int (*show_options)(struct seq_file___130 *, struct kernfs_root___136 *);
	int (*mkdir)(struct kernfs_node___136 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___136 *);
	int (*rename)(struct kernfs_node___136 *, struct kernfs_node___136 *, const char *);
	int (*show_path)(struct seq_file___130 *, struct kernfs_node___136 *, struct kernfs_root___136 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___128;

struct seq_file___130 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___128 *op;
	int poll_event;
	const struct file___140 *file;
	void *private;
};

struct vm_operations_struct___137;

struct kernfs_open_file___136 {
	struct kernfs_node___136 *kn;
	struct file___140 *file;
	struct seq_file___130 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___137 *vm_ops;
};

struct vm_fault___137;

struct vm_operations_struct___137 {
	void (*open)(struct vm_area_struct___140 *);
	void (*close)(struct vm_area_struct___140 *);
	int (*split)(struct vm_area_struct___140 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___140 *);
	vm_fault_t (*fault)(struct vm_fault___137 *);
	vm_fault_t (*huge_fault)(struct vm_fault___137 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___137 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___140 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___137 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___137 *);
	int (*access)(struct vm_area_struct___140 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___140 *);
	int (*set_policy)(struct vm_area_struct___140 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___140 *, long unsigned int);
	struct page___140 * (*find_special_page)(struct vm_area_struct___140 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_area_struct___140 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___140 *vm_next;
	struct vm_area_struct___140 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___139 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___137 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___140 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___133;

struct kobj_type___133;

struct kobject___134 {
	const char *name;
	struct list_head entry;
	struct kobject___134 *parent;
	struct kset___133 *kset;
	struct kobj_type___133 *ktype;
	struct kernfs_node___136 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sysfs_ops___133 {
	ssize_t (*show)(struct kobject___134 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___134 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___133;

struct kset___133 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___134 kobj;
	const struct kset_uevent_ops___133 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___133 {
	void (*release)(struct kobject___134 *);
	const struct sysfs_ops___133 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___2 * (*child_ns_type)(struct kobject___134 *);
	const void * (*namespace)(struct kobject___134 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___133 {
	int (* const filter)(struct kset___133 *, struct kobject___134 *);
	const char * (* const name)(struct kset___133 *, struct kobject___134 *);
	int (* const uevent)(struct kset___133 *, struct kobject___134 *, struct kobj_uevent_env *);
};

struct kobj_attribute___134 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___134 *, struct kobj_attribute___134 *, char *);
	ssize_t (*store)(struct kobject___134 *, struct kobj_attribute___134 *, const char *, size_t);
};

struct kernel_param___117;

struct kernel_param_ops___117 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___117 *);
	int (*get)(char *, const struct kernel_param___117 *);
	void (*free)(void *);
};

struct kparam_array___117;

struct kernel_param___117 {
	const char *name;
	struct module___120 *mod;
	const struct kernel_param_ops___117 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___117 *arr;
	};
};

struct kparam_array___117 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___117 *ops;
	void *elem;
};

struct module_kobject___117 {
	struct kobject___134 kobj;
	struct module___120 *mod;
	struct kobject___134 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___117 {
	struct module___120 *mod;
	struct latch_tree_node node;
};

struct module_layout___117 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___117 mtn;
};

struct module_attribute___117;

struct module___120 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___117 mkobj;
	struct module_attribute___117 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___134 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___117 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___117 core_layout;
	struct module_layout___117 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___117 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___117 *, struct module_kobject___117 *, char *);
	ssize_t (*store)(struct module_attribute___117 *, struct module_kobject___117 *, const char *, size_t);
	void (*setup)(struct module___120 *, const char *);
	int (*test)(struct module___120 *);
	void (*free)(struct module___120 *);
};

struct core_state___139;

struct mm_struct___139 {
	struct {
		struct vm_area_struct___140 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___140 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___140 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___139 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___140 *owner;
		struct user_namespace___120 *user_ns;
		struct file___140 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___139 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___139;

struct address_space___139 {
	struct inode___140 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___140 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___139 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct memcg_cache_array___4;

struct memcg_cache_params___4 {
	struct kmem_cache___4 *root_cache;
	union {
		struct {
			struct memcg_cache_array___4 *memcg_caches;
			struct list_head __root_caches_node;
			struct list_head children;
			bool dying;
		};
		struct {
			struct mem_cgroup___55 *memcg;
			struct list_head children_node;
			struct list_head kmem_caches_node;
			struct percpu_ref refcnt;
			void (*work_fn)(struct kmem_cache___4 *);
			union {
				struct callback_head callback_head;
				struct work_struct work;
			};
		};
	};
};

struct kmem_cache_cpu___4;

struct kmem_cache___4 {
	struct kmem_cache_cpu___4 *cpu_slab;
	slab_flags_t flags;
	long unsigned int min_partial;
	unsigned int size;
	unsigned int object_size;
	unsigned int offset;
	unsigned int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	unsigned int inuse;
	unsigned int align;
	unsigned int red_left_pad;
	const char *name;
	struct list_head list;
	struct kobject___134 kobj;
	struct work_struct kobj_remove_work;
	struct memcg_cache_params___4 memcg_params;
	unsigned int max_attr_size;
	struct kset___133 *memcg_kset;
	unsigned int remote_node_defrag_ratio;
	unsigned int *random_seq;
	unsigned int useroffset;
	unsigned int usersize;
	struct kmem_cache_node *node[8];
};

typedef int (*dev_page_fault_t___137)(struct vm_area_struct___140 *, long unsigned int, const struct page___140 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___137)(struct page___140 *, void *);

struct dev_pagemap___137 {
	dev_page_fault_t___137 page_fault;
	dev_page_free_t___137 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___6 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct cgroup___116;

struct cgroup_subsys___116;

struct cgroup_subsys_state___116 {
	struct cgroup___116 *cgroup;
	struct cgroup_subsys___116 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___116 *parent;
};

struct cgroup_file___116 {
	struct kernfs_node___136 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___55;

struct mem_cgroup___55 {
	struct cgroup_subsys_state___116 css;
	struct mem_cgroup_id___2 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___116 events_file;
	struct cgroup_file___116 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___140 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___55 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct core_thread___139 {
	struct task_struct___140 *task;
	struct core_thread___139 *next;
};

struct core_state___139 {
	atomic_t nr_threads;
	struct core_thread___139 dumper;
	struct completion startup;
};

struct vm_fault___137 {
	struct vm_area_struct___140 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___140 *cow_page;
	struct mem_cgroup___55 *memcg;
	struct page___140 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___139 prealloc_pte;
};

struct shrink_control___55 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___55 *memcg;
};

struct shrinker___55 {
	long unsigned int (*count_objects)(struct shrinker___55 *, struct shrink_control___55 *);
	long unsigned int (*scan_objects)(struct shrinker___55 *, struct shrink_control___55 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct user_struct___135 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___135 *uid_keyring;
	struct key___135 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cgroup_namespace___116;

struct nsproxy___132 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___116 *cgroup_ns;
};

struct bio___60;

struct bio_list___60 {
	struct bio___60 *head;
	struct bio___60 *tail;
};

struct bdi_writeback_congested___60;

struct bdi_writeback___60 {
	struct backing_dev_info___60 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___60 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___116 *memcg_css;
	struct cgroup_subsys_state___116 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___60 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___60 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___6 *dev;
	struct device___6 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___139 *debug_dir;
	struct dentry___139 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___31;

struct io_context___31 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___31 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___116 {
	struct cgroup_subsys_state___116 *subsys[13];
	refcount_t refcount;
	struct css_set___116 *dom_cset;
	struct cgroup___116 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___116 *mg_src_cgrp;
	struct cgroup___116 *mg_dst_cgrp;
	struct css_set___116 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct vm_struct___108 {
	struct vm_struct___108 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___140 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dentry_operations___139;

struct super_block___139;

struct dentry___139 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___139 *d_parent;
	struct qstr d_name;
	struct inode___140 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___139 *d_op;
	struct super_block___139 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___139;

struct block_device___140;

struct inode___140 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___139 *i_op;
	struct super_block___139 *i_sb;
	struct address_space___139 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___140 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___60 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___140 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___139 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___140 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___139 {
	int (*d_revalidate)(struct dentry___139 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___139 *, unsigned int);
	int (*d_hash)(const struct dentry___139 *, struct qstr *);
	int (*d_compare)(const struct dentry___139 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___139 *);
	int (*d_init)(struct dentry___139 *);
	void (*d_release)(struct dentry___139 *);
	void (*d_prune)(struct dentry___139 *);
	void (*d_iput)(struct dentry___139 *, struct inode___140 *);
	char * (*d_dname)(struct dentry___139 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___139 *);
	int (*d_manage)(const struct path___139 *, bool);
	struct dentry___139 * (*d_real)(struct dentry___139 *, const struct inode___140 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___139;

struct mem_dqinfo___139 {
	struct quota_format_type___139 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___139;

struct quota_info___139 {
	unsigned int flags;
	struct rw_semaphore___140 dqio_sem;
	struct inode___140 *files[3];
	struct mem_dqinfo___139 info[3];
	const struct quota_format_ops___139 *ops[3];
};

struct rcuwait___139 {
	struct task_struct___140 *task;
};

struct percpu_rw_semaphore___139 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___140 rw_sem;
	struct rcuwait___139 writer;
	int readers_block;
};

struct sb_writers___139 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___139 rw_sem[3];
};

struct file_system_type___139;

struct super_operations___139;

struct dquot_operations___139;

struct quotactl_ops___139;

struct super_block___139 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___139 *s_type;
	const struct super_operations___139 *s_op;
	const struct dquot_operations___139 *dq_op;
	const struct quotactl_ops___139 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___139 *s_root;
	struct rw_semaphore___140 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___140 *s_bdev;
	struct backing_dev_info___60 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___139 s_dquot;
	struct sb_writers___139 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___139 *s_d_op;
	int cleancache_poolid;
	struct shrinker___55 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___120 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

enum lru_status {
	LRU_REMOVED = 0,
	LRU_REMOVED_RETRY = 1,
	LRU_ROTATE = 2,
	LRU_SKIP = 3,
	LRU_RETRY = 4,
};

typedef enum lru_status (*list_lru_walk_cb)(struct list_head *, struct list_lru_one *, spinlock_t *, void *);

struct io_cq___31 {
	struct request_queue___3 *q;
	struct io_context___31 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___140 {
	struct file___140 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___140 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___139 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___140 *ia_file;
};

struct dquot___139 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___139 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___139 {
	int qf_fmt_id;
	const struct quota_format_ops___139 *qf_ops;
	struct module___120 *qf_owner;
	struct quota_format_type___139 *qf_next;
};

struct quota_format_ops___139 {
	int (*check_quota_file)(struct super_block___139 *, int);
	int (*read_file_info)(struct super_block___139 *, int);
	int (*write_file_info)(struct super_block___139 *, int);
	int (*free_file_info)(struct super_block___139 *, int);
	int (*read_dqblk)(struct dquot___139 *);
	int (*commit_dqblk)(struct dquot___139 *);
	int (*release_dqblk)(struct dquot___139 *);
	int (*get_next_id)(struct super_block___139 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___139 {
	int (*write_dquot)(struct dquot___139 *);
	struct dquot___139 * (*alloc_dquot)(struct super_block___139 *, int);
	void (*destroy_dquot)(struct dquot___139 *);
	int (*acquire_dquot)(struct dquot___139 *);
	int (*release_dquot)(struct dquot___139 *);
	int (*mark_dirty)(struct dquot___139 *);
	int (*write_info)(struct super_block___139 *, int);
	qsize_t * (*get_reserved_space)(struct inode___140 *);
	int (*get_projid)(struct inode___140 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___140 *, qsize_t *);
	int (*get_next_id)(struct super_block___139 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___139 {
	int (*quota_on)(struct super_block___139 *, int, int, const struct path___139 *);
	int (*quota_off)(struct super_block___139 *, int);
	int (*quota_enable)(struct super_block___139 *, unsigned int);
	int (*quota_disable)(struct super_block___139 *, unsigned int);
	int (*quota_sync)(struct super_block___139 *, int);
	int (*set_info)(struct super_block___139 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___139 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___139 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___139 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___139 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___139 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___57;

struct address_space_operations___139 {
	int (*writepage)(struct page___140 *, struct writeback_control___57 *);
	int (*readpage)(struct file___140 *, struct page___140 *);
	int (*writepages)(struct address_space___139 *, struct writeback_control___57 *);
	int (*set_page_dirty)(struct page___140 *);
	int (*readpages)(struct file___140 *, struct address_space___139 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___140 *, struct address_space___139 *, loff_t, unsigned int, unsigned int, struct page___140 **, void **);
	int (*write_end)(struct file___140 *, struct address_space___139 *, loff_t, unsigned int, unsigned int, struct page___140 *, void *);
	sector_t (*bmap)(struct address_space___139 *, sector_t);
	void (*invalidatepage)(struct page___140 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___140 *, gfp_t);
	void (*freepage)(struct page___140 *);
	ssize_t (*direct_IO)(struct kiocb___140 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___139 *, struct page___140 *, struct page___140 *, enum migrate_mode);
	bool (*isolate_page)(struct page___140 *, isolate_mode_t);
	void (*putback_page)(struct page___140 *);
	int (*launder_page)(struct page___140 *);
	int (*is_partially_uptodate)(struct page___140 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___140 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___139 *, struct page___140 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___140 *, sector_t *);
	void (*swap_deactivate)(struct file___140 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___57 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___60 *wb;
	struct inode___140 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___140 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___140 *bd_inode;
	struct super_block___139 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___140 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___60 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___139 {
	struct dentry___139 * (*lookup)(struct inode___140 *, struct dentry___139 *, unsigned int);
	const char * (*get_link)(struct dentry___139 *, struct inode___140 *, struct delayed_call *);
	int (*permission)(struct inode___140 *, int);
	struct posix_acl * (*get_acl)(struct inode___140 *, int);
	int (*readlink)(struct dentry___139 *, char *, int);
	int (*create)(struct inode___140 *, struct dentry___139 *, umode_t, bool);
	int (*link)(struct dentry___139 *, struct inode___140 *, struct dentry___139 *);
	int (*unlink)(struct inode___140 *, struct dentry___139 *);
	int (*symlink)(struct inode___140 *, struct dentry___139 *, const char *);
	int (*mkdir)(struct inode___140 *, struct dentry___139 *, umode_t);
	int (*rmdir)(struct inode___140 *, struct dentry___139 *);
	int (*mknod)(struct inode___140 *, struct dentry___139 *, umode_t, dev_t);
	int (*rename)(struct inode___140 *, struct dentry___139 *, struct inode___140 *, struct dentry___139 *, unsigned int);
	int (*setattr)(struct dentry___139 *, struct iattr___139 *);
	int (*getattr)(const struct path___139 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___139 *, char *, size_t);
	int (*fiemap)(struct inode___140 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___140 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___140 *, struct dentry___139 *, struct file___140 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___140 *, struct dentry___139 *, umode_t);
	int (*set_acl)(struct inode___140 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___139 {
	void (*fl_copy_lock)(struct file_lock___140 *, struct file_lock___140 *);
	void (*fl_release_private)(struct file_lock___140 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___139;

struct lock_manager_operations___139;

struct file_lock___140 {
	struct file_lock___140 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___140 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___139 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___139 *fl_ops;
	const struct lock_manager_operations___139 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___139 {
	int (*lm_compare_owner)(struct file_lock___140 *, struct file_lock___140 *);
	long unsigned int (*lm_owner_key)(struct file_lock___140 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___140 *);
	int (*lm_grant)(struct file_lock___140 *, int);
	bool (*lm_break)(struct file_lock___140 *);
	int (*lm_change)(struct file_lock___140 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___140 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___139 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___139 *fa_next;
	struct file___140 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___139 {
	const char *name;
	int fs_flags;
	struct dentry___139 * (*mount)(struct file_system_type___139 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___139 *);
	struct module___120 *owner;
	struct file_system_type___139 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___139 {
	struct inode___140 * (*alloc_inode)(struct super_block___139 *);
	void (*destroy_inode)(struct inode___140 *);
	void (*dirty_inode)(struct inode___140 *, int);
	int (*write_inode)(struct inode___140 *, struct writeback_control___57 *);
	int (*drop_inode)(struct inode___140 *);
	void (*evict_inode)(struct inode___140 *);
	void (*put_super)(struct super_block___139 *);
	int (*sync_fs)(struct super_block___139 *, int);
	int (*freeze_super)(struct super_block___139 *);
	int (*freeze_fs)(struct super_block___139 *);
	int (*thaw_super)(struct super_block___139 *);
	int (*unfreeze_fs)(struct super_block___139 *);
	int (*statfs)(struct dentry___139 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___139 *, int *, char *);
	void (*umount_begin)(struct super_block___139 *);
	int (*show_options)(struct seq_file___130 *, struct dentry___139 *);
	int (*show_devname)(struct seq_file___130 *, struct dentry___139 *);
	int (*show_path)(struct seq_file___130 *, struct dentry___139 *);
	int (*show_stats)(struct seq_file___130 *, struct dentry___139 *);
	ssize_t (*quota_read)(struct super_block___139 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___139 *, int, const char *, size_t, loff_t);
	struct dquot___139 ** (*get_dquots)(struct inode___140 *);
	int (*bdev_try_to_free_page)(struct super_block___139 *, struct page___140 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___139 *, struct shrink_control___55 *);
	long int (*free_cached_objects)(struct super_block___139 *, struct shrink_control___55 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___60(struct bio___60 *);

struct bio_vec___60 {
	struct page___140 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___60;

struct bio_set___60;

struct bio___60 {
	struct bio___60 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___60 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___60 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___60 *bi_io_vec;
	struct bio_set___60 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___60 bi_inline_vecs[0];
};

typedef void compound_page_dtor___137(struct page___140 *);

struct memcg_cache_array___4 {
	struct callback_head rcu;
	struct kmem_cache___4 *entries[0];
};

typedef int (*key_restrict_link_func_t___135)(struct key___135 *, const struct key_type *, const union key_payload *, struct key___135 *);

struct key_restriction___135;

struct key___135 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___140 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___135 *restrict_link;
};

struct key_restriction___135 {
	key_restrict_link_func_t___135 check;
	struct key___135 *key;
	struct key_type *keytype;
};

struct seq_operations___128 {
	void * (*start)(struct seq_file___130 *, loff_t *);
	void (*stop)(struct seq_file___130 *, void *);
	void * (*next)(struct seq_file___130 *, void *, loff_t *);
	int (*show)(struct seq_file___130 *, void *);
};

struct cgroup_namespace___116 {
	refcount_t count;
	struct ns_common___4 ns;
	struct user_namespace___120 *user_ns;
	struct ucounts___120 *ucounts;
	struct css_set___116 *root_cset;
};

struct ucounts___120 {
	struct hlist_node node;
	struct user_namespace___120 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___116;

struct bpf_map_ops___116 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___116 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___116 *, struct file___140 *);
	void (*map_free)(struct bpf_map___116 *);
	int (*map_get_next_key)(struct bpf_map___116 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___116 *);
	void * (*map_lookup_elem)(struct bpf_map___116 *, void *);
	int (*map_update_elem)(struct bpf_map___116 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___116 *, void *);
	int (*map_push_elem)(struct bpf_map___116 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___116 *, void *);
	int (*map_peek_elem)(struct bpf_map___116 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___116 *, struct file___140 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___116 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___116 *, void *, struct seq_file___130 *);
	int (*map_check_btf)(const struct bpf_map___116 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___116 {
	const struct bpf_map_ops___116 *ops;
	struct bpf_map___116 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___135 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___116;

typedef void (*kthread_work_func_t___116)(struct kthread_work___116 *);

struct kthread_worker___116;

struct kthread_work___116 {
	struct list_head node;
	kthread_work_func_t___116 func;
	struct kthread_worker___116 *worker;
	int canceling;
};

struct kthread_worker___116 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___140 *task;
	struct kthread_work___116 *current_work;
};

struct kthread_delayed_work___116 {
	struct kthread_work___116 work;
	struct timer_list timer;
};

struct psi_group___116 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___116 *poll_kworker;
	struct kthread_delayed_work___116 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___116;

struct cgroup_rstat_cpu___116;

struct cgroup___116 {
	struct cgroup_subsys_state___116 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___136 *kn;
	struct cgroup_file___116 procs_file;
	struct cgroup_file___116 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___116 *subsys[13];
	struct cgroup_root___116 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___116 *dom_cgrp;
	struct cgroup_rstat_cpu___116 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___4 bpf;
	atomic_t congestion_count;
	struct cgroup___116 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___116 psi;
	int ancestor_ids[0];
};

struct cftype___116;

struct cgroup_subsys___116 {
	struct cgroup_subsys_state___116 * (*css_alloc)(struct cgroup_subsys_state___116 *);
	int (*css_online)(struct cgroup_subsys_state___116 *);
	void (*css_offline)(struct cgroup_subsys_state___116 *);
	void (*css_released)(struct cgroup_subsys_state___116 *);
	void (*css_free)(struct cgroup_subsys_state___116 *);
	void (*css_reset)(struct cgroup_subsys_state___116 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___116 *, int);
	int (*css_extra_stat_show)(struct seq_file___130 *, struct cgroup_subsys_state___116 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___140 *);
	void (*cancel_fork)(struct task_struct___140 *);
	void (*fork)(struct task_struct___140 *);
	void (*exit)(struct task_struct___140 *);
	void (*free)(struct task_struct___140 *);
	void (*bind)(struct cgroup_subsys_state___116 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___116 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___116 *dfl_cftypes;
	struct cftype___116 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___116 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___116 *updated_children;
	struct cgroup___116 *updated_next;
};

struct cgroup_root___116 {
	struct kernfs_root___136 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___116 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___116 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___116 *ss;
	struct list_head node;
	struct kernfs_ops___136 *kf_ops;
	int (*open)(struct kernfs_open_file___136 *);
	void (*release)(struct kernfs_open_file___136 *);
	u64 (*read_u64)(struct cgroup_subsys_state___116 *, struct cftype___116 *);
	s64 (*read_s64)(struct cgroup_subsys_state___116 *, struct cftype___116 *);
	int (*seq_show)(struct seq_file___130 *, void *);
	void * (*seq_start)(struct seq_file___130 *, loff_t *);
	void * (*seq_next)(struct seq_file___130 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___130 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___116 *, struct cftype___116 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___116 *, struct cftype___116 *, s64);
	ssize_t (*write)(struct kernfs_open_file___136 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___136 *, struct poll_table_struct___6 *);
};

struct bdi_writeback_congested___60 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___60 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___60 {
	struct bio___60 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___60 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___60 bip_inline_vecs[0];
};

struct bio_set___60 {
	struct kmem_cache___4 *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___60 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___55 {
	struct mem_cgroup___55 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___55 {
	struct lruvec___139 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___55 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___55 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct kmem_cache_cpu___4 {
	void **freelist;
	long unsigned int tid;
	struct page___140 *page;
	struct page___140 *partial;
};

struct module___121;

struct file___141;

struct kiocb___141;

struct vm_area_struct___141;

struct inode___141;

struct file_lock___141;

struct page___141;

struct seq_file___131;

struct file_operations___141 {
	struct module___121 *owner;
	loff_t (*llseek)(struct file___141 *, loff_t, int);
	ssize_t (*read)(struct file___141 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___141 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___141 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___141 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___141 *, bool);
	int (*iterate)(struct file___141 *, struct dir_context *);
	int (*iterate_shared)(struct file___141 *, struct dir_context *);
	__poll_t (*poll)(struct file___141 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___141 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___141 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___141 *, struct vm_area_struct___141 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___141 *, struct file___141 *);
	int (*flush)(struct file___141 *, fl_owner_t);
	int (*release)(struct inode___141 *, struct file___141 *);
	int (*fsync)(struct file___141 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___141 *, int);
	int (*lock)(struct file___141 *, int, struct file_lock___141 *);
	ssize_t (*sendpage)(struct file___141 *, struct page___141 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___141 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___141 *, int, struct file_lock___141 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___141 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___141 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___141 *, long int, struct file_lock___141 **, void **);
	long int (*fallocate)(struct file___141 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___131 *, struct file___141 *);
	ssize_t (*copy_file_range)(struct file___141 *, loff_t, struct file___141 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___141 *, loff_t, struct file___141 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___141 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___140 {
	u64 seqnum;
	struct vm_area_struct___141 *vmas[4];
};

struct page_frag___140 {
	struct page___141 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___140;

struct mem_cgroup___56;

struct cred___136;

struct nsproxy___133;

struct bio_list___61;

struct backing_dev_info___61;

struct css_set___117;

struct task_struct___141 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___141 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___140 *mm;
	struct mm_struct___140 *active_mm;
	struct vmacache___140 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___141 *real_parent;
	struct task_struct___141 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___141 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___56 *active_memcg;
	long int rh_reserved2;
	struct pid___112 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___112 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___112 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___136 *ptracer_cred;
	const struct cred___136 *real_cred;
	const struct cred___136 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___133 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___141 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___61 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___61 *backing_dev_info;
	struct io_context___31 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___117 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___140 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___56 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___141 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___86 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rw_semaphore___141 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___141 *owner;
};

struct key___136;

struct ucounts___121;

struct user_namespace___121 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___121 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___4 ns;
	long unsigned int flags;
	struct key___136 *persistent_keyring_register;
	struct rw_semaphore___141 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___121 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct secondary_data___141 {
	void *stack;
	struct task_struct___141 *task;
	long int status;
};

typedef struct page___141 *pgtable_t___140;

struct address_space___140;

struct dev_pagemap___138;

struct page___141 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___140 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___141 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___140 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___140 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___138 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___56 *mem_cgroup;
};

struct user_struct___136 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___136 *uid_keyring;
	struct key___136 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___138;

struct vm_area_struct___141 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___141 *vm_next;
	struct vm_area_struct___141 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___140 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___138 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___141 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___140;

struct mm_struct___140 {
	struct {
		struct vm_area_struct___141 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___141 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___141 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___140 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___141 *owner;
		struct user_namespace___121 *user_ns;
		struct file___141 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___140 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup___117;

struct cgroup_subsys___117;

struct cgroup_subsys_state___117 {
	struct cgroup___117 *cgroup;
	struct cgroup_subsys___117 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___117 *parent;
};

struct kernfs_node___137;

struct cgroup_file___117 {
	struct kernfs_node___137 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___56;

struct mem_cgroup___56 {
	struct cgroup_subsys_state___117 css;
	struct mem_cgroup_id___6 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___117 events_file;
	struct cgroup_file___117 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___141 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___56 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cred___136 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___136 *session_keyring;
	struct key___136 *process_keyring;
	struct key___136 *thread_keyring;
	struct key___136 *request_key_auth;
	void *security;
	struct user_struct___136 *user;
	struct user_namespace___121 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___117;

struct nsproxy___133 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___117 *cgroup_ns;
};

struct bio___61;

struct bio_list___61 {
	struct bio___61 *head;
	struct bio___61 *tail;
};

struct bdi_writeback_congested___61;

struct bdi_writeback___61 {
	struct backing_dev_info___61 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___61 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___117 *memcg_css;
	struct cgroup_subsys_state___117 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___131;

struct dentry___140;

struct backing_dev_info___61 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___61 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___131 *dev;
	struct device___131 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___140 *debug_dir;
	struct dentry___140 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___117 {
	struct cgroup_subsys_state___117 *subsys[13];
	refcount_t refcount;
	struct css_set___117 *dom_cset;
	struct cgroup___117 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___117 *mg_src_cgrp;
	struct cgroup___117 *mg_dst_cgrp;
	struct css_set___117 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct dentry_operations___140;

struct super_block___140;

struct dentry___140 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___140 *d_parent;
	struct qstr d_name;
	struct inode___141 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___140 *d_op;
	struct super_block___140 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___140;

struct address_space___140 {
	struct inode___141 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___141 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___140 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___140;

struct block_device___141;

struct inode___141 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___140 *i_op;
	struct super_block___140 *i_sb;
	struct address_space___140 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___141 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___61 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___141 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___140 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___141 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___140;

struct dentry_operations___140 {
	int (*d_revalidate)(struct dentry___140 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___140 *, unsigned int);
	int (*d_hash)(const struct dentry___140 *, struct qstr *);
	int (*d_compare)(const struct dentry___140 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___140 *);
	int (*d_init)(struct dentry___140 *);
	void (*d_release)(struct dentry___140 *);
	void (*d_prune)(struct dentry___140 *);
	void (*d_iput)(struct dentry___140 *, struct inode___141 *);
	char * (*d_dname)(struct dentry___140 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___140 *);
	int (*d_manage)(const struct path___140 *, bool);
	struct dentry___140 * (*d_real)(struct dentry___140 *, const struct inode___141 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___140;

struct mem_dqinfo___140 {
	struct quota_format_type___140 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___140;

struct quota_info___140 {
	unsigned int flags;
	struct rw_semaphore___141 dqio_sem;
	struct inode___141 *files[3];
	struct mem_dqinfo___140 info[3];
	const struct quota_format_ops___140 *ops[3];
};

struct rcuwait___140 {
	struct task_struct___141 *task;
};

struct percpu_rw_semaphore___140 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___141 rw_sem;
	struct rcuwait___140 writer;
	int readers_block;
};

struct sb_writers___140 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___140 rw_sem[3];
};

struct shrink_control___56;

struct shrinker___56 {
	long unsigned int (*count_objects)(struct shrinker___56 *, struct shrink_control___56 *);
	long unsigned int (*scan_objects)(struct shrinker___56 *, struct shrink_control___56 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___140;

struct super_operations___140;

struct dquot_operations___140;

struct quotactl_ops___140;

struct xattr_handler___8;

struct super_block___140 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___140 *s_type;
	const struct super_operations___140 *s_op;
	const struct dquot_operations___140 *dq_op;
	const struct quotactl_ops___140 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___140 *s_root;
	struct rw_semaphore___141 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___8 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___141 *s_bdev;
	struct backing_dev_info___61 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___140 s_dquot;
	struct sb_writers___140 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___140 *s_d_op;
	int cleancache_poolid;
	struct shrinker___56 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___121 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct path___140 {
	struct vfsmount *mnt;
	struct dentry___140 *dentry;
};

struct shrink_control___56 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___56 *memcg;
};

struct pglist_data___140;

struct lruvec___140 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___140 *pgdat;
};

struct zone___140 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___140 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___140 {
	struct zone___140 *zone;
	int zone_idx;
};

struct zonelist___140 {
	struct zoneref___140 _zonerefs[25];
};

struct pglist_data___140 {
	struct zone___140 node_zones[3];
	struct zonelist___140 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___141 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___141 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___140 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

typedef struct pglist_data___140 pg_data_t___9;

struct blocking_notifier_head___140 {
	struct rw_semaphore___141 rwsem;
	struct notifier_block *head;
};

typedef int (*dev_page_fault_t___138)(struct vm_area_struct___141 *, long unsigned int, const struct page___141 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___138)(struct page___141 *, void *);

struct dev_pagemap___138 {
	dev_page_fault_t___138 page_fault;
	dev_page_free_t___138 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___131 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct file___141 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___140 f_path;
	struct inode___141 *f_inode;
	const struct file_operations___141 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___112 f_owner;
	const struct cred___136 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___140 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___138;

struct vm_operations_struct___138 {
	void (*open)(struct vm_area_struct___141 *);
	void (*close)(struct vm_area_struct___141 *);
	int (*split)(struct vm_area_struct___141 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___141 *);
	vm_fault_t (*fault)(struct vm_fault___138 *);
	vm_fault_t (*huge_fault)(struct vm_fault___138 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___138 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___141 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___138 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___138 *);
	int (*access)(struct vm_area_struct___141 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___141 *);
	int (*set_policy)(struct vm_area_struct___141 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___141 *, long unsigned int);
	struct page___141 * (*find_special_page)(struct vm_area_struct___141 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___140 {
	struct task_struct___141 *task;
	struct core_thread___140 *next;
};

struct core_state___140 {
	atomic_t nr_threads;
	struct core_thread___140 dumper;
	struct completion startup;
};

struct vm_fault___138 {
	struct vm_area_struct___141 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___141 *cow_page;
	struct mem_cgroup___56 *memcg;
	struct page___141 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___140 prealloc_pte;
};

struct kiocb___141 {
	struct file___141 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___141 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___140 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___141 *ia_file;
};

struct dquot___140 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___140 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___140 {
	int qf_fmt_id;
	const struct quota_format_ops___140 *qf_ops;
	struct module___121 *qf_owner;
	struct quota_format_type___140 *qf_next;
};

struct quota_format_ops___140 {
	int (*check_quota_file)(struct super_block___140 *, int);
	int (*read_file_info)(struct super_block___140 *, int);
	int (*write_file_info)(struct super_block___140 *, int);
	int (*free_file_info)(struct super_block___140 *, int);
	int (*read_dqblk)(struct dquot___140 *);
	int (*commit_dqblk)(struct dquot___140 *);
	int (*release_dqblk)(struct dquot___140 *);
	int (*get_next_id)(struct super_block___140 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___140 {
	int (*write_dquot)(struct dquot___140 *);
	struct dquot___140 * (*alloc_dquot)(struct super_block___140 *, int);
	void (*destroy_dquot)(struct dquot___140 *);
	int (*acquire_dquot)(struct dquot___140 *);
	int (*release_dquot)(struct dquot___140 *);
	int (*mark_dirty)(struct dquot___140 *);
	int (*write_info)(struct super_block___140 *, int);
	qsize_t * (*get_reserved_space)(struct inode___141 *);
	int (*get_projid)(struct inode___141 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___141 *, qsize_t *);
	int (*get_next_id)(struct super_block___140 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___140 {
	int (*quota_on)(struct super_block___140 *, int, int, const struct path___140 *);
	int (*quota_off)(struct super_block___140 *, int);
	int (*quota_enable)(struct super_block___140 *, unsigned int);
	int (*quota_disable)(struct super_block___140 *, unsigned int);
	int (*quota_sync)(struct super_block___140 *, int);
	int (*set_info)(struct super_block___140 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___140 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___140 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___140 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___140 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___140 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___134;

struct kobj_type___134;

struct kobject___135 {
	const char *name;
	struct list_head entry;
	struct kobject___135 *parent;
	struct kset___134 *kset;
	struct kobj_type___134 *ktype;
	struct kernfs_node___137 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___118 {
	struct kobject___135 kobj;
	struct module___121 *mod;
	struct kobject___135 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___118 {
	struct module___121 *mod;
	struct latch_tree_node node;
};

struct module_layout___118 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___118 mtn;
};

struct module_attribute___118;

struct kernel_param___118;

struct module___121 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___118 mkobj;
	struct module_attribute___118 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___135 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___118 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___118 core_layout;
	struct module_layout___118 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___58;

struct swap_info_struct___39;

struct address_space_operations___140 {
	int (*writepage)(struct page___141 *, struct writeback_control___58 *);
	int (*readpage)(struct file___141 *, struct page___141 *);
	int (*writepages)(struct address_space___140 *, struct writeback_control___58 *);
	int (*set_page_dirty)(struct page___141 *);
	int (*readpages)(struct file___141 *, struct address_space___140 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___141 *, struct address_space___140 *, loff_t, unsigned int, unsigned int, struct page___141 **, void **);
	int (*write_end)(struct file___141 *, struct address_space___140 *, loff_t, unsigned int, unsigned int, struct page___141 *, void *);
	sector_t (*bmap)(struct address_space___140 *, sector_t);
	void (*invalidatepage)(struct page___141 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___141 *, gfp_t);
	void (*freepage)(struct page___141 *);
	ssize_t (*direct_IO)(struct kiocb___141 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___140 *, struct page___141 *, struct page___141 *, enum migrate_mode);
	bool (*isolate_page)(struct page___141 *, isolate_mode_t);
	void (*putback_page)(struct page___141 *);
	int (*launder_page)(struct page___141 *);
	int (*is_partially_uptodate)(struct page___141 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___141 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___140 *, struct page___141 *);
	int (*swap_activate)(struct swap_info_struct___39 *, struct file___141 *, sector_t *);
	void (*swap_deactivate)(struct file___141 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___58 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___61 *wb;
	struct inode___141 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct swap_info_struct___39 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___141 *bdev;
	struct file___141 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___141 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___141 *bd_inode;
	struct super_block___140 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___141 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___61 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___140 {
	struct dentry___140 * (*lookup)(struct inode___141 *, struct dentry___140 *, unsigned int);
	const char * (*get_link)(struct dentry___140 *, struct inode___141 *, struct delayed_call *);
	int (*permission)(struct inode___141 *, int);
	struct posix_acl * (*get_acl)(struct inode___141 *, int);
	int (*readlink)(struct dentry___140 *, char *, int);
	int (*create)(struct inode___141 *, struct dentry___140 *, umode_t, bool);
	int (*link)(struct dentry___140 *, struct inode___141 *, struct dentry___140 *);
	int (*unlink)(struct inode___141 *, struct dentry___140 *);
	int (*symlink)(struct inode___141 *, struct dentry___140 *, const char *);
	int (*mkdir)(struct inode___141 *, struct dentry___140 *, umode_t);
	int (*rmdir)(struct inode___141 *, struct dentry___140 *);
	int (*mknod)(struct inode___141 *, struct dentry___140 *, umode_t, dev_t);
	int (*rename)(struct inode___141 *, struct dentry___140 *, struct inode___141 *, struct dentry___140 *, unsigned int);
	int (*setattr)(struct dentry___140 *, struct iattr___140 *);
	int (*getattr)(const struct path___140 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___140 *, char *, size_t);
	int (*fiemap)(struct inode___141 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___141 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___141 *, struct dentry___140 *, struct file___141 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___141 *, struct dentry___140 *, umode_t);
	int (*set_acl)(struct inode___141 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___140 {
	void (*fl_copy_lock)(struct file_lock___141 *, struct file_lock___141 *);
	void (*fl_release_private)(struct file_lock___141 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___140;

struct lock_manager_operations___140;

struct file_lock___141 {
	struct file_lock___141 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___141 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___140 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___140 *fl_ops;
	const struct lock_manager_operations___140 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___140 {
	int (*lm_compare_owner)(struct file_lock___141 *, struct file_lock___141 *);
	long unsigned int (*lm_owner_key)(struct file_lock___141 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___141 *);
	int (*lm_grant)(struct file_lock___141 *, int);
	bool (*lm_break)(struct file_lock___141 *);
	int (*lm_change)(struct file_lock___141 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___141 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___140 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___140 *fa_next;
	struct file___141 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___140 {
	const char *name;
	int fs_flags;
	struct dentry___140 * (*mount)(struct file_system_type___140 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___140 *);
	struct module___121 *owner;
	struct file_system_type___140 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___140 {
	struct inode___141 * (*alloc_inode)(struct super_block___140 *);
	void (*destroy_inode)(struct inode___141 *);
	void (*dirty_inode)(struct inode___141 *, int);
	int (*write_inode)(struct inode___141 *, struct writeback_control___58 *);
	int (*drop_inode)(struct inode___141 *);
	void (*evict_inode)(struct inode___141 *);
	void (*put_super)(struct super_block___140 *);
	int (*sync_fs)(struct super_block___140 *, int);
	int (*freeze_super)(struct super_block___140 *);
	int (*freeze_fs)(struct super_block___140 *);
	int (*thaw_super)(struct super_block___140 *);
	int (*unfreeze_fs)(struct super_block___140 *);
	int (*statfs)(struct dentry___140 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___140 *, int *, char *);
	void (*umount_begin)(struct super_block___140 *);
	int (*show_options)(struct seq_file___131 *, struct dentry___140 *);
	int (*show_devname)(struct seq_file___131 *, struct dentry___140 *);
	int (*show_path)(struct seq_file___131 *, struct dentry___140 *);
	int (*show_stats)(struct seq_file___131 *, struct dentry___140 *);
	ssize_t (*quota_read)(struct super_block___140 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___140 *, int, const char *, size_t, loff_t);
	struct dquot___140 ** (*get_dquots)(struct inode___141 *);
	int (*bdev_try_to_free_page)(struct super_block___140 *, struct page___141 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___140 *, struct shrink_control___56 *);
	long int (*free_cached_objects)(struct super_block___140 *, struct shrink_control___56 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct xattr_handler___8 {
	const char *name;
	const char *prefix;
	int flags;
	bool (*list)(struct dentry___140 *);
	int (*get)(const struct xattr_handler___8 *, struct dentry___140 *, struct inode___141 *, const char *, void *, size_t);
	int (*set)(const struct xattr_handler___8 *, struct dentry___140 *, struct inode___141 *, const char *, const void *, size_t, int);
};

struct seq_operations___129;

struct seq_file___131 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___129 *op;
	int poll_event;
	const struct file___141 *file;
	void *private;
};

typedef void bio_end_io_t___61(struct bio___61 *);

struct bio_vec___61 {
	struct page___141 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___61;

struct bio_set___61;

struct bio___61 {
	struct bio___61 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___61 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___61 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___61 *bi_io_vec;
	struct bio_set___61 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___61 bi_inline_vecs[0];
};

typedef int (*key_restrict_link_func_t___136)(struct key___136 *, const struct key_type *, const union key_payload *, struct key___136 *);

struct key_restriction___136;

struct key___136 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___141 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___136 *restrict_link;
};

struct key_restriction___136 {
	key_restrict_link_func_t___136 check;
	struct key___136 *key;
	struct key_type *keytype;
};

struct seq_operations___129 {
	void * (*start)(struct seq_file___131 *, loff_t *);
	void (*stop)(struct seq_file___131 *, void *);
	void * (*next)(struct seq_file___131 *, void *, loff_t *);
	int (*show)(struct seq_file___131 *, void *);
};

struct kernfs_root___137;

struct kernfs_elem_dir___137 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___137 *root;
};

struct kernfs_syscall_ops___137;

struct kernfs_root___137 {
	struct kernfs_node___137 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___137 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___137 {
	struct kernfs_node___137 *target_kn;
};

struct kernfs_ops___137;

struct kernfs_elem_attr___137 {
	const struct kernfs_ops___137 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___137 *notify_next;
};

struct kernfs_node___137 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___137 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___137 dir;
		struct kernfs_elem_symlink___137 symlink;
		struct kernfs_elem_attr___137 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___137;

struct kernfs_ops___137 {
	int (*open)(struct kernfs_open_file___137 *);
	void (*release)(struct kernfs_open_file___137 *);
	int (*seq_show)(struct seq_file___131 *, void *);
	void * (*seq_start)(struct seq_file___131 *, loff_t *);
	void * (*seq_next)(struct seq_file___131 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___131 *, void *);
	ssize_t (*read)(struct kernfs_open_file___137 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___137 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___137 *, struct vm_area_struct___141 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___137 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___137 {
	int (*remount_fs)(struct kernfs_root___137 *, int *, char *);
	int (*show_options)(struct seq_file___131 *, struct kernfs_root___137 *);
	int (*mkdir)(struct kernfs_node___137 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___137 *);
	int (*rename)(struct kernfs_node___137 *, struct kernfs_node___137 *, const char *);
	int (*show_path)(struct seq_file___131 *, struct kernfs_node___137 *, struct kernfs_root___137 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___137 {
	struct kernfs_node___137 *kn;
	struct file___141 *file;
	struct seq_file___131 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___138 *vm_ops;
};

struct cgroup_namespace___117 {
	refcount_t count;
	struct ns_common___4 ns;
	struct user_namespace___121 *user_ns;
	struct ucounts___121 *ucounts;
	struct css_set___117 *root_cset;
};

struct ucounts___121 {
	struct hlist_node node;
	struct user_namespace___121 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___117;

struct bpf_map_ops___117 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___117 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___117 *, struct file___141 *);
	void (*map_free)(struct bpf_map___117 *);
	int (*map_get_next_key)(struct bpf_map___117 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___117 *);
	void * (*map_lookup_elem)(struct bpf_map___117 *, void *);
	int (*map_update_elem)(struct bpf_map___117 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___117 *, void *);
	int (*map_push_elem)(struct bpf_map___117 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___117 *, void *);
	int (*map_peek_elem)(struct bpf_map___117 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___117 *, struct file___141 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___117 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___117 *, void *, struct seq_file___131 *);
	int (*map_check_btf)(const struct bpf_map___117 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___117 {
	const struct bpf_map_ops___117 *ops;
	struct bpf_map___117 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___136 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___117;

typedef void (*kthread_work_func_t___117)(struct kthread_work___117 *);

struct kthread_worker___117;

struct kthread_work___117 {
	struct list_head node;
	kthread_work_func_t___117 func;
	struct kthread_worker___117 *worker;
	int canceling;
};

struct kthread_worker___117 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___141 *task;
	struct kthread_work___117 *current_work;
};

struct kthread_delayed_work___117 {
	struct kthread_work___117 work;
	struct timer_list timer;
};

struct psi_group___117 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___117 *poll_kworker;
	struct kthread_delayed_work___117 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___117;

struct cgroup_rstat_cpu___117;

struct cgroup___117 {
	struct cgroup_subsys_state___117 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___137 *kn;
	struct cgroup_file___117 procs_file;
	struct cgroup_file___117 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___117 *subsys[13];
	struct cgroup_root___117 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___117 *dom_cgrp;
	struct cgroup_rstat_cpu___117 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___4 bpf;
	atomic_t congestion_count;
	struct cgroup___117 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___117 psi;
	int ancestor_ids[0];
};

struct cftype___117;

struct cgroup_subsys___117 {
	struct cgroup_subsys_state___117 * (*css_alloc)(struct cgroup_subsys_state___117 *);
	int (*css_online)(struct cgroup_subsys_state___117 *);
	void (*css_offline)(struct cgroup_subsys_state___117 *);
	void (*css_released)(struct cgroup_subsys_state___117 *);
	void (*css_free)(struct cgroup_subsys_state___117 *);
	void (*css_reset)(struct cgroup_subsys_state___117 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___117 *, int);
	int (*css_extra_stat_show)(struct seq_file___131 *, struct cgroup_subsys_state___117 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___141 *);
	void (*cancel_fork)(struct task_struct___141 *);
	void (*fork)(struct task_struct___141 *);
	void (*exit)(struct task_struct___141 *);
	void (*free)(struct task_struct___141 *);
	void (*bind)(struct cgroup_subsys_state___117 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___117 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___117 *dfl_cftypes;
	struct cftype___117 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___117 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___117 *updated_children;
	struct cgroup___117 *updated_next;
};

struct cgroup_root___117 {
	struct kernfs_root___137 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___117 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___117 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___117 *ss;
	struct list_head node;
	struct kernfs_ops___137 *kf_ops;
	int (*open)(struct kernfs_open_file___137 *);
	void (*release)(struct kernfs_open_file___137 *);
	u64 (*read_u64)(struct cgroup_subsys_state___117 *, struct cftype___117 *);
	s64 (*read_s64)(struct cgroup_subsys_state___117 *, struct cftype___117 *);
	int (*seq_show)(struct seq_file___131 *, void *);
	void * (*seq_start)(struct seq_file___131 *, loff_t *);
	void * (*seq_next)(struct seq_file___131 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___131 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___117 *, struct cftype___117 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___117 *, struct cftype___117 *, s64);
	ssize_t (*write)(struct kernfs_open_file___137 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___137 *, struct poll_table_struct___6 *);
};

struct dev_pm_info___131 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___131 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___131;

struct bus_type___131;

struct device_driver___131;

struct dev_pm_domain___131;

struct class___131;

struct attribute_group___130;

struct device___131 {
	struct device___131 *parent;
	struct device_private *p;
	struct kobject___135 kobj;
	const char *init_name;
	const struct device_type___131 *type;
	struct mutex mutex;
	struct bus_type___131 *bus;
	struct device_driver___131 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___131 power;
	struct dev_pm_domain___131 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___131 *class;
	const struct attribute_group___130 **groups;
	void (*release)(struct device___131 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct kobj_attribute___135 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___135 *, struct kobj_attribute___135 *, char *);
	ssize_t (*store)(struct kobject___135 *, struct kobj_attribute___135 *, const char *, size_t);
};

typedef void compound_page_dtor___138(struct page___141 *);

struct bdi_writeback_congested___61 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___61 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___61 {
	struct bio___61 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___61 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___61 bip_inline_vecs[0];
};

struct bio_set___61 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___61 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___56 {
	struct mem_cgroup___56 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___56 {
	struct lruvec___140 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___56 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___56 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct bin_attribute___130;

struct attribute_group___130 {
	const char *name;
	umode_t (*is_visible)(struct kobject___135 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___135 *, struct bin_attribute___130 *, int);
	struct attribute **attrs;
	struct bin_attribute___130 **bin_attrs;
};

struct bin_attribute___130 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___141 *, struct kobject___135 *, struct bin_attribute___130 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___141 *, struct kobject___135 *, struct bin_attribute___130 *, char *, loff_t, size_t);
	int (*mmap)(struct file___141 *, struct kobject___135 *, struct bin_attribute___130 *, struct vm_area_struct___141 *);
};

struct sysfs_ops___134 {
	ssize_t (*show)(struct kobject___135 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___135 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___134;

struct kset___134 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___135 kobj;
	const struct kset_uevent_ops___134 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___134 {
	void (*release)(struct kobject___135 *);
	const struct sysfs_ops___134 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___2 * (*child_ns_type)(struct kobject___135 *);
	const void * (*namespace)(struct kobject___135 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___134 {
	int (* const filter)(struct kset___134 *, struct kobject___135 *);
	const char * (* const name)(struct kset___134 *, struct kobject___135 *);
	int (* const uevent)(struct kset___134 *, struct kobject___135 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___131 {
	int (*prepare)(struct device___131 *);
	void (*complete)(struct device___131 *);
	int (*suspend)(struct device___131 *);
	int (*resume)(struct device___131 *);
	int (*freeze)(struct device___131 *);
	int (*thaw)(struct device___131 *);
	int (*poweroff)(struct device___131 *);
	int (*restore)(struct device___131 *);
	int (*suspend_late)(struct device___131 *);
	int (*resume_early)(struct device___131 *);
	int (*freeze_late)(struct device___131 *);
	int (*thaw_early)(struct device___131 *);
	int (*poweroff_late)(struct device___131 *);
	int (*restore_early)(struct device___131 *);
	int (*suspend_noirq)(struct device___131 *);
	int (*resume_noirq)(struct device___131 *);
	int (*freeze_noirq)(struct device___131 *);
	int (*thaw_noirq)(struct device___131 *);
	int (*poweroff_noirq)(struct device___131 *);
	int (*restore_noirq)(struct device___131 *);
	int (*runtime_suspend)(struct device___131 *);
	int (*runtime_resume)(struct device___131 *);
	int (*runtime_idle)(struct device___131 *);
};

struct dev_pm_domain___131 {
	struct dev_pm_ops___131 ops;
	void (*detach)(struct device___131 *, bool);
	int (*activate)(struct device___131 *);
	void (*sync)(struct device___131 *);
	void (*dismiss)(struct device___131 *);
};

struct bus_type___131 {
	const char *name;
	const char *dev_name;
	struct device___131 *dev_root;
	const struct attribute_group___130 **bus_groups;
	const struct attribute_group___130 **dev_groups;
	const struct attribute_group___130 **drv_groups;
	int (*match)(struct device___131 *, struct device_driver___131 *);
	int (*uevent)(struct device___131 *, struct kobj_uevent_env *);
	int (*probe)(struct device___131 *);
	int (*remove)(struct device___131 *);
	void (*shutdown)(struct device___131 *);
	int (*online)(struct device___131 *);
	int (*offline)(struct device___131 *);
	int (*suspend)(struct device___131 *, pm_message_t);
	int (*resume)(struct device___131 *);
	int (*num_vf)(struct device___131 *);
	int (*dma_configure)(struct device___131 *);
	const struct dev_pm_ops___131 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___131 {
	const char *name;
	struct bus_type___131 *bus;
	struct module___121 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___131 *);
	int (*remove)(struct device___131 *);
	void (*shutdown)(struct device___131 *);
	int (*suspend)(struct device___131 *, pm_message_t);
	int (*resume)(struct device___131 *);
	const struct attribute_group___130 **groups;
	const struct dev_pm_ops___131 *pm;
	void (*coredump)(struct device___131 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___131 {
	const char *name;
	const struct attribute_group___130 **groups;
	int (*uevent)(struct device___131 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___131 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___131 *);
	const struct dev_pm_ops___131 *pm;
};

struct class___131 {
	const char *name;
	struct module___121 *owner;
	const struct attribute_group___130 **class_groups;
	const struct attribute_group___130 **dev_groups;
	struct kobject___135 *dev_kobj;
	int (*dev_uevent)(struct device___131 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___131 *, umode_t *);
	void (*class_release)(struct class___131 *);
	void (*dev_release)(struct device___131 *);
	int (*shutdown_pre)(struct device___131 *);
	const struct kobj_ns_type_operations___2 *ns_type;
	const void * (*namespace)(struct device___131 *);
	const struct dev_pm_ops___131 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___109 {
	struct device___131 dev;
};

struct kernel_param_ops___118 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___118 *);
	int (*get)(char *, const struct kernel_param___118 *);
	void (*free)(void *);
};

struct kparam_array___118;

struct kernel_param___118 {
	const char *name;
	struct module___121 *mod;
	const struct kernel_param_ops___118 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___118 *arr;
	};
};

struct kparam_array___118 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___118 *ops;
	void *elem;
};

struct module_attribute___118 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___118 *, struct module_kobject___118 *, char *);
	ssize_t (*store)(struct module_attribute___118 *, struct module_kobject___118 *, const char *, size_t);
	void (*setup)(struct module___121 *, const char *);
	int (*test)(struct module___121 *);
	void (*free)(struct module___121 *);
};

struct module___122;

struct file___142;

struct kiocb___142;

struct iov_iter___63;

struct poll_table_struct___96;

struct vm_area_struct___142;

struct inode___142;

struct file_lock___142;

struct page___142;

struct seq_file___132;

struct file_operations___142 {
	struct module___122 *owner;
	loff_t (*llseek)(struct file___142 *, loff_t, int);
	ssize_t (*read)(struct file___142 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___142 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___142 *, struct iov_iter___63 *);
	ssize_t (*write_iter)(struct kiocb___142 *, struct iov_iter___63 *);
	int (*iopoll)(struct kiocb___142 *, bool);
	int (*iterate)(struct file___142 *, struct dir_context *);
	int (*iterate_shared)(struct file___142 *, struct dir_context *);
	__poll_t (*poll)(struct file___142 *, struct poll_table_struct___96 *);
	long int (*unlocked_ioctl)(struct file___142 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___142 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___142 *, struct vm_area_struct___142 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___142 *, struct file___142 *);
	int (*flush)(struct file___142 *, fl_owner_t);
	int (*release)(struct inode___142 *, struct file___142 *);
	int (*fsync)(struct file___142 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___142 *, int);
	int (*lock)(struct file___142 *, int, struct file_lock___142 *);
	ssize_t (*sendpage)(struct file___142 *, struct page___142 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___142 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___142 *, int, struct file_lock___142 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___142 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___142 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___142 *, long int, struct file_lock___142 **, void **);
	long int (*fallocate)(struct file___142 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___132 *, struct file___142 *);
	ssize_t (*copy_file_range)(struct file___142 *, loff_t, struct file___142 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___142 *, loff_t, struct file___142 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___142 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___141 {
	u64 seqnum;
	struct vm_area_struct___142 *vmas[4];
};

struct page_frag___141 {
	struct page___142 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___87;

struct debug_info___87 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___87 *hbp_break[16];
	struct perf_event___87 *hbp_watch[16];
};

struct thread_struct___87 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___87 debug;
	long: 64;
};

struct mm_struct___141;

struct mem_cgroup___57;

struct pid___113;

struct cred___137;

struct nsproxy___134;

struct signal_struct___126;

struct bio_list___62;

struct backing_dev_info___62;

struct css_set___118;

struct perf_event_context___87;

struct task_struct___142 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___142 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___141 *mm;
	struct mm_struct___141 *active_mm;
	struct vmacache___141 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___142 *real_parent;
	struct task_struct___142 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___142 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___57 *active_memcg;
	long int rh_reserved2;
	struct pid___113 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___113 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___113 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___137 *ptracer_cred;
	const struct cred___137 *real_cred;
	const struct cred___137 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___134 *nsproxy;
	struct signal_struct___126 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___142 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___62 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___62 *backing_dev_info;
	struct io_context___31 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___118 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___87 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___141 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___57 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___142 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___87 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___87 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___142 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___87)(struct perf_event___87 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___87;

struct fasync_struct___141;

struct pid_namespace___113;

struct trace_event_call___80;

struct perf_cgroup___87;

struct perf_event___87 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___87 *group_leader;
	struct pmu___87 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___87 hw;
	struct perf_event_context___87 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___87 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___142 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___141 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___87 *);
	struct callback_head callback_head;
	struct pid_namespace___113 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___87 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___87 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___80 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___87 *cgrp;
	struct list_head sb_list;
};

typedef struct page___142 *pgtable_t___141;

struct address_space___141;

struct dev_pagemap___139;

struct page___142 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___141 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___142 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___141 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___141 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___139 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___57 *mem_cgroup;
};

struct pglist_data___141;

struct lruvec___141 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___141 *pgdat;
};

struct zone___141 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___141 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___141 {
	struct zone___141 *zone;
	int zone_idx;
};

struct zonelist___141 {
	struct zoneref___141 _zonerefs[25];
};

struct pglist_data___141 {
	struct zone___141 node_zones[3];
	struct zonelist___141 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___142 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___142 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___141 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___142 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___142 *owner;
};

struct secondary_data___142 {
	void *stack;
	struct task_struct___142 *task;
	long int status;
};

struct blocking_notifier_head___141 {
	struct rw_semaphore___142 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___139;

struct vm_area_struct___142 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___142 *vm_next;
	struct vm_area_struct___142 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___141 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___139 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___142 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___141;

struct user_namespace___122;

struct mm_struct___141 {
	struct {
		struct vm_area_struct___142 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___142 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___142 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___141 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___142 *owner;
		struct user_namespace___122 *user_ns;
		struct file___142 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___141 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___141;

struct address_space___141 {
	struct inode___142 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___142 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___141 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___139)(struct vm_area_struct___142 *, long unsigned int, const struct page___142 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___139)(struct page___142 *, void *);

struct device___132;

struct dev_pagemap___139 {
	dev_page_fault_t___139 page_fault;
	dev_page_free_t___139 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___132 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct cgroup___118;

struct cgroup_subsys___118;

struct cgroup_subsys_state___118 {
	struct cgroup___118 *cgroup;
	struct cgroup_subsys___118 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___118 *parent;
};

struct kernfs_node___138;

struct cgroup_file___118 {
	struct kernfs_node___138 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___57;

struct mem_cgroup___57 {
	struct cgroup_subsys_state___118 css;
	struct mem_cgroup_id___11 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___118 events_file;
	struct cgroup_file___118 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___142 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___57 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry___141;

struct path___141 {
	struct vfsmount *mnt;
	struct dentry___141 *dentry;
};

struct fown_struct___113 {
	rwlock_t lock;
	struct pid___113 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___142 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___141 f_path;
	struct inode___142 *f_inode;
	const struct file_operations___142 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___113 f_owner;
	const struct cred___137 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___141 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___139;

struct vm_operations_struct___139 {
	void (*open)(struct vm_area_struct___142 *);
	void (*close)(struct vm_area_struct___142 *);
	int (*split)(struct vm_area_struct___142 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___142 *);
	vm_fault_t (*fault)(struct vm_fault___139 *);
	vm_fault_t (*huge_fault)(struct vm_fault___139 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___139 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___142 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___139 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___139 *);
	int (*access)(struct vm_area_struct___142 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___142 *);
	int (*set_policy)(struct vm_area_struct___142 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___142 *, long unsigned int);
	struct page___142 * (*find_special_page)(struct vm_area_struct___142 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___141 {
	struct task_struct___142 *task;
	struct core_thread___141 *next;
};

struct core_state___141 {
	atomic_t nr_threads;
	struct core_thread___141 dumper;
	struct completion startup;
};

struct key___137;

struct ucounts___122;

struct user_namespace___122 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___122 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___4 ns;
	long unsigned int flags;
	struct key___137 *persistent_keyring_register;
	struct rw_semaphore___142 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___122 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___139 {
	struct vm_area_struct___142 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___142 *cow_page;
	struct mem_cgroup___57 *memcg;
	struct page___142 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___141 prealloc_pte;
};

struct shrink_control___57 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___57 *memcg;
};

struct shrinker___57 {
	long unsigned int (*count_objects)(struct shrinker___57 *, struct shrink_control___57 *);
	long unsigned int (*scan_objects)(struct shrinker___57 *, struct shrink_control___57 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct upid___113 {
	int nr;
	struct pid_namespace___113 *ns;
};

struct pid_namespace___113 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___142 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___113 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___141 *proc_self;
	struct dentry___141 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___122 *user_ns;
	struct ucounts___122 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___4 ns;
};

struct pid___113 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___113 numbers[1];
};

struct user_struct___137 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___137 *uid_keyring;
	struct key___137 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___137 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___137 *session_keyring;
	struct key___137 *process_keyring;
	struct key___137 *thread_keyring;
	struct key___137 *request_key_auth;
	void *security;
	struct user_struct___137 *user;
	struct user_namespace___122 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___118;

struct nsproxy___134 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___113 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___118 *cgroup_ns;
};

struct signal_struct___126 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___142 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___142 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___113 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___113 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___141 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___113 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___62;

struct bio_list___62 {
	struct bio___62 *head;
	struct bio___62 *tail;
};

struct bdi_writeback_congested___62;

struct bdi_writeback___62 {
	struct backing_dev_info___62 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___62 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___118 *memcg_css;
	struct cgroup_subsys_state___118 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___62 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___62 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___132 *dev;
	struct device___132 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___141 *debug_dir;
	struct dentry___141 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___118 {
	struct cgroup_subsys_state___118 *subsys[13];
	refcount_t refcount;
	struct css_set___118 *dom_cset;
	struct cgroup___118 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___118 *mg_src_cgrp;
	struct cgroup___118 *mg_dst_cgrp;
	struct css_set___118 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___87 {
	struct pmu___87 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___142 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___87 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

union thread_union___126 {
	struct task_struct___142 task;
	long unsigned int stack[8192];
};

struct kset___135;

struct kobj_type___135;

struct kobject___136 {
	const char *name;
	struct list_head entry;
	struct kobject___136 *parent;
	struct kset___135 *kset;
	struct kobj_type___135 *ktype;
	struct kernfs_node___138 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___132 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___132 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___132;

struct bus_type___132;

struct device_driver___132;

struct dev_pm_domain___132;

struct class___132;

struct attribute_group___131;

struct device___132 {
	struct device___132 *parent;
	struct device_private *p;
	struct kobject___136 kobj;
	const char *init_name;
	const struct device_type___132 *type;
	struct mutex mutex;
	struct bus_type___132 *bus;
	struct device_driver___132 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___132 power;
	struct dev_pm_domain___132 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___132 *class;
	const struct attribute_group___131 **groups;
	void (*release)(struct device___132 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___141;

struct super_block___141;

struct dentry___141 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___141 *d_parent;
	struct qstr d_name;
	struct inode___142 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___141 *d_op;
	struct super_block___141 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___141;

struct block_device___142;

struct inode___142 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___141 *i_op;
	struct super_block___141 *i_sb;
	struct address_space___141 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___142 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___62 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___142 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___141 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___142 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___141 {
	int (*d_revalidate)(struct dentry___141 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___141 *, unsigned int);
	int (*d_hash)(const struct dentry___141 *, struct qstr *);
	int (*d_compare)(const struct dentry___141 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___141 *);
	int (*d_init)(struct dentry___141 *);
	void (*d_release)(struct dentry___141 *);
	void (*d_prune)(struct dentry___141 *);
	void (*d_iput)(struct dentry___141 *, struct inode___142 *);
	char * (*d_dname)(struct dentry___141 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___141 *);
	int (*d_manage)(const struct path___141 *, bool);
	struct dentry___141 * (*d_real)(struct dentry___141 *, const struct inode___142 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___141;

struct mem_dqinfo___141 {
	struct quota_format_type___141 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___141;

struct quota_info___141 {
	unsigned int flags;
	struct rw_semaphore___142 dqio_sem;
	struct inode___142 *files[3];
	struct mem_dqinfo___141 info[3];
	const struct quota_format_ops___141 *ops[3];
};

struct rcuwait___141 {
	struct task_struct___142 *task;
};

struct percpu_rw_semaphore___141 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___142 rw_sem;
	struct rcuwait___141 writer;
	int readers_block;
};

struct sb_writers___141 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___141 rw_sem[3];
};

struct file_system_type___141;

struct super_operations___141;

struct dquot_operations___141;

struct quotactl_ops___141;

struct super_block___141 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___141 *s_type;
	const struct super_operations___141 *s_op;
	const struct dquot_operations___141 *dq_op;
	const struct quotactl_ops___141 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___141 *s_root;
	struct rw_semaphore___142 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___142 *s_bdev;
	struct backing_dev_info___62 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___141 s_dquot;
	struct sb_writers___141 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___141 *s_d_op;
	int cleancache_poolid;
	struct shrinker___57 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___122 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___142 {
	struct file___142 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___142 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___141 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___142 *ia_file;
};

struct dquot___141 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___141 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___141 {
	int qf_fmt_id;
	const struct quota_format_ops___141 *qf_ops;
	struct module___122 *qf_owner;
	struct quota_format_type___141 *qf_next;
};

struct quota_format_ops___141 {
	int (*check_quota_file)(struct super_block___141 *, int);
	int (*read_file_info)(struct super_block___141 *, int);
	int (*write_file_info)(struct super_block___141 *, int);
	int (*free_file_info)(struct super_block___141 *, int);
	int (*read_dqblk)(struct dquot___141 *);
	int (*commit_dqblk)(struct dquot___141 *);
	int (*release_dqblk)(struct dquot___141 *);
	int (*get_next_id)(struct super_block___141 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___141 {
	int (*write_dquot)(struct dquot___141 *);
	struct dquot___141 * (*alloc_dquot)(struct super_block___141 *, int);
	void (*destroy_dquot)(struct dquot___141 *);
	int (*acquire_dquot)(struct dquot___141 *);
	int (*release_dquot)(struct dquot___141 *);
	int (*mark_dirty)(struct dquot___141 *);
	int (*write_info)(struct super_block___141 *, int);
	qsize_t * (*get_reserved_space)(struct inode___142 *);
	int (*get_projid)(struct inode___142 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___142 *, qsize_t *);
	int (*get_next_id)(struct super_block___141 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___141 {
	int (*quota_on)(struct super_block___141 *, int, int, const struct path___141 *);
	int (*quota_off)(struct super_block___141 *, int);
	int (*quota_enable)(struct super_block___141 *, unsigned int);
	int (*quota_disable)(struct super_block___141 *, unsigned int);
	int (*quota_sync)(struct super_block___141 *, int);
	int (*set_info)(struct super_block___141 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___141 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___141 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___141 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___141 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___141 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___119 {
	struct kobject___136 kobj;
	struct module___122 *mod;
	struct kobject___136 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___119 {
	struct module___122 *mod;
	struct latch_tree_node node;
};

struct module_layout___119 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___119 mtn;
};

struct module_attribute___119;

struct kernel_param___119;

struct module___122 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___119 mkobj;
	struct module_attribute___119 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___136 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___119 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___119 core_layout;
	struct module_layout___119 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___80 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___59;

struct address_space_operations___141 {
	int (*writepage)(struct page___142 *, struct writeback_control___59 *);
	int (*readpage)(struct file___142 *, struct page___142 *);
	int (*writepages)(struct address_space___141 *, struct writeback_control___59 *);
	int (*set_page_dirty)(struct page___142 *);
	int (*readpages)(struct file___142 *, struct address_space___141 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___142 *, struct address_space___141 *, loff_t, unsigned int, unsigned int, struct page___142 **, void **);
	int (*write_end)(struct file___142 *, struct address_space___141 *, loff_t, unsigned int, unsigned int, struct page___142 *, void *);
	sector_t (*bmap)(struct address_space___141 *, sector_t);
	void (*invalidatepage)(struct page___142 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___142 *, gfp_t);
	void (*freepage)(struct page___142 *);
	ssize_t (*direct_IO)(struct kiocb___142 *, struct iov_iter___63 *);
	int (*migratepage)(struct address_space___141 *, struct page___142 *, struct page___142 *, enum migrate_mode);
	bool (*isolate_page)(struct page___142 *, isolate_mode_t);
	void (*putback_page)(struct page___142 *);
	int (*launder_page)(struct page___142 *);
	int (*is_partially_uptodate)(struct page___142 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___142 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___141 *, struct page___142 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___142 *, sector_t *);
	void (*swap_deactivate)(struct file___142 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___59 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___62 *wb;
	struct inode___142 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___62;

struct iov_iter___63 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___62 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___142 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___142 *bd_inode;
	struct super_block___141 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___142 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___62 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___141 {
	struct dentry___141 * (*lookup)(struct inode___142 *, struct dentry___141 *, unsigned int);
	const char * (*get_link)(struct dentry___141 *, struct inode___142 *, struct delayed_call *);
	int (*permission)(struct inode___142 *, int);
	struct posix_acl * (*get_acl)(struct inode___142 *, int);
	int (*readlink)(struct dentry___141 *, char *, int);
	int (*create)(struct inode___142 *, struct dentry___141 *, umode_t, bool);
	int (*link)(struct dentry___141 *, struct inode___142 *, struct dentry___141 *);
	int (*unlink)(struct inode___142 *, struct dentry___141 *);
	int (*symlink)(struct inode___142 *, struct dentry___141 *, const char *);
	int (*mkdir)(struct inode___142 *, struct dentry___141 *, umode_t);
	int (*rmdir)(struct inode___142 *, struct dentry___141 *);
	int (*mknod)(struct inode___142 *, struct dentry___141 *, umode_t, dev_t);
	int (*rename)(struct inode___142 *, struct dentry___141 *, struct inode___142 *, struct dentry___141 *, unsigned int);
	int (*setattr)(struct dentry___141 *, struct iattr___141 *);
	int (*getattr)(const struct path___141 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___141 *, char *, size_t);
	int (*fiemap)(struct inode___142 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___142 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___142 *, struct dentry___141 *, struct file___142 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___142 *, struct dentry___141 *, umode_t);
	int (*set_acl)(struct inode___142 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___141 {
	void (*fl_copy_lock)(struct file_lock___142 *, struct file_lock___142 *);
	void (*fl_release_private)(struct file_lock___142 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___141;

struct file_lock___142 {
	struct file_lock___142 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___142 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___141 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___141 *fl_ops;
	const struct lock_manager_operations___141 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___141 {
	int (*lm_compare_owner)(struct file_lock___142 *, struct file_lock___142 *);
	long unsigned int (*lm_owner_key)(struct file_lock___142 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___142 *);
	int (*lm_grant)(struct file_lock___142 *, int);
	bool (*lm_break)(struct file_lock___142 *);
	int (*lm_change)(struct file_lock___142 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___142 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___141 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___141 *fa_next;
	struct file___142 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___141 {
	const char *name;
	int fs_flags;
	struct dentry___141 * (*mount)(struct file_system_type___141 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___141 *);
	struct module___122 *owner;
	struct file_system_type___141 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___141 {
	struct inode___142 * (*alloc_inode)(struct super_block___141 *);
	void (*destroy_inode)(struct inode___142 *);
	void (*dirty_inode)(struct inode___142 *, int);
	int (*write_inode)(struct inode___142 *, struct writeback_control___59 *);
	int (*drop_inode)(struct inode___142 *);
	void (*evict_inode)(struct inode___142 *);
	void (*put_super)(struct super_block___141 *);
	int (*sync_fs)(struct super_block___141 *, int);
	int (*freeze_super)(struct super_block___141 *);
	int (*freeze_fs)(struct super_block___141 *);
	int (*thaw_super)(struct super_block___141 *);
	int (*unfreeze_fs)(struct super_block___141 *);
	int (*statfs)(struct dentry___141 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___141 *, int *, char *);
	void (*umount_begin)(struct super_block___141 *);
	int (*show_options)(struct seq_file___132 *, struct dentry___141 *);
	int (*show_devname)(struct seq_file___132 *, struct dentry___141 *);
	int (*show_path)(struct seq_file___132 *, struct dentry___141 *);
	int (*show_stats)(struct seq_file___132 *, struct dentry___141 *);
	ssize_t (*quota_read)(struct super_block___141 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___141 *, int, const char *, size_t, loff_t);
	struct dquot___141 ** (*get_dquots)(struct inode___142 *);
	int (*bdev_try_to_free_page)(struct super_block___141 *, struct page___142 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___141 *, struct shrink_control___57 *);
	long int (*free_cached_objects)(struct super_block___141 *, struct shrink_control___57 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___95)(struct file___142 *, wait_queue_head_t *, struct poll_table_struct___96 *);

struct poll_table_struct___96 {
	poll_queue_proc___95 _qproc;
	__poll_t _key;
};

struct seq_operations___130;

struct seq_file___132 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___130 *op;
	int poll_event;
	const struct file___142 *file;
	void *private;
};

typedef void bio_end_io_t___62(struct bio___62 *);

struct bio_vec___62 {
	struct page___142 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___62;

struct bio_set___62;

struct bio___62 {
	struct bio___62 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___62 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___62 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___62 *bi_io_vec;
	struct bio_set___62 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___62 bi_inline_vecs[0];
};

struct kobj_attribute___136 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___136 *, struct kobj_attribute___136 *, char *);
	ssize_t (*store)(struct kobject___136 *, struct kobj_attribute___136 *, const char *, size_t);
};

typedef void compound_page_dtor___139(struct page___142 *);

typedef int (*key_restrict_link_func_t___137)(struct key___137 *, const struct key_type *, const union key_payload *, struct key___137 *);

struct key_restriction___137;

struct key___137 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___142 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___137 *restrict_link;
};

struct key_restriction___137 {
	key_restrict_link_func_t___137 check;
	struct key___137 *key;
	struct key_type *keytype;
};

struct seq_operations___130 {
	void * (*start)(struct seq_file___132 *, loff_t *);
	void (*stop)(struct seq_file___132 *, void *);
	void * (*next)(struct seq_file___132 *, void *, loff_t *);
	int (*show)(struct seq_file___132 *, void *);
};

struct cgroup_namespace___118 {
	refcount_t count;
	struct ns_common___4 ns;
	struct user_namespace___122 *user_ns;
	struct ucounts___122 *ucounts;
	struct css_set___118 *root_cset;
};

struct ucounts___122 {
	struct hlist_node node;
	struct user_namespace___122 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct kernfs_root___138;

struct kernfs_elem_dir___138 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___138 *root;
};

struct kernfs_syscall_ops___138;

struct kernfs_root___138 {
	struct kernfs_node___138 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___138 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___138 {
	struct kernfs_node___138 *target_kn;
};

struct kernfs_ops___138;

struct kernfs_elem_attr___138 {
	const struct kernfs_ops___138 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___138 *notify_next;
};

struct kernfs_node___138 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___138 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___138 dir;
		struct kernfs_elem_symlink___138 symlink;
		struct kernfs_elem_attr___138 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___138;

struct kernfs_ops___138 {
	int (*open)(struct kernfs_open_file___138 *);
	void (*release)(struct kernfs_open_file___138 *);
	int (*seq_show)(struct seq_file___132 *, void *);
	void * (*seq_start)(struct seq_file___132 *, loff_t *);
	void * (*seq_next)(struct seq_file___132 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___132 *, void *);
	ssize_t (*read)(struct kernfs_open_file___138 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___138 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___138 *, struct vm_area_struct___142 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___138 *, struct poll_table_struct___96 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___138 {
	int (*remount_fs)(struct kernfs_root___138 *, int *, char *);
	int (*show_options)(struct seq_file___132 *, struct kernfs_root___138 *);
	int (*mkdir)(struct kernfs_node___138 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___138 *);
	int (*rename)(struct kernfs_node___138 *, struct kernfs_node___138 *, const char *);
	int (*show_path)(struct seq_file___132 *, struct kernfs_node___138 *, struct kernfs_root___138 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___138 {
	struct kernfs_node___138 *kn;
	struct file___142 *file;
	struct seq_file___132 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___139 *vm_ops;
};

struct bin_attribute___131;

struct attribute_group___131 {
	const char *name;
	umode_t (*is_visible)(struct kobject___136 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___136 *, struct bin_attribute___131 *, int);
	struct attribute **attrs;
	struct bin_attribute___131 **bin_attrs;
};

struct bin_attribute___131 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___142 *, struct kobject___136 *, struct bin_attribute___131 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___142 *, struct kobject___136 *, struct bin_attribute___131 *, char *, loff_t, size_t);
	int (*mmap)(struct file___142 *, struct kobject___136 *, struct bin_attribute___131 *, struct vm_area_struct___142 *);
};

struct sysfs_ops___135 {
	ssize_t (*show)(struct kobject___136 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___136 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___135;

struct kset___135 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___136 kobj;
	const struct kset_uevent_ops___135 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___135 {
	void (*release)(struct kobject___136 *);
	const struct sysfs_ops___135 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___2 * (*child_ns_type)(struct kobject___136 *);
	const void * (*namespace)(struct kobject___136 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___135 {
	int (* const filter)(struct kset___135 *, struct kobject___136 *);
	const char * (* const name)(struct kset___135 *, struct kobject___136 *);
	int (* const uevent)(struct kset___135 *, struct kobject___136 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___119 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___119 *);
	int (*get)(char *, const struct kernel_param___119 *);
	void (*free)(void *);
};

struct kparam_array___119;

struct kernel_param___119 {
	const char *name;
	struct module___122 *mod;
	const struct kernel_param_ops___119 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___119 *arr;
	};
};

struct kparam_array___119 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___119 *ops;
	void *elem;
};

struct module_attribute___119 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___119 *, struct module_kobject___119 *, char *);
	ssize_t (*store)(struct module_attribute___119 *, struct module_kobject___119 *, const char *, size_t);
	void (*setup)(struct module___122 *, const char *);
	int (*test)(struct module___122 *);
	void (*free)(struct module___122 *);
};

struct trace_event_class___80;

struct trace_event_call___80 {
	struct list_head list;
	struct trace_event_class___80 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___4 *prog_array;
	int (*perf_perm)(struct trace_event_call___80 *, struct perf_event___87 *);
};

struct dev_pm_ops___132 {
	int (*prepare)(struct device___132 *);
	void (*complete)(struct device___132 *);
	int (*suspend)(struct device___132 *);
	int (*resume)(struct device___132 *);
	int (*freeze)(struct device___132 *);
	int (*thaw)(struct device___132 *);
	int (*poweroff)(struct device___132 *);
	int (*restore)(struct device___132 *);
	int (*suspend_late)(struct device___132 *);
	int (*resume_early)(struct device___132 *);
	int (*freeze_late)(struct device___132 *);
	int (*thaw_early)(struct device___132 *);
	int (*poweroff_late)(struct device___132 *);
	int (*restore_early)(struct device___132 *);
	int (*suspend_noirq)(struct device___132 *);
	int (*resume_noirq)(struct device___132 *);
	int (*freeze_noirq)(struct device___132 *);
	int (*thaw_noirq)(struct device___132 *);
	int (*poweroff_noirq)(struct device___132 *);
	int (*restore_noirq)(struct device___132 *);
	int (*runtime_suspend)(struct device___132 *);
	int (*runtime_resume)(struct device___132 *);
	int (*runtime_idle)(struct device___132 *);
};

struct dev_pm_domain___132 {
	struct dev_pm_ops___132 ops;
	void (*detach)(struct device___132 *, bool);
	int (*activate)(struct device___132 *);
	void (*sync)(struct device___132 *);
	void (*dismiss)(struct device___132 *);
};

struct bus_type___132 {
	const char *name;
	const char *dev_name;
	struct device___132 *dev_root;
	const struct attribute_group___131 **bus_groups;
	const struct attribute_group___131 **dev_groups;
	const struct attribute_group___131 **drv_groups;
	int (*match)(struct device___132 *, struct device_driver___132 *);
	int (*uevent)(struct device___132 *, struct kobj_uevent_env *);
	int (*probe)(struct device___132 *);
	int (*remove)(struct device___132 *);
	void (*shutdown)(struct device___132 *);
	int (*online)(struct device___132 *);
	int (*offline)(struct device___132 *);
	int (*suspend)(struct device___132 *, pm_message_t);
	int (*resume)(struct device___132 *);
	int (*num_vf)(struct device___132 *);
	int (*dma_configure)(struct device___132 *);
	const struct dev_pm_ops___132 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___132 {
	const char *name;
	struct bus_type___132 *bus;
	struct module___122 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___132 *);
	int (*remove)(struct device___132 *);
	void (*shutdown)(struct device___132 *);
	int (*suspend)(struct device___132 *, pm_message_t);
	int (*resume)(struct device___132 *);
	const struct attribute_group___131 **groups;
	const struct dev_pm_ops___132 *pm;
	void (*coredump)(struct device___132 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___132 {
	const char *name;
	const struct attribute_group___131 **groups;
	int (*uevent)(struct device___132 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___132 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___132 *);
	const struct dev_pm_ops___132 *pm;
};

struct class___132 {
	const char *name;
	struct module___122 *owner;
	const struct attribute_group___131 **class_groups;
	const struct attribute_group___131 **dev_groups;
	struct kobject___136 *dev_kobj;
	int (*dev_uevent)(struct device___132 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___132 *, umode_t *);
	void (*class_release)(struct class___132 *);
	void (*dev_release)(struct device___132 *);
	int (*shutdown_pre)(struct device___132 *);
	const struct kobj_ns_type_operations___2 *ns_type;
	const void * (*namespace)(struct device___132 *);
	const struct dev_pm_ops___132 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___110 {
	struct device___132 dev;
};

struct bpf_map___118;

struct bpf_map_ops___118 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___118 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___118 *, struct file___142 *);
	void (*map_free)(struct bpf_map___118 *);
	int (*map_get_next_key)(struct bpf_map___118 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___118 *);
	void * (*map_lookup_elem)(struct bpf_map___118 *, void *);
	int (*map_update_elem)(struct bpf_map___118 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___118 *, void *);
	int (*map_push_elem)(struct bpf_map___118 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___118 *, void *);
	int (*map_peek_elem)(struct bpf_map___118 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___118 *, struct file___142 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___118 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___118 *, void *, struct seq_file___132 *);
	int (*map_check_btf)(const struct bpf_map___118 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___118 {
	const struct bpf_map_ops___118 *ops;
	struct bpf_map___118 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___137 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___118;

typedef void (*kthread_work_func_t___118)(struct kthread_work___118 *);

struct kthread_worker___118;

struct kthread_work___118 {
	struct list_head node;
	kthread_work_func_t___118 func;
	struct kthread_worker___118 *worker;
	int canceling;
};

struct kthread_worker___118 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___142 *task;
	struct kthread_work___118 *current_work;
};

struct kthread_delayed_work___118 {
	struct kthread_work___118 work;
	struct timer_list timer;
};

struct psi_group___118 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___118 *poll_kworker;
	struct kthread_delayed_work___118 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___118;

struct cgroup_rstat_cpu___118;

struct cgroup___118 {
	struct cgroup_subsys_state___118 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___138 *kn;
	struct cgroup_file___118 procs_file;
	struct cgroup_file___118 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___118 *subsys[13];
	struct cgroup_root___118 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___118 *dom_cgrp;
	struct cgroup_rstat_cpu___118 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___4 bpf;
	atomic_t congestion_count;
	struct cgroup___118 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___118 psi;
	int ancestor_ids[0];
};

struct cftype___118;

struct cgroup_subsys___118 {
	struct cgroup_subsys_state___118 * (*css_alloc)(struct cgroup_subsys_state___118 *);
	int (*css_online)(struct cgroup_subsys_state___118 *);
	void (*css_offline)(struct cgroup_subsys_state___118 *);
	void (*css_released)(struct cgroup_subsys_state___118 *);
	void (*css_free)(struct cgroup_subsys_state___118 *);
	void (*css_reset)(struct cgroup_subsys_state___118 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___118 *, int);
	int (*css_extra_stat_show)(struct seq_file___132 *, struct cgroup_subsys_state___118 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___142 *);
	void (*cancel_fork)(struct task_struct___142 *);
	void (*fork)(struct task_struct___142 *);
	void (*exit)(struct task_struct___142 *);
	void (*free)(struct task_struct___142 *);
	void (*bind)(struct cgroup_subsys_state___118 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___118 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___118 *dfl_cftypes;
	struct cftype___118 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___118 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___118 *updated_children;
	struct cgroup___118 *updated_next;
};

struct cgroup_root___118 {
	struct kernfs_root___138 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___118 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___118 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___118 *ss;
	struct list_head node;
	struct kernfs_ops___138 *kf_ops;
	int (*open)(struct kernfs_open_file___138 *);
	void (*release)(struct kernfs_open_file___138 *);
	u64 (*read_u64)(struct cgroup_subsys_state___118 *, struct cftype___118 *);
	s64 (*read_s64)(struct cgroup_subsys_state___118 *, struct cftype___118 *);
	int (*seq_show)(struct seq_file___132 *, void *);
	void * (*seq_start)(struct seq_file___132 *, loff_t *);
	void * (*seq_next)(struct seq_file___132 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___132 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___118 *, struct cftype___118 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___118 *, struct cftype___118 *, s64);
	ssize_t (*write)(struct kernfs_open_file___138 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___138 *, struct poll_table_struct___96 *);
};

struct perf_cpu_context___87;

struct pmu___87 {
	struct list_head entry;
	struct module___122 *module;
	struct device___132 *dev;
	const struct attribute_group___131 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___87 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___87 *);
	void (*pmu_disable)(struct pmu___87 *);
	int (*event_init)(struct perf_event___87 *);
	void (*event_mapped)(struct perf_event___87 *, struct mm_struct___141 *);
	void (*event_unmapped)(struct perf_event___87 *, struct mm_struct___141 *);
	int (*add)(struct perf_event___87 *, int);
	void (*del)(struct perf_event___87 *, int);
	void (*start)(struct perf_event___87 *, int);
	void (*stop)(struct perf_event___87 *, int);
	void (*read)(struct perf_event___87 *);
	void (*start_txn)(struct pmu___87 *, unsigned int);
	int (*commit_txn)(struct pmu___87 *);
	void (*cancel_txn)(struct pmu___87 *);
	int (*event_idx)(struct perf_event___87 *);
	void (*sched_task)(struct perf_event_context___87 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___87 *);
	int (*filter_match)(struct perf_event___87 *);
	int (*check_period)(struct perf_event___87 *, u64);
};

struct perf_cpu_context___87 {
	struct perf_event_context___87 ctx;
	struct perf_event_context___87 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___87 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___87 {
	struct cgroup_subsys_state___118 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___80 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___80 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___80 *);
	struct list_head * (*get_fields)(struct trace_event_call___80 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___80 *);
};

struct bdi_writeback_congested___62 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___62 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___62 {
	struct bio___62 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___62 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___62 bip_inline_vecs[0];
};

struct bio_set___62 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___62 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___57 {
	struct mem_cgroup___57 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___57 {
	struct lruvec___141 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___57 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___57 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct hstate___18 {
	int next_nid_to_alloc;
	int next_nid_to_free;
	unsigned int order;
	long unsigned int mask;
	long unsigned int max_huge_pages;
	long unsigned int nr_huge_pages;
	long unsigned int free_huge_pages;
	long unsigned int resv_huge_pages;
	long unsigned int surplus_huge_pages;
	long unsigned int nr_overcommit_huge_pages;
	struct list_head hugepage_activelist;
	struct list_head hugepage_freelists[8];
	unsigned int nr_huge_pages_node[8];
	unsigned int free_huge_pages_node[8];
	unsigned int surplus_huge_pages_node[8];
	struct cftype___118 cgroup_files[5];
	char name[32];
};

typedef struct {
	long unsigned int pd;
} hugepd_t;

struct hstate___19 {
	int next_nid_to_alloc;
	int next_nid_to_free;
	unsigned int order;
	long unsigned int mask;
	long unsigned int max_huge_pages;
	long unsigned int nr_huge_pages;
	long unsigned int free_huge_pages;
	long unsigned int resv_huge_pages;
	long unsigned int surplus_huge_pages;
	long unsigned int nr_overcommit_huge_pages;
	struct list_head hugepage_activelist;
	struct list_head hugepage_freelists[8];
	unsigned int nr_huge_pages_node[8];
	unsigned int free_huge_pages_node[8];
	unsigned int surplus_huge_pages_node[8];
	struct cftype___101 cgroup_files[5];
	char name[32];
};

struct follow_page_context {
	struct dev_pagemap___122 *pgmap;
	unsigned int page_mask;
};

struct file___143;

struct kiocb___143;

struct vm_area_struct___143;

struct inode___143;

struct file_lock___143;

struct page___143;

struct seq_file___133;

struct file_operations___143 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___143 *, loff_t, int);
	ssize_t (*read)(struct file___143 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___143 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___143 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___143 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___143 *, bool);
	int (*iterate)(struct file___143 *, struct dir_context *);
	int (*iterate_shared)(struct file___143 *, struct dir_context *);
	__poll_t (*poll)(struct file___143 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___143 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___143 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___143 *, struct vm_area_struct___143 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___143 *, struct file___143 *);
	int (*flush)(struct file___143 *, fl_owner_t);
	int (*release)(struct inode___143 *, struct file___143 *);
	int (*fsync)(struct file___143 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___143 *, int);
	int (*lock)(struct file___143 *, int, struct file_lock___143 *);
	ssize_t (*sendpage)(struct file___143 *, struct page___143 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___143 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___143 *, int, struct file_lock___143 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___143 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___143 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___143 *, long int, struct file_lock___143 **, void **);
	long int (*fallocate)(struct file___143 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___133 *, struct file___143 *);
	ssize_t (*copy_file_range)(struct file___143 *, loff_t, struct file___143 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___143 *, loff_t, struct file___143 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___143 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___142 {
	u64 seqnum;
	struct vm_area_struct___143 *vmas[4];
};

struct page_frag___142 {
	struct page___143 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___142;

struct mem_cgroup___58;

struct pid___114;

struct cred___138;

struct nsproxy___135;

struct signal_struct___127;

struct bio_list___63;

struct backing_dev_info___63;

struct io_context___32;

struct css_set___119;

struct request_queue___30;

struct vm_struct___109;

struct task_struct___143 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___143 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___142 *mm;
	struct mm_struct___142 *active_mm;
	struct vmacache___142 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___143 *real_parent;
	struct task_struct___143 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___143 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___58 *active_memcg;
	long int rh_reserved2;
	struct pid___114 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___114 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___114 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___138 *ptracer_cred;
	const struct cred___138 *real_cred;
	const struct cred___138 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___135 *nsproxy;
	struct signal_struct___127 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___143 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___63 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___63 *backing_dev_info;
	struct io_context___32 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___119 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___142 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___58 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___30 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___143 *oom_reaper_list;
	struct vm_struct___109 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___87 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___143 *pgtable_t___142;

struct address_space___142;

struct dev_pagemap___140;

struct page___143 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___142 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___143 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___142 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___142 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___140 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___58 *mem_cgroup;
};

struct pglist_data___142;

struct lruvec___142 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___142 *pgdat;
};

struct zone___142 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___142 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___142 {
	struct zone___142 *zone;
	int zone_idx;
};

struct zonelist___142 {
	struct zoneref___142 _zonerefs[25];
};

struct pglist_data___142 {
	struct zone___142 node_zones[3];
	struct zonelist___142 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___143 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___143 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___142 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___143 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___143 *owner;
};

struct secondary_data___143 {
	void *stack;
	struct task_struct___143 *task;
	long int status;
};

struct blocking_notifier_head___142 {
	struct rw_semaphore___143 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___140;

struct vm_area_struct___143 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___143 *vm_next;
	struct vm_area_struct___143 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___142 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___140 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___143 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___142;

struct user_namespace___123;

struct mm_struct___142 {
	struct {
		struct vm_area_struct___143 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___143 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___143 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___142 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___143 *owner;
		struct user_namespace___123 *user_ns;
		struct file___143 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___142 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___142;

struct address_space___142 {
	struct inode___143 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___143 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___142 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___140)(struct vm_area_struct___143 *, long unsigned int, const struct page___143 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___140)(struct page___143 *, void *);

struct device___133;

struct dev_pagemap___140 {
	dev_page_fault_t___140 page_fault;
	dev_page_free_t___140 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___133 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct cgroup___119;

struct cgroup_subsys___119;

struct cgroup_subsys_state___119 {
	struct cgroup___119 *cgroup;
	struct cgroup_subsys___119 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___119 *parent;
};

struct kernfs_node___139;

struct cgroup_file___119 {
	struct kernfs_node___139 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___58;

struct mem_cgroup___58 {
	struct cgroup_subsys_state___119 css;
	struct mem_cgroup_id___6 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___119 events_file;
	struct cgroup_file___119 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___143 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___58 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry___142;

struct path___142 {
	struct vfsmount *mnt;
	struct dentry___142 *dentry;
};

struct fown_struct___114 {
	rwlock_t lock;
	struct pid___114 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___143 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___142 f_path;
	struct inode___143 *f_inode;
	const struct file_operations___143 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___114 f_owner;
	const struct cred___138 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___142 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___140;

struct vm_operations_struct___140 {
	void (*open)(struct vm_area_struct___143 *);
	void (*close)(struct vm_area_struct___143 *);
	int (*split)(struct vm_area_struct___143 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___143 *);
	vm_fault_t (*fault)(struct vm_fault___140 *);
	vm_fault_t (*huge_fault)(struct vm_fault___140 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___140 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___143 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___140 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___140 *);
	int (*access)(struct vm_area_struct___143 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___143 *);
	int (*set_policy)(struct vm_area_struct___143 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___143 *, long unsigned int);
	struct page___143 * (*find_special_page)(struct vm_area_struct___143 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___142 {
	struct task_struct___143 *task;
	struct core_thread___142 *next;
};

struct core_state___142 {
	atomic_t nr_threads;
	struct core_thread___142 dumper;
	struct completion startup;
};

struct key___138;

struct ucounts___123;

struct user_namespace___123 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___123 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___4 ns;
	long unsigned int flags;
	struct key___138 *persistent_keyring_register;
	struct rw_semaphore___143 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___123 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___140 {
	struct vm_area_struct___143 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___143 *cow_page;
	struct mem_cgroup___58 *memcg;
	struct page___143 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___142 prealloc_pte;
};

struct shrink_control___58 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___58 *memcg;
};

struct shrinker___58 {
	long unsigned int (*count_objects)(struct shrinker___58 *, struct shrink_control___58 *);
	long unsigned int (*scan_objects)(struct shrinker___58 *, struct shrink_control___58 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct pid_namespace___114;

struct upid___114 {
	int nr;
	struct pid_namespace___114 *ns;
};

struct pid_namespace___114 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___143 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___114 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___142 *proc_self;
	struct dentry___142 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___123 *user_ns;
	struct ucounts___123 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___4 ns;
};

struct pid___114 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___114 numbers[1];
};

struct user_struct___138 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___138 *uid_keyring;
	struct key___138 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___138 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___138 *session_keyring;
	struct key___138 *process_keyring;
	struct key___138 *thread_keyring;
	struct key___138 *request_key_auth;
	void *security;
	struct user_struct___138 *user;
	struct user_namespace___123 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___119;

struct nsproxy___135 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___114 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___119 *cgroup_ns;
};

struct signal_struct___127 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___143 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___143 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___114 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___114 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___142 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___114 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide41;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___63;

struct bio_list___63 {
	struct bio___63 *head;
	struct bio___63 *tail;
};

struct bdi_writeback_congested___63;

struct bdi_writeback___63 {
	struct backing_dev_info___63 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___63 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___119 *memcg_css;
	struct cgroup_subsys_state___119 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___63 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___63 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___133 *dev;
	struct device___133 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___142 *debug_dir;
	struct dentry___142 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___32;

struct io_context___32 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___32 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___119 {
	struct cgroup_subsys_state___119 *subsys[13];
	refcount_t refcount;
	struct css_set___119 *dom_cset;
	struct cgroup___119 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___119 *mg_src_cgrp;
	struct cgroup___119 *mg_dst_cgrp;
	struct css_set___119 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

typedef blk_qc_t make_request_fn___29(struct request_queue___30 *, struct bio___63 *);

struct request___30;

typedef int dma_drain_needed_fn___29(struct request___30 *);

struct kset___136;

struct kobj_type___136;

struct kobject___137 {
	const char *name;
	struct list_head entry;
	struct kobject___137 *parent;
	struct kset___136 *kset;
	struct kobj_type___136 *ktype;
	struct kernfs_node___139 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___29;

struct bsg_class_device___29 {
	struct device___133 *class_dev;
	int minor;
	struct request_queue___30 *queue;
	const struct bsg_ops___29 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___63 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___63 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___29;

struct request_queue___30 {
	struct list_head queue_head;
	struct request___30 *last_merge;
	struct elevator_queue___29 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___29 *make_request_fn;
	dma_drain_needed_fn___29 *dma_drain_needed;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___63 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___137 kobj;
	struct kobject___137 *mq_kobj;
	struct blk_integrity integrity;
	struct device___133 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	struct bsg_class_device___29 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___63 bio_split;
	struct dentry___142 *debugfs_dir;
	struct dentry___142 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___109 {
	struct vm_struct___109 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___143 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___127 {
	struct task_struct___143 task;
	long unsigned int stack[8192];
};

struct dev_pm_info___133 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___133 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___133;

struct bus_type___133;

struct device_driver___133;

struct dev_pm_domain___133;

struct fwnode_handle___99;

struct class___133;

struct attribute_group___132;

struct device___133 {
	struct device___133 *parent;
	struct device_private *p;
	struct kobject___137 kobj;
	const char *init_name;
	const struct device_type___133 *type;
	struct mutex mutex;
	struct bus_type___133 *bus;
	struct device_driver___133 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___133 power;
	struct dev_pm_domain___133 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___99 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___133 *class;
	const struct attribute_group___132 **groups;
	void (*release)(struct device___133 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___142;

struct super_block___142;

struct dentry___142 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___142 *d_parent;
	struct qstr d_name;
	struct inode___143 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___142 *d_op;
	struct super_block___142 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___142;

struct block_device___143;

struct inode___143 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___142 *i_op;
	struct super_block___142 *i_sb;
	struct address_space___142 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___143 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___63 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___143 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___142 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___143 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___142 {
	int (*d_revalidate)(struct dentry___142 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___142 *, unsigned int);
	int (*d_hash)(const struct dentry___142 *, struct qstr *);
	int (*d_compare)(const struct dentry___142 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___142 *);
	int (*d_init)(struct dentry___142 *);
	void (*d_release)(struct dentry___142 *);
	void (*d_prune)(struct dentry___142 *);
	void (*d_iput)(struct dentry___142 *, struct inode___143 *);
	char * (*d_dname)(struct dentry___142 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___142 *);
	int (*d_manage)(const struct path___142 *, bool);
	struct dentry___142 * (*d_real)(struct dentry___142 *, const struct inode___143 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___142;

struct mem_dqinfo___142 {
	struct quota_format_type___142 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___142;

struct quota_info___142 {
	unsigned int flags;
	struct rw_semaphore___143 dqio_sem;
	struct inode___143 *files[3];
	struct mem_dqinfo___142 info[3];
	const struct quota_format_ops___142 *ops[3];
};

struct rcuwait___142 {
	struct task_struct___143 *task;
};

struct percpu_rw_semaphore___142 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___143 rw_sem;
	struct rcuwait___142 writer;
	int readers_block;
};

struct sb_writers___142 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___142 rw_sem[3];
};

struct file_system_type___142;

struct super_operations___142;

struct dquot_operations___142;

struct quotactl_ops___142;

struct super_block___142 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___142 *s_type;
	const struct super_operations___142 *s_op;
	const struct dquot_operations___142 *dq_op;
	const struct quotactl_ops___142 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___142 *s_root;
	struct rw_semaphore___143 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___143 *s_bdev;
	struct backing_dev_info___63 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___142 s_dquot;
	struct sb_writers___142 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___142 *s_d_op;
	int cleancache_poolid;
	struct shrinker___58 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___123 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct io_cq___32 {
	struct request_queue___30 *q;
	struct io_context___32 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___143 {
	struct file___143 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___143 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___142 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___143 *ia_file;
};

struct dquot___142 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___142 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___142 {
	int qf_fmt_id;
	const struct quota_format_ops___142 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___142 *qf_next;
};

struct quota_format_ops___142 {
	int (*check_quota_file)(struct super_block___142 *, int);
	int (*read_file_info)(struct super_block___142 *, int);
	int (*write_file_info)(struct super_block___142 *, int);
	int (*free_file_info)(struct super_block___142 *, int);
	int (*read_dqblk)(struct dquot___142 *);
	int (*commit_dqblk)(struct dquot___142 *);
	int (*release_dqblk)(struct dquot___142 *);
	int (*get_next_id)(struct super_block___142 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___142 {
	int (*write_dquot)(struct dquot___142 *);
	struct dquot___142 * (*alloc_dquot)(struct super_block___142 *, int);
	void (*destroy_dquot)(struct dquot___142 *);
	int (*acquire_dquot)(struct dquot___142 *);
	int (*release_dquot)(struct dquot___142 *);
	int (*mark_dirty)(struct dquot___142 *);
	int (*write_info)(struct super_block___142 *, int);
	qsize_t * (*get_reserved_space)(struct inode___143 *);
	int (*get_projid)(struct inode___143 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___143 *, qsize_t *);
	int (*get_next_id)(struct super_block___142 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___142 {
	int (*quota_on)(struct super_block___142 *, int, int, const struct path___142 *);
	int (*quota_off)(struct super_block___142 *, int);
	int (*quota_enable)(struct super_block___142 *, unsigned int);
	int (*quota_disable)(struct super_block___142 *, unsigned int);
	int (*quota_sync)(struct super_block___142 *, int);
	int (*set_info)(struct super_block___142 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___142 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___142 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___142 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___142 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___142 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___60;

struct swap_info_struct___40;

struct address_space_operations___142 {
	int (*writepage)(struct page___143 *, struct writeback_control___60 *);
	int (*readpage)(struct file___143 *, struct page___143 *);
	int (*writepages)(struct address_space___142 *, struct writeback_control___60 *);
	int (*set_page_dirty)(struct page___143 *);
	int (*readpages)(struct file___143 *, struct address_space___142 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___143 *, struct address_space___142 *, loff_t, unsigned int, unsigned int, struct page___143 **, void **);
	int (*write_end)(struct file___143 *, struct address_space___142 *, loff_t, unsigned int, unsigned int, struct page___143 *, void *);
	sector_t (*bmap)(struct address_space___142 *, sector_t);
	void (*invalidatepage)(struct page___143 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___143 *, gfp_t);
	void (*freepage)(struct page___143 *);
	ssize_t (*direct_IO)(struct kiocb___143 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___142 *, struct page___143 *, struct page___143 *, enum migrate_mode);
	bool (*isolate_page)(struct page___143 *, isolate_mode_t);
	void (*putback_page)(struct page___143 *);
	int (*launder_page)(struct page___143 *);
	int (*is_partially_uptodate)(struct page___143 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___143 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___142 *, struct page___143 *);
	int (*swap_activate)(struct swap_info_struct___40 *, struct file___143 *, sector_t *);
	void (*swap_deactivate)(struct file___143 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___60 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___63 *wb;
	struct inode___143 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct swap_info_struct___40 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___143 *bdev;
	struct file___143 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct hd_struct___30;

struct gendisk___30;

struct block_device___143 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___143 *bd_inode;
	struct super_block___142 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___143 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___30 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___30 *bd_disk;
	struct request_queue___30 *bd_queue;
	struct backing_dev_info___63 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct hd_struct___30 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___133 __dev;
	struct kobject___137 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___30;

struct block_device_operations___30;

struct gendisk___30 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___30 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___30 *part_tbl;
	struct hd_struct___30 part0;
	const struct block_device_operations___30 *fops;
	struct request_queue___30 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___143 lookup_sem;
	struct kobject___137 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___137 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___142 {
	struct dentry___142 * (*lookup)(struct inode___143 *, struct dentry___142 *, unsigned int);
	const char * (*get_link)(struct dentry___142 *, struct inode___143 *, struct delayed_call *);
	int (*permission)(struct inode___143 *, int);
	struct posix_acl * (*get_acl)(struct inode___143 *, int);
	int (*readlink)(struct dentry___142 *, char *, int);
	int (*create)(struct inode___143 *, struct dentry___142 *, umode_t, bool);
	int (*link)(struct dentry___142 *, struct inode___143 *, struct dentry___142 *);
	int (*unlink)(struct inode___143 *, struct dentry___142 *);
	int (*symlink)(struct inode___143 *, struct dentry___142 *, const char *);
	int (*mkdir)(struct inode___143 *, struct dentry___142 *, umode_t);
	int (*rmdir)(struct inode___143 *, struct dentry___142 *);
	int (*mknod)(struct inode___143 *, struct dentry___142 *, umode_t, dev_t);
	int (*rename)(struct inode___143 *, struct dentry___142 *, struct inode___143 *, struct dentry___142 *, unsigned int);
	int (*setattr)(struct dentry___142 *, struct iattr___142 *);
	int (*getattr)(const struct path___142 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___142 *, char *, size_t);
	int (*fiemap)(struct inode___143 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___143 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___143 *, struct dentry___142 *, struct file___143 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___143 *, struct dentry___142 *, umode_t);
	int (*set_acl)(struct inode___143 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___142 {
	void (*fl_copy_lock)(struct file_lock___143 *, struct file_lock___143 *);
	void (*fl_release_private)(struct file_lock___143 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___142;

struct lock_manager_operations___142;

struct file_lock___143 {
	struct file_lock___143 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___143 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___142 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___142 *fl_ops;
	const struct lock_manager_operations___142 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___142 {
	int (*lm_compare_owner)(struct file_lock___143 *, struct file_lock___143 *);
	long unsigned int (*lm_owner_key)(struct file_lock___143 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___143 *);
	int (*lm_grant)(struct file_lock___143 *, int);
	bool (*lm_break)(struct file_lock___143 *);
	int (*lm_change)(struct file_lock___143 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___143 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___142 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___142 *fa_next;
	struct file___143 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___142 {
	const char *name;
	int fs_flags;
	struct dentry___142 * (*mount)(struct file_system_type___142 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___142 *);
	struct module___11 *owner;
	struct file_system_type___142 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___142 {
	struct inode___143 * (*alloc_inode)(struct super_block___142 *);
	void (*destroy_inode)(struct inode___143 *);
	void (*dirty_inode)(struct inode___143 *, int);
	int (*write_inode)(struct inode___143 *, struct writeback_control___60 *);
	int (*drop_inode)(struct inode___143 *);
	void (*evict_inode)(struct inode___143 *);
	void (*put_super)(struct super_block___142 *);
	int (*sync_fs)(struct super_block___142 *, int);
	int (*freeze_super)(struct super_block___142 *);
	int (*freeze_fs)(struct super_block___142 *);
	int (*thaw_super)(struct super_block___142 *);
	int (*unfreeze_fs)(struct super_block___142 *);
	int (*statfs)(struct dentry___142 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___142 *, int *, char *);
	void (*umount_begin)(struct super_block___142 *);
	int (*show_options)(struct seq_file___133 *, struct dentry___142 *);
	int (*show_devname)(struct seq_file___133 *, struct dentry___142 *);
	int (*show_path)(struct seq_file___133 *, struct dentry___142 *);
	int (*show_stats)(struct seq_file___133 *, struct dentry___142 *);
	ssize_t (*quota_read)(struct super_block___142 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___142 *, int, const char *, size_t, loff_t);
	struct dquot___142 ** (*get_dquots)(struct inode___143 *);
	int (*bdev_try_to_free_page)(struct super_block___142 *, struct page___143 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___142 *, struct shrink_control___58 *);
	long int (*free_cached_objects)(struct super_block___142 *, struct shrink_control___58 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___131;

struct seq_file___133 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___131 *op;
	int poll_event;
	const struct file___143 *file;
	void *private;
};

typedef void bio_end_io_t___63(struct bio___63 *);

struct bio_vec___63 {
	struct page___143 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___63;

struct bio___63 {
	struct bio___63 *bi_next;
	struct gendisk___30 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___63 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___63 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___63 *bi_io_vec;
	struct bio_set___63 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___63 bi_inline_vecs[0];
};

struct kobj_attribute___137 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___137 *, struct kobj_attribute___137 *, char *);
	ssize_t (*store)(struct kobject___137 *, struct kobj_attribute___137 *, const char *, size_t);
};

typedef void compound_page_dtor___140(struct page___143 *);

typedef int (*key_restrict_link_func_t___138)(struct key___138 *, const struct key_type *, const union key_payload *, struct key___138 *);

struct key_restriction___138;

struct key___138 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___143 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___138 *restrict_link;
};

struct key_restriction___138 {
	key_restrict_link_func_t___138 check;
	struct key___138 *key;
	struct key_type *keytype;
};

struct seq_operations___131 {
	void * (*start)(struct seq_file___133 *, loff_t *);
	void (*stop)(struct seq_file___133 *, void *);
	void * (*next)(struct seq_file___133 *, void *, loff_t *);
	int (*show)(struct seq_file___133 *, void *);
};

struct kernfs_root___139;

struct kernfs_elem_dir___139 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___139 *root;
};

struct kernfs_syscall_ops___139;

struct kernfs_root___139 {
	struct kernfs_node___139 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___139 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___139 {
	struct kernfs_node___139 *target_kn;
};

struct kernfs_ops___139;

struct kernfs_elem_attr___139 {
	const struct kernfs_ops___139 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___139 *notify_next;
};

struct kernfs_node___139 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___139 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___139 dir;
		struct kernfs_elem_symlink___139 symlink;
		struct kernfs_elem_attr___139 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___139;

struct kernfs_ops___139 {
	int (*open)(struct kernfs_open_file___139 *);
	void (*release)(struct kernfs_open_file___139 *);
	int (*seq_show)(struct seq_file___133 *, void *);
	void * (*seq_start)(struct seq_file___133 *, loff_t *);
	void * (*seq_next)(struct seq_file___133 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___133 *, void *);
	ssize_t (*read)(struct kernfs_open_file___139 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___139 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___139 *, struct vm_area_struct___143 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___139 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___139 {
	int (*remount_fs)(struct kernfs_root___139 *, int *, char *);
	int (*show_options)(struct seq_file___133 *, struct kernfs_root___139 *);
	int (*mkdir)(struct kernfs_node___139 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___139 *);
	int (*rename)(struct kernfs_node___139 *, struct kernfs_node___139 *, const char *);
	int (*show_path)(struct seq_file___133 *, struct kernfs_node___139 *, struct kernfs_root___139 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___139 {
	struct kernfs_node___139 *kn;
	struct file___143 *file;
	struct seq_file___133 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___140 *vm_ops;
};

struct cgroup_namespace___119 {
	refcount_t count;
	struct ns_common___4 ns;
	struct user_namespace___123 *user_ns;
	struct ucounts___123 *ucounts;
	struct css_set___119 *root_cset;
};

struct ucounts___123 {
	struct hlist_node node;
	struct user_namespace___123 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___119;

struct bpf_map_ops___119 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___119 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___119 *, struct file___143 *);
	void (*map_free)(struct bpf_map___119 *);
	int (*map_get_next_key)(struct bpf_map___119 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___119 *);
	void * (*map_lookup_elem)(struct bpf_map___119 *, void *);
	int (*map_update_elem)(struct bpf_map___119 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___119 *, void *);
	int (*map_push_elem)(struct bpf_map___119 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___119 *, void *);
	int (*map_peek_elem)(struct bpf_map___119 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___119 *, struct file___143 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___119 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___119 *, void *, struct seq_file___133 *);
	int (*map_check_btf)(const struct bpf_map___119 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___119 {
	const struct bpf_map_ops___119 *ops;
	struct bpf_map___119 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___138 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___119;

typedef void (*kthread_work_func_t___119)(struct kthread_work___119 *);

struct kthread_worker___119;

struct kthread_work___119 {
	struct list_head node;
	kthread_work_func_t___119 func;
	struct kthread_worker___119 *worker;
	int canceling;
};

struct kthread_worker___119 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___143 *task;
	struct kthread_work___119 *current_work;
};

struct kthread_delayed_work___119 {
	struct kthread_work___119 work;
	struct timer_list timer;
};

struct psi_group___119 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___119 *poll_kworker;
	struct kthread_delayed_work___119 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___119;

struct cgroup_rstat_cpu___119;

struct cgroup___119 {
	struct cgroup_subsys_state___119 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___139 *kn;
	struct cgroup_file___119 procs_file;
	struct cgroup_file___119 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___119 *subsys[13];
	struct cgroup_root___119 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___119 *dom_cgrp;
	struct cgroup_rstat_cpu___119 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___4 bpf;
	atomic_t congestion_count;
	struct cgroup___119 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___119 psi;
	int ancestor_ids[0];
};

struct cftype___119;

struct cgroup_subsys___119 {
	struct cgroup_subsys_state___119 * (*css_alloc)(struct cgroup_subsys_state___119 *);
	int (*css_online)(struct cgroup_subsys_state___119 *);
	void (*css_offline)(struct cgroup_subsys_state___119 *);
	void (*css_released)(struct cgroup_subsys_state___119 *);
	void (*css_free)(struct cgroup_subsys_state___119 *);
	void (*css_reset)(struct cgroup_subsys_state___119 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___119 *, int);
	int (*css_extra_stat_show)(struct seq_file___133 *, struct cgroup_subsys_state___119 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___143 *);
	void (*cancel_fork)(struct task_struct___143 *);
	void (*fork)(struct task_struct___143 *);
	void (*exit)(struct task_struct___143 *);
	void (*free)(struct task_struct___143 *);
	void (*bind)(struct cgroup_subsys_state___119 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___119 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___119 *dfl_cftypes;
	struct cftype___119 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___119 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___119 *updated_children;
	struct cgroup___119 *updated_next;
};

struct cgroup_root___119 {
	struct kernfs_root___139 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___119 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___119 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___119 *ss;
	struct list_head node;
	struct kernfs_ops___139 *kf_ops;
	int (*open)(struct kernfs_open_file___139 *);
	void (*release)(struct kernfs_open_file___139 *);
	u64 (*read_u64)(struct cgroup_subsys_state___119 *, struct cftype___119 *);
	s64 (*read_s64)(struct cgroup_subsys_state___119 *, struct cftype___119 *);
	int (*seq_show)(struct seq_file___133 *, void *);
	void * (*seq_start)(struct seq_file___133 *, loff_t *);
	void * (*seq_next)(struct seq_file___133 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___133 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___119 *, struct cftype___119 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___119 *, struct cftype___119 *, s64);
	ssize_t (*write)(struct kernfs_open_file___139 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___139 *, struct poll_table_struct___6 *);
};

struct bdi_writeback_congested___63 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___63 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___63 {
	struct bio___63 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___63 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___63 bip_inline_vecs[0];
};

struct mem_cgroup_reclaim_iter___58 {
	struct mem_cgroup___58 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___58 {
	struct lruvec___142 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___58 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___58 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct bin_attribute___132;

struct attribute_group___132 {
	const char *name;
	umode_t (*is_visible)(struct kobject___137 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___137 *, struct bin_attribute___132 *, int);
	struct attribute **attrs;
	struct bin_attribute___132 **bin_attrs;
};

struct bin_attribute___132 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___143 *, struct kobject___137 *, struct bin_attribute___132 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___143 *, struct kobject___137 *, struct bin_attribute___132 *, char *, loff_t, size_t);
	int (*mmap)(struct file___143 *, struct kobject___137 *, struct bin_attribute___132 *, struct vm_area_struct___143 *);
};

struct sysfs_ops___136 {
	ssize_t (*show)(struct kobject___137 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___137 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___136;

struct kset___136 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___137 kobj;
	const struct kset_uevent_ops___136 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___136 {
	void (*release)(struct kobject___137 *);
	const struct sysfs_ops___136 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___2 * (*child_ns_type)(struct kobject___137 *);
	const void * (*namespace)(struct kobject___137 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___136 {
	int (* const filter)(struct kset___136 *, struct kobject___137 *);
	const char * (* const name)(struct kset___136 *, struct kobject___137 *);
	int (* const uevent)(struct kset___136 *, struct kobject___137 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___133 {
	int (*prepare)(struct device___133 *);
	void (*complete)(struct device___133 *);
	int (*suspend)(struct device___133 *);
	int (*resume)(struct device___133 *);
	int (*freeze)(struct device___133 *);
	int (*thaw)(struct device___133 *);
	int (*poweroff)(struct device___133 *);
	int (*restore)(struct device___133 *);
	int (*suspend_late)(struct device___133 *);
	int (*resume_early)(struct device___133 *);
	int (*freeze_late)(struct device___133 *);
	int (*thaw_early)(struct device___133 *);
	int (*poweroff_late)(struct device___133 *);
	int (*restore_early)(struct device___133 *);
	int (*suspend_noirq)(struct device___133 *);
	int (*resume_noirq)(struct device___133 *);
	int (*freeze_noirq)(struct device___133 *);
	int (*thaw_noirq)(struct device___133 *);
	int (*poweroff_noirq)(struct device___133 *);
	int (*restore_noirq)(struct device___133 *);
	int (*runtime_suspend)(struct device___133 *);
	int (*runtime_resume)(struct device___133 *);
	int (*runtime_idle)(struct device___133 *);
};

struct dev_pm_domain___133 {
	struct dev_pm_ops___133 ops;
	void (*detach)(struct device___133 *, bool);
	int (*activate)(struct device___133 *);
	void (*sync)(struct device___133 *);
	void (*dismiss)(struct device___133 *);
};

struct bus_type___133 {
	const char *name;
	const char *dev_name;
	struct device___133 *dev_root;
	const struct attribute_group___132 **bus_groups;
	const struct attribute_group___132 **dev_groups;
	const struct attribute_group___132 **drv_groups;
	int (*match)(struct device___133 *, struct device_driver___133 *);
	int (*uevent)(struct device___133 *, struct kobj_uevent_env *);
	int (*probe)(struct device___133 *);
	int (*remove)(struct device___133 *);
	void (*shutdown)(struct device___133 *);
	int (*online)(struct device___133 *);
	int (*offline)(struct device___133 *);
	int (*suspend)(struct device___133 *, pm_message_t);
	int (*resume)(struct device___133 *);
	int (*num_vf)(struct device___133 *);
	int (*dma_configure)(struct device___133 *);
	const struct dev_pm_ops___133 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___133 {
	const char *name;
	struct bus_type___133 *bus;
	struct module___11 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___133 *);
	int (*remove)(struct device___133 *);
	void (*shutdown)(struct device___133 *);
	int (*suspend)(struct device___133 *, pm_message_t);
	int (*resume)(struct device___133 *);
	const struct attribute_group___132 **groups;
	const struct dev_pm_ops___133 *pm;
	void (*coredump)(struct device___133 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___133 {
	const char *name;
	const struct attribute_group___132 **groups;
	int (*uevent)(struct device___133 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___133 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___133 *);
	const struct dev_pm_ops___133 *pm;
};

struct class___133 {
	const char *name;
	struct module___11 *owner;
	const struct attribute_group___132 **class_groups;
	const struct attribute_group___132 **dev_groups;
	struct kobject___137 *dev_kobj;
	int (*dev_uevent)(struct device___133 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___133 *, umode_t *);
	void (*class_release)(struct class___133 *);
	void (*dev_release)(struct device___133 *);
	int (*shutdown_pre)(struct device___133 *);
	const struct kobj_ns_type_operations___2 *ns_type;
	const void * (*namespace)(struct device___133 *);
	const struct dev_pm_ops___133 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct fwnode_operations___99;

struct fwnode_handle___99 {
	struct fwnode_handle___99 *secondary;
	const struct fwnode_operations___99 *ops;
};

struct node___111 {
	struct device___133 dev;
};

struct disk_part_tbl___30 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___30 *last_lookup;
	struct hd_struct___30 *part[0];
};

struct block_device_operations___30 {
	int (*open)(struct block_device___143 *, fmode_t);
	void (*release)(struct gendisk___30 *, fmode_t);
	int (*rw_page)(struct block_device___143 *, sector_t, struct page___143 *, unsigned int);
	int (*ioctl)(struct block_device___143 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___143 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___30 *, unsigned int);
	int (*media_changed)(struct gendisk___30 *);
	void (*unlock_native_capacity)(struct gendisk___30 *);
	int (*revalidate_disk)(struct gendisk___30 *);
	int (*getgeo)(struct block_device___143 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___143 *, long unsigned int);
	int (*report_zones)(struct gendisk___30 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___11 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___29 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___30 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___30 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___30 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___29(struct request___30 *, blk_status_t);

struct request___30 {
	struct request_queue___30 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___63 *bio;
	struct bio___63 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___63 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___32 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___29 *saved_end_io;
		} flush;
	};
	struct gendisk___30 *rq_disk;
	struct hd_struct___30 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___29 *end_io;
	void *end_io_data;
	struct request___30 *next_rq;
};

struct fwnode_reference_args___99;

struct fwnode_endpoint___99;

struct fwnode_operations___99 {
	struct fwnode_handle___99 * (*get)(struct fwnode_handle___99 *);
	void (*put)(struct fwnode_handle___99 *);
	bool (*device_is_available)(const struct fwnode_handle___99 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___99 *, const struct device___133 *);
	bool (*property_present)(const struct fwnode_handle___99 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___99 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___99 *, const char *, const char **, size_t);
	struct fwnode_handle___99 * (*get_parent)(const struct fwnode_handle___99 *);
	struct fwnode_handle___99 * (*get_next_child_node)(const struct fwnode_handle___99 *, struct fwnode_handle___99 *);
	struct fwnode_handle___99 * (*get_named_child_node)(const struct fwnode_handle___99 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___99 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___99 *);
	struct fwnode_handle___99 * (*graph_get_next_endpoint)(const struct fwnode_handle___99 *, struct fwnode_handle___99 *);
	struct fwnode_handle___99 * (*graph_get_remote_endpoint)(const struct fwnode_handle___99 *);
	struct fwnode_handle___99 * (*graph_get_port_parent)(struct fwnode_handle___99 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___99 *, struct fwnode_endpoint___99 *);
};

struct fwnode_endpoint___99 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___99 *local_fwnode;
};

struct fwnode_reference_args___99 {
	struct fwnode_handle___99 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct elevator_type___29;

struct elevator_mq_ops___29 {
	int (*init_sched)(struct request_queue___30 *, struct elevator_type___29 *);
	void (*exit_sched)(struct elevator_queue___29 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	bool (*allow_merge)(struct request_queue___30 *, struct request___30 *, struct bio___63 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx *, struct bio___63 *);
	int (*request_merge)(struct request_queue___30 *, struct request___30 **, struct bio___63 *);
	void (*request_merged)(struct request_queue___30 *, struct request___30 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___30 *, struct request___30 *, struct request___30 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___30 *, struct bio___63 *);
	void (*finish_request)(struct request___30 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___30 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___30 *, u64);
	void (*started_request)(struct request___30 *);
	void (*requeue_request)(struct request___30 *);
	struct request___30 * (*former_request)(struct request_queue___30 *, struct request___30 *);
	struct request___30 * (*next_request)(struct request_queue___30 *, struct request___30 *);
	void (*init_icq)(struct io_cq___32 *);
	void (*exit_icq)(struct io_cq___32 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___29;

struct elevator_type___29 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___29 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___29 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___11 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___29 {
	struct elevator_type___29 *type;
	void *elevator_data;
	struct kobject___137 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___29 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___29 *, char *);
	ssize_t (*store)(struct elevator_queue___29 *, const char *, size_t);
};

struct file___144;

struct kiocb___144;

struct vm_area_struct___144;

struct inode___144;

struct file_lock___144;

struct page___144;

struct seq_file___134;

struct file_operations___144 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___144 *, loff_t, int);
	ssize_t (*read)(struct file___144 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___144 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___144 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___144 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___144 *, bool);
	int (*iterate)(struct file___144 *, struct dir_context *);
	int (*iterate_shared)(struct file___144 *, struct dir_context *);
	__poll_t (*poll)(struct file___144 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___144 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___144 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___144 *, struct vm_area_struct___144 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___144 *, struct file___144 *);
	int (*flush)(struct file___144 *, fl_owner_t);
	int (*release)(struct inode___144 *, struct file___144 *);
	int (*fsync)(struct file___144 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___144 *, int);
	int (*lock)(struct file___144 *, int, struct file_lock___144 *);
	ssize_t (*sendpage)(struct file___144 *, struct page___144 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___144 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___144 *, int, struct file_lock___144 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___144 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___144 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___144 *, long int, struct file_lock___144 **, void **);
	long int (*fallocate)(struct file___144 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___134 *, struct file___144 *);
	ssize_t (*copy_file_range)(struct file___144 *, loff_t, struct file___144 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___144 *, loff_t, struct file___144 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___144 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct {
	u64 val;
} pfn_t;

struct vmacache___143 {
	u64 seqnum;
	struct vm_area_struct___144 *vmas[4];
};

struct page_frag___143 {
	struct page___144 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___143;

struct mem_cgroup___59;

struct cred___139;

struct nsproxy___136;

struct signal_struct___128;

struct bio_list___64;

struct backing_dev_info___64;

struct css_set___120;

struct vm_struct___110;

struct task_struct___144 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___144 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___143 *mm;
	struct mm_struct___143 *active_mm;
	struct vmacache___143 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___144 *real_parent;
	struct task_struct___144 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___144 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___59 *active_memcg;
	long int rh_reserved2;
	struct pid___114 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___114 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___114 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___139 *ptracer_cred;
	const struct cred___139 *real_cred;
	const struct cred___139 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___136 *nsproxy;
	struct signal_struct___128 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___144 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___64 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___64 *backing_dev_info;
	struct io_context___32 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___120 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___143 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___59 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___144 *oom_reaper_list;
	struct vm_struct___110 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___87 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct secondary_data___144 {
	void *stack;
	struct task_struct___144 *task;
	long int status;
};

struct rw_semaphore___144 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___144 *owner;
};

struct key___139;

struct ucounts___124;

struct user_namespace___124 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___124 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___4 ns;
	long unsigned int flags;
	struct key___139 *persistent_keyring_register;
	struct rw_semaphore___144 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___124 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___144 *pgtable_t___143;

struct address_space___143;

struct dev_pagemap___141;

struct page___144 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___143 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___144 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___143 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___143 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___141 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___59 *mem_cgroup;
};

struct user_struct___139 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___139 *uid_keyring;
	struct key___139 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct anon_vma___9;

struct vm_operations_struct___141;

struct vm_area_struct___144 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___144 *vm_next;
	struct vm_area_struct___144 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___143 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma___9 *anon_vma;
	const struct vm_operations_struct___141 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___144 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___143;

struct mm_struct___143 {
	struct {
		struct vm_area_struct___144 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___144 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___144 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___143 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___144 *owner;
		struct user_namespace___124 *user_ns;
		struct file___144 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___143 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup___120;

struct cgroup_subsys___120;

struct cgroup_subsys_state___120 {
	struct cgroup___120 *cgroup;
	struct cgroup_subsys___120 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___120 *parent;
};

struct kernfs_node___140;

struct cgroup_file___120 {
	struct kernfs_node___140 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___59;

struct mem_cgroup___59 {
	struct cgroup_subsys_state___120 css;
	struct mem_cgroup_id___6 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___120 events_file;
	struct cgroup_file___120 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___144 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___59 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cred___139 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___139 *session_keyring;
	struct key___139 *process_keyring;
	struct key___139 *thread_keyring;
	struct key___139 *request_key_auth;
	void *security;
	struct user_struct___139 *user;
	struct user_namespace___124 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___120;

struct nsproxy___136 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___120 *cgroup_ns;
};

struct signal_struct___128 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___144 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___144 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___114 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___114 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___143 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___114 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___64;

struct bio_list___64 {
	struct bio___64 *head;
	struct bio___64 *tail;
};

struct bdi_writeback_congested___64;

struct bdi_writeback___64 {
	struct backing_dev_info___64 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___64 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___120 *memcg_css;
	struct cgroup_subsys_state___120 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___134;

struct dentry___143;

struct backing_dev_info___64 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___64 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___134 *dev;
	struct device___134 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___143 *debug_dir;
	struct dentry___143 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___120 {
	struct cgroup_subsys_state___120 *subsys[13];
	refcount_t refcount;
	struct css_set___120 *dom_cset;
	struct cgroup___120 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___120 *mg_src_cgrp;
	struct cgroup___120 *mg_dst_cgrp;
	struct css_set___120 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct vm_struct___110 {
	struct vm_struct___110 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___144 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___128 {
	struct task_struct___144 task;
	long unsigned int stack[8192];
};

struct pglist_data___143;

struct lruvec___143 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___143 *pgdat;
};

struct zone___143 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___143 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___143 {
	struct zone___143 *zone;
	int zone_idx;
};

struct zonelist___143 {
	struct zoneref___143 _zonerefs[25];
};

struct pglist_data___143 {
	struct zone___143 node_zones[3];
	struct zonelist___143 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___144 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___144 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___143 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___143 {
	struct rw_semaphore___144 rwsem;
	struct notifier_block *head;
};

struct address_space_operations___143;

struct address_space___143 {
	struct inode___144 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___144 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___143 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___141)(struct vm_area_struct___144 *, long unsigned int, const struct page___144 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___141)(struct page___144 *, void *);

struct dev_pagemap___141 {
	dev_page_fault_t___141 page_fault;
	dev_page_free_t___141 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___134 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___143 {
	struct vfsmount *mnt;
	struct dentry___143 *dentry;
};

struct file___144 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___143 f_path;
	struct inode___144 *f_inode;
	const struct file_operations___144 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___114 f_owner;
	const struct cred___139 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___143 *f_mapping;
	errseq_t f_wb_err;
};

struct anon_vma___9 {
	struct anon_vma___9 *root;
	struct rw_semaphore___144 rwsem;
	atomic_t refcount;
	unsigned int degree;
	struct anon_vma___9 *parent;
	struct rb_root_cached rb_root;
};

struct vm_fault___141;

struct vm_operations_struct___141 {
	void (*open)(struct vm_area_struct___144 *);
	void (*close)(struct vm_area_struct___144 *);
	int (*split)(struct vm_area_struct___144 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___144 *);
	vm_fault_t (*fault)(struct vm_fault___141 *);
	vm_fault_t (*huge_fault)(struct vm_fault___141 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___141 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___144 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___141 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___141 *);
	int (*access)(struct vm_area_struct___144 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___144 *);
	int (*set_policy)(struct vm_area_struct___144 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___144 *, long unsigned int);
	struct page___144 * (*find_special_page)(struct vm_area_struct___144 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___143 {
	struct task_struct___144 *task;
	struct core_thread___143 *next;
};

struct core_state___143 {
	atomic_t nr_threads;
	struct core_thread___143 dumper;
	struct completion startup;
};

struct vm_fault___141 {
	struct vm_area_struct___144 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___144 *cow_page;
	struct mem_cgroup___59 *memcg;
	struct page___144 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___143 prealloc_pte;
};

struct shrink_control___59 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___59 *memcg;
};

struct shrinker___59 {
	long unsigned int (*count_objects)(struct shrinker___59 *, struct shrink_control___59 *);
	long unsigned int (*scan_objects)(struct shrinker___59 *, struct shrink_control___59 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct kset___137;

struct kobj_type___137;

struct kobject___138 {
	const char *name;
	struct list_head entry;
	struct kobject___138 *parent;
	struct kset___137 *kset;
	struct kobj_type___137 *ktype;
	struct kernfs_node___140 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___134 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___134 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___134;

struct bus_type___134;

struct device_driver___134;

struct dev_pm_domain___134;

struct fwnode_handle___100;

struct class___134;

struct attribute_group___133;

struct device___134 {
	struct device___134 *parent;
	struct device_private *p;
	struct kobject___138 kobj;
	const char *init_name;
	const struct device_type___134 *type;
	struct mutex mutex;
	struct bus_type___134 *bus;
	struct device_driver___134 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___134 power;
	struct dev_pm_domain___134 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___100 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___134 *class;
	const struct attribute_group___133 **groups;
	void (*release)(struct device___134 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___143;

struct super_block___143;

struct dentry___143 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___143 *d_parent;
	struct qstr d_name;
	struct inode___144 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___143 *d_op;
	struct super_block___143 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___143;

struct block_device___144;

struct inode___144 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___143 *i_op;
	struct super_block___143 *i_sb;
	struct address_space___143 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___144 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___64 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___144 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___143 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___144 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___143 {
	int (*d_revalidate)(struct dentry___143 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___143 *, unsigned int);
	int (*d_hash)(const struct dentry___143 *, struct qstr *);
	int (*d_compare)(const struct dentry___143 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___143 *);
	int (*d_init)(struct dentry___143 *);
	void (*d_release)(struct dentry___143 *);
	void (*d_prune)(struct dentry___143 *);
	void (*d_iput)(struct dentry___143 *, struct inode___144 *);
	char * (*d_dname)(struct dentry___143 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___143 *);
	int (*d_manage)(const struct path___143 *, bool);
	struct dentry___143 * (*d_real)(struct dentry___143 *, const struct inode___144 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___143;

struct mem_dqinfo___143 {
	struct quota_format_type___143 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___143;

struct quota_info___143 {
	unsigned int flags;
	struct rw_semaphore___144 dqio_sem;
	struct inode___144 *files[3];
	struct mem_dqinfo___143 info[3];
	const struct quota_format_ops___143 *ops[3];
};

struct rcuwait___143 {
	struct task_struct___144 *task;
};

struct percpu_rw_semaphore___143 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___144 rw_sem;
	struct rcuwait___143 writer;
	int readers_block;
};

struct sb_writers___143 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___143 rw_sem[3];
};

struct file_system_type___143;

struct super_operations___143;

struct dquot_operations___143;

struct quotactl_ops___143;

struct super_block___143 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___143 *s_type;
	const struct super_operations___143 *s_op;
	const struct dquot_operations___143 *dq_op;
	const struct quotactl_ops___143 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___143 *s_root;
	struct rw_semaphore___144 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___144 *s_bdev;
	struct backing_dev_info___64 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___143 s_dquot;
	struct sb_writers___143 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___143 *s_d_op;
	int cleancache_poolid;
	struct shrinker___59 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___124 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___144 {
	struct file___144 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___144 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___143 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___144 *ia_file;
};

struct dquot___143 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___143 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___143 {
	int qf_fmt_id;
	const struct quota_format_ops___143 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___143 *qf_next;
};

struct quota_format_ops___143 {
	int (*check_quota_file)(struct super_block___143 *, int);
	int (*read_file_info)(struct super_block___143 *, int);
	int (*write_file_info)(struct super_block___143 *, int);
	int (*free_file_info)(struct super_block___143 *, int);
	int (*read_dqblk)(struct dquot___143 *);
	int (*commit_dqblk)(struct dquot___143 *);
	int (*release_dqblk)(struct dquot___143 *);
	int (*get_next_id)(struct super_block___143 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___143 {
	int (*write_dquot)(struct dquot___143 *);
	struct dquot___143 * (*alloc_dquot)(struct super_block___143 *, int);
	void (*destroy_dquot)(struct dquot___143 *);
	int (*acquire_dquot)(struct dquot___143 *);
	int (*release_dquot)(struct dquot___143 *);
	int (*mark_dirty)(struct dquot___143 *);
	int (*write_info)(struct super_block___143 *, int);
	qsize_t * (*get_reserved_space)(struct inode___144 *);
	int (*get_projid)(struct inode___144 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___144 *, qsize_t *);
	int (*get_next_id)(struct super_block___143 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___143 {
	int (*quota_on)(struct super_block___143 *, int, int, const struct path___143 *);
	int (*quota_off)(struct super_block___143 *, int);
	int (*quota_enable)(struct super_block___143 *, unsigned int);
	int (*quota_disable)(struct super_block___143 *, unsigned int);
	int (*quota_sync)(struct super_block___143 *, int);
	int (*set_info)(struct super_block___143 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___143 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___143 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___143 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___143 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___143 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___61;

struct swap_info_struct___41;

struct address_space_operations___143 {
	int (*writepage)(struct page___144 *, struct writeback_control___61 *);
	int (*readpage)(struct file___144 *, struct page___144 *);
	int (*writepages)(struct address_space___143 *, struct writeback_control___61 *);
	int (*set_page_dirty)(struct page___144 *);
	int (*readpages)(struct file___144 *, struct address_space___143 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___144 *, struct address_space___143 *, loff_t, unsigned int, unsigned int, struct page___144 **, void **);
	int (*write_end)(struct file___144 *, struct address_space___143 *, loff_t, unsigned int, unsigned int, struct page___144 *, void *);
	sector_t (*bmap)(struct address_space___143 *, sector_t);
	void (*invalidatepage)(struct page___144 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___144 *, gfp_t);
	void (*freepage)(struct page___144 *);
	ssize_t (*direct_IO)(struct kiocb___144 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___143 *, struct page___144 *, struct page___144 *, enum migrate_mode);
	bool (*isolate_page)(struct page___144 *, isolate_mode_t);
	void (*putback_page)(struct page___144 *);
	int (*launder_page)(struct page___144 *);
	int (*is_partially_uptodate)(struct page___144 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___144 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___143 *, struct page___144 *);
	int (*swap_activate)(struct swap_info_struct___41 *, struct file___144 *, sector_t *);
	void (*swap_deactivate)(struct file___144 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___61 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___64 *wb;
	struct inode___144 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct swap_info_struct___41 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___144 *bdev;
	struct file___144 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___144 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___144 *bd_inode;
	struct super_block___143 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___144 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___64 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___143 {
	struct dentry___143 * (*lookup)(struct inode___144 *, struct dentry___143 *, unsigned int);
	const char * (*get_link)(struct dentry___143 *, struct inode___144 *, struct delayed_call *);
	int (*permission)(struct inode___144 *, int);
	struct posix_acl * (*get_acl)(struct inode___144 *, int);
	int (*readlink)(struct dentry___143 *, char *, int);
	int (*create)(struct inode___144 *, struct dentry___143 *, umode_t, bool);
	int (*link)(struct dentry___143 *, struct inode___144 *, struct dentry___143 *);
	int (*unlink)(struct inode___144 *, struct dentry___143 *);
	int (*symlink)(struct inode___144 *, struct dentry___143 *, const char *);
	int (*mkdir)(struct inode___144 *, struct dentry___143 *, umode_t);
	int (*rmdir)(struct inode___144 *, struct dentry___143 *);
	int (*mknod)(struct inode___144 *, struct dentry___143 *, umode_t, dev_t);
	int (*rename)(struct inode___144 *, struct dentry___143 *, struct inode___144 *, struct dentry___143 *, unsigned int);
	int (*setattr)(struct dentry___143 *, struct iattr___143 *);
	int (*getattr)(const struct path___143 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___143 *, char *, size_t);
	int (*fiemap)(struct inode___144 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___144 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___144 *, struct dentry___143 *, struct file___144 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___144 *, struct dentry___143 *, umode_t);
	int (*set_acl)(struct inode___144 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___143 {
	void (*fl_copy_lock)(struct file_lock___144 *, struct file_lock___144 *);
	void (*fl_release_private)(struct file_lock___144 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___143;

struct lock_manager_operations___143;

struct file_lock___144 {
	struct file_lock___144 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___144 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___143 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___143 *fl_ops;
	const struct lock_manager_operations___143 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___143 {
	int (*lm_compare_owner)(struct file_lock___144 *, struct file_lock___144 *);
	long unsigned int (*lm_owner_key)(struct file_lock___144 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___144 *);
	int (*lm_grant)(struct file_lock___144 *, int);
	bool (*lm_break)(struct file_lock___144 *);
	int (*lm_change)(struct file_lock___144 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___144 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___143 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___143 *fa_next;
	struct file___144 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___143 {
	const char *name;
	int fs_flags;
	struct dentry___143 * (*mount)(struct file_system_type___143 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___143 *);
	struct module___11 *owner;
	struct file_system_type___143 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___143 {
	struct inode___144 * (*alloc_inode)(struct super_block___143 *);
	void (*destroy_inode)(struct inode___144 *);
	void (*dirty_inode)(struct inode___144 *, int);
	int (*write_inode)(struct inode___144 *, struct writeback_control___61 *);
	int (*drop_inode)(struct inode___144 *);
	void (*evict_inode)(struct inode___144 *);
	void (*put_super)(struct super_block___143 *);
	int (*sync_fs)(struct super_block___143 *, int);
	int (*freeze_super)(struct super_block___143 *);
	int (*freeze_fs)(struct super_block___143 *);
	int (*thaw_super)(struct super_block___143 *);
	int (*unfreeze_fs)(struct super_block___143 *);
	int (*statfs)(struct dentry___143 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___143 *, int *, char *);
	void (*umount_begin)(struct super_block___143 *);
	int (*show_options)(struct seq_file___134 *, struct dentry___143 *);
	int (*show_devname)(struct seq_file___134 *, struct dentry___143 *);
	int (*show_path)(struct seq_file___134 *, struct dentry___143 *);
	int (*show_stats)(struct seq_file___134 *, struct dentry___143 *);
	ssize_t (*quota_read)(struct super_block___143 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___143 *, int, const char *, size_t, loff_t);
	struct dquot___143 ** (*get_dquots)(struct inode___144 *);
	int (*bdev_try_to_free_page)(struct super_block___143 *, struct page___144 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___143 *, struct shrink_control___59 *);
	long int (*free_cached_objects)(struct super_block___143 *, struct shrink_control___59 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___132;

struct seq_file___134 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___132 *op;
	int poll_event;
	const struct file___144 *file;
	void *private;
};

typedef void bio_end_io_t___64(struct bio___64 *);

struct bio_vec___64 {
	struct page___144 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___64;

struct bio_set___64;

struct bio___64 {
	struct bio___64 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___64 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___64 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___64 *bi_io_vec;
	struct bio_set___64 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___64 bi_inline_vecs[0];
};

struct kobj_attribute___138 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___138 *, struct kobj_attribute___138 *, char *);
	ssize_t (*store)(struct kobject___138 *, struct kobj_attribute___138 *, const char *, size_t);
};

typedef void compound_page_dtor___141(struct page___144 *);

struct zap_details {
	struct address_space___143 *check_mapping;
	long unsigned int first_index;
	long unsigned int last_index;
};

typedef int (*pte_fn_t)(pte_t *, pgtable_t___143, long unsigned int, void *);

typedef int (*key_restrict_link_func_t___139)(struct key___139 *, const struct key_type *, const union key_payload *, struct key___139 *);

struct key_restriction___139;

struct key___139 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___144 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___139 *restrict_link;
};

struct key_restriction___139 {
	key_restrict_link_func_t___139 check;
	struct key___139 *key;
	struct key_type *keytype;
};

struct seq_operations___132 {
	void * (*start)(struct seq_file___134 *, loff_t *);
	void (*stop)(struct seq_file___134 *, void *);
	void * (*next)(struct seq_file___134 *, void *, loff_t *);
	int (*show)(struct seq_file___134 *, void *);
};

struct kernfs_root___140;

struct kernfs_elem_dir___140 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___140 *root;
};

struct kernfs_syscall_ops___140;

struct kernfs_root___140 {
	struct kernfs_node___140 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___140 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___140 {
	struct kernfs_node___140 *target_kn;
};

struct kernfs_ops___140;

struct kernfs_elem_attr___140 {
	const struct kernfs_ops___140 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___140 *notify_next;
};

struct kernfs_node___140 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___140 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___140 dir;
		struct kernfs_elem_symlink___140 symlink;
		struct kernfs_elem_attr___140 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___140;

struct kernfs_ops___140 {
	int (*open)(struct kernfs_open_file___140 *);
	void (*release)(struct kernfs_open_file___140 *);
	int (*seq_show)(struct seq_file___134 *, void *);
	void * (*seq_start)(struct seq_file___134 *, loff_t *);
	void * (*seq_next)(struct seq_file___134 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___134 *, void *);
	ssize_t (*read)(struct kernfs_open_file___140 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___140 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___140 *, struct vm_area_struct___144 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___140 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___140 {
	int (*remount_fs)(struct kernfs_root___140 *, int *, char *);
	int (*show_options)(struct seq_file___134 *, struct kernfs_root___140 *);
	int (*mkdir)(struct kernfs_node___140 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___140 *);
	int (*rename)(struct kernfs_node___140 *, struct kernfs_node___140 *, const char *);
	int (*show_path)(struct seq_file___134 *, struct kernfs_node___140 *, struct kernfs_root___140 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___140 {
	struct kernfs_node___140 *kn;
	struct file___144 *file;
	struct seq_file___134 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___141 *vm_ops;
};

struct cgroup_namespace___120 {
	refcount_t count;
	struct ns_common___4 ns;
	struct user_namespace___124 *user_ns;
	struct ucounts___124 *ucounts;
	struct css_set___120 *root_cset;
};

struct ucounts___124 {
	struct hlist_node node;
	struct user_namespace___124 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___120;

struct bpf_map_ops___120 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___120 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___120 *, struct file___144 *);
	void (*map_free)(struct bpf_map___120 *);
	int (*map_get_next_key)(struct bpf_map___120 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___120 *);
	void * (*map_lookup_elem)(struct bpf_map___120 *, void *);
	int (*map_update_elem)(struct bpf_map___120 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___120 *, void *);
	int (*map_push_elem)(struct bpf_map___120 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___120 *, void *);
	int (*map_peek_elem)(struct bpf_map___120 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___120 *, struct file___144 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___120 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___120 *, void *, struct seq_file___134 *);
	int (*map_check_btf)(const struct bpf_map___120 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___120 {
	const struct bpf_map_ops___120 *ops;
	struct bpf_map___120 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___139 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___120;

typedef void (*kthread_work_func_t___120)(struct kthread_work___120 *);

struct kthread_worker___120;

struct kthread_work___120 {
	struct list_head node;
	kthread_work_func_t___120 func;
	struct kthread_worker___120 *worker;
	int canceling;
};

struct kthread_worker___120 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___144 *task;
	struct kthread_work___120 *current_work;
};

struct kthread_delayed_work___120 {
	struct kthread_work___120 work;
	struct timer_list timer;
};

struct psi_group___120 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___120 *poll_kworker;
	struct kthread_delayed_work___120 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___120;

struct cgroup_rstat_cpu___120;

struct cgroup___120 {
	struct cgroup_subsys_state___120 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___140 *kn;
	struct cgroup_file___120 procs_file;
	struct cgroup_file___120 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___120 *subsys[13];
	struct cgroup_root___120 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___120 *dom_cgrp;
	struct cgroup_rstat_cpu___120 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___4 bpf;
	atomic_t congestion_count;
	struct cgroup___120 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___120 psi;
	int ancestor_ids[0];
};

struct cftype___120;

struct cgroup_subsys___120 {
	struct cgroup_subsys_state___120 * (*css_alloc)(struct cgroup_subsys_state___120 *);
	int (*css_online)(struct cgroup_subsys_state___120 *);
	void (*css_offline)(struct cgroup_subsys_state___120 *);
	void (*css_released)(struct cgroup_subsys_state___120 *);
	void (*css_free)(struct cgroup_subsys_state___120 *);
	void (*css_reset)(struct cgroup_subsys_state___120 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___120 *, int);
	int (*css_extra_stat_show)(struct seq_file___134 *, struct cgroup_subsys_state___120 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___144 *);
	void (*cancel_fork)(struct task_struct___144 *);
	void (*fork)(struct task_struct___144 *);
	void (*exit)(struct task_struct___144 *);
	void (*free)(struct task_struct___144 *);
	void (*bind)(struct cgroup_subsys_state___120 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___120 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___120 *dfl_cftypes;
	struct cftype___120 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___120 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___120 *updated_children;
	struct cgroup___120 *updated_next;
};

struct cgroup_root___120 {
	struct kernfs_root___140 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___120 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___120 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___120 *ss;
	struct list_head node;
	struct kernfs_ops___140 *kf_ops;
	int (*open)(struct kernfs_open_file___140 *);
	void (*release)(struct kernfs_open_file___140 *);
	u64 (*read_u64)(struct cgroup_subsys_state___120 *, struct cftype___120 *);
	s64 (*read_s64)(struct cgroup_subsys_state___120 *, struct cftype___120 *);
	int (*seq_show)(struct seq_file___134 *, void *);
	void * (*seq_start)(struct seq_file___134 *, loff_t *);
	void * (*seq_next)(struct seq_file___134 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___134 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___120 *, struct cftype___120 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___120 *, struct cftype___120 *, s64);
	ssize_t (*write)(struct kernfs_open_file___140 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___140 *, struct poll_table_struct___6 *);
};

struct bin_attribute___133;

struct attribute_group___133 {
	const char *name;
	umode_t (*is_visible)(struct kobject___138 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___138 *, struct bin_attribute___133 *, int);
	struct attribute **attrs;
	struct bin_attribute___133 **bin_attrs;
};

struct hstate___20 {
	int next_nid_to_alloc;
	int next_nid_to_free;
	unsigned int order;
	long unsigned int mask;
	long unsigned int max_huge_pages;
	long unsigned int nr_huge_pages;
	long unsigned int free_huge_pages;
	long unsigned int resv_huge_pages;
	long unsigned int surplus_huge_pages;
	long unsigned int nr_overcommit_huge_pages;
	struct list_head hugepage_activelist;
	struct list_head hugepage_freelists[8];
	unsigned int nr_huge_pages_node[8];
	unsigned int free_huge_pages_node[8];
	unsigned int surplus_huge_pages_node[8];
	struct cftype___120 cgroup_files[5];
	char name[32];
};

struct bdi_writeback_congested___64 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___64 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___64 {
	struct bio___64 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___64 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___64 bip_inline_vecs[0];
};

struct bio_set___64 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___64 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___59 {
	struct mem_cgroup___59 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___59 {
	struct lruvec___143 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___59 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___59 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct bin_attribute___133 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___144 *, struct kobject___138 *, struct bin_attribute___133 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___144 *, struct kobject___138 *, struct bin_attribute___133 *, char *, loff_t, size_t);
	int (*mmap)(struct file___144 *, struct kobject___138 *, struct bin_attribute___133 *, struct vm_area_struct___144 *);
};

struct sysfs_ops___137 {
	ssize_t (*show)(struct kobject___138 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___138 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___137;

struct kset___137 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___138 kobj;
	const struct kset_uevent_ops___137 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___137 {
	void (*release)(struct kobject___138 *);
	const struct sysfs_ops___137 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___2 * (*child_ns_type)(struct kobject___138 *);
	const void * (*namespace)(struct kobject___138 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___137 {
	int (* const filter)(struct kset___137 *, struct kobject___138 *);
	const char * (* const name)(struct kset___137 *, struct kobject___138 *);
	int (* const uevent)(struct kset___137 *, struct kobject___138 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___134 {
	int (*prepare)(struct device___134 *);
	void (*complete)(struct device___134 *);
	int (*suspend)(struct device___134 *);
	int (*resume)(struct device___134 *);
	int (*freeze)(struct device___134 *);
	int (*thaw)(struct device___134 *);
	int (*poweroff)(struct device___134 *);
	int (*restore)(struct device___134 *);
	int (*suspend_late)(struct device___134 *);
	int (*resume_early)(struct device___134 *);
	int (*freeze_late)(struct device___134 *);
	int (*thaw_early)(struct device___134 *);
	int (*poweroff_late)(struct device___134 *);
	int (*restore_early)(struct device___134 *);
	int (*suspend_noirq)(struct device___134 *);
	int (*resume_noirq)(struct device___134 *);
	int (*freeze_noirq)(struct device___134 *);
	int (*thaw_noirq)(struct device___134 *);
	int (*poweroff_noirq)(struct device___134 *);
	int (*restore_noirq)(struct device___134 *);
	int (*runtime_suspend)(struct device___134 *);
	int (*runtime_resume)(struct device___134 *);
	int (*runtime_idle)(struct device___134 *);
};

struct dev_pm_domain___134 {
	struct dev_pm_ops___134 ops;
	void (*detach)(struct device___134 *, bool);
	int (*activate)(struct device___134 *);
	void (*sync)(struct device___134 *);
	void (*dismiss)(struct device___134 *);
};

struct bus_type___134 {
	const char *name;
	const char *dev_name;
	struct device___134 *dev_root;
	const struct attribute_group___133 **bus_groups;
	const struct attribute_group___133 **dev_groups;
	const struct attribute_group___133 **drv_groups;
	int (*match)(struct device___134 *, struct device_driver___134 *);
	int (*uevent)(struct device___134 *, struct kobj_uevent_env *);
	int (*probe)(struct device___134 *);
	int (*remove)(struct device___134 *);
	void (*shutdown)(struct device___134 *);
	int (*online)(struct device___134 *);
	int (*offline)(struct device___134 *);
	int (*suspend)(struct device___134 *, pm_message_t);
	int (*resume)(struct device___134 *);
	int (*num_vf)(struct device___134 *);
	int (*dma_configure)(struct device___134 *);
	const struct dev_pm_ops___134 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___134 {
	const char *name;
	struct bus_type___134 *bus;
	struct module___11 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___134 *);
	int (*remove)(struct device___134 *);
	void (*shutdown)(struct device___134 *);
	int (*suspend)(struct device___134 *, pm_message_t);
	int (*resume)(struct device___134 *);
	const struct attribute_group___133 **groups;
	const struct dev_pm_ops___134 *pm;
	void (*coredump)(struct device___134 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___134 {
	const char *name;
	const struct attribute_group___133 **groups;
	int (*uevent)(struct device___134 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___134 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___134 *);
	const struct dev_pm_ops___134 *pm;
};

struct class___134 {
	const char *name;
	struct module___11 *owner;
	const struct attribute_group___133 **class_groups;
	const struct attribute_group___133 **dev_groups;
	struct kobject___138 *dev_kobj;
	int (*dev_uevent)(struct device___134 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___134 *, umode_t *);
	void (*class_release)(struct class___134 *);
	void (*dev_release)(struct device___134 *);
	int (*shutdown_pre)(struct device___134 *);
	const struct kobj_ns_type_operations___2 *ns_type;
	const void * (*namespace)(struct device___134 *);
	const struct dev_pm_ops___134 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct fwnode_operations___100;

struct fwnode_handle___100 {
	struct fwnode_handle___100 *secondary;
	const struct fwnode_operations___100 *ops;
};

struct node___112 {
	struct device___134 dev;
};

enum {
	SWP_USED = 1,
	SWP_WRITEOK = 2,
	SWP_DISCARDABLE = 4,
	SWP_DISCARDING = 8,
	SWP_SOLIDSTATE = 16,
	SWP_CONTINUED = 32,
	SWP_BLKDEV = 64,
	SWP_FILE = 128,
	SWP_AREA_DISCARD = 256,
	SWP_PAGE_DISCARD = 512,
	SWP_STABLE_WRITES = 1024,
	SWP_SYNCHRONOUS_IO = 2048,
	SWP_SCANNING = 4096,
};

struct fwnode_reference_args___100;

struct fwnode_endpoint___100;

struct fwnode_operations___100 {
	struct fwnode_handle___100 * (*get)(struct fwnode_handle___100 *);
	void (*put)(struct fwnode_handle___100 *);
	bool (*device_is_available)(const struct fwnode_handle___100 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___100 *, const struct device___134 *);
	bool (*property_present)(const struct fwnode_handle___100 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___100 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___100 *, const char *, const char **, size_t);
	struct fwnode_handle___100 * (*get_parent)(const struct fwnode_handle___100 *);
	struct fwnode_handle___100 * (*get_next_child_node)(const struct fwnode_handle___100 *, struct fwnode_handle___100 *);
	struct fwnode_handle___100 * (*get_named_child_node)(const struct fwnode_handle___100 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___100 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___100 *);
	struct fwnode_handle___100 * (*graph_get_next_endpoint)(const struct fwnode_handle___100 *, struct fwnode_handle___100 *);
	struct fwnode_handle___100 * (*graph_get_remote_endpoint)(const struct fwnode_handle___100 *);
	struct fwnode_handle___100 * (*graph_get_port_parent)(struct fwnode_handle___100 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___100 *, struct fwnode_endpoint___100 *);
};

struct fwnode_endpoint___100 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___100 *local_fwnode;
};

struct fwnode_reference_args___100 {
	struct fwnode_handle___100 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct mmu_gather_batch___2 {
	struct mmu_gather_batch___2 *next;
	unsigned int nr;
	unsigned int max;
	struct page___144 *pages[0];
};

struct mmu_gather___2 {
	struct mm_struct___143 *mm;
	struct mmu_table_batch *batch;
	long unsigned int start;
	long unsigned int end;
	unsigned int fullmm: 1;
	unsigned int need_flush_all: 1;
	struct mmu_gather_batch___2 *active;
	struct mmu_gather_batch___2 local;
	struct page___144 *__pages[8];
	unsigned int batch_count;
	int page_size;
};

struct module___123;

struct file___145;

struct kiocb___145;

struct iov_iter___64;

struct poll_table_struct___97;

struct vm_area_struct___145;

struct inode___145;

struct file_lock___145;

struct page___145;

struct seq_file___135;

struct file_operations___145 {
	struct module___123 *owner;
	loff_t (*llseek)(struct file___145 *, loff_t, int);
	ssize_t (*read)(struct file___145 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___145 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___145 *, struct iov_iter___64 *);
	ssize_t (*write_iter)(struct kiocb___145 *, struct iov_iter___64 *);
	int (*iopoll)(struct kiocb___145 *, bool);
	int (*iterate)(struct file___145 *, struct dir_context *);
	int (*iterate_shared)(struct file___145 *, struct dir_context *);
	__poll_t (*poll)(struct file___145 *, struct poll_table_struct___97 *);
	long int (*unlocked_ioctl)(struct file___145 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___145 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___145 *, struct vm_area_struct___145 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___145 *, struct file___145 *);
	int (*flush)(struct file___145 *, fl_owner_t);
	int (*release)(struct inode___145 *, struct file___145 *);
	int (*fsync)(struct file___145 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___145 *, int);
	int (*lock)(struct file___145 *, int, struct file_lock___145 *);
	ssize_t (*sendpage)(struct file___145 *, struct page___145 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___145 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___145 *, int, struct file_lock___145 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___145 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___145 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___145 *, long int, struct file_lock___145 **, void **);
	long int (*fallocate)(struct file___145 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___135 *, struct file___145 *);
	ssize_t (*copy_file_range)(struct file___145 *, loff_t, struct file___145 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___145 *, loff_t, struct file___145 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___145 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___144 {
	u64 seqnum;
	struct vm_area_struct___145 *vmas[4];
};

struct page_frag___144 {
	struct page___145 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___88;

struct debug_info___88 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___88 *hbp_break[16];
	struct perf_event___88 *hbp_watch[16];
};

struct thread_struct___88 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___88 debug;
	long: 64;
};

struct mm_struct___144;

struct mem_cgroup___60;

struct pid___115;

struct cred___140;

struct nsproxy___137;

struct signal_struct___129;

struct bio_list___65;

struct backing_dev_info___65;

struct css_set___121;

struct perf_event_context___88;

struct task_struct___145 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___145 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___144 *mm;
	struct mm_struct___144 *active_mm;
	struct vmacache___144 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___145 *real_parent;
	struct task_struct___145 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___145 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___60 *active_memcg;
	long int rh_reserved2;
	struct pid___115 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___115 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___115 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___140 *ptracer_cred;
	const struct cred___140 *real_cred;
	const struct cred___140 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___137 *nsproxy;
	struct signal_struct___129 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___145 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___65 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___65 *backing_dev_info;
	struct io_context___32 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___121 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___88 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___144 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___60 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___145 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___88 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___88 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___145 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___88)(struct perf_event___88 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___88;

struct fasync_struct___144;

struct pid_namespace___115;

struct trace_event_call___81;

struct perf_cgroup___88;

struct perf_event___88 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___88 *group_leader;
	struct pmu___88 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___88 hw;
	struct perf_event_context___88 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___88 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___145 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___144 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___88 *);
	struct callback_head callback_head;
	struct pid_namespace___115 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___88 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___88 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___81 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___88 *cgrp;
	struct list_head sb_list;
};

typedef struct page___145 *pgtable_t___144;

struct address_space___144;

struct dev_pagemap___142;

struct page___145 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___144 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___145 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___144 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___144 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___142 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___60 *mem_cgroup;
};

struct pglist_data___144;

struct lruvec___144 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___144 *pgdat;
};

struct zone___144 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___144 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___144 {
	struct zone___144 *zone;
	int zone_idx;
};

struct zonelist___144 {
	struct zoneref___144 _zonerefs[25];
};

struct pglist_data___144 {
	struct zone___144 node_zones[3];
	struct zonelist___144 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___145 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___145 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___144 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___145 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___145 *owner;
};

struct secondary_data___145 {
	void *stack;
	struct task_struct___145 *task;
	long int status;
};

struct blocking_notifier_head___144 {
	struct rw_semaphore___145 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___142;

struct vm_area_struct___145 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___145 *vm_next;
	struct vm_area_struct___145 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___144 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___142 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___145 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___144;

struct user_namespace___125;

struct mm_struct___144 {
	struct {
		struct vm_area_struct___145 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___145 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___145 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___144 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___145 *owner;
		struct user_namespace___125 *user_ns;
		struct file___145 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___144 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___144;

struct address_space___144 {
	struct inode___145 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___145 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___144 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___142)(struct vm_area_struct___145 *, long unsigned int, const struct page___145 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___142)(struct page___145 *, void *);

struct device___135;

struct dev_pagemap___142 {
	dev_page_fault_t___142 page_fault;
	dev_page_free_t___142 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___135 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct cgroup___121;

struct cgroup_subsys___121;

struct cgroup_subsys_state___121 {
	struct cgroup___121 *cgroup;
	struct cgroup_subsys___121 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___121 *parent;
};

struct kernfs_node___141;

struct cgroup_file___121 {
	struct kernfs_node___141 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___60;

struct mem_cgroup___60 {
	struct cgroup_subsys_state___121 css;
	struct mem_cgroup_id___11 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___121 events_file;
	struct cgroup_file___121 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___145 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___60 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry___144;

struct path___144 {
	struct vfsmount *mnt;
	struct dentry___144 *dentry;
};

struct fown_struct___115 {
	rwlock_t lock;
	struct pid___115 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___145 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___144 f_path;
	struct inode___145 *f_inode;
	const struct file_operations___145 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___115 f_owner;
	const struct cred___140 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___144 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___142;

struct vm_operations_struct___142 {
	void (*open)(struct vm_area_struct___145 *);
	void (*close)(struct vm_area_struct___145 *);
	int (*split)(struct vm_area_struct___145 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___145 *);
	vm_fault_t (*fault)(struct vm_fault___142 *);
	vm_fault_t (*huge_fault)(struct vm_fault___142 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___142 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___145 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___142 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___142 *);
	int (*access)(struct vm_area_struct___145 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___145 *);
	int (*set_policy)(struct vm_area_struct___145 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___145 *, long unsigned int);
	struct page___145 * (*find_special_page)(struct vm_area_struct___145 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___144 {
	struct task_struct___145 *task;
	struct core_thread___144 *next;
};

struct core_state___144 {
	atomic_t nr_threads;
	struct core_thread___144 dumper;
	struct completion startup;
};

struct key___140;

struct ucounts___125;

struct user_namespace___125 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___125 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___4 ns;
	long unsigned int flags;
	struct key___140 *persistent_keyring_register;
	struct rw_semaphore___145 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___125 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___142 {
	struct vm_area_struct___145 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___145 *cow_page;
	struct mem_cgroup___60 *memcg;
	struct page___145 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___144 prealloc_pte;
};

struct shrink_control___60 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___60 *memcg;
};

struct shrinker___60 {
	long unsigned int (*count_objects)(struct shrinker___60 *, struct shrink_control___60 *);
	long unsigned int (*scan_objects)(struct shrinker___60 *, struct shrink_control___60 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct upid___115 {
	int nr;
	struct pid_namespace___115 *ns;
};

struct pid_namespace___115 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___145 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___115 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___144 *proc_self;
	struct dentry___144 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___125 *user_ns;
	struct ucounts___125 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___4 ns;
};

struct pid___115 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___115 numbers[1];
};

struct user_struct___140 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___140 *uid_keyring;
	struct key___140 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___140 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___140 *session_keyring;
	struct key___140 *process_keyring;
	struct key___140 *thread_keyring;
	struct key___140 *request_key_auth;
	void *security;
	struct user_struct___140 *user;
	struct user_namespace___125 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___121;

struct nsproxy___137 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___115 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___121 *cgroup_ns;
};

struct signal_struct___129 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___145 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___145 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___115 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___115 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___144 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___115 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___65;

struct bio_list___65 {
	struct bio___65 *head;
	struct bio___65 *tail;
};

struct bdi_writeback_congested___65;

struct bdi_writeback___65 {
	struct backing_dev_info___65 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___65 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___121 *memcg_css;
	struct cgroup_subsys_state___121 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___65 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___65 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___135 *dev;
	struct device___135 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___144 *debug_dir;
	struct dentry___144 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___121 {
	struct cgroup_subsys_state___121 *subsys[13];
	refcount_t refcount;
	struct css_set___121 *dom_cset;
	struct cgroup___121 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___121 *mg_src_cgrp;
	struct cgroup___121 *mg_dst_cgrp;
	struct css_set___121 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___88 {
	struct pmu___88 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___145 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___88 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

union thread_union___129 {
	struct task_struct___145 task;
	long unsigned int stack[8192];
};

struct kset___138;

struct kobj_type___138;

struct kobject___139 {
	const char *name;
	struct list_head entry;
	struct kobject___139 *parent;
	struct kset___138 *kset;
	struct kobj_type___138 *ktype;
	struct kernfs_node___141 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___135 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___135 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___135;

struct bus_type___135;

struct device_driver___135;

struct dev_pm_domain___135;

struct class___135;

struct attribute_group___134;

struct device___135 {
	struct device___135 *parent;
	struct device_private *p;
	struct kobject___139 kobj;
	const char *init_name;
	const struct device_type___135 *type;
	struct mutex mutex;
	struct bus_type___135 *bus;
	struct device_driver___135 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___135 power;
	struct dev_pm_domain___135 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___135 *class;
	const struct attribute_group___134 **groups;
	void (*release)(struct device___135 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___144;

struct super_block___144;

struct dentry___144 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___144 *d_parent;
	struct qstr d_name;
	struct inode___145 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___144 *d_op;
	struct super_block___144 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___144;

struct block_device___145;

struct inode___145 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___144 *i_op;
	struct super_block___144 *i_sb;
	struct address_space___144 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___145 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___65 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___145 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___144 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___145 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___144 {
	int (*d_revalidate)(struct dentry___144 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___144 *, unsigned int);
	int (*d_hash)(const struct dentry___144 *, struct qstr *);
	int (*d_compare)(const struct dentry___144 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___144 *);
	int (*d_init)(struct dentry___144 *);
	void (*d_release)(struct dentry___144 *);
	void (*d_prune)(struct dentry___144 *);
	void (*d_iput)(struct dentry___144 *, struct inode___145 *);
	char * (*d_dname)(struct dentry___144 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___144 *);
	int (*d_manage)(const struct path___144 *, bool);
	struct dentry___144 * (*d_real)(struct dentry___144 *, const struct inode___145 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___144;

struct mem_dqinfo___144 {
	struct quota_format_type___144 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___144;

struct quota_info___144 {
	unsigned int flags;
	struct rw_semaphore___145 dqio_sem;
	struct inode___145 *files[3];
	struct mem_dqinfo___144 info[3];
	const struct quota_format_ops___144 *ops[3];
};

struct rcuwait___144 {
	struct task_struct___145 *task;
};

struct percpu_rw_semaphore___144 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___145 rw_sem;
	struct rcuwait___144 writer;
	int readers_block;
};

struct sb_writers___144 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___144 rw_sem[3];
};

struct file_system_type___144;

struct super_operations___144;

struct dquot_operations___144;

struct quotactl_ops___144;

struct xattr_handler___9;

struct super_block___144 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___144 *s_type;
	const struct super_operations___144 *s_op;
	const struct dquot_operations___144 *dq_op;
	const struct quotactl_ops___144 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___144 *s_root;
	struct rw_semaphore___145 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___9 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___145 *s_bdev;
	struct backing_dev_info___65 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___144 s_dquot;
	struct sb_writers___144 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___144 *s_d_op;
	int cleancache_poolid;
	struct shrinker___60 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___125 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___145 {
	struct file___145 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___145 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___144 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___145 *ia_file;
};

struct dquot___144 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___144 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___144 {
	int qf_fmt_id;
	const struct quota_format_ops___144 *qf_ops;
	struct module___123 *qf_owner;
	struct quota_format_type___144 *qf_next;
};

struct quota_format_ops___144 {
	int (*check_quota_file)(struct super_block___144 *, int);
	int (*read_file_info)(struct super_block___144 *, int);
	int (*write_file_info)(struct super_block___144 *, int);
	int (*free_file_info)(struct super_block___144 *, int);
	int (*read_dqblk)(struct dquot___144 *);
	int (*commit_dqblk)(struct dquot___144 *);
	int (*release_dqblk)(struct dquot___144 *);
	int (*get_next_id)(struct super_block___144 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___144 {
	int (*write_dquot)(struct dquot___144 *);
	struct dquot___144 * (*alloc_dquot)(struct super_block___144 *, int);
	void (*destroy_dquot)(struct dquot___144 *);
	int (*acquire_dquot)(struct dquot___144 *);
	int (*release_dquot)(struct dquot___144 *);
	int (*mark_dirty)(struct dquot___144 *);
	int (*write_info)(struct super_block___144 *, int);
	qsize_t * (*get_reserved_space)(struct inode___145 *);
	int (*get_projid)(struct inode___145 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___145 *, qsize_t *);
	int (*get_next_id)(struct super_block___144 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___144 {
	int (*quota_on)(struct super_block___144 *, int, int, const struct path___144 *);
	int (*quota_off)(struct super_block___144 *, int);
	int (*quota_enable)(struct super_block___144 *, unsigned int);
	int (*quota_disable)(struct super_block___144 *, unsigned int);
	int (*quota_sync)(struct super_block___144 *, int);
	int (*set_info)(struct super_block___144 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___144 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___144 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___144 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___144 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___144 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___120 {
	struct kobject___139 kobj;
	struct module___123 *mod;
	struct kobject___139 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___120 {
	struct module___123 *mod;
	struct latch_tree_node node;
};

struct module_layout___120 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___120 mtn;
};

struct module_attribute___120;

struct kernel_param___120;

struct module___123 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___120 mkobj;
	struct module_attribute___120 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___139 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___120 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___120 core_layout;
	struct module_layout___120 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___81 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___62;

struct swap_info_struct___42;

struct address_space_operations___144 {
	int (*writepage)(struct page___145 *, struct writeback_control___62 *);
	int (*readpage)(struct file___145 *, struct page___145 *);
	int (*writepages)(struct address_space___144 *, struct writeback_control___62 *);
	int (*set_page_dirty)(struct page___145 *);
	int (*readpages)(struct file___145 *, struct address_space___144 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___145 *, struct address_space___144 *, loff_t, unsigned int, unsigned int, struct page___145 **, void **);
	int (*write_end)(struct file___145 *, struct address_space___144 *, loff_t, unsigned int, unsigned int, struct page___145 *, void *);
	sector_t (*bmap)(struct address_space___144 *, sector_t);
	void (*invalidatepage)(struct page___145 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___145 *, gfp_t);
	void (*freepage)(struct page___145 *);
	ssize_t (*direct_IO)(struct kiocb___145 *, struct iov_iter___64 *);
	int (*migratepage)(struct address_space___144 *, struct page___145 *, struct page___145 *, enum migrate_mode);
	bool (*isolate_page)(struct page___145 *, isolate_mode_t);
	void (*putback_page)(struct page___145 *);
	int (*launder_page)(struct page___145 *);
	int (*is_partially_uptodate)(struct page___145 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___145 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___144 *, struct page___145 *);
	int (*swap_activate)(struct swap_info_struct___42 *, struct file___145 *, sector_t *);
	void (*swap_deactivate)(struct file___145 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___62 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___65 *wb;
	struct inode___145 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___65;

struct iov_iter___64 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___65 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct swap_info_struct___42 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___145 *bdev;
	struct file___145 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___145 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___145 *bd_inode;
	struct super_block___144 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___145 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___65 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___144 {
	struct dentry___144 * (*lookup)(struct inode___145 *, struct dentry___144 *, unsigned int);
	const char * (*get_link)(struct dentry___144 *, struct inode___145 *, struct delayed_call *);
	int (*permission)(struct inode___145 *, int);
	struct posix_acl * (*get_acl)(struct inode___145 *, int);
	int (*readlink)(struct dentry___144 *, char *, int);
	int (*create)(struct inode___145 *, struct dentry___144 *, umode_t, bool);
	int (*link)(struct dentry___144 *, struct inode___145 *, struct dentry___144 *);
	int (*unlink)(struct inode___145 *, struct dentry___144 *);
	int (*symlink)(struct inode___145 *, struct dentry___144 *, const char *);
	int (*mkdir)(struct inode___145 *, struct dentry___144 *, umode_t);
	int (*rmdir)(struct inode___145 *, struct dentry___144 *);
	int (*mknod)(struct inode___145 *, struct dentry___144 *, umode_t, dev_t);
	int (*rename)(struct inode___145 *, struct dentry___144 *, struct inode___145 *, struct dentry___144 *, unsigned int);
	int (*setattr)(struct dentry___144 *, struct iattr___144 *);
	int (*getattr)(const struct path___144 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___144 *, char *, size_t);
	int (*fiemap)(struct inode___145 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___145 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___145 *, struct dentry___144 *, struct file___145 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___145 *, struct dentry___144 *, umode_t);
	int (*set_acl)(struct inode___145 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___144 {
	void (*fl_copy_lock)(struct file_lock___145 *, struct file_lock___145 *);
	void (*fl_release_private)(struct file_lock___145 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___144;

struct file_lock___145 {
	struct file_lock___145 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___145 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___144 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___144 *fl_ops;
	const struct lock_manager_operations___144 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___144 {
	int (*lm_compare_owner)(struct file_lock___145 *, struct file_lock___145 *);
	long unsigned int (*lm_owner_key)(struct file_lock___145 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___145 *);
	int (*lm_grant)(struct file_lock___145 *, int);
	bool (*lm_break)(struct file_lock___145 *);
	int (*lm_change)(struct file_lock___145 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___145 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___144 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___144 *fa_next;
	struct file___145 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___144 {
	const char *name;
	int fs_flags;
	struct dentry___144 * (*mount)(struct file_system_type___144 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___144 *);
	struct module___123 *owner;
	struct file_system_type___144 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___144 {
	struct inode___145 * (*alloc_inode)(struct super_block___144 *);
	void (*destroy_inode)(struct inode___145 *);
	void (*dirty_inode)(struct inode___145 *, int);
	int (*write_inode)(struct inode___145 *, struct writeback_control___62 *);
	int (*drop_inode)(struct inode___145 *);
	void (*evict_inode)(struct inode___145 *);
	void (*put_super)(struct super_block___144 *);
	int (*sync_fs)(struct super_block___144 *, int);
	int (*freeze_super)(struct super_block___144 *);
	int (*freeze_fs)(struct super_block___144 *);
	int (*thaw_super)(struct super_block___144 *);
	int (*unfreeze_fs)(struct super_block___144 *);
	int (*statfs)(struct dentry___144 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___144 *, int *, char *);
	void (*umount_begin)(struct super_block___144 *);
	int (*show_options)(struct seq_file___135 *, struct dentry___144 *);
	int (*show_devname)(struct seq_file___135 *, struct dentry___144 *);
	int (*show_path)(struct seq_file___135 *, struct dentry___144 *);
	int (*show_stats)(struct seq_file___135 *, struct dentry___144 *);
	ssize_t (*quota_read)(struct super_block___144 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___144 *, int, const char *, size_t, loff_t);
	struct dquot___144 ** (*get_dquots)(struct inode___145 *);
	int (*bdev_try_to_free_page)(struct super_block___144 *, struct page___145 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___144 *, struct shrink_control___60 *);
	long int (*free_cached_objects)(struct super_block___144 *, struct shrink_control___60 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct xattr_handler___9 {
	const char *name;
	const char *prefix;
	int flags;
	bool (*list)(struct dentry___144 *);
	int (*get)(const struct xattr_handler___9 *, struct dentry___144 *, struct inode___145 *, const char *, void *, size_t);
	int (*set)(const struct xattr_handler___9 *, struct dentry___144 *, struct inode___145 *, const char *, const void *, size_t, int);
};

typedef void (*poll_queue_proc___96)(struct file___145 *, wait_queue_head_t *, struct poll_table_struct___97 *);

struct poll_table_struct___97 {
	poll_queue_proc___96 _qproc;
	__poll_t _key;
};

struct seq_operations___133;

struct seq_file___135 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___133 *op;
	int poll_event;
	const struct file___145 *file;
	void *private;
};

typedef void bio_end_io_t___65(struct bio___65 *);

struct bio_vec___65 {
	struct page___145 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___65;

struct bio_set___65;

struct bio___65 {
	struct bio___65 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___65 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___65 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___65 *bi_io_vec;
	struct bio_set___65 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___65 bi_inline_vecs[0];
};

struct kobj_attribute___139 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___139 *, struct kobj_attribute___139 *, char *);
	ssize_t (*store)(struct kobject___139 *, struct kobj_attribute___139 *, const char *, size_t);
};

typedef void compound_page_dtor___142(struct page___145 *);

struct mm_walk {
	int (*pud_entry)(pud_t *, long unsigned int, long unsigned int, struct mm_walk *);
	int (*pmd_entry)(pmd_t *, long unsigned int, long unsigned int, struct mm_walk *);
	int (*pte_entry)(pte_t *, long unsigned int, long unsigned int, struct mm_walk *);
	int (*pte_hole)(long unsigned int, long unsigned int, struct mm_walk *);
	int (*hugetlb_entry)(pte_t *, long unsigned int, long unsigned int, long unsigned int, struct mm_walk *);
	int (*test_walk)(long unsigned int, long unsigned int, struct mm_walk *);
	struct mm_struct___144 *mm;
	struct vm_area_struct___145 *vma;
	void *private;
};

typedef int (*key_restrict_link_func_t___140)(struct key___140 *, const struct key_type *, const union key_payload *, struct key___140 *);

struct key_restriction___140;

struct key___140 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___145 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___140 *restrict_link;
};

struct key_restriction___140 {
	key_restrict_link_func_t___140 check;
	struct key___140 *key;
	struct key_type *keytype;
};

struct seq_operations___133 {
	void * (*start)(struct seq_file___135 *, loff_t *);
	void (*stop)(struct seq_file___135 *, void *);
	void * (*next)(struct seq_file___135 *, void *, loff_t *);
	int (*show)(struct seq_file___135 *, void *);
};

struct cgroup_namespace___121 {
	refcount_t count;
	struct ns_common___4 ns;
	struct user_namespace___125 *user_ns;
	struct ucounts___125 *ucounts;
	struct css_set___121 *root_cset;
};

struct ucounts___125 {
	struct hlist_node node;
	struct user_namespace___125 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct kernfs_root___141;

struct kernfs_elem_dir___141 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___141 *root;
};

struct kernfs_syscall_ops___141;

struct kernfs_root___141 {
	struct kernfs_node___141 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___141 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___141 {
	struct kernfs_node___141 *target_kn;
};

struct kernfs_ops___141;

struct kernfs_elem_attr___141 {
	const struct kernfs_ops___141 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___141 *notify_next;
};

struct kernfs_node___141 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___141 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___141 dir;
		struct kernfs_elem_symlink___141 symlink;
		struct kernfs_elem_attr___141 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___141;

struct kernfs_ops___141 {
	int (*open)(struct kernfs_open_file___141 *);
	void (*release)(struct kernfs_open_file___141 *);
	int (*seq_show)(struct seq_file___135 *, void *);
	void * (*seq_start)(struct seq_file___135 *, loff_t *);
	void * (*seq_next)(struct seq_file___135 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___135 *, void *);
	ssize_t (*read)(struct kernfs_open_file___141 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___141 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___141 *, struct vm_area_struct___145 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___141 *, struct poll_table_struct___97 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___141 {
	int (*remount_fs)(struct kernfs_root___141 *, int *, char *);
	int (*show_options)(struct seq_file___135 *, struct kernfs_root___141 *);
	int (*mkdir)(struct kernfs_node___141 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___141 *);
	int (*rename)(struct kernfs_node___141 *, struct kernfs_node___141 *, const char *);
	int (*show_path)(struct seq_file___135 *, struct kernfs_node___141 *, struct kernfs_root___141 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___141 {
	struct kernfs_node___141 *kn;
	struct file___145 *file;
	struct seq_file___135 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___142 *vm_ops;
};

struct bin_attribute___134;

struct attribute_group___134 {
	const char *name;
	umode_t (*is_visible)(struct kobject___139 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___139 *, struct bin_attribute___134 *, int);
	struct attribute **attrs;
	struct bin_attribute___134 **bin_attrs;
};

struct bin_attribute___134 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___145 *, struct kobject___139 *, struct bin_attribute___134 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___145 *, struct kobject___139 *, struct bin_attribute___134 *, char *, loff_t, size_t);
	int (*mmap)(struct file___145 *, struct kobject___139 *, struct bin_attribute___134 *, struct vm_area_struct___145 *);
};

struct sysfs_ops___138 {
	ssize_t (*show)(struct kobject___139 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___139 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___138;

struct kset___138 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___139 kobj;
	const struct kset_uevent_ops___138 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___138 {
	void (*release)(struct kobject___139 *);
	const struct sysfs_ops___138 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___2 * (*child_ns_type)(struct kobject___139 *);
	const void * (*namespace)(struct kobject___139 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___138 {
	int (* const filter)(struct kset___138 *, struct kobject___139 *);
	const char * (* const name)(struct kset___138 *, struct kobject___139 *);
	int (* const uevent)(struct kset___138 *, struct kobject___139 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___120 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___120 *);
	int (*get)(char *, const struct kernel_param___120 *);
	void (*free)(void *);
};

struct kparam_array___120;

struct kernel_param___120 {
	const char *name;
	struct module___123 *mod;
	const struct kernel_param_ops___120 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___120 *arr;
	};
};

struct kparam_array___120 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___120 *ops;
	void *elem;
};

struct module_attribute___120 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___120 *, struct module_kobject___120 *, char *);
	ssize_t (*store)(struct module_attribute___120 *, struct module_kobject___120 *, const char *, size_t);
	void (*setup)(struct module___123 *, const char *);
	int (*test)(struct module___123 *);
	void (*free)(struct module___123 *);
};

struct trace_event_class___81;

struct trace_event_call___81 {
	struct list_head list;
	struct trace_event_class___81 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___4 *prog_array;
	int (*perf_perm)(struct trace_event_call___81 *, struct perf_event___88 *);
};

struct dev_pm_ops___135 {
	int (*prepare)(struct device___135 *);
	void (*complete)(struct device___135 *);
	int (*suspend)(struct device___135 *);
	int (*resume)(struct device___135 *);
	int (*freeze)(struct device___135 *);
	int (*thaw)(struct device___135 *);
	int (*poweroff)(struct device___135 *);
	int (*restore)(struct device___135 *);
	int (*suspend_late)(struct device___135 *);
	int (*resume_early)(struct device___135 *);
	int (*freeze_late)(struct device___135 *);
	int (*thaw_early)(struct device___135 *);
	int (*poweroff_late)(struct device___135 *);
	int (*restore_early)(struct device___135 *);
	int (*suspend_noirq)(struct device___135 *);
	int (*resume_noirq)(struct device___135 *);
	int (*freeze_noirq)(struct device___135 *);
	int (*thaw_noirq)(struct device___135 *);
	int (*poweroff_noirq)(struct device___135 *);
	int (*restore_noirq)(struct device___135 *);
	int (*runtime_suspend)(struct device___135 *);
	int (*runtime_resume)(struct device___135 *);
	int (*runtime_idle)(struct device___135 *);
};

struct dev_pm_domain___135 {
	struct dev_pm_ops___135 ops;
	void (*detach)(struct device___135 *, bool);
	int (*activate)(struct device___135 *);
	void (*sync)(struct device___135 *);
	void (*dismiss)(struct device___135 *);
};

struct bus_type___135 {
	const char *name;
	const char *dev_name;
	struct device___135 *dev_root;
	const struct attribute_group___134 **bus_groups;
	const struct attribute_group___134 **dev_groups;
	const struct attribute_group___134 **drv_groups;
	int (*match)(struct device___135 *, struct device_driver___135 *);
	int (*uevent)(struct device___135 *, struct kobj_uevent_env *);
	int (*probe)(struct device___135 *);
	int (*remove)(struct device___135 *);
	void (*shutdown)(struct device___135 *);
	int (*online)(struct device___135 *);
	int (*offline)(struct device___135 *);
	int (*suspend)(struct device___135 *, pm_message_t);
	int (*resume)(struct device___135 *);
	int (*num_vf)(struct device___135 *);
	int (*dma_configure)(struct device___135 *);
	const struct dev_pm_ops___135 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___135 {
	const char *name;
	struct bus_type___135 *bus;
	struct module___123 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___135 *);
	int (*remove)(struct device___135 *);
	void (*shutdown)(struct device___135 *);
	int (*suspend)(struct device___135 *, pm_message_t);
	int (*resume)(struct device___135 *);
	const struct attribute_group___134 **groups;
	const struct dev_pm_ops___135 *pm;
	void (*coredump)(struct device___135 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___135 {
	const char *name;
	const struct attribute_group___134 **groups;
	int (*uevent)(struct device___135 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___135 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___135 *);
	const struct dev_pm_ops___135 *pm;
};

struct class___135 {
	const char *name;
	struct module___123 *owner;
	const struct attribute_group___134 **class_groups;
	const struct attribute_group___134 **dev_groups;
	struct kobject___139 *dev_kobj;
	int (*dev_uevent)(struct device___135 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___135 *, umode_t *);
	void (*class_release)(struct class___135 *);
	void (*dev_release)(struct device___135 *);
	int (*shutdown_pre)(struct device___135 *);
	const struct kobj_ns_type_operations___2 *ns_type;
	const void * (*namespace)(struct device___135 *);
	const struct dev_pm_ops___135 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___113 {
	struct device___135 dev;
};

struct bpf_map___121;

struct bpf_map_ops___121 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___121 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___121 *, struct file___145 *);
	void (*map_free)(struct bpf_map___121 *);
	int (*map_get_next_key)(struct bpf_map___121 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___121 *);
	void * (*map_lookup_elem)(struct bpf_map___121 *, void *);
	int (*map_update_elem)(struct bpf_map___121 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___121 *, void *);
	int (*map_push_elem)(struct bpf_map___121 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___121 *, void *);
	int (*map_peek_elem)(struct bpf_map___121 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___121 *, struct file___145 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___121 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___121 *, void *, struct seq_file___135 *);
	int (*map_check_btf)(const struct bpf_map___121 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___121 {
	const struct bpf_map_ops___121 *ops;
	struct bpf_map___121 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___140 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___121;

typedef void (*kthread_work_func_t___121)(struct kthread_work___121 *);

struct kthread_worker___121;

struct kthread_work___121 {
	struct list_head node;
	kthread_work_func_t___121 func;
	struct kthread_worker___121 *worker;
	int canceling;
};

struct kthread_worker___121 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___145 *task;
	struct kthread_work___121 *current_work;
};

struct kthread_delayed_work___121 {
	struct kthread_work___121 work;
	struct timer_list timer;
};

struct psi_group___121 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___121 *poll_kworker;
	struct kthread_delayed_work___121 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___121;

struct cgroup_rstat_cpu___121;

struct cgroup___121 {
	struct cgroup_subsys_state___121 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___141 *kn;
	struct cgroup_file___121 procs_file;
	struct cgroup_file___121 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___121 *subsys[13];
	struct cgroup_root___121 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___121 *dom_cgrp;
	struct cgroup_rstat_cpu___121 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___4 bpf;
	atomic_t congestion_count;
	struct cgroup___121 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___121 psi;
	int ancestor_ids[0];
};

struct cftype___121;

struct cgroup_subsys___121 {
	struct cgroup_subsys_state___121 * (*css_alloc)(struct cgroup_subsys_state___121 *);
	int (*css_online)(struct cgroup_subsys_state___121 *);
	void (*css_offline)(struct cgroup_subsys_state___121 *);
	void (*css_released)(struct cgroup_subsys_state___121 *);
	void (*css_free)(struct cgroup_subsys_state___121 *);
	void (*css_reset)(struct cgroup_subsys_state___121 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___121 *, int);
	int (*css_extra_stat_show)(struct seq_file___135 *, struct cgroup_subsys_state___121 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___145 *);
	void (*cancel_fork)(struct task_struct___145 *);
	void (*fork)(struct task_struct___145 *);
	void (*exit)(struct task_struct___145 *);
	void (*free)(struct task_struct___145 *);
	void (*bind)(struct cgroup_subsys_state___121 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___121 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___121 *dfl_cftypes;
	struct cftype___121 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___121 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___121 *updated_children;
	struct cgroup___121 *updated_next;
};

struct cgroup_root___121 {
	struct kernfs_root___141 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___121 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___121 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___121 *ss;
	struct list_head node;
	struct kernfs_ops___141 *kf_ops;
	int (*open)(struct kernfs_open_file___141 *);
	void (*release)(struct kernfs_open_file___141 *);
	u64 (*read_u64)(struct cgroup_subsys_state___121 *, struct cftype___121 *);
	s64 (*read_s64)(struct cgroup_subsys_state___121 *, struct cftype___121 *);
	int (*seq_show)(struct seq_file___135 *, void *);
	void * (*seq_start)(struct seq_file___135 *, loff_t *);
	void * (*seq_next)(struct seq_file___135 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___135 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___121 *, struct cftype___121 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___121 *, struct cftype___121 *, s64);
	ssize_t (*write)(struct kernfs_open_file___141 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___141 *, struct poll_table_struct___97 *);
};

struct perf_cpu_context___88;

struct pmu___88 {
	struct list_head entry;
	struct module___123 *module;
	struct device___135 *dev;
	const struct attribute_group___134 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___88 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___88 *);
	void (*pmu_disable)(struct pmu___88 *);
	int (*event_init)(struct perf_event___88 *);
	void (*event_mapped)(struct perf_event___88 *, struct mm_struct___144 *);
	void (*event_unmapped)(struct perf_event___88 *, struct mm_struct___144 *);
	int (*add)(struct perf_event___88 *, int);
	void (*del)(struct perf_event___88 *, int);
	void (*start)(struct perf_event___88 *, int);
	void (*stop)(struct perf_event___88 *, int);
	void (*read)(struct perf_event___88 *);
	void (*start_txn)(struct pmu___88 *, unsigned int);
	int (*commit_txn)(struct pmu___88 *);
	void (*cancel_txn)(struct pmu___88 *);
	int (*event_idx)(struct perf_event___88 *);
	void (*sched_task)(struct perf_event_context___88 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___88 *);
	int (*filter_match)(struct perf_event___88 *);
	int (*check_period)(struct perf_event___88 *, u64);
};

struct perf_cpu_context___88 {
	struct perf_event_context___88 ctx;
	struct perf_event_context___88 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___88 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___88 {
	struct cgroup_subsys_state___121 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___81 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___81 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___81 *);
	struct list_head * (*get_fields)(struct trace_event_call___81 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___81 *);
};

struct syscall_metadata___28 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___81 *enter_event;
	struct trace_event_call___81 *exit_event;
};

struct bdi_writeback_congested___65 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___65 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___65 {
	struct bio___65 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___65 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___65 bip_inline_vecs[0];
};

struct bio_set___65 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___65 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___60 {
	struct mem_cgroup___60 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___60 {
	struct lruvec___144 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___60 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___60 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct hstate___21 {
	int next_nid_to_alloc;
	int next_nid_to_free;
	unsigned int order;
	long unsigned int mask;
	long unsigned int max_huge_pages;
	long unsigned int nr_huge_pages;
	long unsigned int free_huge_pages;
	long unsigned int resv_huge_pages;
	long unsigned int surplus_huge_pages;
	long unsigned int nr_overcommit_huge_pages;
	struct list_head hugepage_activelist;
	struct list_head hugepage_freelists[8];
	unsigned int nr_huge_pages_node[8];
	unsigned int free_huge_pages_node[8];
	unsigned int surplus_huge_pages_node[8];
	struct cftype___121 cgroup_files[5];
	char name[32];
};

struct module___124;

struct file___146;

struct kiocb___146;

struct iov_iter___65;

struct poll_table_struct___98;

struct vm_area_struct___146;

struct inode___146;

struct file_lock___146;

struct page___146;

struct seq_file___136;

struct file_operations___146 {
	struct module___124 *owner;
	loff_t (*llseek)(struct file___146 *, loff_t, int);
	ssize_t (*read)(struct file___146 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___146 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___146 *, struct iov_iter___65 *);
	ssize_t (*write_iter)(struct kiocb___146 *, struct iov_iter___65 *);
	int (*iopoll)(struct kiocb___146 *, bool);
	int (*iterate)(struct file___146 *, struct dir_context *);
	int (*iterate_shared)(struct file___146 *, struct dir_context *);
	__poll_t (*poll)(struct file___146 *, struct poll_table_struct___98 *);
	long int (*unlocked_ioctl)(struct file___146 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___146 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___146 *, struct vm_area_struct___146 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___146 *, struct file___146 *);
	int (*flush)(struct file___146 *, fl_owner_t);
	int (*release)(struct inode___146 *, struct file___146 *);
	int (*fsync)(struct file___146 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___146 *, int);
	int (*lock)(struct file___146 *, int, struct file_lock___146 *);
	ssize_t (*sendpage)(struct file___146 *, struct page___146 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___146 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___146 *, int, struct file_lock___146 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___146 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___146 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___146 *, long int, struct file_lock___146 **, void **);
	long int (*fallocate)(struct file___146 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___136 *, struct file___146 *);
	ssize_t (*copy_file_range)(struct file___146 *, loff_t, struct file___146 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___146 *, loff_t, struct file___146 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___146 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___145 {
	u64 seqnum;
	struct vm_area_struct___146 *vmas[4];
};

struct page_frag___145 {
	struct page___146 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___89;

struct debug_info___89 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___89 *hbp_break[16];
	struct perf_event___89 *hbp_watch[16];
};

struct thread_struct___89 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___89 debug;
	long: 64;
};

struct mm_struct___145;

struct mem_cgroup___61;

struct pid___116;

struct cred___141;

struct nsproxy___138;

struct signal_struct___130;

struct bio_list___66;

struct backing_dev_info___66;

struct css_set___122;

struct perf_event_context___89;

struct task_struct___146 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___146 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___145 *mm;
	struct mm_struct___145 *active_mm;
	struct vmacache___145 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___146 *real_parent;
	struct task_struct___146 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___146 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___61 *active_memcg;
	long int rh_reserved2;
	struct pid___116 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___116 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___116 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___141 *ptracer_cred;
	const struct cred___141 *real_cred;
	const struct cred___141 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___138 *nsproxy;
	struct signal_struct___130 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___146 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___66 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___66 *backing_dev_info;
	struct io_context___32 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___122 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___89 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___145 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___61 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___146 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___89 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___89 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___146 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___89)(struct perf_event___89 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___89;

struct fasync_struct___145;

struct pid_namespace___116;

struct trace_event_call___82;

struct perf_cgroup___89;

struct perf_event___89 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___89 *group_leader;
	struct pmu___89 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___89 hw;
	struct perf_event_context___89 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___89 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___146 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___145 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___89 *);
	struct callback_head callback_head;
	struct pid_namespace___116 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___89 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___89 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___82 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___89 *cgrp;
	struct list_head sb_list;
};

typedef struct page___146 *pgtable_t___145;

struct address_space___145;

struct dev_pagemap___143;

struct page___146 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___145 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___146 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___145 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___145 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___143 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___61 *mem_cgroup;
};

struct pglist_data___145;

struct lruvec___145 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___145 *pgdat;
};

struct zone___145 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___145 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___145 {
	struct zone___145 *zone;
	int zone_idx;
};

struct zonelist___145 {
	struct zoneref___145 _zonerefs[25];
};

struct pglist_data___145 {
	struct zone___145 node_zones[3];
	struct zonelist___145 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___146 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___146 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___145 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

typedef struct pglist_data___145 pg_data_t___10;

struct rw_semaphore___146 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___146 *owner;
};

struct secondary_data___146 {
	void *stack;
	struct task_struct___146 *task;
	long int status;
};

struct blocking_notifier_head___145 {
	struct rw_semaphore___146 rwsem;
	struct notifier_block *head;
};

struct anon_vma___10;

struct vm_operations_struct___143;

struct vm_area_struct___146 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___146 *vm_next;
	struct vm_area_struct___146 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___145 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma___10 *anon_vma;
	const struct vm_operations_struct___143 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___146 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___145;

struct user_namespace___126;

struct mm_struct___145 {
	struct {
		struct vm_area_struct___146 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___146 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___146 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___145 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___146 *owner;
		struct user_namespace___126 *user_ns;
		struct file___146 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___145 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___145;

struct address_space___145 {
	struct inode___146 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___146 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___145 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___143)(struct vm_area_struct___146 *, long unsigned int, const struct page___146 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___143)(struct page___146 *, void *);

struct device___136;

struct dev_pagemap___143 {
	dev_page_fault_t___143 page_fault;
	dev_page_free_t___143 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___136 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct cgroup___122;

struct cgroup_subsys___122;

struct cgroup_subsys_state___122 {
	struct cgroup___122 *cgroup;
	struct cgroup_subsys___122 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___122 *parent;
};

struct kernfs_node___142;

struct cgroup_file___122 {
	struct kernfs_node___142 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___61;

struct mem_cgroup___61 {
	struct cgroup_subsys_state___122 css;
	struct mem_cgroup_id___6 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___122 events_file;
	struct cgroup_file___122 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___146 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___61 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry___145;

struct path___145 {
	struct vfsmount *mnt;
	struct dentry___145 *dentry;
};

struct fown_struct___116 {
	rwlock_t lock;
	struct pid___116 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___146 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___145 f_path;
	struct inode___146 *f_inode;
	const struct file_operations___146 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___116 f_owner;
	const struct cred___141 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___145 *f_mapping;
	errseq_t f_wb_err;
};

struct anon_vma___10 {
	struct anon_vma___10 *root;
	struct rw_semaphore___146 rwsem;
	atomic_t refcount;
	unsigned int degree;
	struct anon_vma___10 *parent;
	struct rb_root_cached rb_root;
};

struct vm_fault___143;

struct vm_operations_struct___143 {
	void (*open)(struct vm_area_struct___146 *);
	void (*close)(struct vm_area_struct___146 *);
	int (*split)(struct vm_area_struct___146 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___146 *);
	vm_fault_t (*fault)(struct vm_fault___143 *);
	vm_fault_t (*huge_fault)(struct vm_fault___143 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___143 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___146 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___143 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___143 *);
	int (*access)(struct vm_area_struct___146 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___146 *);
	int (*set_policy)(struct vm_area_struct___146 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___146 *, long unsigned int);
	struct page___146 * (*find_special_page)(struct vm_area_struct___146 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___145 {
	struct task_struct___146 *task;
	struct core_thread___145 *next;
};

struct core_state___145 {
	atomic_t nr_threads;
	struct core_thread___145 dumper;
	struct completion startup;
};

struct key___141;

struct ucounts___126;

struct user_namespace___126 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___126 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___4 ns;
	long unsigned int flags;
	struct key___141 *persistent_keyring_register;
	struct rw_semaphore___146 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___126 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___143 {
	struct vm_area_struct___146 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___146 *cow_page;
	struct mem_cgroup___61 *memcg;
	struct page___146 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___145 prealloc_pte;
};

struct shrink_control___61 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___61 *memcg;
};

struct shrinker___61 {
	long unsigned int (*count_objects)(struct shrinker___61 *, struct shrink_control___61 *);
	long unsigned int (*scan_objects)(struct shrinker___61 *, struct shrink_control___61 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct upid___116 {
	int nr;
	struct pid_namespace___116 *ns;
};

struct pid_namespace___116 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___146 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___116 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___145 *proc_self;
	struct dentry___145 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___126 *user_ns;
	struct ucounts___126 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___4 ns;
};

struct pid___116 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___116 numbers[1];
};

struct user_struct___141 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___141 *uid_keyring;
	struct key___141 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___141 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___141 *session_keyring;
	struct key___141 *process_keyring;
	struct key___141 *thread_keyring;
	struct key___141 *request_key_auth;
	void *security;
	struct user_struct___141 *user;
	struct user_namespace___126 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___122;

struct nsproxy___138 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___116 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___122 *cgroup_ns;
};

struct signal_struct___130 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___146 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___146 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___116 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___116 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___145 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___116 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___66;

struct bio_list___66 {
	struct bio___66 *head;
	struct bio___66 *tail;
};

struct bdi_writeback_congested___66;

struct bdi_writeback___66 {
	struct backing_dev_info___66 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___66 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___122 *memcg_css;
	struct cgroup_subsys_state___122 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___66 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___66 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___136 *dev;
	struct device___136 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___145 *debug_dir;
	struct dentry___145 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___122 {
	struct cgroup_subsys_state___122 *subsys[13];
	refcount_t refcount;
	struct css_set___122 *dom_cset;
	struct cgroup___122 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___122 *mg_src_cgrp;
	struct cgroup___122 *mg_dst_cgrp;
	struct css_set___122 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___89 {
	struct pmu___89 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___146 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___89 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

union thread_union___130 {
	struct task_struct___146 task;
	long unsigned int stack[8192];
};

struct kset___139;

struct kobj_type___139;

struct kobject___140 {
	const char *name;
	struct list_head entry;
	struct kobject___140 *parent;
	struct kset___139 *kset;
	struct kobj_type___139 *ktype;
	struct kernfs_node___142 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___136 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___136 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___136;

struct bus_type___136;

struct device_driver___136;

struct dev_pm_domain___136;

struct class___136;

struct attribute_group___135;

struct device___136 {
	struct device___136 *parent;
	struct device_private *p;
	struct kobject___140 kobj;
	const char *init_name;
	const struct device_type___136 *type;
	struct mutex mutex;
	struct bus_type___136 *bus;
	struct device_driver___136 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___136 power;
	struct dev_pm_domain___136 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___136 *class;
	const struct attribute_group___135 **groups;
	void (*release)(struct device___136 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___145;

struct super_block___145;

struct dentry___145 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___145 *d_parent;
	struct qstr d_name;
	struct inode___146 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___145 *d_op;
	struct super_block___145 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___145;

struct block_device___146;

struct inode___146 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___145 *i_op;
	struct super_block___145 *i_sb;
	struct address_space___145 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___146 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___66 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___146 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___145 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___146 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___145 {
	int (*d_revalidate)(struct dentry___145 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___145 *, unsigned int);
	int (*d_hash)(const struct dentry___145 *, struct qstr *);
	int (*d_compare)(const struct dentry___145 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___145 *);
	int (*d_init)(struct dentry___145 *);
	void (*d_release)(struct dentry___145 *);
	void (*d_prune)(struct dentry___145 *);
	void (*d_iput)(struct dentry___145 *, struct inode___146 *);
	char * (*d_dname)(struct dentry___145 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___145 *);
	int (*d_manage)(const struct path___145 *, bool);
	struct dentry___145 * (*d_real)(struct dentry___145 *, const struct inode___146 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___145;

struct mem_dqinfo___145 {
	struct quota_format_type___145 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___145;

struct quota_info___145 {
	unsigned int flags;
	struct rw_semaphore___146 dqio_sem;
	struct inode___146 *files[3];
	struct mem_dqinfo___145 info[3];
	const struct quota_format_ops___145 *ops[3];
};

struct rcuwait___145 {
	struct task_struct___146 *task;
};

struct percpu_rw_semaphore___145 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___146 rw_sem;
	struct rcuwait___145 writer;
	int readers_block;
};

struct sb_writers___145 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___145 rw_sem[3];
};

struct file_system_type___145;

struct super_operations___145;

struct dquot_operations___145;

struct quotactl_ops___145;

struct super_block___145 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___145 *s_type;
	const struct super_operations___145 *s_op;
	const struct dquot_operations___145 *dq_op;
	const struct quotactl_ops___145 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___145 *s_root;
	struct rw_semaphore___146 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___146 *s_bdev;
	struct backing_dev_info___66 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___145 s_dquot;
	struct sb_writers___145 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___145 *s_d_op;
	int cleancache_poolid;
	struct shrinker___61 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___126 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___146 {
	struct file___146 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___146 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___145 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___146 *ia_file;
};

struct dquot___145 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___145 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___145 {
	int qf_fmt_id;
	const struct quota_format_ops___145 *qf_ops;
	struct module___124 *qf_owner;
	struct quota_format_type___145 *qf_next;
};

struct quota_format_ops___145 {
	int (*check_quota_file)(struct super_block___145 *, int);
	int (*read_file_info)(struct super_block___145 *, int);
	int (*write_file_info)(struct super_block___145 *, int);
	int (*free_file_info)(struct super_block___145 *, int);
	int (*read_dqblk)(struct dquot___145 *);
	int (*commit_dqblk)(struct dquot___145 *);
	int (*release_dqblk)(struct dquot___145 *);
	int (*get_next_id)(struct super_block___145 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___145 {
	int (*write_dquot)(struct dquot___145 *);
	struct dquot___145 * (*alloc_dquot)(struct super_block___145 *, int);
	void (*destroy_dquot)(struct dquot___145 *);
	int (*acquire_dquot)(struct dquot___145 *);
	int (*release_dquot)(struct dquot___145 *);
	int (*mark_dirty)(struct dquot___145 *);
	int (*write_info)(struct super_block___145 *, int);
	qsize_t * (*get_reserved_space)(struct inode___146 *);
	int (*get_projid)(struct inode___146 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___146 *, qsize_t *);
	int (*get_next_id)(struct super_block___145 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___145 {
	int (*quota_on)(struct super_block___145 *, int, int, const struct path___145 *);
	int (*quota_off)(struct super_block___145 *, int);
	int (*quota_enable)(struct super_block___145 *, unsigned int);
	int (*quota_disable)(struct super_block___145 *, unsigned int);
	int (*quota_sync)(struct super_block___145 *, int);
	int (*set_info)(struct super_block___145 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___145 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___145 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___145 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___145 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___145 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___121 {
	struct kobject___140 kobj;
	struct module___124 *mod;
	struct kobject___140 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___121 {
	struct module___124 *mod;
	struct latch_tree_node node;
};

struct module_layout___121 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___121 mtn;
};

struct module_attribute___121;

struct kernel_param___121;

struct module___124 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___121 mkobj;
	struct module_attribute___121 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___140 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___121 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___121 core_layout;
	struct module_layout___121 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___82 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___63;

struct swap_info_struct___43;

struct address_space_operations___145 {
	int (*writepage)(struct page___146 *, struct writeback_control___63 *);
	int (*readpage)(struct file___146 *, struct page___146 *);
	int (*writepages)(struct address_space___145 *, struct writeback_control___63 *);
	int (*set_page_dirty)(struct page___146 *);
	int (*readpages)(struct file___146 *, struct address_space___145 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___146 *, struct address_space___145 *, loff_t, unsigned int, unsigned int, struct page___146 **, void **);
	int (*write_end)(struct file___146 *, struct address_space___145 *, loff_t, unsigned int, unsigned int, struct page___146 *, void *);
	sector_t (*bmap)(struct address_space___145 *, sector_t);
	void (*invalidatepage)(struct page___146 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___146 *, gfp_t);
	void (*freepage)(struct page___146 *);
	ssize_t (*direct_IO)(struct kiocb___146 *, struct iov_iter___65 *);
	int (*migratepage)(struct address_space___145 *, struct page___146 *, struct page___146 *, enum migrate_mode);
	bool (*isolate_page)(struct page___146 *, isolate_mode_t);
	void (*putback_page)(struct page___146 *);
	int (*launder_page)(struct page___146 *);
	int (*is_partially_uptodate)(struct page___146 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___146 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___145 *, struct page___146 *);
	int (*swap_activate)(struct swap_info_struct___43 *, struct file___146 *, sector_t *);
	void (*swap_deactivate)(struct file___146 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___63 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___66 *wb;
	struct inode___146 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___66;

struct iov_iter___65 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___66 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct swap_info_struct___43 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___146 *bdev;
	struct file___146 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___146 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___146 *bd_inode;
	struct super_block___145 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___146 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___66 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___145 {
	struct dentry___145 * (*lookup)(struct inode___146 *, struct dentry___145 *, unsigned int);
	const char * (*get_link)(struct dentry___145 *, struct inode___146 *, struct delayed_call *);
	int (*permission)(struct inode___146 *, int);
	struct posix_acl * (*get_acl)(struct inode___146 *, int);
	int (*readlink)(struct dentry___145 *, char *, int);
	int (*create)(struct inode___146 *, struct dentry___145 *, umode_t, bool);
	int (*link)(struct dentry___145 *, struct inode___146 *, struct dentry___145 *);
	int (*unlink)(struct inode___146 *, struct dentry___145 *);
	int (*symlink)(struct inode___146 *, struct dentry___145 *, const char *);
	int (*mkdir)(struct inode___146 *, struct dentry___145 *, umode_t);
	int (*rmdir)(struct inode___146 *, struct dentry___145 *);
	int (*mknod)(struct inode___146 *, struct dentry___145 *, umode_t, dev_t);
	int (*rename)(struct inode___146 *, struct dentry___145 *, struct inode___146 *, struct dentry___145 *, unsigned int);
	int (*setattr)(struct dentry___145 *, struct iattr___145 *);
	int (*getattr)(const struct path___145 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___145 *, char *, size_t);
	int (*fiemap)(struct inode___146 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___146 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___146 *, struct dentry___145 *, struct file___146 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___146 *, struct dentry___145 *, umode_t);
	int (*set_acl)(struct inode___146 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___145 {
	void (*fl_copy_lock)(struct file_lock___146 *, struct file_lock___146 *);
	void (*fl_release_private)(struct file_lock___146 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___145;

struct file_lock___146 {
	struct file_lock___146 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___146 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___145 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___145 *fl_ops;
	const struct lock_manager_operations___145 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___145 {
	int (*lm_compare_owner)(struct file_lock___146 *, struct file_lock___146 *);
	long unsigned int (*lm_owner_key)(struct file_lock___146 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___146 *);
	int (*lm_grant)(struct file_lock___146 *, int);
	bool (*lm_break)(struct file_lock___146 *);
	int (*lm_change)(struct file_lock___146 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___146 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___145 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___145 *fa_next;
	struct file___146 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___145 {
	const char *name;
	int fs_flags;
	struct dentry___145 * (*mount)(struct file_system_type___145 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___145 *);
	struct module___124 *owner;
	struct file_system_type___145 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___145 {
	struct inode___146 * (*alloc_inode)(struct super_block___145 *);
	void (*destroy_inode)(struct inode___146 *);
	void (*dirty_inode)(struct inode___146 *, int);
	int (*write_inode)(struct inode___146 *, struct writeback_control___63 *);
	int (*drop_inode)(struct inode___146 *);
	void (*evict_inode)(struct inode___146 *);
	void (*put_super)(struct super_block___145 *);
	int (*sync_fs)(struct super_block___145 *, int);
	int (*freeze_super)(struct super_block___145 *);
	int (*freeze_fs)(struct super_block___145 *);
	int (*thaw_super)(struct super_block___145 *);
	int (*unfreeze_fs)(struct super_block___145 *);
	int (*statfs)(struct dentry___145 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___145 *, int *, char *);
	void (*umount_begin)(struct super_block___145 *);
	int (*show_options)(struct seq_file___136 *, struct dentry___145 *);
	int (*show_devname)(struct seq_file___136 *, struct dentry___145 *);
	int (*show_path)(struct seq_file___136 *, struct dentry___145 *);
	int (*show_stats)(struct seq_file___136 *, struct dentry___145 *);
	ssize_t (*quota_read)(struct super_block___145 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___145 *, int, const char *, size_t, loff_t);
	struct dquot___145 ** (*get_dquots)(struct inode___146 *);
	int (*bdev_try_to_free_page)(struct super_block___145 *, struct page___146 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___145 *, struct shrink_control___61 *);
	long int (*free_cached_objects)(struct super_block___145 *, struct shrink_control___61 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___97)(struct file___146 *, wait_queue_head_t *, struct poll_table_struct___98 *);

struct poll_table_struct___98 {
	poll_queue_proc___97 _qproc;
	__poll_t _key;
};

struct seq_operations___134;

struct seq_file___136 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___134 *op;
	int poll_event;
	const struct file___146 *file;
	void *private;
};

typedef void bio_end_io_t___66(struct bio___66 *);

struct bio_vec___66 {
	struct page___146 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___66;

struct bio_set___66;

struct bio___66 {
	struct bio___66 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___66 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___66 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___66 *bi_io_vec;
	struct bio_set___66 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___66 bi_inline_vecs[0];
};

struct kobj_attribute___140 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___140 *, struct kobj_attribute___140 *, char *);
	ssize_t (*store)(struct kobject___140 *, struct kobj_attribute___140 *, const char *, size_t);
};

typedef void compound_page_dtor___143(struct page___146 *);

struct key_restriction___141;

struct key___141 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___146 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___141 *restrict_link;
};

typedef int (*key_restrict_link_func_t___141)(struct key___141 *, const struct key_type *, const union key_payload *, struct key___141 *);

struct key_restriction___141 {
	key_restrict_link_func_t___141 check;
	struct key___141 *key;
	struct key_type *keytype;
};

struct seq_operations___134 {
	void * (*start)(struct seq_file___136 *, loff_t *);
	void (*stop)(struct seq_file___136 *, void *);
	void * (*next)(struct seq_file___136 *, void *, loff_t *);
	int (*show)(struct seq_file___136 *, void *);
};

struct kernfs_root___142;

struct kernfs_elem_dir___142 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___142 *root;
};

struct kernfs_syscall_ops___142;

struct kernfs_root___142 {
	struct kernfs_node___142 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___142 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___142 {
	struct kernfs_node___142 *target_kn;
};

struct kernfs_ops___142;

struct kernfs_elem_attr___142 {
	const struct kernfs_ops___142 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___142 *notify_next;
};

struct kernfs_node___142 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___142 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___142 dir;
		struct kernfs_elem_symlink___142 symlink;
		struct kernfs_elem_attr___142 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___142;

struct kernfs_ops___142 {
	int (*open)(struct kernfs_open_file___142 *);
	void (*release)(struct kernfs_open_file___142 *);
	int (*seq_show)(struct seq_file___136 *, void *);
	void * (*seq_start)(struct seq_file___136 *, loff_t *);
	void * (*seq_next)(struct seq_file___136 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___136 *, void *);
	ssize_t (*read)(struct kernfs_open_file___142 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___142 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___142 *, struct vm_area_struct___146 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___142 *, struct poll_table_struct___98 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___142 {
	int (*remount_fs)(struct kernfs_root___142 *, int *, char *);
	int (*show_options)(struct seq_file___136 *, struct kernfs_root___142 *);
	int (*mkdir)(struct kernfs_node___142 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___142 *);
	int (*rename)(struct kernfs_node___142 *, struct kernfs_node___142 *, const char *);
	int (*show_path)(struct seq_file___136 *, struct kernfs_node___142 *, struct kernfs_root___142 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___142 {
	struct kernfs_node___142 *kn;
	struct file___146 *file;
	struct seq_file___136 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___143 *vm_ops;
};

struct cgroup_namespace___122 {
	refcount_t count;
	struct ns_common___4 ns;
	struct user_namespace___126 *user_ns;
	struct ucounts___126 *ucounts;
	struct css_set___122 *root_cset;
};

struct ucounts___126 {
	struct hlist_node node;
	struct user_namespace___126 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___122;

struct bpf_map_ops___122 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___122 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___122 *, struct file___146 *);
	void (*map_free)(struct bpf_map___122 *);
	int (*map_get_next_key)(struct bpf_map___122 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___122 *);
	void * (*map_lookup_elem)(struct bpf_map___122 *, void *);
	int (*map_update_elem)(struct bpf_map___122 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___122 *, void *);
	int (*map_push_elem)(struct bpf_map___122 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___122 *, void *);
	int (*map_peek_elem)(struct bpf_map___122 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___122 *, struct file___146 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___122 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___122 *, void *, struct seq_file___136 *);
	int (*map_check_btf)(const struct bpf_map___122 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___122 {
	const struct bpf_map_ops___122 *ops;
	struct bpf_map___122 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___141 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___122;

typedef void (*kthread_work_func_t___122)(struct kthread_work___122 *);

struct kthread_worker___122;

struct kthread_work___122 {
	struct list_head node;
	kthread_work_func_t___122 func;
	struct kthread_worker___122 *worker;
	int canceling;
};

struct kthread_worker___122 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___146 *task;
	struct kthread_work___122 *current_work;
};

struct kthread_delayed_work___122 {
	struct kthread_work___122 work;
	struct timer_list timer;
};

struct psi_group___122 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___122 *poll_kworker;
	struct kthread_delayed_work___122 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___122;

struct cgroup_rstat_cpu___122;

struct cgroup___122 {
	struct cgroup_subsys_state___122 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___142 *kn;
	struct cgroup_file___122 procs_file;
	struct cgroup_file___122 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___122 *subsys[13];
	struct cgroup_root___122 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___122 *dom_cgrp;
	struct cgroup_rstat_cpu___122 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___4 bpf;
	atomic_t congestion_count;
	struct cgroup___122 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___122 psi;
	int ancestor_ids[0];
};

struct cftype___122;

struct cgroup_subsys___122 {
	struct cgroup_subsys_state___122 * (*css_alloc)(struct cgroup_subsys_state___122 *);
	int (*css_online)(struct cgroup_subsys_state___122 *);
	void (*css_offline)(struct cgroup_subsys_state___122 *);
	void (*css_released)(struct cgroup_subsys_state___122 *);
	void (*css_free)(struct cgroup_subsys_state___122 *);
	void (*css_reset)(struct cgroup_subsys_state___122 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___122 *, int);
	int (*css_extra_stat_show)(struct seq_file___136 *, struct cgroup_subsys_state___122 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___146 *);
	void (*cancel_fork)(struct task_struct___146 *);
	void (*fork)(struct task_struct___146 *);
	void (*exit)(struct task_struct___146 *);
	void (*free)(struct task_struct___146 *);
	void (*bind)(struct cgroup_subsys_state___122 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___122 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___122 *dfl_cftypes;
	struct cftype___122 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___122 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___122 *updated_children;
	struct cgroup___122 *updated_next;
};

struct cgroup_root___122 {
	struct kernfs_root___142 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___122 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___122 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___122 *ss;
	struct list_head node;
	struct kernfs_ops___142 *kf_ops;
	int (*open)(struct kernfs_open_file___142 *);
	void (*release)(struct kernfs_open_file___142 *);
	u64 (*read_u64)(struct cgroup_subsys_state___122 *, struct cftype___122 *);
	s64 (*read_s64)(struct cgroup_subsys_state___122 *, struct cftype___122 *);
	int (*seq_show)(struct seq_file___136 *, void *);
	void * (*seq_start)(struct seq_file___136 *, loff_t *);
	void * (*seq_next)(struct seq_file___136 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___136 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___122 *, struct cftype___122 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___122 *, struct cftype___122 *, s64);
	ssize_t (*write)(struct kernfs_open_file___142 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___142 *, struct poll_table_struct___98 *);
};

struct bdi_writeback_congested___66 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___66 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___66 {
	struct bio___66 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___66 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___66 bip_inline_vecs[0];
};

struct bio_set___66 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___66 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___61 {
	struct mem_cgroup___61 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___61 {
	struct lruvec___145 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___61 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___61 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct bin_attribute___135;

struct attribute_group___135 {
	const char *name;
	umode_t (*is_visible)(struct kobject___140 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___140 *, struct bin_attribute___135 *, int);
	struct attribute **attrs;
	struct bin_attribute___135 **bin_attrs;
};

struct bin_attribute___135 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___146 *, struct kobject___140 *, struct bin_attribute___135 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___146 *, struct kobject___140 *, struct bin_attribute___135 *, char *, loff_t, size_t);
	int (*mmap)(struct file___146 *, struct kobject___140 *, struct bin_attribute___135 *, struct vm_area_struct___146 *);
};

struct sysfs_ops___139 {
	ssize_t (*show)(struct kobject___140 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___140 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___139;

struct kset___139 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___140 kobj;
	const struct kset_uevent_ops___139 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___139 {
	void (*release)(struct kobject___140 *);
	const struct sysfs_ops___139 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___2 * (*child_ns_type)(struct kobject___140 *);
	const void * (*namespace)(struct kobject___140 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___139 {
	int (* const filter)(struct kset___139 *, struct kobject___140 *);
	const char * (* const name)(struct kset___139 *, struct kobject___140 *);
	int (* const uevent)(struct kset___139 *, struct kobject___140 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___136 {
	int (*prepare)(struct device___136 *);
	void (*complete)(struct device___136 *);
	int (*suspend)(struct device___136 *);
	int (*resume)(struct device___136 *);
	int (*freeze)(struct device___136 *);
	int (*thaw)(struct device___136 *);
	int (*poweroff)(struct device___136 *);
	int (*restore)(struct device___136 *);
	int (*suspend_late)(struct device___136 *);
	int (*resume_early)(struct device___136 *);
	int (*freeze_late)(struct device___136 *);
	int (*thaw_early)(struct device___136 *);
	int (*poweroff_late)(struct device___136 *);
	int (*restore_early)(struct device___136 *);
	int (*suspend_noirq)(struct device___136 *);
	int (*resume_noirq)(struct device___136 *);
	int (*freeze_noirq)(struct device___136 *);
	int (*thaw_noirq)(struct device___136 *);
	int (*poweroff_noirq)(struct device___136 *);
	int (*restore_noirq)(struct device___136 *);
	int (*runtime_suspend)(struct device___136 *);
	int (*runtime_resume)(struct device___136 *);
	int (*runtime_idle)(struct device___136 *);
};

struct dev_pm_domain___136 {
	struct dev_pm_ops___136 ops;
	void (*detach)(struct device___136 *, bool);
	int (*activate)(struct device___136 *);
	void (*sync)(struct device___136 *);
	void (*dismiss)(struct device___136 *);
};

struct bus_type___136 {
	const char *name;
	const char *dev_name;
	struct device___136 *dev_root;
	const struct attribute_group___135 **bus_groups;
	const struct attribute_group___135 **dev_groups;
	const struct attribute_group___135 **drv_groups;
	int (*match)(struct device___136 *, struct device_driver___136 *);
	int (*uevent)(struct device___136 *, struct kobj_uevent_env *);
	int (*probe)(struct device___136 *);
	int (*remove)(struct device___136 *);
	void (*shutdown)(struct device___136 *);
	int (*online)(struct device___136 *);
	int (*offline)(struct device___136 *);
	int (*suspend)(struct device___136 *, pm_message_t);
	int (*resume)(struct device___136 *);
	int (*num_vf)(struct device___136 *);
	int (*dma_configure)(struct device___136 *);
	const struct dev_pm_ops___136 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___136 {
	const char *name;
	struct bus_type___136 *bus;
	struct module___124 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___136 *);
	int (*remove)(struct device___136 *);
	void (*shutdown)(struct device___136 *);
	int (*suspend)(struct device___136 *, pm_message_t);
	int (*resume)(struct device___136 *);
	const struct attribute_group___135 **groups;
	const struct dev_pm_ops___136 *pm;
	void (*coredump)(struct device___136 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___136 {
	const char *name;
	const struct attribute_group___135 **groups;
	int (*uevent)(struct device___136 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___136 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___136 *);
	const struct dev_pm_ops___136 *pm;
};

struct class___136 {
	const char *name;
	struct module___124 *owner;
	const struct attribute_group___135 **class_groups;
	const struct attribute_group___135 **dev_groups;
	struct kobject___140 *dev_kobj;
	int (*dev_uevent)(struct device___136 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___136 *, umode_t *);
	void (*class_release)(struct class___136 *);
	void (*dev_release)(struct device___136 *);
	int (*shutdown_pre)(struct device___136 *);
	const struct kobj_ns_type_operations___2 *ns_type;
	const void * (*namespace)(struct device___136 *);
	const struct dev_pm_ops___136 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___114 {
	struct device___136 dev;
};

struct pagevec___7 {
	unsigned char nr;
	bool percpu_pvec_drained;
	struct page___146 *pages[15];
};

struct kernel_param_ops___121 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___121 *);
	int (*get)(char *, const struct kernel_param___121 *);
	void (*free)(void *);
};

struct kparam_array___121;

struct kernel_param___121 {
	const char *name;
	struct module___124 *mod;
	const struct kernel_param_ops___121 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___121 *arr;
	};
};

struct kparam_array___121 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___121 *ops;
	void *elem;
};

struct module_attribute___121 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___121 *, struct module_kobject___121 *, char *);
	ssize_t (*store)(struct module_attribute___121 *, struct module_kobject___121 *, const char *, size_t);
	void (*setup)(struct module___124 *, const char *);
	int (*test)(struct module___124 *);
	void (*free)(struct module___124 *);
};

struct trace_event_class___82;

struct trace_event_call___82 {
	struct list_head list;
	struct trace_event_class___82 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___4 *prog_array;
	int (*perf_perm)(struct trace_event_call___82 *, struct perf_event___89 *);
};

struct perf_cpu_context___89;

struct pmu___89 {
	struct list_head entry;
	struct module___124 *module;
	struct device___136 *dev;
	const struct attribute_group___135 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___89 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___89 *);
	void (*pmu_disable)(struct pmu___89 *);
	int (*event_init)(struct perf_event___89 *);
	void (*event_mapped)(struct perf_event___89 *, struct mm_struct___145 *);
	void (*event_unmapped)(struct perf_event___89 *, struct mm_struct___145 *);
	int (*add)(struct perf_event___89 *, int);
	void (*del)(struct perf_event___89 *, int);
	void (*start)(struct perf_event___89 *, int);
	void (*stop)(struct perf_event___89 *, int);
	void (*read)(struct perf_event___89 *);
	void (*start_txn)(struct pmu___89 *, unsigned int);
	int (*commit_txn)(struct pmu___89 *);
	void (*cancel_txn)(struct pmu___89 *);
	int (*event_idx)(struct perf_event___89 *);
	void (*sched_task)(struct perf_event_context___89 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___89 *);
	int (*filter_match)(struct perf_event___89 *);
	int (*check_period)(struct perf_event___89 *, u64);
};

struct perf_cpu_context___89 {
	struct perf_event_context___89 ctx;
	struct perf_event_context___89 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___89 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___89 {
	struct cgroup_subsys_state___122 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___82 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___82 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___82 *);
	struct list_head * (*get_fields)(struct trace_event_call___82 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___82 *);
};

struct syscall_metadata___29 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___82 *enter_event;
	struct trace_event_call___82 *exit_event;
};

struct hstate___22 {
	int next_nid_to_alloc;
	int next_nid_to_free;
	unsigned int order;
	long unsigned int mask;
	long unsigned int max_huge_pages;
	long unsigned int nr_huge_pages;
	long unsigned int free_huge_pages;
	long unsigned int resv_huge_pages;
	long unsigned int surplus_huge_pages;
	long unsigned int nr_overcommit_huge_pages;
	struct list_head hugepage_activelist;
	struct list_head hugepage_freelists[8];
	unsigned int nr_huge_pages_node[8];
	unsigned int free_huge_pages_node[8];
	unsigned int surplus_huge_pages_node[8];
	struct cftype___122 cgroup_files[5];
	char name[32];
};

struct module___125;

struct file___147;

struct kiocb___147;

struct iov_iter___66;

struct poll_table_struct___99;

struct vm_area_struct___147;

struct inode___147;

struct file_lock___147;

struct page___147;

struct seq_file___137;

struct file_operations___147 {
	struct module___125 *owner;
	loff_t (*llseek)(struct file___147 *, loff_t, int);
	ssize_t (*read)(struct file___147 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___147 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___147 *, struct iov_iter___66 *);
	ssize_t (*write_iter)(struct kiocb___147 *, struct iov_iter___66 *);
	int (*iopoll)(struct kiocb___147 *, bool);
	int (*iterate)(struct file___147 *, struct dir_context *);
	int (*iterate_shared)(struct file___147 *, struct dir_context *);
	__poll_t (*poll)(struct file___147 *, struct poll_table_struct___99 *);
	long int (*unlocked_ioctl)(struct file___147 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___147 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___147 *, struct vm_area_struct___147 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___147 *, struct file___147 *);
	int (*flush)(struct file___147 *, fl_owner_t);
	int (*release)(struct inode___147 *, struct file___147 *);
	int (*fsync)(struct file___147 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___147 *, int);
	int (*lock)(struct file___147 *, int, struct file_lock___147 *);
	ssize_t (*sendpage)(struct file___147 *, struct page___147 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___147 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___147 *, int, struct file_lock___147 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___147 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___147 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___147 *, long int, struct file_lock___147 **, void **);
	long int (*fallocate)(struct file___147 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___137 *, struct file___147 *);
	ssize_t (*copy_file_range)(struct file___147 *, loff_t, struct file___147 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___147 *, loff_t, struct file___147 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___147 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___146 {
	u64 seqnum;
	struct vm_area_struct___147 *vmas[4];
};

struct page_frag___146 {
	struct page___147 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___90;

struct debug_info___90 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___90 *hbp_break[16];
	struct perf_event___90 *hbp_watch[16];
};

struct thread_struct___90 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___90 debug;
	long: 64;
};

struct mm_struct___146;

struct mem_cgroup___62;

struct pid___117;

struct cred___142;

struct nsproxy___139;

struct signal_struct___131;

struct bio_list___67;

struct backing_dev_info___67;

struct io_context___33;

struct css_set___123;

struct perf_event_context___90;

struct request_queue___31;

struct vm_struct___111;

struct task_struct___147 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___147 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___146 *mm;
	struct mm_struct___146 *active_mm;
	struct vmacache___146 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___147 *real_parent;
	struct task_struct___147 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___147 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___62 *active_memcg;
	long int rh_reserved2;
	struct pid___117 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___117 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___117 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___142 *ptracer_cred;
	const struct cred___142 *real_cred;
	const struct cred___142 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___139 *nsproxy;
	struct signal_struct___131 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___147 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___67 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___67 *backing_dev_info;
	struct io_context___33 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___123 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___90 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___146 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___62 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___31 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___147 *oom_reaper_list;
	struct vm_struct___111 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___90 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___90 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___147 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___90)(struct perf_event___90 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___90;

struct fasync_struct___146;

struct pid_namespace___117;

struct trace_event_call___83;

struct perf_cgroup___90;

struct perf_event___90 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___90 *group_leader;
	struct pmu___90 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___90 hw;
	struct perf_event_context___90 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___90 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___147 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___146 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___90 *);
	struct callback_head callback_head;
	struct pid_namespace___117 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___90 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___90 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___83 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___90 *cgrp;
	struct list_head sb_list;
};

typedef struct page___147 *pgtable_t___146;

struct address_space___146;

struct dev_pagemap___144;

struct page___147 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___146 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___147 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___146 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___146 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___144 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___62 *mem_cgroup;
};

struct pglist_data___146;

struct lruvec___146 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___146 *pgdat;
};

struct zone___146 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___146 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___146 {
	struct zone___146 *zone;
	int zone_idx;
};

struct zonelist___146 {
	struct zoneref___146 _zonerefs[25];
};

struct pglist_data___146 {
	struct zone___146 node_zones[3];
	struct zonelist___146 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___147 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___147 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___146 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___147 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___147 *owner;
};

struct secondary_data___147 {
	void *stack;
	struct task_struct___147 *task;
	long int status;
};

struct blocking_notifier_head___146 {
	struct rw_semaphore___147 rwsem;
	struct notifier_block *head;
};

struct cgroup___123;

struct cgroup_subsys___123;

struct cgroup_subsys_state___123 {
	struct cgroup___123 *cgroup;
	struct cgroup_subsys___123 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___123 *parent;
};

struct kernfs_node___143;

struct cgroup_file___123 {
	struct kernfs_node___143 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___62;

struct mem_cgroup___62 {
	struct cgroup_subsys_state___123 css;
	struct mem_cgroup_id___17 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___123 events_file;
	struct cgroup_file___123 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___147 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___62 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___146;

struct super_block___146;

struct dentry___146 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___146 *d_parent;
	struct qstr d_name;
	struct inode___147 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___146 *d_op;
	struct super_block___146 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___146;

struct address_space___146 {
	struct inode___147 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___147 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___146 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___146;

struct bdi_writeback___67;

struct block_device___147;

struct inode___147 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___146 *i_op;
	struct super_block___146 *i_sb;
	struct address_space___146 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___147 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___67 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___147 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___146 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___147 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vfsmount___20;

struct path___146;

struct dentry_operations___146 {
	int (*d_revalidate)(struct dentry___146 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___146 *, unsigned int);
	int (*d_hash)(const struct dentry___146 *, struct qstr *);
	int (*d_compare)(const struct dentry___146 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___146 *);
	int (*d_init)(struct dentry___146 *);
	void (*d_release)(struct dentry___146 *);
	void (*d_prune)(struct dentry___146 *);
	void (*d_iput)(struct dentry___146 *, struct inode___147 *);
	char * (*d_dname)(struct dentry___146 *, char *, int);
	struct vfsmount___20 * (*d_automount)(struct path___146 *);
	int (*d_manage)(const struct path___146 *, bool);
	struct dentry___146 * (*d_real)(struct dentry___146 *, const struct inode___147 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___146;

struct mem_dqinfo___146 {
	struct quota_format_type___146 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___146;

struct quota_info___146 {
	unsigned int flags;
	struct rw_semaphore___147 dqio_sem;
	struct inode___147 *files[3];
	struct mem_dqinfo___146 info[3];
	const struct quota_format_ops___146 *ops[3];
};

struct rcuwait___146 {
	struct task_struct___147 *task;
};

struct percpu_rw_semaphore___146 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___147 rw_sem;
	struct rcuwait___146 writer;
	int readers_block;
};

struct sb_writers___146 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___146 rw_sem[3];
};

struct shrink_control___62;

struct shrinker___62 {
	long unsigned int (*count_objects)(struct shrinker___62 *, struct shrink_control___62 *);
	long unsigned int (*scan_objects)(struct shrinker___62 *, struct shrink_control___62 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___146;

struct super_operations___146;

struct dquot_operations___146;

struct quotactl_ops___146;

struct xattr_handler___10;

struct user_namespace___127;

struct super_block___146 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___146 *s_type;
	const struct super_operations___146 *s_op;
	const struct dquot_operations___146 *dq_op;
	const struct quotactl_ops___146 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___146 *s_root;
	struct rw_semaphore___147 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___10 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___147 *s_bdev;
	struct backing_dev_info___67 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___146 s_dquot;
	struct sb_writers___146 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___146 *s_d_op;
	int cleancache_poolid;
	struct shrinker___62 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___127 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___20 {
	struct dentry___146 *mnt_root;
	struct super_block___146 *mnt_sb;
	int mnt_flags;
};

struct path___146 {
	struct vfsmount___20 *mnt;
	struct dentry___146 *dentry;
};

struct key___142;

struct ucounts___127;

struct user_namespace___127 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___127 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___4 ns;
	long unsigned int flags;
	struct key___142 *persistent_keyring_register;
	struct rw_semaphore___147 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___127 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct shrink_control___62 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___62 *memcg;
};

struct upid___117 {
	int nr;
	struct pid_namespace___117 *ns;
};

struct pid_namespace___117 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___147 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___117 *parent;
	struct vfsmount___20 *proc_mnt;
	struct dentry___146 *proc_self;
	struct dentry___146 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___127 *user_ns;
	struct ucounts___127 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___4 ns;
};

struct pid___117 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___117 numbers[1];
};

struct anon_vma___11;

struct vm_operations_struct___144;

struct vm_area_struct___147 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___147 *vm_next;
	struct vm_area_struct___147 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___146 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma___11 *anon_vma;
	const struct vm_operations_struct___144 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___147 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___146;

struct mm_struct___146 {
	struct {
		struct vm_area_struct___147 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___147 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___147 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___146 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___147 *owner;
		struct user_namespace___127 *user_ns;
		struct file___147 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___146 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___144)(struct vm_area_struct___147 *, long unsigned int, const struct page___147 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___144)(struct page___147 *, void *);

struct device___137;

struct dev_pagemap___144 {
	dev_page_fault_t___144 page_fault;
	dev_page_free_t___144 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___137 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct fown_struct___117 {
	rwlock_t lock;
	struct pid___117 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___147 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___146 f_path;
	struct inode___147 *f_inode;
	const struct file_operations___147 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___117 f_owner;
	const struct cred___142 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___146 *f_mapping;
	errseq_t f_wb_err;
};

struct anon_vma___11 {
	struct anon_vma___11 *root;
	struct rw_semaphore___147 rwsem;
	atomic_t refcount;
	unsigned int degree;
	struct anon_vma___11 *parent;
	struct rb_root_cached rb_root;
};

struct vm_fault___144;

struct vm_operations_struct___144 {
	void (*open)(struct vm_area_struct___147 *);
	void (*close)(struct vm_area_struct___147 *);
	int (*split)(struct vm_area_struct___147 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___147 *);
	vm_fault_t (*fault)(struct vm_fault___144 *);
	vm_fault_t (*huge_fault)(struct vm_fault___144 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___144 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___147 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___144 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___144 *);
	int (*access)(struct vm_area_struct___147 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___147 *);
	int (*set_policy)(struct vm_area_struct___147 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___147 *, long unsigned int);
	struct page___147 * (*find_special_page)(struct vm_area_struct___147 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___146 {
	struct task_struct___147 *task;
	struct core_thread___146 *next;
};

struct core_state___146 {
	atomic_t nr_threads;
	struct core_thread___146 dumper;
	struct completion startup;
};

struct vm_special_mapping___3 {
	const char *name;
	struct page___147 **pages;
	vm_fault_t (*fault)(const struct vm_special_mapping___3 *, struct vm_area_struct___147 *, struct vm_fault___144 *);
	int (*mremap)(const struct vm_special_mapping___3 *, struct vm_area_struct___147 *);
};

struct vm_fault___144 {
	struct vm_area_struct___147 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___147 *cow_page;
	struct mem_cgroup___62 *memcg;
	struct page___147 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___146 prealloc_pte;
};

struct user_struct___142 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___142 *uid_keyring;
	struct key___142 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___142 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___142 *session_keyring;
	struct key___142 *process_keyring;
	struct key___142 *thread_keyring;
	struct key___142 *request_key_auth;
	void *security;
	struct user_struct___142 *user;
	struct user_namespace___127 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___123;

struct nsproxy___139 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___117 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___123 *cgroup_ns;
};

struct signal_struct___131 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___147 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___147 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___117 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___117 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___146 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___117 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide45;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___67;

struct bio_list___67 {
	struct bio___67 *head;
	struct bio___67 *tail;
};

struct bdi_writeback_congested___67;

struct bdi_writeback___67 {
	struct backing_dev_info___67 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___67 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___123 *memcg_css;
	struct cgroup_subsys_state___123 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___67 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___67 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___137 *dev;
	struct device___137 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___146 *debug_dir;
	struct dentry___146 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___33;

struct io_context___33 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___33 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___123 {
	struct cgroup_subsys_state___123 *subsys[13];
	refcount_t refcount;
	struct css_set___123 *dom_cset;
	struct cgroup___123 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___123 *mg_src_cgrp;
	struct cgroup___123 *mg_dst_cgrp;
	struct css_set___123 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___90 {
	struct pmu___90 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___147 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___90 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

typedef blk_qc_t make_request_fn___30(struct request_queue___31 *, struct bio___67 *);

struct request___31;

typedef int dma_drain_needed_fn___30(struct request___31 *);

struct kset___140;

struct kobj_type___140;

struct kobject___141 {
	const char *name;
	struct list_head entry;
	struct kobject___141 *parent;
	struct kset___140 *kset;
	struct kobj_type___140 *ktype;
	struct kernfs_node___143 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___30;

struct bsg_class_device___30 {
	struct device___137 *class_dev;
	int minor;
	struct request_queue___31 *queue;
	const struct bsg_ops___30 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___67 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___67 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___30;

struct blkcg_gq___21;

struct request_queue___31 {
	struct list_head queue_head;
	struct request___31 *last_merge;
	struct elevator_queue___30 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___30 *make_request_fn;
	dma_drain_needed_fn___30 *dma_drain_needed;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___67 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___141 kobj;
	struct kobject___141 *mq_kobj;
	struct blk_integrity integrity;
	struct device___137 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___21 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	struct bsg_class_device___30 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___67 bio_split;
	struct dentry___146 *debugfs_dir;
	struct dentry___146 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___111 {
	struct vm_struct___111 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___147 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___131 {
	struct task_struct___147 task;
	long unsigned int stack[8192];
};

struct io_cq___33 {
	struct request_queue___31 *q;
	struct io_context___33 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___147 {
	struct file___147 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___147 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___146 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___147 *ia_file;
};

struct dquot___146 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___146 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___146 {
	int qf_fmt_id;
	const struct quota_format_ops___146 *qf_ops;
	struct module___125 *qf_owner;
	struct quota_format_type___146 *qf_next;
};

struct quota_format_ops___146 {
	int (*check_quota_file)(struct super_block___146 *, int);
	int (*read_file_info)(struct super_block___146 *, int);
	int (*write_file_info)(struct super_block___146 *, int);
	int (*free_file_info)(struct super_block___146 *, int);
	int (*read_dqblk)(struct dquot___146 *);
	int (*commit_dqblk)(struct dquot___146 *);
	int (*release_dqblk)(struct dquot___146 *);
	int (*get_next_id)(struct super_block___146 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___146 {
	int (*write_dquot)(struct dquot___146 *);
	struct dquot___146 * (*alloc_dquot)(struct super_block___146 *, int);
	void (*destroy_dquot)(struct dquot___146 *);
	int (*acquire_dquot)(struct dquot___146 *);
	int (*release_dquot)(struct dquot___146 *);
	int (*mark_dirty)(struct dquot___146 *);
	int (*write_info)(struct super_block___146 *, int);
	qsize_t * (*get_reserved_space)(struct inode___147 *);
	int (*get_projid)(struct inode___147 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___147 *, qsize_t *);
	int (*get_next_id)(struct super_block___146 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___146 {
	int (*quota_on)(struct super_block___146 *, int, int, const struct path___146 *);
	int (*quota_off)(struct super_block___146 *, int);
	int (*quota_enable)(struct super_block___146 *, unsigned int);
	int (*quota_disable)(struct super_block___146 *, unsigned int);
	int (*quota_sync)(struct super_block___146 *, int);
	int (*set_info)(struct super_block___146 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___146 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___146 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___146 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___146 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___146 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___122 {
	struct kobject___141 kobj;
	struct module___125 *mod;
	struct kobject___141 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___122 {
	struct module___125 *mod;
	struct latch_tree_node node;
};

struct module_layout___122 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___122 mtn;
};

struct module_attribute___122;

struct kernel_param___122;

struct module___125 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___122 mkobj;
	struct module_attribute___122 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___141 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___122 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___122 core_layout;
	struct module_layout___122 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___83 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide43;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide44;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___64;

struct swap_info_struct___44;

struct address_space_operations___146 {
	int (*writepage)(struct page___147 *, struct writeback_control___64 *);
	int (*readpage)(struct file___147 *, struct page___147 *);
	int (*writepages)(struct address_space___146 *, struct writeback_control___64 *);
	int (*set_page_dirty)(struct page___147 *);
	int (*readpages)(struct file___147 *, struct address_space___146 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___147 *, struct address_space___146 *, loff_t, unsigned int, unsigned int, struct page___147 **, void **);
	int (*write_end)(struct file___147 *, struct address_space___146 *, loff_t, unsigned int, unsigned int, struct page___147 *, void *);
	sector_t (*bmap)(struct address_space___146 *, sector_t);
	void (*invalidatepage)(struct page___147 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___147 *, gfp_t);
	void (*freepage)(struct page___147 *);
	ssize_t (*direct_IO)(struct kiocb___147 *, struct iov_iter___66 *);
	int (*migratepage)(struct address_space___146 *, struct page___147 *, struct page___147 *, enum migrate_mode);
	bool (*isolate_page)(struct page___147 *, isolate_mode_t);
	void (*putback_page)(struct page___147 *);
	int (*launder_page)(struct page___147 *);
	int (*is_partially_uptodate)(struct page___147 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___147 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___146 *, struct page___147 *);
	int (*swap_activate)(struct swap_info_struct___44 *, struct file___147 *, sector_t *);
	void (*swap_deactivate)(struct file___147 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___64 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___67 *wb;
	struct inode___147 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___67;

struct iov_iter___66 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___67 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct swap_info_struct___44 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___147 *bdev;
	struct file___147 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct hd_struct___31;

struct gendisk___31;

struct block_device___147 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___147 *bd_inode;
	struct super_block___146 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___147 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___31 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___31 *bd_disk;
	struct request_queue___31 *bd_queue;
	struct backing_dev_info___67 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___137 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___137 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___137;

struct bus_type___137;

struct device_driver___137;

struct dev_pm_domain___137;

struct fwnode_handle___101;

struct class___137;

struct attribute_group___136;

struct device___137 {
	struct device___137 *parent;
	struct device_private *p;
	struct kobject___141 kobj;
	const char *init_name;
	const struct device_type___137 *type;
	struct mutex mutex;
	struct bus_type___137 *bus;
	struct device_driver___137 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___137 power;
	struct dev_pm_domain___137 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___101 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___137 *class;
	const struct attribute_group___136 **groups;
	void (*release)(struct device___137 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___31 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___137 __dev;
	struct kobject___141 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___31;

struct block_device_operations___31;

struct gendisk___31 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___31 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___31 *part_tbl;
	struct hd_struct___31 part0;
	const struct block_device_operations___31 *fops;
	struct request_queue___31 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___147 lookup_sem;
	struct kobject___141 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___141 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___146 {
	struct dentry___146 * (*lookup)(struct inode___147 *, struct dentry___146 *, unsigned int);
	const char * (*get_link)(struct dentry___146 *, struct inode___147 *, struct delayed_call *);
	int (*permission)(struct inode___147 *, int);
	struct posix_acl * (*get_acl)(struct inode___147 *, int);
	int (*readlink)(struct dentry___146 *, char *, int);
	int (*create)(struct inode___147 *, struct dentry___146 *, umode_t, bool);
	int (*link)(struct dentry___146 *, struct inode___147 *, struct dentry___146 *);
	int (*unlink)(struct inode___147 *, struct dentry___146 *);
	int (*symlink)(struct inode___147 *, struct dentry___146 *, const char *);
	int (*mkdir)(struct inode___147 *, struct dentry___146 *, umode_t);
	int (*rmdir)(struct inode___147 *, struct dentry___146 *);
	int (*mknod)(struct inode___147 *, struct dentry___146 *, umode_t, dev_t);
	int (*rename)(struct inode___147 *, struct dentry___146 *, struct inode___147 *, struct dentry___146 *, unsigned int);
	int (*setattr)(struct dentry___146 *, struct iattr___146 *);
	int (*getattr)(const struct path___146 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___146 *, char *, size_t);
	int (*fiemap)(struct inode___147 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___147 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___147 *, struct dentry___146 *, struct file___147 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___147 *, struct dentry___146 *, umode_t);
	int (*set_acl)(struct inode___147 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___146 {
	void (*fl_copy_lock)(struct file_lock___147 *, struct file_lock___147 *);
	void (*fl_release_private)(struct file_lock___147 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___146;

struct file_lock___147 {
	struct file_lock___147 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___147 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___146 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___146 *fl_ops;
	const struct lock_manager_operations___146 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___146 {
	int (*lm_compare_owner)(struct file_lock___147 *, struct file_lock___147 *);
	long unsigned int (*lm_owner_key)(struct file_lock___147 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___147 *);
	int (*lm_grant)(struct file_lock___147 *, int);
	bool (*lm_break)(struct file_lock___147 *);
	int (*lm_change)(struct file_lock___147 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___147 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___146 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___146 *fa_next;
	struct file___147 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___146 {
	const char *name;
	int fs_flags;
	struct dentry___146 * (*mount)(struct file_system_type___146 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___146 *);
	struct module___125 *owner;
	struct file_system_type___146 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___146 {
	struct inode___147 * (*alloc_inode)(struct super_block___146 *);
	void (*destroy_inode)(struct inode___147 *);
	void (*dirty_inode)(struct inode___147 *, int);
	int (*write_inode)(struct inode___147 *, struct writeback_control___64 *);
	int (*drop_inode)(struct inode___147 *);
	void (*evict_inode)(struct inode___147 *);
	void (*put_super)(struct super_block___146 *);
	int (*sync_fs)(struct super_block___146 *, int);
	int (*freeze_super)(struct super_block___146 *);
	int (*freeze_fs)(struct super_block___146 *);
	int (*thaw_super)(struct super_block___146 *);
	int (*unfreeze_fs)(struct super_block___146 *);
	int (*statfs)(struct dentry___146 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___146 *, int *, char *);
	void (*umount_begin)(struct super_block___146 *);
	int (*show_options)(struct seq_file___137 *, struct dentry___146 *);
	int (*show_devname)(struct seq_file___137 *, struct dentry___146 *);
	int (*show_path)(struct seq_file___137 *, struct dentry___146 *);
	int (*show_stats)(struct seq_file___137 *, struct dentry___146 *);
	ssize_t (*quota_read)(struct super_block___146 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___146 *, int, const char *, size_t, loff_t);
	struct dquot___146 ** (*get_dquots)(struct inode___147 *);
	int (*bdev_try_to_free_page)(struct super_block___146 *, struct page___147 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___146 *, struct shrink_control___62 *);
	long int (*free_cached_objects)(struct super_block___146 *, struct shrink_control___62 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct xattr_handler___10 {
	const char *name;
	const char *prefix;
	int flags;
	bool (*list)(struct dentry___146 *);
	int (*get)(const struct xattr_handler___10 *, struct dentry___146 *, struct inode___147 *, const char *, void *, size_t);
	int (*set)(const struct xattr_handler___10 *, struct dentry___146 *, struct inode___147 *, const char *, const void *, size_t, int);
};

typedef void (*poll_queue_proc___98)(struct file___147 *, wait_queue_head_t *, struct poll_table_struct___99 *);

struct poll_table_struct___99 {
	poll_queue_proc___98 _qproc;
	__poll_t _key;
};

struct seq_operations___135;

struct seq_file___137 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___135 *op;
	int poll_event;
	const struct file___147 *file;
	void *private;
};

typedef void bio_end_io_t___67(struct bio___67 *);

struct bio_vec___67 {
	struct page___147 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___67;

struct bio___67 {
	struct bio___67 *bi_next;
	struct gendisk___31 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___67 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___21 *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___67 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___67 *bi_io_vec;
	struct bio_set___67 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___67 bi_inline_vecs[0];
};

struct bio_integrity_payload___67 {
	struct bio___67 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___67 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___67 bip_inline_vecs[0];
};

struct blkcg___21;

struct blkg_policy_data___21;

struct blkcg_gq___21 {
	struct request_queue___31 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___21 *blkcg;
	struct bdi_writeback_congested___67 *wb_congested;
	struct blkcg_gq___21 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_rwstat stat_bytes;
	struct blkg_rwstat stat_ios;
	struct blkg_policy_data___21 *pd[5];
	struct callback_head callback_head;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
};

struct dev_pm_ops___137;

struct device_type___137 {
	const char *name;
	const struct attribute_group___136 **groups;
	int (*uevent)(struct device___137 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___137 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___137 *);
	const struct dev_pm_ops___137 *pm;
};

struct class___137 {
	const char *name;
	struct module___125 *owner;
	const struct attribute_group___136 **class_groups;
	const struct attribute_group___136 **dev_groups;
	struct kobject___141 *dev_kobj;
	int (*dev_uevent)(struct device___137 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___137 *, umode_t *);
	void (*class_release)(struct class___137 *);
	void (*dev_release)(struct device___137 *);
	int (*shutdown_pre)(struct device___137 *);
	const struct kobj_ns_type_operations___2 *ns_type;
	const void * (*namespace)(struct device___137 *);
	const struct dev_pm_ops___137 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct kernfs_root___143;

struct kernfs_elem_dir___143 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___143 *root;
};

struct kernfs_syscall_ops___143;

struct kernfs_root___143 {
	struct kernfs_node___143 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___143 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___143 {
	struct kernfs_node___143 *target_kn;
};

struct kernfs_ops___143;

struct kernfs_elem_attr___143 {
	const struct kernfs_ops___143 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___143 *notify_next;
};

struct kernfs_node___143 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___143 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___143 dir;
		struct kernfs_elem_symlink___143 symlink;
		struct kernfs_elem_attr___143 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___143;

struct kernfs_ops___143 {
	int (*open)(struct kernfs_open_file___143 *);
	void (*release)(struct kernfs_open_file___143 *);
	int (*seq_show)(struct seq_file___137 *, void *);
	void * (*seq_start)(struct seq_file___137 *, loff_t *);
	void * (*seq_next)(struct seq_file___137 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___137 *, void *);
	ssize_t (*read)(struct kernfs_open_file___143 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___143 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___143 *, struct vm_area_struct___147 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___143 *, struct poll_table_struct___99 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___143 {
	int (*remount_fs)(struct kernfs_root___143 *, int *, char *);
	int (*show_options)(struct seq_file___137 *, struct kernfs_root___143 *);
	int (*mkdir)(struct kernfs_node___143 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___143 *);
	int (*rename)(struct kernfs_node___143 *, struct kernfs_node___143 *, const char *);
	int (*show_path)(struct seq_file___137 *, struct kernfs_node___143 *, struct kernfs_root___143 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___143 {
	struct kernfs_node___143 *kn;
	struct file___147 *file;
	struct seq_file___137 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___144 *vm_ops;
};

struct bin_attribute___136;

struct attribute_group___136 {
	const char *name;
	umode_t (*is_visible)(struct kobject___141 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___141 *, struct bin_attribute___136 *, int);
	struct attribute **attrs;
	struct bin_attribute___136 **bin_attrs;
};

struct bin_attribute___136 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___147 *, struct kobject___141 *, struct bin_attribute___136 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___147 *, struct kobject___141 *, struct bin_attribute___136 *, char *, loff_t, size_t);
	int (*mmap)(struct file___147 *, struct kobject___141 *, struct bin_attribute___136 *, struct vm_area_struct___147 *);
};

struct sysfs_ops___140 {
	ssize_t (*show)(struct kobject___141 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___141 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___140;

struct kset___140 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___141 kobj;
	const struct kset_uevent_ops___140 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___140 {
	void (*release)(struct kobject___141 *);
	const struct sysfs_ops___140 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___2 * (*child_ns_type)(struct kobject___141 *);
	const void * (*namespace)(struct kobject___141 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___140 {
	int (* const filter)(struct kset___140 *, struct kobject___141 *);
	const char * (* const name)(struct kset___140 *, struct kobject___141 *);
	int (* const uevent)(struct kset___140 *, struct kobject___141 *, struct kobj_uevent_env *);
};

struct kobj_attribute___141 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___141 *, struct kobj_attribute___141 *, char *);
	ssize_t (*store)(struct kobject___141 *, struct kobj_attribute___141 *, const char *, size_t);
};

struct dev_pm_ops___137 {
	int (*prepare)(struct device___137 *);
	void (*complete)(struct device___137 *);
	int (*suspend)(struct device___137 *);
	int (*resume)(struct device___137 *);
	int (*freeze)(struct device___137 *);
	int (*thaw)(struct device___137 *);
	int (*poweroff)(struct device___137 *);
	int (*restore)(struct device___137 *);
	int (*suspend_late)(struct device___137 *);
	int (*resume_early)(struct device___137 *);
	int (*freeze_late)(struct device___137 *);
	int (*thaw_early)(struct device___137 *);
	int (*poweroff_late)(struct device___137 *);
	int (*restore_early)(struct device___137 *);
	int (*suspend_noirq)(struct device___137 *);
	int (*resume_noirq)(struct device___137 *);
	int (*freeze_noirq)(struct device___137 *);
	int (*thaw_noirq)(struct device___137 *);
	int (*poweroff_noirq)(struct device___137 *);
	int (*restore_noirq)(struct device___137 *);
	int (*runtime_suspend)(struct device___137 *);
	int (*runtime_resume)(struct device___137 *);
	int (*runtime_idle)(struct device___137 *);
};

struct dev_pm_domain___137 {
	struct dev_pm_ops___137 ops;
	void (*detach)(struct device___137 *, bool);
	int (*activate)(struct device___137 *);
	void (*sync)(struct device___137 *);
	void (*dismiss)(struct device___137 *);
};

struct bus_type___137 {
	const char *name;
	const char *dev_name;
	struct device___137 *dev_root;
	const struct attribute_group___136 **bus_groups;
	const struct attribute_group___136 **dev_groups;
	const struct attribute_group___136 **drv_groups;
	int (*match)(struct device___137 *, struct device_driver___137 *);
	int (*uevent)(struct device___137 *, struct kobj_uevent_env *);
	int (*probe)(struct device___137 *);
	int (*remove)(struct device___137 *);
	void (*shutdown)(struct device___137 *);
	int (*online)(struct device___137 *);
	int (*offline)(struct device___137 *);
	int (*suspend)(struct device___137 *, pm_message_t);
	int (*resume)(struct device___137 *);
	int (*num_vf)(struct device___137 *);
	int (*dma_configure)(struct device___137 *);
	const struct dev_pm_ops___137 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___137 {
	const char *name;
	struct bus_type___137 *bus;
	struct module___125 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___137 *);
	int (*remove)(struct device___137 *);
	void (*shutdown)(struct device___137 *);
	int (*suspend)(struct device___137 *, pm_message_t);
	int (*resume)(struct device___137 *);
	const struct attribute_group___136 **groups;
	const struct dev_pm_ops___137 *pm;
	void (*coredump)(struct device___137 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct fwnode_operations___101;

struct fwnode_handle___101 {
	struct fwnode_handle___101 *secondary;
	const struct fwnode_operations___101 *ops;
};

struct disk_part_tbl___31 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___31 *last_lookup;
	struct hd_struct___31 *part[0];
};

struct block_device_operations___31 {
	int (*open)(struct block_device___147 *, fmode_t);
	void (*release)(struct gendisk___31 *, fmode_t);
	int (*rw_page)(struct block_device___147 *, sector_t, struct page___147 *, unsigned int);
	int (*ioctl)(struct block_device___147 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___147 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___31 *, unsigned int);
	int (*media_changed)(struct gendisk___31 *);
	void (*unlock_native_capacity)(struct gendisk___31 *);
	int (*revalidate_disk)(struct gendisk___31 *);
	int (*getgeo)(struct block_device___147 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___147 *, long unsigned int);
	int (*report_zones)(struct gendisk___31 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___125 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___144(struct page___147 *);

struct vm_unmapped_area_info {
	long unsigned int flags;
	long unsigned int length;
	long unsigned int low_limit;
	long unsigned int high_limit;
	long unsigned int align_mask;
	long unsigned int align_offset;
};

struct bdi_writeback_congested___67 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___67 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bsg_ops___30 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___31 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___31 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___31 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___30(struct request___31 *, blk_status_t);

struct request___31 {
	struct request_queue___31 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___67 *bio;
	struct bio___67 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___67 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___33 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___30 *saved_end_io;
		} flush;
	};
	struct gendisk___31 *rq_disk;
	struct hd_struct___31 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___30 *end_io;
	void *end_io_data;
	struct request___31 *next_rq;
};

struct fwnode_reference_args___101;

struct fwnode_endpoint___101;

struct fwnode_operations___101 {
	struct fwnode_handle___101 * (*get)(struct fwnode_handle___101 *);
	void (*put)(struct fwnode_handle___101 *);
	bool (*device_is_available)(const struct fwnode_handle___101 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___101 *, const struct device___137 *);
	bool (*property_present)(const struct fwnode_handle___101 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___101 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___101 *, const char *, const char **, size_t);
	struct fwnode_handle___101 * (*get_parent)(const struct fwnode_handle___101 *);
	struct fwnode_handle___101 * (*get_next_child_node)(const struct fwnode_handle___101 *, struct fwnode_handle___101 *);
	struct fwnode_handle___101 * (*get_named_child_node)(const struct fwnode_handle___101 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___101 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___101 *);
	struct fwnode_handle___101 * (*graph_get_next_endpoint)(const struct fwnode_handle___101 *, struct fwnode_handle___101 *);
	struct fwnode_handle___101 * (*graph_get_remote_endpoint)(const struct fwnode_handle___101 *);
	struct fwnode_handle___101 * (*graph_get_port_parent)(struct fwnode_handle___101 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___101 *, struct fwnode_endpoint___101 *);
};

struct fwnode_endpoint___101 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___101 *local_fwnode;
};

struct fwnode_reference_args___101 {
	struct fwnode_handle___101 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct elevator_type___30;

struct elevator_mq_ops___30 {
	int (*init_sched)(struct request_queue___31 *, struct elevator_type___30 *);
	void (*exit_sched)(struct elevator_queue___30 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	bool (*allow_merge)(struct request_queue___31 *, struct request___31 *, struct bio___67 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx *, struct bio___67 *);
	int (*request_merge)(struct request_queue___31 *, struct request___31 **, struct bio___67 *);
	void (*request_merged)(struct request_queue___31 *, struct request___31 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___31 *, struct request___31 *, struct request___31 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___31 *, struct bio___67 *);
	void (*finish_request)(struct request___31 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___31 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___31 *, u64);
	void (*started_request)(struct request___31 *);
	void (*requeue_request)(struct request___31 *);
	struct request___31 * (*former_request)(struct request_queue___31 *, struct request___31 *);
	struct request___31 * (*next_request)(struct request_queue___31 *, struct request___31 *);
	void (*init_icq)(struct io_cq___33 *);
	void (*exit_icq)(struct io_cq___33 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___30;

struct elevator_type___30 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___30 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___30 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___125 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___30 {
	struct elevator_type___30 *type;
	void *elevator_data;
	struct kobject___141 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___30 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___30 *, char *);
	ssize_t (*store)(struct elevator_queue___30 *, const char *, size_t);
};

typedef int (*key_restrict_link_func_t___142)(struct key___142 *, const struct key_type *, const union key_payload *, struct key___142 *);

struct key_restriction___142;

struct key___142 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___147 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___142 *restrict_link;
};

struct key_restriction___142 {
	key_restrict_link_func_t___142 check;
	struct key___142 *key;
	struct key_type *keytype;
};

struct seq_operations___135 {
	void * (*start)(struct seq_file___137 *, loff_t *);
	void (*stop)(struct seq_file___137 *, void *);
	void * (*next)(struct seq_file___137 *, void *, loff_t *);
	int (*show)(struct seq_file___137 *, void *);
};

struct cgroup_namespace___123 {
	refcount_t count;
	struct ns_common___4 ns;
	struct user_namespace___127 *user_ns;
	struct ucounts___127 *ucounts;
	struct css_set___123 *root_cset;
};

struct ucounts___127 {
	struct hlist_node node;
	struct user_namespace___127 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___123;

struct bpf_map_ops___123 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___123 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___123 *, struct file___147 *);
	void (*map_free)(struct bpf_map___123 *);
	int (*map_get_next_key)(struct bpf_map___123 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___123 *);
	void * (*map_lookup_elem)(struct bpf_map___123 *, void *);
	int (*map_update_elem)(struct bpf_map___123 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___123 *, void *);
	int (*map_push_elem)(struct bpf_map___123 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___123 *, void *);
	int (*map_peek_elem)(struct bpf_map___123 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___123 *, struct file___147 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___123 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___123 *, void *, struct seq_file___137 *);
	int (*map_check_btf)(const struct bpf_map___123 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___123 {
	const struct bpf_map_ops___123 *ops;
	struct bpf_map___123 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___142 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___123;

typedef void (*kthread_work_func_t___123)(struct kthread_work___123 *);

struct kthread_worker___123;

struct kthread_work___123 {
	struct list_head node;
	kthread_work_func_t___123 func;
	struct kthread_worker___123 *worker;
	int canceling;
};

struct kthread_worker___123 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___147 *task;
	struct kthread_work___123 *current_work;
};

struct kthread_delayed_work___123 {
	struct kthread_work___123 work;
	struct timer_list timer;
};

struct psi_group___123 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___123 *poll_kworker;
	struct kthread_delayed_work___123 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___123;

struct cgroup_rstat_cpu___123;

struct cgroup___123 {
	struct cgroup_subsys_state___123 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___143 *kn;
	struct cgroup_file___123 procs_file;
	struct cgroup_file___123 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___123 *subsys[13];
	struct cgroup_root___123 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___123 *dom_cgrp;
	struct cgroup_rstat_cpu___123 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___4 bpf;
	atomic_t congestion_count;
	struct cgroup___123 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___123 psi;
	int ancestor_ids[0];
};

struct cftype___123;

struct cgroup_subsys___123 {
	struct cgroup_subsys_state___123 * (*css_alloc)(struct cgroup_subsys_state___123 *);
	int (*css_online)(struct cgroup_subsys_state___123 *);
	void (*css_offline)(struct cgroup_subsys_state___123 *);
	void (*css_released)(struct cgroup_subsys_state___123 *);
	void (*css_free)(struct cgroup_subsys_state___123 *);
	void (*css_reset)(struct cgroup_subsys_state___123 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___123 *, int);
	int (*css_extra_stat_show)(struct seq_file___137 *, struct cgroup_subsys_state___123 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___147 *);
	void (*cancel_fork)(struct task_struct___147 *);
	void (*fork)(struct task_struct___147 *);
	void (*exit)(struct task_struct___147 *);
	void (*free)(struct task_struct___147 *);
	void (*bind)(struct cgroup_subsys_state___123 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___123 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___123 *dfl_cftypes;
	struct cftype___123 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___123 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___123 *updated_children;
	struct cgroup___123 *updated_next;
};

struct cgroup_root___123 {
	struct kernfs_root___143 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___123 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___123 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___123 *ss;
	struct list_head node;
	struct kernfs_ops___143 *kf_ops;
	int (*open)(struct kernfs_open_file___143 *);
	void (*release)(struct kernfs_open_file___143 *);
	u64 (*read_u64)(struct cgroup_subsys_state___123 *, struct cftype___123 *);
	s64 (*read_s64)(struct cgroup_subsys_state___123 *, struct cftype___123 *);
	int (*seq_show)(struct seq_file___137 *, void *);
	void * (*seq_start)(struct seq_file___137 *, loff_t *);
	void * (*seq_next)(struct seq_file___137 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___137 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___123 *, struct cftype___123 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___123 *, struct cftype___123 *, s64);
	ssize_t (*write)(struct kernfs_open_file___143 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___143 *, struct poll_table_struct___99 *);
};

struct blkcg_policy_data___21;

struct blkcg___21 {
	struct cgroup_subsys_state___123 css;
	spinlock_t lock;
	struct xarray blkg_tree;
	struct blkcg_gq___21 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___21 *cpd[5];
	struct list_head all_blkcgs_node;
	struct list_head cgwb_list;
	refcount_t cgwb_refcnt;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct blkcg_policy_data___21 {
	struct blkcg___21 *blkcg;
	int plid;
};

struct blkg_policy_data___21 {
	struct blkcg_gq___21 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___62 {
	struct mem_cgroup___62 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___62 {
	struct lruvec___146 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___62 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___62 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct node___115 {
	struct device___137 dev;
};

struct kernel_param_ops___122 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___122 *);
	int (*get)(char *, const struct kernel_param___122 *);
	void (*free)(void *);
};

struct kparam_array___122;

struct kernel_param___122 {
	const char *name;
	struct module___125 *mod;
	const struct kernel_param_ops___122 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___122 *arr;
	};
};

struct kparam_array___122 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___122 *ops;
	void *elem;
};

struct module_attribute___122 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___122 *, struct module_kobject___122 *, char *);
	ssize_t (*store)(struct module_attribute___122 *, struct module_kobject___122 *, const char *, size_t);
	void (*setup)(struct module___125 *, const char *);
	int (*test)(struct module___125 *);
	void (*free)(struct module___125 *);
};

struct trace_event_class___83;

struct trace_event_call___83 {
	struct list_head list;
	struct trace_event_class___83 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___4 *prog_array;
	int (*perf_perm)(struct trace_event_call___83 *, struct perf_event___90 *);
};

struct perf_cpu_context___90;

struct pmu___90 {
	struct list_head entry;
	struct module___125 *module;
	struct device___137 *dev;
	const struct attribute_group___136 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___90 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___90 *);
	void (*pmu_disable)(struct pmu___90 *);
	int (*event_init)(struct perf_event___90 *);
	void (*event_mapped)(struct perf_event___90 *, struct mm_struct___146 *);
	void (*event_unmapped)(struct perf_event___90 *, struct mm_struct___146 *);
	int (*add)(struct perf_event___90 *, int);
	void (*del)(struct perf_event___90 *, int);
	void (*start)(struct perf_event___90 *, int);
	void (*stop)(struct perf_event___90 *, int);
	void (*read)(struct perf_event___90 *);
	void (*start_txn)(struct pmu___90 *, unsigned int);
	int (*commit_txn)(struct pmu___90 *);
	void (*cancel_txn)(struct pmu___90 *);
	int (*event_idx)(struct perf_event___90 *);
	void (*sched_task)(struct perf_event_context___90 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___90 *);
	int (*filter_match)(struct perf_event___90 *);
	int (*check_period)(struct perf_event___90 *, u64);
};

struct perf_cpu_context___90 {
	struct perf_event_context___90 ctx;
	struct perf_event_context___90 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___90 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___90 {
	struct cgroup_subsys_state___123 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___83 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___83 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___83 *);
	struct list_head * (*get_fields)(struct trace_event_call___83 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___83 *);
};

struct syscall_metadata___30 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___83 *enter_event;
	struct trace_event_call___83 *exit_event;
};

struct hstate___23;

struct hugepage_subpool___3 {
	spinlock_t lock;
	long int count;
	long int max_hpages;
	long int used_hpages;
	struct hstate___23 *hstate;
	long int min_hpages;
	long int rsv_hpages;
};

struct hstate___23 {
	int next_nid_to_alloc;
	int next_nid_to_free;
	unsigned int order;
	long unsigned int mask;
	long unsigned int max_huge_pages;
	long unsigned int nr_huge_pages;
	long unsigned int free_huge_pages;
	long unsigned int resv_huge_pages;
	long unsigned int surplus_huge_pages;
	long unsigned int nr_overcommit_huge_pages;
	struct list_head hugepage_activelist;
	struct list_head hugepage_freelists[8];
	unsigned int nr_huge_pages_node[8];
	unsigned int free_huge_pages_node[8];
	unsigned int surplus_huge_pages_node[8];
	struct cftype___123 cgroup_files[5];
	char name[32];
};

enum {
	HUGETLB_SHMFS_INODE = 1,
	HUGETLB_ANONHUGE_INODE = 2,
};

struct hugetlbfs_sb_info___3 {
	long int max_inodes;
	long int free_inodes;
	spinlock_t stat_lock;
	struct hstate___23 *hstate;
	struct hugepage_subpool___3 *spool;
	kuid_t uid;
	kgid_t gid;
	umode_t mode;
};

struct anon_vma_chain___2 {
	struct vm_area_struct___147 *vma;
	struct anon_vma___11 *anon_vma;
	struct list_head same_vma;
	struct rb_node rb;
	long unsigned int rb_subtree_last;
};

struct mmu_gather_batch___3 {
	struct mmu_gather_batch___3 *next;
	unsigned int nr;
	unsigned int max;
	struct page___147 *pages[0];
};

struct mmu_gather___3 {
	struct mm_struct___146 *mm;
	struct mmu_table_batch *batch;
	long unsigned int start;
	long unsigned int end;
	unsigned int fullmm: 1;
	unsigned int need_flush_all: 1;
	struct mmu_gather_batch___3 *active;
	struct mmu_gather_batch___3 local;
	struct page___147 *__pages[8];
	unsigned int batch_count;
	int page_size;
};

struct module___126;

struct file___148;

struct kiocb___148;

struct iov_iter___67;

struct poll_table_struct___100;

struct vm_area_struct___148;

struct inode___148;

struct file_lock___148;

struct page___148;

struct seq_file___138;

struct file_operations___148 {
	struct module___126 *owner;
	loff_t (*llseek)(struct file___148 *, loff_t, int);
	ssize_t (*read)(struct file___148 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___148 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___148 *, struct iov_iter___67 *);
	ssize_t (*write_iter)(struct kiocb___148 *, struct iov_iter___67 *);
	int (*iopoll)(struct kiocb___148 *, bool);
	int (*iterate)(struct file___148 *, struct dir_context *);
	int (*iterate_shared)(struct file___148 *, struct dir_context *);
	__poll_t (*poll)(struct file___148 *, struct poll_table_struct___100 *);
	long int (*unlocked_ioctl)(struct file___148 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___148 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___148 *, struct vm_area_struct___148 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___148 *, struct file___148 *);
	int (*flush)(struct file___148 *, fl_owner_t);
	int (*release)(struct inode___148 *, struct file___148 *);
	int (*fsync)(struct file___148 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___148 *, int);
	int (*lock)(struct file___148 *, int, struct file_lock___148 *);
	ssize_t (*sendpage)(struct file___148 *, struct page___148 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___148 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___148 *, int, struct file_lock___148 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___148 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___148 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___148 *, long int, struct file_lock___148 **, void **);
	long int (*fallocate)(struct file___148 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___138 *, struct file___148 *);
	ssize_t (*copy_file_range)(struct file___148 *, loff_t, struct file___148 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___148 *, loff_t, struct file___148 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___148 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___147 {
	u64 seqnum;
	struct vm_area_struct___148 *vmas[4];
};

struct page_frag___147 {
	struct page___148 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___91;

struct debug_info___91 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___91 *hbp_break[16];
	struct perf_event___91 *hbp_watch[16];
};

struct thread_struct___91 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___91 debug;
	long: 64;
};

struct mm_struct___147;

struct mem_cgroup___63;

struct pid___118;

struct cred___143;

struct nsproxy___140;

struct signal_struct___132;

struct bio_list___68;

struct backing_dev_info___68;

struct css_set___124;

struct perf_event_context___91;

struct task_struct___148 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___148 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___147 *mm;
	struct mm_struct___147 *active_mm;
	struct vmacache___147 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___148 *real_parent;
	struct task_struct___148 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___148 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___63 *active_memcg;
	long int rh_reserved2;
	struct pid___118 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___118 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___118 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___143 *ptracer_cred;
	const struct cred___143 *real_cred;
	const struct cred___143 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___140 *nsproxy;
	struct signal_struct___132 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___148 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___68 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___68 *backing_dev_info;
	struct io_context___33 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___124 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___91 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___147 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___63 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___148 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___91 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___91 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___148 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___91)(struct perf_event___91 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___91;

struct fasync_struct___147;

struct pid_namespace___118;

struct trace_event_call___84;

struct perf_cgroup___91;

struct perf_event___91 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___91 *group_leader;
	struct pmu___91 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___91 hw;
	struct perf_event_context___91 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___91 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___148 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___147 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___91 *);
	struct callback_head callback_head;
	struct pid_namespace___118 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___91 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___91 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___84 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___91 *cgrp;
	struct list_head sb_list;
};

typedef struct page___148 *pgtable_t___147;

struct address_space___147;

struct dev_pagemap___145;

struct page___148 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___147 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___148 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___147 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___147 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___145 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___63 *mem_cgroup;
};

struct pglist_data___147;

struct lruvec___147 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___147 *pgdat;
};

struct zone___147 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___147 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___147 {
	struct zone___147 *zone;
	int zone_idx;
};

struct zonelist___147 {
	struct zoneref___147 _zonerefs[25];
};

struct pglist_data___147 {
	struct zone___147 node_zones[3];
	struct zonelist___147 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___148 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___148 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___147 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___148 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___148 *owner;
};

struct secondary_data___148 {
	void *stack;
	struct task_struct___148 *task;
	long int status;
};

struct blocking_notifier_head___147 {
	struct rw_semaphore___148 rwsem;
	struct notifier_block *head;
};

struct anon_vma___12;

struct vm_operations_struct___145;

struct vm_area_struct___148 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___148 *vm_next;
	struct vm_area_struct___148 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___147 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma___12 *anon_vma;
	const struct vm_operations_struct___145 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___148 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___147;

struct user_namespace___128;

struct mm_struct___147 {
	struct {
		struct vm_area_struct___148 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___148 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___148 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___147 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___148 *owner;
		struct user_namespace___128 *user_ns;
		struct file___148 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___147 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___147;

struct address_space___147 {
	struct inode___148 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___148 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___147 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___145)(struct vm_area_struct___148 *, long unsigned int, const struct page___148 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___145)(struct page___148 *, void *);

struct device___138;

struct dev_pagemap___145 {
	dev_page_fault_t___145 page_fault;
	dev_page_free_t___145 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___138 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct cgroup___124;

struct cgroup_subsys___124;

struct cgroup_subsys_state___124 {
	struct cgroup___124 *cgroup;
	struct cgroup_subsys___124 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___124 *parent;
};

struct kernfs_node___144;

struct cgroup_file___124 {
	struct kernfs_node___144 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___63;

struct mem_cgroup___63 {
	struct cgroup_subsys_state___124 css;
	struct mem_cgroup_id___11 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___124 events_file;
	struct cgroup_file___124 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___148 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___63 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry___147;

struct path___147 {
	struct vfsmount *mnt;
	struct dentry___147 *dentry;
};

struct fown_struct___118 {
	rwlock_t lock;
	struct pid___118 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___148 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___147 f_path;
	struct inode___148 *f_inode;
	const struct file_operations___148 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___118 f_owner;
	const struct cred___143 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___147 *f_mapping;
	errseq_t f_wb_err;
};

struct anon_vma___12 {
	struct anon_vma___12 *root;
	struct rw_semaphore___148 rwsem;
	atomic_t refcount;
	unsigned int degree;
	struct anon_vma___12 *parent;
	struct rb_root_cached rb_root;
};

struct vm_fault___145;

struct vm_operations_struct___145 {
	void (*open)(struct vm_area_struct___148 *);
	void (*close)(struct vm_area_struct___148 *);
	int (*split)(struct vm_area_struct___148 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___148 *);
	vm_fault_t (*fault)(struct vm_fault___145 *);
	vm_fault_t (*huge_fault)(struct vm_fault___145 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___145 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___148 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___145 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___145 *);
	int (*access)(struct vm_area_struct___148 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___148 *);
	int (*set_policy)(struct vm_area_struct___148 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___148 *, long unsigned int);
	struct page___148 * (*find_special_page)(struct vm_area_struct___148 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___147 {
	struct task_struct___148 *task;
	struct core_thread___147 *next;
};

struct core_state___147 {
	atomic_t nr_threads;
	struct core_thread___147 dumper;
	struct completion startup;
};

struct key___143;

struct ucounts___128;

struct user_namespace___128 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___128 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___4 ns;
	long unsigned int flags;
	struct key___143 *persistent_keyring_register;
	struct rw_semaphore___148 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___128 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___145 {
	struct vm_area_struct___148 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___148 *cow_page;
	struct mem_cgroup___63 *memcg;
	struct page___148 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___147 prealloc_pte;
};

struct shrink_control___63 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___63 *memcg;
};

struct shrinker___63 {
	long unsigned int (*count_objects)(struct shrinker___63 *, struct shrink_control___63 *);
	long unsigned int (*scan_objects)(struct shrinker___63 *, struct shrink_control___63 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct upid___118 {
	int nr;
	struct pid_namespace___118 *ns;
};

struct pid_namespace___118 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___148 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___118 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___147 *proc_self;
	struct dentry___147 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___128 *user_ns;
	struct ucounts___128 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___4 ns;
};

struct pid___118 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___118 numbers[1];
};

struct user_struct___143 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___143 *uid_keyring;
	struct key___143 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___143 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___143 *session_keyring;
	struct key___143 *process_keyring;
	struct key___143 *thread_keyring;
	struct key___143 *request_key_auth;
	void *security;
	struct user_struct___143 *user;
	struct user_namespace___128 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___124;

struct nsproxy___140 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___118 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___124 *cgroup_ns;
};

struct signal_struct___132 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___148 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___148 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___118 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___118 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___147 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___118 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___68;

struct bio_list___68 {
	struct bio___68 *head;
	struct bio___68 *tail;
};

struct bdi_writeback_congested___68;

struct bdi_writeback___68 {
	struct backing_dev_info___68 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___68 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___124 *memcg_css;
	struct cgroup_subsys_state___124 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___68 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___68 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___138 *dev;
	struct device___138 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___147 *debug_dir;
	struct dentry___147 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___124 {
	struct cgroup_subsys_state___124 *subsys[13];
	refcount_t refcount;
	struct css_set___124 *dom_cset;
	struct cgroup___124 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___124 *mg_src_cgrp;
	struct cgroup___124 *mg_dst_cgrp;
	struct css_set___124 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___91 {
	struct pmu___91 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___148 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___91 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

union thread_union___132 {
	struct task_struct___148 task;
	long unsigned int stack[8192];
};

struct kset___141;

struct kobj_type___141;

struct kobject___142 {
	const char *name;
	struct list_head entry;
	struct kobject___142 *parent;
	struct kset___141 *kset;
	struct kobj_type___141 *ktype;
	struct kernfs_node___144 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___138 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___138 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___138;

struct bus_type___138;

struct device_driver___138;

struct dev_pm_domain___138;

struct class___138;

struct attribute_group___137;

struct device___138 {
	struct device___138 *parent;
	struct device_private *p;
	struct kobject___142 kobj;
	const char *init_name;
	const struct device_type___138 *type;
	struct mutex mutex;
	struct bus_type___138 *bus;
	struct device_driver___138 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___138 power;
	struct dev_pm_domain___138 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___138 *class;
	const struct attribute_group___137 **groups;
	void (*release)(struct device___138 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___147;

struct super_block___147;

struct dentry___147 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___147 *d_parent;
	struct qstr d_name;
	struct inode___148 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___147 *d_op;
	struct super_block___147 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___147;

struct block_device___148;

struct inode___148 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___147 *i_op;
	struct super_block___147 *i_sb;
	struct address_space___147 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___148 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___68 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___148 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___147 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___148 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___147 {
	int (*d_revalidate)(struct dentry___147 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___147 *, unsigned int);
	int (*d_hash)(const struct dentry___147 *, struct qstr *);
	int (*d_compare)(const struct dentry___147 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___147 *);
	int (*d_init)(struct dentry___147 *);
	void (*d_release)(struct dentry___147 *);
	void (*d_prune)(struct dentry___147 *);
	void (*d_iput)(struct dentry___147 *, struct inode___148 *);
	char * (*d_dname)(struct dentry___147 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___147 *);
	int (*d_manage)(const struct path___147 *, bool);
	struct dentry___147 * (*d_real)(struct dentry___147 *, const struct inode___148 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___147;

struct mem_dqinfo___147 {
	struct quota_format_type___147 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___147;

struct quota_info___147 {
	unsigned int flags;
	struct rw_semaphore___148 dqio_sem;
	struct inode___148 *files[3];
	struct mem_dqinfo___147 info[3];
	const struct quota_format_ops___147 *ops[3];
};

struct rcuwait___147 {
	struct task_struct___148 *task;
};

struct percpu_rw_semaphore___147 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___148 rw_sem;
	struct rcuwait___147 writer;
	int readers_block;
};

struct sb_writers___147 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___147 rw_sem[3];
};

struct file_system_type___147;

struct super_operations___147;

struct dquot_operations___147;

struct quotactl_ops___147;

struct super_block___147 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___147 *s_type;
	const struct super_operations___147 *s_op;
	const struct dquot_operations___147 *dq_op;
	const struct quotactl_ops___147 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___147 *s_root;
	struct rw_semaphore___148 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___148 *s_bdev;
	struct backing_dev_info___68 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___147 s_dquot;
	struct sb_writers___147 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___147 *s_d_op;
	int cleancache_poolid;
	struct shrinker___63 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___128 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___148 {
	struct file___148 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___148 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___147 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___148 *ia_file;
};

struct dquot___147 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___147 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___147 {
	int qf_fmt_id;
	const struct quota_format_ops___147 *qf_ops;
	struct module___126 *qf_owner;
	struct quota_format_type___147 *qf_next;
};

struct quota_format_ops___147 {
	int (*check_quota_file)(struct super_block___147 *, int);
	int (*read_file_info)(struct super_block___147 *, int);
	int (*write_file_info)(struct super_block___147 *, int);
	int (*free_file_info)(struct super_block___147 *, int);
	int (*read_dqblk)(struct dquot___147 *);
	int (*commit_dqblk)(struct dquot___147 *);
	int (*release_dqblk)(struct dquot___147 *);
	int (*get_next_id)(struct super_block___147 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___147 {
	int (*write_dquot)(struct dquot___147 *);
	struct dquot___147 * (*alloc_dquot)(struct super_block___147 *, int);
	void (*destroy_dquot)(struct dquot___147 *);
	int (*acquire_dquot)(struct dquot___147 *);
	int (*release_dquot)(struct dquot___147 *);
	int (*mark_dirty)(struct dquot___147 *);
	int (*write_info)(struct super_block___147 *, int);
	qsize_t * (*get_reserved_space)(struct inode___148 *);
	int (*get_projid)(struct inode___148 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___148 *, qsize_t *);
	int (*get_next_id)(struct super_block___147 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___147 {
	int (*quota_on)(struct super_block___147 *, int, int, const struct path___147 *);
	int (*quota_off)(struct super_block___147 *, int);
	int (*quota_enable)(struct super_block___147 *, unsigned int);
	int (*quota_disable)(struct super_block___147 *, unsigned int);
	int (*quota_sync)(struct super_block___147 *, int);
	int (*set_info)(struct super_block___147 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___147 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___147 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___147 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___147 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___147 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___123 {
	struct kobject___142 kobj;
	struct module___126 *mod;
	struct kobject___142 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___123 {
	struct module___126 *mod;
	struct latch_tree_node node;
};

struct module_layout___123 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___123 mtn;
};

struct module_attribute___123;

struct kernel_param___123;

struct module___126 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___123 mkobj;
	struct module_attribute___123 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___142 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___123 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___123 core_layout;
	struct module_layout___123 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___84 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___65;

struct swap_info_struct___45;

struct address_space_operations___147 {
	int (*writepage)(struct page___148 *, struct writeback_control___65 *);
	int (*readpage)(struct file___148 *, struct page___148 *);
	int (*writepages)(struct address_space___147 *, struct writeback_control___65 *);
	int (*set_page_dirty)(struct page___148 *);
	int (*readpages)(struct file___148 *, struct address_space___147 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___148 *, struct address_space___147 *, loff_t, unsigned int, unsigned int, struct page___148 **, void **);
	int (*write_end)(struct file___148 *, struct address_space___147 *, loff_t, unsigned int, unsigned int, struct page___148 *, void *);
	sector_t (*bmap)(struct address_space___147 *, sector_t);
	void (*invalidatepage)(struct page___148 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___148 *, gfp_t);
	void (*freepage)(struct page___148 *);
	ssize_t (*direct_IO)(struct kiocb___148 *, struct iov_iter___67 *);
	int (*migratepage)(struct address_space___147 *, struct page___148 *, struct page___148 *, enum migrate_mode);
	bool (*isolate_page)(struct page___148 *, isolate_mode_t);
	void (*putback_page)(struct page___148 *);
	int (*launder_page)(struct page___148 *);
	int (*is_partially_uptodate)(struct page___148 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___148 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___147 *, struct page___148 *);
	int (*swap_activate)(struct swap_info_struct___45 *, struct file___148 *, sector_t *);
	void (*swap_deactivate)(struct file___148 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___65 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___68 *wb;
	struct inode___148 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___68;

struct iov_iter___67 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___68 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct swap_info_struct___45 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___148 *bdev;
	struct file___148 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___148 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___148 *bd_inode;
	struct super_block___147 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___148 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___68 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___147 {
	struct dentry___147 * (*lookup)(struct inode___148 *, struct dentry___147 *, unsigned int);
	const char * (*get_link)(struct dentry___147 *, struct inode___148 *, struct delayed_call *);
	int (*permission)(struct inode___148 *, int);
	struct posix_acl * (*get_acl)(struct inode___148 *, int);
	int (*readlink)(struct dentry___147 *, char *, int);
	int (*create)(struct inode___148 *, struct dentry___147 *, umode_t, bool);
	int (*link)(struct dentry___147 *, struct inode___148 *, struct dentry___147 *);
	int (*unlink)(struct inode___148 *, struct dentry___147 *);
	int (*symlink)(struct inode___148 *, struct dentry___147 *, const char *);
	int (*mkdir)(struct inode___148 *, struct dentry___147 *, umode_t);
	int (*rmdir)(struct inode___148 *, struct dentry___147 *);
	int (*mknod)(struct inode___148 *, struct dentry___147 *, umode_t, dev_t);
	int (*rename)(struct inode___148 *, struct dentry___147 *, struct inode___148 *, struct dentry___147 *, unsigned int);
	int (*setattr)(struct dentry___147 *, struct iattr___147 *);
	int (*getattr)(const struct path___147 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___147 *, char *, size_t);
	int (*fiemap)(struct inode___148 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___148 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___148 *, struct dentry___147 *, struct file___148 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___148 *, struct dentry___147 *, umode_t);
	int (*set_acl)(struct inode___148 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___147 {
	void (*fl_copy_lock)(struct file_lock___148 *, struct file_lock___148 *);
	void (*fl_release_private)(struct file_lock___148 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___147;

struct file_lock___148 {
	struct file_lock___148 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___148 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___147 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___147 *fl_ops;
	const struct lock_manager_operations___147 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___147 {
	int (*lm_compare_owner)(struct file_lock___148 *, struct file_lock___148 *);
	long unsigned int (*lm_owner_key)(struct file_lock___148 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___148 *);
	int (*lm_grant)(struct file_lock___148 *, int);
	bool (*lm_break)(struct file_lock___148 *);
	int (*lm_change)(struct file_lock___148 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___148 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___147 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___147 *fa_next;
	struct file___148 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___147 {
	const char *name;
	int fs_flags;
	struct dentry___147 * (*mount)(struct file_system_type___147 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___147 *);
	struct module___126 *owner;
	struct file_system_type___147 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___147 {
	struct inode___148 * (*alloc_inode)(struct super_block___147 *);
	void (*destroy_inode)(struct inode___148 *);
	void (*dirty_inode)(struct inode___148 *, int);
	int (*write_inode)(struct inode___148 *, struct writeback_control___65 *);
	int (*drop_inode)(struct inode___148 *);
	void (*evict_inode)(struct inode___148 *);
	void (*put_super)(struct super_block___147 *);
	int (*sync_fs)(struct super_block___147 *, int);
	int (*freeze_super)(struct super_block___147 *);
	int (*freeze_fs)(struct super_block___147 *);
	int (*thaw_super)(struct super_block___147 *);
	int (*unfreeze_fs)(struct super_block___147 *);
	int (*statfs)(struct dentry___147 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___147 *, int *, char *);
	void (*umount_begin)(struct super_block___147 *);
	int (*show_options)(struct seq_file___138 *, struct dentry___147 *);
	int (*show_devname)(struct seq_file___138 *, struct dentry___147 *);
	int (*show_path)(struct seq_file___138 *, struct dentry___147 *);
	int (*show_stats)(struct seq_file___138 *, struct dentry___147 *);
	ssize_t (*quota_read)(struct super_block___147 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___147 *, int, const char *, size_t, loff_t);
	struct dquot___147 ** (*get_dquots)(struct inode___148 *);
	int (*bdev_try_to_free_page)(struct super_block___147 *, struct page___148 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___147 *, struct shrink_control___63 *);
	long int (*free_cached_objects)(struct super_block___147 *, struct shrink_control___63 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___99)(struct file___148 *, wait_queue_head_t *, struct poll_table_struct___100 *);

struct poll_table_struct___100 {
	poll_queue_proc___99 _qproc;
	__poll_t _key;
};

struct seq_operations___136;

struct seq_file___138 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___136 *op;
	int poll_event;
	const struct file___148 *file;
	void *private;
};

typedef void bio_end_io_t___68(struct bio___68 *);

struct bio_vec___68 {
	struct page___148 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___68;

struct bio_set___68;

struct bio___68 {
	struct bio___68 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___68 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___68 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___68 *bi_io_vec;
	struct bio_set___68 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___68 bi_inline_vecs[0];
};

struct kobj_attribute___142 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___142 *, struct kobj_attribute___142 *, char *);
	ssize_t (*store)(struct kobject___142 *, struct kobj_attribute___142 *, const char *, size_t);
};

typedef void compound_page_dtor___145(struct page___148 *);

struct mm_walk___2 {
	int (*pud_entry)(pud_t *, long unsigned int, long unsigned int, struct mm_walk___2 *);
	int (*pmd_entry)(pmd_t *, long unsigned int, long unsigned int, struct mm_walk___2 *);
	int (*pte_entry)(pte_t *, long unsigned int, long unsigned int, struct mm_walk___2 *);
	int (*pte_hole)(long unsigned int, long unsigned int, struct mm_walk___2 *);
	int (*hugetlb_entry)(pte_t *, long unsigned int, long unsigned int, long unsigned int, struct mm_walk___2 *);
	int (*test_walk)(long unsigned int, long unsigned int, struct mm_walk___2 *);
	struct mm_struct___147 *mm;
	struct vm_area_struct___148 *vma;
	void *private;
};

typedef int (*key_restrict_link_func_t___143)(struct key___143 *, const struct key_type *, const union key_payload *, struct key___143 *);

struct key_restriction___143;

struct key___143 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___148 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___143 *restrict_link;
};

struct key_restriction___143 {
	key_restrict_link_func_t___143 check;
	struct key___143 *key;
	struct key_type *keytype;
};

struct seq_operations___136 {
	void * (*start)(struct seq_file___138 *, loff_t *);
	void (*stop)(struct seq_file___138 *, void *);
	void * (*next)(struct seq_file___138 *, void *, loff_t *);
	int (*show)(struct seq_file___138 *, void *);
};

struct kernfs_root___144;

struct kernfs_elem_dir___144 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___144 *root;
};

struct kernfs_syscall_ops___144;

struct kernfs_root___144 {
	struct kernfs_node___144 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___144 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___144 {
	struct kernfs_node___144 *target_kn;
};

struct kernfs_ops___144;

struct kernfs_elem_attr___144 {
	const struct kernfs_ops___144 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___144 *notify_next;
};

struct kernfs_node___144 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___144 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___144 dir;
		struct kernfs_elem_symlink___144 symlink;
		struct kernfs_elem_attr___144 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___144;

struct kernfs_ops___144 {
	int (*open)(struct kernfs_open_file___144 *);
	void (*release)(struct kernfs_open_file___144 *);
	int (*seq_show)(struct seq_file___138 *, void *);
	void * (*seq_start)(struct seq_file___138 *, loff_t *);
	void * (*seq_next)(struct seq_file___138 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___138 *, void *);
	ssize_t (*read)(struct kernfs_open_file___144 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___144 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___144 *, struct vm_area_struct___148 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___144 *, struct poll_table_struct___100 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___144 {
	int (*remount_fs)(struct kernfs_root___144 *, int *, char *);
	int (*show_options)(struct seq_file___138 *, struct kernfs_root___144 *);
	int (*mkdir)(struct kernfs_node___144 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___144 *);
	int (*rename)(struct kernfs_node___144 *, struct kernfs_node___144 *, const char *);
	int (*show_path)(struct seq_file___138 *, struct kernfs_node___144 *, struct kernfs_root___144 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___144 {
	struct kernfs_node___144 *kn;
	struct file___148 *file;
	struct seq_file___138 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___145 *vm_ops;
};

struct cgroup_namespace___124 {
	refcount_t count;
	struct ns_common___4 ns;
	struct user_namespace___128 *user_ns;
	struct ucounts___128 *ucounts;
	struct css_set___124 *root_cset;
};

struct ucounts___128 {
	struct hlist_node node;
	struct user_namespace___128 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___124;

struct bpf_map_ops___124 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___124 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___124 *, struct file___148 *);
	void (*map_free)(struct bpf_map___124 *);
	int (*map_get_next_key)(struct bpf_map___124 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___124 *);
	void * (*map_lookup_elem)(struct bpf_map___124 *, void *);
	int (*map_update_elem)(struct bpf_map___124 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___124 *, void *);
	int (*map_push_elem)(struct bpf_map___124 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___124 *, void *);
	int (*map_peek_elem)(struct bpf_map___124 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___124 *, struct file___148 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___124 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___124 *, void *, struct seq_file___138 *);
	int (*map_check_btf)(const struct bpf_map___124 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___124 {
	const struct bpf_map_ops___124 *ops;
	struct bpf_map___124 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___143 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___124;

typedef void (*kthread_work_func_t___124)(struct kthread_work___124 *);

struct kthread_worker___124;

struct kthread_work___124 {
	struct list_head node;
	kthread_work_func_t___124 func;
	struct kthread_worker___124 *worker;
	int canceling;
};

struct kthread_worker___124 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___148 *task;
	struct kthread_work___124 *current_work;
};

struct kthread_delayed_work___124 {
	struct kthread_work___124 work;
	struct timer_list timer;
};

struct psi_group___124 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___124 *poll_kworker;
	struct kthread_delayed_work___124 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___124;

struct cgroup_rstat_cpu___124;

struct cgroup___124 {
	struct cgroup_subsys_state___124 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___144 *kn;
	struct cgroup_file___124 procs_file;
	struct cgroup_file___124 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___124 *subsys[13];
	struct cgroup_root___124 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___124 *dom_cgrp;
	struct cgroup_rstat_cpu___124 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___4 bpf;
	atomic_t congestion_count;
	struct cgroup___124 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___124 psi;
	int ancestor_ids[0];
};

struct cftype___124;

struct cgroup_subsys___124 {
	struct cgroup_subsys_state___124 * (*css_alloc)(struct cgroup_subsys_state___124 *);
	int (*css_online)(struct cgroup_subsys_state___124 *);
	void (*css_offline)(struct cgroup_subsys_state___124 *);
	void (*css_released)(struct cgroup_subsys_state___124 *);
	void (*css_free)(struct cgroup_subsys_state___124 *);
	void (*css_reset)(struct cgroup_subsys_state___124 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___124 *, int);
	int (*css_extra_stat_show)(struct seq_file___138 *, struct cgroup_subsys_state___124 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___148 *);
	void (*cancel_fork)(struct task_struct___148 *);
	void (*fork)(struct task_struct___148 *);
	void (*exit)(struct task_struct___148 *);
	void (*free)(struct task_struct___148 *);
	void (*bind)(struct cgroup_subsys_state___124 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___124 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___124 *dfl_cftypes;
	struct cftype___124 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___124 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___124 *updated_children;
	struct cgroup___124 *updated_next;
};

struct cgroup_root___124 {
	struct kernfs_root___144 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___124 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___124 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___124 *ss;
	struct list_head node;
	struct kernfs_ops___144 *kf_ops;
	int (*open)(struct kernfs_open_file___144 *);
	void (*release)(struct kernfs_open_file___144 *);
	u64 (*read_u64)(struct cgroup_subsys_state___124 *, struct cftype___124 *);
	s64 (*read_s64)(struct cgroup_subsys_state___124 *, struct cftype___124 *);
	int (*seq_show)(struct seq_file___138 *, void *);
	void * (*seq_start)(struct seq_file___138 *, loff_t *);
	void * (*seq_next)(struct seq_file___138 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___138 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___124 *, struct cftype___124 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___124 *, struct cftype___124 *, s64);
	ssize_t (*write)(struct kernfs_open_file___144 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___144 *, struct poll_table_struct___100 *);
};

struct bin_attribute___137;

struct attribute_group___137 {
	const char *name;
	umode_t (*is_visible)(struct kobject___142 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___142 *, struct bin_attribute___137 *, int);
	struct attribute **attrs;
	struct bin_attribute___137 **bin_attrs;
};

struct hstate___24 {
	int next_nid_to_alloc;
	int next_nid_to_free;
	unsigned int order;
	long unsigned int mask;
	long unsigned int max_huge_pages;
	long unsigned int nr_huge_pages;
	long unsigned int free_huge_pages;
	long unsigned int resv_huge_pages;
	long unsigned int surplus_huge_pages;
	long unsigned int nr_overcommit_huge_pages;
	struct list_head hugepage_activelist;
	struct list_head hugepage_freelists[8];
	unsigned int nr_huge_pages_node[8];
	unsigned int free_huge_pages_node[8];
	unsigned int surplus_huge_pages_node[8];
	struct cftype___124 cgroup_files[5];
	char name[32];
};

struct bin_attribute___137 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___148 *, struct kobject___142 *, struct bin_attribute___137 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___148 *, struct kobject___142 *, struct bin_attribute___137 *, char *, loff_t, size_t);
	int (*mmap)(struct file___148 *, struct kobject___142 *, struct bin_attribute___137 *, struct vm_area_struct___148 *);
};

struct sysfs_ops___141 {
	ssize_t (*show)(struct kobject___142 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___142 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___141;

struct kset___141 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___142 kobj;
	const struct kset_uevent_ops___141 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___141 {
	void (*release)(struct kobject___142 *);
	const struct sysfs_ops___141 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___2 * (*child_ns_type)(struct kobject___142 *);
	const void * (*namespace)(struct kobject___142 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___141 {
	int (* const filter)(struct kset___141 *, struct kobject___142 *);
	const char * (* const name)(struct kset___141 *, struct kobject___142 *);
	int (* const uevent)(struct kset___141 *, struct kobject___142 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___123 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___123 *);
	int (*get)(char *, const struct kernel_param___123 *);
	void (*free)(void *);
};

struct kparam_array___123;

struct kernel_param___123 {
	const char *name;
	struct module___126 *mod;
	const struct kernel_param_ops___123 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___123 *arr;
	};
};

struct kparam_array___123 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___123 *ops;
	void *elem;
};

struct module_attribute___123 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___123 *, struct module_kobject___123 *, char *);
	ssize_t (*store)(struct module_attribute___123 *, struct module_kobject___123 *, const char *, size_t);
	void (*setup)(struct module___126 *, const char *);
	int (*test)(struct module___126 *);
	void (*free)(struct module___126 *);
};

struct trace_event_class___84;

struct trace_event_call___84 {
	struct list_head list;
	struct trace_event_class___84 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___4 *prog_array;
	int (*perf_perm)(struct trace_event_call___84 *, struct perf_event___91 *);
};

struct dev_pm_ops___138 {
	int (*prepare)(struct device___138 *);
	void (*complete)(struct device___138 *);
	int (*suspend)(struct device___138 *);
	int (*resume)(struct device___138 *);
	int (*freeze)(struct device___138 *);
	int (*thaw)(struct device___138 *);
	int (*poweroff)(struct device___138 *);
	int (*restore)(struct device___138 *);
	int (*suspend_late)(struct device___138 *);
	int (*resume_early)(struct device___138 *);
	int (*freeze_late)(struct device___138 *);
	int (*thaw_early)(struct device___138 *);
	int (*poweroff_late)(struct device___138 *);
	int (*restore_early)(struct device___138 *);
	int (*suspend_noirq)(struct device___138 *);
	int (*resume_noirq)(struct device___138 *);
	int (*freeze_noirq)(struct device___138 *);
	int (*thaw_noirq)(struct device___138 *);
	int (*poweroff_noirq)(struct device___138 *);
	int (*restore_noirq)(struct device___138 *);
	int (*runtime_suspend)(struct device___138 *);
	int (*runtime_resume)(struct device___138 *);
	int (*runtime_idle)(struct device___138 *);
};

struct dev_pm_domain___138 {
	struct dev_pm_ops___138 ops;
	void (*detach)(struct device___138 *, bool);
	int (*activate)(struct device___138 *);
	void (*sync)(struct device___138 *);
	void (*dismiss)(struct device___138 *);
};

struct bus_type___138 {
	const char *name;
	const char *dev_name;
	struct device___138 *dev_root;
	const struct attribute_group___137 **bus_groups;
	const struct attribute_group___137 **dev_groups;
	const struct attribute_group___137 **drv_groups;
	int (*match)(struct device___138 *, struct device_driver___138 *);
	int (*uevent)(struct device___138 *, struct kobj_uevent_env *);
	int (*probe)(struct device___138 *);
	int (*remove)(struct device___138 *);
	void (*shutdown)(struct device___138 *);
	int (*online)(struct device___138 *);
	int (*offline)(struct device___138 *);
	int (*suspend)(struct device___138 *, pm_message_t);
	int (*resume)(struct device___138 *);
	int (*num_vf)(struct device___138 *);
	int (*dma_configure)(struct device___138 *);
	const struct dev_pm_ops___138 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___138 {
	const char *name;
	struct bus_type___138 *bus;
	struct module___126 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___138 *);
	int (*remove)(struct device___138 *);
	void (*shutdown)(struct device___138 *);
	int (*suspend)(struct device___138 *, pm_message_t);
	int (*resume)(struct device___138 *);
	const struct attribute_group___137 **groups;
	const struct dev_pm_ops___138 *pm;
	void (*coredump)(struct device___138 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___138 {
	const char *name;
	const struct attribute_group___137 **groups;
	int (*uevent)(struct device___138 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___138 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___138 *);
	const struct dev_pm_ops___138 *pm;
};

struct class___138 {
	const char *name;
	struct module___126 *owner;
	const struct attribute_group___137 **class_groups;
	const struct attribute_group___137 **dev_groups;
	struct kobject___142 *dev_kobj;
	int (*dev_uevent)(struct device___138 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___138 *, umode_t *);
	void (*class_release)(struct class___138 *);
	void (*dev_release)(struct device___138 *);
	int (*shutdown_pre)(struct device___138 *);
	const struct kobj_ns_type_operations___2 *ns_type;
	const void * (*namespace)(struct device___138 *);
	const struct dev_pm_ops___138 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___116 {
	struct device___138 dev;
};

struct perf_cpu_context___91;

struct pmu___91 {
	struct list_head entry;
	struct module___126 *module;
	struct device___138 *dev;
	const struct attribute_group___137 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___91 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___91 *);
	void (*pmu_disable)(struct pmu___91 *);
	int (*event_init)(struct perf_event___91 *);
	void (*event_mapped)(struct perf_event___91 *, struct mm_struct___147 *);
	void (*event_unmapped)(struct perf_event___91 *, struct mm_struct___147 *);
	int (*add)(struct perf_event___91 *, int);
	void (*del)(struct perf_event___91 *, int);
	void (*start)(struct perf_event___91 *, int);
	void (*stop)(struct perf_event___91 *, int);
	void (*read)(struct perf_event___91 *);
	void (*start_txn)(struct pmu___91 *, unsigned int);
	int (*commit_txn)(struct pmu___91 *);
	void (*cancel_txn)(struct pmu___91 *);
	int (*event_idx)(struct perf_event___91 *);
	void (*sched_task)(struct perf_event_context___91 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___91 *);
	int (*filter_match)(struct perf_event___91 *);
	int (*check_period)(struct perf_event___91 *, u64);
};

struct perf_cpu_context___91 {
	struct perf_event_context___91 ctx;
	struct perf_event_context___91 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___91 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___91 {
	struct cgroup_subsys_state___124 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___84 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___84 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___84 *);
	struct list_head * (*get_fields)(struct trace_event_call___84 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___84 *);
};

struct syscall_metadata___31 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___84 *enter_event;
	struct trace_event_call___84 *exit_event;
};

struct bdi_writeback_congested___68 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___68 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___68 {
	struct bio___68 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___68 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___68 bip_inline_vecs[0];
};

struct bio_set___68 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___68 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___63 {
	struct mem_cgroup___63 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___63 {
	struct lruvec___147 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___63 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___63 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct attribute_group___138;

struct page_vma_mapped_walk___2 {
	struct page___131 *page;
	struct vm_area_struct___131 *vma;
	long unsigned int address;
	pmd_t *pmd;
	pte_t *pte;
	spinlock_t *ptl;
	unsigned int flags;
};

struct rmap_walk_control {
	void *arg;
	bool (*rmap_one)(struct page___131 *, struct vm_area_struct___131 *, long unsigned int, void *);
	int (*done)(struct page___131 *);
	struct anon_vma___5 * (*anon_lock)(struct page___131 *);
	bool (*invalid_vma)(struct vm_area_struct___131 *, void *);
};

struct hstate___25 {
	int next_nid_to_alloc;
	int next_nid_to_free;
	unsigned int order;
	long unsigned int mask;
	long unsigned int max_huge_pages;
	long unsigned int nr_huge_pages;
	long unsigned int free_huge_pages;
	long unsigned int resv_huge_pages;
	long unsigned int surplus_huge_pages;
	long unsigned int nr_overcommit_huge_pages;
	struct list_head hugepage_activelist;
	struct list_head hugepage_freelists[8];
	unsigned int nr_huge_pages_node[8];
	unsigned int free_huge_pages_node[8];
	unsigned int surplus_huge_pages_node[8];
	struct cftype___107 cgroup_files[5];
	char name[32];
};

struct page_referenced_arg {
	int mapcount;
	int referenced;
	long unsigned int vm_flags;
	struct mem_cgroup___47 *memcg;
};

struct vmap_area {
	long unsigned int va_start;
	long unsigned int va_end;
	long unsigned int flags;
	struct rb_node rb_node;
	struct list_head list;
	struct llist_node purge_list;
	struct vm_struct___36 *vm;
	struct callback_head callback_head;
};

struct vfree_deferred {
	struct llist_head list;
	struct work_struct wq;
};

struct vmap_block_queue {
	spinlock_t lock;
	struct list_head free;
};

struct vmap_block {
	spinlock_t lock;
	struct vmap_area *va;
	long unsigned int free;
	long unsigned int dirty;
	long unsigned int dirty_min;
	long unsigned int dirty_max;
	struct list_head free_list;
	struct callback_head callback_head;
	struct list_head purge;
};

struct module___127;

struct file___149;

struct kiocb___149;

struct poll_table_struct___101;

struct vm_area_struct___149;

struct inode___149;

struct file_lock___149;

struct page___149;

struct seq_file___139;

struct file_operations___149 {
	struct module___127 *owner;
	loff_t (*llseek)(struct file___149 *, loff_t, int);
	ssize_t (*read)(struct file___149 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___149 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___149 *, struct iov_iter___67 *);
	ssize_t (*write_iter)(struct kiocb___149 *, struct iov_iter___67 *);
	int (*iopoll)(struct kiocb___149 *, bool);
	int (*iterate)(struct file___149 *, struct dir_context *);
	int (*iterate_shared)(struct file___149 *, struct dir_context *);
	__poll_t (*poll)(struct file___149 *, struct poll_table_struct___101 *);
	long int (*unlocked_ioctl)(struct file___149 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___149 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___149 *, struct vm_area_struct___149 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___149 *, struct file___149 *);
	int (*flush)(struct file___149 *, fl_owner_t);
	int (*release)(struct inode___149 *, struct file___149 *);
	int (*fsync)(struct file___149 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___149 *, int);
	int (*lock)(struct file___149 *, int, struct file_lock___149 *);
	ssize_t (*sendpage)(struct file___149 *, struct page___149 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___149 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___149 *, int, struct file_lock___149 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___149 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___149 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___149 *, long int, struct file_lock___149 **, void **);
	long int (*fallocate)(struct file___149 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___139 *, struct file___149 *);
	ssize_t (*copy_file_range)(struct file___149 *, loff_t, struct file___149 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___149 *, loff_t, struct file___149 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___149 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___148 {
	u64 seqnum;
	struct vm_area_struct___149 *vmas[4];
};

struct page_frag___148 {
	struct page___149 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___92;

struct debug_info___92 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___92 *hbp_break[16];
	struct perf_event___92 *hbp_watch[16];
};

struct thread_struct___92 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___92 debug;
	long: 64;
};

struct mm_struct___148;

struct pid___119;

struct cred___144;

struct nsproxy___141;

struct signal_struct___133;

struct css_set___125;

struct perf_event_context___92;

struct task_struct___149 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___149 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___148 *mm;
	struct mm_struct___148 *active_mm;
	struct vmacache___148 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___149 *real_parent;
	struct task_struct___149 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___149 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___119 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___119 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___119 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___144 *ptracer_cred;
	const struct cred___144 *real_cred;
	const struct cred___144 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___141 *nsproxy;
	struct signal_struct___133 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___149 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___33 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___125 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___92 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___148 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___149 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___92 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___92 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___149 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___92)(struct perf_event___92 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___92;

struct fasync_struct___148;

struct pid_namespace___119;

struct trace_event_call___85;

struct perf_cgroup___92;

struct perf_event___92 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___92 *group_leader;
	struct pmu___92 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___92 hw;
	struct perf_event_context___92 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___92 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___149 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___148 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___92 *);
	struct callback_head callback_head;
	struct pid_namespace___119 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___92 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___92 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___85 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___92 *cgrp;
	struct list_head sb_list;
};

typedef struct page___149 *pgtable_t___148;

struct address_space___148;

struct dev_pagemap___146;

struct page___149 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___148 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___149 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___148 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___148 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___146 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___148;

struct lruvec___148 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___148 *pgdat;
};

struct zone___148 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___148 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___148 {
	struct zone___148 *zone;
	int zone_idx;
};

struct zonelist___148 {
	struct zoneref___148 _zonerefs[25];
};

struct pglist_data___148 {
	struct zone___148 node_zones[3];
	struct zonelist___148 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___149 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___149 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___148 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___149 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___149 *owner;
};

struct secondary_data___149 {
	void *stack;
	struct task_struct___149 *task;
	long int status;
};

struct blocking_notifier_head___148 {
	struct rw_semaphore___149 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___146;

struct vm_area_struct___149 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___149 *vm_next;
	struct vm_area_struct___149 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___148 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___146 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___149 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___148;

struct user_namespace___129;

struct mm_struct___148 {
	struct {
		struct vm_area_struct___149 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___149 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___149 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___148 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___149 *owner;
		struct user_namespace___129 *user_ns;
		struct file___149 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___148 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___148;

struct address_space___148 {
	struct inode___149 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___149 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___148 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___146)(struct vm_area_struct___149 *, long unsigned int, const struct page___149 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___146)(struct page___149 *, void *);

struct device___139;

struct dev_pagemap___146 {
	dev_page_fault_t___146 page_fault;
	dev_page_free_t___146 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___139 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct dentry___148;

struct path___148 {
	struct vfsmount *mnt;
	struct dentry___148 *dentry;
};

struct fown_struct___119 {
	rwlock_t lock;
	struct pid___119 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___149 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___148 f_path;
	struct inode___149 *f_inode;
	const struct file_operations___149 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___119 f_owner;
	const struct cred___144 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___148 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___146;

struct vm_operations_struct___146 {
	void (*open)(struct vm_area_struct___149 *);
	void (*close)(struct vm_area_struct___149 *);
	int (*split)(struct vm_area_struct___149 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___149 *);
	vm_fault_t (*fault)(struct vm_fault___146 *);
	vm_fault_t (*huge_fault)(struct vm_fault___146 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___146 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___149 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___146 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___146 *);
	int (*access)(struct vm_area_struct___149 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___149 *);
	int (*set_policy)(struct vm_area_struct___149 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___149 *, long unsigned int);
	struct page___149 * (*find_special_page)(struct vm_area_struct___149 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___148 {
	struct task_struct___149 *task;
	struct core_thread___148 *next;
};

struct core_state___148 {
	atomic_t nr_threads;
	struct core_thread___148 dumper;
	struct completion startup;
};

struct key___144;

struct ucounts___129;

struct user_namespace___129 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___129 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___4 ns;
	long unsigned int flags;
	struct key___144 *persistent_keyring_register;
	struct rw_semaphore___149 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___129 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___146 {
	struct vm_area_struct___149 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___149 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___149 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___148 prealloc_pte;
};

struct upid___119 {
	int nr;
	struct pid_namespace___119 *ns;
};

struct pid_namespace___119 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___149 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___119 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___148 *proc_self;
	struct dentry___148 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___129 *user_ns;
	struct ucounts___129 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___4 ns;
};

struct pid___119 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___119 numbers[1];
};

struct user_struct___144 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___144 *uid_keyring;
	struct key___144 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___144 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___144 *session_keyring;
	struct key___144 *process_keyring;
	struct key___144 *thread_keyring;
	struct key___144 *request_key_auth;
	void *security;
	struct user_struct___144 *user;
	struct user_namespace___129 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___125;

struct nsproxy___141 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___119 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___125 *cgroup_ns;
};

struct signal_struct___133 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___149 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___149 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___119 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___119 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___148 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___119 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___125;

struct cgroup___125;

struct css_set___125 {
	struct cgroup_subsys_state___125 *subsys[13];
	refcount_t refcount;
	struct css_set___125 *dom_cset;
	struct cgroup___125 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___125 *mg_src_cgrp;
	struct cgroup___125 *mg_dst_cgrp;
	struct css_set___125 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___92 {
	struct pmu___92 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___149 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___92 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

union thread_union___133 {
	struct task_struct___149 task;
	long unsigned int stack[8192];
};

struct kset___142;

struct kobj_type___142;

struct kernfs_node___145;

struct kobject___143 {
	const char *name;
	struct list_head entry;
	struct kobject___143 *parent;
	struct kset___142 *kset;
	struct kobj_type___142 *ktype;
	struct kernfs_node___145 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___139 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___139 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___139;

struct bus_type___139;

struct device_driver___139;

struct dev_pm_domain___139;

struct class___139;

struct attribute_group___139;

struct device___139 {
	struct device___139 *parent;
	struct device_private *p;
	struct kobject___143 kobj;
	const char *init_name;
	const struct device_type___139 *type;
	struct mutex mutex;
	struct bus_type___139 *bus;
	struct device_driver___139 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___139 power;
	struct dev_pm_domain___139 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___139 *class;
	const struct attribute_group___139 **groups;
	void (*release)(struct device___139 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___148;

struct super_block___148;

struct dentry___148 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___148 *d_parent;
	struct qstr d_name;
	struct inode___149 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___148 *d_op;
	struct super_block___148 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___148;

struct block_device___149;

struct inode___149 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___148 *i_op;
	struct super_block___148 *i_sb;
	struct address_space___148 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___149 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___149 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___148 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___149 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___148 {
	int (*d_revalidate)(struct dentry___148 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___148 *, unsigned int);
	int (*d_hash)(const struct dentry___148 *, struct qstr *);
	int (*d_compare)(const struct dentry___148 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___148 *);
	int (*d_init)(struct dentry___148 *);
	void (*d_release)(struct dentry___148 *);
	void (*d_prune)(struct dentry___148 *);
	void (*d_iput)(struct dentry___148 *, struct inode___149 *);
	char * (*d_dname)(struct dentry___148 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___148 *);
	int (*d_manage)(const struct path___148 *, bool);
	struct dentry___148 * (*d_real)(struct dentry___148 *, const struct inode___149 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___148;

struct mem_dqinfo___148 {
	struct quota_format_type___148 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___148;

struct quota_info___148 {
	unsigned int flags;
	struct rw_semaphore___149 dqio_sem;
	struct inode___149 *files[3];
	struct mem_dqinfo___148 info[3];
	const struct quota_format_ops___148 *ops[3];
};

struct rcuwait___148 {
	struct task_struct___149 *task;
};

struct percpu_rw_semaphore___148 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___149 rw_sem;
	struct rcuwait___148 writer;
	int readers_block;
};

struct sb_writers___148 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___148 rw_sem[3];
};

struct file_system_type___148;

struct super_operations___148;

struct dquot_operations___148;

struct quotactl_ops___148;

struct super_block___148 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___148 *s_type;
	const struct super_operations___148 *s_op;
	const struct dquot_operations___148 *dq_op;
	const struct quotactl_ops___148 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___148 *s_root;
	struct rw_semaphore___149 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___149 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___148 s_dquot;
	struct sb_writers___148 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___148 *s_d_op;
	int cleancache_poolid;
	struct shrinker___63 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___129 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___149 {
	struct file___149 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___149 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___148 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___149 *ia_file;
};

struct dquot___148 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___148 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___148 {
	int qf_fmt_id;
	const struct quota_format_ops___148 *qf_ops;
	struct module___127 *qf_owner;
	struct quota_format_type___148 *qf_next;
};

struct quota_format_ops___148 {
	int (*check_quota_file)(struct super_block___148 *, int);
	int (*read_file_info)(struct super_block___148 *, int);
	int (*write_file_info)(struct super_block___148 *, int);
	int (*free_file_info)(struct super_block___148 *, int);
	int (*read_dqblk)(struct dquot___148 *);
	int (*commit_dqblk)(struct dquot___148 *);
	int (*release_dqblk)(struct dquot___148 *);
	int (*get_next_id)(struct super_block___148 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___148 {
	int (*write_dquot)(struct dquot___148 *);
	struct dquot___148 * (*alloc_dquot)(struct super_block___148 *, int);
	void (*destroy_dquot)(struct dquot___148 *);
	int (*acquire_dquot)(struct dquot___148 *);
	int (*release_dquot)(struct dquot___148 *);
	int (*mark_dirty)(struct dquot___148 *);
	int (*write_info)(struct super_block___148 *, int);
	qsize_t * (*get_reserved_space)(struct inode___149 *);
	int (*get_projid)(struct inode___149 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___149 *, qsize_t *);
	int (*get_next_id)(struct super_block___148 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___148 {
	int (*quota_on)(struct super_block___148 *, int, int, const struct path___148 *);
	int (*quota_off)(struct super_block___148 *, int);
	int (*quota_enable)(struct super_block___148 *, unsigned int);
	int (*quota_disable)(struct super_block___148 *, unsigned int);
	int (*quota_sync)(struct super_block___148 *, int);
	int (*set_info)(struct super_block___148 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___148 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___148 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___148 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___148 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___148 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___124 {
	struct kobject___143 kobj;
	struct module___127 *mod;
	struct kobject___143 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___124 {
	struct module___127 *mod;
	struct latch_tree_node node;
};

struct module_layout___124 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___124 mtn;
};

struct module_attribute___124;

struct kernel_param___124;

struct module___127 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___124 mkobj;
	struct module_attribute___124 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___143 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___124 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___124 core_layout;
	struct module_layout___124 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___85 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___148 {
	int (*writepage)(struct page___149 *, struct writeback_control___3 *);
	int (*readpage)(struct file___149 *, struct page___149 *);
	int (*writepages)(struct address_space___148 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___149 *);
	int (*readpages)(struct file___149 *, struct address_space___148 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___149 *, struct address_space___148 *, loff_t, unsigned int, unsigned int, struct page___149 **, void **);
	int (*write_end)(struct file___149 *, struct address_space___148 *, loff_t, unsigned int, unsigned int, struct page___149 *, void *);
	sector_t (*bmap)(struct address_space___148 *, sector_t);
	void (*invalidatepage)(struct page___149 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___149 *, gfp_t);
	void (*freepage)(struct page___149 *);
	ssize_t (*direct_IO)(struct kiocb___149 *, struct iov_iter___67 *);
	int (*migratepage)(struct address_space___148 *, struct page___149 *, struct page___149 *, enum migrate_mode);
	bool (*isolate_page)(struct page___149 *, isolate_mode_t);
	void (*putback_page)(struct page___149 *);
	int (*launder_page)(struct page___149 *);
	int (*is_partially_uptodate)(struct page___149 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___149 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___148 *, struct page___149 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___149 *, sector_t *);
	void (*swap_deactivate)(struct file___149 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___149 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___149 *bd_inode;
	struct super_block___148 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___149 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___148 {
	struct dentry___148 * (*lookup)(struct inode___149 *, struct dentry___148 *, unsigned int);
	const char * (*get_link)(struct dentry___148 *, struct inode___149 *, struct delayed_call *);
	int (*permission)(struct inode___149 *, int);
	struct posix_acl * (*get_acl)(struct inode___149 *, int);
	int (*readlink)(struct dentry___148 *, char *, int);
	int (*create)(struct inode___149 *, struct dentry___148 *, umode_t, bool);
	int (*link)(struct dentry___148 *, struct inode___149 *, struct dentry___148 *);
	int (*unlink)(struct inode___149 *, struct dentry___148 *);
	int (*symlink)(struct inode___149 *, struct dentry___148 *, const char *);
	int (*mkdir)(struct inode___149 *, struct dentry___148 *, umode_t);
	int (*rmdir)(struct inode___149 *, struct dentry___148 *);
	int (*mknod)(struct inode___149 *, struct dentry___148 *, umode_t, dev_t);
	int (*rename)(struct inode___149 *, struct dentry___148 *, struct inode___149 *, struct dentry___148 *, unsigned int);
	int (*setattr)(struct dentry___148 *, struct iattr___148 *);
	int (*getattr)(const struct path___148 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___148 *, char *, size_t);
	int (*fiemap)(struct inode___149 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___149 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___149 *, struct dentry___148 *, struct file___149 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___149 *, struct dentry___148 *, umode_t);
	int (*set_acl)(struct inode___149 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___148 {
	void (*fl_copy_lock)(struct file_lock___149 *, struct file_lock___149 *);
	void (*fl_release_private)(struct file_lock___149 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___148;

struct file_lock___149 {
	struct file_lock___149 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___149 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___148 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___148 *fl_ops;
	const struct lock_manager_operations___148 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___148 {
	int (*lm_compare_owner)(struct file_lock___149 *, struct file_lock___149 *);
	long unsigned int (*lm_owner_key)(struct file_lock___149 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___149 *);
	int (*lm_grant)(struct file_lock___149 *, int);
	bool (*lm_break)(struct file_lock___149 *);
	int (*lm_change)(struct file_lock___149 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___149 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___148 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___148 *fa_next;
	struct file___149 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___148 {
	const char *name;
	int fs_flags;
	struct dentry___148 * (*mount)(struct file_system_type___148 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___148 *);
	struct module___127 *owner;
	struct file_system_type___148 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___148 {
	struct inode___149 * (*alloc_inode)(struct super_block___148 *);
	void (*destroy_inode)(struct inode___149 *);
	void (*dirty_inode)(struct inode___149 *, int);
	int (*write_inode)(struct inode___149 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___149 *);
	void (*evict_inode)(struct inode___149 *);
	void (*put_super)(struct super_block___148 *);
	int (*sync_fs)(struct super_block___148 *, int);
	int (*freeze_super)(struct super_block___148 *);
	int (*freeze_fs)(struct super_block___148 *);
	int (*thaw_super)(struct super_block___148 *);
	int (*unfreeze_fs)(struct super_block___148 *);
	int (*statfs)(struct dentry___148 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___148 *, int *, char *);
	void (*umount_begin)(struct super_block___148 *);
	int (*show_options)(struct seq_file___139 *, struct dentry___148 *);
	int (*show_devname)(struct seq_file___139 *, struct dentry___148 *);
	int (*show_path)(struct seq_file___139 *, struct dentry___148 *);
	int (*show_stats)(struct seq_file___139 *, struct dentry___148 *);
	ssize_t (*quota_read)(struct super_block___148 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___148 *, int, const char *, size_t, loff_t);
	struct dquot___148 ** (*get_dquots)(struct inode___149 *);
	int (*bdev_try_to_free_page)(struct super_block___148 *, struct page___149 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___148 *, struct shrink_control___63 *);
	long int (*free_cached_objects)(struct super_block___148 *, struct shrink_control___63 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___100)(struct file___149 *, wait_queue_head_t *, struct poll_table_struct___101 *);

struct poll_table_struct___101 {
	poll_queue_proc___100 _qproc;
	__poll_t _key;
};

struct seq_operations___137;

struct seq_file___139 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___137 *op;
	int poll_event;
	const struct file___149 *file;
	void *private;
};

struct kobj_attribute___143 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___143 *, struct kobj_attribute___143 *, char *);
	ssize_t (*store)(struct kobject___143 *, struct kobj_attribute___143 *, const char *, size_t);
};

typedef void compound_page_dtor___146(struct page___149 *);

typedef int (*key_restrict_link_func_t___144)(struct key___144 *, const struct key_type *, const union key_payload *, struct key___144 *);

struct key_restriction___144;

struct key___144 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___149 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___144 *restrict_link;
};

struct key_restriction___144 {
	key_restrict_link_func_t___144 check;
	struct key___144 *key;
	struct key_type *keytype;
};

struct cgroup_namespace___125 {
	refcount_t count;
	struct ns_common___4 ns;
	struct user_namespace___129 *user_ns;
	struct ucounts___129 *ucounts;
	struct css_set___125 *root_cset;
};

struct ucounts___129 {
	struct hlist_node node;
	struct user_namespace___129 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct seq_operations___137 {
	void * (*start)(struct seq_file___139 *, loff_t *);
	void (*stop)(struct seq_file___139 *, void *);
	void * (*next)(struct seq_file___139 *, void *, loff_t *);
	int (*show)(struct seq_file___139 *, void *);
};

struct kernfs_root___145;

struct kernfs_elem_dir___145 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___145 *root;
};

struct kernfs_syscall_ops___145;

struct kernfs_root___145 {
	struct kernfs_node___145 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___145 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___145 {
	struct kernfs_node___145 *target_kn;
};

struct kernfs_ops___145;

struct kernfs_elem_attr___145 {
	const struct kernfs_ops___145 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___145 *notify_next;
};

struct kernfs_node___145 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___145 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___145 dir;
		struct kernfs_elem_symlink___145 symlink;
		struct kernfs_elem_attr___145 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___145;

struct kernfs_ops___145 {
	int (*open)(struct kernfs_open_file___145 *);
	void (*release)(struct kernfs_open_file___145 *);
	int (*seq_show)(struct seq_file___139 *, void *);
	void * (*seq_start)(struct seq_file___139 *, loff_t *);
	void * (*seq_next)(struct seq_file___139 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___139 *, void *);
	ssize_t (*read)(struct kernfs_open_file___145 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___145 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___145 *, struct vm_area_struct___149 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___145 *, struct poll_table_struct___101 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___145 {
	int (*remount_fs)(struct kernfs_root___145 *, int *, char *);
	int (*show_options)(struct seq_file___139 *, struct kernfs_root___145 *);
	int (*mkdir)(struct kernfs_node___145 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___145 *);
	int (*rename)(struct kernfs_node___145 *, struct kernfs_node___145 *, const char *);
	int (*show_path)(struct seq_file___139 *, struct kernfs_node___145 *, struct kernfs_root___145 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___145 {
	struct kernfs_node___145 *kn;
	struct file___149 *file;
	struct seq_file___139 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___146 *vm_ops;
};

struct bin_attribute___138;

struct attribute_group___139 {
	const char *name;
	umode_t (*is_visible)(struct kobject___143 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___143 *, struct bin_attribute___138 *, int);
	struct attribute **attrs;
	struct bin_attribute___138 **bin_attrs;
};

struct bin_attribute___138 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___149 *, struct kobject___143 *, struct bin_attribute___138 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___149 *, struct kobject___143 *, struct bin_attribute___138 *, char *, loff_t, size_t);
	int (*mmap)(struct file___149 *, struct kobject___143 *, struct bin_attribute___138 *, struct vm_area_struct___149 *);
};

struct sysfs_ops___142 {
	ssize_t (*show)(struct kobject___143 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___143 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___142;

struct kset___142 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___143 kobj;
	const struct kset_uevent_ops___142 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___142 {
	void (*release)(struct kobject___143 *);
	const struct sysfs_ops___142 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___2 * (*child_ns_type)(struct kobject___143 *);
	const void * (*namespace)(struct kobject___143 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___142 {
	int (* const filter)(struct kset___142 *, struct kobject___143 *);
	const char * (* const name)(struct kset___142 *, struct kobject___143 *);
	int (* const uevent)(struct kset___142 *, struct kobject___143 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___124 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___124 *);
	int (*get)(char *, const struct kernel_param___124 *);
	void (*free)(void *);
};

struct kparam_array___124;

struct kernel_param___124 {
	const char *name;
	struct module___127 *mod;
	const struct kernel_param_ops___124 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___124 *arr;
	};
};

struct kparam_array___124 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___124 *ops;
	void *elem;
};

struct module_attribute___124 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___124 *, struct module_kobject___124 *, char *);
	ssize_t (*store)(struct module_attribute___124 *, struct module_kobject___124 *, const char *, size_t);
	void (*setup)(struct module___127 *, const char *);
	int (*test)(struct module___127 *);
	void (*free)(struct module___127 *);
};

struct trace_event_class___85;

struct trace_event_call___85 {
	struct list_head list;
	struct trace_event_class___85 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___4 *prog_array;
	int (*perf_perm)(struct trace_event_call___85 *, struct perf_event___92 *);
};

struct dev_pm_ops___139 {
	int (*prepare)(struct device___139 *);
	void (*complete)(struct device___139 *);
	int (*suspend)(struct device___139 *);
	int (*resume)(struct device___139 *);
	int (*freeze)(struct device___139 *);
	int (*thaw)(struct device___139 *);
	int (*poweroff)(struct device___139 *);
	int (*restore)(struct device___139 *);
	int (*suspend_late)(struct device___139 *);
	int (*resume_early)(struct device___139 *);
	int (*freeze_late)(struct device___139 *);
	int (*thaw_early)(struct device___139 *);
	int (*poweroff_late)(struct device___139 *);
	int (*restore_early)(struct device___139 *);
	int (*suspend_noirq)(struct device___139 *);
	int (*resume_noirq)(struct device___139 *);
	int (*freeze_noirq)(struct device___139 *);
	int (*thaw_noirq)(struct device___139 *);
	int (*poweroff_noirq)(struct device___139 *);
	int (*restore_noirq)(struct device___139 *);
	int (*runtime_suspend)(struct device___139 *);
	int (*runtime_resume)(struct device___139 *);
	int (*runtime_idle)(struct device___139 *);
};

struct dev_pm_domain___139 {
	struct dev_pm_ops___139 ops;
	void (*detach)(struct device___139 *, bool);
	int (*activate)(struct device___139 *);
	void (*sync)(struct device___139 *);
	void (*dismiss)(struct device___139 *);
};

struct bus_type___139 {
	const char *name;
	const char *dev_name;
	struct device___139 *dev_root;
	const struct attribute_group___139 **bus_groups;
	const struct attribute_group___139 **dev_groups;
	const struct attribute_group___139 **drv_groups;
	int (*match)(struct device___139 *, struct device_driver___139 *);
	int (*uevent)(struct device___139 *, struct kobj_uevent_env *);
	int (*probe)(struct device___139 *);
	int (*remove)(struct device___139 *);
	void (*shutdown)(struct device___139 *);
	int (*online)(struct device___139 *);
	int (*offline)(struct device___139 *);
	int (*suspend)(struct device___139 *, pm_message_t);
	int (*resume)(struct device___139 *);
	int (*num_vf)(struct device___139 *);
	int (*dma_configure)(struct device___139 *);
	const struct dev_pm_ops___139 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___139 {
	const char *name;
	struct bus_type___139 *bus;
	struct module___127 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___139 *);
	int (*remove)(struct device___139 *);
	void (*shutdown)(struct device___139 *);
	int (*suspend)(struct device___139 *, pm_message_t);
	int (*resume)(struct device___139 *);
	const struct attribute_group___139 **groups;
	const struct dev_pm_ops___139 *pm;
	void (*coredump)(struct device___139 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___139 {
	const char *name;
	const struct attribute_group___139 **groups;
	int (*uevent)(struct device___139 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___139 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___139 *);
	const struct dev_pm_ops___139 *pm;
};

struct class___139 {
	const char *name;
	struct module___127 *owner;
	const struct attribute_group___139 **class_groups;
	const struct attribute_group___139 **dev_groups;
	struct kobject___143 *dev_kobj;
	int (*dev_uevent)(struct device___139 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___139 *, umode_t *);
	void (*class_release)(struct class___139 *);
	void (*dev_release)(struct device___139 *);
	int (*shutdown_pre)(struct device___139 *);
	const struct kobj_ns_type_operations___2 *ns_type;
	const void * (*namespace)(struct device___139 *);
	const struct dev_pm_ops___139 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___117 {
	struct device___139 dev;
};

struct bpf_map___125;

struct bpf_map_ops___125 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___125 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___125 *, struct file___149 *);
	void (*map_free)(struct bpf_map___125 *);
	int (*map_get_next_key)(struct bpf_map___125 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___125 *);
	void * (*map_lookup_elem)(struct bpf_map___125 *, void *);
	int (*map_update_elem)(struct bpf_map___125 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___125 *, void *);
	int (*map_push_elem)(struct bpf_map___125 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___125 *, void *);
	int (*map_peek_elem)(struct bpf_map___125 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___125 *, struct file___149 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___125 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___125 *, void *, struct seq_file___139 *);
	int (*map_check_btf)(const struct bpf_map___125 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___125 {
	const struct bpf_map_ops___125 *ops;
	struct bpf_map___125 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___144 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___125;

typedef void (*kthread_work_func_t___125)(struct kthread_work___125 *);

struct kthread_worker___125;

struct kthread_work___125 {
	struct list_head node;
	kthread_work_func_t___125 func;
	struct kthread_worker___125 *worker;
	int canceling;
};

struct kthread_worker___125 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___149 *task;
	struct kthread_work___125 *current_work;
};

struct kthread_delayed_work___125 {
	struct kthread_work___125 work;
	struct timer_list timer;
};

struct psi_group___125 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___125 *poll_kworker;
	struct kthread_delayed_work___125 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___125 {
	struct kernfs_node___145 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___125;

struct cgroup_subsys_state___125 {
	struct cgroup___125 *cgroup;
	struct cgroup_subsys___125 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___125 *parent;
};

struct cgroup_root___125;

struct cgroup_rstat_cpu___125;

struct cgroup___125 {
	struct cgroup_subsys_state___125 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___145 *kn;
	struct cgroup_file___125 procs_file;
	struct cgroup_file___125 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___125 *subsys[13];
	struct cgroup_root___125 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___125 *dom_cgrp;
	struct cgroup_rstat_cpu___125 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___4 bpf;
	atomic_t congestion_count;
	struct cgroup___125 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___125 psi;
	int ancestor_ids[0];
};

struct cftype___125;

struct cgroup_subsys___125 {
	struct cgroup_subsys_state___125 * (*css_alloc)(struct cgroup_subsys_state___125 *);
	int (*css_online)(struct cgroup_subsys_state___125 *);
	void (*css_offline)(struct cgroup_subsys_state___125 *);
	void (*css_released)(struct cgroup_subsys_state___125 *);
	void (*css_free)(struct cgroup_subsys_state___125 *);
	void (*css_reset)(struct cgroup_subsys_state___125 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___125 *, int);
	int (*css_extra_stat_show)(struct seq_file___139 *, struct cgroup_subsys_state___125 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___149 *);
	void (*cancel_fork)(struct task_struct___149 *);
	void (*fork)(struct task_struct___149 *);
	void (*exit)(struct task_struct___149 *);
	void (*free)(struct task_struct___149 *);
	void (*bind)(struct cgroup_subsys_state___125 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___125 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___125 *dfl_cftypes;
	struct cftype___125 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___125 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___125 *updated_children;
	struct cgroup___125 *updated_next;
};

struct cgroup_root___125 {
	struct kernfs_root___145 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___125 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___125 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___125 *ss;
	struct list_head node;
	struct kernfs_ops___145 *kf_ops;
	int (*open)(struct kernfs_open_file___145 *);
	void (*release)(struct kernfs_open_file___145 *);
	u64 (*read_u64)(struct cgroup_subsys_state___125 *, struct cftype___125 *);
	s64 (*read_s64)(struct cgroup_subsys_state___125 *, struct cftype___125 *);
	int (*seq_show)(struct seq_file___139 *, void *);
	void * (*seq_start)(struct seq_file___139 *, loff_t *);
	void * (*seq_next)(struct seq_file___139 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___139 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___125 *, struct cftype___125 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___125 *, struct cftype___125 *, s64);
	ssize_t (*write)(struct kernfs_open_file___145 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___145 *, struct poll_table_struct___101 *);
};

struct perf_cpu_context___92;

struct pmu___92 {
	struct list_head entry;
	struct module___127 *module;
	struct device___139 *dev;
	const struct attribute_group___139 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___92 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___92 *);
	void (*pmu_disable)(struct pmu___92 *);
	int (*event_init)(struct perf_event___92 *);
	void (*event_mapped)(struct perf_event___92 *, struct mm_struct___148 *);
	void (*event_unmapped)(struct perf_event___92 *, struct mm_struct___148 *);
	int (*add)(struct perf_event___92 *, int);
	void (*del)(struct perf_event___92 *, int);
	void (*start)(struct perf_event___92 *, int);
	void (*stop)(struct perf_event___92 *, int);
	void (*read)(struct perf_event___92 *);
	void (*start_txn)(struct pmu___92 *, unsigned int);
	int (*commit_txn)(struct pmu___92 *);
	void (*cancel_txn)(struct pmu___92 *);
	int (*event_idx)(struct perf_event___92 *);
	void (*sched_task)(struct perf_event_context___92 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___92 *);
	int (*filter_match)(struct perf_event___92 *);
	int (*check_period)(struct perf_event___92 *, u64);
};

struct perf_cpu_context___92 {
	struct perf_event_context___92 ctx;
	struct perf_event_context___92 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___92 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___92 {
	struct cgroup_subsys_state___125 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___85 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___85 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___85 *);
	struct list_head * (*get_fields)(struct trace_event_call___85 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___85 *);
};

struct syscall_metadata___32 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___85 *enter_event;
	struct trace_event_call___85 *exit_event;
};

typedef struct pglist_data___148 pg_data_t___11;

struct module___128;

struct file___150;

struct kiocb___150;

struct iov_iter___68;

struct poll_table_struct___102;

struct vm_area_struct___150;

struct inode___150;

struct file_lock___150;

struct page___150;

struct seq_file___140;

struct file_operations___150 {
	struct module___128 *owner;
	loff_t (*llseek)(struct file___150 *, loff_t, int);
	ssize_t (*read)(struct file___150 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___150 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___150 *, struct iov_iter___68 *);
	ssize_t (*write_iter)(struct kiocb___150 *, struct iov_iter___68 *);
	int (*iopoll)(struct kiocb___150 *, bool);
	int (*iterate)(struct file___150 *, struct dir_context *);
	int (*iterate_shared)(struct file___150 *, struct dir_context *);
	__poll_t (*poll)(struct file___150 *, struct poll_table_struct___102 *);
	long int (*unlocked_ioctl)(struct file___150 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___150 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___150 *, struct vm_area_struct___150 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___150 *, struct file___150 *);
	int (*flush)(struct file___150 *, fl_owner_t);
	int (*release)(struct inode___150 *, struct file___150 *);
	int (*fsync)(struct file___150 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___150 *, int);
	int (*lock)(struct file___150 *, int, struct file_lock___150 *);
	ssize_t (*sendpage)(struct file___150 *, struct page___150 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___150 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___150 *, int, struct file_lock___150 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___150 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___150 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___150 *, long int, struct file_lock___150 **, void **);
	long int (*fallocate)(struct file___150 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___140 *, struct file___150 *);
	ssize_t (*copy_file_range)(struct file___150 *, loff_t, struct file___150 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___150 *, loff_t, struct file___150 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___150 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___149 {
	u64 seqnum;
	struct vm_area_struct___150 *vmas[4];
};

struct page_frag___149 {
	struct page___150 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___93;

struct debug_info___93 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___93 *hbp_break[16];
	struct perf_event___93 *hbp_watch[16];
};

struct thread_struct___93 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___93 debug;
	long: 64;
};

struct mm_struct___149;

struct mem_cgroup___64;

struct pid___120;

struct cred___145;

struct nsproxy___142;

struct signal_struct___134;

struct bio_list___69;

struct backing_dev_info___69;

struct io_context___34;

struct css_set___126;

struct perf_event_context___93;

struct request_queue___32;

struct vm_struct___112;

struct task_struct___150 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___150 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___149 *mm;
	struct mm_struct___149 *active_mm;
	struct vmacache___149 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___150 *real_parent;
	struct task_struct___150 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___150 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___64 *active_memcg;
	long int rh_reserved2;
	struct pid___120 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___120 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___120 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___145 *ptracer_cred;
	const struct cred___145 *real_cred;
	const struct cred___145 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___142 *nsproxy;
	struct signal_struct___134 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___150 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___69 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___69 *backing_dev_info;
	struct io_context___34 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___126 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___93 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___149 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___64 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___32 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___150 *oom_reaper_list;
	struct vm_struct___112 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___93 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___93 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___150 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___93)(struct perf_event___93 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___93;

struct fasync_struct___149;

struct pid_namespace___120;

struct trace_event_call___86;

struct perf_cgroup___93;

struct perf_event___93 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___93 *group_leader;
	struct pmu___93 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___93 hw;
	struct perf_event_context___93 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___93 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___150 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___149 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___93 *);
	struct callback_head callback_head;
	struct pid_namespace___120 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___93 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___93 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___86 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___93 *cgrp;
	struct list_head sb_list;
};

typedef struct page___150 *pgtable_t___149;

struct address_space___149;

struct dev_pagemap___147;

struct page___150 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___149 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___150 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___149 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___149 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___147 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___64 *mem_cgroup;
};

struct pglist_data___149;

struct lruvec___149 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___149 *pgdat;
};

struct zone___149 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___149 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___149 {
	struct zone___149 *zone;
	int zone_idx;
};

struct zonelist___149 {
	struct zoneref___149 _zonerefs[25];
};

struct pglist_data___149 {
	struct zone___149 node_zones[3];
	struct zonelist___149 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___150 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___150 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___149 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___150 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___150 *owner;
};

struct secondary_data___150 {
	void *stack;
	struct task_struct___150 *task;
	long int status;
};

struct blocking_notifier_head___149 {
	struct rw_semaphore___150 rwsem;
	struct notifier_block *head;
};

struct anon_vma___13;

struct vm_operations_struct___147;

struct vm_area_struct___150 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___150 *vm_next;
	struct vm_area_struct___150 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___149 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma___13 *anon_vma;
	const struct vm_operations_struct___147 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___150 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___149;

struct user_namespace___130;

struct mm_struct___149 {
	struct {
		struct vm_area_struct___150 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___150 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___150 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___149 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___150 *owner;
		struct user_namespace___130 *user_ns;
		struct file___150 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___149 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___149;

struct address_space___149 {
	struct inode___150 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___150 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___149 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___147)(struct vm_area_struct___150 *, long unsigned int, const struct page___150 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___147)(struct page___150 *, void *);

struct device___140;

struct dev_pagemap___147 {
	dev_page_fault_t___147 page_fault;
	dev_page_free_t___147 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___140 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct cgroup___126;

struct cgroup_subsys___126;

struct cgroup_subsys_state___126 {
	struct cgroup___126 *cgroup;
	struct cgroup_subsys___126 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___126 *parent;
};

struct kernfs_node___146;

struct cgroup_file___126 {
	struct kernfs_node___146 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___64;

struct mem_cgroup___64 {
	struct cgroup_subsys_state___126 css;
	struct mem_cgroup_id___11 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___126 events_file;
	struct cgroup_file___126 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___150 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___64 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry___149;

struct path___149 {
	struct vfsmount *mnt;
	struct dentry___149 *dentry;
};

struct fown_struct___120 {
	rwlock_t lock;
	struct pid___120 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___150 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___149 f_path;
	struct inode___150 *f_inode;
	const struct file_operations___150 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___120 f_owner;
	const struct cred___145 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___149 *f_mapping;
	errseq_t f_wb_err;
};

struct anon_vma___13 {
	struct anon_vma___13 *root;
	struct rw_semaphore___150 rwsem;
	atomic_t refcount;
	unsigned int degree;
	struct anon_vma___13 *parent;
	struct rb_root_cached rb_root;
};

struct vm_fault___147;

struct vm_operations_struct___147 {
	void (*open)(struct vm_area_struct___150 *);
	void (*close)(struct vm_area_struct___150 *);
	int (*split)(struct vm_area_struct___150 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___150 *);
	vm_fault_t (*fault)(struct vm_fault___147 *);
	vm_fault_t (*huge_fault)(struct vm_fault___147 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___147 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___150 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___147 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___147 *);
	int (*access)(struct vm_area_struct___150 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___150 *);
	int (*set_policy)(struct vm_area_struct___150 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___150 *, long unsigned int);
	struct page___150 * (*find_special_page)(struct vm_area_struct___150 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___149 {
	struct task_struct___150 *task;
	struct core_thread___149 *next;
};

struct core_state___149 {
	atomic_t nr_threads;
	struct core_thread___149 dumper;
	struct completion startup;
};

struct key___145;

struct ucounts___130;

struct user_namespace___130 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___130 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___4 ns;
	long unsigned int flags;
	struct key___145 *persistent_keyring_register;
	struct rw_semaphore___150 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___130 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___147 {
	struct vm_area_struct___150 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___150 *cow_page;
	struct mem_cgroup___64 *memcg;
	struct page___150 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___149 prealloc_pte;
};

struct shrink_control___64 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___64 *memcg;
};

struct shrinker___64 {
	long unsigned int (*count_objects)(struct shrinker___64 *, struct shrink_control___64 *);
	long unsigned int (*scan_objects)(struct shrinker___64 *, struct shrink_control___64 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct upid___120 {
	int nr;
	struct pid_namespace___120 *ns;
};

struct pid_namespace___120 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___150 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___120 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___149 *proc_self;
	struct dentry___149 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___130 *user_ns;
	struct ucounts___130 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___4 ns;
};

struct pid___120 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___120 numbers[1];
};

struct user_struct___145 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___145 *uid_keyring;
	struct key___145 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___145 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___145 *session_keyring;
	struct key___145 *process_keyring;
	struct key___145 *thread_keyring;
	struct key___145 *request_key_auth;
	void *security;
	struct user_struct___145 *user;
	struct user_namespace___130 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___126;

struct nsproxy___142 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___120 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___126 *cgroup_ns;
};

struct signal_struct___134 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___150 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___150 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___120 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___120 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___149 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___120 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___69;

struct bio_list___69 {
	struct bio___69 *head;
	struct bio___69 *tail;
};

struct bdi_writeback_congested___69;

struct bdi_writeback___69 {
	struct backing_dev_info___69 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___69 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___126 *memcg_css;
	struct cgroup_subsys_state___126 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___69 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___69 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___140 *dev;
	struct device___140 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___149 *debug_dir;
	struct dentry___149 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___34;

struct io_context___34 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___34 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___126 {
	struct cgroup_subsys_state___126 *subsys[13];
	refcount_t refcount;
	struct css_set___126 *dom_cset;
	struct cgroup___126 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___126 *mg_src_cgrp;
	struct cgroup___126 *mg_dst_cgrp;
	struct css_set___126 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___93 {
	struct pmu___93 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___150 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___93 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

typedef blk_qc_t make_request_fn___31(struct request_queue___32 *, struct bio___69 *);

struct request___32;

typedef int dma_drain_needed_fn___31(struct request___32 *);

struct kset___143;

struct kobj_type___143;

struct kobject___144 {
	const char *name;
	struct list_head entry;
	struct kobject___144 *parent;
	struct kset___143 *kset;
	struct kobj_type___143 *ktype;
	struct kernfs_node___146 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___31;

struct bsg_class_device___31 {
	struct device___140 *class_dev;
	int minor;
	struct request_queue___32 *queue;
	const struct bsg_ops___31 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___69 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___69 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___31;

struct blkcg_gq___22;

struct request_queue___32 {
	struct list_head queue_head;
	struct request___32 *last_merge;
	struct elevator_queue___31 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___31 *make_request_fn;
	dma_drain_needed_fn___31 *dma_drain_needed;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___69 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___144 kobj;
	struct kobject___144 *mq_kobj;
	struct blk_integrity integrity;
	struct device___140 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___22 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide37;
		union {		};
	};
	struct bsg_class_device___31 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___69 bio_split;
	struct dentry___149 *debugfs_dir;
	struct dentry___149 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___112 {
	struct vm_struct___112 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___150 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___134 {
	struct task_struct___150 task;
	long unsigned int stack[8192];
};

struct dev_pm_info___140 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___140 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___140;

struct bus_type___140;

struct device_driver___140;

struct dev_pm_domain___140;

struct fwnode_handle___102;

struct class___140;

struct attribute_group___140;

struct device___140 {
	struct device___140 *parent;
	struct device_private *p;
	struct kobject___144 kobj;
	const char *init_name;
	const struct device_type___140 *type;
	struct mutex mutex;
	struct bus_type___140 *bus;
	struct device_driver___140 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___140 power;
	struct dev_pm_domain___140 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___102 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___140 *class;
	const struct attribute_group___140 **groups;
	void (*release)(struct device___140 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___149;

struct super_block___149;

struct dentry___149 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___149 *d_parent;
	struct qstr d_name;
	struct inode___150 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___149 *d_op;
	struct super_block___149 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___149;

struct block_device___150;

struct inode___150 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___149 *i_op;
	struct super_block___149 *i_sb;
	struct address_space___149 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___150 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___69 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___150 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___149 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___150 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___149 {
	int (*d_revalidate)(struct dentry___149 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___149 *, unsigned int);
	int (*d_hash)(const struct dentry___149 *, struct qstr *);
	int (*d_compare)(const struct dentry___149 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___149 *);
	int (*d_init)(struct dentry___149 *);
	void (*d_release)(struct dentry___149 *);
	void (*d_prune)(struct dentry___149 *);
	void (*d_iput)(struct dentry___149 *, struct inode___150 *);
	char * (*d_dname)(struct dentry___149 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___149 *);
	int (*d_manage)(const struct path___149 *, bool);
	struct dentry___149 * (*d_real)(struct dentry___149 *, const struct inode___150 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___149;

struct mem_dqinfo___149 {
	struct quota_format_type___149 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___149;

struct quota_info___149 {
	unsigned int flags;
	struct rw_semaphore___150 dqio_sem;
	struct inode___150 *files[3];
	struct mem_dqinfo___149 info[3];
	const struct quota_format_ops___149 *ops[3];
};

struct rcuwait___149 {
	struct task_struct___150 *task;
};

struct percpu_rw_semaphore___149 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___150 rw_sem;
	struct rcuwait___149 writer;
	int readers_block;
};

struct sb_writers___149 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___149 rw_sem[3];
};

struct file_system_type___149;

struct super_operations___149;

struct dquot_operations___149;

struct quotactl_ops___149;

struct xattr_handler___11;

struct super_block___149 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___149 *s_type;
	const struct super_operations___149 *s_op;
	const struct dquot_operations___149 *dq_op;
	const struct quotactl_ops___149 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___149 *s_root;
	struct rw_semaphore___150 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___11 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___150 *s_bdev;
	struct backing_dev_info___69 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___149 s_dquot;
	struct sb_writers___149 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___149 *s_d_op;
	int cleancache_poolid;
	struct shrinker___64 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___130 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct io_cq___34 {
	struct request_queue___32 *q;
	struct io_context___34 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___150 {
	struct file___150 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___150 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___149 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___150 *ia_file;
};

struct dquot___149 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___149 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___149 {
	int qf_fmt_id;
	const struct quota_format_ops___149 *qf_ops;
	struct module___128 *qf_owner;
	struct quota_format_type___149 *qf_next;
};

struct quota_format_ops___149 {
	int (*check_quota_file)(struct super_block___149 *, int);
	int (*read_file_info)(struct super_block___149 *, int);
	int (*write_file_info)(struct super_block___149 *, int);
	int (*free_file_info)(struct super_block___149 *, int);
	int (*read_dqblk)(struct dquot___149 *);
	int (*commit_dqblk)(struct dquot___149 *);
	int (*release_dqblk)(struct dquot___149 *);
	int (*get_next_id)(struct super_block___149 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___149 {
	int (*write_dquot)(struct dquot___149 *);
	struct dquot___149 * (*alloc_dquot)(struct super_block___149 *, int);
	void (*destroy_dquot)(struct dquot___149 *);
	int (*acquire_dquot)(struct dquot___149 *);
	int (*release_dquot)(struct dquot___149 *);
	int (*mark_dirty)(struct dquot___149 *);
	int (*write_info)(struct super_block___149 *, int);
	qsize_t * (*get_reserved_space)(struct inode___150 *);
	int (*get_projid)(struct inode___150 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___150 *, qsize_t *);
	int (*get_next_id)(struct super_block___149 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___149 {
	int (*quota_on)(struct super_block___149 *, int, int, const struct path___149 *);
	int (*quota_off)(struct super_block___149 *, int);
	int (*quota_enable)(struct super_block___149 *, unsigned int);
	int (*quota_disable)(struct super_block___149 *, unsigned int);
	int (*quota_sync)(struct super_block___149 *, int);
	int (*set_info)(struct super_block___149 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___149 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___149 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___149 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___149 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___149 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___125 {
	struct kobject___144 kobj;
	struct module___128 *mod;
	struct kobject___144 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___125 {
	struct module___128 *mod;
	struct latch_tree_node node;
};

struct module_layout___125 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___125 mtn;
};

struct module_attribute___125;

struct kernel_param___125;

struct module___128 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___125 mkobj;
	struct module_attribute___125 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___144 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___125 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___125 core_layout;
	struct module_layout___125 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___86 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___66;

struct swap_info_struct___46;

struct address_space_operations___149 {
	int (*writepage)(struct page___150 *, struct writeback_control___66 *);
	int (*readpage)(struct file___150 *, struct page___150 *);
	int (*writepages)(struct address_space___149 *, struct writeback_control___66 *);
	int (*set_page_dirty)(struct page___150 *);
	int (*readpages)(struct file___150 *, struct address_space___149 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___150 *, struct address_space___149 *, loff_t, unsigned int, unsigned int, struct page___150 **, void **);
	int (*write_end)(struct file___150 *, struct address_space___149 *, loff_t, unsigned int, unsigned int, struct page___150 *, void *);
	sector_t (*bmap)(struct address_space___149 *, sector_t);
	void (*invalidatepage)(struct page___150 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___150 *, gfp_t);
	void (*freepage)(struct page___150 *);
	ssize_t (*direct_IO)(struct kiocb___150 *, struct iov_iter___68 *);
	int (*migratepage)(struct address_space___149 *, struct page___150 *, struct page___150 *, enum migrate_mode);
	bool (*isolate_page)(struct page___150 *, isolate_mode_t);
	void (*putback_page)(struct page___150 *);
	int (*launder_page)(struct page___150 *);
	int (*is_partially_uptodate)(struct page___150 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___150 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___149 *, struct page___150 *);
	int (*swap_activate)(struct swap_info_struct___46 *, struct file___150 *, sector_t *);
	void (*swap_deactivate)(struct file___150 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___66 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___69 *wb;
	struct inode___150 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___69;

struct iov_iter___68 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___69 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct swap_info_struct___46 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___150 *bdev;
	struct file___150 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct hd_struct___32;

struct gendisk___32;

struct block_device___150 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___150 *bd_inode;
	struct super_block___149 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___150 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___32 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___32 *bd_disk;
	struct request_queue___32 *bd_queue;
	struct backing_dev_info___69 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct hd_struct___32 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___140 __dev;
	struct kobject___144 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___32;

struct block_device_operations___32;

struct gendisk___32 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___32 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___32 *part_tbl;
	struct hd_struct___32 part0;
	const struct block_device_operations___32 *fops;
	struct request_queue___32 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___150 lookup_sem;
	struct kobject___144 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___144 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___149 {
	struct dentry___149 * (*lookup)(struct inode___150 *, struct dentry___149 *, unsigned int);
	const char * (*get_link)(struct dentry___149 *, struct inode___150 *, struct delayed_call *);
	int (*permission)(struct inode___150 *, int);
	struct posix_acl * (*get_acl)(struct inode___150 *, int);
	int (*readlink)(struct dentry___149 *, char *, int);
	int (*create)(struct inode___150 *, struct dentry___149 *, umode_t, bool);
	int (*link)(struct dentry___149 *, struct inode___150 *, struct dentry___149 *);
	int (*unlink)(struct inode___150 *, struct dentry___149 *);
	int (*symlink)(struct inode___150 *, struct dentry___149 *, const char *);
	int (*mkdir)(struct inode___150 *, struct dentry___149 *, umode_t);
	int (*rmdir)(struct inode___150 *, struct dentry___149 *);
	int (*mknod)(struct inode___150 *, struct dentry___149 *, umode_t, dev_t);
	int (*rename)(struct inode___150 *, struct dentry___149 *, struct inode___150 *, struct dentry___149 *, unsigned int);
	int (*setattr)(struct dentry___149 *, struct iattr___149 *);
	int (*getattr)(const struct path___149 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___149 *, char *, size_t);
	int (*fiemap)(struct inode___150 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___150 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___150 *, struct dentry___149 *, struct file___150 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___150 *, struct dentry___149 *, umode_t);
	int (*set_acl)(struct inode___150 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___149 {
	void (*fl_copy_lock)(struct file_lock___150 *, struct file_lock___150 *);
	void (*fl_release_private)(struct file_lock___150 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___149;

struct file_lock___150 {
	struct file_lock___150 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___150 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___149 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___149 *fl_ops;
	const struct lock_manager_operations___149 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___149 {
	int (*lm_compare_owner)(struct file_lock___150 *, struct file_lock___150 *);
	long unsigned int (*lm_owner_key)(struct file_lock___150 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___150 *);
	int (*lm_grant)(struct file_lock___150 *, int);
	bool (*lm_break)(struct file_lock___150 *);
	int (*lm_change)(struct file_lock___150 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___150 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___149 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___149 *fa_next;
	struct file___150 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___149 {
	const char *name;
	int fs_flags;
	struct dentry___149 * (*mount)(struct file_system_type___149 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___149 *);
	struct module___128 *owner;
	struct file_system_type___149 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___149 {
	struct inode___150 * (*alloc_inode)(struct super_block___149 *);
	void (*destroy_inode)(struct inode___150 *);
	void (*dirty_inode)(struct inode___150 *, int);
	int (*write_inode)(struct inode___150 *, struct writeback_control___66 *);
	int (*drop_inode)(struct inode___150 *);
	void (*evict_inode)(struct inode___150 *);
	void (*put_super)(struct super_block___149 *);
	int (*sync_fs)(struct super_block___149 *, int);
	int (*freeze_super)(struct super_block___149 *);
	int (*freeze_fs)(struct super_block___149 *);
	int (*thaw_super)(struct super_block___149 *);
	int (*unfreeze_fs)(struct super_block___149 *);
	int (*statfs)(struct dentry___149 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___149 *, int *, char *);
	void (*umount_begin)(struct super_block___149 *);
	int (*show_options)(struct seq_file___140 *, struct dentry___149 *);
	int (*show_devname)(struct seq_file___140 *, struct dentry___149 *);
	int (*show_path)(struct seq_file___140 *, struct dentry___149 *);
	int (*show_stats)(struct seq_file___140 *, struct dentry___149 *);
	ssize_t (*quota_read)(struct super_block___149 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___149 *, int, const char *, size_t, loff_t);
	struct dquot___149 ** (*get_dquots)(struct inode___150 *);
	int (*bdev_try_to_free_page)(struct super_block___149 *, struct page___150 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___149 *, struct shrink_control___64 *);
	long int (*free_cached_objects)(struct super_block___149 *, struct shrink_control___64 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct xattr_handler___11 {
	const char *name;
	const char *prefix;
	int flags;
	bool (*list)(struct dentry___149 *);
	int (*get)(const struct xattr_handler___11 *, struct dentry___149 *, struct inode___150 *, const char *, void *, size_t);
	int (*set)(const struct xattr_handler___11 *, struct dentry___149 *, struct inode___150 *, const char *, const void *, size_t, int);
};

typedef void (*poll_queue_proc___101)(struct file___150 *, wait_queue_head_t *, struct poll_table_struct___102 *);

struct poll_table_struct___102 {
	poll_queue_proc___101 _qproc;
	__poll_t _key;
};

struct seq_operations___138;

struct seq_file___140 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___138 *op;
	int poll_event;
	const struct file___150 *file;
	void *private;
};

typedef void bio_end_io_t___69(struct bio___69 *);

struct bio_vec___69 {
	struct page___150 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___69;

struct bio___69 {
	struct bio___69 *bi_next;
	struct gendisk___32 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___69 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___22 *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___69 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___69 *bi_io_vec;
	struct bio_set___69 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___69 bi_inline_vecs[0];
};

struct kobj_attribute___144 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___144 *, struct kobj_attribute___144 *, char *);
	ssize_t (*store)(struct kobject___144 *, struct kobj_attribute___144 *, const char *, size_t);
};

typedef void compound_page_dtor___147(struct page___150 *);

struct mm_walk___3 {
	int (*pud_entry)(pud_t *, long unsigned int, long unsigned int, struct mm_walk___3 *);
	int (*pmd_entry)(pmd_t *, long unsigned int, long unsigned int, struct mm_walk___3 *);
	int (*pte_entry)(pte_t *, long unsigned int, long unsigned int, struct mm_walk___3 *);
	int (*pte_hole)(long unsigned int, long unsigned int, struct mm_walk___3 *);
	int (*hugetlb_entry)(pte_t *, long unsigned int, long unsigned int, long unsigned int, struct mm_walk___3 *);
	int (*test_walk)(long unsigned int, long unsigned int, struct mm_walk___3 *);
	struct mm_struct___149 *mm;
	struct vm_area_struct___150 *vma;
	void *private;
};

enum mf_flags {
	MF_COUNT_INCREASED = 1,
	MF_ACTION_REQUIRED = 2,
	MF_MUST_KILL = 4,
	MF_SOFT_OFFLINE = 8,
};

typedef int (*key_restrict_link_func_t___145)(struct key___145 *, const struct key_type *, const union key_payload *, struct key___145 *);

struct key_restriction___145;

struct key___145 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___150 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___145 *restrict_link;
};

struct key_restriction___145 {
	key_restrict_link_func_t___145 check;
	struct key___145 *key;
	struct key_type *keytype;
};

struct seq_operations___138 {
	void * (*start)(struct seq_file___140 *, loff_t *);
	void (*stop)(struct seq_file___140 *, void *);
	void * (*next)(struct seq_file___140 *, void *, loff_t *);
	int (*show)(struct seq_file___140 *, void *);
};

struct cgroup_namespace___126 {
	refcount_t count;
	struct ns_common___4 ns;
	struct user_namespace___130 *user_ns;
	struct ucounts___130 *ucounts;
	struct css_set___126 *root_cset;
};

struct ucounts___130 {
	struct hlist_node node;
	struct user_namespace___130 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct kernfs_root___146;

struct kernfs_elem_dir___146 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___146 *root;
};

struct kernfs_syscall_ops___146;

struct kernfs_root___146 {
	struct kernfs_node___146 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___146 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___146 {
	struct kernfs_node___146 *target_kn;
};

struct kernfs_ops___146;

struct kernfs_elem_attr___146 {
	const struct kernfs_ops___146 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___146 *notify_next;
};

struct kernfs_node___146 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___146 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___146 dir;
		struct kernfs_elem_symlink___146 symlink;
		struct kernfs_elem_attr___146 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___146;

struct kernfs_ops___146 {
	int (*open)(struct kernfs_open_file___146 *);
	void (*release)(struct kernfs_open_file___146 *);
	int (*seq_show)(struct seq_file___140 *, void *);
	void * (*seq_start)(struct seq_file___140 *, loff_t *);
	void * (*seq_next)(struct seq_file___140 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___140 *, void *);
	ssize_t (*read)(struct kernfs_open_file___146 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___146 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___146 *, struct vm_area_struct___150 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___146 *, struct poll_table_struct___102 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___146 {
	int (*remount_fs)(struct kernfs_root___146 *, int *, char *);
	int (*show_options)(struct seq_file___140 *, struct kernfs_root___146 *);
	int (*mkdir)(struct kernfs_node___146 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___146 *);
	int (*rename)(struct kernfs_node___146 *, struct kernfs_node___146 *, const char *);
	int (*show_path)(struct seq_file___140 *, struct kernfs_node___146 *, struct kernfs_root___146 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___146 {
	struct kernfs_node___146 *kn;
	struct file___150 *file;
	struct seq_file___140 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___147 *vm_ops;
};

struct bin_attribute___139;

struct attribute_group___140 {
	const char *name;
	umode_t (*is_visible)(struct kobject___144 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___144 *, struct bin_attribute___139 *, int);
	struct attribute **attrs;
	struct bin_attribute___139 **bin_attrs;
};

struct bin_attribute___139 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___150 *, struct kobject___144 *, struct bin_attribute___139 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___150 *, struct kobject___144 *, struct bin_attribute___139 *, char *, loff_t, size_t);
	int (*mmap)(struct file___150 *, struct kobject___144 *, struct bin_attribute___139 *, struct vm_area_struct___150 *);
};

struct sysfs_ops___143 {
	ssize_t (*show)(struct kobject___144 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___144 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___143;

struct kset___143 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___144 kobj;
	const struct kset_uevent_ops___143 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___143 {
	void (*release)(struct kobject___144 *);
	const struct sysfs_ops___143 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___2 * (*child_ns_type)(struct kobject___144 *);
	const void * (*namespace)(struct kobject___144 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___143 {
	int (* const filter)(struct kset___143 *, struct kobject___144 *);
	const char * (* const name)(struct kset___143 *, struct kobject___144 *);
	int (* const uevent)(struct kset___143 *, struct kobject___144 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___125 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___125 *);
	int (*get)(char *, const struct kernel_param___125 *);
	void (*free)(void *);
};

struct kparam_array___125;

struct kernel_param___125 {
	const char *name;
	struct module___128 *mod;
	const struct kernel_param_ops___125 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___125 *arr;
	};
};

struct kparam_array___125 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___125 *ops;
	void *elem;
};

struct module_attribute___125 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___125 *, struct module_kobject___125 *, char *);
	ssize_t (*store)(struct module_attribute___125 *, struct module_kobject___125 *, const char *, size_t);
	void (*setup)(struct module___128 *, const char *);
	int (*test)(struct module___128 *);
	void (*free)(struct module___128 *);
};

struct trace_event_class___86;

struct trace_event_call___86 {
	struct list_head list;
	struct trace_event_class___86 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___4 *prog_array;
	int (*perf_perm)(struct trace_event_call___86 *, struct perf_event___93 *);
};

struct dev_pm_ops___140 {
	int (*prepare)(struct device___140 *);
	void (*complete)(struct device___140 *);
	int (*suspend)(struct device___140 *);
	int (*resume)(struct device___140 *);
	int (*freeze)(struct device___140 *);
	int (*thaw)(struct device___140 *);
	int (*poweroff)(struct device___140 *);
	int (*restore)(struct device___140 *);
	int (*suspend_late)(struct device___140 *);
	int (*resume_early)(struct device___140 *);
	int (*freeze_late)(struct device___140 *);
	int (*thaw_early)(struct device___140 *);
	int (*poweroff_late)(struct device___140 *);
	int (*restore_early)(struct device___140 *);
	int (*suspend_noirq)(struct device___140 *);
	int (*resume_noirq)(struct device___140 *);
	int (*freeze_noirq)(struct device___140 *);
	int (*thaw_noirq)(struct device___140 *);
	int (*poweroff_noirq)(struct device___140 *);
	int (*restore_noirq)(struct device___140 *);
	int (*runtime_suspend)(struct device___140 *);
	int (*runtime_resume)(struct device___140 *);
	int (*runtime_idle)(struct device___140 *);
};

struct dev_pm_domain___140 {
	struct dev_pm_ops___140 ops;
	void (*detach)(struct device___140 *, bool);
	int (*activate)(struct device___140 *);
	void (*sync)(struct device___140 *);
	void (*dismiss)(struct device___140 *);
};

struct bus_type___140 {
	const char *name;
	const char *dev_name;
	struct device___140 *dev_root;
	const struct attribute_group___140 **bus_groups;
	const struct attribute_group___140 **dev_groups;
	const struct attribute_group___140 **drv_groups;
	int (*match)(struct device___140 *, struct device_driver___140 *);
	int (*uevent)(struct device___140 *, struct kobj_uevent_env *);
	int (*probe)(struct device___140 *);
	int (*remove)(struct device___140 *);
	void (*shutdown)(struct device___140 *);
	int (*online)(struct device___140 *);
	int (*offline)(struct device___140 *);
	int (*suspend)(struct device___140 *, pm_message_t);
	int (*resume)(struct device___140 *);
	int (*num_vf)(struct device___140 *);
	int (*dma_configure)(struct device___140 *);
	const struct dev_pm_ops___140 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___140 {
	const char *name;
	struct bus_type___140 *bus;
	struct module___128 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___140 *);
	int (*remove)(struct device___140 *);
	void (*shutdown)(struct device___140 *);
	int (*suspend)(struct device___140 *, pm_message_t);
	int (*resume)(struct device___140 *);
	const struct attribute_group___140 **groups;
	const struct dev_pm_ops___140 *pm;
	void (*coredump)(struct device___140 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___140 {
	const char *name;
	const struct attribute_group___140 **groups;
	int (*uevent)(struct device___140 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___140 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___140 *);
	const struct dev_pm_ops___140 *pm;
};

struct class___140 {
	const char *name;
	struct module___128 *owner;
	const struct attribute_group___140 **class_groups;
	const struct attribute_group___140 **dev_groups;
	struct kobject___144 *dev_kobj;
	int (*dev_uevent)(struct device___140 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___140 *, umode_t *);
	void (*class_release)(struct class___140 *);
	void (*dev_release)(struct device___140 *);
	int (*shutdown_pre)(struct device___140 *);
	const struct kobj_ns_type_operations___2 *ns_type;
	const void * (*namespace)(struct device___140 *);
	const struct dev_pm_ops___140 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct fwnode_operations___102;

struct fwnode_handle___102 {
	struct fwnode_handle___102 *secondary;
	const struct fwnode_operations___102 *ops;
};

struct node___118 {
	struct device___140 dev;
};

struct bpf_map___126;

struct bpf_map_ops___126 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___126 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___126 *, struct file___150 *);
	void (*map_free)(struct bpf_map___126 *);
	int (*map_get_next_key)(struct bpf_map___126 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___126 *);
	void * (*map_lookup_elem)(struct bpf_map___126 *, void *);
	int (*map_update_elem)(struct bpf_map___126 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___126 *, void *);
	int (*map_push_elem)(struct bpf_map___126 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___126 *, void *);
	int (*map_peek_elem)(struct bpf_map___126 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___126 *, struct file___150 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___126 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___126 *, void *, struct seq_file___140 *);
	int (*map_check_btf)(const struct bpf_map___126 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___126 {
	const struct bpf_map_ops___126 *ops;
	struct bpf_map___126 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___145 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___126;

typedef void (*kthread_work_func_t___126)(struct kthread_work___126 *);

struct kthread_worker___126;

struct kthread_work___126 {
	struct list_head node;
	kthread_work_func_t___126 func;
	struct kthread_worker___126 *worker;
	int canceling;
};

struct kthread_worker___126 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___150 *task;
	struct kthread_work___126 *current_work;
};

struct kthread_delayed_work___126 {
	struct kthread_work___126 work;
	struct timer_list timer;
};

struct psi_group___126 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___126 *poll_kworker;
	struct kthread_delayed_work___126 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___126;

struct cgroup_rstat_cpu___126;

struct cgroup___126 {
	struct cgroup_subsys_state___126 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___146 *kn;
	struct cgroup_file___126 procs_file;
	struct cgroup_file___126 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___126 *subsys[13];
	struct cgroup_root___126 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___126 *dom_cgrp;
	struct cgroup_rstat_cpu___126 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___4 bpf;
	atomic_t congestion_count;
	struct cgroup___126 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___126 psi;
	int ancestor_ids[0];
};

struct cftype___126;

struct cgroup_subsys___126 {
	struct cgroup_subsys_state___126 * (*css_alloc)(struct cgroup_subsys_state___126 *);
	int (*css_online)(struct cgroup_subsys_state___126 *);
	void (*css_offline)(struct cgroup_subsys_state___126 *);
	void (*css_released)(struct cgroup_subsys_state___126 *);
	void (*css_free)(struct cgroup_subsys_state___126 *);
	void (*css_reset)(struct cgroup_subsys_state___126 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___126 *, int);
	int (*css_extra_stat_show)(struct seq_file___140 *, struct cgroup_subsys_state___126 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___150 *);
	void (*cancel_fork)(struct task_struct___150 *);
	void (*fork)(struct task_struct___150 *);
	void (*exit)(struct task_struct___150 *);
	void (*free)(struct task_struct___150 *);
	void (*bind)(struct cgroup_subsys_state___126 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___126 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___126 *dfl_cftypes;
	struct cftype___126 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___126 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___126 *updated_children;
	struct cgroup___126 *updated_next;
};

struct cgroup_root___126 {
	struct kernfs_root___146 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___126 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___126 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___126 *ss;
	struct list_head node;
	struct kernfs_ops___146 *kf_ops;
	int (*open)(struct kernfs_open_file___146 *);
	void (*release)(struct kernfs_open_file___146 *);
	u64 (*read_u64)(struct cgroup_subsys_state___126 *, struct cftype___126 *);
	s64 (*read_s64)(struct cgroup_subsys_state___126 *, struct cftype___126 *);
	int (*seq_show)(struct seq_file___140 *, void *);
	void * (*seq_start)(struct seq_file___140 *, loff_t *);
	void * (*seq_next)(struct seq_file___140 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___140 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___126 *, struct cftype___126 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___126 *, struct cftype___126 *, s64);
	ssize_t (*write)(struct kernfs_open_file___146 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___146 *, struct poll_table_struct___102 *);
};

struct perf_cpu_context___93;

struct pmu___93 {
	struct list_head entry;
	struct module___128 *module;
	struct device___140 *dev;
	const struct attribute_group___140 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___93 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___93 *);
	void (*pmu_disable)(struct pmu___93 *);
	int (*event_init)(struct perf_event___93 *);
	void (*event_mapped)(struct perf_event___93 *, struct mm_struct___149 *);
	void (*event_unmapped)(struct perf_event___93 *, struct mm_struct___149 *);
	int (*add)(struct perf_event___93 *, int);
	void (*del)(struct perf_event___93 *, int);
	void (*start)(struct perf_event___93 *, int);
	void (*stop)(struct perf_event___93 *, int);
	void (*read)(struct perf_event___93 *);
	void (*start_txn)(struct pmu___93 *, unsigned int);
	int (*commit_txn)(struct pmu___93 *);
	void (*cancel_txn)(struct pmu___93 *);
	int (*event_idx)(struct perf_event___93 *);
	void (*sched_task)(struct perf_event_context___93 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___93 *);
	int (*filter_match)(struct perf_event___93 *);
	int (*check_period)(struct perf_event___93 *, u64);
};

struct perf_cpu_context___93 {
	struct perf_event_context___93 ctx;
	struct perf_event_context___93 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___93 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___93 {
	struct cgroup_subsys_state___126 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___86 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___86 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___86 *);
	struct list_head * (*get_fields)(struct trace_event_call___86 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___86 *);
};

struct syscall_metadata___33 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___86 *enter_event;
	struct trace_event_call___86 *exit_event;
};

struct hstate___26 {
	int next_nid_to_alloc;
	int next_nid_to_free;
	unsigned int order;
	long unsigned int mask;
	long unsigned int max_huge_pages;
	long unsigned int nr_huge_pages;
	long unsigned int free_huge_pages;
	long unsigned int resv_huge_pages;
	long unsigned int surplus_huge_pages;
	long unsigned int nr_overcommit_huge_pages;
	struct list_head hugepage_activelist;
	struct list_head hugepage_freelists[8];
	unsigned int nr_huge_pages_node[8];
	unsigned int free_huge_pages_node[8];
	unsigned int surplus_huge_pages_node[8];
	struct cftype___126 cgroup_files[5];
	char name[32];
};

struct bdi_writeback_congested___69 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___69 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___69 {
	struct bio___69 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___69 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___69 bip_inline_vecs[0];
};

struct blkcg___22;

struct blkg_policy_data___22;

struct blkcg_gq___22 {
	struct request_queue___32 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___22 *blkcg;
	struct bdi_writeback_congested___69 *wb_congested;
	struct blkcg_gq___22 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_rwstat stat_bytes;
	struct blkg_rwstat stat_ios;
	struct blkg_policy_data___22 *pd[5];
	struct callback_head callback_head;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
};

struct mem_cgroup_reclaim_iter___64 {
	struct mem_cgroup___64 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___64 {
	struct lruvec___149 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___64 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___64 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct disk_part_tbl___32 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___32 *last_lookup;
	struct hd_struct___32 *part[0];
};

struct block_device_operations___32 {
	int (*open)(struct block_device___150 *, fmode_t);
	void (*release)(struct gendisk___32 *, fmode_t);
	int (*rw_page)(struct block_device___150 *, sector_t, struct page___150 *, unsigned int);
	int (*ioctl)(struct block_device___150 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___150 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___32 *, unsigned int);
	int (*media_changed)(struct gendisk___32 *);
	void (*unlock_native_capacity)(struct gendisk___32 *);
	int (*revalidate_disk)(struct gendisk___32 *);
	int (*getgeo)(struct block_device___150 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___150 *, long unsigned int);
	int (*report_zones)(struct gendisk___32 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___128 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___31 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___32 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___32 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___32 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___31(struct request___32 *, blk_status_t);

struct request___32 {
	struct request_queue___32 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___69 *bio;
	struct bio___69 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___69 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___34 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___31 *saved_end_io;
		} flush;
	};
	struct gendisk___32 *rq_disk;
	struct hd_struct___32 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___31 *end_io;
	void *end_io_data;
	struct request___32 *next_rq;
};

struct fwnode_reference_args___102;

struct fwnode_endpoint___102;

struct fwnode_operations___102 {
	struct fwnode_handle___102 * (*get)(struct fwnode_handle___102 *);
	void (*put)(struct fwnode_handle___102 *);
	bool (*device_is_available)(const struct fwnode_handle___102 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___102 *, const struct device___140 *);
	bool (*property_present)(const struct fwnode_handle___102 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___102 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___102 *, const char *, const char **, size_t);
	struct fwnode_handle___102 * (*get_parent)(const struct fwnode_handle___102 *);
	struct fwnode_handle___102 * (*get_next_child_node)(const struct fwnode_handle___102 *, struct fwnode_handle___102 *);
	struct fwnode_handle___102 * (*get_named_child_node)(const struct fwnode_handle___102 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___102 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___102 *);
	struct fwnode_handle___102 * (*graph_get_next_endpoint)(const struct fwnode_handle___102 *, struct fwnode_handle___102 *);
	struct fwnode_handle___102 * (*graph_get_remote_endpoint)(const struct fwnode_handle___102 *);
	struct fwnode_handle___102 * (*graph_get_port_parent)(struct fwnode_handle___102 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___102 *, struct fwnode_endpoint___102 *);
};

struct fwnode_endpoint___102 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___102 *local_fwnode;
};

struct fwnode_reference_args___102 {
	struct fwnode_handle___102 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct elevator_type___31;

struct elevator_mq_ops___31 {
	int (*init_sched)(struct request_queue___32 *, struct elevator_type___31 *);
	void (*exit_sched)(struct elevator_queue___31 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	bool (*allow_merge)(struct request_queue___32 *, struct request___32 *, struct bio___69 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx *, struct bio___69 *);
	int (*request_merge)(struct request_queue___32 *, struct request___32 **, struct bio___69 *);
	void (*request_merged)(struct request_queue___32 *, struct request___32 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___32 *, struct request___32 *, struct request___32 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___32 *, struct bio___69 *);
	void (*finish_request)(struct request___32 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___32 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___32 *, u64);
	void (*started_request)(struct request___32 *);
	void (*requeue_request)(struct request___32 *);
	struct request___32 * (*former_request)(struct request_queue___32 *, struct request___32 *);
	struct request___32 * (*next_request)(struct request_queue___32 *, struct request___32 *);
	void (*init_icq)(struct io_cq___34 *);
	void (*exit_icq)(struct io_cq___34 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide36;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___31;

struct elevator_type___31 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___31 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___31 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___128 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___31 {
	struct elevator_type___31 *type;
	void *elevator_data;
	struct kobject___144 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___31 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___31 *, char *);
	ssize_t (*store)(struct elevator_queue___31 *, const char *, size_t);
};

struct blkcg_policy_data___22;

struct blkcg___22 {
	struct cgroup_subsys_state___126 css;
	spinlock_t lock;
	struct xarray blkg_tree;
	struct blkcg_gq___22 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___22 *cpd[5];
	struct list_head all_blkcgs_node;
	struct list_head cgwb_list;
	refcount_t cgwb_refcnt;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct blkcg_policy_data___22 {
	struct blkcg___22 *blkcg;
	int plid;
};

struct blkg_policy_data___22 {
	struct blkcg_gq___22 *blkg;
	int plid;
};

struct mmu_gather_batch___4 {
	struct mmu_gather_batch___4 *next;
	unsigned int nr;
	unsigned int max;
	struct page___150 *pages[0];
};

struct mmu_gather___4 {
	struct mm_struct___149 *mm;
	struct mmu_table_batch *batch;
	long unsigned int start;
	long unsigned int end;
	unsigned int fullmm: 1;
	unsigned int need_flush_all: 1;
	struct mmu_gather_batch___4 *active;
	struct mmu_gather_batch___4 local;
	struct page___150 *__pages[8];
	unsigned int batch_count;
	int page_size;
};

struct vma_swap_readahead {
	short unsigned int win;
	short unsigned int offset;
	short unsigned int nr_pte;
	pte_t *ptes;
};

struct module___129;

struct file___151;

struct kiocb___151;

struct iov_iter___69;

struct poll_table_struct___103;

struct vm_area_struct___151;

struct inode___151;

struct file_lock___151;

struct page___151;

struct seq_file___141;

struct file_operations___151 {
	struct module___129 *owner;
	loff_t (*llseek)(struct file___151 *, loff_t, int);
	ssize_t (*read)(struct file___151 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___151 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___151 *, struct iov_iter___69 *);
	ssize_t (*write_iter)(struct kiocb___151 *, struct iov_iter___69 *);
	int (*iopoll)(struct kiocb___151 *, bool);
	int (*iterate)(struct file___151 *, struct dir_context *);
	int (*iterate_shared)(struct file___151 *, struct dir_context *);
	__poll_t (*poll)(struct file___151 *, struct poll_table_struct___103 *);
	long int (*unlocked_ioctl)(struct file___151 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___151 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___151 *, struct vm_area_struct___151 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___151 *, struct file___151 *);
	int (*flush)(struct file___151 *, fl_owner_t);
	int (*release)(struct inode___151 *, struct file___151 *);
	int (*fsync)(struct file___151 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___151 *, int);
	int (*lock)(struct file___151 *, int, struct file_lock___151 *);
	ssize_t (*sendpage)(struct file___151 *, struct page___151 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___151 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___151 *, int, struct file_lock___151 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___151 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___151 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___151 *, long int, struct file_lock___151 **, void **);
	long int (*fallocate)(struct file___151 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___141 *, struct file___151 *);
	ssize_t (*copy_file_range)(struct file___151 *, loff_t, struct file___151 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___151 *, loff_t, struct file___151 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___151 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___150 {
	u64 seqnum;
	struct vm_area_struct___151 *vmas[4];
};

struct page_frag___150 {
	struct page___151 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___94;

struct debug_info___94 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___94 *hbp_break[16];
	struct perf_event___94 *hbp_watch[16];
};

struct thread_struct___94 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___94 debug;
	long: 64;
};

struct mm_struct___150;

struct mem_cgroup___65;

struct pid___121;

struct cred___146;

struct nsproxy___143;

struct signal_struct___135;

struct bio_list___70;

struct backing_dev_info___70;

struct io_context___35;

struct css_set___127;

struct perf_event_context___94;

struct request_queue___33;

struct vm_struct___113;

struct task_struct___151 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___151 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___150 *mm;
	struct mm_struct___150 *active_mm;
	struct vmacache___150 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___151 *real_parent;
	struct task_struct___151 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___151 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___65 *active_memcg;
	long int rh_reserved2;
	struct pid___121 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___121 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___121 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___146 *ptracer_cred;
	const struct cred___146 *real_cred;
	const struct cred___146 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___143 *nsproxy;
	struct signal_struct___135 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___151 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___70 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___70 *backing_dev_info;
	struct io_context___35 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___127 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___94 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___150 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___65 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___33 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___151 *oom_reaper_list;
	struct vm_struct___113 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___94 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___94 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___151 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___94)(struct perf_event___94 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___94;

struct fasync_struct___150;

struct pid_namespace___121;

struct trace_event_call___87;

struct perf_cgroup___94;

struct perf_event___94 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___94 *group_leader;
	struct pmu___94 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___94 hw;
	struct perf_event_context___94 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___94 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___151 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___150 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___94 *);
	struct callback_head callback_head;
	struct pid_namespace___121 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___94 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___94 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___87 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___94 *cgrp;
	struct list_head sb_list;
};

typedef struct page___151 *pgtable_t___150;

struct address_space___150;

struct dev_pagemap___148;

struct page___151 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___150 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___151 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___150 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___150 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___148 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___65 *mem_cgroup;
};

struct pglist_data___150;

struct lruvec___150 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___150 *pgdat;
};

struct zone___150 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___150 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___150 {
	struct zone___150 *zone;
	int zone_idx;
};

struct zonelist___150 {
	struct zoneref___150 _zonerefs[25];
};

struct pglist_data___150 {
	struct zone___150 node_zones[3];
	struct zonelist___150 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___151 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___151 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___150 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___151 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___151 *owner;
};

struct secondary_data___151 {
	void *stack;
	struct task_struct___151 *task;
	long int status;
};

struct blocking_notifier_head___150 {
	struct rw_semaphore___151 rwsem;
	struct notifier_block *head;
};

struct anon_vma___14;

struct vm_operations_struct___148;

struct vm_area_struct___151 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___151 *vm_next;
	struct vm_area_struct___151 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___150 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma___14 *anon_vma;
	const struct vm_operations_struct___148 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___151 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___150;

struct user_namespace___131;

struct mm_struct___150 {
	struct {
		struct vm_area_struct___151 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___151 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___151 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___150 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___151 *owner;
		struct user_namespace___131 *user_ns;
		struct file___151 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___150 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___150;

struct address_space___150 {
	struct inode___151 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___151 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___150 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___148)(struct vm_area_struct___151 *, long unsigned int, const struct page___151 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___148)(struct page___151 *, void *);

struct device___141;

struct dev_pagemap___148 {
	dev_page_fault_t___148 page_fault;
	dev_page_free_t___148 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___141 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct cgroup___127;

struct cgroup_subsys___127;

struct cgroup_subsys_state___127 {
	struct cgroup___127 *cgroup;
	struct cgroup_subsys___127 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___127 *parent;
};

struct kernfs_node___147;

struct cgroup_file___127 {
	struct kernfs_node___147 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___65;

struct mem_cgroup___65 {
	struct cgroup_subsys_state___127 css;
	struct mem_cgroup_id___6 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___127 events_file;
	struct cgroup_file___127 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___151 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___65 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry___150;

struct path___150 {
	struct vfsmount *mnt;
	struct dentry___150 *dentry;
};

struct fown_struct___121 {
	rwlock_t lock;
	struct pid___121 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___151 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___150 f_path;
	struct inode___151 *f_inode;
	const struct file_operations___151 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___121 f_owner;
	const struct cred___146 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___150 *f_mapping;
	errseq_t f_wb_err;
};

struct anon_vma___14 {
	struct anon_vma___14 *root;
	struct rw_semaphore___151 rwsem;
	atomic_t refcount;
	unsigned int degree;
	struct anon_vma___14 *parent;
	struct rb_root_cached rb_root;
};

struct vm_fault___148;

struct vm_operations_struct___148 {
	void (*open)(struct vm_area_struct___151 *);
	void (*close)(struct vm_area_struct___151 *);
	int (*split)(struct vm_area_struct___151 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___151 *);
	vm_fault_t (*fault)(struct vm_fault___148 *);
	vm_fault_t (*huge_fault)(struct vm_fault___148 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___148 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___151 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___148 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___148 *);
	int (*access)(struct vm_area_struct___151 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___151 *);
	int (*set_policy)(struct vm_area_struct___151 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___151 *, long unsigned int);
	struct page___151 * (*find_special_page)(struct vm_area_struct___151 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___150 {
	struct task_struct___151 *task;
	struct core_thread___150 *next;
};

struct core_state___150 {
	atomic_t nr_threads;
	struct core_thread___150 dumper;
	struct completion startup;
};

struct key___146;

struct ucounts___131;

struct user_namespace___131 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___131 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___4 ns;
	long unsigned int flags;
	struct key___146 *persistent_keyring_register;
	struct rw_semaphore___151 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___131 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___148 {
	struct vm_area_struct___151 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___151 *cow_page;
	struct mem_cgroup___65 *memcg;
	struct page___151 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___150 prealloc_pte;
};

struct shrink_control___65 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___65 *memcg;
};

struct shrinker___65 {
	long unsigned int (*count_objects)(struct shrinker___65 *, struct shrink_control___65 *);
	long unsigned int (*scan_objects)(struct shrinker___65 *, struct shrink_control___65 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct upid___121 {
	int nr;
	struct pid_namespace___121 *ns;
};

struct pid_namespace___121 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___151 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___121 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___150 *proc_self;
	struct dentry___150 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___131 *user_ns;
	struct ucounts___131 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___4 ns;
};

struct pid___121 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___121 numbers[1];
};

struct user_struct___146 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___146 *uid_keyring;
	struct key___146 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___146 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___146 *session_keyring;
	struct key___146 *process_keyring;
	struct key___146 *thread_keyring;
	struct key___146 *request_key_auth;
	void *security;
	struct user_struct___146 *user;
	struct user_namespace___131 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___127;

struct nsproxy___143 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___121 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___127 *cgroup_ns;
};

struct signal_struct___135 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___151 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___151 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___121 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___121 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___150 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___121 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide47;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___70;

struct bio_list___70 {
	struct bio___70 *head;
	struct bio___70 *tail;
};

struct bdi_writeback_congested___70;

struct bdi_writeback___70 {
	struct backing_dev_info___70 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___70 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___127 *memcg_css;
	struct cgroup_subsys_state___127 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___70 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___70 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___141 *dev;
	struct device___141 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___150 *debug_dir;
	struct dentry___150 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___35;

struct io_context___35 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___35 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___127 {
	struct cgroup_subsys_state___127 *subsys[13];
	refcount_t refcount;
	struct css_set___127 *dom_cset;
	struct cgroup___127 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___127 *mg_src_cgrp;
	struct cgroup___127 *mg_dst_cgrp;
	struct css_set___127 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___94 {
	struct pmu___94 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___151 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___94 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

typedef blk_qc_t make_request_fn___32(struct request_queue___33 *, struct bio___70 *);

struct request___33;

typedef int dma_drain_needed_fn___32(struct request___33 *);

struct kset___144;

struct kobj_type___144;

struct kobject___145 {
	const char *name;
	struct list_head entry;
	struct kobject___145 *parent;
	struct kset___144 *kset;
	struct kobj_type___144 *ktype;
	struct kernfs_node___147 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___32;

struct bsg_class_device___32 {
	struct device___141 *class_dev;
	int minor;
	struct request_queue___33 *queue;
	const struct bsg_ops___32 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___70 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___70 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___32;

struct blkcg_gq___23;

struct request_queue___33 {
	struct list_head queue_head;
	struct request___33 *last_merge;
	struct elevator_queue___32 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___32 *make_request_fn;
	dma_drain_needed_fn___32 *dma_drain_needed;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___70 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___145 kobj;
	struct kobject___145 *mq_kobj;
	struct blk_integrity integrity;
	struct device___141 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___23 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	struct bsg_class_device___32 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___70 bio_split;
	struct dentry___150 *debugfs_dir;
	struct dentry___150 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___113 {
	struct vm_struct___113 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___151 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___135 {
	struct task_struct___151 task;
	long unsigned int stack[8192];
};

struct dev_pm_info___141 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___141 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___141;

struct bus_type___141;

struct device_driver___141;

struct dev_pm_domain___141;

struct fwnode_handle___103;

struct class___141;

struct attribute_group___141;

struct device___141 {
	struct device___141 *parent;
	struct device_private *p;
	struct kobject___145 kobj;
	const char *init_name;
	const struct device_type___141 *type;
	struct mutex mutex;
	struct bus_type___141 *bus;
	struct device_driver___141 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___141 power;
	struct dev_pm_domain___141 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___103 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___141 *class;
	const struct attribute_group___141 **groups;
	void (*release)(struct device___141 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___150;

struct super_block___150;

struct dentry___150 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___150 *d_parent;
	struct qstr d_name;
	struct inode___151 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___150 *d_op;
	struct super_block___150 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___150;

struct block_device___151;

struct inode___151 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___150 *i_op;
	struct super_block___150 *i_sb;
	struct address_space___150 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___151 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___70 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___151 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___150 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___151 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___150 {
	int (*d_revalidate)(struct dentry___150 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___150 *, unsigned int);
	int (*d_hash)(const struct dentry___150 *, struct qstr *);
	int (*d_compare)(const struct dentry___150 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___150 *);
	int (*d_init)(struct dentry___150 *);
	void (*d_release)(struct dentry___150 *);
	void (*d_prune)(struct dentry___150 *);
	void (*d_iput)(struct dentry___150 *, struct inode___151 *);
	char * (*d_dname)(struct dentry___150 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___150 *);
	int (*d_manage)(const struct path___150 *, bool);
	struct dentry___150 * (*d_real)(struct dentry___150 *, const struct inode___151 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___150;

struct mem_dqinfo___150 {
	struct quota_format_type___150 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___150;

struct quota_info___150 {
	unsigned int flags;
	struct rw_semaphore___151 dqio_sem;
	struct inode___151 *files[3];
	struct mem_dqinfo___150 info[3];
	const struct quota_format_ops___150 *ops[3];
};

struct rcuwait___150 {
	struct task_struct___151 *task;
};

struct percpu_rw_semaphore___150 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___151 rw_sem;
	struct rcuwait___150 writer;
	int readers_block;
};

struct sb_writers___150 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___150 rw_sem[3];
};

struct file_system_type___150;

struct super_operations___150;

struct dquot_operations___150;

struct quotactl_ops___150;

struct xattr_handler___12;

struct super_block___150 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___150 *s_type;
	const struct super_operations___150 *s_op;
	const struct dquot_operations___150 *dq_op;
	const struct quotactl_ops___150 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___150 *s_root;
	struct rw_semaphore___151 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___12 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___151 *s_bdev;
	struct backing_dev_info___70 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___150 s_dquot;
	struct sb_writers___150 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___150 *s_d_op;
	int cleancache_poolid;
	struct shrinker___65 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___131 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct io_cq___35 {
	struct request_queue___33 *q;
	struct io_context___35 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___151 {
	struct file___151 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___151 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___150 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___151 *ia_file;
};

struct dquot___150 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___150 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___150 {
	int qf_fmt_id;
	const struct quota_format_ops___150 *qf_ops;
	struct module___129 *qf_owner;
	struct quota_format_type___150 *qf_next;
};

struct quota_format_ops___150 {
	int (*check_quota_file)(struct super_block___150 *, int);
	int (*read_file_info)(struct super_block___150 *, int);
	int (*write_file_info)(struct super_block___150 *, int);
	int (*free_file_info)(struct super_block___150 *, int);
	int (*read_dqblk)(struct dquot___150 *);
	int (*commit_dqblk)(struct dquot___150 *);
	int (*release_dqblk)(struct dquot___150 *);
	int (*get_next_id)(struct super_block___150 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___150 {
	int (*write_dquot)(struct dquot___150 *);
	struct dquot___150 * (*alloc_dquot)(struct super_block___150 *, int);
	void (*destroy_dquot)(struct dquot___150 *);
	int (*acquire_dquot)(struct dquot___150 *);
	int (*release_dquot)(struct dquot___150 *);
	int (*mark_dirty)(struct dquot___150 *);
	int (*write_info)(struct super_block___150 *, int);
	qsize_t * (*get_reserved_space)(struct inode___151 *);
	int (*get_projid)(struct inode___151 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___151 *, qsize_t *);
	int (*get_next_id)(struct super_block___150 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___150 {
	int (*quota_on)(struct super_block___150 *, int, int, const struct path___150 *);
	int (*quota_off)(struct super_block___150 *, int);
	int (*quota_enable)(struct super_block___150 *, unsigned int);
	int (*quota_disable)(struct super_block___150 *, unsigned int);
	int (*quota_sync)(struct super_block___150 *, int);
	int (*set_info)(struct super_block___150 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___150 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___150 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___150 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___150 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___150 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___126 {
	struct kobject___145 kobj;
	struct module___129 *mod;
	struct kobject___145 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___126 {
	struct module___129 *mod;
	struct latch_tree_node node;
};

struct module_layout___126 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___126 mtn;
};

struct module_attribute___126;

struct kernel_param___126;

struct module___129 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___126 mkobj;
	struct module_attribute___126 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___145 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___126 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___126 core_layout;
	struct module_layout___126 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___87 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide45;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide46;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___67;

struct swap_info_struct___47;

struct address_space_operations___150 {
	int (*writepage)(struct page___151 *, struct writeback_control___67 *);
	int (*readpage)(struct file___151 *, struct page___151 *);
	int (*writepages)(struct address_space___150 *, struct writeback_control___67 *);
	int (*set_page_dirty)(struct page___151 *);
	int (*readpages)(struct file___151 *, struct address_space___150 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___151 *, struct address_space___150 *, loff_t, unsigned int, unsigned int, struct page___151 **, void **);
	int (*write_end)(struct file___151 *, struct address_space___150 *, loff_t, unsigned int, unsigned int, struct page___151 *, void *);
	sector_t (*bmap)(struct address_space___150 *, sector_t);
	void (*invalidatepage)(struct page___151 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___151 *, gfp_t);
	void (*freepage)(struct page___151 *);
	ssize_t (*direct_IO)(struct kiocb___151 *, struct iov_iter___69 *);
	int (*migratepage)(struct address_space___150 *, struct page___151 *, struct page___151 *, enum migrate_mode);
	bool (*isolate_page)(struct page___151 *, isolate_mode_t);
	void (*putback_page)(struct page___151 *);
	int (*launder_page)(struct page___151 *);
	int (*is_partially_uptodate)(struct page___151 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___151 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___150 *, struct page___151 *);
	int (*swap_activate)(struct swap_info_struct___47 *, struct file___151 *, sector_t *);
	void (*swap_deactivate)(struct file___151 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___67 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___70 *wb;
	struct inode___151 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___70;

struct iov_iter___69 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___70 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct swap_info_struct___47 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___151 *bdev;
	struct file___151 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct hd_struct___33;

struct gendisk___33;

struct block_device___151 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___151 *bd_inode;
	struct super_block___150 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___151 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___33 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___33 *bd_disk;
	struct request_queue___33 *bd_queue;
	struct backing_dev_info___70 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct hd_struct___33 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___141 __dev;
	struct kobject___145 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___33;

struct block_device_operations___33;

struct gendisk___33 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___33 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___33 *part_tbl;
	struct hd_struct___33 part0;
	const struct block_device_operations___33 *fops;
	struct request_queue___33 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___151 lookup_sem;
	struct kobject___145 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___145 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___150 {
	struct dentry___150 * (*lookup)(struct inode___151 *, struct dentry___150 *, unsigned int);
	const char * (*get_link)(struct dentry___150 *, struct inode___151 *, struct delayed_call *);
	int (*permission)(struct inode___151 *, int);
	struct posix_acl * (*get_acl)(struct inode___151 *, int);
	int (*readlink)(struct dentry___150 *, char *, int);
	int (*create)(struct inode___151 *, struct dentry___150 *, umode_t, bool);
	int (*link)(struct dentry___150 *, struct inode___151 *, struct dentry___150 *);
	int (*unlink)(struct inode___151 *, struct dentry___150 *);
	int (*symlink)(struct inode___151 *, struct dentry___150 *, const char *);
	int (*mkdir)(struct inode___151 *, struct dentry___150 *, umode_t);
	int (*rmdir)(struct inode___151 *, struct dentry___150 *);
	int (*mknod)(struct inode___151 *, struct dentry___150 *, umode_t, dev_t);
	int (*rename)(struct inode___151 *, struct dentry___150 *, struct inode___151 *, struct dentry___150 *, unsigned int);
	int (*setattr)(struct dentry___150 *, struct iattr___150 *);
	int (*getattr)(const struct path___150 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___150 *, char *, size_t);
	int (*fiemap)(struct inode___151 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___151 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___151 *, struct dentry___150 *, struct file___151 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___151 *, struct dentry___150 *, umode_t);
	int (*set_acl)(struct inode___151 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___150 {
	void (*fl_copy_lock)(struct file_lock___151 *, struct file_lock___151 *);
	void (*fl_release_private)(struct file_lock___151 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___150;

struct file_lock___151 {
	struct file_lock___151 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___151 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___150 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___150 *fl_ops;
	const struct lock_manager_operations___150 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___150 {
	int (*lm_compare_owner)(struct file_lock___151 *, struct file_lock___151 *);
	long unsigned int (*lm_owner_key)(struct file_lock___151 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___151 *);
	int (*lm_grant)(struct file_lock___151 *, int);
	bool (*lm_break)(struct file_lock___151 *);
	int (*lm_change)(struct file_lock___151 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___151 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___150 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___150 *fa_next;
	struct file___151 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___150 {
	const char *name;
	int fs_flags;
	struct dentry___150 * (*mount)(struct file_system_type___150 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___150 *);
	struct module___129 *owner;
	struct file_system_type___150 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___150 {
	struct inode___151 * (*alloc_inode)(struct super_block___150 *);
	void (*destroy_inode)(struct inode___151 *);
	void (*dirty_inode)(struct inode___151 *, int);
	int (*write_inode)(struct inode___151 *, struct writeback_control___67 *);
	int (*drop_inode)(struct inode___151 *);
	void (*evict_inode)(struct inode___151 *);
	void (*put_super)(struct super_block___150 *);
	int (*sync_fs)(struct super_block___150 *, int);
	int (*freeze_super)(struct super_block___150 *);
	int (*freeze_fs)(struct super_block___150 *);
	int (*thaw_super)(struct super_block___150 *);
	int (*unfreeze_fs)(struct super_block___150 *);
	int (*statfs)(struct dentry___150 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___150 *, int *, char *);
	void (*umount_begin)(struct super_block___150 *);
	int (*show_options)(struct seq_file___141 *, struct dentry___150 *);
	int (*show_devname)(struct seq_file___141 *, struct dentry___150 *);
	int (*show_path)(struct seq_file___141 *, struct dentry___150 *);
	int (*show_stats)(struct seq_file___141 *, struct dentry___150 *);
	ssize_t (*quota_read)(struct super_block___150 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___150 *, int, const char *, size_t, loff_t);
	struct dquot___150 ** (*get_dquots)(struct inode___151 *);
	int (*bdev_try_to_free_page)(struct super_block___150 *, struct page___151 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___150 *, struct shrink_control___65 *);
	long int (*free_cached_objects)(struct super_block___150 *, struct shrink_control___65 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct xattr_handler___12 {
	const char *name;
	const char *prefix;
	int flags;
	bool (*list)(struct dentry___150 *);
	int (*get)(const struct xattr_handler___12 *, struct dentry___150 *, struct inode___151 *, const char *, void *, size_t);
	int (*set)(const struct xattr_handler___12 *, struct dentry___150 *, struct inode___151 *, const char *, const void *, size_t, int);
};

typedef void (*poll_queue_proc___102)(struct file___151 *, wait_queue_head_t *, struct poll_table_struct___103 *);

struct poll_table_struct___103 {
	poll_queue_proc___102 _qproc;
	__poll_t _key;
};

struct seq_operations___139;

struct seq_file___141 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___139 *op;
	int poll_event;
	const struct file___151 *file;
	void *private;
};

typedef void bio_end_io_t___70(struct bio___70 *);

struct bio_vec___70 {
	struct page___151 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___70;

struct bio___70 {
	struct bio___70 *bi_next;
	struct gendisk___33 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___70 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___23 *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___70 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___70 *bi_io_vec;
	struct bio_set___70 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___70 bi_inline_vecs[0];
};

struct kobj_attribute___145 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___145 *, struct kobj_attribute___145 *, char *);
	ssize_t (*store)(struct kobject___145 *, struct kobj_attribute___145 *, const char *, size_t);
};

typedef void compound_page_dtor___148(struct page___151 *);

typedef int (*key_restrict_link_func_t___146)(struct key___146 *, const struct key_type *, const union key_payload *, struct key___146 *);

struct key_restriction___146;

struct key___146 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___151 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___146 *restrict_link;
};

struct key_restriction___146 {
	key_restrict_link_func_t___146 check;
	struct key___146 *key;
	struct key_type *keytype;
};

struct seq_operations___139 {
	void * (*start)(struct seq_file___141 *, loff_t *);
	void (*stop)(struct seq_file___141 *, void *);
	void * (*next)(struct seq_file___141 *, void *, loff_t *);
	int (*show)(struct seq_file___141 *, void *);
};

struct kernfs_root___147;

struct kernfs_elem_dir___147 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___147 *root;
};

struct kernfs_syscall_ops___147;

struct kernfs_root___147 {
	struct kernfs_node___147 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___147 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___147 {
	struct kernfs_node___147 *target_kn;
};

struct kernfs_ops___147;

struct kernfs_elem_attr___147 {
	const struct kernfs_ops___147 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___147 *notify_next;
};

struct kernfs_node___147 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___147 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___147 dir;
		struct kernfs_elem_symlink___147 symlink;
		struct kernfs_elem_attr___147 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___147;

struct kernfs_ops___147 {
	int (*open)(struct kernfs_open_file___147 *);
	void (*release)(struct kernfs_open_file___147 *);
	int (*seq_show)(struct seq_file___141 *, void *);
	void * (*seq_start)(struct seq_file___141 *, loff_t *);
	void * (*seq_next)(struct seq_file___141 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___141 *, void *);
	ssize_t (*read)(struct kernfs_open_file___147 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___147 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___147 *, struct vm_area_struct___151 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___147 *, struct poll_table_struct___103 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___147 {
	int (*remount_fs)(struct kernfs_root___147 *, int *, char *);
	int (*show_options)(struct seq_file___141 *, struct kernfs_root___147 *);
	int (*mkdir)(struct kernfs_node___147 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___147 *);
	int (*rename)(struct kernfs_node___147 *, struct kernfs_node___147 *, const char *);
	int (*show_path)(struct seq_file___141 *, struct kernfs_node___147 *, struct kernfs_root___147 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___147 {
	struct kernfs_node___147 *kn;
	struct file___151 *file;
	struct seq_file___141 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___148 *vm_ops;
};

struct cgroup_namespace___127 {
	refcount_t count;
	struct ns_common___4 ns;
	struct user_namespace___131 *user_ns;
	struct ucounts___131 *ucounts;
	struct css_set___127 *root_cset;
};

struct ucounts___131 {
	struct hlist_node node;
	struct user_namespace___131 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___127;

struct bpf_map_ops___127 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___127 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___127 *, struct file___151 *);
	void (*map_free)(struct bpf_map___127 *);
	int (*map_get_next_key)(struct bpf_map___127 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___127 *);
	void * (*map_lookup_elem)(struct bpf_map___127 *, void *);
	int (*map_update_elem)(struct bpf_map___127 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___127 *, void *);
	int (*map_push_elem)(struct bpf_map___127 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___127 *, void *);
	int (*map_peek_elem)(struct bpf_map___127 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___127 *, struct file___151 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___127 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___127 *, void *, struct seq_file___141 *);
	int (*map_check_btf)(const struct bpf_map___127 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___127 {
	const struct bpf_map_ops___127 *ops;
	struct bpf_map___127 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___146 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___127;

typedef void (*kthread_work_func_t___127)(struct kthread_work___127 *);

struct kthread_worker___127;

struct kthread_work___127 {
	struct list_head node;
	kthread_work_func_t___127 func;
	struct kthread_worker___127 *worker;
	int canceling;
};

struct kthread_worker___127 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___151 *task;
	struct kthread_work___127 *current_work;
};

struct kthread_delayed_work___127 {
	struct kthread_work___127 work;
	struct timer_list timer;
};

struct psi_group___127 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___127 *poll_kworker;
	struct kthread_delayed_work___127 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___127;

struct cgroup_rstat_cpu___127;

struct cgroup___127 {
	struct cgroup_subsys_state___127 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___147 *kn;
	struct cgroup_file___127 procs_file;
	struct cgroup_file___127 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___127 *subsys[13];
	struct cgroup_root___127 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___127 *dom_cgrp;
	struct cgroup_rstat_cpu___127 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___4 bpf;
	atomic_t congestion_count;
	struct cgroup___127 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___127 psi;
	int ancestor_ids[0];
};

struct cftype___127;

struct cgroup_subsys___127 {
	struct cgroup_subsys_state___127 * (*css_alloc)(struct cgroup_subsys_state___127 *);
	int (*css_online)(struct cgroup_subsys_state___127 *);
	void (*css_offline)(struct cgroup_subsys_state___127 *);
	void (*css_released)(struct cgroup_subsys_state___127 *);
	void (*css_free)(struct cgroup_subsys_state___127 *);
	void (*css_reset)(struct cgroup_subsys_state___127 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___127 *, int);
	int (*css_extra_stat_show)(struct seq_file___141 *, struct cgroup_subsys_state___127 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___151 *);
	void (*cancel_fork)(struct task_struct___151 *);
	void (*fork)(struct task_struct___151 *);
	void (*exit)(struct task_struct___151 *);
	void (*free)(struct task_struct___151 *);
	void (*bind)(struct cgroup_subsys_state___127 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___127 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___127 *dfl_cftypes;
	struct cftype___127 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___127 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___127 *updated_children;
	struct cgroup___127 *updated_next;
};

struct cgroup_root___127 {
	struct kernfs_root___147 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___127 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___127 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___127 *ss;
	struct list_head node;
	struct kernfs_ops___147 *kf_ops;
	int (*open)(struct kernfs_open_file___147 *);
	void (*release)(struct kernfs_open_file___147 *);
	u64 (*read_u64)(struct cgroup_subsys_state___127 *, struct cftype___127 *);
	s64 (*read_s64)(struct cgroup_subsys_state___127 *, struct cftype___127 *);
	int (*seq_show)(struct seq_file___141 *, void *);
	void * (*seq_start)(struct seq_file___141 *, loff_t *);
	void * (*seq_next)(struct seq_file___141 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___141 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___127 *, struct cftype___127 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___127 *, struct cftype___127 *, s64);
	ssize_t (*write)(struct kernfs_open_file___147 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___147 *, struct poll_table_struct___103 *);
};

struct bin_attribute___140;

struct attribute_group___141 {
	const char *name;
	umode_t (*is_visible)(struct kobject___145 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___145 *, struct bin_attribute___140 *, int);
	struct attribute **attrs;
	struct bin_attribute___140 **bin_attrs;
};

typedef int filler_t___3(void *, struct page___151 *);

struct hstate___27 {
	int next_nid_to_alloc;
	int next_nid_to_free;
	unsigned int order;
	long unsigned int mask;
	long unsigned int max_huge_pages;
	long unsigned int nr_huge_pages;
	long unsigned int free_huge_pages;
	long unsigned int resv_huge_pages;
	long unsigned int surplus_huge_pages;
	long unsigned int nr_overcommit_huge_pages;
	struct list_head hugepage_activelist;
	struct list_head hugepage_freelists[8];
	unsigned int nr_huge_pages_node[8];
	unsigned int free_huge_pages_node[8];
	unsigned int surplus_huge_pages_node[8];
	struct cftype___127 cgroup_files[5];
	char name[32];
};

struct bdi_writeback_congested___70 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___70 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___70 {
	struct bio___70 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___70 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___70 bip_inline_vecs[0];
};

struct blkcg___23;

struct blkg_policy_data___23;

struct blkcg_gq___23 {
	struct request_queue___33 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___23 *blkcg;
	struct bdi_writeback_congested___70 *wb_congested;
	struct blkcg_gq___23 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_rwstat stat_bytes;
	struct blkg_rwstat stat_ios;
	struct blkg_policy_data___23 *pd[5];
	struct callback_head callback_head;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
};

struct mem_cgroup_reclaim_iter___65 {
	struct mem_cgroup___65 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___65 {
	struct lruvec___150 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___65 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___65 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct bin_attribute___140 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___151 *, struct kobject___145 *, struct bin_attribute___140 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___151 *, struct kobject___145 *, struct bin_attribute___140 *, char *, loff_t, size_t);
	int (*mmap)(struct file___151 *, struct kobject___145 *, struct bin_attribute___140 *, struct vm_area_struct___151 *);
};

struct sysfs_ops___144 {
	ssize_t (*show)(struct kobject___145 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___145 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___144;

struct kset___144 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___145 kobj;
	const struct kset_uevent_ops___144 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___144 {
	void (*release)(struct kobject___145 *);
	const struct sysfs_ops___144 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___2 * (*child_ns_type)(struct kobject___145 *);
	const void * (*namespace)(struct kobject___145 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___144 {
	int (* const filter)(struct kset___144 *, struct kobject___145 *);
	const char * (* const name)(struct kset___144 *, struct kobject___145 *);
	int (* const uevent)(struct kset___144 *, struct kobject___145 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___141 {
	int (*prepare)(struct device___141 *);
	void (*complete)(struct device___141 *);
	int (*suspend)(struct device___141 *);
	int (*resume)(struct device___141 *);
	int (*freeze)(struct device___141 *);
	int (*thaw)(struct device___141 *);
	int (*poweroff)(struct device___141 *);
	int (*restore)(struct device___141 *);
	int (*suspend_late)(struct device___141 *);
	int (*resume_early)(struct device___141 *);
	int (*freeze_late)(struct device___141 *);
	int (*thaw_early)(struct device___141 *);
	int (*poweroff_late)(struct device___141 *);
	int (*restore_early)(struct device___141 *);
	int (*suspend_noirq)(struct device___141 *);
	int (*resume_noirq)(struct device___141 *);
	int (*freeze_noirq)(struct device___141 *);
	int (*thaw_noirq)(struct device___141 *);
	int (*poweroff_noirq)(struct device___141 *);
	int (*restore_noirq)(struct device___141 *);
	int (*runtime_suspend)(struct device___141 *);
	int (*runtime_resume)(struct device___141 *);
	int (*runtime_idle)(struct device___141 *);
};

struct dev_pm_domain___141 {
	struct dev_pm_ops___141 ops;
	void (*detach)(struct device___141 *, bool);
	int (*activate)(struct device___141 *);
	void (*sync)(struct device___141 *);
	void (*dismiss)(struct device___141 *);
};

struct bus_type___141 {
	const char *name;
	const char *dev_name;
	struct device___141 *dev_root;
	const struct attribute_group___141 **bus_groups;
	const struct attribute_group___141 **dev_groups;
	const struct attribute_group___141 **drv_groups;
	int (*match)(struct device___141 *, struct device_driver___141 *);
	int (*uevent)(struct device___141 *, struct kobj_uevent_env *);
	int (*probe)(struct device___141 *);
	int (*remove)(struct device___141 *);
	void (*shutdown)(struct device___141 *);
	int (*online)(struct device___141 *);
	int (*offline)(struct device___141 *);
	int (*suspend)(struct device___141 *, pm_message_t);
	int (*resume)(struct device___141 *);
	int (*num_vf)(struct device___141 *);
	int (*dma_configure)(struct device___141 *);
	const struct dev_pm_ops___141 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___141 {
	const char *name;
	struct bus_type___141 *bus;
	struct module___129 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___141 *);
	int (*remove)(struct device___141 *);
	void (*shutdown)(struct device___141 *);
	int (*suspend)(struct device___141 *, pm_message_t);
	int (*resume)(struct device___141 *);
	const struct attribute_group___141 **groups;
	const struct dev_pm_ops___141 *pm;
	void (*coredump)(struct device___141 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___141 {
	const char *name;
	const struct attribute_group___141 **groups;
	int (*uevent)(struct device___141 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___141 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___141 *);
	const struct dev_pm_ops___141 *pm;
};

struct class___141 {
	const char *name;
	struct module___129 *owner;
	const struct attribute_group___141 **class_groups;
	const struct attribute_group___141 **dev_groups;
	struct kobject___145 *dev_kobj;
	int (*dev_uevent)(struct device___141 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___141 *, umode_t *);
	void (*class_release)(struct class___141 *);
	void (*dev_release)(struct device___141 *);
	int (*shutdown_pre)(struct device___141 *);
	const struct kobj_ns_type_operations___2 *ns_type;
	const void * (*namespace)(struct device___141 *);
	const struct dev_pm_ops___141 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct fwnode_operations___103;

struct fwnode_handle___103 {
	struct fwnode_handle___103 *secondary;
	const struct fwnode_operations___103 *ops;
};

struct node___119 {
	struct device___141 dev;
};

union swap_header {
	struct {
		char reserved[65526];
		char magic[10];
	} magic;
	struct {
		char bootbits[1024];
		__u32 version;
		__u32 last_page;
		__u32 nr_badpages;
		unsigned char sws_uuid[16];
		unsigned char sws_volume[16];
		__u32 padding[117];
		__u32 badpages[1];
	} info;
};

struct disk_part_tbl___33 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___33 *last_lookup;
	struct hd_struct___33 *part[0];
};

struct block_device_operations___33 {
	int (*open)(struct block_device___151 *, fmode_t);
	void (*release)(struct gendisk___33 *, fmode_t);
	int (*rw_page)(struct block_device___151 *, sector_t, struct page___151 *, unsigned int);
	int (*ioctl)(struct block_device___151 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___151 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___33 *, unsigned int);
	int (*media_changed)(struct gendisk___33 *);
	void (*unlock_native_capacity)(struct gendisk___33 *);
	int (*revalidate_disk)(struct gendisk___33 *);
	int (*getgeo)(struct block_device___151 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___151 *, long unsigned int);
	int (*report_zones)(struct gendisk___33 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___129 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___32 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___33 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___33 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___33 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___32(struct request___33 *, blk_status_t);

struct request___33 {
	struct request_queue___33 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___70 *bio;
	struct bio___70 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___70 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___35 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___32 *saved_end_io;
		} flush;
	};
	struct gendisk___33 *rq_disk;
	struct hd_struct___33 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___32 *end_io;
	void *end_io_data;
	struct request___33 *next_rq;
};

struct fwnode_reference_args___103;

struct fwnode_endpoint___103;

struct fwnode_operations___103 {
	struct fwnode_handle___103 * (*get)(struct fwnode_handle___103 *);
	void (*put)(struct fwnode_handle___103 *);
	bool (*device_is_available)(const struct fwnode_handle___103 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___103 *, const struct device___141 *);
	bool (*property_present)(const struct fwnode_handle___103 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___103 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___103 *, const char *, const char **, size_t);
	struct fwnode_handle___103 * (*get_parent)(const struct fwnode_handle___103 *);
	struct fwnode_handle___103 * (*get_next_child_node)(const struct fwnode_handle___103 *, struct fwnode_handle___103 *);
	struct fwnode_handle___103 * (*get_named_child_node)(const struct fwnode_handle___103 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___103 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___103 *);
	struct fwnode_handle___103 * (*graph_get_next_endpoint)(const struct fwnode_handle___103 *, struct fwnode_handle___103 *);
	struct fwnode_handle___103 * (*graph_get_remote_endpoint)(const struct fwnode_handle___103 *);
	struct fwnode_handle___103 * (*graph_get_port_parent)(struct fwnode_handle___103 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___103 *, struct fwnode_endpoint___103 *);
};

struct fwnode_endpoint___103 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___103 *local_fwnode;
};

struct fwnode_reference_args___103 {
	struct fwnode_handle___103 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct elevator_type___32;

struct elevator_mq_ops___32 {
	int (*init_sched)(struct request_queue___33 *, struct elevator_type___32 *);
	void (*exit_sched)(struct elevator_queue___32 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	bool (*allow_merge)(struct request_queue___33 *, struct request___33 *, struct bio___70 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx *, struct bio___70 *);
	int (*request_merge)(struct request_queue___33 *, struct request___33 **, struct bio___70 *);
	void (*request_merged)(struct request_queue___33 *, struct request___33 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___33 *, struct request___33 *, struct request___33 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___33 *, struct bio___70 *);
	void (*finish_request)(struct request___33 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___33 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___33 *, u64);
	void (*started_request)(struct request___33 *);
	void (*requeue_request)(struct request___33 *);
	struct request___33 * (*former_request)(struct request_queue___33 *, struct request___33 *);
	struct request___33 * (*next_request)(struct request_queue___33 *, struct request___33 *);
	void (*init_icq)(struct io_cq___35 *);
	void (*exit_icq)(struct io_cq___35 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___32;

struct elevator_type___32 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___32 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___32 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___129 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___32 {
	struct elevator_type___32 *type;
	void *elevator_data;
	struct kobject___145 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___32 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___32 *, char *);
	ssize_t (*store)(struct elevator_queue___32 *, const char *, size_t);
};

struct blkcg_policy_data___23;

struct blkcg___23 {
	struct cgroup_subsys_state___127 css;
	spinlock_t lock;
	struct xarray blkg_tree;
	struct blkcg_gq___23 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___23 *cpd[5];
	struct list_head all_blkcgs_node;
	struct list_head cgwb_list;
	refcount_t cgwb_refcnt;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct blkcg_policy_data___23 {
	struct blkcg___23 *blkcg;
	int plid;
};

struct blkg_policy_data___23 {
	struct blkcg_gq___23 *blkg;
	int plid;
};

typedef struct poll_table_struct___103 poll_table___10;

struct kernel_param_ops___126 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___126 *);
	int (*get)(char *, const struct kernel_param___126 *);
	void (*free)(void *);
};

struct kparam_array___126;

struct kernel_param___126 {
	const char *name;
	struct module___129 *mod;
	const struct kernel_param_ops___126 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___126 *arr;
	};
};

struct kparam_array___126 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___126 *ops;
	void *elem;
};

struct module_attribute___126 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___126 *, struct module_kobject___126 *, char *);
	ssize_t (*store)(struct module_attribute___126 *, struct module_kobject___126 *, const char *, size_t);
	void (*setup)(struct module___129 *, const char *);
	int (*test)(struct module___129 *);
	void (*free)(struct module___129 *);
};

struct trace_event_class___87;

struct trace_event_call___87 {
	struct list_head list;
	struct trace_event_class___87 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___4 *prog_array;
	int (*perf_perm)(struct trace_event_call___87 *, struct perf_event___94 *);
};

struct perf_cpu_context___94;

struct pmu___94 {
	struct list_head entry;
	struct module___129 *module;
	struct device___141 *dev;
	const struct attribute_group___141 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___94 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___94 *);
	void (*pmu_disable)(struct pmu___94 *);
	int (*event_init)(struct perf_event___94 *);
	void (*event_mapped)(struct perf_event___94 *, struct mm_struct___150 *);
	void (*event_unmapped)(struct perf_event___94 *, struct mm_struct___150 *);
	int (*add)(struct perf_event___94 *, int);
	void (*del)(struct perf_event___94 *, int);
	void (*start)(struct perf_event___94 *, int);
	void (*stop)(struct perf_event___94 *, int);
	void (*read)(struct perf_event___94 *);
	void (*start_txn)(struct pmu___94 *, unsigned int);
	int (*commit_txn)(struct pmu___94 *);
	void (*cancel_txn)(struct pmu___94 *);
	int (*event_idx)(struct perf_event___94 *);
	void (*sched_task)(struct perf_event_context___94 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___94 *);
	int (*filter_match)(struct perf_event___94 *);
	int (*check_period)(struct perf_event___94 *, u64);
};

struct perf_cpu_context___94 {
	struct perf_event_context___94 ctx;
	struct perf_event_context___94 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___94 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___94 {
	struct cgroup_subsys_state___127 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___87 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___87 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___87 *);
	struct list_head * (*get_fields)(struct trace_event_call___87 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___87 *);
};

struct syscall_metadata___34 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___87 *enter_event;
	struct trace_event_call___87 *exit_event;
};

struct swap_slots_cache {
	bool lock_initialized;
	struct mutex alloc_lock;
	swp_entry_t *slots;
	int nr;
	int cur;
	spinlock_t free_lock;
	swp_entry_t *slots_ret;
	int n_ret;
};

struct frontswap_ops {
	void (*init)(unsigned int);
	int (*store)(unsigned int, long unsigned int, struct page___130 *);
	int (*load)(unsigned int, long unsigned int, struct page___130 *);
	void (*invalidate_page)(unsigned int, long unsigned int);
	void (*invalidate_area)(unsigned int);
	struct frontswap_ops *next;
};

struct frontswap_ops___2 {
	void (*init)(unsigned int);
	int (*store)(unsigned int, long unsigned int, struct page___36 *);
	int (*load)(unsigned int, long unsigned int, struct page___36 *);
	void (*invalidate_page)(unsigned int, long unsigned int);
	void (*invalidate_area)(unsigned int);
	struct frontswap_ops___2 *next;
};

struct crypto_async_request___4;

typedef void (*crypto_completion_t___4)(struct crypto_async_request___4 *, int);

struct crypto_tfm___4;

struct crypto_async_request___4 {
	struct list_head list;
	crypto_completion_t___4 complete;
	void *data;
	struct crypto_tfm___4 *tfm;
	u32 flags;
};

struct crypto_ablkcipher___4;

struct ablkcipher_request___4;

struct ablkcipher_tfm___4 {
	int (*setkey)(struct crypto_ablkcipher___4 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___4 *);
	int (*decrypt)(struct ablkcipher_request___4 *);
	struct crypto_ablkcipher___4 *base;
	unsigned int ivsize;
	unsigned int reqsize;
};

struct blkcipher_desc___4;

struct blkcipher_tfm___4 {
	void *iv;
	int (*setkey)(struct crypto_tfm___4 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___4 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___4 *, struct scatterlist *, struct scatterlist *, unsigned int);
};

struct cipher_tfm___4 {
	int (*cit_setkey)(struct crypto_tfm___4 *, const u8 *, unsigned int);
	void (*cit_encrypt_one)(struct crypto_tfm___4 *, u8 *, const u8 *);
	void (*cit_decrypt_one)(struct crypto_tfm___4 *, u8 *, const u8 *);
};

struct compress_tfm___4 {
	int (*cot_compress)(struct crypto_tfm___4 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*cot_decompress)(struct crypto_tfm___4 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___4;

struct crypto_tfm___4 {
	u32 crt_flags;
	union {
		struct ablkcipher_tfm___4 ablkcipher;
		struct blkcipher_tfm___4 blkcipher;
		struct cipher_tfm___4 cipher;
		struct compress_tfm___4 compress;
	} crt_u;
	void (*exit)(struct crypto_tfm___4 *);
	struct crypto_alg___4 *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct ablkcipher_request___4 {
	struct crypto_async_request___4 base;
	unsigned int nbytes;
	void *info;
	struct scatterlist *src;
	struct scatterlist *dst;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_blkcipher___4;

struct blkcipher_desc___4 {
	struct crypto_blkcipher___4 *tfm;
	void *info;
	u32 flags;
};

struct crypto_blkcipher___4 {
	struct crypto_tfm___4 base;
};

struct ablkcipher_alg___4 {
	int (*setkey)(struct crypto_ablkcipher___4 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___4 *);
	int (*decrypt)(struct ablkcipher_request___4 *);
	int (*givencrypt)(struct skcipher_givcrypt_request *);
	int (*givdecrypt)(struct skcipher_givcrypt_request *);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct crypto_ablkcipher___4 {
	struct crypto_tfm___4 base;
};

struct blkcipher_alg___4 {
	int (*setkey)(struct crypto_tfm___4 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___4 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___4 *, struct scatterlist *, struct scatterlist *, unsigned int);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct cipher_alg___4 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___4 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___4 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___4 *, u8 *, const u8 *);
};

struct compress_alg___4 {
	int (*coa_compress)(struct crypto_tfm___4 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___4 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___4 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type *cra_type;
	union {
		struct ablkcipher_alg___4 ablkcipher;
		struct blkcipher_alg___4 blkcipher;
		struct cipher_alg___4 cipher;
		struct compress_alg___4 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___4 *);
	void (*cra_exit)(struct crypto_tfm___4 *);
	void (*cra_destroy)(struct crypto_alg___4 *);
	struct module___33 *cra_module;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct crypto_comp {
	struct crypto_tfm___4 base;
};

struct zpool;

struct zpool_ops {
	int (*evict)(struct zpool *, long unsigned int);
};

enum zpool_mapmode {
	ZPOOL_MM_RW = 0,
	ZPOOL_MM_RO = 1,
	ZPOOL_MM_WO = 2,
	ZPOOL_MM_DEFAULT = 0,
};

struct zswap_pool {
	struct zpool *zpool;
	struct crypto_comp **tfm;
	struct kref kref;
	struct list_head list;
	struct work_struct work;
	struct hlist_node node;
	char tfm_name[128];
};

struct zswap_entry {
	struct rb_node rbnode;
	long unsigned int offset;
	int refcount;
	unsigned int length;
	struct zswap_pool *pool;
	union {
		long unsigned int handle;
		long unsigned int value;
	};
};

struct zswap_header {
	swp_entry_t swpentry;
};

struct zswap_tree {
	struct rb_root rbroot;
	spinlock_t lock;
};

enum zswap_get_swap_ret {
	ZSWAP_SWAPCACHE_NEW = 0,
	ZSWAP_SWAPCACHE_EXIST = 1,
	ZSWAP_SWAPCACHE_FAIL = 2,
};

struct device_attribute___10 {
	struct attribute attr;
	ssize_t (*show)(struct device___58 *, struct device_attribute___10 *, char *);
	ssize_t (*store)(struct device___58 *, struct device_attribute___10 *, const char *, size_t);
};

typedef void (*dr_release_t___5)(struct device___58 *, void *);

struct dma_pool {
	struct list_head page_list;
	spinlock_t lock;
	size_t size;
	struct device___58 *dev;
	size_t allocation;
	size_t boundary;
	char name[32];
	struct list_head pools;
};

struct dma_page {
	struct list_head page_list;
	void *vaddr;
	dma_addr_t dma;
	unsigned int in_use;
	unsigned int offset;
};

struct file___152;

struct kiocb___152;

struct vm_area_struct___152;

struct inode___152;

struct file_lock___152;

struct page___152;

struct seq_file___142;

struct file_operations___152 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___152 *, loff_t, int);
	ssize_t (*read)(struct file___152 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___152 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___152 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___152 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___152 *, bool);
	int (*iterate)(struct file___152 *, struct dir_context *);
	int (*iterate_shared)(struct file___152 *, struct dir_context *);
	__poll_t (*poll)(struct file___152 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___152 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___152 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___152 *, struct vm_area_struct___152 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___152 *, struct file___152 *);
	int (*flush)(struct file___152 *, fl_owner_t);
	int (*release)(struct inode___152 *, struct file___152 *);
	int (*fsync)(struct file___152 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___152 *, int);
	int (*lock)(struct file___152 *, int, struct file_lock___152 *);
	ssize_t (*sendpage)(struct file___152 *, struct page___152 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___152 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___152 *, int, struct file_lock___152 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___152 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___152 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___152 *, long int, struct file_lock___152 **, void **);
	long int (*fallocate)(struct file___152 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___142 *, struct file___152 *);
	ssize_t (*copy_file_range)(struct file___152 *, loff_t, struct file___152 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___152 *, loff_t, struct file___152 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___152 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___151 {
	u64 seqnum;
	struct vm_area_struct___152 *vmas[4];
};

struct page_frag___151 {
	struct page___152 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___151;

struct mem_cgroup___66;

struct cred___147;

struct nsproxy___144;

struct signal_struct___136;

struct bio_list___71;

struct backing_dev_info___71;

struct css_set___128;

struct vm_struct___114;

struct task_struct___152 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___152 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___151 *mm;
	struct mm_struct___151 *active_mm;
	struct vmacache___151 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___152 *real_parent;
	struct task_struct___152 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___152 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___66 *active_memcg;
	long int rh_reserved2;
	struct pid___121 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___121 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___121 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___147 *ptracer_cred;
	const struct cred___147 *real_cred;
	const struct cred___147 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___144 *nsproxy;
	struct signal_struct___136 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___152 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___71 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___71 *backing_dev_info;
	struct io_context___35 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___128 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___151 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___66 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___152 *oom_reaper_list;
	struct vm_struct___114 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___94 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___152 *pgtable_t___151;

struct address_space___151;

struct dev_pagemap___149;

struct page___152 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___151 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___152 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___151 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___151 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___149 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___66 *mem_cgroup;
};

struct pglist_data___151;

struct lruvec___151 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___151 *pgdat;
};

struct zone___151 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___151 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___151 {
	struct zone___151 *zone;
	int zone_idx;
};

struct zonelist___151 {
	struct zoneref___151 _zonerefs[25];
};

struct pglist_data___151 {
	struct zone___151 node_zones[3];
	struct zonelist___151 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___152 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___152 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___151 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___152 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___152 *owner;
};

struct secondary_data___152 {
	void *stack;
	struct task_struct___152 *task;
	long int status;
};

struct blocking_notifier_head___151 {
	struct rw_semaphore___152 rwsem;
	struct notifier_block *head;
};

struct anon_vma___15;

struct vm_operations_struct___149;

struct vm_area_struct___152 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___152 *vm_next;
	struct vm_area_struct___152 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___151 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma___15 *anon_vma;
	const struct vm_operations_struct___149 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___152 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___151;

struct user_namespace___132;

struct mm_struct___151 {
	struct {
		struct vm_area_struct___152 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___152 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___152 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___151 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___152 *owner;
		struct user_namespace___132 *user_ns;
		struct file___152 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___151 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___151;

struct address_space___151 {
	struct inode___152 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___152 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___151 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___149)(struct vm_area_struct___152 *, long unsigned int, const struct page___152 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___149)(struct page___152 *, void *);

struct device___142;

struct dev_pagemap___149 {
	dev_page_fault_t___149 page_fault;
	dev_page_free_t___149 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___142 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct cgroup___128;

struct cgroup_subsys___128;

struct cgroup_subsys_state___128 {
	struct cgroup___128 *cgroup;
	struct cgroup_subsys___128 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___128 *parent;
};

struct kernfs_node___148;

struct cgroup_file___128 {
	struct kernfs_node___148 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___66;

struct mem_cgroup___66 {
	struct cgroup_subsys_state___128 css;
	struct mem_cgroup_id___8 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___128 events_file;
	struct cgroup_file___128 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___152 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___66 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry___151;

struct path___151 {
	struct vfsmount *mnt;
	struct dentry___151 *dentry;
};

struct file___152 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___151 f_path;
	struct inode___152 *f_inode;
	const struct file_operations___152 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___121 f_owner;
	const struct cred___147 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___151 *f_mapping;
	errseq_t f_wb_err;
};

struct anon_vma___15 {
	struct anon_vma___15 *root;
	struct rw_semaphore___152 rwsem;
	atomic_t refcount;
	unsigned int degree;
	struct anon_vma___15 *parent;
	struct rb_root_cached rb_root;
};

struct vm_fault___149;

struct vm_operations_struct___149 {
	void (*open)(struct vm_area_struct___152 *);
	void (*close)(struct vm_area_struct___152 *);
	int (*split)(struct vm_area_struct___152 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___152 *);
	vm_fault_t (*fault)(struct vm_fault___149 *);
	vm_fault_t (*huge_fault)(struct vm_fault___149 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___149 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___152 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___149 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___149 *);
	int (*access)(struct vm_area_struct___152 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___152 *);
	int (*set_policy)(struct vm_area_struct___152 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___152 *, long unsigned int);
	struct page___152 * (*find_special_page)(struct vm_area_struct___152 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___151 {
	struct task_struct___152 *task;
	struct core_thread___151 *next;
};

struct core_state___151 {
	atomic_t nr_threads;
	struct core_thread___151 dumper;
	struct completion startup;
};

struct key___147;

struct ucounts___132;

struct user_namespace___132 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___132 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___4 ns;
	long unsigned int flags;
	struct key___147 *persistent_keyring_register;
	struct rw_semaphore___152 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___132 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___149 {
	struct vm_area_struct___152 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___152 *cow_page;
	struct mem_cgroup___66 *memcg;
	struct page___152 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___151 prealloc_pte;
};

struct shrink_control___66 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___66 *memcg;
};

struct shrinker___66 {
	long unsigned int (*count_objects)(struct shrinker___66 *, struct shrink_control___66 *);
	long unsigned int (*scan_objects)(struct shrinker___66 *, struct shrink_control___66 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct user_struct___147 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___147 *uid_keyring;
	struct key___147 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___147 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___147 *session_keyring;
	struct key___147 *process_keyring;
	struct key___147 *thread_keyring;
	struct key___147 *request_key_auth;
	void *security;
	struct user_struct___147 *user;
	struct user_namespace___132 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___128;

struct nsproxy___144 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___128 *cgroup_ns;
};

struct signal_struct___136 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___152 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___152 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___121 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___121 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___151 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___121 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___71;

struct bio_list___71 {
	struct bio___71 *head;
	struct bio___71 *tail;
};

struct bdi_writeback_congested___71;

struct bdi_writeback___71 {
	struct backing_dev_info___71 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___71 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___128 *memcg_css;
	struct cgroup_subsys_state___128 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___71 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___71 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___142 *dev;
	struct device___142 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___151 *debug_dir;
	struct dentry___151 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___128 {
	struct cgroup_subsys_state___128 *subsys[13];
	refcount_t refcount;
	struct css_set___128 *dom_cset;
	struct cgroup___128 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___128 *mg_src_cgrp;
	struct cgroup___128 *mg_dst_cgrp;
	struct css_set___128 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct vm_struct___114 {
	struct vm_struct___114 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___152 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___136 {
	struct task_struct___152 task;
	long unsigned int stack[8192];
};

struct kset___145;

struct kobj_type___145;

struct kobject___146 {
	const char *name;
	struct list_head entry;
	struct kobject___146 *parent;
	struct kset___145 *kset;
	struct kobj_type___145 *ktype;
	struct kernfs_node___148 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___142 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___142 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___142;

struct bus_type___142;

struct device_driver___142;

struct dev_pm_domain___142;

struct fwnode_handle___104;

struct class___142;

struct attribute_group___142;

struct device___142 {
	struct device___142 *parent;
	struct device_private *p;
	struct kobject___146 kobj;
	const char *init_name;
	const struct device_type___142 *type;
	struct mutex mutex;
	struct bus_type___142 *bus;
	struct device_driver___142 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___142 power;
	struct dev_pm_domain___142 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___104 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___142 *class;
	const struct attribute_group___142 **groups;
	void (*release)(struct device___142 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___151;

struct super_block___151;

struct dentry___151 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___151 *d_parent;
	struct qstr d_name;
	struct inode___152 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___151 *d_op;
	struct super_block___151 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___151;

struct block_device___152;

struct inode___152 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___151 *i_op;
	struct super_block___151 *i_sb;
	struct address_space___151 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___152 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___71 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___152 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___151 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___152 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___151 {
	int (*d_revalidate)(struct dentry___151 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___151 *, unsigned int);
	int (*d_hash)(const struct dentry___151 *, struct qstr *);
	int (*d_compare)(const struct dentry___151 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___151 *);
	int (*d_init)(struct dentry___151 *);
	void (*d_release)(struct dentry___151 *);
	void (*d_prune)(struct dentry___151 *);
	void (*d_iput)(struct dentry___151 *, struct inode___152 *);
	char * (*d_dname)(struct dentry___151 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___151 *);
	int (*d_manage)(const struct path___151 *, bool);
	struct dentry___151 * (*d_real)(struct dentry___151 *, const struct inode___152 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___151;

struct mem_dqinfo___151 {
	struct quota_format_type___151 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___151;

struct quota_info___151 {
	unsigned int flags;
	struct rw_semaphore___152 dqio_sem;
	struct inode___152 *files[3];
	struct mem_dqinfo___151 info[3];
	const struct quota_format_ops___151 *ops[3];
};

struct rcuwait___151 {
	struct task_struct___152 *task;
};

struct percpu_rw_semaphore___151 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___152 rw_sem;
	struct rcuwait___151 writer;
	int readers_block;
};

struct sb_writers___151 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___151 rw_sem[3];
};

struct file_system_type___151;

struct super_operations___151;

struct dquot_operations___151;

struct quotactl_ops___151;

struct super_block___151 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___151 *s_type;
	const struct super_operations___151 *s_op;
	const struct dquot_operations___151 *dq_op;
	const struct quotactl_ops___151 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___151 *s_root;
	struct rw_semaphore___152 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___152 *s_bdev;
	struct backing_dev_info___71 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___151 s_dquot;
	struct sb_writers___151 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___151 *s_d_op;
	int cleancache_poolid;
	struct shrinker___66 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___132 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___152 {
	struct file___152 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___152 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___151 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___152 *ia_file;
};

struct dquot___151 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___151 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___151 {
	int qf_fmt_id;
	const struct quota_format_ops___151 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___151 *qf_next;
};

struct quota_format_ops___151 {
	int (*check_quota_file)(struct super_block___151 *, int);
	int (*read_file_info)(struct super_block___151 *, int);
	int (*write_file_info)(struct super_block___151 *, int);
	int (*free_file_info)(struct super_block___151 *, int);
	int (*read_dqblk)(struct dquot___151 *);
	int (*commit_dqblk)(struct dquot___151 *);
	int (*release_dqblk)(struct dquot___151 *);
	int (*get_next_id)(struct super_block___151 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___151 {
	int (*write_dquot)(struct dquot___151 *);
	struct dquot___151 * (*alloc_dquot)(struct super_block___151 *, int);
	void (*destroy_dquot)(struct dquot___151 *);
	int (*acquire_dquot)(struct dquot___151 *);
	int (*release_dquot)(struct dquot___151 *);
	int (*mark_dirty)(struct dquot___151 *);
	int (*write_info)(struct super_block___151 *, int);
	qsize_t * (*get_reserved_space)(struct inode___152 *);
	int (*get_projid)(struct inode___152 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___152 *, qsize_t *);
	int (*get_next_id)(struct super_block___151 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___151 {
	int (*quota_on)(struct super_block___151 *, int, int, const struct path___151 *);
	int (*quota_off)(struct super_block___151 *, int);
	int (*quota_enable)(struct super_block___151 *, unsigned int);
	int (*quota_disable)(struct super_block___151 *, unsigned int);
	int (*quota_sync)(struct super_block___151 *, int);
	int (*set_info)(struct super_block___151 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___151 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___151 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___151 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___151 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___151 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___68;

struct swap_info_struct___48;

struct address_space_operations___151 {
	int (*writepage)(struct page___152 *, struct writeback_control___68 *);
	int (*readpage)(struct file___152 *, struct page___152 *);
	int (*writepages)(struct address_space___151 *, struct writeback_control___68 *);
	int (*set_page_dirty)(struct page___152 *);
	int (*readpages)(struct file___152 *, struct address_space___151 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___152 *, struct address_space___151 *, loff_t, unsigned int, unsigned int, struct page___152 **, void **);
	int (*write_end)(struct file___152 *, struct address_space___151 *, loff_t, unsigned int, unsigned int, struct page___152 *, void *);
	sector_t (*bmap)(struct address_space___151 *, sector_t);
	void (*invalidatepage)(struct page___152 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___152 *, gfp_t);
	void (*freepage)(struct page___152 *);
	ssize_t (*direct_IO)(struct kiocb___152 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___151 *, struct page___152 *, struct page___152 *, enum migrate_mode);
	bool (*isolate_page)(struct page___152 *, isolate_mode_t);
	void (*putback_page)(struct page___152 *);
	int (*launder_page)(struct page___152 *);
	int (*is_partially_uptodate)(struct page___152 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___152 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___151 *, struct page___152 *);
	int (*swap_activate)(struct swap_info_struct___48 *, struct file___152 *, sector_t *);
	void (*swap_deactivate)(struct file___152 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___68 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___71 *wb;
	struct inode___152 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct swap_info_struct___48 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___152 *bdev;
	struct file___152 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___152 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___152 *bd_inode;
	struct super_block___151 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___152 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___71 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___151 {
	struct dentry___151 * (*lookup)(struct inode___152 *, struct dentry___151 *, unsigned int);
	const char * (*get_link)(struct dentry___151 *, struct inode___152 *, struct delayed_call *);
	int (*permission)(struct inode___152 *, int);
	struct posix_acl * (*get_acl)(struct inode___152 *, int);
	int (*readlink)(struct dentry___151 *, char *, int);
	int (*create)(struct inode___152 *, struct dentry___151 *, umode_t, bool);
	int (*link)(struct dentry___151 *, struct inode___152 *, struct dentry___151 *);
	int (*unlink)(struct inode___152 *, struct dentry___151 *);
	int (*symlink)(struct inode___152 *, struct dentry___151 *, const char *);
	int (*mkdir)(struct inode___152 *, struct dentry___151 *, umode_t);
	int (*rmdir)(struct inode___152 *, struct dentry___151 *);
	int (*mknod)(struct inode___152 *, struct dentry___151 *, umode_t, dev_t);
	int (*rename)(struct inode___152 *, struct dentry___151 *, struct inode___152 *, struct dentry___151 *, unsigned int);
	int (*setattr)(struct dentry___151 *, struct iattr___151 *);
	int (*getattr)(const struct path___151 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___151 *, char *, size_t);
	int (*fiemap)(struct inode___152 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___152 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___152 *, struct dentry___151 *, struct file___152 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___152 *, struct dentry___151 *, umode_t);
	int (*set_acl)(struct inode___152 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___151 {
	void (*fl_copy_lock)(struct file_lock___152 *, struct file_lock___152 *);
	void (*fl_release_private)(struct file_lock___152 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___151;

struct lock_manager_operations___151;

struct file_lock___152 {
	struct file_lock___152 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___152 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___151 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___151 *fl_ops;
	const struct lock_manager_operations___151 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___151 {
	int (*lm_compare_owner)(struct file_lock___152 *, struct file_lock___152 *);
	long unsigned int (*lm_owner_key)(struct file_lock___152 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___152 *);
	int (*lm_grant)(struct file_lock___152 *, int);
	bool (*lm_break)(struct file_lock___152 *);
	int (*lm_change)(struct file_lock___152 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___152 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___151 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___151 *fa_next;
	struct file___152 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___151 {
	const char *name;
	int fs_flags;
	struct dentry___151 * (*mount)(struct file_system_type___151 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___151 *);
	struct module___11 *owner;
	struct file_system_type___151 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___151 {
	struct inode___152 * (*alloc_inode)(struct super_block___151 *);
	void (*destroy_inode)(struct inode___152 *);
	void (*dirty_inode)(struct inode___152 *, int);
	int (*write_inode)(struct inode___152 *, struct writeback_control___68 *);
	int (*drop_inode)(struct inode___152 *);
	void (*evict_inode)(struct inode___152 *);
	void (*put_super)(struct super_block___151 *);
	int (*sync_fs)(struct super_block___151 *, int);
	int (*freeze_super)(struct super_block___151 *);
	int (*freeze_fs)(struct super_block___151 *);
	int (*thaw_super)(struct super_block___151 *);
	int (*unfreeze_fs)(struct super_block___151 *);
	int (*statfs)(struct dentry___151 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___151 *, int *, char *);
	void (*umount_begin)(struct super_block___151 *);
	int (*show_options)(struct seq_file___142 *, struct dentry___151 *);
	int (*show_devname)(struct seq_file___142 *, struct dentry___151 *);
	int (*show_path)(struct seq_file___142 *, struct dentry___151 *);
	int (*show_stats)(struct seq_file___142 *, struct dentry___151 *);
	ssize_t (*quota_read)(struct super_block___151 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___151 *, int, const char *, size_t, loff_t);
	struct dquot___151 ** (*get_dquots)(struct inode___152 *);
	int (*bdev_try_to_free_page)(struct super_block___151 *, struct page___152 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___151 *, struct shrink_control___66 *);
	long int (*free_cached_objects)(struct super_block___151 *, struct shrink_control___66 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___140;

struct seq_file___142 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___140 *op;
	int poll_event;
	const struct file___152 *file;
	void *private;
};

typedef void bio_end_io_t___71(struct bio___71 *);

struct bio_vec___71 {
	struct page___152 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___71;

struct bio_set___71;

struct bio___71 {
	struct bio___71 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___71 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___71 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___71 *bi_io_vec;
	struct bio_set___71 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___71 bi_inline_vecs[0];
};

struct kobj_attribute___146 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___146 *, struct kobj_attribute___146 *, char *);
	ssize_t (*store)(struct kobject___146 *, struct kobj_attribute___146 *, const char *, size_t);
};

typedef void compound_page_dtor___149(struct page___152 *);

typedef int (*key_restrict_link_func_t___147)(struct key___147 *, const struct key_type *, const union key_payload *, struct key___147 *);

struct key_restriction___147;

struct key___147 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___152 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___147 *restrict_link;
};

struct key_restriction___147 {
	key_restrict_link_func_t___147 check;
	struct key___147 *key;
	struct key_type *keytype;
};

struct seq_operations___140 {
	void * (*start)(struct seq_file___142 *, loff_t *);
	void (*stop)(struct seq_file___142 *, void *);
	void * (*next)(struct seq_file___142 *, void *, loff_t *);
	int (*show)(struct seq_file___142 *, void *);
};

struct bin_attribute___141;

struct attribute_group___142 {
	const char *name;
	umode_t (*is_visible)(struct kobject___146 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___146 *, struct bin_attribute___141 *, int);
	struct attribute **attrs;
	struct bin_attribute___141 **bin_attrs;
};

struct kernfs_root___148;

struct kernfs_elem_dir___148 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___148 *root;
};

struct kernfs_syscall_ops___148;

struct kernfs_root___148 {
	struct kernfs_node___148 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___148 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___148 {
	struct kernfs_node___148 *target_kn;
};

struct kernfs_ops___148;

struct kernfs_elem_attr___148 {
	const struct kernfs_ops___148 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___148 *notify_next;
};

struct kernfs_node___148 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___148 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___148 dir;
		struct kernfs_elem_symlink___148 symlink;
		struct kernfs_elem_attr___148 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___148;

struct kernfs_ops___148 {
	int (*open)(struct kernfs_open_file___148 *);
	void (*release)(struct kernfs_open_file___148 *);
	int (*seq_show)(struct seq_file___142 *, void *);
	void * (*seq_start)(struct seq_file___142 *, loff_t *);
	void * (*seq_next)(struct seq_file___142 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___142 *, void *);
	ssize_t (*read)(struct kernfs_open_file___148 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___148 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___148 *, struct vm_area_struct___152 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___148 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___148 {
	int (*remount_fs)(struct kernfs_root___148 *, int *, char *);
	int (*show_options)(struct seq_file___142 *, struct kernfs_root___148 *);
	int (*mkdir)(struct kernfs_node___148 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___148 *);
	int (*rename)(struct kernfs_node___148 *, struct kernfs_node___148 *, const char *);
	int (*show_path)(struct seq_file___142 *, struct kernfs_node___148 *, struct kernfs_root___148 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___148 {
	struct kernfs_node___148 *kn;
	struct file___152 *file;
	struct seq_file___142 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___149 *vm_ops;
};

struct bin_attribute___141 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___152 *, struct kobject___146 *, struct bin_attribute___141 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___152 *, struct kobject___146 *, struct bin_attribute___141 *, char *, loff_t, size_t);
	int (*mmap)(struct file___152 *, struct kobject___146 *, struct bin_attribute___141 *, struct vm_area_struct___152 *);
};

struct sysfs_ops___145 {
	ssize_t (*show)(struct kobject___146 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___146 *, struct attribute *, const char *, size_t);
};

struct cgroup_namespace___128 {
	refcount_t count;
	struct ns_common___4 ns;
	struct user_namespace___132 *user_ns;
	struct ucounts___132 *ucounts;
	struct css_set___128 *root_cset;
};

struct ucounts___132 {
	struct hlist_node node;
	struct user_namespace___132 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___128;

struct bpf_map_ops___128 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___128 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___128 *, struct file___152 *);
	void (*map_free)(struct bpf_map___128 *);
	int (*map_get_next_key)(struct bpf_map___128 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___128 *);
	void * (*map_lookup_elem)(struct bpf_map___128 *, void *);
	int (*map_update_elem)(struct bpf_map___128 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___128 *, void *);
	int (*map_push_elem)(struct bpf_map___128 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___128 *, void *);
	int (*map_peek_elem)(struct bpf_map___128 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___128 *, struct file___152 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___128 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___128 *, void *, struct seq_file___142 *);
	int (*map_check_btf)(const struct bpf_map___128 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___128 {
	const struct bpf_map_ops___128 *ops;
	struct bpf_map___128 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___147 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___128;

typedef void (*kthread_work_func_t___128)(struct kthread_work___128 *);

struct kthread_worker___128;

struct kthread_work___128 {
	struct list_head node;
	kthread_work_func_t___128 func;
	struct kthread_worker___128 *worker;
	int canceling;
};

struct kthread_worker___128 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___152 *task;
	struct kthread_work___128 *current_work;
};

struct kthread_delayed_work___128 {
	struct kthread_work___128 work;
	struct timer_list timer;
};

struct psi_group___128 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___128 *poll_kworker;
	struct kthread_delayed_work___128 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___128;

struct cgroup_rstat_cpu___128;

struct cgroup___128 {
	struct cgroup_subsys_state___128 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___148 *kn;
	struct cgroup_file___128 procs_file;
	struct cgroup_file___128 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___128 *subsys[13];
	struct cgroup_root___128 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___128 *dom_cgrp;
	struct cgroup_rstat_cpu___128 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___4 bpf;
	atomic_t congestion_count;
	struct cgroup___128 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___128 psi;
	int ancestor_ids[0];
};

struct cftype___128;

struct cgroup_subsys___128 {
	struct cgroup_subsys_state___128 * (*css_alloc)(struct cgroup_subsys_state___128 *);
	int (*css_online)(struct cgroup_subsys_state___128 *);
	void (*css_offline)(struct cgroup_subsys_state___128 *);
	void (*css_released)(struct cgroup_subsys_state___128 *);
	void (*css_free)(struct cgroup_subsys_state___128 *);
	void (*css_reset)(struct cgroup_subsys_state___128 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___128 *, int);
	int (*css_extra_stat_show)(struct seq_file___142 *, struct cgroup_subsys_state___128 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___152 *);
	void (*cancel_fork)(struct task_struct___152 *);
	void (*fork)(struct task_struct___152 *);
	void (*exit)(struct task_struct___152 *);
	void (*free)(struct task_struct___152 *);
	void (*bind)(struct cgroup_subsys_state___128 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___128 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___128 *dfl_cftypes;
	struct cftype___128 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___128 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___128 *updated_children;
	struct cgroup___128 *updated_next;
};

struct cgroup_root___128 {
	struct kernfs_root___148 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___128 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___128 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___128 *ss;
	struct list_head node;
	struct kernfs_ops___148 *kf_ops;
	int (*open)(struct kernfs_open_file___148 *);
	void (*release)(struct kernfs_open_file___148 *);
	u64 (*read_u64)(struct cgroup_subsys_state___128 *, struct cftype___128 *);
	s64 (*read_s64)(struct cgroup_subsys_state___128 *, struct cftype___128 *);
	int (*seq_show)(struct seq_file___142 *, void *);
	void * (*seq_start)(struct seq_file___142 *, loff_t *);
	void * (*seq_next)(struct seq_file___142 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___142 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___128 *, struct cftype___128 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___128 *, struct cftype___128 *, s64);
	ssize_t (*write)(struct kernfs_open_file___148 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___148 *, struct poll_table_struct___6 *);
};

struct bdi_writeback_congested___71 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___71 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___71 {
	struct bio___71 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___71 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___71 bip_inline_vecs[0];
};

struct bio_set___71 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___71 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___66 {
	struct mem_cgroup___66 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___66 {
	struct lruvec___151 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___66 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___66 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

enum string_size_units {
	STRING_UNITS_10 = 0,
	STRING_UNITS_2 = 1,
};

struct kset_uevent_ops___145;

struct kset___145 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___146 kobj;
	const struct kset_uevent_ops___145 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___145 {
	void (*release)(struct kobject___146 *);
	const struct sysfs_ops___145 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___2 * (*child_ns_type)(struct kobject___146 *);
	const void * (*namespace)(struct kobject___146 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___145 {
	int (* const filter)(struct kset___145 *, struct kobject___146 *);
	const char * (* const name)(struct kset___145 *, struct kobject___146 *);
	int (* const uevent)(struct kset___145 *, struct kobject___146 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___142 {
	int (*prepare)(struct device___142 *);
	void (*complete)(struct device___142 *);
	int (*suspend)(struct device___142 *);
	int (*resume)(struct device___142 *);
	int (*freeze)(struct device___142 *);
	int (*thaw)(struct device___142 *);
	int (*poweroff)(struct device___142 *);
	int (*restore)(struct device___142 *);
	int (*suspend_late)(struct device___142 *);
	int (*resume_early)(struct device___142 *);
	int (*freeze_late)(struct device___142 *);
	int (*thaw_early)(struct device___142 *);
	int (*poweroff_late)(struct device___142 *);
	int (*restore_early)(struct device___142 *);
	int (*suspend_noirq)(struct device___142 *);
	int (*resume_noirq)(struct device___142 *);
	int (*freeze_noirq)(struct device___142 *);
	int (*thaw_noirq)(struct device___142 *);
	int (*poweroff_noirq)(struct device___142 *);
	int (*restore_noirq)(struct device___142 *);
	int (*runtime_suspend)(struct device___142 *);
	int (*runtime_resume)(struct device___142 *);
	int (*runtime_idle)(struct device___142 *);
};

struct dev_pm_domain___142 {
	struct dev_pm_ops___142 ops;
	void (*detach)(struct device___142 *, bool);
	int (*activate)(struct device___142 *);
	void (*sync)(struct device___142 *);
	void (*dismiss)(struct device___142 *);
};

struct bus_type___142 {
	const char *name;
	const char *dev_name;
	struct device___142 *dev_root;
	const struct attribute_group___142 **bus_groups;
	const struct attribute_group___142 **dev_groups;
	const struct attribute_group___142 **drv_groups;
	int (*match)(struct device___142 *, struct device_driver___142 *);
	int (*uevent)(struct device___142 *, struct kobj_uevent_env *);
	int (*probe)(struct device___142 *);
	int (*remove)(struct device___142 *);
	void (*shutdown)(struct device___142 *);
	int (*online)(struct device___142 *);
	int (*offline)(struct device___142 *);
	int (*suspend)(struct device___142 *, pm_message_t);
	int (*resume)(struct device___142 *);
	int (*num_vf)(struct device___142 *);
	int (*dma_configure)(struct device___142 *);
	const struct dev_pm_ops___142 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___142 {
	const char *name;
	struct bus_type___142 *bus;
	struct module___11 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___142 *);
	int (*remove)(struct device___142 *);
	void (*shutdown)(struct device___142 *);
	int (*suspend)(struct device___142 *, pm_message_t);
	int (*resume)(struct device___142 *);
	const struct attribute_group___142 **groups;
	const struct dev_pm_ops___142 *pm;
	void (*coredump)(struct device___142 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___142 {
	const char *name;
	const struct attribute_group___142 **groups;
	int (*uevent)(struct device___142 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___142 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___142 *);
	const struct dev_pm_ops___142 *pm;
};

struct class___142 {
	const char *name;
	struct module___11 *owner;
	const struct attribute_group___142 **class_groups;
	const struct attribute_group___142 **dev_groups;
	struct kobject___146 *dev_kobj;
	int (*dev_uevent)(struct device___142 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___142 *, umode_t *);
	void (*class_release)(struct class___142 *);
	void (*dev_release)(struct device___142 *);
	int (*shutdown_pre)(struct device___142 *);
	const struct kobj_ns_type_operations___2 *ns_type;
	const void * (*namespace)(struct device___142 *);
	const struct dev_pm_ops___142 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct fwnode_operations___104;

struct fwnode_handle___104 {
	struct fwnode_handle___104 *secondary;
	const struct fwnode_operations___104 *ops;
};

struct node___120 {
	struct device___142 dev;
};

struct mmu_gather_batch___5 {
	struct mmu_gather_batch___5 *next;
	unsigned int nr;
	unsigned int max;
	struct page___152 *pages[0];
};

struct mmu_gather___5 {
	struct mm_struct___151 *mm;
	struct mmu_table_batch *batch;
	long unsigned int start;
	long unsigned int end;
	unsigned int fullmm: 1;
	unsigned int need_flush_all: 1;
	struct mmu_gather_batch___5 *active;
	struct mmu_gather_batch___5 local;
	struct page___152 *__pages[8];
	unsigned int batch_count;
	int page_size;
};

struct fwnode_reference_args___104;

struct fwnode_endpoint___104;

struct fwnode_operations___104 {
	struct fwnode_handle___104 * (*get)(struct fwnode_handle___104 *);
	void (*put)(struct fwnode_handle___104 *);
	bool (*device_is_available)(const struct fwnode_handle___104 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___104 *, const struct device___142 *);
	bool (*property_present)(const struct fwnode_handle___104 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___104 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___104 *, const char *, const char **, size_t);
	struct fwnode_handle___104 * (*get_parent)(const struct fwnode_handle___104 *);
	struct fwnode_handle___104 * (*get_next_child_node)(const struct fwnode_handle___104 *, struct fwnode_handle___104 *);
	struct fwnode_handle___104 * (*get_named_child_node)(const struct fwnode_handle___104 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___104 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___104 *);
	struct fwnode_handle___104 * (*graph_get_next_endpoint)(const struct fwnode_handle___104 *, struct fwnode_handle___104 *);
	struct fwnode_handle___104 * (*graph_get_remote_endpoint)(const struct fwnode_handle___104 *);
	struct fwnode_handle___104 * (*graph_get_port_parent)(struct fwnode_handle___104 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___104 *, struct fwnode_endpoint___104 *);
};

struct fwnode_endpoint___104 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___104 *local_fwnode;
};

struct fwnode_reference_args___104 {
	struct fwnode_handle___104 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct hstate___28;

struct hugepage_subpool___4 {
	spinlock_t lock;
	long int count;
	long int max_hpages;
	long int used_hpages;
	struct hstate___28 *hstate;
	long int min_hpages;
	long int rsv_hpages;
};

struct hstate___28 {
	int next_nid_to_alloc;
	int next_nid_to_free;
	unsigned int order;
	long unsigned int mask;
	long unsigned int max_huge_pages;
	long unsigned int nr_huge_pages;
	long unsigned int free_huge_pages;
	long unsigned int resv_huge_pages;
	long unsigned int surplus_huge_pages;
	long unsigned int nr_overcommit_huge_pages;
	struct list_head hugepage_activelist;
	struct list_head hugepage_freelists[8];
	unsigned int nr_huge_pages_node[8];
	unsigned int free_huge_pages_node[8];
	unsigned int surplus_huge_pages_node[8];
	struct cftype___128 cgroup_files[5];
	char name[32];
};

struct resv_map {
	struct kref refs;
	spinlock_t lock;
	struct list_head regions;
	long int adds_in_progress;
	struct list_head region_cache;
	long int region_cache_count;
};

struct hugetlbfs_sb_info___4 {
	long int max_inodes;
	long int free_inodes;
	spinlock_t stat_lock;
	struct hstate___28 *hstate;
	struct hugepage_subpool___4 *spool;
	kuid_t uid;
	kgid_t gid;
	umode_t mode;
};

struct huge_bootmem_page {
	struct list_head list;
	struct hstate___28 *hstate;
};

struct file_region {
	struct list_head link;
	long int from;
	long int to;
};

enum vma_resv_mode {
	VMA_NEEDS_RESV = 0,
	VMA_COMMIT_RESV = 1,
	VMA_END_RESV = 2,
	VMA_ADD_RESV = 3,
};

struct node_hstate {
	struct kobject___146 *hugepages_kobj;
	struct kobject___146 *hstate_kobjs[4];
};

struct hugetlb_cgroup;

struct module___130;

struct file___153;

struct kiocb___153;

struct iov_iter___70;

struct poll_table_struct___104;

struct vm_area_struct___153;

struct inode___153;

struct file_lock___153;

struct page___153;

struct seq_file___143;

struct file_operations___153 {
	struct module___130 *owner;
	loff_t (*llseek)(struct file___153 *, loff_t, int);
	ssize_t (*read)(struct file___153 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___153 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___153 *, struct iov_iter___70 *);
	ssize_t (*write_iter)(struct kiocb___153 *, struct iov_iter___70 *);
	int (*iopoll)(struct kiocb___153 *, bool);
	int (*iterate)(struct file___153 *, struct dir_context *);
	int (*iterate_shared)(struct file___153 *, struct dir_context *);
	__poll_t (*poll)(struct file___153 *, struct poll_table_struct___104 *);
	long int (*unlocked_ioctl)(struct file___153 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___153 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___153 *, struct vm_area_struct___153 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___153 *, struct file___153 *);
	int (*flush)(struct file___153 *, fl_owner_t);
	int (*release)(struct inode___153 *, struct file___153 *);
	int (*fsync)(struct file___153 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___153 *, int);
	int (*lock)(struct file___153 *, int, struct file_lock___153 *);
	ssize_t (*sendpage)(struct file___153 *, struct page___153 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___153 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___153 *, int, struct file_lock___153 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___153 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___153 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___153 *, long int, struct file_lock___153 **, void **);
	long int (*fallocate)(struct file___153 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___143 *, struct file___153 *);
	ssize_t (*copy_file_range)(struct file___153 *, loff_t, struct file___153 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___153 *, loff_t, struct file___153 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___153 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___152 {
	u64 seqnum;
	struct vm_area_struct___153 *vmas[4];
};

struct page_frag___152 {
	struct page___153 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___95;

struct debug_info___95 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___95 *hbp_break[16];
	struct perf_event___95 *hbp_watch[16];
};

struct thread_struct___95 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___95 debug;
	long: 64;
};

struct mm_struct___152;

struct mem_cgroup___67;

struct pid___122;

struct cred___148;

struct nsproxy___145;

struct signal_struct___137;

struct bio_list___72;

struct backing_dev_info___72;

struct css_set___129;

struct perf_event_context___95;

struct task_struct___153 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___153 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___152 *mm;
	struct mm_struct___152 *active_mm;
	struct vmacache___152 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___153 *real_parent;
	struct task_struct___153 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___153 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___67 *active_memcg;
	long int rh_reserved2;
	struct pid___122 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___122 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___122 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___148 *ptracer_cred;
	const struct cred___148 *real_cred;
	const struct cred___148 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___145 *nsproxy;
	struct signal_struct___137 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___153 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___72 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___72 *backing_dev_info;
	struct io_context___35 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___129 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___95 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___152 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___67 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___153 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___95 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___95 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___153 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___95)(struct perf_event___95 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___95;

struct fasync_struct___152;

struct pid_namespace___122;

struct trace_event_call___88;

struct perf_cgroup___95;

struct perf_event___95 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___95 *group_leader;
	struct pmu___95 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___95 hw;
	struct perf_event_context___95 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___95 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___153 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___152 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___95 *);
	struct callback_head callback_head;
	struct pid_namespace___122 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___95 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___95 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___88 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___95 *cgrp;
	struct list_head sb_list;
};

struct nodemask_scratch {
	nodemask_t mask1;
	nodemask_t mask2;
};

typedef struct page___153 *pgtable_t___152;

struct address_space___152;

struct dev_pagemap___150;

struct page___153 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___152 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___153 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___152 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___152 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___150 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___67 *mem_cgroup;
};

struct pglist_data___152;

struct lruvec___152 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___152 *pgdat;
};

struct zone___152 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___152 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___152 {
	struct zone___152 *zone;
	int zone_idx;
};

struct zonelist___152 {
	struct zoneref___152 _zonerefs[25];
};

struct pglist_data___152 {
	struct zone___152 node_zones[3];
	struct zonelist___152 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___153 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___153 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___152 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

typedef struct pglist_data___152 pg_data_t___12;

struct rw_semaphore___153 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___153 *owner;
};

struct secondary_data___153 {
	void *stack;
	struct task_struct___153 *task;
	long int status;
};

struct blocking_notifier_head___152 {
	struct rw_semaphore___153 rwsem;
	struct notifier_block *head;
};

struct dentry_operations___152;

struct super_block___152;

struct dentry___152 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___152 *d_parent;
	struct qstr d_name;
	struct inode___153 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___152 *d_op;
	struct super_block___152 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___152;

struct address_space___152 {
	struct inode___153 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___153 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___152 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___152;

struct bdi_writeback___72;

struct block_device___153;

struct inode___153 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___152 *i_op;
	struct super_block___152 *i_sb;
	struct address_space___152 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___153 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___72 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___153 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___152 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___153 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___152;

struct dentry_operations___152 {
	int (*d_revalidate)(struct dentry___152 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___152 *, unsigned int);
	int (*d_hash)(const struct dentry___152 *, struct qstr *);
	int (*d_compare)(const struct dentry___152 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___152 *);
	int (*d_init)(struct dentry___152 *);
	void (*d_release)(struct dentry___152 *);
	void (*d_prune)(struct dentry___152 *);
	void (*d_iput)(struct dentry___152 *, struct inode___153 *);
	char * (*d_dname)(struct dentry___152 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___152 *);
	int (*d_manage)(const struct path___152 *, bool);
	struct dentry___152 * (*d_real)(struct dentry___152 *, const struct inode___153 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___152;

struct mem_dqinfo___152 {
	struct quota_format_type___152 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___152;

struct quota_info___152 {
	unsigned int flags;
	struct rw_semaphore___153 dqio_sem;
	struct inode___153 *files[3];
	struct mem_dqinfo___152 info[3];
	const struct quota_format_ops___152 *ops[3];
};

struct rcuwait___152 {
	struct task_struct___153 *task;
};

struct percpu_rw_semaphore___152 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___153 rw_sem;
	struct rcuwait___152 writer;
	int readers_block;
};

struct sb_writers___152 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___152 rw_sem[3];
};

struct shrink_control___67;

struct shrinker___67 {
	long unsigned int (*count_objects)(struct shrinker___67 *, struct shrink_control___67 *);
	long unsigned int (*scan_objects)(struct shrinker___67 *, struct shrink_control___67 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___152;

struct super_operations___152;

struct dquot_operations___152;

struct quotactl_ops___152;

struct user_namespace___133;

struct super_block___152 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___152 *s_type;
	const struct super_operations___152 *s_op;
	const struct dquot_operations___152 *dq_op;
	const struct quotactl_ops___152 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___152 *s_root;
	struct rw_semaphore___153 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___153 *s_bdev;
	struct backing_dev_info___72 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___152 s_dquot;
	struct sb_writers___152 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___152 *s_d_op;
	int cleancache_poolid;
	struct shrinker___67 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___133 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct path___152 {
	struct vfsmount *mnt;
	struct dentry___152 *dentry;
};

struct key___148;

struct ucounts___133;

struct user_namespace___133 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___133 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___4 ns;
	long unsigned int flags;
	struct key___148 *persistent_keyring_register;
	struct rw_semaphore___153 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___133 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct shrink_control___67 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___67 *memcg;
};

struct cgroup___129;

struct cgroup_subsys___129;

struct cgroup_subsys_state___129 {
	struct cgroup___129 *cgroup;
	struct cgroup_subsys___129 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___129 *parent;
};

struct kernfs_node___149;

struct cgroup_file___129 {
	struct kernfs_node___149 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___67;

struct mem_cgroup___67 {
	struct cgroup_subsys_state___129 css;
	struct mem_cgroup_id___4 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___129 events_file;
	struct cgroup_file___129 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___153 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___67 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct upid___122 {
	int nr;
	struct pid_namespace___122 *ns;
};

struct pid_namespace___122 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___153 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___122 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___152 *proc_self;
	struct dentry___152 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___133 *user_ns;
	struct ucounts___133 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___4 ns;
};

struct pid___122 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___122 numbers[1];
};

struct anon_vma___16;

struct vm_operations_struct___150;

struct vm_area_struct___153 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___153 *vm_next;
	struct vm_area_struct___153 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___152 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma___16 *anon_vma;
	const struct vm_operations_struct___150 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___153 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___152;

struct mm_struct___152 {
	struct {
		struct vm_area_struct___153 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___153 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___153 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___152 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___153 *owner;
		struct user_namespace___133 *user_ns;
		struct file___153 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___152 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___150)(struct vm_area_struct___153 *, long unsigned int, const struct page___153 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___150)(struct page___153 *, void *);

struct device___143;

struct dev_pagemap___150 {
	dev_page_fault_t___150 page_fault;
	dev_page_free_t___150 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___143 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct fown_struct___122 {
	rwlock_t lock;
	struct pid___122 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___153 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___152 f_path;
	struct inode___153 *f_inode;
	const struct file_operations___153 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___122 f_owner;
	const struct cred___148 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___152 *f_mapping;
	errseq_t f_wb_err;
};

struct anon_vma___16 {
	struct anon_vma___16 *root;
	struct rw_semaphore___153 rwsem;
	atomic_t refcount;
	unsigned int degree;
	struct anon_vma___16 *parent;
	struct rb_root_cached rb_root;
};

struct vm_fault___150;

struct vm_operations_struct___150 {
	void (*open)(struct vm_area_struct___153 *);
	void (*close)(struct vm_area_struct___153 *);
	int (*split)(struct vm_area_struct___153 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___153 *);
	vm_fault_t (*fault)(struct vm_fault___150 *);
	vm_fault_t (*huge_fault)(struct vm_fault___150 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___150 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___153 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___150 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___150 *);
	int (*access)(struct vm_area_struct___153 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___153 *);
	int (*set_policy)(struct vm_area_struct___153 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___153 *, long unsigned int);
	struct page___153 * (*find_special_page)(struct vm_area_struct___153 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___152 {
	struct task_struct___153 *task;
	struct core_thread___152 *next;
};

struct core_state___152 {
	atomic_t nr_threads;
	struct core_thread___152 dumper;
	struct completion startup;
};

struct vm_fault___150 {
	struct vm_area_struct___153 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___153 *cow_page;
	struct mem_cgroup___67 *memcg;
	struct page___153 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___152 prealloc_pte;
};

struct user_struct___148 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___148 *uid_keyring;
	struct key___148 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___148 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___148 *session_keyring;
	struct key___148 *process_keyring;
	struct key___148 *thread_keyring;
	struct key___148 *request_key_auth;
	void *security;
	struct user_struct___148 *user;
	struct user_namespace___133 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___129;

struct nsproxy___145 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___122 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___129 *cgroup_ns;
};

struct signal_struct___137 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___153 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___153 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___122 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___122 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___152 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___122 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___72;

struct bio_list___72 {
	struct bio___72 *head;
	struct bio___72 *tail;
};

struct bdi_writeback_congested___72;

struct bdi_writeback___72 {
	struct backing_dev_info___72 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___72 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___129 *memcg_css;
	struct cgroup_subsys_state___129 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___72 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___72 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___143 *dev;
	struct device___143 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___152 *debug_dir;
	struct dentry___152 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___129 {
	struct cgroup_subsys_state___129 *subsys[13];
	refcount_t refcount;
	struct css_set___129 *dom_cset;
	struct cgroup___129 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___129 *mg_src_cgrp;
	struct cgroup___129 *mg_dst_cgrp;
	struct css_set___129 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___95 {
	struct pmu___95 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___153 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___95 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

union thread_union___137 {
	struct task_struct___153 task;
	long unsigned int stack[8192];
};

struct kiocb___153 {
	struct file___153 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___153 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___152 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___153 *ia_file;
};

struct dquot___152 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___152 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___152 {
	int qf_fmt_id;
	const struct quota_format_ops___152 *qf_ops;
	struct module___130 *qf_owner;
	struct quota_format_type___152 *qf_next;
};

struct quota_format_ops___152 {
	int (*check_quota_file)(struct super_block___152 *, int);
	int (*read_file_info)(struct super_block___152 *, int);
	int (*write_file_info)(struct super_block___152 *, int);
	int (*free_file_info)(struct super_block___152 *, int);
	int (*read_dqblk)(struct dquot___152 *);
	int (*commit_dqblk)(struct dquot___152 *);
	int (*release_dqblk)(struct dquot___152 *);
	int (*get_next_id)(struct super_block___152 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___152 {
	int (*write_dquot)(struct dquot___152 *);
	struct dquot___152 * (*alloc_dquot)(struct super_block___152 *, int);
	void (*destroy_dquot)(struct dquot___152 *);
	int (*acquire_dquot)(struct dquot___152 *);
	int (*release_dquot)(struct dquot___152 *);
	int (*mark_dirty)(struct dquot___152 *);
	int (*write_info)(struct super_block___152 *, int);
	qsize_t * (*get_reserved_space)(struct inode___153 *);
	int (*get_projid)(struct inode___153 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___153 *, qsize_t *);
	int (*get_next_id)(struct super_block___152 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___152 {
	int (*quota_on)(struct super_block___152 *, int, int, const struct path___152 *);
	int (*quota_off)(struct super_block___152 *, int);
	int (*quota_enable)(struct super_block___152 *, unsigned int);
	int (*quota_disable)(struct super_block___152 *, unsigned int);
	int (*quota_sync)(struct super_block___152 *, int);
	int (*set_info)(struct super_block___152 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___152 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___152 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___152 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___152 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___152 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___146;

struct kobj_type___146;

struct kobject___147 {
	const char *name;
	struct list_head entry;
	struct kobject___147 *parent;
	struct kset___146 *kset;
	struct kobj_type___146 *ktype;
	struct kernfs_node___149 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___127 {
	struct kobject___147 kobj;
	struct module___130 *mod;
	struct kobject___147 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___127 {
	struct module___130 *mod;
	struct latch_tree_node node;
};

struct module_layout___127 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___127 mtn;
};

struct module_attribute___127;

struct kernel_param___127;

struct module___130 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___127 mkobj;
	struct module_attribute___127 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___147 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___127 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___127 core_layout;
	struct module_layout___127 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___88 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide35;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___69;

struct swap_info_struct___49;

struct address_space_operations___152 {
	int (*writepage)(struct page___153 *, struct writeback_control___69 *);
	int (*readpage)(struct file___153 *, struct page___153 *);
	int (*writepages)(struct address_space___152 *, struct writeback_control___69 *);
	int (*set_page_dirty)(struct page___153 *);
	int (*readpages)(struct file___153 *, struct address_space___152 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___153 *, struct address_space___152 *, loff_t, unsigned int, unsigned int, struct page___153 **, void **);
	int (*write_end)(struct file___153 *, struct address_space___152 *, loff_t, unsigned int, unsigned int, struct page___153 *, void *);
	sector_t (*bmap)(struct address_space___152 *, sector_t);
	void (*invalidatepage)(struct page___153 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___153 *, gfp_t);
	void (*freepage)(struct page___153 *);
	ssize_t (*direct_IO)(struct kiocb___153 *, struct iov_iter___70 *);
	int (*migratepage)(struct address_space___152 *, struct page___153 *, struct page___153 *, enum migrate_mode);
	bool (*isolate_page)(struct page___153 *, isolate_mode_t);
	void (*putback_page)(struct page___153 *);
	int (*launder_page)(struct page___153 *);
	int (*is_partially_uptodate)(struct page___153 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___153 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___152 *, struct page___153 *);
	int (*swap_activate)(struct swap_info_struct___49 *, struct file___153 *, sector_t *);
	void (*swap_deactivate)(struct file___153 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___69 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___72 *wb;
	struct inode___153 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___72;

struct iov_iter___70 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___72 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct swap_info_struct___49 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___153 *bdev;
	struct file___153 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___153 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___153 *bd_inode;
	struct super_block___152 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___153 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___72 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___152 {
	struct dentry___152 * (*lookup)(struct inode___153 *, struct dentry___152 *, unsigned int);
	const char * (*get_link)(struct dentry___152 *, struct inode___153 *, struct delayed_call *);
	int (*permission)(struct inode___153 *, int);
	struct posix_acl * (*get_acl)(struct inode___153 *, int);
	int (*readlink)(struct dentry___152 *, char *, int);
	int (*create)(struct inode___153 *, struct dentry___152 *, umode_t, bool);
	int (*link)(struct dentry___152 *, struct inode___153 *, struct dentry___152 *);
	int (*unlink)(struct inode___153 *, struct dentry___152 *);
	int (*symlink)(struct inode___153 *, struct dentry___152 *, const char *);
	int (*mkdir)(struct inode___153 *, struct dentry___152 *, umode_t);
	int (*rmdir)(struct inode___153 *, struct dentry___152 *);
	int (*mknod)(struct inode___153 *, struct dentry___152 *, umode_t, dev_t);
	int (*rename)(struct inode___153 *, struct dentry___152 *, struct inode___153 *, struct dentry___152 *, unsigned int);
	int (*setattr)(struct dentry___152 *, struct iattr___152 *);
	int (*getattr)(const struct path___152 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___152 *, char *, size_t);
	int (*fiemap)(struct inode___153 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___153 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___153 *, struct dentry___152 *, struct file___153 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___153 *, struct dentry___152 *, umode_t);
	int (*set_acl)(struct inode___153 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___152 {
	void (*fl_copy_lock)(struct file_lock___153 *, struct file_lock___153 *);
	void (*fl_release_private)(struct file_lock___153 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___152;

struct file_lock___153 {
	struct file_lock___153 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___153 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___152 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___152 *fl_ops;
	const struct lock_manager_operations___152 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___152 {
	int (*lm_compare_owner)(struct file_lock___153 *, struct file_lock___153 *);
	long unsigned int (*lm_owner_key)(struct file_lock___153 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___153 *);
	int (*lm_grant)(struct file_lock___153 *, int);
	bool (*lm_break)(struct file_lock___153 *);
	int (*lm_change)(struct file_lock___153 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___153 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___152 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___152 *fa_next;
	struct file___153 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___152 {
	const char *name;
	int fs_flags;
	struct dentry___152 * (*mount)(struct file_system_type___152 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___152 *);
	struct module___130 *owner;
	struct file_system_type___152 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___152 {
	struct inode___153 * (*alloc_inode)(struct super_block___152 *);
	void (*destroy_inode)(struct inode___153 *);
	void (*dirty_inode)(struct inode___153 *, int);
	int (*write_inode)(struct inode___153 *, struct writeback_control___69 *);
	int (*drop_inode)(struct inode___153 *);
	void (*evict_inode)(struct inode___153 *);
	void (*put_super)(struct super_block___152 *);
	int (*sync_fs)(struct super_block___152 *, int);
	int (*freeze_super)(struct super_block___152 *);
	int (*freeze_fs)(struct super_block___152 *);
	int (*thaw_super)(struct super_block___152 *);
	int (*unfreeze_fs)(struct super_block___152 *);
	int (*statfs)(struct dentry___152 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___152 *, int *, char *);
	void (*umount_begin)(struct super_block___152 *);
	int (*show_options)(struct seq_file___143 *, struct dentry___152 *);
	int (*show_devname)(struct seq_file___143 *, struct dentry___152 *);
	int (*show_path)(struct seq_file___143 *, struct dentry___152 *);
	int (*show_stats)(struct seq_file___143 *, struct dentry___152 *);
	ssize_t (*quota_read)(struct super_block___152 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___152 *, int, const char *, size_t, loff_t);
	struct dquot___152 ** (*get_dquots)(struct inode___153 *);
	int (*bdev_try_to_free_page)(struct super_block___152 *, struct page___153 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___152 *, struct shrink_control___67 *);
	long int (*free_cached_objects)(struct super_block___152 *, struct shrink_control___67 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___103)(struct file___153 *, wait_queue_head_t *, struct poll_table_struct___104 *);

struct poll_table_struct___104 {
	poll_queue_proc___103 _qproc;
	__poll_t _key;
};

struct seq_operations___141;

struct seq_file___143 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___141 *op;
	int poll_event;
	const struct file___153 *file;
	void *private;
};

typedef void bio_end_io_t___72(struct bio___72 *);

struct bio_vec___72 {
	struct page___153 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___72;

struct bio_set___72;

struct bio___72 {
	struct bio___72 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___72 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___72 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___72 *bi_io_vec;
	struct bio_set___72 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___72 bi_inline_vecs[0];
};

struct dev_pm_info___143 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___143 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___143;

struct bus_type___143;

struct device_driver___143;

struct dev_pm_domain___143;

struct class___143;

struct attribute_group___143;

struct device___143 {
	struct device___143 *parent;
	struct device_private *p;
	struct kobject___147 kobj;
	const char *init_name;
	const struct device_type___143 *type;
	struct mutex mutex;
	struct bus_type___143 *bus;
	struct device_driver___143 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___143 power;
	struct dev_pm_domain___143 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___143 *class;
	const struct attribute_group___143 **groups;
	void (*release)(struct device___143 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct kobj_attribute___147 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___147 *, struct kobj_attribute___147 *, char *);
	ssize_t (*store)(struct kobject___147 *, struct kobj_attribute___147 *, const char *, size_t);
};

typedef void compound_page_dtor___150(struct page___153 *);

struct mm_walk___4 {
	int (*pud_entry)(pud_t *, long unsigned int, long unsigned int, struct mm_walk___4 *);
	int (*pmd_entry)(pmd_t *, long unsigned int, long unsigned int, struct mm_walk___4 *);
	int (*pte_entry)(pte_t *, long unsigned int, long unsigned int, struct mm_walk___4 *);
	int (*pte_hole)(long unsigned int, long unsigned int, struct mm_walk___4 *);
	int (*hugetlb_entry)(pte_t *, long unsigned int, long unsigned int, long unsigned int, struct mm_walk___4 *);
	int (*test_walk)(long unsigned int, long unsigned int, struct mm_walk___4 *);
	struct mm_struct___152 *mm;
	struct vm_area_struct___153 *vma;
	void *private;
};

struct bin_attribute___142;

struct attribute_group___143 {
	const char *name;
	umode_t (*is_visible)(struct kobject___147 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___147 *, struct bin_attribute___142 *, int);
	struct attribute **attrs;
	struct bin_attribute___142 **bin_attrs;
};

struct sp_node {
	struct rb_node nd;
	long unsigned int start;
	long unsigned int end;
	struct mempolicy *policy;
};

typedef int (*key_restrict_link_func_t___148)(struct key___148 *, const struct key_type *, const union key_payload *, struct key___148 *);

struct key_restriction___148;

struct key___148 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___153 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___148 *restrict_link;
};

struct key_restriction___148 {
	key_restrict_link_func_t___148 check;
	struct key___148 *key;
	struct key_type *keytype;
};

struct seq_operations___141 {
	void * (*start)(struct seq_file___143 *, loff_t *);
	void (*stop)(struct seq_file___143 *, void *);
	void * (*next)(struct seq_file___143 *, void *, loff_t *);
	int (*show)(struct seq_file___143 *, void *);
};

struct kernfs_root___149;

struct kernfs_elem_dir___149 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___149 *root;
};

struct kernfs_syscall_ops___149;

struct kernfs_root___149 {
	struct kernfs_node___149 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___149 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___149 {
	struct kernfs_node___149 *target_kn;
};

struct kernfs_ops___149;

struct kernfs_elem_attr___149 {
	const struct kernfs_ops___149 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___149 *notify_next;
};

struct kernfs_node___149 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___149 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___149 dir;
		struct kernfs_elem_symlink___149 symlink;
		struct kernfs_elem_attr___149 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___149;

struct kernfs_ops___149 {
	int (*open)(struct kernfs_open_file___149 *);
	void (*release)(struct kernfs_open_file___149 *);
	int (*seq_show)(struct seq_file___143 *, void *);
	void * (*seq_start)(struct seq_file___143 *, loff_t *);
	void * (*seq_next)(struct seq_file___143 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___143 *, void *);
	ssize_t (*read)(struct kernfs_open_file___149 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___149 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___149 *, struct vm_area_struct___153 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___149 *, struct poll_table_struct___104 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___149 {
	int (*remount_fs)(struct kernfs_root___149 *, int *, char *);
	int (*show_options)(struct seq_file___143 *, struct kernfs_root___149 *);
	int (*mkdir)(struct kernfs_node___149 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___149 *);
	int (*rename)(struct kernfs_node___149 *, struct kernfs_node___149 *, const char *);
	int (*show_path)(struct seq_file___143 *, struct kernfs_node___149 *, struct kernfs_root___149 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___149 {
	struct kernfs_node___149 *kn;
	struct file___153 *file;
	struct seq_file___143 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___150 *vm_ops;
};

struct cgroup_namespace___129 {
	refcount_t count;
	struct ns_common___4 ns;
	struct user_namespace___133 *user_ns;
	struct ucounts___133 *ucounts;
	struct css_set___129 *root_cset;
};

struct ucounts___133 {
	struct hlist_node node;
	struct user_namespace___133 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___129;

struct bpf_map_ops___129 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___129 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___129 *, struct file___153 *);
	void (*map_free)(struct bpf_map___129 *);
	int (*map_get_next_key)(struct bpf_map___129 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___129 *);
	void * (*map_lookup_elem)(struct bpf_map___129 *, void *);
	int (*map_update_elem)(struct bpf_map___129 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___129 *, void *);
	int (*map_push_elem)(struct bpf_map___129 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___129 *, void *);
	int (*map_peek_elem)(struct bpf_map___129 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___129 *, struct file___153 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___129 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___129 *, void *, struct seq_file___143 *);
	int (*map_check_btf)(const struct bpf_map___129 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___129 {
	const struct bpf_map_ops___129 *ops;
	struct bpf_map___129 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___148 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___129;

typedef void (*kthread_work_func_t___129)(struct kthread_work___129 *);

struct kthread_worker___129;

struct kthread_work___129 {
	struct list_head node;
	kthread_work_func_t___129 func;
	struct kthread_worker___129 *worker;
	int canceling;
};

struct kthread_worker___129 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___153 *task;
	struct kthread_work___129 *current_work;
};

struct kthread_delayed_work___129 {
	struct kthread_work___129 work;
	struct timer_list timer;
};

struct psi_group___129 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___129 *poll_kworker;
	struct kthread_delayed_work___129 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___129;

struct cgroup_rstat_cpu___129;

struct cgroup___129 {
	struct cgroup_subsys_state___129 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___149 *kn;
	struct cgroup_file___129 procs_file;
	struct cgroup_file___129 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___129 *subsys[13];
	struct cgroup_root___129 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___129 *dom_cgrp;
	struct cgroup_rstat_cpu___129 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___4 bpf;
	atomic_t congestion_count;
	struct cgroup___129 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___129 psi;
	int ancestor_ids[0];
};

struct cftype___129;

struct cgroup_subsys___129 {
	struct cgroup_subsys_state___129 * (*css_alloc)(struct cgroup_subsys_state___129 *);
	int (*css_online)(struct cgroup_subsys_state___129 *);
	void (*css_offline)(struct cgroup_subsys_state___129 *);
	void (*css_released)(struct cgroup_subsys_state___129 *);
	void (*css_free)(struct cgroup_subsys_state___129 *);
	void (*css_reset)(struct cgroup_subsys_state___129 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___129 *, int);
	int (*css_extra_stat_show)(struct seq_file___143 *, struct cgroup_subsys_state___129 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___153 *);
	void (*cancel_fork)(struct task_struct___153 *);
	void (*fork)(struct task_struct___153 *);
	void (*exit)(struct task_struct___153 *);
	void (*free)(struct task_struct___153 *);
	void (*bind)(struct cgroup_subsys_state___129 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___129 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___129 *dfl_cftypes;
	struct cftype___129 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___129 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___129 *updated_children;
	struct cgroup___129 *updated_next;
};

struct cgroup_root___129 {
	struct kernfs_root___149 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___129 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___129 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___129 *ss;
	struct list_head node;
	struct kernfs_ops___149 *kf_ops;
	int (*open)(struct kernfs_open_file___149 *);
	void (*release)(struct kernfs_open_file___149 *);
	u64 (*read_u64)(struct cgroup_subsys_state___129 *, struct cftype___129 *);
	s64 (*read_s64)(struct cgroup_subsys_state___129 *, struct cftype___129 *);
	int (*seq_show)(struct seq_file___143 *, void *);
	void * (*seq_start)(struct seq_file___143 *, loff_t *);
	void * (*seq_next)(struct seq_file___143 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___143 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___129 *, struct cftype___129 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___129 *, struct cftype___129 *, s64);
	ssize_t (*write)(struct kernfs_open_file___149 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___149 *, struct poll_table_struct___104 *);
};

struct hstate___29;

struct hugepage_subpool___5 {
	spinlock_t lock;
	long int count;
	long int max_hpages;
	long int used_hpages;
	struct hstate___29 *hstate;
	long int min_hpages;
	long int rsv_hpages;
};

struct hstate___29 {
	int next_nid_to_alloc;
	int next_nid_to_free;
	unsigned int order;
	long unsigned int mask;
	long unsigned int max_huge_pages;
	long unsigned int nr_huge_pages;
	long unsigned int free_huge_pages;
	long unsigned int resv_huge_pages;
	long unsigned int surplus_huge_pages;
	long unsigned int nr_overcommit_huge_pages;
	struct list_head hugepage_activelist;
	struct list_head hugepage_freelists[8];
	unsigned int nr_huge_pages_node[8];
	unsigned int free_huge_pages_node[8];
	unsigned int surplus_huge_pages_node[8];
	struct cftype___129 cgroup_files[5];
	char name[32];
};

struct hugetlbfs_sb_info___5 {
	long int max_inodes;
	long int free_inodes;
	spinlock_t stat_lock;
	struct hstate___29 *hstate;
	struct hugepage_subpool___5 *spool;
	kuid_t uid;
	kgid_t gid;
	umode_t mode;
};

struct bdi_writeback_congested___72 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___72 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___72 {
	struct bio___72 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___72 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___72 bip_inline_vecs[0];
};

struct bio_set___72 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___72 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___67 {
	struct mem_cgroup___67 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___67 {
	struct lruvec___152 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___67 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___67 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct bin_attribute___142 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___153 *, struct kobject___147 *, struct bin_attribute___142 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___153 *, struct kobject___147 *, struct bin_attribute___142 *, char *, loff_t, size_t);
	int (*mmap)(struct file___153 *, struct kobject___147 *, struct bin_attribute___142 *, struct vm_area_struct___153 *);
};

struct sysfs_ops___146 {
	ssize_t (*show)(struct kobject___147 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___147 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___146;

struct kset___146 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___147 kobj;
	const struct kset_uevent_ops___146 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___146 {
	void (*release)(struct kobject___147 *);
	const struct sysfs_ops___146 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___2 * (*child_ns_type)(struct kobject___147 *);
	const void * (*namespace)(struct kobject___147 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___146 {
	int (* const filter)(struct kset___146 *, struct kobject___147 *);
	const char * (* const name)(struct kset___146 *, struct kobject___147 *);
	int (* const uevent)(struct kset___146 *, struct kobject___147 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___143 {
	int (*prepare)(struct device___143 *);
	void (*complete)(struct device___143 *);
	int (*suspend)(struct device___143 *);
	int (*resume)(struct device___143 *);
	int (*freeze)(struct device___143 *);
	int (*thaw)(struct device___143 *);
	int (*poweroff)(struct device___143 *);
	int (*restore)(struct device___143 *);
	int (*suspend_late)(struct device___143 *);
	int (*resume_early)(struct device___143 *);
	int (*freeze_late)(struct device___143 *);
	int (*thaw_early)(struct device___143 *);
	int (*poweroff_late)(struct device___143 *);
	int (*restore_early)(struct device___143 *);
	int (*suspend_noirq)(struct device___143 *);
	int (*resume_noirq)(struct device___143 *);
	int (*freeze_noirq)(struct device___143 *);
	int (*thaw_noirq)(struct device___143 *);
	int (*poweroff_noirq)(struct device___143 *);
	int (*restore_noirq)(struct device___143 *);
	int (*runtime_suspend)(struct device___143 *);
	int (*runtime_resume)(struct device___143 *);
	int (*runtime_idle)(struct device___143 *);
};

struct dev_pm_domain___143 {
	struct dev_pm_ops___143 ops;
	void (*detach)(struct device___143 *, bool);
	int (*activate)(struct device___143 *);
	void (*sync)(struct device___143 *);
	void (*dismiss)(struct device___143 *);
};

struct bus_type___143 {
	const char *name;
	const char *dev_name;
	struct device___143 *dev_root;
	const struct attribute_group___143 **bus_groups;
	const struct attribute_group___143 **dev_groups;
	const struct attribute_group___143 **drv_groups;
	int (*match)(struct device___143 *, struct device_driver___143 *);
	int (*uevent)(struct device___143 *, struct kobj_uevent_env *);
	int (*probe)(struct device___143 *);
	int (*remove)(struct device___143 *);
	void (*shutdown)(struct device___143 *);
	int (*online)(struct device___143 *);
	int (*offline)(struct device___143 *);
	int (*suspend)(struct device___143 *, pm_message_t);
	int (*resume)(struct device___143 *);
	int (*num_vf)(struct device___143 *);
	int (*dma_configure)(struct device___143 *);
	const struct dev_pm_ops___143 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___143 {
	const char *name;
	struct bus_type___143 *bus;
	struct module___130 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___143 *);
	int (*remove)(struct device___143 *);
	void (*shutdown)(struct device___143 *);
	int (*suspend)(struct device___143 *, pm_message_t);
	int (*resume)(struct device___143 *);
	const struct attribute_group___143 **groups;
	const struct dev_pm_ops___143 *pm;
	void (*coredump)(struct device___143 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___143 {
	const char *name;
	const struct attribute_group___143 **groups;
	int (*uevent)(struct device___143 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___143 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___143 *);
	const struct dev_pm_ops___143 *pm;
};

struct class___143 {
	const char *name;
	struct module___130 *owner;
	const struct attribute_group___143 **class_groups;
	const struct attribute_group___143 **dev_groups;
	struct kobject___147 *dev_kobj;
	int (*dev_uevent)(struct device___143 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___143 *, umode_t *);
	void (*class_release)(struct class___143 *);
	void (*dev_release)(struct device___143 *);
	int (*shutdown_pre)(struct device___143 *);
	const struct kobj_ns_type_operations___2 *ns_type;
	const void * (*namespace)(struct device___143 *);
	const struct dev_pm_ops___143 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___121 {
	struct device___143 dev;
};

struct kernel_param_ops___127 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___127 *);
	int (*get)(char *, const struct kernel_param___127 *);
	void (*free)(void *);
};

struct kparam_array___127;

struct kernel_param___127 {
	const char *name;
	struct module___130 *mod;
	const struct kernel_param_ops___127 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___127 *arr;
	};
};

struct kparam_array___127 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___127 *ops;
	void *elem;
};

struct module_attribute___127 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___127 *, struct module_kobject___127 *, char *);
	ssize_t (*store)(struct module_attribute___127 *, struct module_kobject___127 *, const char *, size_t);
	void (*setup)(struct module___130 *, const char *);
	int (*test)(struct module___130 *);
	void (*free)(struct module___130 *);
};

struct trace_event_class___88;

struct trace_event_call___88 {
	struct list_head list;
	struct trace_event_class___88 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___4 *prog_array;
	int (*perf_perm)(struct trace_event_call___88 *, struct perf_event___95 *);
};

struct perf_cpu_context___95;

struct pmu___95 {
	struct list_head entry;
	struct module___130 *module;
	struct device___143 *dev;
	const struct attribute_group___143 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___95 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___95 *);
	void (*pmu_disable)(struct pmu___95 *);
	int (*event_init)(struct perf_event___95 *);
	void (*event_mapped)(struct perf_event___95 *, struct mm_struct___152 *);
	void (*event_unmapped)(struct perf_event___95 *, struct mm_struct___152 *);
	int (*add)(struct perf_event___95 *, int);
	void (*del)(struct perf_event___95 *, int);
	void (*start)(struct perf_event___95 *, int);
	void (*stop)(struct perf_event___95 *, int);
	void (*read)(struct perf_event___95 *);
	void (*start_txn)(struct pmu___95 *, unsigned int);
	int (*commit_txn)(struct pmu___95 *);
	void (*cancel_txn)(struct pmu___95 *);
	int (*event_idx)(struct perf_event___95 *);
	void (*sched_task)(struct perf_event_context___95 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___95 *);
	int (*filter_match)(struct perf_event___95 *);
	int (*check_period)(struct perf_event___95 *, u64);
};

struct perf_cpu_context___95 {
	struct perf_event_context___95 ctx;
	struct perf_event_context___95 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___95 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___95 {
	struct cgroup_subsys_state___129 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___88 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___88 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___88 *);
	struct list_head * (*get_fields)(struct trace_event_call___88 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___88 *);
};

struct syscall_metadata___35 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___88 *enter_event;
	struct trace_event_call___88 *exit_event;
};

struct mempolicy_operations {
	int (*create)(struct mempolicy *, const nodemask_t *);
	void (*rebind)(struct mempolicy *, const nodemask_t *);
};

struct queue_pages {
	struct list_head *pagelist;
	long unsigned int flags;
	nodemask_t *nmask;
	struct vm_area_struct___153 *prev;
};

struct anon_vma_chain___3 {
	struct vm_area_struct___144 *vma;
	struct anon_vma___9 *anon_vma;
	struct list_head same_vma;
	struct rb_node rb;
	long unsigned int rb_subtree_last;
};

struct rmap_walk_control___2 {
	void *arg;
	bool (*rmap_one)(struct page___144 *, struct vm_area_struct___144 *, long unsigned int, void *);
	int (*done)(struct page___144 *);
	struct anon_vma___9 * (*anon_lock)(struct page___144 *);
	bool (*invalid_vma)(struct vm_area_struct___144 *, void *);
};

struct rmap_item;

struct mm_slot {
	struct hlist_node link;
	struct list_head mm_list;
	struct rmap_item *rmap_list;
	struct mm_struct___143 *mm;
};

struct stable_node;

struct rmap_item {
	struct rmap_item *rmap_list;
	union {
		struct anon_vma___9 *anon_vma;
		int nid;
	};
	struct mm_struct___143 *mm;
	long unsigned int address;
	unsigned int oldchecksum;
	union {
		struct rb_node node;
		struct {
			struct stable_node *head;
			struct hlist_node hlist;
		};
	};
};

struct ksm_scan {
	struct mm_slot *mm_slot;
	long unsigned int address;
	struct rmap_item **rmap_list;
	long unsigned int seqnr;
};

struct stable_node {
	union {
		struct rb_node node;
		struct {
			struct list_head *head;
			struct {
				struct hlist_node hlist_dup;
				struct list_head list;
			};
		};
	};
	struct hlist_head hlist;
	union {
		long unsigned int kpfn;
		long unsigned int chain_prune_time;
	};
	int rmap_hlist_len;
	int nid;
};

struct module___131;

struct file___154;

struct kiocb___154;

struct vm_area_struct___154;

struct inode___154;

struct file_lock___154;

struct page___154;

struct seq_file___144;

struct file_operations___154 {
	struct module___131 *owner;
	loff_t (*llseek)(struct file___154 *, loff_t, int);
	ssize_t (*read)(struct file___154 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___154 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___154 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___154 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___154 *, bool);
	int (*iterate)(struct file___154 *, struct dir_context *);
	int (*iterate_shared)(struct file___154 *, struct dir_context *);
	__poll_t (*poll)(struct file___154 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___154 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___154 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___154 *, struct vm_area_struct___154 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___154 *, struct file___154 *);
	int (*flush)(struct file___154 *, fl_owner_t);
	int (*release)(struct inode___154 *, struct file___154 *);
	int (*fsync)(struct file___154 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___154 *, int);
	int (*lock)(struct file___154 *, int, struct file_lock___154 *);
	ssize_t (*sendpage)(struct file___154 *, struct page___154 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___154 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___154 *, int, struct file_lock___154 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___154 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___154 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___154 *, long int, struct file_lock___154 **, void **);
	long int (*fallocate)(struct file___154 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___144 *, struct file___154 *);
	ssize_t (*copy_file_range)(struct file___154 *, loff_t, struct file___154 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___154 *, loff_t, struct file___154 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___154 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___153 {
	u64 seqnum;
	struct vm_area_struct___154 *vmas[4];
};

struct page_frag___153 {
	struct page___154 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___153;

struct mem_cgroup___68;

struct cred___149;

struct nsproxy___146;

struct bio_list___73;

struct backing_dev_info___73;

struct io_context___36;

struct css_set___130;

struct vm_struct___115;

struct task_struct___154 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___154 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___153 *mm;
	struct mm_struct___153 *active_mm;
	struct vmacache___153 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___154 *real_parent;
	struct task_struct___154 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___154 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___68 *active_memcg;
	long int rh_reserved2;
	struct pid___122 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___122 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___122 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___149 *ptracer_cred;
	const struct cred___149 *real_cred;
	const struct cred___149 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___146 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___154 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___73 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___73 *backing_dev_info;
	struct io_context___36 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___130 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___153 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___68 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___154 *oom_reaper_list;
	struct vm_struct___115 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___95 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___154 *pgtable_t___153;

struct address_space___153;

struct kmem_cache___5;

struct dev_pagemap___151;

struct page___154 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___153 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___154 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache___5 *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___153 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___153 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___151 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___68 *mem_cgroup;
};

struct pglist_data___153;

struct lruvec___153 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___153 *pgdat;
};

struct zone___153 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___153 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___153 {
	struct zone___153 *zone;
	int zone_idx;
};

struct zonelist___153 {
	struct zoneref___153 _zonerefs[25];
};

struct pglist_data___153 {
	struct zone___153 node_zones[3];
	struct zonelist___153 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___154 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___154 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___153 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

typedef struct pglist_data___153 pg_data_t___13;

struct rw_semaphore___154 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___154 *owner;
};

struct secondary_data___154 {
	void *stack;
	struct task_struct___154 *task;
	long int status;
};

struct blocking_notifier_head___153 {
	struct rw_semaphore___154 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___151;

struct vm_area_struct___154 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___154 *vm_next;
	struct vm_area_struct___154 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___153 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___151 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___154 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___153;

struct user_namespace___134;

struct mm_struct___153 {
	struct {
		struct vm_area_struct___154 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___154 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___154 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___153 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___154 *owner;
		struct user_namespace___134 *user_ns;
		struct file___154 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___153 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___153;

struct address_space___153 {
	struct inode___154 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___154 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___153 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___147;

struct kobj_type___147;

struct kernfs_node___150;

struct kobject___148 {
	const char *name;
	struct list_head entry;
	struct kobject___148 *parent;
	struct kset___147 *kset;
	struct kobj_type___147 *ktype;
	struct kernfs_node___150 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct memcg_cache_array___5;

struct memcg_cache_params___5 {
	struct kmem_cache___5 *root_cache;
	union {
		struct {
			struct memcg_cache_array___5 *memcg_caches;
			struct list_head __root_caches_node;
			struct list_head children;
			bool dying;
		};
		struct {
			struct mem_cgroup___68 *memcg;
			struct list_head children_node;
			struct list_head kmem_caches_node;
			struct percpu_ref refcnt;
			void (*work_fn)(struct kmem_cache___5 *);
			union {
				struct callback_head callback_head;
				struct work_struct work;
			};
		};
	};
};

struct kmem_cache_cpu___5;

struct kmem_cache___5 {
	struct kmem_cache_cpu___5 *cpu_slab;
	slab_flags_t flags;
	long unsigned int min_partial;
	unsigned int size;
	unsigned int object_size;
	unsigned int offset;
	unsigned int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	unsigned int inuse;
	unsigned int align;
	unsigned int red_left_pad;
	const char *name;
	struct list_head list;
	struct kobject___148 kobj;
	struct work_struct kobj_remove_work;
	struct memcg_cache_params___5 memcg_params;
	unsigned int max_attr_size;
	struct kset___147 *memcg_kset;
	unsigned int remote_node_defrag_ratio;
	unsigned int *random_seq;
	unsigned int useroffset;
	unsigned int usersize;
	struct kmem_cache_node *node[8];
};

typedef int (*dev_page_fault_t___151)(struct vm_area_struct___154 *, long unsigned int, const struct page___154 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___151)(struct page___154 *, void *);

struct device___144;

struct dev_pagemap___151 {
	dev_page_fault_t___151 page_fault;
	dev_page_free_t___151 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___144 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct cgroup___130;

struct cgroup_subsys___130;

struct cgroup_subsys_state___130 {
	struct cgroup___130 *cgroup;
	struct cgroup_subsys___130 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___130 *parent;
};

struct cgroup_file___130 {
	struct kernfs_node___150 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___68;

struct mem_cgroup___68 {
	struct cgroup_subsys_state___130 css;
	struct mem_cgroup_id___6 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___130 events_file;
	struct cgroup_file___130 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___154 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___68 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry___153;

struct path___153 {
	struct vfsmount *mnt;
	struct dentry___153 *dentry;
};

struct file___154 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___153 f_path;
	struct inode___154 *f_inode;
	const struct file_operations___154 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___122 f_owner;
	const struct cred___149 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___153 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___151;

struct vm_operations_struct___151 {
	void (*open)(struct vm_area_struct___154 *);
	void (*close)(struct vm_area_struct___154 *);
	int (*split)(struct vm_area_struct___154 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___154 *);
	vm_fault_t (*fault)(struct vm_fault___151 *);
	vm_fault_t (*huge_fault)(struct vm_fault___151 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___151 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___154 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___151 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___151 *);
	int (*access)(struct vm_area_struct___154 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___154 *);
	int (*set_policy)(struct vm_area_struct___154 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___154 *, long unsigned int);
	struct page___154 * (*find_special_page)(struct vm_area_struct___154 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___153 {
	struct task_struct___154 *task;
	struct core_thread___153 *next;
};

struct core_state___153 {
	atomic_t nr_threads;
	struct core_thread___153 dumper;
	struct completion startup;
};

struct key___149;

struct ucounts___134;

struct user_namespace___134 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___134 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___4 ns;
	long unsigned int flags;
	struct key___149 *persistent_keyring_register;
	struct rw_semaphore___154 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___134 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___151 {
	struct vm_area_struct___154 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___154 *cow_page;
	struct mem_cgroup___68 *memcg;
	struct page___154 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___153 prealloc_pte;
};

struct shrink_control___68 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___68 *memcg;
};

struct shrinker___68 {
	long unsigned int (*count_objects)(struct shrinker___68 *, struct shrink_control___68 *);
	long unsigned int (*scan_objects)(struct shrinker___68 *, struct shrink_control___68 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct user_struct___149 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___149 *uid_keyring;
	struct key___149 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___149 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___149 *session_keyring;
	struct key___149 *process_keyring;
	struct key___149 *thread_keyring;
	struct key___149 *request_key_auth;
	void *security;
	struct user_struct___149 *user;
	struct user_namespace___134 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___130;

struct nsproxy___146 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___130 *cgroup_ns;
};

struct bio___73;

struct bio_list___73 {
	struct bio___73 *head;
	struct bio___73 *tail;
};

struct bdi_writeback_congested___73;

struct bdi_writeback___73 {
	struct backing_dev_info___73 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___73 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___130 *memcg_css;
	struct cgroup_subsys_state___130 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___73 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___73 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___144 *dev;
	struct device___144 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___153 *debug_dir;
	struct dentry___153 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___36;

struct io_context___36 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___36 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___130 {
	struct cgroup_subsys_state___130 *subsys[13];
	refcount_t refcount;
	struct css_set___130 *dom_cset;
	struct cgroup___130 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___130 *mg_src_cgrp;
	struct cgroup___130 *mg_dst_cgrp;
	struct css_set___130 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct vm_struct___115 {
	struct vm_struct___115 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___154 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___138 {
	struct task_struct___154 task;
	long unsigned int stack[8192];
};

struct dev_pm_info___144 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___144 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___144;

struct bus_type___144;

struct device_driver___144;

struct dev_pm_domain___144;

struct class___144;

struct attribute_group___144;

struct device___144 {
	struct device___144 *parent;
	struct device_private *p;
	struct kobject___148 kobj;
	const char *init_name;
	const struct device_type___144 *type;
	struct mutex mutex;
	struct bus_type___144 *bus;
	struct device_driver___144 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___144 power;
	struct dev_pm_domain___144 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___144 *class;
	const struct attribute_group___144 **groups;
	void (*release)(struct device___144 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___153;

struct super_block___153;

struct dentry___153 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___153 *d_parent;
	struct qstr d_name;
	struct inode___154 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___153 *d_op;
	struct super_block___153 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___153;

struct block_device___154;

struct inode___154 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___153 *i_op;
	struct super_block___153 *i_sb;
	struct address_space___153 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___154 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___73 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___154 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___153 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___154 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___153 {
	int (*d_revalidate)(struct dentry___153 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___153 *, unsigned int);
	int (*d_hash)(const struct dentry___153 *, struct qstr *);
	int (*d_compare)(const struct dentry___153 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___153 *);
	int (*d_init)(struct dentry___153 *);
	void (*d_release)(struct dentry___153 *);
	void (*d_prune)(struct dentry___153 *);
	void (*d_iput)(struct dentry___153 *, struct inode___154 *);
	char * (*d_dname)(struct dentry___153 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___153 *);
	int (*d_manage)(const struct path___153 *, bool);
	struct dentry___153 * (*d_real)(struct dentry___153 *, const struct inode___154 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___153;

struct mem_dqinfo___153 {
	struct quota_format_type___153 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___153;

struct quota_info___153 {
	unsigned int flags;
	struct rw_semaphore___154 dqio_sem;
	struct inode___154 *files[3];
	struct mem_dqinfo___153 info[3];
	const struct quota_format_ops___153 *ops[3];
};

struct rcuwait___153 {
	struct task_struct___154 *task;
};

struct percpu_rw_semaphore___153 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___154 rw_sem;
	struct rcuwait___153 writer;
	int readers_block;
};

struct sb_writers___153 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___153 rw_sem[3];
};

struct file_system_type___153;

struct super_operations___153;

struct dquot_operations___153;

struct quotactl_ops___153;

struct super_block___153 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___153 *s_type;
	const struct super_operations___153 *s_op;
	const struct dquot_operations___153 *dq_op;
	const struct quotactl_ops___153 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___153 *s_root;
	struct rw_semaphore___154 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___154 *s_bdev;
	struct backing_dev_info___73 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___153 s_dquot;
	struct sb_writers___153 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___153 *s_d_op;
	int cleancache_poolid;
	struct shrinker___68 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___134 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct io_cq___36 {
	struct request_queue___3 *q;
	struct io_context___36 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___5 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___154 {
	struct file___154 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___154 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___153 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___154 *ia_file;
};

struct dquot___153 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___153 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___153 {
	int qf_fmt_id;
	const struct quota_format_ops___153 *qf_ops;
	struct module___131 *qf_owner;
	struct quota_format_type___153 *qf_next;
};

struct quota_format_ops___153 {
	int (*check_quota_file)(struct super_block___153 *, int);
	int (*read_file_info)(struct super_block___153 *, int);
	int (*write_file_info)(struct super_block___153 *, int);
	int (*free_file_info)(struct super_block___153 *, int);
	int (*read_dqblk)(struct dquot___153 *);
	int (*commit_dqblk)(struct dquot___153 *);
	int (*release_dqblk)(struct dquot___153 *);
	int (*get_next_id)(struct super_block___153 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___153 {
	int (*write_dquot)(struct dquot___153 *);
	struct dquot___153 * (*alloc_dquot)(struct super_block___153 *, int);
	void (*destroy_dquot)(struct dquot___153 *);
	int (*acquire_dquot)(struct dquot___153 *);
	int (*release_dquot)(struct dquot___153 *);
	int (*mark_dirty)(struct dquot___153 *);
	int (*write_info)(struct super_block___153 *, int);
	qsize_t * (*get_reserved_space)(struct inode___154 *);
	int (*get_projid)(struct inode___154 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___154 *, qsize_t *);
	int (*get_next_id)(struct super_block___153 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___153 {
	int (*quota_on)(struct super_block___153 *, int, int, const struct path___153 *);
	int (*quota_off)(struct super_block___153 *, int);
	int (*quota_enable)(struct super_block___153 *, unsigned int);
	int (*quota_disable)(struct super_block___153 *, unsigned int);
	int (*quota_sync)(struct super_block___153 *, int);
	int (*set_info)(struct super_block___153 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___153 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___153 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___153 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___153 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___153 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___128 {
	struct kobject___148 kobj;
	struct module___131 *mod;
	struct kobject___148 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___128 {
	struct module___131 *mod;
	struct latch_tree_node node;
};

struct module_layout___128 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___128 mtn;
};

struct module_attribute___128;

struct kernel_param___128;

struct module___131 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___128 mkobj;
	struct module_attribute___128 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___148 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___128 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___128 core_layout;
	struct module_layout___128 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___70;

struct swap_info_struct___50;

struct address_space_operations___153 {
	int (*writepage)(struct page___154 *, struct writeback_control___70 *);
	int (*readpage)(struct file___154 *, struct page___154 *);
	int (*writepages)(struct address_space___153 *, struct writeback_control___70 *);
	int (*set_page_dirty)(struct page___154 *);
	int (*readpages)(struct file___154 *, struct address_space___153 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___154 *, struct address_space___153 *, loff_t, unsigned int, unsigned int, struct page___154 **, void **);
	int (*write_end)(struct file___154 *, struct address_space___153 *, loff_t, unsigned int, unsigned int, struct page___154 *, void *);
	sector_t (*bmap)(struct address_space___153 *, sector_t);
	void (*invalidatepage)(struct page___154 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___154 *, gfp_t);
	void (*freepage)(struct page___154 *);
	ssize_t (*direct_IO)(struct kiocb___154 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___153 *, struct page___154 *, struct page___154 *, enum migrate_mode);
	bool (*isolate_page)(struct page___154 *, isolate_mode_t);
	void (*putback_page)(struct page___154 *);
	int (*launder_page)(struct page___154 *);
	int (*is_partially_uptodate)(struct page___154 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___154 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___153 *, struct page___154 *);
	int (*swap_activate)(struct swap_info_struct___50 *, struct file___154 *, sector_t *);
	void (*swap_deactivate)(struct file___154 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___70 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___73 *wb;
	struct inode___154 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct swap_info_struct___50 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___154 *bdev;
	struct file___154 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___154 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___154 *bd_inode;
	struct super_block___153 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___154 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___73 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___153 {
	struct dentry___153 * (*lookup)(struct inode___154 *, struct dentry___153 *, unsigned int);
	const char * (*get_link)(struct dentry___153 *, struct inode___154 *, struct delayed_call *);
	int (*permission)(struct inode___154 *, int);
	struct posix_acl * (*get_acl)(struct inode___154 *, int);
	int (*readlink)(struct dentry___153 *, char *, int);
	int (*create)(struct inode___154 *, struct dentry___153 *, umode_t, bool);
	int (*link)(struct dentry___153 *, struct inode___154 *, struct dentry___153 *);
	int (*unlink)(struct inode___154 *, struct dentry___153 *);
	int (*symlink)(struct inode___154 *, struct dentry___153 *, const char *);
	int (*mkdir)(struct inode___154 *, struct dentry___153 *, umode_t);
	int (*rmdir)(struct inode___154 *, struct dentry___153 *);
	int (*mknod)(struct inode___154 *, struct dentry___153 *, umode_t, dev_t);
	int (*rename)(struct inode___154 *, struct dentry___153 *, struct inode___154 *, struct dentry___153 *, unsigned int);
	int (*setattr)(struct dentry___153 *, struct iattr___153 *);
	int (*getattr)(const struct path___153 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___153 *, char *, size_t);
	int (*fiemap)(struct inode___154 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___154 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___154 *, struct dentry___153 *, struct file___154 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___154 *, struct dentry___153 *, umode_t);
	int (*set_acl)(struct inode___154 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___153 {
	void (*fl_copy_lock)(struct file_lock___154 *, struct file_lock___154 *);
	void (*fl_release_private)(struct file_lock___154 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___153;

struct lock_manager_operations___153;

struct file_lock___154 {
	struct file_lock___154 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___154 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___153 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___153 *fl_ops;
	const struct lock_manager_operations___153 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___153 {
	int (*lm_compare_owner)(struct file_lock___154 *, struct file_lock___154 *);
	long unsigned int (*lm_owner_key)(struct file_lock___154 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___154 *);
	int (*lm_grant)(struct file_lock___154 *, int);
	bool (*lm_break)(struct file_lock___154 *);
	int (*lm_change)(struct file_lock___154 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___154 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___153 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___153 *fa_next;
	struct file___154 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___153 {
	const char *name;
	int fs_flags;
	struct dentry___153 * (*mount)(struct file_system_type___153 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___153 *);
	struct module___131 *owner;
	struct file_system_type___153 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___153 {
	struct inode___154 * (*alloc_inode)(struct super_block___153 *);
	void (*destroy_inode)(struct inode___154 *);
	void (*dirty_inode)(struct inode___154 *, int);
	int (*write_inode)(struct inode___154 *, struct writeback_control___70 *);
	int (*drop_inode)(struct inode___154 *);
	void (*evict_inode)(struct inode___154 *);
	void (*put_super)(struct super_block___153 *);
	int (*sync_fs)(struct super_block___153 *, int);
	int (*freeze_super)(struct super_block___153 *);
	int (*freeze_fs)(struct super_block___153 *);
	int (*thaw_super)(struct super_block___153 *);
	int (*unfreeze_fs)(struct super_block___153 *);
	int (*statfs)(struct dentry___153 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___153 *, int *, char *);
	void (*umount_begin)(struct super_block___153 *);
	int (*show_options)(struct seq_file___144 *, struct dentry___153 *);
	int (*show_devname)(struct seq_file___144 *, struct dentry___153 *);
	int (*show_path)(struct seq_file___144 *, struct dentry___153 *);
	int (*show_stats)(struct seq_file___144 *, struct dentry___153 *);
	ssize_t (*quota_read)(struct super_block___153 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___153 *, int, const char *, size_t, loff_t);
	struct dquot___153 ** (*get_dquots)(struct inode___154 *);
	int (*bdev_try_to_free_page)(struct super_block___153 *, struct page___154 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___153 *, struct shrink_control___68 *);
	long int (*free_cached_objects)(struct super_block___153 *, struct shrink_control___68 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___142;

struct seq_file___144 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___142 *op;
	int poll_event;
	const struct file___154 *file;
	void *private;
};

typedef void bio_end_io_t___73(struct bio___73 *);

struct bio_vec___73 {
	struct page___154 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___73;

struct bio_set___73;

struct bio___73 {
	struct bio___73 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___73 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___73 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___73 *bi_io_vec;
	struct bio_set___73 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___73 bi_inline_vecs[0];
};

struct kobj_attribute___148 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___148 *, struct kobj_attribute___148 *, char *);
	ssize_t (*store)(struct kobject___148 *, struct kobj_attribute___148 *, const char *, size_t);
};

typedef void compound_page_dtor___151(struct page___154 *);

typedef int (*key_restrict_link_func_t___149)(struct key___149 *, const struct key_type *, const union key_payload *, struct key___149 *);

struct key_restriction___149;

struct key___149 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___154 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___149 *restrict_link;
};

struct key_restriction___149 {
	key_restrict_link_func_t___149 check;
	struct key___149 *key;
	struct key_type *keytype;
};

struct seq_operations___142 {
	void * (*start)(struct seq_file___144 *, loff_t *);
	void (*stop)(struct seq_file___144 *, void *);
	void * (*next)(struct seq_file___144 *, void *, loff_t *);
	int (*show)(struct seq_file___144 *, void *);
};

struct kernfs_root___150;

struct kernfs_elem_dir___150 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___150 *root;
};

struct kernfs_syscall_ops___150;

struct kernfs_root___150 {
	struct kernfs_node___150 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___150 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___150 {
	struct kernfs_node___150 *target_kn;
};

struct kernfs_ops___150;

struct kernfs_elem_attr___150 {
	const struct kernfs_ops___150 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___150 *notify_next;
};

struct kernfs_node___150 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___150 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___150 dir;
		struct kernfs_elem_symlink___150 symlink;
		struct kernfs_elem_attr___150 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___150;

struct kernfs_ops___150 {
	int (*open)(struct kernfs_open_file___150 *);
	void (*release)(struct kernfs_open_file___150 *);
	int (*seq_show)(struct seq_file___144 *, void *);
	void * (*seq_start)(struct seq_file___144 *, loff_t *);
	void * (*seq_next)(struct seq_file___144 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___144 *, void *);
	ssize_t (*read)(struct kernfs_open_file___150 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___150 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___150 *, struct vm_area_struct___154 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___150 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___150 {
	int (*remount_fs)(struct kernfs_root___150 *, int *, char *);
	int (*show_options)(struct seq_file___144 *, struct kernfs_root___150 *);
	int (*mkdir)(struct kernfs_node___150 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___150 *);
	int (*rename)(struct kernfs_node___150 *, struct kernfs_node___150 *, const char *);
	int (*show_path)(struct seq_file___144 *, struct kernfs_node___150 *, struct kernfs_root___150 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___150 {
	struct kernfs_node___150 *kn;
	struct file___154 *file;
	struct seq_file___144 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___151 *vm_ops;
};

struct cgroup_namespace___130 {
	refcount_t count;
	struct ns_common___4 ns;
	struct user_namespace___134 *user_ns;
	struct ucounts___134 *ucounts;
	struct css_set___130 *root_cset;
};

struct ucounts___134 {
	struct hlist_node node;
	struct user_namespace___134 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___130;

struct bpf_map_ops___130 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___130 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___130 *, struct file___154 *);
	void (*map_free)(struct bpf_map___130 *);
	int (*map_get_next_key)(struct bpf_map___130 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___130 *);
	void * (*map_lookup_elem)(struct bpf_map___130 *, void *);
	int (*map_update_elem)(struct bpf_map___130 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___130 *, void *);
	int (*map_push_elem)(struct bpf_map___130 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___130 *, void *);
	int (*map_peek_elem)(struct bpf_map___130 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___130 *, struct file___154 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___130 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___130 *, void *, struct seq_file___144 *);
	int (*map_check_btf)(const struct bpf_map___130 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___130 {
	const struct bpf_map_ops___130 *ops;
	struct bpf_map___130 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___149 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___130;

typedef void (*kthread_work_func_t___130)(struct kthread_work___130 *);

struct kthread_worker___130;

struct kthread_work___130 {
	struct list_head node;
	kthread_work_func_t___130 func;
	struct kthread_worker___130 *worker;
	int canceling;
};

struct kthread_worker___130 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___154 *task;
	struct kthread_work___130 *current_work;
};

struct kthread_delayed_work___130 {
	struct kthread_work___130 work;
	struct timer_list timer;
};

struct psi_group___130 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___130 *poll_kworker;
	struct kthread_delayed_work___130 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___130;

struct cgroup_rstat_cpu___130;

struct cgroup___130 {
	struct cgroup_subsys_state___130 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___150 *kn;
	struct cgroup_file___130 procs_file;
	struct cgroup_file___130 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___130 *subsys[13];
	struct cgroup_root___130 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___130 *dom_cgrp;
	struct cgroup_rstat_cpu___130 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___4 bpf;
	atomic_t congestion_count;
	struct cgroup___130 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___130 psi;
	int ancestor_ids[0];
};

struct cftype___130;

struct cgroup_subsys___130 {
	struct cgroup_subsys_state___130 * (*css_alloc)(struct cgroup_subsys_state___130 *);
	int (*css_online)(struct cgroup_subsys_state___130 *);
	void (*css_offline)(struct cgroup_subsys_state___130 *);
	void (*css_released)(struct cgroup_subsys_state___130 *);
	void (*css_free)(struct cgroup_subsys_state___130 *);
	void (*css_reset)(struct cgroup_subsys_state___130 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___130 *, int);
	int (*css_extra_stat_show)(struct seq_file___144 *, struct cgroup_subsys_state___130 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___154 *);
	void (*cancel_fork)(struct task_struct___154 *);
	void (*fork)(struct task_struct___154 *);
	void (*exit)(struct task_struct___154 *);
	void (*free)(struct task_struct___154 *);
	void (*bind)(struct cgroup_subsys_state___130 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___130 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___130 *dfl_cftypes;
	struct cftype___130 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___130 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___130 *updated_children;
	struct cgroup___130 *updated_next;
};

struct cgroup_root___130 {
	struct kernfs_root___150 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___130 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___130 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___130 *ss;
	struct list_head node;
	struct kernfs_ops___150 *kf_ops;
	int (*open)(struct kernfs_open_file___150 *);
	void (*release)(struct kernfs_open_file___150 *);
	u64 (*read_u64)(struct cgroup_subsys_state___130 *, struct cftype___130 *);
	s64 (*read_s64)(struct cgroup_subsys_state___130 *, struct cftype___130 *);
	int (*seq_show)(struct seq_file___144 *, void *);
	void * (*seq_start)(struct seq_file___144 *, loff_t *);
	void * (*seq_next)(struct seq_file___144 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___144 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___130 *, struct cftype___130 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___130 *, struct cftype___130 *, s64);
	ssize_t (*write)(struct kernfs_open_file___150 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___150 *, struct poll_table_struct___6 *);
};

struct bdi_writeback_congested___73 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___73 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___73 {
	struct bio___73 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___73 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___73 bip_inline_vecs[0];
};

struct bio_set___73 {
	struct kmem_cache___5 *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___73 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___68 {
	struct mem_cgroup___68 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___68 {
	struct lruvec___153 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___68 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___68 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct bin_attribute___143;

struct attribute_group___144 {
	const char *name;
	umode_t (*is_visible)(struct kobject___148 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___148 *, struct bin_attribute___143 *, int);
	struct attribute **attrs;
	struct bin_attribute___143 **bin_attrs;
};

struct bin_attribute___143 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___154 *, struct kobject___148 *, struct bin_attribute___143 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___154 *, struct kobject___148 *, struct bin_attribute___143 *, char *, loff_t, size_t);
	int (*mmap)(struct file___154 *, struct kobject___148 *, struct bin_attribute___143 *, struct vm_area_struct___154 *);
};

struct sysfs_ops___147 {
	ssize_t (*show)(struct kobject___148 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___148 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___147;

struct kset___147 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___148 kobj;
	const struct kset_uevent_ops___147 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___147 {
	void (*release)(struct kobject___148 *);
	const struct sysfs_ops___147 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___2 * (*child_ns_type)(struct kobject___148 *);
	const void * (*namespace)(struct kobject___148 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___147 {
	int (* const filter)(struct kset___147 *, struct kobject___148 *);
	const char * (* const name)(struct kset___147 *, struct kobject___148 *);
	int (* const uevent)(struct kset___147 *, struct kobject___148 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___144 {
	int (*prepare)(struct device___144 *);
	void (*complete)(struct device___144 *);
	int (*suspend)(struct device___144 *);
	int (*resume)(struct device___144 *);
	int (*freeze)(struct device___144 *);
	int (*thaw)(struct device___144 *);
	int (*poweroff)(struct device___144 *);
	int (*restore)(struct device___144 *);
	int (*suspend_late)(struct device___144 *);
	int (*resume_early)(struct device___144 *);
	int (*freeze_late)(struct device___144 *);
	int (*thaw_early)(struct device___144 *);
	int (*poweroff_late)(struct device___144 *);
	int (*restore_early)(struct device___144 *);
	int (*suspend_noirq)(struct device___144 *);
	int (*resume_noirq)(struct device___144 *);
	int (*freeze_noirq)(struct device___144 *);
	int (*thaw_noirq)(struct device___144 *);
	int (*poweroff_noirq)(struct device___144 *);
	int (*restore_noirq)(struct device___144 *);
	int (*runtime_suspend)(struct device___144 *);
	int (*runtime_resume)(struct device___144 *);
	int (*runtime_idle)(struct device___144 *);
};

struct dev_pm_domain___144 {
	struct dev_pm_ops___144 ops;
	void (*detach)(struct device___144 *, bool);
	int (*activate)(struct device___144 *);
	void (*sync)(struct device___144 *);
	void (*dismiss)(struct device___144 *);
};

struct bus_type___144 {
	const char *name;
	const char *dev_name;
	struct device___144 *dev_root;
	const struct attribute_group___144 **bus_groups;
	const struct attribute_group___144 **dev_groups;
	const struct attribute_group___144 **drv_groups;
	int (*match)(struct device___144 *, struct device_driver___144 *);
	int (*uevent)(struct device___144 *, struct kobj_uevent_env *);
	int (*probe)(struct device___144 *);
	int (*remove)(struct device___144 *);
	void (*shutdown)(struct device___144 *);
	int (*online)(struct device___144 *);
	int (*offline)(struct device___144 *);
	int (*suspend)(struct device___144 *, pm_message_t);
	int (*resume)(struct device___144 *);
	int (*num_vf)(struct device___144 *);
	int (*dma_configure)(struct device___144 *);
	const struct dev_pm_ops___144 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___144 {
	const char *name;
	struct bus_type___144 *bus;
	struct module___131 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___144 *);
	int (*remove)(struct device___144 *);
	void (*shutdown)(struct device___144 *);
	int (*suspend)(struct device___144 *, pm_message_t);
	int (*resume)(struct device___144 *);
	const struct attribute_group___144 **groups;
	const struct dev_pm_ops___144 *pm;
	void (*coredump)(struct device___144 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___144 {
	const char *name;
	const struct attribute_group___144 **groups;
	int (*uevent)(struct device___144 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___144 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___144 *);
	const struct dev_pm_ops___144 *pm;
};

struct class___144 {
	const char *name;
	struct module___131 *owner;
	const struct attribute_group___144 **class_groups;
	const struct attribute_group___144 **dev_groups;
	struct kobject___148 *dev_kobj;
	int (*dev_uevent)(struct device___144 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___144 *, umode_t *);
	void (*class_release)(struct class___144 *);
	void (*dev_release)(struct device___144 *);
	int (*shutdown_pre)(struct device___144 *);
	const struct kobj_ns_type_operations___2 *ns_type;
	const void * (*namespace)(struct device___144 *);
	const struct dev_pm_ops___144 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___122 {
	struct device___144 dev;
};

struct kernel_param_ops___128 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___128 *);
	int (*get)(char *, const struct kernel_param___128 *);
	void (*free)(void *);
};

struct kparam_array___128;

struct kernel_param___128 {
	const char *name;
	struct module___131 *mod;
	const struct kernel_param_ops___128 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___128 *arr;
	};
};

struct kparam_array___128 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___128 *ops;
	void *elem;
};

struct module_attribute___128 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___128 *, struct module_kobject___128 *, char *);
	ssize_t (*store)(struct module_attribute___128 *, struct module_kobject___128 *, const char *, size_t);
	void (*setup)(struct module___131 *, const char *);
	int (*test)(struct module___131 *);
	void (*free)(struct module___131 *);
};

struct memcg_cache_array___5 {
	struct callback_head rcu;
	struct kmem_cache___5 *entries[0];
};

enum stat_item {
	ALLOC_FASTPATH = 0,
	ALLOC_SLOWPATH = 1,
	FREE_FASTPATH = 2,
	FREE_SLOWPATH = 3,
	FREE_FROZEN = 4,
	FREE_ADD_PARTIAL = 5,
	FREE_REMOVE_PARTIAL = 6,
	ALLOC_FROM_PARTIAL = 7,
	ALLOC_SLAB = 8,
	ALLOC_REFILL = 9,
	ALLOC_NODE_MISMATCH = 10,
	FREE_SLAB = 11,
	CPUSLAB_FLUSH = 12,
	DEACTIVATE_FULL = 13,
	DEACTIVATE_EMPTY = 14,
	DEACTIVATE_TO_HEAD = 15,
	DEACTIVATE_TO_TAIL = 16,
	DEACTIVATE_REMOTE_FREES = 17,
	DEACTIVATE_BYPASS = 18,
	ORDER_FALLBACK = 19,
	CMPXCHG_DOUBLE_CPU_FAIL = 20,
	CMPXCHG_DOUBLE_FAIL = 21,
	CPU_PARTIAL_ALLOC = 22,
	CPU_PARTIAL_FREE = 23,
	CPU_PARTIAL_NODE = 24,
	CPU_PARTIAL_DRAIN = 25,
	NR_SLUB_STAT_ITEMS = 26,
};

struct kmem_cache_cpu___5 {
	void **freelist;
	long unsigned int tid;
	struct page___154 *page;
	struct page___154 *partial;
};

struct track {
	long unsigned int addr;
	long unsigned int addrs[16];
	int cpu;
	int pid;
	long unsigned int when;
};

enum track_item {
	TRACK_ALLOC = 0,
	TRACK_FREE = 1,
};

struct detached_freelist {
	struct page___154 *page;
	void *tail;
	void *freelist;
	int cnt;
	struct kmem_cache___5 *s;
};

struct location {
	long unsigned int count;
	long unsigned int addr;
	long long int sum_time;
	long int min_time;
	long int max_time;
	long int min_pid;
	long int max_pid;
	long unsigned int cpus[64];
	nodemask_t nodes;
};

struct loc_track {
	long unsigned int max;
	long unsigned int count;
	struct location *loc;
};

enum slab_stat_type {
	SL_ALL = 0,
	SL_PARTIAL = 1,
	SL_CPU = 2,
	SL_OBJECTS = 3,
	SL_TOTAL = 4,
};

struct slab_attribute {
	struct attribute attr;
	ssize_t (*show)(struct kmem_cache___5 *, char *);
	ssize_t (*store)(struct kmem_cache___5 *, const char *, size_t);
};

struct saved_alias {
	struct kmem_cache___5 *s;
	const char *name;
	struct saved_alias *next;
};

enum slab_modes {
	M_NONE = 0,
	M_PARTIAL = 1,
	M_FULL = 2,
	M_FREE = 3,
};

struct buffer_head;

typedef void bh_end_io_t(struct buffer_head *, int);

struct buffer_head {
	long unsigned int b_state;
	struct buffer_head *b_this_page;
	struct page___131 *b_page;
	sector_t b_blocknr;
	size_t b_size;
	char *b_data;
	struct block_device___131 *b_bdev;
	bh_end_io_t *b_end_io;
	void *b_private;
	struct list_head b_assoc_buffers;
	struct address_space___130 *b_assoc_map;
	atomic_t b_count;
};

struct hugepage_subpool___6 {
	spinlock_t lock;
	long int count;
	long int max_hpages;
	long int used_hpages;
	struct hstate___25 *hstate;
	long int min_hpages;
	long int rsv_hpages;
};

struct hugetlbfs_sb_info___6 {
	long int max_inodes;
	long int free_inodes;
	spinlock_t stat_lock;
	struct hstate___25 *hstate;
	struct hugepage_subpool___6 *spool;
	kuid_t uid;
	kgid_t gid;
	umode_t mode;
};

typedef struct page___131 *new_page_t(struct page___131 *, long unsigned int);

typedef void free_page_t(struct page___131 *, long unsigned int);

enum bh_state_bits {
	BH_Uptodate = 0,
	BH_Dirty = 1,
	BH_Lock = 2,
	BH_Req = 3,
	BH_Uptodate_Lock = 4,
	BH_Mapped = 5,
	BH_New = 6,
	BH_Async_Read = 7,
	BH_Async_Write = 8,
	BH_Delay = 9,
	BH_Boundary = 10,
	BH_Write_EIO = 11,
	BH_Unwritten = 12,
	BH_Quiet = 13,
	BH_Meta = 14,
	BH_Prio = 15,
	BH_Defer_Completion = 16,
	BH_PrivateStart = 17,
};

struct trace_event_file___40;

struct trace_event_buffer___32 {
	struct ring_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___40 *trace_file;
	void *entry;
	long unsigned int flags;
	int pc;
};

struct trace_event_file___40 {
	struct list_head list;
	struct trace_event_call___73 *event_call;
	struct event_filter *filter;
	struct dentry___131 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct syscall_metadata___36 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___73 *enter_event;
	struct trace_event_call___73 *exit_event;
};

struct trace_event_raw_mm_migrate_pages {
	struct trace_entry ent;
	long unsigned int succeeded;
	long unsigned int failed;
	enum migrate_mode mode;
	int reason;
	char __data[0];
};

struct trace_event_data_offsets_mm_migrate_pages {};

struct mmu_gather_batch___6 {
	struct mmu_gather_batch___6 *next;
	unsigned int nr;
	unsigned int max;
	struct page___125 *pages[0];
};

struct mmu_gather___6 {
	struct mm_struct___124 *mm;
	struct mmu_table_batch *batch;
	long unsigned int start;
	long unsigned int end;
	unsigned int fullmm: 1;
	unsigned int need_flush_all: 1;
	struct mmu_gather_batch___6 *active;
	struct mmu_gather_batch___6 local;
	struct page___125 *__pages[8];
	unsigned int batch_count;
	int page_size;
};

struct module___132;

struct file___155;

struct kiocb___155;

struct iov_iter___71;

struct poll_table_struct___105;

struct vm_area_struct___155;

struct inode___155;

struct file_lock___155;

struct page___155;

struct seq_file___145;

struct file_operations___155 {
	struct module___132 *owner;
	loff_t (*llseek)(struct file___155 *, loff_t, int);
	ssize_t (*read)(struct file___155 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___155 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___155 *, struct iov_iter___71 *);
	ssize_t (*write_iter)(struct kiocb___155 *, struct iov_iter___71 *);
	int (*iopoll)(struct kiocb___155 *, bool);
	int (*iterate)(struct file___155 *, struct dir_context *);
	int (*iterate_shared)(struct file___155 *, struct dir_context *);
	__poll_t (*poll)(struct file___155 *, struct poll_table_struct___105 *);
	long int (*unlocked_ioctl)(struct file___155 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___155 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___155 *, struct vm_area_struct___155 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___155 *, struct file___155 *);
	int (*flush)(struct file___155 *, fl_owner_t);
	int (*release)(struct inode___155 *, struct file___155 *);
	int (*fsync)(struct file___155 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___155 *, int);
	int (*lock)(struct file___155 *, int, struct file_lock___155 *);
	ssize_t (*sendpage)(struct file___155 *, struct page___155 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___155 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___155 *, int, struct file_lock___155 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___155 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___155 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___155 *, long int, struct file_lock___155 **, void **);
	long int (*fallocate)(struct file___155 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___145 *, struct file___155 *);
	ssize_t (*copy_file_range)(struct file___155 *, loff_t, struct file___155 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___155 *, loff_t, struct file___155 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___155 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___154 {
	u64 seqnum;
	struct vm_area_struct___155 *vmas[4];
};

struct page_frag___154 {
	struct page___155 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___96;

struct debug_info___96 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___96 *hbp_break[16];
	struct perf_event___96 *hbp_watch[16];
};

struct thread_struct___96 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___96 debug;
	long: 64;
};

struct mm_struct___154;

struct mem_cgroup___69;

struct pid___123;

struct cred___150;

struct nsproxy___147;

struct signal_struct___138;

struct bio_list___74;

struct backing_dev_info___74;

struct css_set___131;

struct perf_event_context___96;

struct task_struct___155 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___155 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___154 *mm;
	struct mm_struct___154 *active_mm;
	struct vmacache___154 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___155 *real_parent;
	struct task_struct___155 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___155 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___69 *active_memcg;
	long int rh_reserved2;
	struct pid___123 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___123 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___123 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___150 *ptracer_cred;
	const struct cred___150 *real_cred;
	const struct cred___150 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___147 *nsproxy;
	struct signal_struct___138 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___155 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___74 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___74 *backing_dev_info;
	struct io_context___36 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___131 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___96 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___154 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___69 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___155 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___96 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___96 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___155 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___96)(struct perf_event___96 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___96;

struct fasync_struct___154;

struct pid_namespace___123;

struct trace_event_call___89;

struct perf_cgroup___96;

struct perf_event___96 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___96 *group_leader;
	struct pmu___96 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___96 hw;
	struct perf_event_context___96 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___96 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___155 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___154 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___96 *);
	struct callback_head callback_head;
	struct pid_namespace___123 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___96 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___96 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___89 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___96 *cgrp;
	struct list_head sb_list;
};

typedef struct page___155 *pgtable_t___154;

struct address_space___154;

struct dev_pagemap___152;

struct page___155 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___154 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___155 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___154 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___154 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___152 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___69 *mem_cgroup;
};

struct pglist_data___154;

struct lruvec___154 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___154 *pgdat;
};

struct zone___154 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___154 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___154 {
	struct zone___154 *zone;
	int zone_idx;
};

struct zonelist___154 {
	struct zoneref___154 _zonerefs[25];
};

struct pglist_data___154 {
	struct zone___154 node_zones[3];
	struct zonelist___154 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___155 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___155 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___154 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___155 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___155 *owner;
};

struct secondary_data___155 {
	void *stack;
	struct task_struct___155 *task;
	long int status;
};

struct blocking_notifier_head___154 {
	struct rw_semaphore___155 rwsem;
	struct notifier_block *head;
};

struct anon_vma___17;

struct vm_operations_struct___152;

struct vm_area_struct___155 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___155 *vm_next;
	struct vm_area_struct___155 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___154 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma___17 *anon_vma;
	const struct vm_operations_struct___152 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___155 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___154;

struct user_namespace___135;

struct mm_struct___154 {
	struct {
		struct vm_area_struct___155 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___155 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___155 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___154 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___155 *owner;
		struct user_namespace___135 *user_ns;
		struct file___155 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___154 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___154;

struct address_space___154 {
	struct inode___155 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___155 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___154 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___152)(struct vm_area_struct___155 *, long unsigned int, const struct page___155 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___152)(struct page___155 *, void *);

struct device___145;

struct dev_pagemap___152 {
	dev_page_fault_t___152 page_fault;
	dev_page_free_t___152 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___145 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct cgroup___131;

struct cgroup_subsys___131;

struct cgroup_subsys_state___131 {
	struct cgroup___131 *cgroup;
	struct cgroup_subsys___131 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___131 *parent;
};

struct kernfs_node___151;

struct cgroup_file___131 {
	struct kernfs_node___151 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___69;

struct mem_cgroup___69 {
	struct cgroup_subsys_state___131 css;
	struct mem_cgroup_id___6 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___131 events_file;
	struct cgroup_file___131 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___155 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___69 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry___154;

struct path___154 {
	struct vfsmount *mnt;
	struct dentry___154 *dentry;
};

struct fown_struct___123 {
	rwlock_t lock;
	struct pid___123 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___155 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___154 f_path;
	struct inode___155 *f_inode;
	const struct file_operations___155 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___123 f_owner;
	const struct cred___150 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___154 *f_mapping;
	errseq_t f_wb_err;
};

struct anon_vma___17 {
	struct anon_vma___17 *root;
	struct rw_semaphore___155 rwsem;
	atomic_t refcount;
	unsigned int degree;
	struct anon_vma___17 *parent;
	struct rb_root_cached rb_root;
};

struct vm_fault___152;

struct vm_operations_struct___152 {
	void (*open)(struct vm_area_struct___155 *);
	void (*close)(struct vm_area_struct___155 *);
	int (*split)(struct vm_area_struct___155 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___155 *);
	vm_fault_t (*fault)(struct vm_fault___152 *);
	vm_fault_t (*huge_fault)(struct vm_fault___152 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___152 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___155 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___152 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___152 *);
	int (*access)(struct vm_area_struct___155 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___155 *);
	int (*set_policy)(struct vm_area_struct___155 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___155 *, long unsigned int);
	struct page___155 * (*find_special_page)(struct vm_area_struct___155 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___154 {
	struct task_struct___155 *task;
	struct core_thread___154 *next;
};

struct core_state___154 {
	atomic_t nr_threads;
	struct core_thread___154 dumper;
	struct completion startup;
};

struct key___150;

struct ucounts___135;

struct user_namespace___135 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___135 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___4 ns;
	long unsigned int flags;
	struct key___150 *persistent_keyring_register;
	struct rw_semaphore___155 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___135 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___152 {
	struct vm_area_struct___155 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___155 *cow_page;
	struct mem_cgroup___69 *memcg;
	struct page___155 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___154 prealloc_pte;
};

struct shrink_control___69 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___69 *memcg;
};

struct shrinker___69 {
	long unsigned int (*count_objects)(struct shrinker___69 *, struct shrink_control___69 *);
	long unsigned int (*scan_objects)(struct shrinker___69 *, struct shrink_control___69 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct upid___123 {
	int nr;
	struct pid_namespace___123 *ns;
};

struct pid_namespace___123 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___155 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___123 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___154 *proc_self;
	struct dentry___154 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___135 *user_ns;
	struct ucounts___135 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___4 ns;
};

struct pid___123 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___123 numbers[1];
};

struct user_struct___150 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___150 *uid_keyring;
	struct key___150 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___150 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___150 *session_keyring;
	struct key___150 *process_keyring;
	struct key___150 *thread_keyring;
	struct key___150 *request_key_auth;
	void *security;
	struct user_struct___150 *user;
	struct user_namespace___135 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___131;

struct nsproxy___147 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___123 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___131 *cgroup_ns;
};

struct signal_struct___138 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___155 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___155 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___123 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___123 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___154 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___123 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide39;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___74;

struct bio_list___74 {
	struct bio___74 *head;
	struct bio___74 *tail;
};

struct bdi_writeback_congested___74;

struct bdi_writeback___74 {
	struct backing_dev_info___74 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___74 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___131 *memcg_css;
	struct cgroup_subsys_state___131 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___74 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___74 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___145 *dev;
	struct device___145 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___154 *debug_dir;
	struct dentry___154 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___131 {
	struct cgroup_subsys_state___131 *subsys[13];
	refcount_t refcount;
	struct css_set___131 *dom_cset;
	struct cgroup___131 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___131 *mg_src_cgrp;
	struct cgroup___131 *mg_dst_cgrp;
	struct css_set___131 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___96 {
	struct pmu___96 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___155 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___96 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

union thread_union___139 {
	struct task_struct___155 task;
	long unsigned int stack[8192];
};

struct kset___148;

struct kobj_type___148;

struct kobject___149 {
	const char *name;
	struct list_head entry;
	struct kobject___149 *parent;
	struct kset___148 *kset;
	struct kobj_type___148 *ktype;
	struct kernfs_node___151 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___145 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___145 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___145;

struct bus_type___145;

struct device_driver___145;

struct dev_pm_domain___145;

struct class___145;

struct attribute_group___145;

struct device___145 {
	struct device___145 *parent;
	struct device_private *p;
	struct kobject___149 kobj;
	const char *init_name;
	const struct device_type___145 *type;
	struct mutex mutex;
	struct bus_type___145 *bus;
	struct device_driver___145 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___145 power;
	struct dev_pm_domain___145 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___145 *class;
	const struct attribute_group___145 **groups;
	void (*release)(struct device___145 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___154;

struct super_block___154;

struct dentry___154 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___154 *d_parent;
	struct qstr d_name;
	struct inode___155 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___154 *d_op;
	struct super_block___154 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___154;

struct block_device___155;

struct inode___155 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___154 *i_op;
	struct super_block___154 *i_sb;
	struct address_space___154 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___155 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___74 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___155 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___154 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___155 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___154 {
	int (*d_revalidate)(struct dentry___154 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___154 *, unsigned int);
	int (*d_hash)(const struct dentry___154 *, struct qstr *);
	int (*d_compare)(const struct dentry___154 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___154 *);
	int (*d_init)(struct dentry___154 *);
	void (*d_release)(struct dentry___154 *);
	void (*d_prune)(struct dentry___154 *);
	void (*d_iput)(struct dentry___154 *, struct inode___155 *);
	char * (*d_dname)(struct dentry___154 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___154 *);
	int (*d_manage)(const struct path___154 *, bool);
	struct dentry___154 * (*d_real)(struct dentry___154 *, const struct inode___155 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___154;

struct mem_dqinfo___154 {
	struct quota_format_type___154 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___154;

struct quota_info___154 {
	unsigned int flags;
	struct rw_semaphore___155 dqio_sem;
	struct inode___155 *files[3];
	struct mem_dqinfo___154 info[3];
	const struct quota_format_ops___154 *ops[3];
};

struct rcuwait___154 {
	struct task_struct___155 *task;
};

struct percpu_rw_semaphore___154 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___155 rw_sem;
	struct rcuwait___154 writer;
	int readers_block;
};

struct sb_writers___154 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___154 rw_sem[3];
};

struct file_system_type___154;

struct super_operations___154;

struct dquot_operations___154;

struct quotactl_ops___154;

struct xattr_handler___13;

struct super_block___154 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___154 *s_type;
	const struct super_operations___154 *s_op;
	const struct dquot_operations___154 *dq_op;
	const struct quotactl_ops___154 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___154 *s_root;
	struct rw_semaphore___155 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___13 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___155 *s_bdev;
	struct backing_dev_info___74 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___154 s_dquot;
	struct sb_writers___154 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___154 *s_d_op;
	int cleancache_poolid;
	struct shrinker___69 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___135 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___155 {
	struct file___155 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___155 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___154 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___155 *ia_file;
};

struct dquot___154 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___154 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___154 {
	int qf_fmt_id;
	const struct quota_format_ops___154 *qf_ops;
	struct module___132 *qf_owner;
	struct quota_format_type___154 *qf_next;
};

struct quota_format_ops___154 {
	int (*check_quota_file)(struct super_block___154 *, int);
	int (*read_file_info)(struct super_block___154 *, int);
	int (*write_file_info)(struct super_block___154 *, int);
	int (*free_file_info)(struct super_block___154 *, int);
	int (*read_dqblk)(struct dquot___154 *);
	int (*commit_dqblk)(struct dquot___154 *);
	int (*release_dqblk)(struct dquot___154 *);
	int (*get_next_id)(struct super_block___154 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___154 {
	int (*write_dquot)(struct dquot___154 *);
	struct dquot___154 * (*alloc_dquot)(struct super_block___154 *, int);
	void (*destroy_dquot)(struct dquot___154 *);
	int (*acquire_dquot)(struct dquot___154 *);
	int (*release_dquot)(struct dquot___154 *);
	int (*mark_dirty)(struct dquot___154 *);
	int (*write_info)(struct super_block___154 *, int);
	qsize_t * (*get_reserved_space)(struct inode___155 *);
	int (*get_projid)(struct inode___155 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___155 *, qsize_t *);
	int (*get_next_id)(struct super_block___154 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___154 {
	int (*quota_on)(struct super_block___154 *, int, int, const struct path___154 *);
	int (*quota_off)(struct super_block___154 *, int);
	int (*quota_enable)(struct super_block___154 *, unsigned int);
	int (*quota_disable)(struct super_block___154 *, unsigned int);
	int (*quota_sync)(struct super_block___154 *, int);
	int (*set_info)(struct super_block___154 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___154 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___154 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___154 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___154 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___154 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___129 {
	struct kobject___149 kobj;
	struct module___132 *mod;
	struct kobject___149 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___129 {
	struct module___132 *mod;
	struct latch_tree_node node;
};

struct module_layout___129 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___129 mtn;
};

struct module_attribute___129;

struct kernel_param___129;

struct module___132 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___129 mkobj;
	struct module_attribute___129 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___149 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___129 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___129 core_layout;
	struct module_layout___129 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___89 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide37;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide38;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___71;

struct swap_info_struct___51;

struct address_space_operations___154 {
	int (*writepage)(struct page___155 *, struct writeback_control___71 *);
	int (*readpage)(struct file___155 *, struct page___155 *);
	int (*writepages)(struct address_space___154 *, struct writeback_control___71 *);
	int (*set_page_dirty)(struct page___155 *);
	int (*readpages)(struct file___155 *, struct address_space___154 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___155 *, struct address_space___154 *, loff_t, unsigned int, unsigned int, struct page___155 **, void **);
	int (*write_end)(struct file___155 *, struct address_space___154 *, loff_t, unsigned int, unsigned int, struct page___155 *, void *);
	sector_t (*bmap)(struct address_space___154 *, sector_t);
	void (*invalidatepage)(struct page___155 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___155 *, gfp_t);
	void (*freepage)(struct page___155 *);
	ssize_t (*direct_IO)(struct kiocb___155 *, struct iov_iter___71 *);
	int (*migratepage)(struct address_space___154 *, struct page___155 *, struct page___155 *, enum migrate_mode);
	bool (*isolate_page)(struct page___155 *, isolate_mode_t);
	void (*putback_page)(struct page___155 *);
	int (*launder_page)(struct page___155 *);
	int (*is_partially_uptodate)(struct page___155 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___155 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___154 *, struct page___155 *);
	int (*swap_activate)(struct swap_info_struct___51 *, struct file___155 *, sector_t *);
	void (*swap_deactivate)(struct file___155 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___71 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___74 *wb;
	struct inode___155 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___74;

struct iov_iter___71 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___74 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct swap_info_struct___51 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___155 *bdev;
	struct file___155 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___155 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___155 *bd_inode;
	struct super_block___154 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___155 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___74 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___154 {
	struct dentry___154 * (*lookup)(struct inode___155 *, struct dentry___154 *, unsigned int);
	const char * (*get_link)(struct dentry___154 *, struct inode___155 *, struct delayed_call *);
	int (*permission)(struct inode___155 *, int);
	struct posix_acl * (*get_acl)(struct inode___155 *, int);
	int (*readlink)(struct dentry___154 *, char *, int);
	int (*create)(struct inode___155 *, struct dentry___154 *, umode_t, bool);
	int (*link)(struct dentry___154 *, struct inode___155 *, struct dentry___154 *);
	int (*unlink)(struct inode___155 *, struct dentry___154 *);
	int (*symlink)(struct inode___155 *, struct dentry___154 *, const char *);
	int (*mkdir)(struct inode___155 *, struct dentry___154 *, umode_t);
	int (*rmdir)(struct inode___155 *, struct dentry___154 *);
	int (*mknod)(struct inode___155 *, struct dentry___154 *, umode_t, dev_t);
	int (*rename)(struct inode___155 *, struct dentry___154 *, struct inode___155 *, struct dentry___154 *, unsigned int);
	int (*setattr)(struct dentry___154 *, struct iattr___154 *);
	int (*getattr)(const struct path___154 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___154 *, char *, size_t);
	int (*fiemap)(struct inode___155 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___155 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___155 *, struct dentry___154 *, struct file___155 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___155 *, struct dentry___154 *, umode_t);
	int (*set_acl)(struct inode___155 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___154 {
	void (*fl_copy_lock)(struct file_lock___155 *, struct file_lock___155 *);
	void (*fl_release_private)(struct file_lock___155 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___154;

struct file_lock___155 {
	struct file_lock___155 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___155 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___154 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___154 *fl_ops;
	const struct lock_manager_operations___154 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___154 {
	int (*lm_compare_owner)(struct file_lock___155 *, struct file_lock___155 *);
	long unsigned int (*lm_owner_key)(struct file_lock___155 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___155 *);
	int (*lm_grant)(struct file_lock___155 *, int);
	bool (*lm_break)(struct file_lock___155 *);
	int (*lm_change)(struct file_lock___155 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___155 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___154 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___154 *fa_next;
	struct file___155 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___154 {
	const char *name;
	int fs_flags;
	struct dentry___154 * (*mount)(struct file_system_type___154 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___154 *);
	struct module___132 *owner;
	struct file_system_type___154 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___154 {
	struct inode___155 * (*alloc_inode)(struct super_block___154 *);
	void (*destroy_inode)(struct inode___155 *);
	void (*dirty_inode)(struct inode___155 *, int);
	int (*write_inode)(struct inode___155 *, struct writeback_control___71 *);
	int (*drop_inode)(struct inode___155 *);
	void (*evict_inode)(struct inode___155 *);
	void (*put_super)(struct super_block___154 *);
	int (*sync_fs)(struct super_block___154 *, int);
	int (*freeze_super)(struct super_block___154 *);
	int (*freeze_fs)(struct super_block___154 *);
	int (*thaw_super)(struct super_block___154 *);
	int (*unfreeze_fs)(struct super_block___154 *);
	int (*statfs)(struct dentry___154 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___154 *, int *, char *);
	void (*umount_begin)(struct super_block___154 *);
	int (*show_options)(struct seq_file___145 *, struct dentry___154 *);
	int (*show_devname)(struct seq_file___145 *, struct dentry___154 *);
	int (*show_path)(struct seq_file___145 *, struct dentry___154 *);
	int (*show_stats)(struct seq_file___145 *, struct dentry___154 *);
	ssize_t (*quota_read)(struct super_block___154 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___154 *, int, const char *, size_t, loff_t);
	struct dquot___154 ** (*get_dquots)(struct inode___155 *);
	int (*bdev_try_to_free_page)(struct super_block___154 *, struct page___155 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___154 *, struct shrink_control___69 *);
	long int (*free_cached_objects)(struct super_block___154 *, struct shrink_control___69 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct xattr_handler___13 {
	const char *name;
	const char *prefix;
	int flags;
	bool (*list)(struct dentry___154 *);
	int (*get)(const struct xattr_handler___13 *, struct dentry___154 *, struct inode___155 *, const char *, void *, size_t);
	int (*set)(const struct xattr_handler___13 *, struct dentry___154 *, struct inode___155 *, const char *, const void *, size_t, int);
};

typedef void (*poll_queue_proc___104)(struct file___155 *, wait_queue_head_t *, struct poll_table_struct___105 *);

struct poll_table_struct___105 {
	poll_queue_proc___104 _qproc;
	__poll_t _key;
};

struct seq_operations___143;

struct seq_file___145 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___143 *op;
	int poll_event;
	const struct file___155 *file;
	void *private;
};

typedef void bio_end_io_t___74(struct bio___74 *);

struct bio_vec___74 {
	struct page___155 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___74;

struct bio_set___74;

struct bio___74 {
	struct bio___74 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___74 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___74 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___74 *bi_io_vec;
	struct bio_set___74 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___74 bi_inline_vecs[0];
};

struct kobj_attribute___149 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___149 *, struct kobj_attribute___149 *, char *);
	ssize_t (*store)(struct kobject___149 *, struct kobj_attribute___149 *, const char *, size_t);
};

typedef void compound_page_dtor___152(struct page___155 *);

typedef int (*key_restrict_link_func_t___150)(struct key___150 *, const struct key_type *, const union key_payload *, struct key___150 *);

struct key_restriction___150;

struct key___150 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___155 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___150 *restrict_link;
};

struct key_restriction___150 {
	key_restrict_link_func_t___150 check;
	struct key___150 *key;
	struct key_type *keytype;
};

struct seq_operations___143 {
	void * (*start)(struct seq_file___145 *, loff_t *);
	void (*stop)(struct seq_file___145 *, void *);
	void * (*next)(struct seq_file___145 *, void *, loff_t *);
	int (*show)(struct seq_file___145 *, void *);
};

struct kernfs_root___151;

struct kernfs_elem_dir___151 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___151 *root;
};

struct kernfs_syscall_ops___151;

struct kernfs_root___151 {
	struct kernfs_node___151 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___151 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___151 {
	struct kernfs_node___151 *target_kn;
};

struct kernfs_ops___151;

struct kernfs_elem_attr___151 {
	const struct kernfs_ops___151 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___151 *notify_next;
};

struct kernfs_node___151 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___151 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___151 dir;
		struct kernfs_elem_symlink___151 symlink;
		struct kernfs_elem_attr___151 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___151;

struct kernfs_ops___151 {
	int (*open)(struct kernfs_open_file___151 *);
	void (*release)(struct kernfs_open_file___151 *);
	int (*seq_show)(struct seq_file___145 *, void *);
	void * (*seq_start)(struct seq_file___145 *, loff_t *);
	void * (*seq_next)(struct seq_file___145 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___145 *, void *);
	ssize_t (*read)(struct kernfs_open_file___151 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___151 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___151 *, struct vm_area_struct___155 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___151 *, struct poll_table_struct___105 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___151 {
	int (*remount_fs)(struct kernfs_root___151 *, int *, char *);
	int (*show_options)(struct seq_file___145 *, struct kernfs_root___151 *);
	int (*mkdir)(struct kernfs_node___151 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___151 *);
	int (*rename)(struct kernfs_node___151 *, struct kernfs_node___151 *, const char *);
	int (*show_path)(struct seq_file___145 *, struct kernfs_node___151 *, struct kernfs_root___151 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___151 {
	struct kernfs_node___151 *kn;
	struct file___155 *file;
	struct seq_file___145 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___152 *vm_ops;
};

struct cgroup_namespace___131 {
	refcount_t count;
	struct ns_common___4 ns;
	struct user_namespace___135 *user_ns;
	struct ucounts___135 *ucounts;
	struct css_set___131 *root_cset;
};

struct ucounts___135 {
	struct hlist_node node;
	struct user_namespace___135 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___131;

struct bpf_map_ops___131 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___131 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___131 *, struct file___155 *);
	void (*map_free)(struct bpf_map___131 *);
	int (*map_get_next_key)(struct bpf_map___131 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___131 *);
	void * (*map_lookup_elem)(struct bpf_map___131 *, void *);
	int (*map_update_elem)(struct bpf_map___131 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___131 *, void *);
	int (*map_push_elem)(struct bpf_map___131 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___131 *, void *);
	int (*map_peek_elem)(struct bpf_map___131 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___131 *, struct file___155 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___131 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___131 *, void *, struct seq_file___145 *);
	int (*map_check_btf)(const struct bpf_map___131 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___131 {
	const struct bpf_map_ops___131 *ops;
	struct bpf_map___131 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___150 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___131;

typedef void (*kthread_work_func_t___131)(struct kthread_work___131 *);

struct kthread_worker___131;

struct kthread_work___131 {
	struct list_head node;
	kthread_work_func_t___131 func;
	struct kthread_worker___131 *worker;
	int canceling;
};

struct kthread_worker___131 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___155 *task;
	struct kthread_work___131 *current_work;
};

struct kthread_delayed_work___131 {
	struct kthread_work___131 work;
	struct timer_list timer;
};

struct psi_group___131 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___131 *poll_kworker;
	struct kthread_delayed_work___131 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___131;

struct cgroup_rstat_cpu___131;

struct cgroup___131 {
	struct cgroup_subsys_state___131 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___151 *kn;
	struct cgroup_file___131 procs_file;
	struct cgroup_file___131 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___131 *subsys[13];
	struct cgroup_root___131 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___131 *dom_cgrp;
	struct cgroup_rstat_cpu___131 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___4 bpf;
	atomic_t congestion_count;
	struct cgroup___131 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___131 psi;
	int ancestor_ids[0];
};

struct cftype___131;

struct cgroup_subsys___131 {
	struct cgroup_subsys_state___131 * (*css_alloc)(struct cgroup_subsys_state___131 *);
	int (*css_online)(struct cgroup_subsys_state___131 *);
	void (*css_offline)(struct cgroup_subsys_state___131 *);
	void (*css_released)(struct cgroup_subsys_state___131 *);
	void (*css_free)(struct cgroup_subsys_state___131 *);
	void (*css_reset)(struct cgroup_subsys_state___131 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___131 *, int);
	int (*css_extra_stat_show)(struct seq_file___145 *, struct cgroup_subsys_state___131 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___155 *);
	void (*cancel_fork)(struct task_struct___155 *);
	void (*fork)(struct task_struct___155 *);
	void (*exit)(struct task_struct___155 *);
	void (*free)(struct task_struct___155 *);
	void (*bind)(struct cgroup_subsys_state___131 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___131 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___131 *dfl_cftypes;
	struct cftype___131 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___131 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___131 *updated_children;
	struct cgroup___131 *updated_next;
};

struct cgroup_root___131 {
	struct kernfs_root___151 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___131 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___131 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___131 *ss;
	struct list_head node;
	struct kernfs_ops___151 *kf_ops;
	int (*open)(struct kernfs_open_file___151 *);
	void (*release)(struct kernfs_open_file___151 *);
	u64 (*read_u64)(struct cgroup_subsys_state___131 *, struct cftype___131 *);
	s64 (*read_s64)(struct cgroup_subsys_state___131 *, struct cftype___131 *);
	int (*seq_show)(struct seq_file___145 *, void *);
	void * (*seq_start)(struct seq_file___145 *, loff_t *);
	void * (*seq_next)(struct seq_file___145 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___145 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___131 *, struct cftype___131 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___131 *, struct cftype___131 *, s64);
	ssize_t (*write)(struct kernfs_open_file___151 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___151 *, struct poll_table_struct___105 *);
};

struct bdi_writeback_congested___74 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___74 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___74 {
	struct bio___74 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___74 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___74 bip_inline_vecs[0];
};

struct bio_set___74 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___74 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___69 {
	struct mem_cgroup___69 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___69 {
	struct lruvec___154 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___69 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___69 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct bin_attribute___144;

struct attribute_group___145 {
	const char *name;
	umode_t (*is_visible)(struct kobject___149 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___149 *, struct bin_attribute___144 *, int);
	struct attribute **attrs;
	struct bin_attribute___144 **bin_attrs;
};

struct bin_attribute___144 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___155 *, struct kobject___149 *, struct bin_attribute___144 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___155 *, struct kobject___149 *, struct bin_attribute___144 *, char *, loff_t, size_t);
	int (*mmap)(struct file___155 *, struct kobject___149 *, struct bin_attribute___144 *, struct vm_area_struct___155 *);
};

struct sysfs_ops___148 {
	ssize_t (*show)(struct kobject___149 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___149 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___148;

struct kset___148 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___149 kobj;
	const struct kset_uevent_ops___148 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___148 {
	void (*release)(struct kobject___149 *);
	const struct sysfs_ops___148 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___2 * (*child_ns_type)(struct kobject___149 *);
	const void * (*namespace)(struct kobject___149 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___148 {
	int (* const filter)(struct kset___148 *, struct kobject___149 *);
	const char * (* const name)(struct kset___148 *, struct kobject___149 *);
	int (* const uevent)(struct kset___148 *, struct kobject___149 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___145 {
	int (*prepare)(struct device___145 *);
	void (*complete)(struct device___145 *);
	int (*suspend)(struct device___145 *);
	int (*resume)(struct device___145 *);
	int (*freeze)(struct device___145 *);
	int (*thaw)(struct device___145 *);
	int (*poweroff)(struct device___145 *);
	int (*restore)(struct device___145 *);
	int (*suspend_late)(struct device___145 *);
	int (*resume_early)(struct device___145 *);
	int (*freeze_late)(struct device___145 *);
	int (*thaw_early)(struct device___145 *);
	int (*poweroff_late)(struct device___145 *);
	int (*restore_early)(struct device___145 *);
	int (*suspend_noirq)(struct device___145 *);
	int (*resume_noirq)(struct device___145 *);
	int (*freeze_noirq)(struct device___145 *);
	int (*thaw_noirq)(struct device___145 *);
	int (*poweroff_noirq)(struct device___145 *);
	int (*restore_noirq)(struct device___145 *);
	int (*runtime_suspend)(struct device___145 *);
	int (*runtime_resume)(struct device___145 *);
	int (*runtime_idle)(struct device___145 *);
};

struct dev_pm_domain___145 {
	struct dev_pm_ops___145 ops;
	void (*detach)(struct device___145 *, bool);
	int (*activate)(struct device___145 *);
	void (*sync)(struct device___145 *);
	void (*dismiss)(struct device___145 *);
};

struct bus_type___145 {
	const char *name;
	const char *dev_name;
	struct device___145 *dev_root;
	const struct attribute_group___145 **bus_groups;
	const struct attribute_group___145 **dev_groups;
	const struct attribute_group___145 **drv_groups;
	int (*match)(struct device___145 *, struct device_driver___145 *);
	int (*uevent)(struct device___145 *, struct kobj_uevent_env *);
	int (*probe)(struct device___145 *);
	int (*remove)(struct device___145 *);
	void (*shutdown)(struct device___145 *);
	int (*online)(struct device___145 *);
	int (*offline)(struct device___145 *);
	int (*suspend)(struct device___145 *, pm_message_t);
	int (*resume)(struct device___145 *);
	int (*num_vf)(struct device___145 *);
	int (*dma_configure)(struct device___145 *);
	const struct dev_pm_ops___145 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___145 {
	const char *name;
	struct bus_type___145 *bus;
	struct module___132 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___145 *);
	int (*remove)(struct device___145 *);
	void (*shutdown)(struct device___145 *);
	int (*suspend)(struct device___145 *, pm_message_t);
	int (*resume)(struct device___145 *);
	const struct attribute_group___145 **groups;
	const struct dev_pm_ops___145 *pm;
	void (*coredump)(struct device___145 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___145 {
	const char *name;
	const struct attribute_group___145 **groups;
	int (*uevent)(struct device___145 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___145 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___145 *);
	const struct dev_pm_ops___145 *pm;
};

struct class___145 {
	const char *name;
	struct module___132 *owner;
	const struct attribute_group___145 **class_groups;
	const struct attribute_group___145 **dev_groups;
	struct kobject___149 *dev_kobj;
	int (*dev_uevent)(struct device___145 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___145 *, umode_t *);
	void (*class_release)(struct class___145 *);
	void (*dev_release)(struct device___145 *);
	int (*shutdown_pre)(struct device___145 *);
	const struct kobj_ns_type_operations___2 *ns_type;
	const void * (*namespace)(struct device___145 *);
	const struct dev_pm_ops___145 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___123 {
	struct device___145 dev;
};

enum scan_result {
	SCAN_FAIL = 0,
	SCAN_SUCCEED = 1,
	SCAN_PMD_NULL = 2,
	SCAN_EXCEED_NONE_PTE = 3,
	SCAN_PTE_NON_PRESENT = 4,
	SCAN_PAGE_RO = 5,
	SCAN_LACK_REFERENCED_PAGE = 6,
	SCAN_PAGE_NULL = 7,
	SCAN_SCAN_ABORT = 8,
	SCAN_PAGE_COUNT = 9,
	SCAN_PAGE_LRU = 10,
	SCAN_PAGE_LOCK = 11,
	SCAN_PAGE_ANON = 12,
	SCAN_PAGE_COMPOUND = 13,
	SCAN_ANY_PROCESS = 14,
	SCAN_VMA_NULL = 15,
	SCAN_VMA_CHECK = 16,
	SCAN_ADDRESS_RANGE = 17,
	SCAN_SWAP_CACHE_PAGE = 18,
	SCAN_DEL_PAGE_LRU = 19,
	SCAN_ALLOC_HUGE_PAGE_FAIL = 20,
	SCAN_CGROUP_CHARGE_FAIL = 21,
	SCAN_EXCEED_SWAP_PTE = 22,
	SCAN_TRUNCATED = 23,
};

struct kernel_param_ops___129 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___129 *);
	int (*get)(char *, const struct kernel_param___129 *);
	void (*free)(void *);
};

struct kparam_array___129;

struct kernel_param___129 {
	const char *name;
	struct module___132 *mod;
	const struct kernel_param_ops___129 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___129 *arr;
	};
};

struct kparam_array___129 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___129 *ops;
	void *elem;
};

struct module_attribute___129 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___129 *, struct module_kobject___129 *, char *);
	ssize_t (*store)(struct module_attribute___129 *, struct module_kobject___129 *, const char *, size_t);
	void (*setup)(struct module___132 *, const char *);
	int (*test)(struct module___132 *);
	void (*free)(struct module___132 *);
};

struct trace_event_class___89;

struct trace_event_call___89 {
	struct list_head list;
	struct trace_event_class___89 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___4 *prog_array;
	int (*perf_perm)(struct trace_event_call___89 *, struct perf_event___96 *);
};

struct perf_cpu_context___96;

struct pmu___96 {
	struct list_head entry;
	struct module___132 *module;
	struct device___145 *dev;
	const struct attribute_group___145 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___96 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___96 *);
	void (*pmu_disable)(struct pmu___96 *);
	int (*event_init)(struct perf_event___96 *);
	void (*event_mapped)(struct perf_event___96 *, struct mm_struct___154 *);
	void (*event_unmapped)(struct perf_event___96 *, struct mm_struct___154 *);
	int (*add)(struct perf_event___96 *, int);
	void (*del)(struct perf_event___96 *, int);
	void (*start)(struct perf_event___96 *, int);
	void (*stop)(struct perf_event___96 *, int);
	void (*read)(struct perf_event___96 *);
	void (*start_txn)(struct pmu___96 *, unsigned int);
	int (*commit_txn)(struct pmu___96 *);
	void (*cancel_txn)(struct pmu___96 *);
	int (*event_idx)(struct perf_event___96 *);
	void (*sched_task)(struct perf_event_context___96 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___96 *);
	int (*filter_match)(struct perf_event___96 *);
	int (*check_period)(struct perf_event___96 *, u64);
};

struct perf_cpu_context___96 {
	struct perf_event_context___96 ctx;
	struct perf_event_context___96 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___96 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___96 {
	struct cgroup_subsys_state___131 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___89 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___89 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___89 *);
	struct list_head * (*get_fields)(struct trace_event_call___89 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___89 *);
};

struct trace_event_file___41;

struct trace_event_buffer___33 {
	struct ring_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___41 *trace_file;
	void *entry;
	long unsigned int flags;
	int pc;
};

struct trace_event_file___41 {
	struct list_head list;
	struct trace_event_call___89 *event_call;
	struct event_filter *filter;
	struct dentry___154 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_mm_khugepaged_scan_pmd {
	struct trace_entry ent;
	struct mm_struct___154 *mm;
	long unsigned int pfn;
	bool writable;
	int referenced;
	int none_or_zero;
	int status;
	int unmapped;
	char __data[0];
};

struct trace_event_raw_mm_collapse_huge_page {
	struct trace_entry ent;
	struct mm_struct___154 *mm;
	int isolated;
	int status;
	char __data[0];
};

struct trace_event_raw_mm_collapse_huge_page_isolate {
	struct trace_entry ent;
	long unsigned int pfn;
	int none_or_zero;
	int referenced;
	bool writable;
	int status;
	char __data[0];
};

struct trace_event_raw_mm_collapse_huge_page_swapin {
	struct trace_entry ent;
	struct mm_struct___154 *mm;
	int swapped_in;
	int referenced;
	int ret;
	char __data[0];
};

struct trace_event_data_offsets_mm_khugepaged_scan_pmd {};

struct trace_event_data_offsets_mm_collapse_huge_page {};

struct trace_event_data_offsets_mm_collapse_huge_page_isolate {};

struct trace_event_data_offsets_mm_collapse_huge_page_swapin {};

struct mm_slot___2 {
	struct hlist_node hash;
	struct list_head mm_node;
	struct mm_struct___154 *mm;
};

struct khugepaged_scan {
	struct list_head mm_head;
	struct mm_slot___2 *mm_slot;
	long unsigned int address;
};

typedef __kernel_ulong_t __kernel_ino_t;

typedef __kernel_ino_t ino_t;

struct module___133;

struct file___156;

struct kiocb___156;

struct iov_iter___72;

struct poll_table_struct___106;

struct vm_area_struct___156;

struct inode___156;

struct file_lock___156;

struct page___156;

struct pipe_inode_info___35;

struct seq_file___146;

struct file_operations___156 {
	struct module___133 *owner;
	loff_t (*llseek)(struct file___156 *, loff_t, int);
	ssize_t (*read)(struct file___156 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___156 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___156 *, struct iov_iter___72 *);
	ssize_t (*write_iter)(struct kiocb___156 *, struct iov_iter___72 *);
	int (*iopoll)(struct kiocb___156 *, bool);
	int (*iterate)(struct file___156 *, struct dir_context *);
	int (*iterate_shared)(struct file___156 *, struct dir_context *);
	__poll_t (*poll)(struct file___156 *, struct poll_table_struct___106 *);
	long int (*unlocked_ioctl)(struct file___156 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___156 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___156 *, struct vm_area_struct___156 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___156 *, struct file___156 *);
	int (*flush)(struct file___156 *, fl_owner_t);
	int (*release)(struct inode___156 *, struct file___156 *);
	int (*fsync)(struct file___156 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___156 *, int);
	int (*lock)(struct file___156 *, int, struct file_lock___156 *);
	ssize_t (*sendpage)(struct file___156 *, struct page___156 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___156 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___156 *, int, struct file_lock___156 *);
	ssize_t (*splice_write)(struct pipe_inode_info___35 *, struct file___156 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___156 *, loff_t *, struct pipe_inode_info___35 *, size_t, unsigned int);
	int (*setlease)(struct file___156 *, long int, struct file_lock___156 **, void **);
	long int (*fallocate)(struct file___156 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___146 *, struct file___156 *);
	ssize_t (*copy_file_range)(struct file___156 *, loff_t, struct file___156 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___156 *, loff_t, struct file___156 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___156 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___156 *pgtable_t___155;

struct address_space___155;

struct kmem_cache___6;

struct mm_struct___155;

struct dev_pagemap___153;

struct mem_cgroup___70;

struct page___156 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___155 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___156 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache___6 *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___155 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___155 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___153 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___70 *mem_cgroup;
};

struct vmacache___155 {
	u64 seqnum;
	struct vm_area_struct___156 *vmas[4];
};

struct page_frag___155 {
	struct page___156 *page;
	__u32 offset;
	__u32 size;
};

struct pid___124;

struct cred___151;

struct nsproxy___148;

struct signal_struct___139;

struct bio_list___75;

struct backing_dev_info___75;

struct io_context___37;

struct css_set___132;

struct request_queue___34;

struct vm_struct___116;

struct task_struct___156 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___156 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___155 *mm;
	struct mm_struct___155 *active_mm;
	struct vmacache___155 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___156 *real_parent;
	struct task_struct___156 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___156 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___70 *active_memcg;
	long int rh_reserved2;
	struct pid___124 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___124 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___124 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___151 *ptracer_cred;
	const struct cred___151 *real_cred;
	const struct cred___151 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___148 *nsproxy;
	struct signal_struct___139 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___156 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___75 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___75 *backing_dev_info;
	struct io_context___37 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___132 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___35 *splice_pipe;
	struct page_frag___155 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___70 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___34 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___156 *oom_reaper_list;
	struct vm_struct___116 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___96 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___124;

struct upid___124 {
	int nr;
	struct pid_namespace___124 *ns;
};

struct dentry___155;

struct user_namespace___136;

struct ucounts___136;

struct pid_namespace___124 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___156 *child_reaper;
	struct kmem_cache___6 *pid_cachep;
	unsigned int level;
	struct pid_namespace___124 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___155 *proc_self;
	struct dentry___155 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___136 *user_ns;
	struct ucounts___136 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___4 ns;
};

struct pid___124 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___124 numbers[1];
};

struct rw_semaphore___156 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___156 *owner;
};

struct key___151;

struct user_namespace___136 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___136 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___4 ns;
	long unsigned int flags;
	struct key___151 *persistent_keyring_register;
	struct rw_semaphore___156 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___136 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct secondary_data___156 {
	void *stack;
	struct task_struct___156 *task;
	long int status;
};

struct user_struct___151 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___151 *uid_keyring;
	struct key___151 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___153;

struct vm_area_struct___156 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___156 *vm_next;
	struct vm_area_struct___156 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___155 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___153 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___156 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___155;

struct mm_struct___155 {
	struct {
		struct vm_area_struct___156 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___156 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___156 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___155 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___156 *owner;
		struct user_namespace___136 *user_ns;
		struct file___156 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___155 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup___132;

struct cgroup_subsys___132;

struct cgroup_subsys_state___132 {
	struct cgroup___132 *cgroup;
	struct cgroup_subsys___132 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___132 *parent;
};

struct kernfs_node___152;

struct cgroup_file___132 {
	struct kernfs_node___152 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___70;

struct mem_cgroup___70 {
	struct cgroup_subsys_state___132 css;
	struct mem_cgroup_id___6 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___132 events_file;
	struct cgroup_file___132 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___156 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___70 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cred___151 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___151 *session_keyring;
	struct key___151 *process_keyring;
	struct key___151 *thread_keyring;
	struct key___151 *request_key_auth;
	void *security;
	struct user_struct___151 *user;
	struct user_namespace___136 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___30;

struct cgroup_namespace___132;

struct nsproxy___148 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___124 *pid_ns_for_children;
	struct net___30 *net_ns;
	struct cgroup_namespace___132 *cgroup_ns;
};

struct signal_struct___139 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___156 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___156 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___124 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___124 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___155 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___124 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide41;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___75;

struct bio_list___75 {
	struct bio___75 *head;
	struct bio___75 *tail;
};

struct bdi_writeback_congested___75;

struct bdi_writeback___75 {
	struct backing_dev_info___75 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___75 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___132 *memcg_css;
	struct cgroup_subsys_state___132 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___146;

struct backing_dev_info___75 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___75 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___146 *dev;
	struct device___146 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___155 *debug_dir;
	struct dentry___155 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___37;

struct io_context___37 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___37 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___132 {
	struct cgroup_subsys_state___132 *subsys[13];
	refcount_t refcount;
	struct css_set___132 *dom_cset;
	struct cgroup___132 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___132 *mg_src_cgrp;
	struct cgroup___132 *mg_dst_cgrp;
	struct css_set___132 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___155;

struct pipe_buffer___35;

struct pipe_inode_info___35 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___156 *tmp_page;
	struct fasync_struct___155 *fasync_readers;
	struct fasync_struct___155 *fasync_writers;
	struct pipe_buffer___35 *bufs;
	struct user_struct___151 *user;
};

typedef blk_qc_t make_request_fn___33(struct request_queue___34 *, struct bio___75 *);

struct request___34;

typedef int dma_drain_needed_fn___33(struct request___34 *);

struct kset___149;

struct kobj_type___149;

struct kobject___150 {
	const char *name;
	struct list_head entry;
	struct kobject___150 *parent;
	struct kset___149 *kset;
	struct kobj_type___149 *ktype;
	struct kernfs_node___152 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___33;

struct bsg_class_device___33 {
	struct device___146 *class_dev;
	int minor;
	struct request_queue___34 *queue;
	const struct bsg_ops___33 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___75 {
	struct kmem_cache___6 *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___75 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___33;

struct blkcg_gq___24;

struct request_queue___34 {
	struct list_head queue_head;
	struct request___34 *last_merge;
	struct elevator_queue___33 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___33 *make_request_fn;
	dma_drain_needed_fn___33 *dma_drain_needed;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___75 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___150 kobj;
	struct kobject___150 *mq_kobj;
	struct blk_integrity integrity;
	struct device___146 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___24 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	struct bsg_class_device___33 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___75 bio_split;
	struct dentry___155 *debugfs_dir;
	struct dentry___155 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___116 {
	struct vm_struct___116 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___156 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___140 {
	struct task_struct___156 task;
	long unsigned int stack[8192];
};

struct dentry_operations___155;

struct super_block___155;

struct dentry___155 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___155 *d_parent;
	struct qstr d_name;
	struct inode___156 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___155 *d_op;
	struct super_block___155 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___155;

struct address_space___155 {
	struct inode___156 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___156 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___155 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___155;

struct block_device___156;

struct inode___156 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___155 *i_op;
	struct super_block___155 *i_sb;
	struct address_space___155 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___156 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___75 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___156 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___155 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___35 *i_pipe;
		struct block_device___156 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___155;

struct dentry_operations___155 {
	int (*d_revalidate)(struct dentry___155 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___155 *, unsigned int);
	int (*d_hash)(const struct dentry___155 *, struct qstr *);
	int (*d_compare)(const struct dentry___155 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___155 *);
	int (*d_init)(struct dentry___155 *);
	void (*d_release)(struct dentry___155 *);
	void (*d_prune)(struct dentry___155 *);
	void (*d_iput)(struct dentry___155 *, struct inode___156 *);
	char * (*d_dname)(struct dentry___155 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___155 *);
	int (*d_manage)(const struct path___155 *, bool);
	struct dentry___155 * (*d_real)(struct dentry___155 *, const struct inode___156 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___155;

struct mem_dqinfo___155 {
	struct quota_format_type___155 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___155;

struct quota_info___155 {
	unsigned int flags;
	struct rw_semaphore___156 dqio_sem;
	struct inode___156 *files[3];
	struct mem_dqinfo___155 info[3];
	const struct quota_format_ops___155 *ops[3];
};

struct rcuwait___155 {
	struct task_struct___156 *task;
};

struct percpu_rw_semaphore___155 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___156 rw_sem;
	struct rcuwait___155 writer;
	int readers_block;
};

struct sb_writers___155 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___155 rw_sem[3];
};

struct shrink_control___70;

struct shrinker___70 {
	long unsigned int (*count_objects)(struct shrinker___70 *, struct shrink_control___70 *);
	long unsigned int (*scan_objects)(struct shrinker___70 *, struct shrink_control___70 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___155;

struct super_operations___155;

struct dquot_operations___155;

struct quotactl_ops___155;

struct xattr_handler___14;

struct super_block___155 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___155 *s_type;
	const struct super_operations___155 *s_op;
	const struct dquot_operations___155 *dq_op;
	const struct quotactl_ops___155 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___155 *s_root;
	struct rw_semaphore___156 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___14 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___156 *s_bdev;
	struct backing_dev_info___75 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___155 s_dquot;
	struct sb_writers___155 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___155 *s_d_op;
	int cleancache_poolid;
	struct shrinker___70 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___136 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct path___155 {
	struct vfsmount *mnt;
	struct dentry___155 *dentry;
};

struct shrink_control___70 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___70 *memcg;
};

struct pglist_data___155;

struct lruvec___155 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___155 *pgdat;
};

struct zone___155 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___155 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___155 {
	struct zone___155 *zone;
	int zone_idx;
};

struct zonelist___155 {
	struct zoneref___155 _zonerefs[25];
};

struct pglist_data___155 {
	struct zone___155 node_zones[3];
	struct zonelist___155 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___156 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___156 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___155 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

typedef struct pglist_data___155 pg_data_t___14;

struct blocking_notifier_head___155 {
	struct rw_semaphore___156 rwsem;
	struct notifier_block *head;
};

struct memcg_cache_array___6;

struct memcg_cache_params___6 {
	struct kmem_cache___6 *root_cache;
	union {
		struct {
			struct memcg_cache_array___6 *memcg_caches;
			struct list_head __root_caches_node;
			struct list_head children;
			bool dying;
		};
		struct {
			struct mem_cgroup___70 *memcg;
			struct list_head children_node;
			struct list_head kmem_caches_node;
			struct percpu_ref refcnt;
			void (*work_fn)(struct kmem_cache___6 *);
			union {
				struct callback_head callback_head;
				struct work_struct work;
			};
		};
	};
};

struct kmem_cache_cpu___6;

struct kmem_cache___6 {
	struct kmem_cache_cpu___6 *cpu_slab;
	slab_flags_t flags;
	long unsigned int min_partial;
	unsigned int size;
	unsigned int object_size;
	unsigned int offset;
	unsigned int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	unsigned int inuse;
	unsigned int align;
	unsigned int red_left_pad;
	const char *name;
	struct list_head list;
	struct kobject___150 kobj;
	struct work_struct kobj_remove_work;
	struct memcg_cache_params___6 memcg_params;
	unsigned int max_attr_size;
	struct kset___149 *memcg_kset;
	unsigned int remote_node_defrag_ratio;
	unsigned int *random_seq;
	unsigned int useroffset;
	unsigned int usersize;
	struct kmem_cache_node *node[8];
};

typedef int (*dev_page_fault_t___153)(struct vm_area_struct___156 *, long unsigned int, const struct page___156 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___153)(struct page___156 *, void *);

struct dev_pagemap___153 {
	dev_page_fault_t___153 page_fault;
	dev_page_free_t___153 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___146 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct fown_struct___124 {
	rwlock_t lock;
	struct pid___124 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___156 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___155 f_path;
	struct inode___156 *f_inode;
	const struct file_operations___156 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___124 f_owner;
	const struct cred___151 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___155 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___153;

struct vm_operations_struct___153 {
	void (*open)(struct vm_area_struct___156 *);
	void (*close)(struct vm_area_struct___156 *);
	int (*split)(struct vm_area_struct___156 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___156 *);
	vm_fault_t (*fault)(struct vm_fault___153 *);
	vm_fault_t (*huge_fault)(struct vm_fault___153 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___153 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___156 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___153 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___153 *);
	int (*access)(struct vm_area_struct___156 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___156 *);
	int (*set_policy)(struct vm_area_struct___156 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___156 *, long unsigned int);
	struct page___156 * (*find_special_page)(struct vm_area_struct___156 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___155 {
	struct task_struct___156 *task;
	struct core_thread___155 *next;
};

struct core_state___155 {
	atomic_t nr_threads;
	struct core_thread___155 dumper;
	struct completion startup;
};

struct vm_fault___153 {
	struct vm_area_struct___156 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___156 *cow_page;
	struct mem_cgroup___70 *memcg;
	struct page___156 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___155 prealloc_pte;
};

struct io_cq___37 {
	struct request_queue___34 *q;
	struct io_context___37 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___6 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___156 {
	struct file___156 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___156 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___155 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___156 *ia_file;
};

struct dquot___155 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___155 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___155 {
	int qf_fmt_id;
	const struct quota_format_ops___155 *qf_ops;
	struct module___133 *qf_owner;
	struct quota_format_type___155 *qf_next;
};

struct quota_format_ops___155 {
	int (*check_quota_file)(struct super_block___155 *, int);
	int (*read_file_info)(struct super_block___155 *, int);
	int (*write_file_info)(struct super_block___155 *, int);
	int (*free_file_info)(struct super_block___155 *, int);
	int (*read_dqblk)(struct dquot___155 *);
	int (*commit_dqblk)(struct dquot___155 *);
	int (*release_dqblk)(struct dquot___155 *);
	int (*get_next_id)(struct super_block___155 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___155 {
	int (*write_dquot)(struct dquot___155 *);
	struct dquot___155 * (*alloc_dquot)(struct super_block___155 *, int);
	void (*destroy_dquot)(struct dquot___155 *);
	int (*acquire_dquot)(struct dquot___155 *);
	int (*release_dquot)(struct dquot___155 *);
	int (*mark_dirty)(struct dquot___155 *);
	int (*write_info)(struct super_block___155 *, int);
	qsize_t * (*get_reserved_space)(struct inode___156 *);
	int (*get_projid)(struct inode___156 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___156 *, qsize_t *);
	int (*get_next_id)(struct super_block___155 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___155 {
	int (*quota_on)(struct super_block___155 *, int, int, const struct path___155 *);
	int (*quota_off)(struct super_block___155 *, int);
	int (*quota_enable)(struct super_block___155 *, unsigned int);
	int (*quota_disable)(struct super_block___155 *, unsigned int);
	int (*quota_sync)(struct super_block___155 *, int);
	int (*set_info)(struct super_block___155 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___155 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___155 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___155 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___155 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___155 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___130 {
	struct kobject___150 kobj;
	struct module___133 *mod;
	struct kobject___150 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___130 {
	struct module___133 *mod;
	struct latch_tree_node node;
};

struct module_layout___130 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___130 mtn;
};

struct module_attribute___130;

struct kernel_param___130;

struct module___133 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___130 mkobj;
	struct module_attribute___130 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___150 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___130 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___130 core_layout;
	struct module_layout___130 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide67;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide68;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___72;

struct swap_info_struct___52;

struct address_space_operations___155 {
	int (*writepage)(struct page___156 *, struct writeback_control___72 *);
	int (*readpage)(struct file___156 *, struct page___156 *);
	int (*writepages)(struct address_space___155 *, struct writeback_control___72 *);
	int (*set_page_dirty)(struct page___156 *);
	int (*readpages)(struct file___156 *, struct address_space___155 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___156 *, struct address_space___155 *, loff_t, unsigned int, unsigned int, struct page___156 **, void **);
	int (*write_end)(struct file___156 *, struct address_space___155 *, loff_t, unsigned int, unsigned int, struct page___156 *, void *);
	sector_t (*bmap)(struct address_space___155 *, sector_t);
	void (*invalidatepage)(struct page___156 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___156 *, gfp_t);
	void (*freepage)(struct page___156 *);
	ssize_t (*direct_IO)(struct kiocb___156 *, struct iov_iter___72 *);
	int (*migratepage)(struct address_space___155 *, struct page___156 *, struct page___156 *, enum migrate_mode);
	bool (*isolate_page)(struct page___156 *, isolate_mode_t);
	void (*putback_page)(struct page___156 *);
	int (*launder_page)(struct page___156 *);
	int (*is_partially_uptodate)(struct page___156 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___156 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___155 *, struct page___156 *);
	int (*swap_activate)(struct swap_info_struct___52 *, struct file___156 *, sector_t *);
	void (*swap_deactivate)(struct file___156 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___72 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___75 *wb;
	struct inode___156 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___75;

struct iov_iter___72 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___75 *bvec;
		struct pipe_inode_info___35 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct swap_info_struct___52 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___156 *bdev;
	struct file___156 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct hd_struct___34;

struct gendisk___34;

struct block_device___156 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___156 *bd_inode;
	struct super_block___155 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___156 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___34 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___34 *bd_disk;
	struct request_queue___34 *bd_queue;
	struct backing_dev_info___75 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___146 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___146 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___146;

struct bus_type___146;

struct device_driver___146;

struct dev_pm_domain___146;

struct dma_map_ops___37;

struct fwnode_handle___105;

struct class___146;

struct attribute_group___146;

struct device___146 {
	struct device___146 *parent;
	struct device_private *p;
	struct kobject___150 kobj;
	const char *init_name;
	const struct device_type___146 *type;
	struct mutex mutex;
	struct bus_type___146 *bus;
	struct device_driver___146 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___146 power;
	struct dev_pm_domain___146 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___37 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___105 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___146 *class;
	const struct attribute_group___146 **groups;
	void (*release)(struct device___146 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___34 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___146 __dev;
	struct kobject___150 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___34;

struct block_device_operations___34;

struct gendisk___34 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___34 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___34 *part_tbl;
	struct hd_struct___34 part0;
	const struct block_device_operations___34 *fops;
	struct request_queue___34 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___156 lookup_sem;
	struct kobject___150 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___150 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___155 {
	struct dentry___155 * (*lookup)(struct inode___156 *, struct dentry___155 *, unsigned int);
	const char * (*get_link)(struct dentry___155 *, struct inode___156 *, struct delayed_call *);
	int (*permission)(struct inode___156 *, int);
	struct posix_acl * (*get_acl)(struct inode___156 *, int);
	int (*readlink)(struct dentry___155 *, char *, int);
	int (*create)(struct inode___156 *, struct dentry___155 *, umode_t, bool);
	int (*link)(struct dentry___155 *, struct inode___156 *, struct dentry___155 *);
	int (*unlink)(struct inode___156 *, struct dentry___155 *);
	int (*symlink)(struct inode___156 *, struct dentry___155 *, const char *);
	int (*mkdir)(struct inode___156 *, struct dentry___155 *, umode_t);
	int (*rmdir)(struct inode___156 *, struct dentry___155 *);
	int (*mknod)(struct inode___156 *, struct dentry___155 *, umode_t, dev_t);
	int (*rename)(struct inode___156 *, struct dentry___155 *, struct inode___156 *, struct dentry___155 *, unsigned int);
	int (*setattr)(struct dentry___155 *, struct iattr___155 *);
	int (*getattr)(const struct path___155 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___155 *, char *, size_t);
	int (*fiemap)(struct inode___156 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___156 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___156 *, struct dentry___155 *, struct file___156 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___156 *, struct dentry___155 *, umode_t);
	int (*set_acl)(struct inode___156 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___155 {
	void (*fl_copy_lock)(struct file_lock___156 *, struct file_lock___156 *);
	void (*fl_release_private)(struct file_lock___156 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___155;

struct file_lock___156 {
	struct file_lock___156 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___156 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___155 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___155 *fl_ops;
	const struct lock_manager_operations___155 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___155 {
	int (*lm_compare_owner)(struct file_lock___156 *, struct file_lock___156 *);
	long unsigned int (*lm_owner_key)(struct file_lock___156 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___156 *);
	int (*lm_grant)(struct file_lock___156 *, int);
	bool (*lm_break)(struct file_lock___156 *);
	int (*lm_change)(struct file_lock___156 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___156 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___155 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___155 *fa_next;
	struct file___156 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___155 {
	const char *name;
	int fs_flags;
	struct dentry___155 * (*mount)(struct file_system_type___155 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___155 *);
	struct module___133 *owner;
	struct file_system_type___155 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___155 {
	struct inode___156 * (*alloc_inode)(struct super_block___155 *);
	void (*destroy_inode)(struct inode___156 *);
	void (*dirty_inode)(struct inode___156 *, int);
	int (*write_inode)(struct inode___156 *, struct writeback_control___72 *);
	int (*drop_inode)(struct inode___156 *);
	void (*evict_inode)(struct inode___156 *);
	void (*put_super)(struct super_block___155 *);
	int (*sync_fs)(struct super_block___155 *, int);
	int (*freeze_super)(struct super_block___155 *);
	int (*freeze_fs)(struct super_block___155 *);
	int (*thaw_super)(struct super_block___155 *);
	int (*unfreeze_fs)(struct super_block___155 *);
	int (*statfs)(struct dentry___155 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___155 *, int *, char *);
	void (*umount_begin)(struct super_block___155 *);
	int (*show_options)(struct seq_file___146 *, struct dentry___155 *);
	int (*show_devname)(struct seq_file___146 *, struct dentry___155 *);
	int (*show_path)(struct seq_file___146 *, struct dentry___155 *);
	int (*show_stats)(struct seq_file___146 *, struct dentry___155 *);
	ssize_t (*quota_read)(struct super_block___155 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___155 *, int, const char *, size_t, loff_t);
	struct dquot___155 ** (*get_dquots)(struct inode___156 *);
	int (*bdev_try_to_free_page)(struct super_block___155 *, struct page___156 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___155 *, struct shrink_control___70 *);
	long int (*free_cached_objects)(struct super_block___155 *, struct shrink_control___70 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct xattr_handler___14 {
	const char *name;
	const char *prefix;
	int flags;
	bool (*list)(struct dentry___155 *);
	int (*get)(const struct xattr_handler___14 *, struct dentry___155 *, struct inode___156 *, const char *, void *, size_t);
	int (*set)(const struct xattr_handler___14 *, struct dentry___155 *, struct inode___156 *, const char *, const void *, size_t, int);
};

typedef void (*poll_queue_proc___105)(struct file___156 *, wait_queue_head_t *, struct poll_table_struct___106 *);

struct poll_table_struct___106 {
	poll_queue_proc___105 _qproc;
	__poll_t _key;
};

struct seq_operations___144;

struct seq_file___146 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___144 *op;
	int poll_event;
	const struct file___156 *file;
	void *private;
};

typedef void bio_end_io_t___75(struct bio___75 *);

struct bio_vec___75 {
	struct page___156 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___75;

struct bio___75 {
	struct bio___75 *bi_next;
	struct gendisk___34 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___75 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___24 *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___75 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___75 *bi_io_vec;
	struct bio_set___75 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___75 bi_inline_vecs[0];
};

typedef int (*key_restrict_link_func_t___151)(struct key___151 *, const struct key_type *, const union key_payload *, struct key___151 *);

struct key_restriction___151;

struct key___151 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___156 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___151 *restrict_link;
};

struct key_restriction___151 {
	key_restrict_link_func_t___151 check;
	struct key___151 *key;
	struct key_type *keytype;
};

struct seq_operations___144 {
	void * (*start)(struct seq_file___146 *, loff_t *);
	void (*stop)(struct seq_file___146 *, void *);
	void * (*next)(struct seq_file___146 *, void *, loff_t *);
	int (*show)(struct seq_file___146 *, void *);
};

struct kernfs_root___152;

struct kernfs_elem_dir___152 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___152 *root;
};

struct kernfs_syscall_ops___152;

struct kernfs_root___152 {
	struct kernfs_node___152 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___152 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___152 {
	struct kernfs_node___152 *target_kn;
};

struct kernfs_ops___152;

struct kernfs_elem_attr___152 {
	const struct kernfs_ops___152 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___152 *notify_next;
};

struct kernfs_node___152 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___152 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___152 dir;
		struct kernfs_elem_symlink___152 symlink;
		struct kernfs_elem_attr___152 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___152;

struct kernfs_ops___152 {
	int (*open)(struct kernfs_open_file___152 *);
	void (*release)(struct kernfs_open_file___152 *);
	int (*seq_show)(struct seq_file___146 *, void *);
	void * (*seq_start)(struct seq_file___146 *, loff_t *);
	void * (*seq_next)(struct seq_file___146 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___146 *, void *);
	ssize_t (*read)(struct kernfs_open_file___152 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___152 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___152 *, struct vm_area_struct___156 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___152 *, struct poll_table_struct___106 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___152 {
	int (*remount_fs)(struct kernfs_root___152 *, int *, char *);
	int (*show_options)(struct seq_file___146 *, struct kernfs_root___152 *);
	int (*mkdir)(struct kernfs_node___152 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___152 *);
	int (*rename)(struct kernfs_node___152 *, struct kernfs_node___152 *, const char *);
	int (*show_path)(struct seq_file___146 *, struct kernfs_node___152 *, struct kernfs_root___152 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___152 {
	struct kernfs_node___152 *kn;
	struct file___156 *file;
	struct seq_file___146 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___153 *vm_ops;
};

struct inet_frags___21;

struct netns_frags___21 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___21 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_rules_ops___10;

struct sock___12;

struct fib_notifier_ops___10;

struct netns_ipv4___21 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___10 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___12 *fibnl;
	struct sock___12 **icmp_sk;
	struct sock___12 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___12 **tcp_sk;
	struct netns_frags___21 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___10 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___10 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___10 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct dst_entry___11;

struct net_device___25;

struct sk_buff___24;

struct neighbour___11;

struct dst_ops___28 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___28 *);
	struct dst_entry___11 * (*check)(struct dst_entry___11 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___11 *);
	unsigned int (*mtu)(const struct dst_entry___11 *);
	u32 * (*cow_metrics)(struct dst_entry___11 *, long unsigned int);
	void (*destroy)(struct dst_entry___11 *);
	void (*ifdown)(struct dst_entry___11 *, struct net_device___25 *, int);
	struct dst_entry___11 * (*negative_advice)(struct dst_entry___11 *);
	void (*link_failure)(struct sk_buff___24 *);
	void (*update_pmtu)(struct dst_entry___11 *, struct sock___12 *, struct sk_buff___24 *, u32);
	void (*redirect)(struct dst_entry___11 *, struct sock___12 *, struct sk_buff___24 *);
	int (*local_out)(struct net___30 *, struct sock___12 *, struct sk_buff___24 *);
	struct neighbour___11 * (*neigh_lookup)(const struct dst_entry___11 *, struct sk_buff___24 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___11 *, const void *);
	struct kmem_cache___6 *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___28 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___21 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___28 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___10 *fib6_rules_ops;
	struct sock___12 **icmp_sk;
	struct sock___12 *ndisc_sk;
	struct sock___12 *tcp_sk;
	struct sock___12 *igmp_sk;
	struct sock___12 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___10 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___10 *notifier_ops;
	struct fib_notifier_ops___10 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___10 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___12 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___21 {
	struct netns_frags___21 frags;
};

struct netns_xfrm___28 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___12 *nlsk;
	struct sock___12 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___28 xfrm4_dst_ops;
	struct dst_ops___28 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___20;

struct net___30 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___136 *user_ns;
	struct ucounts___136 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___4 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___12 *rtnl;
	struct sock___12 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___25 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___21 ipv4;
	struct netns_ipv6___28 ipv6;
	struct netns_sctp___10 sctp;
	struct netns_nf nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___21 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___12 *nfnl;
	struct sock___12 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___28 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___12 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___20 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cgroup_namespace___132 {
	refcount_t count;
	struct ns_common___4 ns;
	struct user_namespace___136 *user_ns;
	struct ucounts___136 *ucounts;
	struct css_set___132 *root_cset;
};

struct ucounts___136 {
	struct hlist_node node;
	struct user_namespace___136 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct fd___9 {
	struct file___156 *file;
	unsigned int flags;
};

struct bpf_map___132;

struct bpf_map_ops___132 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___132 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___132 *, struct file___156 *);
	void (*map_free)(struct bpf_map___132 *);
	int (*map_get_next_key)(struct bpf_map___132 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___132 *);
	void * (*map_lookup_elem)(struct bpf_map___132 *, void *);
	int (*map_update_elem)(struct bpf_map___132 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___132 *, void *);
	int (*map_push_elem)(struct bpf_map___132 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___132 *, void *);
	int (*map_peek_elem)(struct bpf_map___132 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___132 *, struct file___156 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___132 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___132 *, void *, struct seq_file___146 *);
	int (*map_check_btf)(const struct bpf_map___132 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___132 {
	const struct bpf_map_ops___132 *ops;
	struct bpf_map___132 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___151 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___21;

struct bpf_map_dev_ops___21 {
	int (*map_get_next_key)(struct bpf_offloaded_map___21 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___21 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___21 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___21 *, void *);
};

struct bpf_offloaded_map___21 {
	struct bpf_map___132 map;
	struct net_device___25 *netdev;
	const struct bpf_map_dev_ops___21 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

typedef rx_handler_result_t rx_handler_func_t___21(struct sk_buff___24 **);

typedef struct {
	struct net___30 *net;
} possible_net_t___22;

struct net_device_ops___21;

struct ethtool_ops___21;

struct l3mdev_ops___11;

struct ndisc_ops___5;

struct xfrmdev_ops___21;

struct tlsdev_ops___21;

struct header_ops___21;

struct inet6_dev___5;

struct netdev_rx_queue___21;

struct mini_Qdisc___20;

struct netdev_queue___21;

struct Qdisc___20;

struct rtnl_link_ops___20;

struct dcbnl_rtnl_ops___21;

struct net_device___25 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___21 *netdev_ops;
	const struct ethtool_ops___21 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___11 *l3mdev_ops;
	const struct ndisc_ops___5 *ndisc_ops;
	const struct xfrmdev_ops___21 *xfrmdev_ops;
	const struct tlsdev_ops___21 *tlsdev_ops;
	const struct header_ops___21 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___149 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___5 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___21 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___20 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___21 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___20 *miniq_ingress;
	struct netdev_queue___21 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___21 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___20 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___20 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___21 = 0,
		NETREG_REGISTERED___21 = 1,
		NETREG_UNREGISTERING___21 = 2,
		NETREG_UNREGISTERED___21 = 3,
		NETREG_RELEASED___21 = 4,
		NETREG_DUMMY___21 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___21 = 0,
		RTNL_LINK_INITIALIZING___21 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___25 *);
	struct netpoll_info *npinfo;
	possible_net_t___22 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___146 dev;
	const struct attribute_group___146 *sysfs_groups[4];
	const struct attribute_group___146 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___20 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___21 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide62;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct bpf_prog_ops___20 {
	int (*test_run)(struct bpf_prog___20 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_aux___20;

struct bpf_prog___20 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___20 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

struct bpf_verifier_ops___20 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___20 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___20 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___20 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___20 *, u32 *);
};

struct bpf_prog_offload_ops___20 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___20 *);
	int (*translate)(struct bpf_prog___20 *);
	void (*destroy)(struct bpf_prog___20 *);
};

struct bpf_prog_offload___20 {
	struct bpf_prog___20 *prog;
	struct net_device___25 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___20 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___20 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___20 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___20 *ops;
	struct bpf_map___132 **used_maps;
	struct bpf_prog___20 *prog;
	struct user_struct___151 *user;
	u64 load_time;
	struct bpf_map___132 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___20 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___20 {
	struct bpf_prog___20 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___20 {
	struct callback_head rcu;
	struct bpf_prog_array_item___20 items[0];
};

struct cgroup_bpf___20 {
	struct bpf_prog_array___20 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___20 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___132;

typedef void (*kthread_work_func_t___132)(struct kthread_work___132 *);

struct kthread_worker___132;

struct kthread_work___132 {
	struct list_head node;
	kthread_work_func_t___132 func;
	struct kthread_worker___132 *worker;
	int canceling;
};

struct kthread_worker___132 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___156 *task;
	struct kthread_work___132 *current_work;
};

struct kthread_delayed_work___132 {
	struct kthread_work___132 work;
	struct timer_list timer;
};

struct psi_group___132 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___132 *poll_kworker;
	struct kthread_delayed_work___132 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___132;

struct cgroup_rstat_cpu___132;

struct cgroup___132 {
	struct cgroup_subsys_state___132 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___152 *kn;
	struct cgroup_file___132 procs_file;
	struct cgroup_file___132 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___132 *subsys[13];
	struct cgroup_root___132 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___132 *dom_cgrp;
	struct cgroup_rstat_cpu___132 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___20 bpf;
	atomic_t congestion_count;
	struct cgroup___132 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___132 psi;
	int ancestor_ids[0];
};

struct cftype___132;

struct cgroup_subsys___132 {
	struct cgroup_subsys_state___132 * (*css_alloc)(struct cgroup_subsys_state___132 *);
	int (*css_online)(struct cgroup_subsys_state___132 *);
	void (*css_offline)(struct cgroup_subsys_state___132 *);
	void (*css_released)(struct cgroup_subsys_state___132 *);
	void (*css_free)(struct cgroup_subsys_state___132 *);
	void (*css_reset)(struct cgroup_subsys_state___132 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___132 *, int);
	int (*css_extra_stat_show)(struct seq_file___146 *, struct cgroup_subsys_state___132 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___156 *);
	void (*cancel_fork)(struct task_struct___156 *);
	void (*fork)(struct task_struct___156 *);
	void (*exit)(struct task_struct___156 *);
	void (*free)(struct task_struct___156 *);
	void (*bind)(struct cgroup_subsys_state___132 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___132 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___132 *dfl_cftypes;
	struct cftype___132 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___132 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___132 *updated_children;
	struct cgroup___132 *updated_next;
};

struct cgroup_root___132 {
	struct kernfs_root___152 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___132 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___132 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___132 *ss;
	struct list_head node;
	struct kernfs_ops___152 *kf_ops;
	int (*open)(struct kernfs_open_file___152 *);
	void (*release)(struct kernfs_open_file___152 *);
	u64 (*read_u64)(struct cgroup_subsys_state___132 *, struct cftype___132 *);
	s64 (*read_s64)(struct cgroup_subsys_state___132 *, struct cftype___132 *);
	int (*seq_show)(struct seq_file___146 *, void *);
	void * (*seq_start)(struct seq_file___146 *, loff_t *);
	void * (*seq_next)(struct seq_file___146 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___146 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___132 *, struct cftype___132 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___132 *, struct cftype___132 *, s64);
	ssize_t (*write)(struct kernfs_open_file___152 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___152 *, struct poll_table_struct___106 *);
};

struct css_task_iter___5 {
	struct cgroup_subsys___132 *ss;
	unsigned int flags;
	struct list_head *cset_pos;
	struct list_head *cset_head;
	struct list_head *tcset_pos;
	struct list_head *tcset_head;
	struct list_head *task_pos;
	struct list_head *tasks_head;
	struct list_head *mg_tasks_head;
	struct css_set___132 *cur_cset;
	struct css_set___132 *cur_dcset;
	struct task_struct___156 *cur_task;
	struct list_head iters_node;
};

struct kobj_attribute___150 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___150 *, struct kobj_attribute___150 *, char *);
	ssize_t (*store)(struct kobject___150 *, struct kobj_attribute___150 *, const char *, size_t);
};

typedef void compound_page_dtor___153(struct page___156 *);

struct mm_walk___5 {
	int (*pud_entry)(pud_t *, long unsigned int, long unsigned int, struct mm_walk___5 *);
	int (*pmd_entry)(pmd_t *, long unsigned int, long unsigned int, struct mm_walk___5 *);
	int (*pte_entry)(pte_t *, long unsigned int, long unsigned int, struct mm_walk___5 *);
	int (*pte_hole)(long unsigned int, long unsigned int, struct mm_walk___5 *);
	int (*hugetlb_entry)(pte_t *, long unsigned int, long unsigned int, long unsigned int, struct mm_walk___5 *);
	int (*test_walk)(long unsigned int, long unsigned int, struct mm_walk___5 *);
	struct mm_struct___155 *mm;
	struct vm_area_struct___156 *vma;
	void *private;
};

struct bdi_writeback_congested___75 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___75 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___75 {
	struct bio___75 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___75 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___75 bip_inline_vecs[0];
};

struct blkcg___24;

struct blkg_policy_data___24;

struct blkcg_gq___24 {
	struct request_queue___34 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___24 *blkcg;
	struct bdi_writeback_congested___75 *wb_congested;
	struct blkcg_gq___24 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_rwstat stat_bytes;
	struct blkg_rwstat stat_ios;
	struct blkg_policy_data___24 *pd[5];
	struct callback_head callback_head;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
};

struct mem_cgroup_reclaim_cookie___2 {
	pg_data_t___14 *pgdat;
	int priority;
	unsigned int generation;
};

struct mem_cgroup_reclaim_iter___70 {
	struct mem_cgroup___70 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___70 {
	struct lruvec___155 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___70 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___70 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct kobj_ns_type_operations___10 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___12 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct proto___10;

struct sock_common___10 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___10 *skc_prot;
	possible_net_t___22 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___12 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff_head___21 {
	struct sk_buff___24 *next;
	struct sk_buff___24 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___10;

struct socket_wq___10;

struct socket___10;

struct sock___12 {
	struct sock_common___10 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___21 sk_error_queue;
	struct sk_buff_head___21 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___24 *head;
		struct sk_buff___24 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___10 *sk_filter;
	union {
		struct socket_wq___10 *sk_wq;
		struct socket_wq___10 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___11 *sk_rx_dst;
	struct dst_entry___11 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___24 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___21 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___155 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___10 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___124 *sk_peer_pid;
	const struct cred___151 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___10 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___70 *sk_memcg;
	void (*sk_state_change)(struct sock___12 *);
	void (*sk_data_ready)(struct sock___12 *);
	void (*sk_write_space)(struct sock___12 *);
	void (*sk_error_report)(struct sock___12 *);
	int (*sk_backlog_rcv)(struct sock___12 *, struct sk_buff___24 *);
	struct sk_buff___24 * (*sk_validate_xmit_skb)(struct sock___12 *, struct net_device___25 *, struct sk_buff___24 *);
	void (*sk_destruct)(struct sock___12 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct bin_attribute___145;

struct attribute_group___146 {
	const char *name;
	umode_t (*is_visible)(struct kobject___150 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___150 *, struct bin_attribute___145 *, int);
	struct attribute **attrs;
	struct bin_attribute___145 **bin_attrs;
};

struct bin_attribute___145 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___156 *, struct kobject___150 *, struct bin_attribute___145 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___156 *, struct kobject___150 *, struct bin_attribute___145 *, char *, loff_t, size_t);
	int (*mmap)(struct file___156 *, struct kobject___150 *, struct bin_attribute___145 *, struct vm_area_struct___156 *);
};

struct sysfs_ops___149 {
	ssize_t (*show)(struct kobject___150 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___150 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___149;

struct kset___149 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___150 kobj;
	const struct kset_uevent_ops___149 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___149 {
	void (*release)(struct kobject___150 *);
	const struct sysfs_ops___149 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___10 * (*child_ns_type)(struct kobject___150 *);
	const void * (*namespace)(struct kobject___150 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___149 {
	int (* const filter)(struct kset___149 *, struct kobject___150 *);
	const char * (* const name)(struct kset___149 *, struct kobject___150 *);
	int (* const uevent)(struct kset___149 *, struct kobject___150 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___146 {
	int (*prepare)(struct device___146 *);
	void (*complete)(struct device___146 *);
	int (*suspend)(struct device___146 *);
	int (*resume)(struct device___146 *);
	int (*freeze)(struct device___146 *);
	int (*thaw)(struct device___146 *);
	int (*poweroff)(struct device___146 *);
	int (*restore)(struct device___146 *);
	int (*suspend_late)(struct device___146 *);
	int (*resume_early)(struct device___146 *);
	int (*freeze_late)(struct device___146 *);
	int (*thaw_early)(struct device___146 *);
	int (*poweroff_late)(struct device___146 *);
	int (*restore_early)(struct device___146 *);
	int (*suspend_noirq)(struct device___146 *);
	int (*resume_noirq)(struct device___146 *);
	int (*freeze_noirq)(struct device___146 *);
	int (*thaw_noirq)(struct device___146 *);
	int (*poweroff_noirq)(struct device___146 *);
	int (*restore_noirq)(struct device___146 *);
	int (*runtime_suspend)(struct device___146 *);
	int (*runtime_resume)(struct device___146 *);
	int (*runtime_idle)(struct device___146 *);
};

struct dev_pm_domain___146 {
	struct dev_pm_ops___146 ops;
	void (*detach)(struct device___146 *, bool);
	int (*activate)(struct device___146 *);
	void (*sync)(struct device___146 *);
	void (*dismiss)(struct device___146 *);
};

struct bus_type___146 {
	const char *name;
	const char *dev_name;
	struct device___146 *dev_root;
	const struct attribute_group___146 **bus_groups;
	const struct attribute_group___146 **dev_groups;
	const struct attribute_group___146 **drv_groups;
	int (*match)(struct device___146 *, struct device_driver___146 *);
	int (*uevent)(struct device___146 *, struct kobj_uevent_env *);
	int (*probe)(struct device___146 *);
	int (*remove)(struct device___146 *);
	void (*shutdown)(struct device___146 *);
	int (*online)(struct device___146 *);
	int (*offline)(struct device___146 *);
	int (*suspend)(struct device___146 *, pm_message_t);
	int (*resume)(struct device___146 *);
	int (*num_vf)(struct device___146 *);
	int (*dma_configure)(struct device___146 *);
	const struct dev_pm_ops___146 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___146 {
	const char *name;
	struct bus_type___146 *bus;
	struct module___133 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___146 *);
	int (*remove)(struct device___146 *);
	void (*shutdown)(struct device___146 *);
	int (*suspend)(struct device___146 *, pm_message_t);
	int (*resume)(struct device___146 *);
	const struct attribute_group___146 **groups;
	const struct dev_pm_ops___146 *pm;
	void (*coredump)(struct device___146 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___146 {
	const char *name;
	const struct attribute_group___146 **groups;
	int (*uevent)(struct device___146 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___146 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___146 *);
	const struct dev_pm_ops___146 *pm;
};

struct class___146 {
	const char *name;
	struct module___133 *owner;
	const struct attribute_group___146 **class_groups;
	const struct attribute_group___146 **dev_groups;
	struct kobject___150 *dev_kobj;
	int (*dev_uevent)(struct device___146 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___146 *, umode_t *);
	void (*class_release)(struct class___146 *);
	void (*dev_release)(struct device___146 *);
	int (*shutdown_pre)(struct device___146 *);
	const struct kobj_ns_type_operations___10 *ns_type;
	const void * (*namespace)(struct device___146 *);
	const struct dev_pm_ops___146 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___37 {
	void * (*alloc)(struct device___146 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___146 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___146 *, struct vm_area_struct___156 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___146 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___146 *, struct page___156 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___146 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___146 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___146 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___146 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___146 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___146 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide46;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___146 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___146 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___146 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___146 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___146 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___146 *, u64);
	u64 (*get_required_mask)(struct device___146 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___105;

struct fwnode_handle___105 {
	struct fwnode_handle___105 *secondary;
	const struct fwnode_operations___105 *ops;
};

struct node___124 {
	struct device___146 dev;
};

struct memcg_cache_array___6 {
	struct callback_head rcu;
	struct kmem_cache___6 *entries[0];
};

struct hstate___30 {
	int next_nid_to_alloc;
	int next_nid_to_free;
	unsigned int order;
	long unsigned int mask;
	long unsigned int max_huge_pages;
	long unsigned int nr_huge_pages;
	long unsigned int free_huge_pages;
	long unsigned int resv_huge_pages;
	long unsigned int surplus_huge_pages;
	long unsigned int nr_overcommit_huge_pages;
	struct list_head hugepage_activelist;
	struct list_head hugepage_freelists[8];
	unsigned int nr_huge_pages_node[8];
	unsigned int free_huge_pages_node[8];
	unsigned int surplus_huge_pages_node[8];
	struct cftype___132 cgroup_files[5];
	char name[32];
};

struct disk_part_tbl___34 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___34 *last_lookup;
	struct hd_struct___34 *part[0];
};

struct block_device_operations___34 {
	int (*open)(struct block_device___156 *, fmode_t);
	void (*release)(struct gendisk___34 *, fmode_t);
	int (*rw_page)(struct block_device___156 *, sector_t, struct page___156 *, unsigned int);
	int (*ioctl)(struct block_device___156 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___156 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___34 *, unsigned int);
	int (*media_changed)(struct gendisk___34 *);
	void (*unlock_native_capacity)(struct gendisk___34 *);
	int (*revalidate_disk)(struct gendisk___34 *);
	int (*getgeo)(struct block_device___156 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___156 *, long unsigned int);
	int (*report_zones)(struct gendisk___34 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___133 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___33 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___34 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___34 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___34 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___33(struct request___34 *, blk_status_t);

struct request___34 {
	struct request_queue___34 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___75 *bio;
	struct bio___75 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___75 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___37 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___33 *saved_end_io;
		} flush;
	};
	struct gendisk___34 *rq_disk;
	struct hd_struct___34 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___33 *end_io;
	void *end_io_data;
	struct request___34 *next_rq;
};

struct fwnode_reference_args___105;

struct fwnode_endpoint___105;

struct fwnode_operations___105 {
	struct fwnode_handle___105 * (*get)(struct fwnode_handle___105 *);
	void (*put)(struct fwnode_handle___105 *);
	bool (*device_is_available)(const struct fwnode_handle___105 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___105 *, const struct device___146 *);
	bool (*property_present)(const struct fwnode_handle___105 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___105 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___105 *, const char *, const char **, size_t);
	struct fwnode_handle___105 * (*get_parent)(const struct fwnode_handle___105 *);
	struct fwnode_handle___105 * (*get_next_child_node)(const struct fwnode_handle___105 *, struct fwnode_handle___105 *);
	struct fwnode_handle___105 * (*get_named_child_node)(const struct fwnode_handle___105 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___105 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___105 *);
	struct fwnode_handle___105 * (*graph_get_next_endpoint)(const struct fwnode_handle___105 *, struct fwnode_handle___105 *);
	struct fwnode_handle___105 * (*graph_get_remote_endpoint)(const struct fwnode_handle___105 *);
	struct fwnode_handle___105 * (*graph_get_port_parent)(struct fwnode_handle___105 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___105 *, struct fwnode_endpoint___105 *);
};

struct fwnode_endpoint___105 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___105 *local_fwnode;
};

struct fwnode_reference_args___105 {
	struct fwnode_handle___105 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct elevator_type___33;

struct elevator_mq_ops___33 {
	int (*init_sched)(struct request_queue___34 *, struct elevator_type___33 *);
	void (*exit_sched)(struct elevator_queue___33 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	bool (*allow_merge)(struct request_queue___34 *, struct request___34 *, struct bio___75 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx *, struct bio___75 *);
	int (*request_merge)(struct request_queue___34 *, struct request___34 **, struct bio___75 *);
	void (*request_merged)(struct request_queue___34 *, struct request___34 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___34 *, struct request___34 *, struct request___34 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___34 *, struct bio___75 *);
	void (*finish_request)(struct request___34 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___34 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___34 *, u64);
	void (*started_request)(struct request___34 *);
	void (*requeue_request)(struct request___34 *);
	struct request___34 * (*former_request)(struct request_queue___34 *, struct request___34 *);
	struct request___34 * (*next_request)(struct request_queue___34 *, struct request___34 *);
	void (*init_icq)(struct io_cq___37 *);
	void (*exit_icq)(struct io_cq___37 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___33;

struct elevator_type___33 {
	struct kmem_cache___6 *icq_cache;
	struct elevator_mq_ops___33 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___33 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___133 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___33 {
	struct elevator_type___33 *type;
	void *elevator_data;
	struct kobject___150 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___33 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___33 *, char *);
	ssize_t (*store)(struct elevator_queue___33 *, const char *, size_t);
};

struct blkcg_policy_data___24;

struct blkcg___24 {
	struct cgroup_subsys_state___132 css;
	spinlock_t lock;
	struct xarray blkg_tree;
	struct blkcg_gq___24 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___24 *cpd[5];
	struct list_head all_blkcgs_node;
	struct list_head cgwb_list;
	refcount_t cgwb_refcnt;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct blkcg_policy_data___24 {
	struct blkcg___24 *blkcg;
	int plid;
};

struct blkg_policy_data___24 {
	struct blkcg_gq___24 *blkg;
	int plid;
};

typedef struct poll_table_struct___106 poll_table___11;

struct oom_control___3 {
	struct zonelist___155 *zonelist;
	nodemask_t *nodemask;
	struct mem_cgroup___70 *memcg;
	const gfp_t gfp_mask;
	const int order;
	long unsigned int totalpages;
	struct task_struct___156 *chosen;
	long unsigned int chosen_points;
};

struct msghdr___10 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___72 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___156 *msg_iocb;
};

struct socket_wq___10 {
	wait_queue_head_t wait;
	struct fasync_struct___155 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___10;

struct socket___10 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___10 *wq;
	struct file___156 *file;
	struct sock___12 *sk;
	const struct proto_ops___10 *ops;
};

typedef int (*sk_read_actor_t___10)(read_descriptor_t *, struct sk_buff___24 *, unsigned int, size_t);

struct proto_ops___10 {
	int family;
	struct module___133 *owner;
	int (*release)(struct socket___10 *);
	int (*bind)(struct socket___10 *, struct sockaddr *, int);
	int (*connect)(struct socket___10 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___10 *, struct socket___10 *);
	int (*accept)(struct socket___10 *, struct socket___10 *, int, bool);
	int (*getname)(struct socket___10 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___156 *, struct socket___10 *, struct poll_table_struct___106 *);
	int (*ioctl)(struct socket___10 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___10 *, int);
	int (*shutdown)(struct socket___10 *, int);
	int (*setsockopt)(struct socket___10 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___10 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___10 *, struct msghdr___10 *, size_t);
	int (*recvmsg)(struct socket___10 *, struct msghdr___10 *, size_t, int);
	int (*mmap)(struct file___156 *, struct socket___10 *, struct vm_area_struct___156 *);
	ssize_t (*sendpage)(struct socket___10 *, struct page___156 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___10 *, loff_t *, struct pipe_inode_info___35 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___12 *, int);
	int (*peek_len)(struct socket___10 *);
	int (*read_sock)(struct sock___12 *, read_descriptor_t *, sk_read_actor_t___10);
	int (*sendpage_locked)(struct sock___12 *, struct page___156 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___12 *, struct msghdr___10 *, size_t);
	int (*set_rcvlowat)(struct sock___12 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct nf_bridge_info___21;

struct sk_buff___24 {
	union {
		struct {
			struct sk_buff___24 *next;
			struct sk_buff___24 *prev;
			union {
				struct net_device___25 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___12 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___24 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___21 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct pipe_buf_operations___35;

struct pipe_buffer___35 {
	struct page___156 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___35 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___35 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___35 *, struct pipe_buffer___35 *);
	void (*release)(struct pipe_inode_info___35 *, struct pipe_buffer___35 *);
	int (*steal)(struct pipe_inode_info___35 *, struct pipe_buffer___35 *);
	union {
		bool (*get)(struct pipe_inode_info___35 *, struct pipe_buffer___35 *);
		struct {
			void (*get)(struct pipe_inode_info___35 *, struct pipe_buffer___35 *);
		} __UNIQUE_ID_rh_kabi_hide49;
		union {		};
	};
};

struct nf_bridge_info___21 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___21 = 0,
		BRNF_PROTO_8021Q___21 = 1,
		BRNF_PROTO_PPPOE___21 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___25 *physindev;
	struct net_device___25 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

struct ethtool_ops___21 {
	int (*get_settings)(struct net_device___25 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___25 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___25 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___25 *);
	void (*get_regs)(struct net_device___25 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___25 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___25 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___25 *);
	void (*set_msglevel)(struct net_device___25 *, u32);
	int (*nway_reset)(struct net_device___25 *);
	u32 (*get_link)(struct net_device___25 *);
	int (*get_eeprom_len)(struct net_device___25 *);
	int (*get_eeprom)(struct net_device___25 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___25 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___25 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___25 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___25 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___25 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___25 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___25 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___25 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___25 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___25 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___25 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___25 *);
	void (*complete)(struct net_device___25 *);
	u32 (*get_priv_flags)(struct net_device___25 *);
	int (*set_priv_flags)(struct net_device___25 *, u32);
	int (*get_sset_count)(struct net_device___25 *, int);
	int (*get_rxnfc)(struct net_device___25 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___25 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___25 *, struct ethtool_flash *);
	int (*reset)(struct net_device___25 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___25 *);
	u32 (*get_rxfh_indir_size)(struct net_device___25 *);
	int (*get_rxfh)(struct net_device___25 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___25 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___25 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___25 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___25 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___25 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___25 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___25 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___25 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___25 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___25 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___25 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___25 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___25 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___25 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___25 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___25 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___25 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___25 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___25 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide52;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___25 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___25 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide53;
		union {		};
	};
	int (*get_fecparam)(struct net_device___25 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___25 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___25 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___25 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide54;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___25 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide55;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___21;

struct inet_frags___21 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___21 *, const void *);
	void (*destructor)(struct inet_frag_queue___21 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache___6 *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___21 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___24 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___24 *fragments_tail;
	struct sk_buff___24 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___21 *net;
	struct callback_head rcu;
};

struct ip_ra_chain {
	struct ip_ra_chain *next;
	struct sock___12 *sk;
	union {
		void (*destructor)(struct sock___12 *);
		struct sock___12 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___10;

struct fib_lookup_arg___10;

struct fib_rules_ops___10 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___10 *, struct flowi *, int, struct fib_lookup_arg___10 *);
	bool (*suppress)(struct fib_rule___10 *, struct fib_lookup_arg___10 *);
	int (*match)(struct fib_rule___10 *, struct flowi *, int);
	int (*configure)(struct fib_rule___10 *, struct sk_buff___24 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___10 *);
	int (*compare)(struct fib_rule___10 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___10 *, struct sk_buff___24 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___10 *);
	void (*flush_cache)(struct fib_rules_ops___10 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___133 *owner;
	struct net___30 *fro_net;
	struct callback_head rcu;
};

struct fib_table {
	struct hlist_node tb_hlist;
	u32 tb_id;
	int tb_num_default;
	struct callback_head rcu;
	long unsigned int *tb_data;
	long unsigned int __data[0];
};

struct inet_peer_base {
	struct rb_root rb_root;
	seqlock_t lock;
	int total;
};

struct fib_notifier_ops___10 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___30 *);
	int (*fib_dump)(struct net___30 *, struct notifier_block *);
	struct module___133 *owner;
	struct callback_head rcu;
};

struct dst_entry___11 {
	struct net_device___25 *dev;
	struct dst_ops___28 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___24 *);
	int (*output)(struct net___30 *, struct sock___12 *, struct sk_buff___24 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___10;

struct neigh_parms___11;

struct neigh_ops___10;

struct neighbour___11 {
	struct neighbour___11 *next;
	struct neigh_table___10 *tbl;
	struct neigh_parms___11 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___21 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___11 *, struct sk_buff___24 *);
	const struct neigh_ops___10 *ops;
	struct callback_head rcu;
	struct net_device___25 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct pernet_operations___21 {
	struct list_head list;
	int (*init)(struct net___30 *);
	void (*exit)(struct net___30 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___21 {
	int (*ieee_getets)(struct net_device___25 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___25 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___25 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___25 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___25 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___25 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___25 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___25 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___25 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___25 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___25 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___25 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___25 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___25 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___25 *);
	u8 (*setstate)(struct net_device___25 *, u8);
	void (*getpermhwaddr)(struct net_device___25 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___25 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___25 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___25 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___25 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___25 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___25 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___25 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___25 *, int, u8 *);
	void (*setpfccfg)(struct net_device___25 *, int, u8);
	void (*getpfccfg)(struct net_device___25 *, int, u8 *);
	u8 (*setall)(struct net_device___25 *);
	u8 (*getcap)(struct net_device___25 *, int, u8 *);
	int (*getnumtcs)(struct net_device___25 *, int, u8 *);
	int (*setnumtcs)(struct net_device___25 *, int, u8);
	u8 (*getpfcstate)(struct net_device___25 *);
	void (*setpfcstate)(struct net_device___25 *, u8);
	void (*getbcncfg)(struct net_device___25 *, int, u32 *);
	void (*setbcncfg)(struct net_device___25 *, int, u32);
	void (*getbcnrp)(struct net_device___25 *, int, u8 *);
	void (*setbcnrp)(struct net_device___25 *, int, u8);
	int (*setapp)(struct net_device___25 *, u8, u16, u8);
	int (*getapp)(struct net_device___25 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___25 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___25 *, int, u8);
	u8 (*getdcbx)(struct net_device___25 *);
	u8 (*setdcbx)(struct net_device___25 *, u8);
	int (*peer_getappinfo)(struct net_device___25 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___25 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___25 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___25 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___25 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___25 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct xdp_rxq_info___21 {
	struct net_device___25 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___21 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___25 *dev_rx;
};

struct netlink_callback___21 {
	struct sk_buff___24 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___21 *);
	int (*dump)(struct sk_buff___24 *, struct netlink_callback___21 *);
	int (*done)(struct netlink_callback___21 *);
	void *data;
	struct module___133 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___21 {
	int (*create)(struct sk_buff___24 *, struct net_device___25 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___24 *, unsigned char *);
	int (*cache)(const struct neighbour___11 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___25 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___21 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___21 *, int);
	int poll_owner;
	struct net_device___25 *dev;
	struct sk_buff___24 *gro_list;
	struct sk_buff___24 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___21 {
	struct net_device___25 *dev;
	struct Qdisc___20 *qdisc;
	struct Qdisc___20 *qdisc_sleeping;
	struct kobject___150 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___25 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide56;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___20 {
	struct sk_buff___24 *head;
	struct sk_buff___24 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___20;

struct Qdisc___20 {
	int (*enqueue)(struct sk_buff___24 *, struct Qdisc___20 *, struct sk_buff___24 **);
	struct sk_buff___24 * (*dequeue)(struct Qdisc___20 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___20 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___21 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___21 gso_skb;
	struct qdisc_skb_head___20 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___20 *next_sched;
	struct sk_buff_head___21 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___21 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___150 kobj;
	struct net_device___25 *dev;
	long: 64;
	struct xdp_rxq_info___21 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide57;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___21)(struct net_device___25 *, struct sk_buff___24 *, struct net_device___25 *);

struct netdev_bpf___21 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___20 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___20 *prog;
			const struct bpf_prog_offload_ops___20 *ops;
		} verifier;
		struct {
			struct bpf_prog___20 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___21 *offmap;
		};
		struct {
			struct xdp_umem *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___21 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___24 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___21 {
	int (*tls_dev_add)(struct net_device___25 *, struct sock___12 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___25 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___25 *, struct sock___12 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide58;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___21 {
	int (*ndo_init)(struct net_device___25 *);
	void (*ndo_uninit)(struct net_device___25 *);
	int (*ndo_open)(struct net_device___25 *);
	int (*ndo_stop)(struct net_device___25 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___24 *, struct net_device___25 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___24 *, struct net_device___25 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___25 *, struct sk_buff___24 *, struct net_device___25 *, select_queue_fallback_t___21);
	void (*ndo_change_rx_flags)(struct net_device___25 *, int);
	void (*ndo_set_rx_mode)(struct net_device___25 *);
	int (*ndo_set_mac_address)(struct net_device___25 *, void *);
	int (*ndo_validate_addr)(struct net_device___25 *);
	int (*ndo_do_ioctl)(struct net_device___25 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___25 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___25 *, int);
	int (*ndo_neigh_setup)(struct net_device___25 *, struct neigh_parms___11 *);
	void (*ndo_tx_timeout)(struct net_device___25 *);
	void (*ndo_get_stats64)(struct net_device___25 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___25 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___25 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___25 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___25 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___25 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___25 *);
	int (*ndo_netpoll_setup)(struct net_device___25 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___25 *);
	int (*ndo_set_vf_mac)(struct net_device___25 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___25 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___25 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___25 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___25 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___25 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___25 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___25 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___25 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___25 *, int, struct sk_buff___24 *);
	int (*ndo_set_vf_guid)(struct net_device___25 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___25 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___25 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___25 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___25 *, const struct sk_buff___24 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___25 *, struct net_device___25 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___25 *, struct net_device___25 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___25 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___25 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___25 *, struct neighbour___11 *);
	void (*ndo_neigh_destroy)(struct net_device___25 *, struct neighbour___11 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___25 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___25 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide59;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___25 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___24 *, struct netlink_callback___21 *, struct net_device___25 *, struct net_device___25 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___25 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___25 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide60;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___24 *, u32, u32, struct net_device___25 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___25 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___25 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___25 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___25 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___25 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___25 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___25 *, struct net_device___25 *);
	void (*ndo_dfwd_del_station)(struct net_device___25 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___25 *);
	int (*ndo_set_tx_maxrate)(struct net_device___25 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___25 *);
	int (*ndo_change_proto_down)(struct net_device___25 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___25 *, struct sk_buff___24 *);
	void (*ndo_set_rx_headroom)(struct net_device___25 *, int);
	int (*ndo_bpf)(struct net_device___25 *, struct netdev_bpf___21 *);
	int (*ndo_xdp_xmit)(struct net_device___25 *, int, struct xdp_frame___21 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___25 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___25 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide61;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___11 {
	possible_net_t___22 net;
	struct net_device___25 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___11 *);
	void (*neigh_cleanup)(struct neighbour___11 *);
	struct neigh_table___10 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___11 {
	u32 (*l3mdev_fib_table)(const struct net_device___25 *);
	struct sk_buff___24 * (*l3mdev_l3_rcv)(struct net_device___25 *, struct sk_buff___24 *, u16);
	struct sk_buff___24 * (*l3mdev_l3_out)(struct net_device___25 *, struct sock___12 *, struct sk_buff___24 *, u16);
	struct dst_entry___11 * (*l3mdev_link_scope_lookup)(const struct net_device___25 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct ndisc_ops___5 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___25 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___25 *, struct neighbour___11 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___25 *, u8, struct neighbour___11 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___25 *, struct sk_buff___24 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___30 *, struct net_device___25 *, const struct prefix_info *, struct inet6_dev___5 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___4;

struct inet6_dev___5 {
	struct net_device___25 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___4 *mc_list;
	struct ifmcaddr6___4 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	u8 rndid[8];
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___11 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
};

struct tcf_proto___20;

struct mini_Qdisc___20 {
	struct tcf_proto___20 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___20 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___25 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___30 *, struct net_device___25 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___25 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___25 *, struct list_head *);
	size_t (*get_size)(const struct net_device___25 *);
	int (*fill_info)(struct sk_buff___24 *, const struct net_device___25 *);
	size_t (*get_xstats_size)(const struct net_device___25 *);
	int (*fill_xstats)(struct sk_buff___24 *, const struct net_device___25 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___25 *, struct net_device___25 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___25 *, const struct net_device___25 *);
	int (*fill_slave_info)(struct sk_buff___24 *, const struct net_device___25 *, const struct net_device___25 *);
	struct net___30 * (*get_link_net)(const struct net_device___25 *);
	size_t (*get_linkxstats_size)(const struct net_device___25 *, int);
	int (*fill_linkxstats)(struct sk_buff___24 *, const struct net_device___25 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___21 {
	struct list_head poll_list;
	struct sk_buff_head___21 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___21 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___20 *output_queue;
	struct Qdisc___20 **output_queue_tailp;
	struct sk_buff___24 *completion_queue;
	struct sk_buff_head___21 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___21 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___21 input_pkt_queue;
	struct napi_struct___21 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kernel_param_ops___130 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___130 *);
	int (*get)(char *, const struct kernel_param___130 *);
	void (*free)(void *);
};

struct kparam_array___130;

struct kernel_param___130 {
	const char *name;
	struct module___133 *mod;
	const struct kernel_param_ops___130 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___130 *arr;
	};
};

struct kparam_array___130 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___130 *ops;
	void *elem;
};

struct module_attribute___130 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___130 *, struct module_kobject___130 *, char *);
	ssize_t (*store)(struct module_attribute___130 *, struct module_kobject___130 *, const char *, size_t);
	void (*setup)(struct module___133 *, const char *);
	int (*test)(struct module___133 *);
	void (*free)(struct module___133 *);
};

struct gnet_dump___20 {
	spinlock_t *lock;
	struct sk_buff___24 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___20;

struct Qdisc_ops___20 {
	struct Qdisc_ops___20 *next;
	const struct Qdisc_class_ops___20 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___24 *, struct Qdisc___20 *, struct sk_buff___24 **);
	struct sk_buff___24 * (*dequeue)(struct Qdisc___20 *);
	struct sk_buff___24 * (*peek)(struct Qdisc___20 *);
	int (*init)(struct Qdisc___20 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___20 *);
	void (*destroy)(struct Qdisc___20 *);
	int (*change)(struct Qdisc___20 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___20 *);
	int (*change_tx_queue_len)(struct Qdisc___20 *, unsigned int);
	int (*dump)(struct Qdisc___20 *, struct sk_buff___24 *);
	int (*dump_stats)(struct Qdisc___20 *, struct gnet_dump___20 *);
	void (*ingress_block_set)(struct Qdisc___20 *, u32);
	void (*egress_block_set)(struct Qdisc___20 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___20 *);
	u32 (*egress_block_get)(struct Qdisc___20 *);
	struct module___133 *owner;
};

struct tcf_block___20;

struct Qdisc_class_ops___20 {
	unsigned int flags;
	struct netdev_queue___21 * (*select_queue)(struct Qdisc___20 *, struct tcmsg *);
	int (*graft)(struct Qdisc___20 *, long unsigned int, struct Qdisc___20 *, struct Qdisc___20 **, struct netlink_ext_ack *);
	struct Qdisc___20 * (*leaf)(struct Qdisc___20 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___20 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___20 *, u32);
	int (*change)(struct Qdisc___20 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___20 *, long unsigned int);
	void (*walk)(struct Qdisc___20 *, struct qdisc_walker *);
	struct tcf_block___20 * (*tcf_block)(struct Qdisc___20 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___20 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___20 *, long unsigned int);
	int (*dump)(struct Qdisc___20 *, long unsigned int, struct sk_buff___24 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___20 *, long unsigned int, struct gnet_dump___20 *);
};

struct tcf_chain___20;

struct tcf_block___20 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___30 *net;
	struct Qdisc___20 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___20 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___20;

struct tcf_proto_ops___20;

struct tcf_proto___20 {
	struct tcf_proto___20 *next;
	void *root;
	int (*classify)(struct sk_buff___24 *, const struct tcf_proto___20 *, struct tcf_result___20 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___20 *ops;
	struct tcf_chain___20 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___20 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___20 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___20 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___24 *, const struct tcf_proto___20 *, struct tcf_result___20 *);
	int (*init)(struct tcf_proto___20 *);
	void (*destroy)(struct tcf_proto___20 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___20 *, u32);
	void (*put)(struct tcf_proto___20 *, void *);
	int (*change)(struct net___30 *, struct sk_buff___24 *, struct tcf_proto___20 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___20 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___20 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___20 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___30 *, struct tcf_chain___20 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___30 *, struct tcf_proto___20 *, void *, struct sk_buff___24 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___24 *, struct net___30 *, void *);
	struct module___133 *owner;
	int flags;
};

struct tcf_chain___20 {
	struct mutex filter_chain_lock;
	struct tcf_proto___20 *filter_chain;
	struct list_head list;
	struct tcf_block___20 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___20 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___10 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___20 *prog;
};

struct bpf_redirect_info___20 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___132 *map;
	struct bpf_map___132 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___10;

struct neigh_hash_table___10;

struct neigh_table___10 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___25 *, __u32 *);
	bool (*key_eq)(const struct neighbour___11 *, const void *);
	int (*constructor)(struct neighbour___11 *);
	int (*pconstructor)(struct pneigh_entry___10 *);
	void (*pdestructor)(struct pneigh_entry___10 *);
	void (*proxy_redo)(struct sk_buff___24 *);
	char *id;
	struct neigh_parms___11 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___21 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___10 *nht;
	struct pneigh_entry___10 **phash_buckets;
};

struct neigh_ops___10 {
	int family;
	void (*solicit)(struct neighbour___11 *, struct sk_buff___24 *);
	void (*error_report)(struct neighbour___11 *, struct sk_buff___24 *);
	int (*output)(struct neighbour___11 *, struct sk_buff___24 *);
	int (*connected_output)(struct neighbour___11 *, struct sk_buff___24 *);
};

struct pneigh_entry___10 {
	struct pneigh_entry___10 *next;
	possible_net_t___22 net;
	struct net_device___25 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___10 {
	struct neighbour___11 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___10 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___10 *ctarget;
	struct net___30 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___10 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___10 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___5;

struct timewait_sock_ops___5;

struct proto___10 {
	void (*close)(struct sock___12 *, long int);
	int (*pre_connect)(struct sock___12 *, struct sockaddr *, int);
	int (*connect)(struct sock___12 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___12 *, int);
	struct sock___12 * (*accept)(struct sock___12 *, int, int *, bool);
	int (*ioctl)(struct sock___12 *, int, long unsigned int);
	int (*init)(struct sock___12 *);
	void (*destroy)(struct sock___12 *);
	void (*shutdown)(struct sock___12 *, int);
	int (*setsockopt)(struct sock___12 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___12 *, int, int, char *, int *);
	void (*keepalive)(struct sock___12 *, int);
	int (*sendmsg)(struct sock___12 *, struct msghdr___10 *, size_t);
	int (*recvmsg)(struct sock___12 *, struct msghdr___10 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___12 *, struct page___156 *, int, size_t, int);
	int (*bind)(struct sock___12 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___12 *, struct sk_buff___24 *);
	void (*release_cb)(struct sock___12 *);
	int (*hash)(struct sock___12 *);
	void (*unhash)(struct sock___12 *);
	void (*rehash)(struct sock___12 *);
	int (*get_port)(struct sock___12 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___12 *);
	bool (*stream_memory_read)(const struct sock___12 *);
	void (*enter_memory_pressure)(struct sock___12 *);
	void (*leave_memory_pressure)(struct sock___12 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache___6 *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___5 *rsk_prot;
	struct timewait_sock_ops___5 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___133 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___12 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct request_sock___4;

struct request_sock_ops___5 {
	int family;
	unsigned int obj_size;
	struct kmem_cache___6 *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___12 *, struct request_sock___4 *);
	void (*send_ack)(const struct sock___12 *, struct sk_buff___24 *, struct request_sock___4 *);
	void (*send_reset)(const struct sock___12 *, struct sk_buff___24 *);
	void (*destructor)(struct request_sock___4 *);
	void (*syn_ack_timeout)(const struct request_sock___4 *);
};

struct timewait_sock_ops___5 {
	struct kmem_cache___6 *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___12 *, struct sock___12 *, void *);
	void (*twsk_destructor)(struct sock___12 *);
};

struct request_sock___4 {
	struct sock_common___10 __req_common;
	struct request_sock___4 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___5 *rsk_ops;
	struct sock___12 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___4 {
	struct in6_addr mca_addr;
	struct inet6_dev___5 *idev;
	struct ifmcaddr6___4 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ip6_ra_chain___4 {
	struct ip6_ra_chain___4 *next;
	struct sock___12 *sk;
	int sel;
	void (*destructor)(struct sock___12 *);
};

struct ip_rt_acct {
	__u32 o_bytes;
	__u32 o_packets;
	__u32 i_bytes;
	__u32 i_packets;
};

struct kmem_cache_cpu___6 {
	void **freelist;
	long unsigned int tid;
	struct page___156 *page;
	struct page___156 *partial;
};

struct mem_cgroup_tree_per_node {
	struct rb_root rb_root;
	struct rb_node *rb_rightmost;
	spinlock_t lock;
};

struct mem_cgroup_tree {
	struct mem_cgroup_tree_per_node *rb_tree_per_node[8];
};

struct mem_cgroup_eventfd_list {
	struct list_head list;
	struct eventfd_ctx *eventfd;
};

struct mem_cgroup_event {
	struct mem_cgroup___70 *memcg;
	struct eventfd_ctx *eventfd;
	struct list_head list;
	int (*register_event)(struct mem_cgroup___70 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct mem_cgroup___70 *, struct eventfd_ctx *);
	poll_table___11 pt;
	wait_queue_head_t *wqh;
	wait_queue_entry_t wait;
	struct work_struct remove;
};

struct move_charge_struct {
	spinlock_t lock;
	struct mm_struct___155 *mm;
	struct mem_cgroup___70 *from;
	struct mem_cgroup___70 *to;
	long unsigned int flags;
	long unsigned int precharge;
	long unsigned int moved_charge;
	long unsigned int moved_swap;
	struct task_struct___156 *moving_task;
	wait_queue_head_t waitq;
};

enum res_type {
	_MEM = 0,
	_MEMSWAP = 1,
	_OOM_TYPE = 2,
	_KMEM = 3,
	_TCP = 4,
};

struct oom_wait_info {
	struct mem_cgroup___70 *memcg;
	wait_queue_entry_t wait;
};

enum oom_status {
	OOM_SUCCESS = 0,
	OOM_FAILED = 1,
	OOM_ASYNC = 2,
	OOM_SKIPPED = 3,
};

struct memcg_stock_pcp {
	struct mem_cgroup___70 *cached;
	unsigned int nr_pages;
	struct work_struct work;
	long unsigned int flags;
};

struct memcg_kmem_cache_create_work {
	struct mem_cgroup___70 *memcg;
	struct kmem_cache___6 *cachep;
	struct work_struct work;
};

struct accumulated_stats {
	long unsigned int stat[35];
	long unsigned int events[81];
	long unsigned int lru_pages[5];
	const unsigned int *stats_array;
	const unsigned int *events_array;
	int stats_size;
	int events_size;
};

enum {
	RES_USAGE = 0,
	RES_LIMIT = 1,
	RES_MAX_USAGE = 2,
	RES_FAILCNT = 3,
	RES_SOFT_LIMIT = 4,
};

union mc_target {
	struct page___156 *page;
	swp_entry_t ent;
};

enum mc_target_type {
	MC_TARGET_NONE = 0,
	MC_TARGET_PAGE = 1,
	MC_TARGET_SWAP = 2,
	MC_TARGET_DEVICE = 3,
};

struct uncharge_gather {
	struct mem_cgroup___70 *memcg;
	long unsigned int pgpgout;
	long unsigned int nr_anon;
	long unsigned int nr_file;
	long unsigned int nr_kmem;
	long unsigned int nr_huge;
	long unsigned int nr_shmem;
	struct page___156 *dummy_page;
};

struct numa_stat {
	const char *name;
	unsigned int lru_mask;
};

enum vmpressure_levels {
	VMPRESSURE_LOW = 0,
	VMPRESSURE_MEDIUM = 1,
	VMPRESSURE_CRITICAL = 2,
	VMPRESSURE_NUM_LEVELS = 3,
};

enum vmpressure_modes {
	VMPRESSURE_NO_PASSTHROUGH = 0,
	VMPRESSURE_HIERARCHY = 1,
	VMPRESSURE_LOCAL = 2,
	VMPRESSURE_NUM_MODES = 3,
};

struct vmpressure_event {
	struct eventfd_ctx *efd;
	enum vmpressure_levels level;
	enum vmpressure_modes mode;
	struct list_head node;
};

struct swap_cgroup_ctrl {
	struct page___156 **map;
	long unsigned int length;
	spinlock_t lock;
};

struct swap_cgroup {
	short unsigned int id;
};

struct hugetlb_cgroup___2 {
	struct cgroup_subsys_state___132 css;
	struct page_counter hugepage[4];
};

enum {
	RES_USAGE___2 = 0,
	RES_LIMIT___2 = 1,
	RES_MAX_USAGE___2 = 2,
	RES_FAILCNT___2 = 3,
};

struct file___157;

struct kiocb___157;

struct vm_area_struct___157;

struct inode___157;

struct file_lock___157;

struct page___157;

struct seq_file___147;

struct file_operations___157 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___157 *, loff_t, int);
	ssize_t (*read)(struct file___157 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___157 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___157 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___157 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___157 *, bool);
	int (*iterate)(struct file___157 *, struct dir_context *);
	int (*iterate_shared)(struct file___157 *, struct dir_context *);
	__poll_t (*poll)(struct file___157 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___157 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___157 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___157 *, struct vm_area_struct___157 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___157 *, struct file___157 *);
	int (*flush)(struct file___157 *, fl_owner_t);
	int (*release)(struct inode___157 *, struct file___157 *);
	int (*fsync)(struct file___157 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___157 *, int);
	int (*lock)(struct file___157 *, int, struct file_lock___157 *);
	ssize_t (*sendpage)(struct file___157 *, struct page___157 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___157 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___157 *, int, struct file_lock___157 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___157 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___157 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___157 *, long int, struct file_lock___157 **, void **);
	long int (*fallocate)(struct file___157 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___147 *, struct file___157 *);
	ssize_t (*copy_file_range)(struct file___157 *, loff_t, struct file___157 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___157 *, loff_t, struct file___157 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___157 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___156 {
	u64 seqnum;
	struct vm_area_struct___157 *vmas[4];
};

struct page_frag___156 {
	struct page___157 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___156;

struct mem_cgroup___71;

struct cred___152;

struct nsproxy___149;

struct signal_struct___140;

struct bio_list___76;

struct backing_dev_info___76;

struct io_context___38;

struct css_set___133;

struct request_queue___35;

struct vm_struct___117;

struct task_struct___157 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___157 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___156 *mm;
	struct mm_struct___156 *active_mm;
	struct vmacache___156 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___157 *real_parent;
	struct task_struct___157 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___157 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___71 *active_memcg;
	long int rh_reserved2;
	struct pid___124 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___124 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___124 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___152 *ptracer_cred;
	const struct cred___152 *real_cred;
	const struct cred___152 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___149 *nsproxy;
	struct signal_struct___140 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___157 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___76 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___76 *backing_dev_info;
	struct io_context___38 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___133 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___156 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___71 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___35 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___157 *oom_reaper_list;
	struct vm_struct___117 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___96 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___157 *pgtable_t___156;

struct address_space___156;

struct dev_pagemap___154;

struct page___157 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___156 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___157 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___156 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___156 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___154 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___71 *mem_cgroup;
};

struct pglist_data___156;

struct lruvec___156 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___156 *pgdat;
};

struct zone___156 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___156 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___156 {
	struct zone___156 *zone;
	int zone_idx;
};

struct zonelist___156 {
	struct zoneref___156 _zonerefs[25];
};

struct pglist_data___156 {
	struct zone___156 node_zones[3];
	struct zonelist___156 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___157 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___157 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___156 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___157 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___157 *owner;
};

struct secondary_data___157 {
	void *stack;
	struct task_struct___157 *task;
	long int status;
};

struct blocking_notifier_head___156 {
	struct rw_semaphore___157 rwsem;
	struct notifier_block *head;
};

struct anon_vma___18;

struct vm_operations_struct___154;

struct vm_area_struct___157 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___157 *vm_next;
	struct vm_area_struct___157 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___156 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma___18 *anon_vma;
	const struct vm_operations_struct___154 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___157 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___156;

struct user_namespace___137;

struct mm_struct___156 {
	struct {
		struct vm_area_struct___157 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___157 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___157 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___156 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___157 *owner;
		struct user_namespace___137 *user_ns;
		struct file___157 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___156 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___156;

struct address_space___156 {
	struct inode___157 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___157 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___156 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___154)(struct vm_area_struct___157 *, long unsigned int, const struct page___157 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___154)(struct page___157 *, void *);

struct device___147;

struct dev_pagemap___154 {
	dev_page_fault_t___154 page_fault;
	dev_page_free_t___154 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___147 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct cgroup___133;

struct cgroup_subsys___133;

struct cgroup_subsys_state___133 {
	struct cgroup___133 *cgroup;
	struct cgroup_subsys___133 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___133 *parent;
};

struct kernfs_node___153;

struct cgroup_file___133 {
	struct kernfs_node___153 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___71;

struct mem_cgroup___71 {
	struct cgroup_subsys_state___133 css;
	struct mem_cgroup_id___8 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___133 events_file;
	struct cgroup_file___133 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___157 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___71 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry___156;

struct path___156 {
	struct vfsmount *mnt;
	struct dentry___156 *dentry;
};

struct file___157 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___156 f_path;
	struct inode___157 *f_inode;
	const struct file_operations___157 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___124 f_owner;
	const struct cred___152 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___156 *f_mapping;
	errseq_t f_wb_err;
};

struct anon_vma___18 {
	struct anon_vma___18 *root;
	struct rw_semaphore___157 rwsem;
	atomic_t refcount;
	unsigned int degree;
	struct anon_vma___18 *parent;
	struct rb_root_cached rb_root;
};

struct vm_fault___154;

struct vm_operations_struct___154 {
	void (*open)(struct vm_area_struct___157 *);
	void (*close)(struct vm_area_struct___157 *);
	int (*split)(struct vm_area_struct___157 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___157 *);
	vm_fault_t (*fault)(struct vm_fault___154 *);
	vm_fault_t (*huge_fault)(struct vm_fault___154 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___154 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___157 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___154 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___154 *);
	int (*access)(struct vm_area_struct___157 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___157 *);
	int (*set_policy)(struct vm_area_struct___157 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___157 *, long unsigned int);
	struct page___157 * (*find_special_page)(struct vm_area_struct___157 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___156 {
	struct task_struct___157 *task;
	struct core_thread___156 *next;
};

struct core_state___156 {
	atomic_t nr_threads;
	struct core_thread___156 dumper;
	struct completion startup;
};

struct key___152;

struct ucounts___137;

struct user_namespace___137 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___137 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___4 ns;
	long unsigned int flags;
	struct key___152 *persistent_keyring_register;
	struct rw_semaphore___157 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___137 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___154 {
	struct vm_area_struct___157 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___157 *cow_page;
	struct mem_cgroup___71 *memcg;
	struct page___157 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___156 prealloc_pte;
};

struct shrink_control___71 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___71 *memcg;
};

struct shrinker___71 {
	long unsigned int (*count_objects)(struct shrinker___71 *, struct shrink_control___71 *);
	long unsigned int (*scan_objects)(struct shrinker___71 *, struct shrink_control___71 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct user_struct___152 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___152 *uid_keyring;
	struct key___152 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___152 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___152 *session_keyring;
	struct key___152 *process_keyring;
	struct key___152 *thread_keyring;
	struct key___152 *request_key_auth;
	void *security;
	struct user_struct___152 *user;
	struct user_namespace___137 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___133;

struct nsproxy___149 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___133 *cgroup_ns;
};

struct signal_struct___140 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___157 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___157 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___124 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___124 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___156 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___124 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___76;

struct bio_list___76 {
	struct bio___76 *head;
	struct bio___76 *tail;
};

struct bdi_writeback_congested___76;

struct bdi_writeback___76 {
	struct backing_dev_info___76 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___76 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___133 *memcg_css;
	struct cgroup_subsys_state___133 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___76 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___76 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___147 *dev;
	struct device___147 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___156 *debug_dir;
	struct dentry___156 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___38;

struct io_context___38 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___38 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___133 {
	struct cgroup_subsys_state___133 *subsys[13];
	refcount_t refcount;
	struct css_set___133 *dom_cset;
	struct cgroup___133 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___133 *mg_src_cgrp;
	struct cgroup___133 *mg_dst_cgrp;
	struct css_set___133 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

typedef blk_qc_t make_request_fn___34(struct request_queue___35 *, struct bio___76 *);

struct request___35;

typedef int dma_drain_needed_fn___34(struct request___35 *);

struct kset___150;

struct kobj_type___150;

struct kobject___151 {
	const char *name;
	struct list_head entry;
	struct kobject___151 *parent;
	struct kset___150 *kset;
	struct kobj_type___150 *ktype;
	struct kernfs_node___153 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___34;

struct bsg_class_device___34 {
	struct device___147 *class_dev;
	int minor;
	struct request_queue___35 *queue;
	const struct bsg_ops___34 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___76 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___76 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___34;

struct blkcg_gq___25;

struct request_queue___35 {
	struct list_head queue_head;
	struct request___35 *last_merge;
	struct elevator_queue___34 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___34 *make_request_fn;
	dma_drain_needed_fn___34 *dma_drain_needed;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___76 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___151 kobj;
	struct kobject___151 *mq_kobj;
	struct blk_integrity integrity;
	struct device___147 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___25 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	struct bsg_class_device___34 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___76 bio_split;
	struct dentry___156 *debugfs_dir;
	struct dentry___156 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___117 {
	struct vm_struct___117 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___157 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___141 {
	struct task_struct___157 task;
	long unsigned int stack[8192];
};

struct dev_pm_info___147 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___147 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___147;

struct bus_type___147;

struct device_driver___147;

struct dev_pm_domain___147;

struct dma_map_ops___38;

struct fwnode_handle___106;

struct class___147;

struct attribute_group___147;

struct device___147 {
	struct device___147 *parent;
	struct device_private *p;
	struct kobject___151 kobj;
	const char *init_name;
	const struct device_type___147 *type;
	struct mutex mutex;
	struct bus_type___147 *bus;
	struct device_driver___147 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___147 power;
	struct dev_pm_domain___147 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___38 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___106 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___147 *class;
	const struct attribute_group___147 **groups;
	void (*release)(struct device___147 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___156;

struct super_block___156;

struct dentry___156 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___156 *d_parent;
	struct qstr d_name;
	struct inode___157 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___156 *d_op;
	struct super_block___156 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___156;

struct block_device___157;

struct inode___157 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___156 *i_op;
	struct super_block___156 *i_sb;
	struct address_space___156 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___157 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___76 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___157 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___156 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___157 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___156 {
	int (*d_revalidate)(struct dentry___156 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___156 *, unsigned int);
	int (*d_hash)(const struct dentry___156 *, struct qstr *);
	int (*d_compare)(const struct dentry___156 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___156 *);
	int (*d_init)(struct dentry___156 *);
	void (*d_release)(struct dentry___156 *);
	void (*d_prune)(struct dentry___156 *);
	void (*d_iput)(struct dentry___156 *, struct inode___157 *);
	char * (*d_dname)(struct dentry___156 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___156 *);
	int (*d_manage)(const struct path___156 *, bool);
	struct dentry___156 * (*d_real)(struct dentry___156 *, const struct inode___157 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___156;

struct mem_dqinfo___156 {
	struct quota_format_type___156 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___156;

struct quota_info___156 {
	unsigned int flags;
	struct rw_semaphore___157 dqio_sem;
	struct inode___157 *files[3];
	struct mem_dqinfo___156 info[3];
	const struct quota_format_ops___156 *ops[3];
};

struct rcuwait___156 {
	struct task_struct___157 *task;
};

struct percpu_rw_semaphore___156 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___157 rw_sem;
	struct rcuwait___156 writer;
	int readers_block;
};

struct sb_writers___156 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___156 rw_sem[3];
};

struct file_system_type___156;

struct super_operations___156;

struct dquot_operations___156;

struct quotactl_ops___156;

struct super_block___156 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___156 *s_type;
	const struct super_operations___156 *s_op;
	const struct dquot_operations___156 *dq_op;
	const struct quotactl_ops___156 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___156 *s_root;
	struct rw_semaphore___157 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___157 *s_bdev;
	struct backing_dev_info___76 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___156 s_dquot;
	struct sb_writers___156 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___156 *s_d_op;
	int cleancache_poolid;
	struct shrinker___71 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___137 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct io_cq___38 {
	struct request_queue___35 *q;
	struct io_context___38 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___6 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___157 {
	struct file___157 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___157 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___156 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___157 *ia_file;
};

struct dquot___156 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___156 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___156 {
	int qf_fmt_id;
	const struct quota_format_ops___156 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___156 *qf_next;
};

struct quota_format_ops___156 {
	int (*check_quota_file)(struct super_block___156 *, int);
	int (*read_file_info)(struct super_block___156 *, int);
	int (*write_file_info)(struct super_block___156 *, int);
	int (*free_file_info)(struct super_block___156 *, int);
	int (*read_dqblk)(struct dquot___156 *);
	int (*commit_dqblk)(struct dquot___156 *);
	int (*release_dqblk)(struct dquot___156 *);
	int (*get_next_id)(struct super_block___156 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___156 {
	int (*write_dquot)(struct dquot___156 *);
	struct dquot___156 * (*alloc_dquot)(struct super_block___156 *, int);
	void (*destroy_dquot)(struct dquot___156 *);
	int (*acquire_dquot)(struct dquot___156 *);
	int (*release_dquot)(struct dquot___156 *);
	int (*mark_dirty)(struct dquot___156 *);
	int (*write_info)(struct super_block___156 *, int);
	qsize_t * (*get_reserved_space)(struct inode___157 *);
	int (*get_projid)(struct inode___157 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___157 *, qsize_t *);
	int (*get_next_id)(struct super_block___156 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___156 {
	int (*quota_on)(struct super_block___156 *, int, int, const struct path___156 *);
	int (*quota_off)(struct super_block___156 *, int);
	int (*quota_enable)(struct super_block___156 *, unsigned int);
	int (*quota_disable)(struct super_block___156 *, unsigned int);
	int (*quota_sync)(struct super_block___156 *, int);
	int (*set_info)(struct super_block___156 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___156 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___156 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___156 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___156 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___156 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___73;

struct swap_info_struct___53;

struct address_space_operations___156 {
	int (*writepage)(struct page___157 *, struct writeback_control___73 *);
	int (*readpage)(struct file___157 *, struct page___157 *);
	int (*writepages)(struct address_space___156 *, struct writeback_control___73 *);
	int (*set_page_dirty)(struct page___157 *);
	int (*readpages)(struct file___157 *, struct address_space___156 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___157 *, struct address_space___156 *, loff_t, unsigned int, unsigned int, struct page___157 **, void **);
	int (*write_end)(struct file___157 *, struct address_space___156 *, loff_t, unsigned int, unsigned int, struct page___157 *, void *);
	sector_t (*bmap)(struct address_space___156 *, sector_t);
	void (*invalidatepage)(struct page___157 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___157 *, gfp_t);
	void (*freepage)(struct page___157 *);
	ssize_t (*direct_IO)(struct kiocb___157 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___156 *, struct page___157 *, struct page___157 *, enum migrate_mode);
	bool (*isolate_page)(struct page___157 *, isolate_mode_t);
	void (*putback_page)(struct page___157 *);
	int (*launder_page)(struct page___157 *);
	int (*is_partially_uptodate)(struct page___157 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___157 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___156 *, struct page___157 *);
	int (*swap_activate)(struct swap_info_struct___53 *, struct file___157 *, sector_t *);
	void (*swap_deactivate)(struct file___157 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___73 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___76 *wb;
	struct inode___157 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct swap_info_struct___53 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___157 *bdev;
	struct file___157 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct hd_struct___35;

struct gendisk___35;

struct block_device___157 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___157 *bd_inode;
	struct super_block___156 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___157 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___35 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___35 *bd_disk;
	struct request_queue___35 *bd_queue;
	struct backing_dev_info___76 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct hd_struct___35 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___147 __dev;
	struct kobject___151 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___35;

struct block_device_operations___35;

struct gendisk___35 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___35 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___35 *part_tbl;
	struct hd_struct___35 part0;
	const struct block_device_operations___35 *fops;
	struct request_queue___35 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___157 lookup_sem;
	struct kobject___151 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___151 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___156 {
	struct dentry___156 * (*lookup)(struct inode___157 *, struct dentry___156 *, unsigned int);
	const char * (*get_link)(struct dentry___156 *, struct inode___157 *, struct delayed_call *);
	int (*permission)(struct inode___157 *, int);
	struct posix_acl * (*get_acl)(struct inode___157 *, int);
	int (*readlink)(struct dentry___156 *, char *, int);
	int (*create)(struct inode___157 *, struct dentry___156 *, umode_t, bool);
	int (*link)(struct dentry___156 *, struct inode___157 *, struct dentry___156 *);
	int (*unlink)(struct inode___157 *, struct dentry___156 *);
	int (*symlink)(struct inode___157 *, struct dentry___156 *, const char *);
	int (*mkdir)(struct inode___157 *, struct dentry___156 *, umode_t);
	int (*rmdir)(struct inode___157 *, struct dentry___156 *);
	int (*mknod)(struct inode___157 *, struct dentry___156 *, umode_t, dev_t);
	int (*rename)(struct inode___157 *, struct dentry___156 *, struct inode___157 *, struct dentry___156 *, unsigned int);
	int (*setattr)(struct dentry___156 *, struct iattr___156 *);
	int (*getattr)(const struct path___156 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___156 *, char *, size_t);
	int (*fiemap)(struct inode___157 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___157 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___157 *, struct dentry___156 *, struct file___157 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___157 *, struct dentry___156 *, umode_t);
	int (*set_acl)(struct inode___157 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___156 {
	void (*fl_copy_lock)(struct file_lock___157 *, struct file_lock___157 *);
	void (*fl_release_private)(struct file_lock___157 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___156;

struct lock_manager_operations___156;

struct file_lock___157 {
	struct file_lock___157 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___157 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___156 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___156 *fl_ops;
	const struct lock_manager_operations___156 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___156 {
	int (*lm_compare_owner)(struct file_lock___157 *, struct file_lock___157 *);
	long unsigned int (*lm_owner_key)(struct file_lock___157 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___157 *);
	int (*lm_grant)(struct file_lock___157 *, int);
	bool (*lm_break)(struct file_lock___157 *);
	int (*lm_change)(struct file_lock___157 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___157 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___156 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___156 *fa_next;
	struct file___157 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___156 {
	const char *name;
	int fs_flags;
	struct dentry___156 * (*mount)(struct file_system_type___156 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___156 *);
	struct module___11 *owner;
	struct file_system_type___156 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___156 {
	struct inode___157 * (*alloc_inode)(struct super_block___156 *);
	void (*destroy_inode)(struct inode___157 *);
	void (*dirty_inode)(struct inode___157 *, int);
	int (*write_inode)(struct inode___157 *, struct writeback_control___73 *);
	int (*drop_inode)(struct inode___157 *);
	void (*evict_inode)(struct inode___157 *);
	void (*put_super)(struct super_block___156 *);
	int (*sync_fs)(struct super_block___156 *, int);
	int (*freeze_super)(struct super_block___156 *);
	int (*freeze_fs)(struct super_block___156 *);
	int (*thaw_super)(struct super_block___156 *);
	int (*unfreeze_fs)(struct super_block___156 *);
	int (*statfs)(struct dentry___156 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___156 *, int *, char *);
	void (*umount_begin)(struct super_block___156 *);
	int (*show_options)(struct seq_file___147 *, struct dentry___156 *);
	int (*show_devname)(struct seq_file___147 *, struct dentry___156 *);
	int (*show_path)(struct seq_file___147 *, struct dentry___156 *);
	int (*show_stats)(struct seq_file___147 *, struct dentry___156 *);
	ssize_t (*quota_read)(struct super_block___156 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___156 *, int, const char *, size_t, loff_t);
	struct dquot___156 ** (*get_dquots)(struct inode___157 *);
	int (*bdev_try_to_free_page)(struct super_block___156 *, struct page___157 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___156 *, struct shrink_control___71 *);
	long int (*free_cached_objects)(struct super_block___156 *, struct shrink_control___71 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___145;

struct seq_file___147 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___145 *op;
	int poll_event;
	const struct file___157 *file;
	void *private;
};

typedef void bio_end_io_t___76(struct bio___76 *);

struct bio_vec___76 {
	struct page___157 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___76;

struct bio___76 {
	struct bio___76 *bi_next;
	struct gendisk___35 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___76 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___25 *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___76 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___76 *bi_io_vec;
	struct bio_set___76 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___76 bi_inline_vecs[0];
};

struct kobj_attribute___151 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___151 *, struct kobj_attribute___151 *, char *);
	ssize_t (*store)(struct kobject___151 *, struct kobj_attribute___151 *, const char *, size_t);
};

typedef void compound_page_dtor___154(struct page___157 *);

enum mf_result {
	MF_IGNORED = 0,
	MF_FAILED = 1,
	MF_DELAYED = 2,
	MF_RECOVERED = 3,
};

enum mf_action_page_type {
	MF_MSG_KERNEL = 0,
	MF_MSG_KERNEL_HIGH_ORDER = 1,
	MF_MSG_SLAB = 2,
	MF_MSG_DIFFERENT_COMPOUND = 3,
	MF_MSG_POISONED_HUGE = 4,
	MF_MSG_HUGE = 5,
	MF_MSG_FREE_HUGE = 6,
	MF_MSG_NON_PMD_HUGE = 7,
	MF_MSG_UNMAP_FAILED = 8,
	MF_MSG_DIRTY_SWAPCACHE = 9,
	MF_MSG_CLEAN_SWAPCACHE = 10,
	MF_MSG_DIRTY_MLOCKED_LRU = 11,
	MF_MSG_CLEAN_MLOCKED_LRU = 12,
	MF_MSG_DIRTY_UNEVICTABLE_LRU = 13,
	MF_MSG_CLEAN_UNEVICTABLE_LRU = 14,
	MF_MSG_DIRTY_LRU = 15,
	MF_MSG_CLEAN_LRU = 16,
	MF_MSG_TRUNCATED_LRU = 17,
	MF_MSG_BUDDY = 18,
	MF_MSG_BUDDY_2ND = 19,
	MF_MSG_UNKNOWN = 20,
};

typedef int (*key_restrict_link_func_t___152)(struct key___152 *, const struct key_type *, const union key_payload *, struct key___152 *);

struct key_restriction___152;

struct key___152 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___157 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___152 *restrict_link;
};

struct key_restriction___152 {
	key_restrict_link_func_t___152 check;
	struct key___152 *key;
	struct key_type *keytype;
};

struct seq_operations___145 {
	void * (*start)(struct seq_file___147 *, loff_t *);
	void (*stop)(struct seq_file___147 *, void *);
	void * (*next)(struct seq_file___147 *, void *, loff_t *);
	int (*show)(struct seq_file___147 *, void *);
};

struct kernfs_root___153;

struct kernfs_elem_dir___153 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___153 *root;
};

struct kernfs_syscall_ops___153;

struct kernfs_root___153 {
	struct kernfs_node___153 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___153 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___153 {
	struct kernfs_node___153 *target_kn;
};

struct kernfs_ops___153;

struct kernfs_elem_attr___153 {
	const struct kernfs_ops___153 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___153 *notify_next;
};

struct kernfs_node___153 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___153 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___153 dir;
		struct kernfs_elem_symlink___153 symlink;
		struct kernfs_elem_attr___153 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___153;

struct kernfs_ops___153 {
	int (*open)(struct kernfs_open_file___153 *);
	void (*release)(struct kernfs_open_file___153 *);
	int (*seq_show)(struct seq_file___147 *, void *);
	void * (*seq_start)(struct seq_file___147 *, loff_t *);
	void * (*seq_next)(struct seq_file___147 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___147 *, void *);
	ssize_t (*read)(struct kernfs_open_file___153 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___153 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___153 *, struct vm_area_struct___157 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___153 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___153 {
	int (*remount_fs)(struct kernfs_root___153 *, int *, char *);
	int (*show_options)(struct seq_file___147 *, struct kernfs_root___153 *);
	int (*mkdir)(struct kernfs_node___153 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___153 *);
	int (*rename)(struct kernfs_node___153 *, struct kernfs_node___153 *, const char *);
	int (*show_path)(struct seq_file___147 *, struct kernfs_node___153 *, struct kernfs_root___153 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___153 {
	struct kernfs_node___153 *kn;
	struct file___157 *file;
	struct seq_file___147 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___154 *vm_ops;
};

struct cgroup_namespace___133 {
	refcount_t count;
	struct ns_common___4 ns;
	struct user_namespace___137 *user_ns;
	struct ucounts___137 *ucounts;
	struct css_set___133 *root_cset;
};

struct ucounts___137 {
	struct hlist_node node;
	struct user_namespace___137 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___133;

struct bpf_map_ops___133 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___133 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___133 *, struct file___157 *);
	void (*map_free)(struct bpf_map___133 *);
	int (*map_get_next_key)(struct bpf_map___133 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___133 *);
	void * (*map_lookup_elem)(struct bpf_map___133 *, void *);
	int (*map_update_elem)(struct bpf_map___133 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___133 *, void *);
	int (*map_push_elem)(struct bpf_map___133 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___133 *, void *);
	int (*map_peek_elem)(struct bpf_map___133 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___133 *, struct file___157 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___133 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___133 *, void *, struct seq_file___147 *);
	int (*map_check_btf)(const struct bpf_map___133 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___133 {
	const struct bpf_map_ops___133 *ops;
	struct bpf_map___133 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___152 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___133;

typedef void (*kthread_work_func_t___133)(struct kthread_work___133 *);

struct kthread_worker___133;

struct kthread_work___133 {
	struct list_head node;
	kthread_work_func_t___133 func;
	struct kthread_worker___133 *worker;
	int canceling;
};

struct kthread_worker___133 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___157 *task;
	struct kthread_work___133 *current_work;
};

struct kthread_delayed_work___133 {
	struct kthread_work___133 work;
	struct timer_list timer;
};

struct psi_group___133 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___133 *poll_kworker;
	struct kthread_delayed_work___133 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___133;

struct cgroup_rstat_cpu___133;

struct cgroup___133 {
	struct cgroup_subsys_state___133 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___153 *kn;
	struct cgroup_file___133 procs_file;
	struct cgroup_file___133 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___133 *subsys[13];
	struct cgroup_root___133 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___133 *dom_cgrp;
	struct cgroup_rstat_cpu___133 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___20 bpf;
	atomic_t congestion_count;
	struct cgroup___133 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___133 psi;
	int ancestor_ids[0];
};

struct cftype___133;

struct cgroup_subsys___133 {
	struct cgroup_subsys_state___133 * (*css_alloc)(struct cgroup_subsys_state___133 *);
	int (*css_online)(struct cgroup_subsys_state___133 *);
	void (*css_offline)(struct cgroup_subsys_state___133 *);
	void (*css_released)(struct cgroup_subsys_state___133 *);
	void (*css_free)(struct cgroup_subsys_state___133 *);
	void (*css_reset)(struct cgroup_subsys_state___133 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___133 *, int);
	int (*css_extra_stat_show)(struct seq_file___147 *, struct cgroup_subsys_state___133 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___157 *);
	void (*cancel_fork)(struct task_struct___157 *);
	void (*fork)(struct task_struct___157 *);
	void (*exit)(struct task_struct___157 *);
	void (*free)(struct task_struct___157 *);
	void (*bind)(struct cgroup_subsys_state___133 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___133 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___133 *dfl_cftypes;
	struct cftype___133 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___133 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___133 *updated_children;
	struct cgroup___133 *updated_next;
};

struct cgroup_root___133 {
	struct kernfs_root___153 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___133 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___133 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___133 *ss;
	struct list_head node;
	struct kernfs_ops___153 *kf_ops;
	int (*open)(struct kernfs_open_file___153 *);
	void (*release)(struct kernfs_open_file___153 *);
	u64 (*read_u64)(struct cgroup_subsys_state___133 *, struct cftype___133 *);
	s64 (*read_s64)(struct cgroup_subsys_state___133 *, struct cftype___133 *);
	int (*seq_show)(struct seq_file___147 *, void *);
	void * (*seq_start)(struct seq_file___147 *, loff_t *);
	void * (*seq_next)(struct seq_file___147 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___147 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___133 *, struct cftype___133 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___133 *, struct cftype___133 *, s64);
	ssize_t (*write)(struct kernfs_open_file___153 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___153 *, struct poll_table_struct___6 *);
};

struct bdi_writeback_congested___76 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___76 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___76 {
	struct bio___76 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___76 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___76 bip_inline_vecs[0];
};

struct blkcg___25;

struct blkg_policy_data___25;

struct blkcg_gq___25 {
	struct request_queue___35 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___25 *blkcg;
	struct bdi_writeback_congested___76 *wb_congested;
	struct blkcg_gq___25 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_rwstat stat_bytes;
	struct blkg_rwstat stat_ios;
	struct blkg_policy_data___25 *pd[5];
	struct callback_head callback_head;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
};

struct mem_cgroup_reclaim_iter___71 {
	struct mem_cgroup___71 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___71 {
	struct lruvec___156 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___71 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___71 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct anon_vma_chain___4 {
	struct vm_area_struct___157 *vma;
	struct anon_vma___18 *anon_vma;
	struct list_head same_vma;
	struct rb_node rb;
	long unsigned int rb_subtree_last;
};

struct bin_attribute___146;

struct attribute_group___147 {
	const char *name;
	umode_t (*is_visible)(struct kobject___151 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___151 *, struct bin_attribute___146 *, int);
	struct attribute **attrs;
	struct bin_attribute___146 **bin_attrs;
};

struct bin_attribute___146 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___157 *, struct kobject___151 *, struct bin_attribute___146 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___157 *, struct kobject___151 *, struct bin_attribute___146 *, char *, loff_t, size_t);
	int (*mmap)(struct file___157 *, struct kobject___151 *, struct bin_attribute___146 *, struct vm_area_struct___157 *);
};

struct sysfs_ops___150 {
	ssize_t (*show)(struct kobject___151 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___151 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___150;

struct kset___150 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___151 kobj;
	const struct kset_uevent_ops___150 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___150 {
	void (*release)(struct kobject___151 *);
	const struct sysfs_ops___150 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___10 * (*child_ns_type)(struct kobject___151 *);
	const void * (*namespace)(struct kobject___151 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___150 {
	int (* const filter)(struct kset___150 *, struct kobject___151 *);
	const char * (* const name)(struct kset___150 *, struct kobject___151 *);
	int (* const uevent)(struct kset___150 *, struct kobject___151 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___147 {
	int (*prepare)(struct device___147 *);
	void (*complete)(struct device___147 *);
	int (*suspend)(struct device___147 *);
	int (*resume)(struct device___147 *);
	int (*freeze)(struct device___147 *);
	int (*thaw)(struct device___147 *);
	int (*poweroff)(struct device___147 *);
	int (*restore)(struct device___147 *);
	int (*suspend_late)(struct device___147 *);
	int (*resume_early)(struct device___147 *);
	int (*freeze_late)(struct device___147 *);
	int (*thaw_early)(struct device___147 *);
	int (*poweroff_late)(struct device___147 *);
	int (*restore_early)(struct device___147 *);
	int (*suspend_noirq)(struct device___147 *);
	int (*resume_noirq)(struct device___147 *);
	int (*freeze_noirq)(struct device___147 *);
	int (*thaw_noirq)(struct device___147 *);
	int (*poweroff_noirq)(struct device___147 *);
	int (*restore_noirq)(struct device___147 *);
	int (*runtime_suspend)(struct device___147 *);
	int (*runtime_resume)(struct device___147 *);
	int (*runtime_idle)(struct device___147 *);
};

struct dev_pm_domain___147 {
	struct dev_pm_ops___147 ops;
	void (*detach)(struct device___147 *, bool);
	int (*activate)(struct device___147 *);
	void (*sync)(struct device___147 *);
	void (*dismiss)(struct device___147 *);
};

struct bus_type___147 {
	const char *name;
	const char *dev_name;
	struct device___147 *dev_root;
	const struct attribute_group___147 **bus_groups;
	const struct attribute_group___147 **dev_groups;
	const struct attribute_group___147 **drv_groups;
	int (*match)(struct device___147 *, struct device_driver___147 *);
	int (*uevent)(struct device___147 *, struct kobj_uevent_env *);
	int (*probe)(struct device___147 *);
	int (*remove)(struct device___147 *);
	void (*shutdown)(struct device___147 *);
	int (*online)(struct device___147 *);
	int (*offline)(struct device___147 *);
	int (*suspend)(struct device___147 *, pm_message_t);
	int (*resume)(struct device___147 *);
	int (*num_vf)(struct device___147 *);
	int (*dma_configure)(struct device___147 *);
	const struct dev_pm_ops___147 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___147 {
	const char *name;
	struct bus_type___147 *bus;
	struct module___11 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___147 *);
	int (*remove)(struct device___147 *);
	void (*shutdown)(struct device___147 *);
	int (*suspend)(struct device___147 *, pm_message_t);
	int (*resume)(struct device___147 *);
	const struct attribute_group___147 **groups;
	const struct dev_pm_ops___147 *pm;
	void (*coredump)(struct device___147 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___147 {
	const char *name;
	const struct attribute_group___147 **groups;
	int (*uevent)(struct device___147 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___147 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___147 *);
	const struct dev_pm_ops___147 *pm;
};

struct class___147 {
	const char *name;
	struct module___11 *owner;
	const struct attribute_group___147 **class_groups;
	const struct attribute_group___147 **dev_groups;
	struct kobject___151 *dev_kobj;
	int (*dev_uevent)(struct device___147 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___147 *, umode_t *);
	void (*class_release)(struct class___147 *);
	void (*dev_release)(struct device___147 *);
	int (*shutdown_pre)(struct device___147 *);
	const struct kobj_ns_type_operations___10 *ns_type;
	const void * (*namespace)(struct device___147 *);
	const struct dev_pm_ops___147 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___38 {
	void * (*alloc)(struct device___147 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___147 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___147 *, struct vm_area_struct___157 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___147 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___147 *, struct page___157 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___147 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___147 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___147 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___147 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___147 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___147 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide44;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___147 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___147 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___147 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___147 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___147 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___147 *, u64);
	u64 (*get_required_mask)(struct device___147 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___106;

struct fwnode_handle___106 {
	struct fwnode_handle___106 *secondary;
	const struct fwnode_operations___106 *ops;
};

struct node___125 {
	struct device___147 dev;
};

struct disk_part_tbl___35 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___35 *last_lookup;
	struct hd_struct___35 *part[0];
};

struct block_device_operations___35 {
	int (*open)(struct block_device___157 *, fmode_t);
	void (*release)(struct gendisk___35 *, fmode_t);
	int (*rw_page)(struct block_device___157 *, sector_t, struct page___157 *, unsigned int);
	int (*ioctl)(struct block_device___157 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___157 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___35 *, unsigned int);
	int (*media_changed)(struct gendisk___35 *);
	void (*unlock_native_capacity)(struct gendisk___35 *);
	int (*revalidate_disk)(struct gendisk___35 *);
	int (*getgeo)(struct block_device___157 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___157 *, long unsigned int);
	int (*report_zones)(struct gendisk___35 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___11 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___34 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___35 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___35 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___35 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___34(struct request___35 *, blk_status_t);

struct request___35 {
	struct request_queue___35 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___76 *bio;
	struct bio___76 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___76 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___38 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___34 *saved_end_io;
		} flush;
	};
	struct gendisk___35 *rq_disk;
	struct hd_struct___35 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___34 *end_io;
	void *end_io_data;
	struct request___35 *next_rq;
};

struct fwnode_reference_args___106;

struct fwnode_endpoint___106;

struct fwnode_operations___106 {
	struct fwnode_handle___106 * (*get)(struct fwnode_handle___106 *);
	void (*put)(struct fwnode_handle___106 *);
	bool (*device_is_available)(const struct fwnode_handle___106 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___106 *, const struct device___147 *);
	bool (*property_present)(const struct fwnode_handle___106 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___106 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___106 *, const char *, const char **, size_t);
	struct fwnode_handle___106 * (*get_parent)(const struct fwnode_handle___106 *);
	struct fwnode_handle___106 * (*get_next_child_node)(const struct fwnode_handle___106 *, struct fwnode_handle___106 *);
	struct fwnode_handle___106 * (*get_named_child_node)(const struct fwnode_handle___106 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___106 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___106 *);
	struct fwnode_handle___106 * (*graph_get_next_endpoint)(const struct fwnode_handle___106 *, struct fwnode_handle___106 *);
	struct fwnode_handle___106 * (*graph_get_remote_endpoint)(const struct fwnode_handle___106 *);
	struct fwnode_handle___106 * (*graph_get_port_parent)(struct fwnode_handle___106 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___106 *, struct fwnode_endpoint___106 *);
};

struct fwnode_endpoint___106 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___106 *local_fwnode;
};

struct fwnode_reference_args___106 {
	struct fwnode_handle___106 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct elevator_type___34;

struct elevator_mq_ops___34 {
	int (*init_sched)(struct request_queue___35 *, struct elevator_type___34 *);
	void (*exit_sched)(struct elevator_queue___34 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	bool (*allow_merge)(struct request_queue___35 *, struct request___35 *, struct bio___76 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx *, struct bio___76 *);
	int (*request_merge)(struct request_queue___35 *, struct request___35 **, struct bio___76 *);
	void (*request_merged)(struct request_queue___35 *, struct request___35 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___35 *, struct request___35 *, struct request___35 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___35 *, struct bio___76 *);
	void (*finish_request)(struct request___35 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___35 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___35 *, u64);
	void (*started_request)(struct request___35 *);
	void (*requeue_request)(struct request___35 *);
	struct request___35 * (*former_request)(struct request_queue___35 *, struct request___35 *);
	struct request___35 * (*next_request)(struct request_queue___35 *, struct request___35 *);
	void (*init_icq)(struct io_cq___38 *);
	void (*exit_icq)(struct io_cq___38 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___34;

struct elevator_type___34 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___34 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___34 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___11 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___34 {
	struct elevator_type___34 *type;
	void *elevator_data;
	struct kobject___151 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___34 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___34 *, char *);
	ssize_t (*store)(struct elevator_queue___34 *, const char *, size_t);
};

struct blkcg_policy_data___25;

struct blkcg___25 {
	struct cgroup_subsys_state___133 css;
	spinlock_t lock;
	struct xarray blkg_tree;
	struct blkcg_gq___25 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___25 *cpd[5];
	struct list_head all_blkcgs_node;
	struct list_head cgwb_list;
	refcount_t cgwb_refcnt;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct blkcg_policy_data___25 {
	struct blkcg___25 *blkcg;
	int plid;
};

struct blkg_policy_data___25 {
	struct blkcg_gq___25 *blkg;
	int plid;
};

struct hstate___31 {
	int next_nid_to_alloc;
	int next_nid_to_free;
	unsigned int order;
	long unsigned int mask;
	long unsigned int max_huge_pages;
	long unsigned int nr_huge_pages;
	long unsigned int free_huge_pages;
	long unsigned int resv_huge_pages;
	long unsigned int surplus_huge_pages;
	long unsigned int nr_overcommit_huge_pages;
	struct list_head hugepage_activelist;
	struct list_head hugepage_freelists[8];
	unsigned int nr_huge_pages_node[8];
	unsigned int free_huge_pages_node[8];
	unsigned int surplus_huge_pages_node[8];
	struct cftype___133 cgroup_files[5];
	char name[32];
};

struct __kfifo {
	unsigned int in;
	unsigned int out;
	unsigned int mask;
	unsigned int esize;
	void *data;
};

struct to_kill {
	struct list_head nd;
	struct task_struct___157 *tsk;
	long unsigned int addr;
	char addr_valid;
};

struct page_state {
	long unsigned int mask;
	long unsigned int res;
	enum mf_action_page_type type;
	int (*action)(struct page___157 *, long unsigned int);
};

struct memory_failure_entry {
	long unsigned int pfn;
	int flags;
};

struct memory_failure_cpu {
	struct {
		union {
			struct __kfifo kfifo;
			struct memory_failure_entry *type;
			const struct memory_failure_entry *const_type;
			char (*rectype)[0];
			struct memory_failure_entry *ptr;
			const struct memory_failure_entry *ptr_const;
		};
		struct memory_failure_entry buf[16];
	} fifo;
	spinlock_t lock;
	struct work_struct work;
};

struct module___134;

struct file___158;

struct kiocb___158;

struct vm_area_struct___158;

struct inode___158;

struct file_lock___158;

struct page___158;

struct seq_file___148;

struct file_operations___158 {
	struct module___134 *owner;
	loff_t (*llseek)(struct file___158 *, loff_t, int);
	ssize_t (*read)(struct file___158 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___158 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___158 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___158 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___158 *, bool);
	int (*iterate)(struct file___158 *, struct dir_context *);
	int (*iterate_shared)(struct file___158 *, struct dir_context *);
	__poll_t (*poll)(struct file___158 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___158 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___158 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___158 *, struct vm_area_struct___158 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___158 *, struct file___158 *);
	int (*flush)(struct file___158 *, fl_owner_t);
	int (*release)(struct inode___158 *, struct file___158 *);
	int (*fsync)(struct file___158 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___158 *, int);
	int (*lock)(struct file___158 *, int, struct file_lock___158 *);
	ssize_t (*sendpage)(struct file___158 *, struct page___158 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___158 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___158 *, int, struct file_lock___158 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___158 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___158 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___158 *, long int, struct file_lock___158 **, void **);
	long int (*fallocate)(struct file___158 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___148 *, struct file___158 *);
	ssize_t (*copy_file_range)(struct file___158 *, loff_t, struct file___158 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___158 *, loff_t, struct file___158 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___158 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___157 {
	u64 seqnum;
	struct vm_area_struct___158 *vmas[4];
};

struct page_frag___157 {
	struct page___158 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___157;

struct cred___153;

struct task_struct___158 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___158 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___157 *mm;
	struct mm_struct___157 *active_mm;
	struct vmacache___157 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___158 *real_parent;
	struct task_struct___158 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___158 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___124 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___124 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___124 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___153 *ptracer_cred;
	const struct cred___153 *real_cred;
	const struct cred___153 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___158 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___38 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___157 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___158 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___96 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___158 *pgtable_t___157;

struct address_space___157;

struct dev_pagemap___155;

struct page___158 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___157 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___158 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___157 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___157 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___155 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___157;

struct lruvec___157 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___157 *pgdat;
};

struct zone___157 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___157 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___157 {
	struct zone___157 *zone;
	int zone_idx;
};

struct zonelist___157 {
	struct zoneref___157 _zonerefs[25];
};

struct pglist_data___157 {
	struct zone___157 node_zones[3];
	struct zonelist___157 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___158 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___158 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___157 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___158 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___158 *owner;
};

struct secondary_data___158 {
	void *stack;
	struct task_struct___158 *task;
	long int status;
};

struct blocking_notifier_head___157 {
	struct rw_semaphore___158 rwsem;
	struct notifier_block *head;
};

struct dentry___157;

struct path___157 {
	struct vfsmount *mnt;
	struct dentry___157 *dentry;
};

struct file___158 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___157 f_path;
	struct inode___158 *f_inode;
	const struct file_operations___158 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___124 f_owner;
	const struct cred___153 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___157 *f_mapping;
	errseq_t f_wb_err;
};

struct key___153;

struct user_struct___153;

struct cred___153 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___153 *session_keyring;
	struct key___153 *process_keyring;
	struct key___153 *thread_keyring;
	struct key___153 *request_key_auth;
	void *security;
	struct user_struct___153 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___154;

struct kernfs_elem_dir___154 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___154 *root;
};

struct kernfs_node___154;

struct kernfs_syscall_ops___154;

struct kernfs_root___154 {
	struct kernfs_node___154 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___154 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___154 {
	struct kernfs_node___154 *target_kn;
};

struct kernfs_ops___154;

struct kernfs_elem_attr___154 {
	const struct kernfs_ops___154 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___154 *notify_next;
};

struct kernfs_node___154 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___154 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___154 dir;
		struct kernfs_elem_symlink___154 symlink;
		struct kernfs_elem_attr___154 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___154;

struct kernfs_ops___154 {
	int (*open)(struct kernfs_open_file___154 *);
	void (*release)(struct kernfs_open_file___154 *);
	int (*seq_show)(struct seq_file___148 *, void *);
	void * (*seq_start)(struct seq_file___148 *, loff_t *);
	void * (*seq_next)(struct seq_file___148 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___148 *, void *);
	ssize_t (*read)(struct kernfs_open_file___154 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___154 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___154 *, struct vm_area_struct___158 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___154 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___154 {
	int (*remount_fs)(struct kernfs_root___154 *, int *, char *);
	int (*show_options)(struct seq_file___148 *, struct kernfs_root___154 *);
	int (*mkdir)(struct kernfs_node___154 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___154 *);
	int (*rename)(struct kernfs_node___154 *, struct kernfs_node___154 *, const char *);
	int (*show_path)(struct seq_file___148 *, struct kernfs_node___154 *, struct kernfs_root___154 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___146;

struct seq_file___148 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___146 *op;
	int poll_event;
	const struct file___158 *file;
	void *private;
};

struct vm_operations_struct___155;

struct kernfs_open_file___154 {
	struct kernfs_node___154 *kn;
	struct file___158 *file;
	struct seq_file___148 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___155 *vm_ops;
};

struct vm_fault___155;

struct vm_operations_struct___155 {
	void (*open)(struct vm_area_struct___158 *);
	void (*close)(struct vm_area_struct___158 *);
	int (*split)(struct vm_area_struct___158 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___158 *);
	vm_fault_t (*fault)(struct vm_fault___155 *);
	vm_fault_t (*huge_fault)(struct vm_fault___155 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___155 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___158 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___155 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___155 *);
	int (*access)(struct vm_area_struct___158 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___158 *);
	int (*set_policy)(struct vm_area_struct___158 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___158 *, long unsigned int);
	struct page___158 * (*find_special_page)(struct vm_area_struct___158 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_area_struct___158 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___158 *vm_next;
	struct vm_area_struct___158 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___157 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___155 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___158 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___151;

struct kobj_type___151;

struct kobject___152 {
	const char *name;
	struct list_head entry;
	struct kobject___152 *parent;
	struct kset___151 *kset;
	struct kobj_type___151 *ktype;
	struct kernfs_node___154 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sysfs_ops___151 {
	ssize_t (*show)(struct kobject___152 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___152 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___151;

struct kset___151 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___152 kobj;
	const struct kset_uevent_ops___151 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___151 {
	void (*release)(struct kobject___152 *);
	const struct sysfs_ops___151 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___10 * (*child_ns_type)(struct kobject___152 *);
	const void * (*namespace)(struct kobject___152 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___151 {
	int (* const filter)(struct kset___151 *, struct kobject___152 *);
	const char * (* const name)(struct kset___151 *, struct kobject___152 *);
	int (* const uevent)(struct kset___151 *, struct kobject___152 *, struct kobj_uevent_env *);
};

struct kobj_attribute___152 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___152 *, struct kobj_attribute___152 *, char *);
	ssize_t (*store)(struct kobject___152 *, struct kobj_attribute___152 *, const char *, size_t);
};

struct kernel_param___131;

struct kernel_param_ops___131 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___131 *);
	int (*get)(char *, const struct kernel_param___131 *);
	void (*free)(void *);
};

struct kparam_array___131;

struct kernel_param___131 {
	const char *name;
	struct module___134 *mod;
	const struct kernel_param_ops___131 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___131 *arr;
	};
};

struct kparam_array___131 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___131 *ops;
	void *elem;
};

struct module_kobject___131 {
	struct kobject___152 kobj;
	struct module___134 *mod;
	struct kobject___152 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___131 {
	struct module___134 *mod;
	struct latch_tree_node node;
};

struct module_layout___131 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___131 mtn;
};

struct module_attribute___131;

struct module___134 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___131 mkobj;
	struct module_attribute___131 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___152 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___131 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___131 core_layout;
	struct module_layout___131 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___131 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___131 *, struct module_kobject___131 *, char *);
	ssize_t (*store)(struct module_attribute___131 *, struct module_kobject___131 *, const char *, size_t);
	void (*setup)(struct module___134 *, const char *);
	int (*test)(struct module___134 *);
	void (*free)(struct module___134 *);
};

struct dentry_operations___157;

struct super_block___157;

struct dentry___157 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___157 *d_parent;
	struct qstr d_name;
	struct inode___158 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___157 *d_op;
	struct super_block___157 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___157;

struct address_space___157 {
	struct inode___158 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___158 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___157 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___157;

struct block_device___158;

struct inode___158 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___157 *i_op;
	struct super_block___157 *i_sb;
	struct address_space___157 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___158 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___158 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___157 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___158 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___157 {
	int (*d_revalidate)(struct dentry___157 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___157 *, unsigned int);
	int (*d_hash)(const struct dentry___157 *, struct qstr *);
	int (*d_compare)(const struct dentry___157 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___157 *);
	int (*d_init)(struct dentry___157 *);
	void (*d_release)(struct dentry___157 *);
	void (*d_prune)(struct dentry___157 *);
	void (*d_iput)(struct dentry___157 *, struct inode___158 *);
	char * (*d_dname)(struct dentry___157 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___157 *);
	int (*d_manage)(const struct path___157 *, bool);
	struct dentry___157 * (*d_real)(struct dentry___157 *, const struct inode___158 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___157;

struct mem_dqinfo___157 {
	struct quota_format_type___157 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___157;

struct quota_info___157 {
	unsigned int flags;
	struct rw_semaphore___158 dqio_sem;
	struct inode___158 *files[3];
	struct mem_dqinfo___157 info[3];
	const struct quota_format_ops___157 *ops[3];
};

struct rcuwait___157 {
	struct task_struct___158 *task;
};

struct percpu_rw_semaphore___157 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___158 rw_sem;
	struct rcuwait___157 writer;
	int readers_block;
};

struct sb_writers___157 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___157 rw_sem[3];
};

struct file_system_type___157;

struct super_operations___157;

struct dquot_operations___157;

struct quotactl_ops___157;

struct export_operations___4;

struct super_block___157 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___157 *s_type;
	const struct super_operations___157 *s_op;
	const struct dquot_operations___157 *dq_op;
	const struct quotactl_ops___157 *s_qcop;
	const struct export_operations___4 *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___157 *s_root;
	struct rw_semaphore___158 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___158 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___157 s_dquot;
	struct sb_writers___157 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___157 *s_d_op;
	int cleancache_poolid;
	struct shrinker___71 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct core_state___157;

struct mm_struct___157 {
	struct {
		struct vm_area_struct___158 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___158 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___158 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___157 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___158 *owner;
		struct user_namespace___3 *user_ns;
		struct file___158 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___157 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___155)(struct vm_area_struct___158 *, long unsigned int, const struct page___158 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___155)(struct page___158 *, void *);

struct dev_pagemap___155 {
	dev_page_fault_t___155 page_fault;
	dev_page_free_t___155 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___6 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___157 {
	struct task_struct___158 *task;
	struct core_thread___157 *next;
};

struct core_state___157 {
	atomic_t nr_threads;
	struct core_thread___157 dumper;
	struct completion startup;
};

struct vm_fault___155 {
	struct vm_area_struct___158 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___158 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___158 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___157 prealloc_pte;
};

struct user_struct___153 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___153 *uid_keyring;
	struct key___153 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct kiocb___158 {
	struct file___158 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___158 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___157 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___158 *ia_file;
};

struct dquot___157 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___157 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___157 {
	int qf_fmt_id;
	const struct quota_format_ops___157 *qf_ops;
	struct module___134 *qf_owner;
	struct quota_format_type___157 *qf_next;
};

struct quota_format_ops___157 {
	int (*check_quota_file)(struct super_block___157 *, int);
	int (*read_file_info)(struct super_block___157 *, int);
	int (*write_file_info)(struct super_block___157 *, int);
	int (*free_file_info)(struct super_block___157 *, int);
	int (*read_dqblk)(struct dquot___157 *);
	int (*commit_dqblk)(struct dquot___157 *);
	int (*release_dqblk)(struct dquot___157 *);
	int (*get_next_id)(struct super_block___157 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___157 {
	int (*write_dquot)(struct dquot___157 *);
	struct dquot___157 * (*alloc_dquot)(struct super_block___157 *, int);
	void (*destroy_dquot)(struct dquot___157 *);
	int (*acquire_dquot)(struct dquot___157 *);
	int (*release_dquot)(struct dquot___157 *);
	int (*mark_dirty)(struct dquot___157 *);
	int (*write_info)(struct super_block___157 *, int);
	qsize_t * (*get_reserved_space)(struct inode___158 *);
	int (*get_projid)(struct inode___158 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___158 *, qsize_t *);
	int (*get_next_id)(struct super_block___157 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___157 {
	int (*quota_on)(struct super_block___157 *, int, int, const struct path___157 *);
	int (*quota_off)(struct super_block___157 *, int);
	int (*quota_enable)(struct super_block___157 *, unsigned int);
	int (*quota_disable)(struct super_block___157 *, unsigned int);
	int (*quota_sync)(struct super_block___157 *, int);
	int (*set_info)(struct super_block___157 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___157 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___157 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___157 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___157 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___157 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___157 {
	int (*writepage)(struct page___158 *, struct writeback_control___3 *);
	int (*readpage)(struct file___158 *, struct page___158 *);
	int (*writepages)(struct address_space___157 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___158 *);
	int (*readpages)(struct file___158 *, struct address_space___157 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___158 *, struct address_space___157 *, loff_t, unsigned int, unsigned int, struct page___158 **, void **);
	int (*write_end)(struct file___158 *, struct address_space___157 *, loff_t, unsigned int, unsigned int, struct page___158 *, void *);
	sector_t (*bmap)(struct address_space___157 *, sector_t);
	void (*invalidatepage)(struct page___158 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___158 *, gfp_t);
	void (*freepage)(struct page___158 *);
	ssize_t (*direct_IO)(struct kiocb___158 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___157 *, struct page___158 *, struct page___158 *, enum migrate_mode);
	bool (*isolate_page)(struct page___158 *, isolate_mode_t);
	void (*putback_page)(struct page___158 *);
	int (*launder_page)(struct page___158 *);
	int (*is_partially_uptodate)(struct page___158 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___158 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___157 *, struct page___158 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___158 *, sector_t *);
	void (*swap_deactivate)(struct file___158 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___158 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___158 *bd_inode;
	struct super_block___157 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___158 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___157 {
	struct dentry___157 * (*lookup)(struct inode___158 *, struct dentry___157 *, unsigned int);
	const char * (*get_link)(struct dentry___157 *, struct inode___158 *, struct delayed_call *);
	int (*permission)(struct inode___158 *, int);
	struct posix_acl * (*get_acl)(struct inode___158 *, int);
	int (*readlink)(struct dentry___157 *, char *, int);
	int (*create)(struct inode___158 *, struct dentry___157 *, umode_t, bool);
	int (*link)(struct dentry___157 *, struct inode___158 *, struct dentry___157 *);
	int (*unlink)(struct inode___158 *, struct dentry___157 *);
	int (*symlink)(struct inode___158 *, struct dentry___157 *, const char *);
	int (*mkdir)(struct inode___158 *, struct dentry___157 *, umode_t);
	int (*rmdir)(struct inode___158 *, struct dentry___157 *);
	int (*mknod)(struct inode___158 *, struct dentry___157 *, umode_t, dev_t);
	int (*rename)(struct inode___158 *, struct dentry___157 *, struct inode___158 *, struct dentry___157 *, unsigned int);
	int (*setattr)(struct dentry___157 *, struct iattr___157 *);
	int (*getattr)(const struct path___157 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___157 *, char *, size_t);
	int (*fiemap)(struct inode___158 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___158 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___158 *, struct dentry___157 *, struct file___158 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___158 *, struct dentry___157 *, umode_t);
	int (*set_acl)(struct inode___158 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___157 {
	void (*fl_copy_lock)(struct file_lock___158 *, struct file_lock___158 *);
	void (*fl_release_private)(struct file_lock___158 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___157;

struct lock_manager_operations___157;

struct file_lock___158 {
	struct file_lock___158 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___158 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___157 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___157 *fl_ops;
	const struct lock_manager_operations___157 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___157 {
	int (*lm_compare_owner)(struct file_lock___158 *, struct file_lock___158 *);
	long unsigned int (*lm_owner_key)(struct file_lock___158 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___158 *);
	int (*lm_grant)(struct file_lock___158 *, int);
	bool (*lm_break)(struct file_lock___158 *);
	int (*lm_change)(struct file_lock___158 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___158 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___157 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___157 *fa_next;
	struct file___158 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___157 {
	const char *name;
	int fs_flags;
	struct dentry___157 * (*mount)(struct file_system_type___157 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___157 *);
	struct module___134 *owner;
	struct file_system_type___157 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___157 {
	struct inode___158 * (*alloc_inode)(struct super_block___157 *);
	void (*destroy_inode)(struct inode___158 *);
	void (*dirty_inode)(struct inode___158 *, int);
	int (*write_inode)(struct inode___158 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___158 *);
	void (*evict_inode)(struct inode___158 *);
	void (*put_super)(struct super_block___157 *);
	int (*sync_fs)(struct super_block___157 *, int);
	int (*freeze_super)(struct super_block___157 *);
	int (*freeze_fs)(struct super_block___157 *);
	int (*thaw_super)(struct super_block___157 *);
	int (*unfreeze_fs)(struct super_block___157 *);
	int (*statfs)(struct dentry___157 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___157 *, int *, char *);
	void (*umount_begin)(struct super_block___157 *);
	int (*show_options)(struct seq_file___148 *, struct dentry___157 *);
	int (*show_devname)(struct seq_file___148 *, struct dentry___157 *);
	int (*show_path)(struct seq_file___148 *, struct dentry___157 *);
	int (*show_stats)(struct seq_file___148 *, struct dentry___157 *);
	ssize_t (*quota_read)(struct super_block___157 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___157 *, int, const char *, size_t, loff_t);
	struct dquot___157 ** (*get_dquots)(struct inode___158 *);
	int (*bdev_try_to_free_page)(struct super_block___157 *, struct page___158 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___157 *, struct shrink_control___71 *);
	long int (*free_cached_objects)(struct super_block___157 *, struct shrink_control___71 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct export_operations___4 {
	int (*encode_fh)(struct inode___158 *, __u32 *, int *, struct inode___158 *);
	struct dentry___157 * (*fh_to_dentry)(struct super_block___157 *, struct fid *, int, int);
	struct dentry___157 * (*fh_to_parent)(struct super_block___157 *, struct fid *, int, int);
	int (*get_name)(struct dentry___157 *, char *, struct dentry___157 *);
	struct dentry___157 * (*get_parent)(struct dentry___157 *);
	int (*commit_metadata)(struct inode___158 *);
	int (*get_uuid)(struct super_block___157 *, u8 *, u32 *, u64 *);
	int (*map_blocks)(struct inode___158 *, loff_t, u64, struct iomap *, bool, u32 *);
	int (*commit_blocks)(struct inode___158 *, struct iomap *, int, struct iattr___157 *);
};

typedef void compound_page_dtor___155(struct page___158 *);

typedef int (*key_restrict_link_func_t___153)(struct key___153 *, const struct key_type *, const union key_payload *, struct key___153 *);

struct key_restriction___153;

struct key___153 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___158 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___153 *restrict_link;
};

struct key_restriction___153 {
	key_restrict_link_func_t___153 check;
	struct key___153 *key;
	struct key_type *keytype;
};

struct seq_operations___146 {
	void * (*start)(struct seq_file___148 *, loff_t *);
	void (*stop)(struct seq_file___148 *, void *);
	void * (*next)(struct seq_file___148 *, void *, loff_t *);
	int (*show)(struct seq_file___148 *, void *);
};

struct cleancache_filekey {
	union {
		ino_t ino;
		__u32 fh[6];
		u32 key[6];
	} u;
};

struct cleancache_ops {
	int (*init_fs)(size_t);
	int (*init_shared_fs)(uuid_t *, size_t);
	int (*get_page)(int, struct cleancache_filekey, long unsigned int, struct page___158 *);
	void (*put_page)(int, struct cleancache_filekey, long unsigned int, struct page___158 *);
	void (*invalidate_page)(int, struct cleancache_filekey, long unsigned int);
	void (*invalidate_inode)(int, struct cleancache_filekey);
	void (*invalidate_fs)(int);
};

struct module___135;

struct file___159;

struct kiocb___159;

struct poll_table_struct___107;

struct vm_area_struct___159;

struct inode___159;

struct file_lock___159;

struct page___159;

struct seq_file___149;

struct file_operations___159 {
	struct module___135 *owner;
	loff_t (*llseek)(struct file___159 *, loff_t, int);
	ssize_t (*read)(struct file___159 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___159 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___159 *, struct iov_iter___72 *);
	ssize_t (*write_iter)(struct kiocb___159 *, struct iov_iter___72 *);
	int (*iopoll)(struct kiocb___159 *, bool);
	int (*iterate)(struct file___159 *, struct dir_context *);
	int (*iterate_shared)(struct file___159 *, struct dir_context *);
	__poll_t (*poll)(struct file___159 *, struct poll_table_struct___107 *);
	long int (*unlocked_ioctl)(struct file___159 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___159 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___159 *, struct vm_area_struct___159 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___159 *, struct file___159 *);
	int (*flush)(struct file___159 *, fl_owner_t);
	int (*release)(struct inode___159 *, struct file___159 *);
	int (*fsync)(struct file___159 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___159 *, int);
	int (*lock)(struct file___159 *, int, struct file_lock___159 *);
	ssize_t (*sendpage)(struct file___159 *, struct page___159 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___159 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___159 *, int, struct file_lock___159 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___159 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___159 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___159 *, long int, struct file_lock___159 **, void **);
	long int (*fallocate)(struct file___159 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___149 *, struct file___159 *);
	ssize_t (*copy_file_range)(struct file___159 *, loff_t, struct file___159 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___159 *, loff_t, struct file___159 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___159 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___158 {
	u64 seqnum;
	struct vm_area_struct___159 *vmas[4];
};

struct page_frag___158 {
	struct page___159 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___97;

struct debug_info___97 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___97 *hbp_break[16];
	struct perf_event___97 *hbp_watch[16];
};

struct thread_struct___97 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___97 debug;
	long: 64;
};

struct mm_struct___158;

struct pid___125;

struct cred___154;

struct nsproxy___150;

struct signal_struct___141;

struct css_set___134;

struct perf_event_context___97;

struct task_struct___159 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___159 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___158 *mm;
	struct mm_struct___158 *active_mm;
	struct vmacache___158 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___159 *real_parent;
	struct task_struct___159 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___159 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___125 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___125 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___125 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___154 *ptracer_cred;
	const struct cred___154 *real_cred;
	const struct cred___154 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___150 *nsproxy;
	struct signal_struct___141 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___159 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___38 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___134 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___97 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___158 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___159 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___97 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___97 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___159 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___97)(struct perf_event___97 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___97;

struct fasync_struct___158;

struct pid_namespace___125;

struct trace_event_call___90;

struct perf_cgroup___97;

struct perf_event___97 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___97 *group_leader;
	struct pmu___97 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___97 hw;
	struct perf_event_context___97 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___97 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___159 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___158 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___97 *);
	struct callback_head callback_head;
	struct pid_namespace___125 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___97 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___97 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___90 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___97 *cgrp;
	struct list_head sb_list;
};

typedef struct page___159 *pgtable_t___158;

struct address_space___158;

struct dev_pagemap___156;

struct page___159 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___158 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___159 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___158 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___158 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___156 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___158;

struct lruvec___158 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___158 *pgdat;
};

struct zone___158 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___158 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___158 {
	struct zone___158 *zone;
	int zone_idx;
};

struct zonelist___158 {
	struct zoneref___158 _zonerefs[25];
};

struct pglist_data___158 {
	struct zone___158 node_zones[3];
	struct zonelist___158 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___159 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___159 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___158 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___159 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___159 *owner;
};

struct secondary_data___159 {
	void *stack;
	struct task_struct___159 *task;
	long int status;
};

struct blocking_notifier_head___158 {
	struct rw_semaphore___159 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___156;

struct vm_area_struct___159 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___159 *vm_next;
	struct vm_area_struct___159 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___158 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___156 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___159 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___158;

struct user_namespace___138;

struct mm_struct___158 {
	struct {
		struct vm_area_struct___159 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___159 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___159 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___158 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___159 *owner;
		struct user_namespace___138 *user_ns;
		struct file___159 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___158 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___158;

struct address_space___158 {
	struct inode___159 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___159 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___158 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___156)(struct vm_area_struct___159 *, long unsigned int, const struct page___159 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___156)(struct page___159 *, void *);

struct device___148;

struct dev_pagemap___156 {
	dev_page_fault_t___156 page_fault;
	dev_page_free_t___156 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___148 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct dentry___158;

struct path___158 {
	struct vfsmount *mnt;
	struct dentry___158 *dentry;
};

struct fown_struct___125 {
	rwlock_t lock;
	struct pid___125 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___159 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___158 f_path;
	struct inode___159 *f_inode;
	const struct file_operations___159 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___125 f_owner;
	const struct cred___154 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___158 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___156;

struct vm_operations_struct___156 {
	void (*open)(struct vm_area_struct___159 *);
	void (*close)(struct vm_area_struct___159 *);
	int (*split)(struct vm_area_struct___159 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___159 *);
	vm_fault_t (*fault)(struct vm_fault___156 *);
	vm_fault_t (*huge_fault)(struct vm_fault___156 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___156 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___159 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___156 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___156 *);
	int (*access)(struct vm_area_struct___159 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___159 *);
	int (*set_policy)(struct vm_area_struct___159 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___159 *, long unsigned int);
	struct page___159 * (*find_special_page)(struct vm_area_struct___159 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___158 {
	struct task_struct___159 *task;
	struct core_thread___158 *next;
};

struct core_state___158 {
	atomic_t nr_threads;
	struct core_thread___158 dumper;
	struct completion startup;
};

struct key___154;

struct ucounts___138;

struct user_namespace___138 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___138 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___4 ns;
	long unsigned int flags;
	struct key___154 *persistent_keyring_register;
	struct rw_semaphore___159 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___138 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___156 {
	struct vm_area_struct___159 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___159 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___159 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___158 prealloc_pte;
};

struct upid___125 {
	int nr;
	struct pid_namespace___125 *ns;
};

struct pid_namespace___125 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___159 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___125 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___158 *proc_self;
	struct dentry___158 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___138 *user_ns;
	struct ucounts___138 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___4 ns;
};

struct pid___125 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___125 numbers[1];
};

struct user_struct___154 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___154 *uid_keyring;
	struct key___154 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___154 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___154 *session_keyring;
	struct key___154 *process_keyring;
	struct key___154 *thread_keyring;
	struct key___154 *request_key_auth;
	void *security;
	struct user_struct___154 *user;
	struct user_namespace___138 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___134;

struct nsproxy___150 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___125 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___134 *cgroup_ns;
};

struct signal_struct___141 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___159 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___159 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___125 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___125 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___158 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___125 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___134;

struct cgroup___134;

struct css_set___134 {
	struct cgroup_subsys_state___134 *subsys[13];
	refcount_t refcount;
	struct css_set___134 *dom_cset;
	struct cgroup___134 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___134 *mg_src_cgrp;
	struct cgroup___134 *mg_dst_cgrp;
	struct css_set___134 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___97 {
	struct pmu___97 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___159 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___97 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

union thread_union___142 {
	struct task_struct___159 task;
	long unsigned int stack[8192];
};

struct kset___152;

struct kobj_type___152;

struct kernfs_node___155;

struct kobject___153 {
	const char *name;
	struct list_head entry;
	struct kobject___153 *parent;
	struct kset___152 *kset;
	struct kobj_type___152 *ktype;
	struct kernfs_node___155 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___148 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___148 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___148;

struct bus_type___148;

struct device_driver___148;

struct dev_pm_domain___148;

struct class___148;

struct attribute_group___148;

struct device___148 {
	struct device___148 *parent;
	struct device_private *p;
	struct kobject___153 kobj;
	const char *init_name;
	const struct device_type___148 *type;
	struct mutex mutex;
	struct bus_type___148 *bus;
	struct device_driver___148 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___148 power;
	struct dev_pm_domain___148 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___148 *class;
	const struct attribute_group___148 **groups;
	void (*release)(struct device___148 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___158;

struct super_block___158;

struct dentry___158 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___158 *d_parent;
	struct qstr d_name;
	struct inode___159 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___158 *d_op;
	struct super_block___158 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___158;

struct block_device___159;

struct inode___159 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___158 *i_op;
	struct super_block___158 *i_sb;
	struct address_space___158 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___159 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___159 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___158 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___159 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___158 {
	int (*d_revalidate)(struct dentry___158 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___158 *, unsigned int);
	int (*d_hash)(const struct dentry___158 *, struct qstr *);
	int (*d_compare)(const struct dentry___158 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___158 *);
	int (*d_init)(struct dentry___158 *);
	void (*d_release)(struct dentry___158 *);
	void (*d_prune)(struct dentry___158 *);
	void (*d_iput)(struct dentry___158 *, struct inode___159 *);
	char * (*d_dname)(struct dentry___158 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___158 *);
	int (*d_manage)(const struct path___158 *, bool);
	struct dentry___158 * (*d_real)(struct dentry___158 *, const struct inode___159 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___158;

struct mem_dqinfo___158 {
	struct quota_format_type___158 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___158;

struct quota_info___158 {
	unsigned int flags;
	struct rw_semaphore___159 dqio_sem;
	struct inode___159 *files[3];
	struct mem_dqinfo___158 info[3];
	const struct quota_format_ops___158 *ops[3];
};

struct rcuwait___158 {
	struct task_struct___159 *task;
};

struct percpu_rw_semaphore___158 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___159 rw_sem;
	struct rcuwait___158 writer;
	int readers_block;
};

struct sb_writers___158 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___158 rw_sem[3];
};

struct file_system_type___158;

struct super_operations___158;

struct dquot_operations___158;

struct quotactl_ops___158;

struct super_block___158 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___158 *s_type;
	const struct super_operations___158 *s_op;
	const struct dquot_operations___158 *dq_op;
	const struct quotactl_ops___158 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___158 *s_root;
	struct rw_semaphore___159 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___159 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___158 s_dquot;
	struct sb_writers___158 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___158 *s_d_op;
	int cleancache_poolid;
	struct shrinker___71 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___138 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___159 {
	struct file___159 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___159 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___158 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___159 *ia_file;
};

struct dquot___158 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___158 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___158 {
	int qf_fmt_id;
	const struct quota_format_ops___158 *qf_ops;
	struct module___135 *qf_owner;
	struct quota_format_type___158 *qf_next;
};

struct quota_format_ops___158 {
	int (*check_quota_file)(struct super_block___158 *, int);
	int (*read_file_info)(struct super_block___158 *, int);
	int (*write_file_info)(struct super_block___158 *, int);
	int (*free_file_info)(struct super_block___158 *, int);
	int (*read_dqblk)(struct dquot___158 *);
	int (*commit_dqblk)(struct dquot___158 *);
	int (*release_dqblk)(struct dquot___158 *);
	int (*get_next_id)(struct super_block___158 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___158 {
	int (*write_dquot)(struct dquot___158 *);
	struct dquot___158 * (*alloc_dquot)(struct super_block___158 *, int);
	void (*destroy_dquot)(struct dquot___158 *);
	int (*acquire_dquot)(struct dquot___158 *);
	int (*release_dquot)(struct dquot___158 *);
	int (*mark_dirty)(struct dquot___158 *);
	int (*write_info)(struct super_block___158 *, int);
	qsize_t * (*get_reserved_space)(struct inode___159 *);
	int (*get_projid)(struct inode___159 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___159 *, qsize_t *);
	int (*get_next_id)(struct super_block___158 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___158 {
	int (*quota_on)(struct super_block___158 *, int, int, const struct path___158 *);
	int (*quota_off)(struct super_block___158 *, int);
	int (*quota_enable)(struct super_block___158 *, unsigned int);
	int (*quota_disable)(struct super_block___158 *, unsigned int);
	int (*quota_sync)(struct super_block___158 *, int);
	int (*set_info)(struct super_block___158 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___158 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___158 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___158 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___158 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___158 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___132 {
	struct kobject___153 kobj;
	struct module___135 *mod;
	struct kobject___153 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___132 {
	struct module___135 *mod;
	struct latch_tree_node node;
};

struct module_layout___132 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___132 mtn;
};

struct module_attribute___132;

struct kernel_param___132;

struct module___135 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___132 mkobj;
	struct module_attribute___132 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___153 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___132 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___132 core_layout;
	struct module_layout___132 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___90 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___158 {
	int (*writepage)(struct page___159 *, struct writeback_control___3 *);
	int (*readpage)(struct file___159 *, struct page___159 *);
	int (*writepages)(struct address_space___158 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___159 *);
	int (*readpages)(struct file___159 *, struct address_space___158 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___159 *, struct address_space___158 *, loff_t, unsigned int, unsigned int, struct page___159 **, void **);
	int (*write_end)(struct file___159 *, struct address_space___158 *, loff_t, unsigned int, unsigned int, struct page___159 *, void *);
	sector_t (*bmap)(struct address_space___158 *, sector_t);
	void (*invalidatepage)(struct page___159 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___159 *, gfp_t);
	void (*freepage)(struct page___159 *);
	ssize_t (*direct_IO)(struct kiocb___159 *, struct iov_iter___72 *);
	int (*migratepage)(struct address_space___158 *, struct page___159 *, struct page___159 *, enum migrate_mode);
	bool (*isolate_page)(struct page___159 *, isolate_mode_t);
	void (*putback_page)(struct page___159 *);
	int (*launder_page)(struct page___159 *);
	int (*is_partially_uptodate)(struct page___159 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___159 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___158 *, struct page___159 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___159 *, sector_t *);
	void (*swap_deactivate)(struct file___159 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___159 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___159 *bd_inode;
	struct super_block___158 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___159 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___158 {
	struct dentry___158 * (*lookup)(struct inode___159 *, struct dentry___158 *, unsigned int);
	const char * (*get_link)(struct dentry___158 *, struct inode___159 *, struct delayed_call *);
	int (*permission)(struct inode___159 *, int);
	struct posix_acl * (*get_acl)(struct inode___159 *, int);
	int (*readlink)(struct dentry___158 *, char *, int);
	int (*create)(struct inode___159 *, struct dentry___158 *, umode_t, bool);
	int (*link)(struct dentry___158 *, struct inode___159 *, struct dentry___158 *);
	int (*unlink)(struct inode___159 *, struct dentry___158 *);
	int (*symlink)(struct inode___159 *, struct dentry___158 *, const char *);
	int (*mkdir)(struct inode___159 *, struct dentry___158 *, umode_t);
	int (*rmdir)(struct inode___159 *, struct dentry___158 *);
	int (*mknod)(struct inode___159 *, struct dentry___158 *, umode_t, dev_t);
	int (*rename)(struct inode___159 *, struct dentry___158 *, struct inode___159 *, struct dentry___158 *, unsigned int);
	int (*setattr)(struct dentry___158 *, struct iattr___158 *);
	int (*getattr)(const struct path___158 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___158 *, char *, size_t);
	int (*fiemap)(struct inode___159 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___159 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___159 *, struct dentry___158 *, struct file___159 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___159 *, struct dentry___158 *, umode_t);
	int (*set_acl)(struct inode___159 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___158 {
	void (*fl_copy_lock)(struct file_lock___159 *, struct file_lock___159 *);
	void (*fl_release_private)(struct file_lock___159 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___158;

struct file_lock___159 {
	struct file_lock___159 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___159 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___158 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___158 *fl_ops;
	const struct lock_manager_operations___158 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___158 {
	int (*lm_compare_owner)(struct file_lock___159 *, struct file_lock___159 *);
	long unsigned int (*lm_owner_key)(struct file_lock___159 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___159 *);
	int (*lm_grant)(struct file_lock___159 *, int);
	bool (*lm_break)(struct file_lock___159 *);
	int (*lm_change)(struct file_lock___159 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___159 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___158 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___158 *fa_next;
	struct file___159 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___158 {
	const char *name;
	int fs_flags;
	struct dentry___158 * (*mount)(struct file_system_type___158 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___158 *);
	struct module___135 *owner;
	struct file_system_type___158 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___158 {
	struct inode___159 * (*alloc_inode)(struct super_block___158 *);
	void (*destroy_inode)(struct inode___159 *);
	void (*dirty_inode)(struct inode___159 *, int);
	int (*write_inode)(struct inode___159 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___159 *);
	void (*evict_inode)(struct inode___159 *);
	void (*put_super)(struct super_block___158 *);
	int (*sync_fs)(struct super_block___158 *, int);
	int (*freeze_super)(struct super_block___158 *);
	int (*freeze_fs)(struct super_block___158 *);
	int (*thaw_super)(struct super_block___158 *);
	int (*unfreeze_fs)(struct super_block___158 *);
	int (*statfs)(struct dentry___158 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___158 *, int *, char *);
	void (*umount_begin)(struct super_block___158 *);
	int (*show_options)(struct seq_file___149 *, struct dentry___158 *);
	int (*show_devname)(struct seq_file___149 *, struct dentry___158 *);
	int (*show_path)(struct seq_file___149 *, struct dentry___158 *);
	int (*show_stats)(struct seq_file___149 *, struct dentry___158 *);
	ssize_t (*quota_read)(struct super_block___158 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___158 *, int, const char *, size_t, loff_t);
	struct dquot___158 ** (*get_dquots)(struct inode___159 *);
	int (*bdev_try_to_free_page)(struct super_block___158 *, struct page___159 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___158 *, struct shrink_control___71 *);
	long int (*free_cached_objects)(struct super_block___158 *, struct shrink_control___71 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___106)(struct file___159 *, wait_queue_head_t *, struct poll_table_struct___107 *);

struct poll_table_struct___107 {
	poll_queue_proc___106 _qproc;
	__poll_t _key;
};

struct seq_operations___147;

struct seq_file___149 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___147 *op;
	int poll_event;
	const struct file___159 *file;
	void *private;
};

struct kobj_attribute___153 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___153 *, struct kobj_attribute___153 *, char *);
	ssize_t (*store)(struct kobject___153 *, struct kobj_attribute___153 *, const char *, size_t);
};

typedef void compound_page_dtor___156(struct page___159 *);

struct kernfs_root___155;

struct kernfs_elem_dir___155 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___155 *root;
};

struct kernfs_syscall_ops___155;

struct kernfs_root___155 {
	struct kernfs_node___155 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___155 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___155 {
	struct kernfs_node___155 *target_kn;
};

struct kernfs_ops___155;

struct kernfs_elem_attr___155 {
	const struct kernfs_ops___155 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___155 *notify_next;
};

struct kernfs_node___155 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___155 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___155 dir;
		struct kernfs_elem_symlink___155 symlink;
		struct kernfs_elem_attr___155 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___155;

struct kernfs_ops___155 {
	int (*open)(struct kernfs_open_file___155 *);
	void (*release)(struct kernfs_open_file___155 *);
	int (*seq_show)(struct seq_file___149 *, void *);
	void * (*seq_start)(struct seq_file___149 *, loff_t *);
	void * (*seq_next)(struct seq_file___149 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___149 *, void *);
	ssize_t (*read)(struct kernfs_open_file___155 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___155 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___155 *, struct vm_area_struct___159 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___155 *, struct poll_table_struct___107 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___155 {
	int (*remount_fs)(struct kernfs_root___155 *, int *, char *);
	int (*show_options)(struct seq_file___149 *, struct kernfs_root___155 *);
	int (*mkdir)(struct kernfs_node___155 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___155 *);
	int (*rename)(struct kernfs_node___155 *, struct kernfs_node___155 *, const char *);
	int (*show_path)(struct seq_file___149 *, struct kernfs_node___155 *, struct kernfs_root___155 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___155 {
	struct kernfs_node___155 *kn;
	struct file___159 *file;
	struct seq_file___149 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___156 *vm_ops;
};

struct bin_attribute___147;

struct attribute_group___148 {
	const char *name;
	umode_t (*is_visible)(struct kobject___153 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___153 *, struct bin_attribute___147 *, int);
	struct attribute **attrs;
	struct bin_attribute___147 **bin_attrs;
};

struct bin_attribute___147 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___159 *, struct kobject___153 *, struct bin_attribute___147 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___159 *, struct kobject___153 *, struct bin_attribute___147 *, char *, loff_t, size_t);
	int (*mmap)(struct file___159 *, struct kobject___153 *, struct bin_attribute___147 *, struct vm_area_struct___159 *);
};

struct sysfs_ops___152 {
	ssize_t (*show)(struct kobject___153 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___153 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___152;

struct kset___152 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___153 kobj;
	const struct kset_uevent_ops___152 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___152 {
	void (*release)(struct kobject___153 *);
	const struct sysfs_ops___152 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___10 * (*child_ns_type)(struct kobject___153 *);
	const void * (*namespace)(struct kobject___153 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___152 {
	int (* const filter)(struct kset___152 *, struct kobject___153 *);
	const char * (* const name)(struct kset___152 *, struct kobject___153 *);
	int (* const uevent)(struct kset___152 *, struct kobject___153 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___148 {
	int (*prepare)(struct device___148 *);
	void (*complete)(struct device___148 *);
	int (*suspend)(struct device___148 *);
	int (*resume)(struct device___148 *);
	int (*freeze)(struct device___148 *);
	int (*thaw)(struct device___148 *);
	int (*poweroff)(struct device___148 *);
	int (*restore)(struct device___148 *);
	int (*suspend_late)(struct device___148 *);
	int (*resume_early)(struct device___148 *);
	int (*freeze_late)(struct device___148 *);
	int (*thaw_early)(struct device___148 *);
	int (*poweroff_late)(struct device___148 *);
	int (*restore_early)(struct device___148 *);
	int (*suspend_noirq)(struct device___148 *);
	int (*resume_noirq)(struct device___148 *);
	int (*freeze_noirq)(struct device___148 *);
	int (*thaw_noirq)(struct device___148 *);
	int (*poweroff_noirq)(struct device___148 *);
	int (*restore_noirq)(struct device___148 *);
	int (*runtime_suspend)(struct device___148 *);
	int (*runtime_resume)(struct device___148 *);
	int (*runtime_idle)(struct device___148 *);
};

struct dev_pm_domain___148 {
	struct dev_pm_ops___148 ops;
	void (*detach)(struct device___148 *, bool);
	int (*activate)(struct device___148 *);
	void (*sync)(struct device___148 *);
	void (*dismiss)(struct device___148 *);
};

struct bus_type___148 {
	const char *name;
	const char *dev_name;
	struct device___148 *dev_root;
	const struct attribute_group___148 **bus_groups;
	const struct attribute_group___148 **dev_groups;
	const struct attribute_group___148 **drv_groups;
	int (*match)(struct device___148 *, struct device_driver___148 *);
	int (*uevent)(struct device___148 *, struct kobj_uevent_env *);
	int (*probe)(struct device___148 *);
	int (*remove)(struct device___148 *);
	void (*shutdown)(struct device___148 *);
	int (*online)(struct device___148 *);
	int (*offline)(struct device___148 *);
	int (*suspend)(struct device___148 *, pm_message_t);
	int (*resume)(struct device___148 *);
	int (*num_vf)(struct device___148 *);
	int (*dma_configure)(struct device___148 *);
	const struct dev_pm_ops___148 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___148 {
	const char *name;
	struct bus_type___148 *bus;
	struct module___135 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___148 *);
	int (*remove)(struct device___148 *);
	void (*shutdown)(struct device___148 *);
	int (*suspend)(struct device___148 *, pm_message_t);
	int (*resume)(struct device___148 *);
	const struct attribute_group___148 **groups;
	const struct dev_pm_ops___148 *pm;
	void (*coredump)(struct device___148 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___148 {
	const char *name;
	const struct attribute_group___148 **groups;
	int (*uevent)(struct device___148 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___148 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___148 *);
	const struct dev_pm_ops___148 *pm;
};

struct class___148 {
	const char *name;
	struct module___135 *owner;
	const struct attribute_group___148 **class_groups;
	const struct attribute_group___148 **dev_groups;
	struct kobject___153 *dev_kobj;
	int (*dev_uevent)(struct device___148 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___148 *, umode_t *);
	void (*class_release)(struct class___148 *);
	void (*dev_release)(struct device___148 *);
	int (*shutdown_pre)(struct device___148 *);
	const struct kobj_ns_type_operations___10 *ns_type;
	const void * (*namespace)(struct device___148 *);
	const struct dev_pm_ops___148 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___126 {
	struct device___148 dev;
};

struct memory_isolate_notify {
	long unsigned int start_pfn;
	unsigned int nr_pages;
	unsigned int pages_found;
};

typedef int (*key_restrict_link_func_t___154)(struct key___154 *, const struct key_type *, const union key_payload *, struct key___154 *);

struct key_restriction___154;

struct key___154 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___159 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___154 *restrict_link;
};

struct key_restriction___154 {
	key_restrict_link_func_t___154 check;
	struct key___154 *key;
	struct key_type *keytype;
};

struct seq_operations___147 {
	void * (*start)(struct seq_file___149 *, loff_t *);
	void (*stop)(struct seq_file___149 *, void *);
	void * (*next)(struct seq_file___149 *, void *, loff_t *);
	int (*show)(struct seq_file___149 *, void *);
};

struct cgroup_namespace___134 {
	refcount_t count;
	struct ns_common___4 ns;
	struct user_namespace___138 *user_ns;
	struct ucounts___138 *ucounts;
	struct css_set___134 *root_cset;
};

struct ucounts___138 {
	struct hlist_node node;
	struct user_namespace___138 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___134;

struct bpf_map_ops___134 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___134 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___134 *, struct file___159 *);
	void (*map_free)(struct bpf_map___134 *);
	int (*map_get_next_key)(struct bpf_map___134 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___134 *);
	void * (*map_lookup_elem)(struct bpf_map___134 *, void *);
	int (*map_update_elem)(struct bpf_map___134 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___134 *, void *);
	int (*map_push_elem)(struct bpf_map___134 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___134 *, void *);
	int (*map_peek_elem)(struct bpf_map___134 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___134 *, struct file___159 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___134 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___134 *, void *, struct seq_file___149 *);
	int (*map_check_btf)(const struct bpf_map___134 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___134 {
	const struct bpf_map_ops___134 *ops;
	struct bpf_map___134 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___154 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___134;

typedef void (*kthread_work_func_t___134)(struct kthread_work___134 *);

struct kthread_worker___134;

struct kthread_work___134 {
	struct list_head node;
	kthread_work_func_t___134 func;
	struct kthread_worker___134 *worker;
	int canceling;
};

struct kthread_worker___134 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___159 *task;
	struct kthread_work___134 *current_work;
};

struct kthread_delayed_work___134 {
	struct kthread_work___134 work;
	struct timer_list timer;
};

struct psi_group___134 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___134 *poll_kworker;
	struct kthread_delayed_work___134 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___134 {
	struct kernfs_node___155 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___134;

struct cgroup_subsys_state___134 {
	struct cgroup___134 *cgroup;
	struct cgroup_subsys___134 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___134 *parent;
};

struct cgroup_root___134;

struct cgroup_rstat_cpu___134;

struct cgroup___134 {
	struct cgroup_subsys_state___134 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___155 *kn;
	struct cgroup_file___134 procs_file;
	struct cgroup_file___134 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___134 *subsys[13];
	struct cgroup_root___134 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___134 *dom_cgrp;
	struct cgroup_rstat_cpu___134 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___20 bpf;
	atomic_t congestion_count;
	struct cgroup___134 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___134 psi;
	int ancestor_ids[0];
};

struct cftype___134;

struct cgroup_subsys___134 {
	struct cgroup_subsys_state___134 * (*css_alloc)(struct cgroup_subsys_state___134 *);
	int (*css_online)(struct cgroup_subsys_state___134 *);
	void (*css_offline)(struct cgroup_subsys_state___134 *);
	void (*css_released)(struct cgroup_subsys_state___134 *);
	void (*css_free)(struct cgroup_subsys_state___134 *);
	void (*css_reset)(struct cgroup_subsys_state___134 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___134 *, int);
	int (*css_extra_stat_show)(struct seq_file___149 *, struct cgroup_subsys_state___134 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___159 *);
	void (*cancel_fork)(struct task_struct___159 *);
	void (*fork)(struct task_struct___159 *);
	void (*exit)(struct task_struct___159 *);
	void (*free)(struct task_struct___159 *);
	void (*bind)(struct cgroup_subsys_state___134 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___134 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___134 *dfl_cftypes;
	struct cftype___134 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___134 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___134 *updated_children;
	struct cgroup___134 *updated_next;
};

struct cgroup_root___134 {
	struct kernfs_root___155 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___134 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___134 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___134 *ss;
	struct list_head node;
	struct kernfs_ops___155 *kf_ops;
	int (*open)(struct kernfs_open_file___155 *);
	void (*release)(struct kernfs_open_file___155 *);
	u64 (*read_u64)(struct cgroup_subsys_state___134 *, struct cftype___134 *);
	s64 (*read_s64)(struct cgroup_subsys_state___134 *, struct cftype___134 *);
	int (*seq_show)(struct seq_file___149 *, void *);
	void * (*seq_start)(struct seq_file___149 *, loff_t *);
	void * (*seq_next)(struct seq_file___149 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___149 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___134 *, struct cftype___134 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___134 *, struct cftype___134 *, s64);
	ssize_t (*write)(struct kernfs_open_file___155 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___155 *, struct poll_table_struct___107 *);
};

struct hstate___32 {
	int next_nid_to_alloc;
	int next_nid_to_free;
	unsigned int order;
	long unsigned int mask;
	long unsigned int max_huge_pages;
	long unsigned int nr_huge_pages;
	long unsigned int free_huge_pages;
	long unsigned int resv_huge_pages;
	long unsigned int surplus_huge_pages;
	long unsigned int nr_overcommit_huge_pages;
	struct list_head hugepage_activelist;
	struct list_head hugepage_freelists[8];
	unsigned int nr_huge_pages_node[8];
	unsigned int free_huge_pages_node[8];
	unsigned int surplus_huge_pages_node[8];
	struct cftype___134 cgroup_files[5];
	char name[32];
};

struct kernel_param_ops___132 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___132 *);
	int (*get)(char *, const struct kernel_param___132 *);
	void (*free)(void *);
};

struct kparam_array___132;

struct kernel_param___132 {
	const char *name;
	struct module___135 *mod;
	const struct kernel_param_ops___132 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___132 *arr;
	};
};

struct kparam_array___132 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___132 *ops;
	void *elem;
};

struct module_attribute___132 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___132 *, struct module_kobject___132 *, char *);
	ssize_t (*store)(struct module_attribute___132 *, struct module_kobject___132 *, const char *, size_t);
	void (*setup)(struct module___135 *, const char *);
	int (*test)(struct module___135 *);
	void (*free)(struct module___135 *);
};

struct trace_event_class___90;

struct trace_event_call___90 {
	struct list_head list;
	struct trace_event_class___90 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___20 *prog_array;
	int (*perf_perm)(struct trace_event_call___90 *, struct perf_event___97 *);
};

struct perf_cpu_context___97;

struct pmu___97 {
	struct list_head entry;
	struct module___135 *module;
	struct device___148 *dev;
	const struct attribute_group___148 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___97 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___97 *);
	void (*pmu_disable)(struct pmu___97 *);
	int (*event_init)(struct perf_event___97 *);
	void (*event_mapped)(struct perf_event___97 *, struct mm_struct___158 *);
	void (*event_unmapped)(struct perf_event___97 *, struct mm_struct___158 *);
	int (*add)(struct perf_event___97 *, int);
	void (*del)(struct perf_event___97 *, int);
	void (*start)(struct perf_event___97 *, int);
	void (*stop)(struct perf_event___97 *, int);
	void (*read)(struct perf_event___97 *);
	void (*start_txn)(struct pmu___97 *, unsigned int);
	int (*commit_txn)(struct pmu___97 *);
	void (*cancel_txn)(struct pmu___97 *);
	int (*event_idx)(struct perf_event___97 *);
	void (*sched_task)(struct perf_event_context___97 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___97 *);
	int (*filter_match)(struct perf_event___97 *);
	int (*check_period)(struct perf_event___97 *, u64);
};

struct perf_cpu_context___97 {
	struct perf_event_context___97 ctx;
	struct perf_event_context___97 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___97 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___97 {
	struct cgroup_subsys_state___134 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___90 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___90 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___90 *);
	struct list_head * (*get_fields)(struct trace_event_call___90 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___90 *);
};

struct trace_event_file___42;

struct trace_event_buffer___34 {
	struct ring_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___42 *trace_file;
	void *entry;
	long unsigned int flags;
	int pc;
};

struct trace_event_file___42 {
	struct list_head list;
	struct trace_event_call___90 *event_call;
	struct event_filter *filter;
	struct dentry___158 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_test_pages_isolated {
	struct trace_entry ent;
	long unsigned int start_pfn;
	long unsigned int end_pfn;
	long unsigned int fin_pfn;
	char __data[0];
};

struct trace_event_data_offsets_test_pages_isolated {};

struct zpool_driver;

struct zpool {
	struct zpool_driver *driver;
	void *pool;
	const struct zpool_ops *ops;
	bool evictable;
	struct list_head list;
};

struct zpool_driver {
	char *type;
	struct module___118 *owner;
	atomic_t refcount;
	struct list_head list;
	void * (*create)(const char *, gfp_t, const struct zpool_ops *, struct zpool *);
	void (*destroy)(void *);
	int (*malloc)(void *, size_t, gfp_t, long unsigned int *);
	void (*free)(void *, long unsigned int);
	int (*shrink)(void *, unsigned int, unsigned int *);
	void * (*map)(void *, long unsigned int, enum zpool_mapmode);
	void (*unmap)(void *, long unsigned int);
	u64 (*total_size)(void *);
};

struct zbud_pool;

struct zbud_ops {
	int (*evict)(struct zbud_pool *, long unsigned int);
};

struct zbud_pool {
	spinlock_t lock;
	struct list_head unbuddied[63];
	struct list_head buddied;
	struct list_head lru;
	u64 pages_nr;
	const struct zbud_ops *ops;
	struct zpool *zpool;
	const struct zpool_ops *zpool_ops;
};

struct zbud_header {
	struct list_head buddy;
	struct list_head lru;
	unsigned int first_chunks;
	unsigned int last_chunks;
	bool under_reclaim;
};

enum buddy {
	FIRST = 0,
	LAST = 1,
};

enum zs_mapmode {
	ZS_MM_RW = 0,
	ZS_MM_RO = 1,
	ZS_MM_WO = 2,
};

struct zs_pool_stats {
	long unsigned int pages_compacted;
};

struct zpool_driver___2 {
	char *type;
	struct module___33 *owner;
	atomic_t refcount;
	struct list_head list;
	void * (*create)(const char *, gfp_t, const struct zpool_ops *, struct zpool *);
	void (*destroy)(void *);
	int (*malloc)(void *, size_t, gfp_t, long unsigned int *);
	void (*free)(void *, long unsigned int);
	int (*shrink)(void *, unsigned int, unsigned int *);
	void * (*map)(void *, long unsigned int, enum zpool_mapmode);
	void (*unmap)(void *, long unsigned int);
	u64 (*total_size)(void *);
};

enum fullness_group {
	ZS_EMPTY = 0,
	ZS_ALMOST_EMPTY = 1,
	ZS_ALMOST_FULL = 2,
	ZS_FULL = 3,
	NR_ZS_FULLNESS = 4,
};

enum zs_stat_type {
	CLASS_EMPTY = 0,
	CLASS_ALMOST_EMPTY = 1,
	CLASS_ALMOST_FULL = 2,
	CLASS_FULL = 3,
	OBJ_ALLOCATED = 4,
	OBJ_USED = 5,
	NR_ZS_STAT_TYPE = 6,
};

struct zs_size_stat {
	long unsigned int objs[6];
};

struct size_class {
	spinlock_t lock;
	struct list_head fullness_list[4];
	int size;
	int objs_per_zspage;
	int pages_per_zspage;
	unsigned int index;
	struct zs_size_stat stats;
};

struct link_free {
	union {
		long unsigned int next;
		long unsigned int handle;
	};
};

struct zs_pool {
	const char *name;
	struct size_class *size_class[257];
	struct kmem_cache *handle_cachep;
	struct kmem_cache *zspage_cachep;
	atomic_long_t pages_allocated;
	struct zs_pool_stats stats;
	struct shrinker___13 shrinker;
	struct dentry___37 *stat_dentry;
	struct inode___38 *inode;
	struct work_struct free_work;
};

struct zspage {
	struct {
		unsigned int fullness: 2;
		unsigned int class: 9;
		unsigned int isolated: 3;
		unsigned int magic: 8;
	};
	unsigned int inuse;
	unsigned int freeobj;
	struct page___36 *first_page;
	struct list_head list;
	rwlock_t lock;
};

struct mapping_area {
	char *vm_buf;
	char *vm_addr;
	enum zs_mapmode vm_mm;
};

struct zs_compact_control {
	struct page___36 *s_page;
	struct page___36 *d_page;
	int obj_idx;
};

struct balloon_dev_info {
	long unsigned int isolated_pages;
	spinlock_t pages_lock;
	struct list_head pages;
	int (*migratepage)(struct balloon_dev_info *, struct page___159 *, struct page___159 *, enum migrate_mode);
	struct inode___159 *inode;
};

struct hugepage_subpool___7 {
	spinlock_t lock;
	long int count;
	long int max_hpages;
	long int used_hpages;
	struct hstate___16 *hstate;
	long int min_hpages;
	long int rsv_hpages;
};

struct hugetlbfs_sb_info___7 {
	long int max_inodes;
	long int free_inodes;
	spinlock_t stat_lock;
	struct hstate___16 *hstate;
	struct hugepage_subpool___7 *spool;
	kuid_t uid;
	kgid_t gid;
	umode_t mode;
};

struct file___160;

struct kiocb___160;

struct vm_area_struct___160;

struct inode___160;

struct file_lock___160;

struct page___160;

struct seq_file___150;

struct file_operations___160 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___160 *, loff_t, int);
	ssize_t (*read)(struct file___160 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___160 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___160 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___160 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___160 *, bool);
	int (*iterate)(struct file___160 *, struct dir_context *);
	int (*iterate_shared)(struct file___160 *, struct dir_context *);
	__poll_t (*poll)(struct file___160 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___160 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___160 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___160 *, struct vm_area_struct___160 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___160 *, struct file___160 *);
	int (*flush)(struct file___160 *, fl_owner_t);
	int (*release)(struct inode___160 *, struct file___160 *);
	int (*fsync)(struct file___160 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___160 *, int);
	int (*lock)(struct file___160 *, int, struct file_lock___160 *);
	ssize_t (*sendpage)(struct file___160 *, struct page___160 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___160 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___160 *, int, struct file_lock___160 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___160 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___160 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___160 *, long int, struct file_lock___160 **, void **);
	long int (*fallocate)(struct file___160 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___150 *, struct file___160 *);
	ssize_t (*copy_file_range)(struct file___160 *, loff_t, struct file___160 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___160 *, loff_t, struct file___160 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___160 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___159 {
	u64 seqnum;
	struct vm_area_struct___160 *vmas[4];
};

struct page_frag___159 {
	struct page___160 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___159;

struct mem_cgroup___72;

struct cred___155;

struct nsproxy___151;

struct bio_list___77;

struct backing_dev_info___77;

struct css_set___135;

struct task_struct___160 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___160 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___159 *mm;
	struct mm_struct___159 *active_mm;
	struct vmacache___159 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___160 *real_parent;
	struct task_struct___160 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___160 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___72 *active_memcg;
	long int rh_reserved2;
	struct pid___125 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___125 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___125 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___155 *ptracer_cred;
	const struct cred___155 *real_cred;
	const struct cred___155 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___151 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___160 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___77 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___77 *backing_dev_info;
	struct io_context___38 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___135 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___159 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___72 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___160 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___97 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___160 *pgtable_t___159;

struct address_space___159;

struct dev_pagemap___157;

struct page___160 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___159 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___160 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___159 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___159 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___157 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___72 *mem_cgroup;
};

struct pglist_data___159;

struct lruvec___159 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___159 *pgdat;
};

struct zone___159 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___159 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___159 {
	struct zone___159 *zone;
	int zone_idx;
};

struct zonelist___159 {
	struct zoneref___159 _zonerefs[25];
};

struct pglist_data___159 {
	struct zone___159 node_zones[3];
	struct zonelist___159 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___160 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___160 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___159 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___160 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___160 *owner;
};

struct secondary_data___160 {
	void *stack;
	struct task_struct___160 *task;
	long int status;
};

struct blocking_notifier_head___159 {
	struct rw_semaphore___160 rwsem;
	struct notifier_block *head;
};

struct anon_vma___19;

struct vm_operations_struct___157;

struct vm_area_struct___160 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___160 *vm_next;
	struct vm_area_struct___160 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___159 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma___19 *anon_vma;
	const struct vm_operations_struct___157 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___160 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___159;

struct user_namespace___139;

struct mm_struct___159 {
	struct {
		struct vm_area_struct___160 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___160 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___160 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___159 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___160 *owner;
		struct user_namespace___139 *user_ns;
		struct file___160 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___159 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___159;

struct address_space___159 {
	struct inode___160 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___160 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___159 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___157)(struct vm_area_struct___160 *, long unsigned int, const struct page___160 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___157)(struct page___160 *, void *);

struct dev_pagemap___157 {
	dev_page_fault_t___157 page_fault;
	dev_page_free_t___157 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___6 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct cgroup___135;

struct cgroup_subsys___135;

struct cgroup_subsys_state___135 {
	struct cgroup___135 *cgroup;
	struct cgroup_subsys___135 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___135 *parent;
};

struct kernfs_node___156;

struct cgroup_file___135 {
	struct kernfs_node___156 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___72;

struct mem_cgroup___72 {
	struct cgroup_subsys_state___135 css;
	struct mem_cgroup_id___6 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___135 events_file;
	struct cgroup_file___135 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___160 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___72 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry___159;

struct path___159 {
	struct vfsmount *mnt;
	struct dentry___159 *dentry;
};

struct file___160 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___159 f_path;
	struct inode___160 *f_inode;
	const struct file_operations___160 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___125 f_owner;
	const struct cred___155 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___159 *f_mapping;
	errseq_t f_wb_err;
};

struct anon_vma___19 {
	struct anon_vma___19 *root;
	struct rw_semaphore___160 rwsem;
	atomic_t refcount;
	unsigned int degree;
	struct anon_vma___19 *parent;
	struct rb_root_cached rb_root;
};

struct vm_fault___157;

struct vm_operations_struct___157 {
	void (*open)(struct vm_area_struct___160 *);
	void (*close)(struct vm_area_struct___160 *);
	int (*split)(struct vm_area_struct___160 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___160 *);
	vm_fault_t (*fault)(struct vm_fault___157 *);
	vm_fault_t (*huge_fault)(struct vm_fault___157 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___157 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___160 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___157 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___157 *);
	int (*access)(struct vm_area_struct___160 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___160 *);
	int (*set_policy)(struct vm_area_struct___160 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___160 *, long unsigned int);
	struct page___160 * (*find_special_page)(struct vm_area_struct___160 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___159 {
	struct task_struct___160 *task;
	struct core_thread___159 *next;
};

struct core_state___159 {
	atomic_t nr_threads;
	struct core_thread___159 dumper;
	struct completion startup;
};

struct key___155;

struct ucounts___139;

struct user_namespace___139 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___139 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___4 ns;
	long unsigned int flags;
	struct key___155 *persistent_keyring_register;
	struct rw_semaphore___160 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___139 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___157 {
	struct vm_area_struct___160 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___160 *cow_page;
	struct mem_cgroup___72 *memcg;
	struct page___160 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___159 prealloc_pte;
};

struct dentry_operations___159;

struct super_block___159;

struct dentry___159 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___159 *d_parent;
	struct qstr d_name;
	struct inode___160 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___159 *d_op;
	struct super_block___159 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___159;

struct bdi_writeback___77;

struct block_device___160;

struct inode___160 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___159 *i_op;
	struct super_block___159 *i_sb;
	struct address_space___159 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___160 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___77 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___160 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___159 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___160 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___159 {
	int (*d_revalidate)(struct dentry___159 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___159 *, unsigned int);
	int (*d_hash)(const struct dentry___159 *, struct qstr *);
	int (*d_compare)(const struct dentry___159 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___159 *);
	int (*d_init)(struct dentry___159 *);
	void (*d_release)(struct dentry___159 *);
	void (*d_prune)(struct dentry___159 *);
	void (*d_iput)(struct dentry___159 *, struct inode___160 *);
	char * (*d_dname)(struct dentry___159 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___159 *);
	int (*d_manage)(const struct path___159 *, bool);
	struct dentry___159 * (*d_real)(struct dentry___159 *, const struct inode___160 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___159;

struct mem_dqinfo___159 {
	struct quota_format_type___159 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___159;

struct quota_info___159 {
	unsigned int flags;
	struct rw_semaphore___160 dqio_sem;
	struct inode___160 *files[3];
	struct mem_dqinfo___159 info[3];
	const struct quota_format_ops___159 *ops[3];
};

struct rcuwait___159 {
	struct task_struct___160 *task;
};

struct percpu_rw_semaphore___159 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___160 rw_sem;
	struct rcuwait___159 writer;
	int readers_block;
};

struct sb_writers___159 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___159 rw_sem[3];
};

struct shrink_control___72;

struct shrinker___72 {
	long unsigned int (*count_objects)(struct shrinker___72 *, struct shrink_control___72 *);
	long unsigned int (*scan_objects)(struct shrinker___72 *, struct shrink_control___72 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___159;

struct super_operations___159;

struct dquot_operations___159;

struct quotactl_ops___159;

struct super_block___159 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___159 *s_type;
	const struct super_operations___159 *s_op;
	const struct dquot_operations___159 *dq_op;
	const struct quotactl_ops___159 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___159 *s_root;
	struct rw_semaphore___160 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___160 *s_bdev;
	struct backing_dev_info___77 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___159 s_dquot;
	struct sb_writers___159 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___159 *s_d_op;
	int cleancache_poolid;
	struct shrinker___72 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___139 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___72 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___72 *memcg;
};

struct user_struct___155 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___155 *uid_keyring;
	struct key___155 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___155 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___155 *session_keyring;
	struct key___155 *process_keyring;
	struct key___155 *thread_keyring;
	struct key___155 *request_key_auth;
	void *security;
	struct user_struct___155 *user;
	struct user_namespace___139 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___135;

struct nsproxy___151 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___135 *cgroup_ns;
};

struct bio___77;

struct bio_list___77 {
	struct bio___77 *head;
	struct bio___77 *tail;
};

struct bdi_writeback_congested___77;

struct bdi_writeback___77 {
	struct backing_dev_info___77 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___77 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___135 *memcg_css;
	struct cgroup_subsys_state___135 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___77 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___77 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___6 *dev;
	struct device___6 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___159 *debug_dir;
	struct dentry___159 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___135 {
	struct cgroup_subsys_state___135 *subsys[13];
	refcount_t refcount;
	struct css_set___135 *dom_cset;
	struct cgroup___135 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___135 *mg_src_cgrp;
	struct cgroup___135 *mg_dst_cgrp;
	struct css_set___135 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct kiocb___160 {
	struct file___160 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___160 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___159 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___160 *ia_file;
};

struct dquot___159 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___159 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___159 {
	int qf_fmt_id;
	const struct quota_format_ops___159 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___159 *qf_next;
};

struct quota_format_ops___159 {
	int (*check_quota_file)(struct super_block___159 *, int);
	int (*read_file_info)(struct super_block___159 *, int);
	int (*write_file_info)(struct super_block___159 *, int);
	int (*free_file_info)(struct super_block___159 *, int);
	int (*read_dqblk)(struct dquot___159 *);
	int (*commit_dqblk)(struct dquot___159 *);
	int (*release_dqblk)(struct dquot___159 *);
	int (*get_next_id)(struct super_block___159 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___159 {
	int (*write_dquot)(struct dquot___159 *);
	struct dquot___159 * (*alloc_dquot)(struct super_block___159 *, int);
	void (*destroy_dquot)(struct dquot___159 *);
	int (*acquire_dquot)(struct dquot___159 *);
	int (*release_dquot)(struct dquot___159 *);
	int (*mark_dirty)(struct dquot___159 *);
	int (*write_info)(struct super_block___159 *, int);
	qsize_t * (*get_reserved_space)(struct inode___160 *);
	int (*get_projid)(struct inode___160 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___160 *, qsize_t *);
	int (*get_next_id)(struct super_block___159 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___159 {
	int (*quota_on)(struct super_block___159 *, int, int, const struct path___159 *);
	int (*quota_off)(struct super_block___159 *, int);
	int (*quota_enable)(struct super_block___159 *, unsigned int);
	int (*quota_disable)(struct super_block___159 *, unsigned int);
	int (*quota_sync)(struct super_block___159 *, int);
	int (*set_info)(struct super_block___159 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___159 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___159 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___159 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___159 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___159 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___74;

struct address_space_operations___159 {
	int (*writepage)(struct page___160 *, struct writeback_control___74 *);
	int (*readpage)(struct file___160 *, struct page___160 *);
	int (*writepages)(struct address_space___159 *, struct writeback_control___74 *);
	int (*set_page_dirty)(struct page___160 *);
	int (*readpages)(struct file___160 *, struct address_space___159 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___160 *, struct address_space___159 *, loff_t, unsigned int, unsigned int, struct page___160 **, void **);
	int (*write_end)(struct file___160 *, struct address_space___159 *, loff_t, unsigned int, unsigned int, struct page___160 *, void *);
	sector_t (*bmap)(struct address_space___159 *, sector_t);
	void (*invalidatepage)(struct page___160 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___160 *, gfp_t);
	void (*freepage)(struct page___160 *);
	ssize_t (*direct_IO)(struct kiocb___160 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___159 *, struct page___160 *, struct page___160 *, enum migrate_mode);
	bool (*isolate_page)(struct page___160 *, isolate_mode_t);
	void (*putback_page)(struct page___160 *);
	int (*launder_page)(struct page___160 *);
	int (*is_partially_uptodate)(struct page___160 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___160 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___159 *, struct page___160 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___160 *, sector_t *);
	void (*swap_deactivate)(struct file___160 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___74 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___77 *wb;
	struct inode___160 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___160 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___160 *bd_inode;
	struct super_block___159 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___160 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___77 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___159 {
	struct dentry___159 * (*lookup)(struct inode___160 *, struct dentry___159 *, unsigned int);
	const char * (*get_link)(struct dentry___159 *, struct inode___160 *, struct delayed_call *);
	int (*permission)(struct inode___160 *, int);
	struct posix_acl * (*get_acl)(struct inode___160 *, int);
	int (*readlink)(struct dentry___159 *, char *, int);
	int (*create)(struct inode___160 *, struct dentry___159 *, umode_t, bool);
	int (*link)(struct dentry___159 *, struct inode___160 *, struct dentry___159 *);
	int (*unlink)(struct inode___160 *, struct dentry___159 *);
	int (*symlink)(struct inode___160 *, struct dentry___159 *, const char *);
	int (*mkdir)(struct inode___160 *, struct dentry___159 *, umode_t);
	int (*rmdir)(struct inode___160 *, struct dentry___159 *);
	int (*mknod)(struct inode___160 *, struct dentry___159 *, umode_t, dev_t);
	int (*rename)(struct inode___160 *, struct dentry___159 *, struct inode___160 *, struct dentry___159 *, unsigned int);
	int (*setattr)(struct dentry___159 *, struct iattr___159 *);
	int (*getattr)(const struct path___159 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___159 *, char *, size_t);
	int (*fiemap)(struct inode___160 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___160 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___160 *, struct dentry___159 *, struct file___160 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___160 *, struct dentry___159 *, umode_t);
	int (*set_acl)(struct inode___160 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___159 {
	void (*fl_copy_lock)(struct file_lock___160 *, struct file_lock___160 *);
	void (*fl_release_private)(struct file_lock___160 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___159;

struct lock_manager_operations___159;

struct file_lock___160 {
	struct file_lock___160 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___160 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___159 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___159 *fl_ops;
	const struct lock_manager_operations___159 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___159 {
	int (*lm_compare_owner)(struct file_lock___160 *, struct file_lock___160 *);
	long unsigned int (*lm_owner_key)(struct file_lock___160 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___160 *);
	int (*lm_grant)(struct file_lock___160 *, int);
	bool (*lm_break)(struct file_lock___160 *);
	int (*lm_change)(struct file_lock___160 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___160 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___159 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___159 *fa_next;
	struct file___160 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___159 {
	const char *name;
	int fs_flags;
	struct dentry___159 * (*mount)(struct file_system_type___159 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___159 *);
	struct module___11 *owner;
	struct file_system_type___159 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___159 {
	struct inode___160 * (*alloc_inode)(struct super_block___159 *);
	void (*destroy_inode)(struct inode___160 *);
	void (*dirty_inode)(struct inode___160 *, int);
	int (*write_inode)(struct inode___160 *, struct writeback_control___74 *);
	int (*drop_inode)(struct inode___160 *);
	void (*evict_inode)(struct inode___160 *);
	void (*put_super)(struct super_block___159 *);
	int (*sync_fs)(struct super_block___159 *, int);
	int (*freeze_super)(struct super_block___159 *);
	int (*freeze_fs)(struct super_block___159 *);
	int (*thaw_super)(struct super_block___159 *);
	int (*unfreeze_fs)(struct super_block___159 *);
	int (*statfs)(struct dentry___159 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___159 *, int *, char *);
	void (*umount_begin)(struct super_block___159 *);
	int (*show_options)(struct seq_file___150 *, struct dentry___159 *);
	int (*show_devname)(struct seq_file___150 *, struct dentry___159 *);
	int (*show_path)(struct seq_file___150 *, struct dentry___159 *);
	int (*show_stats)(struct seq_file___150 *, struct dentry___159 *);
	ssize_t (*quota_read)(struct super_block___159 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___159 *, int, const char *, size_t, loff_t);
	struct dquot___159 ** (*get_dquots)(struct inode___160 *);
	int (*bdev_try_to_free_page)(struct super_block___159 *, struct page___160 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___159 *, struct shrink_control___72 *);
	long int (*free_cached_objects)(struct super_block___159 *, struct shrink_control___72 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___148;

struct seq_file___150 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___148 *op;
	int poll_event;
	const struct file___160 *file;
	void *private;
};

struct kset___153;

struct kobj_type___153;

struct kobject___154 {
	const char *name;
	struct list_head entry;
	struct kobject___154 *parent;
	struct kset___153 *kset;
	struct kobj_type___153 *ktype;
	struct kernfs_node___156 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___77(struct bio___77 *);

struct bio_vec___77 {
	struct page___160 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___77;

struct bio_set___77;

struct bio___77 {
	struct bio___77 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___77 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___77 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___77 *bi_io_vec;
	struct bio_set___77 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___77 bi_inline_vecs[0];
};

struct kernfs_root___156;

struct kernfs_elem_dir___156 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___156 *root;
};

struct kernfs_syscall_ops___156;

struct kernfs_root___156 {
	struct kernfs_node___156 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___156 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___156 {
	struct kernfs_node___156 *target_kn;
};

struct kernfs_ops___156;

struct kernfs_elem_attr___156 {
	const struct kernfs_ops___156 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___156 *notify_next;
};

struct kernfs_node___156 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___156 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___156 dir;
		struct kernfs_elem_symlink___156 symlink;
		struct kernfs_elem_attr___156 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___156;

struct kernfs_ops___156 {
	int (*open)(struct kernfs_open_file___156 *);
	void (*release)(struct kernfs_open_file___156 *);
	int (*seq_show)(struct seq_file___150 *, void *);
	void * (*seq_start)(struct seq_file___150 *, loff_t *);
	void * (*seq_next)(struct seq_file___150 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___150 *, void *);
	ssize_t (*read)(struct kernfs_open_file___156 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___156 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___156 *, struct vm_area_struct___160 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___156 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___156 {
	int (*remount_fs)(struct kernfs_root___156 *, int *, char *);
	int (*show_options)(struct seq_file___150 *, struct kernfs_root___156 *);
	int (*mkdir)(struct kernfs_node___156 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___156 *);
	int (*rename)(struct kernfs_node___156 *, struct kernfs_node___156 *, const char *);
	int (*show_path)(struct seq_file___150 *, struct kernfs_node___156 *, struct kernfs_root___156 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___156 {
	struct kernfs_node___156 *kn;
	struct file___160 *file;
	struct seq_file___150 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___157 *vm_ops;
};

struct bin_attribute___148;

struct attribute_group___149 {
	const char *name;
	umode_t (*is_visible)(struct kobject___154 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___154 *, struct bin_attribute___148 *, int);
	struct attribute **attrs;
	struct bin_attribute___148 **bin_attrs;
};

struct bin_attribute___148 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___160 *, struct kobject___154 *, struct bin_attribute___148 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___160 *, struct kobject___154 *, struct bin_attribute___148 *, char *, loff_t, size_t);
	int (*mmap)(struct file___160 *, struct kobject___154 *, struct bin_attribute___148 *, struct vm_area_struct___160 *);
};

struct sysfs_ops___153 {
	ssize_t (*show)(struct kobject___154 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___154 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___153;

struct kset___153 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___154 kobj;
	const struct kset_uevent_ops___153 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___153 {
	void (*release)(struct kobject___154 *);
	const struct sysfs_ops___153 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___10 * (*child_ns_type)(struct kobject___154 *);
	const void * (*namespace)(struct kobject___154 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___153 {
	int (* const filter)(struct kset___153 *, struct kobject___154 *);
	const char * (* const name)(struct kset___153 *, struct kobject___154 *);
	int (* const uevent)(struct kset___153 *, struct kobject___154 *, struct kobj_uevent_env *);
};

struct kobj_attribute___154 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___154 *, struct kobj_attribute___154 *, char *);
	ssize_t (*store)(struct kobject___154 *, struct kobj_attribute___154 *, const char *, size_t);
};

typedef void compound_page_dtor___157(struct page___160 *);

typedef int (*key_restrict_link_func_t___155)(struct key___155 *, const struct key_type *, const union key_payload *, struct key___155 *);

struct key_restriction___155;

struct key___155 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___160 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___155 *restrict_link;
};

struct key_restriction___155 {
	key_restrict_link_func_t___155 check;
	struct key___155 *key;
	struct key_type *keytype;
};

struct seq_operations___148 {
	void * (*start)(struct seq_file___150 *, loff_t *);
	void (*stop)(struct seq_file___150 *, void *);
	void * (*next)(struct seq_file___150 *, void *, loff_t *);
	int (*show)(struct seq_file___150 *, void *);
};

struct cgroup_namespace___135 {
	refcount_t count;
	struct ns_common___4 ns;
	struct user_namespace___139 *user_ns;
	struct ucounts___139 *ucounts;
	struct css_set___135 *root_cset;
};

struct ucounts___139 {
	struct hlist_node node;
	struct user_namespace___139 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___135;

struct bpf_map_ops___135 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___135 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___135 *, struct file___160 *);
	void (*map_free)(struct bpf_map___135 *);
	int (*map_get_next_key)(struct bpf_map___135 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___135 *);
	void * (*map_lookup_elem)(struct bpf_map___135 *, void *);
	int (*map_update_elem)(struct bpf_map___135 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___135 *, void *);
	int (*map_push_elem)(struct bpf_map___135 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___135 *, void *);
	int (*map_peek_elem)(struct bpf_map___135 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___135 *, struct file___160 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___135 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___135 *, void *, struct seq_file___150 *);
	int (*map_check_btf)(const struct bpf_map___135 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___135 {
	const struct bpf_map_ops___135 *ops;
	struct bpf_map___135 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___155 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___135;

typedef void (*kthread_work_func_t___135)(struct kthread_work___135 *);

struct kthread_worker___135;

struct kthread_work___135 {
	struct list_head node;
	kthread_work_func_t___135 func;
	struct kthread_worker___135 *worker;
	int canceling;
};

struct kthread_worker___135 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___160 *task;
	struct kthread_work___135 *current_work;
};

struct kthread_delayed_work___135 {
	struct kthread_work___135 work;
	struct timer_list timer;
};

struct psi_group___135 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___135 *poll_kworker;
	struct kthread_delayed_work___135 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___135;

struct cgroup_rstat_cpu___135;

struct cgroup___135 {
	struct cgroup_subsys_state___135 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___156 *kn;
	struct cgroup_file___135 procs_file;
	struct cgroup_file___135 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___135 *subsys[13];
	struct cgroup_root___135 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___135 *dom_cgrp;
	struct cgroup_rstat_cpu___135 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___20 bpf;
	atomic_t congestion_count;
	struct cgroup___135 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___135 psi;
	int ancestor_ids[0];
};

struct cftype___135;

struct cgroup_subsys___135 {
	struct cgroup_subsys_state___135 * (*css_alloc)(struct cgroup_subsys_state___135 *);
	int (*css_online)(struct cgroup_subsys_state___135 *);
	void (*css_offline)(struct cgroup_subsys_state___135 *);
	void (*css_released)(struct cgroup_subsys_state___135 *);
	void (*css_free)(struct cgroup_subsys_state___135 *);
	void (*css_reset)(struct cgroup_subsys_state___135 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___135 *, int);
	int (*css_extra_stat_show)(struct seq_file___150 *, struct cgroup_subsys_state___135 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___160 *);
	void (*cancel_fork)(struct task_struct___160 *);
	void (*fork)(struct task_struct___160 *);
	void (*exit)(struct task_struct___160 *);
	void (*free)(struct task_struct___160 *);
	void (*bind)(struct cgroup_subsys_state___135 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___135 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___135 *dfl_cftypes;
	struct cftype___135 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___135 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___135 *updated_children;
	struct cgroup___135 *updated_next;
};

struct cgroup_root___135 {
	struct kernfs_root___156 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___135 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___135 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___135 *ss;
	struct list_head node;
	struct kernfs_ops___156 *kf_ops;
	int (*open)(struct kernfs_open_file___156 *);
	void (*release)(struct kernfs_open_file___156 *);
	u64 (*read_u64)(struct cgroup_subsys_state___135 *, struct cftype___135 *);
	s64 (*read_s64)(struct cgroup_subsys_state___135 *, struct cftype___135 *);
	int (*seq_show)(struct seq_file___150 *, void *);
	void * (*seq_start)(struct seq_file___150 *, loff_t *);
	void * (*seq_next)(struct seq_file___150 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___150 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___135 *, struct cftype___135 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___135 *, struct cftype___135 *, s64);
	ssize_t (*write)(struct kernfs_open_file___156 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___156 *, struct poll_table_struct___6 *);
};

struct bdi_writeback_congested___77 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___77 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___77 {
	struct bio___77 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___77 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___77 bip_inline_vecs[0];
};

struct bio_set___77 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___77 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___72 {
	struct mem_cgroup___72 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___72 {
	struct lruvec___159 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___72 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___72 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct page_vma_mapped_walk___3 {
	struct page___160 *page;
	struct vm_area_struct___160 *vma;
	long unsigned int address;
	pmd_t *pmd;
	pte_t *pte;
	spinlock_t *ptl;
	unsigned int flags;
};

struct rmap_walk_control___3 {
	void *arg;
	bool (*rmap_one)(struct page___160 *, struct vm_area_struct___160 *, long unsigned int, void *);
	int (*done)(struct page___160 *);
	struct anon_vma___19 * (*anon_lock)(struct page___160 *);
	bool (*invalid_vma)(struct vm_area_struct___160 *, void *);
};

enum {
	BAD_STACK = 4294967295,
	NOT_STACK = 0,
	GOOD_FRAME = 1,
	GOOD_STACK = 2,
};

struct module___136;

struct file___161;

struct kiocb___161;

struct iov_iter___73;

struct poll_table_struct___108;

struct vm_area_struct___161;

struct inode___161;

struct file_lock___161;

struct page___161;

struct seq_file___151;

struct file_operations___161 {
	struct module___136 *owner;
	loff_t (*llseek)(struct file___161 *, loff_t, int);
	ssize_t (*read)(struct file___161 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___161 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___161 *, struct iov_iter___73 *);
	ssize_t (*write_iter)(struct kiocb___161 *, struct iov_iter___73 *);
	int (*iopoll)(struct kiocb___161 *, bool);
	int (*iterate)(struct file___161 *, struct dir_context *);
	int (*iterate_shared)(struct file___161 *, struct dir_context *);
	__poll_t (*poll)(struct file___161 *, struct poll_table_struct___108 *);
	long int (*unlocked_ioctl)(struct file___161 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___161 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___161 *, struct vm_area_struct___161 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___161 *, struct file___161 *);
	int (*flush)(struct file___161 *, fl_owner_t);
	int (*release)(struct inode___161 *, struct file___161 *);
	int (*fsync)(struct file___161 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___161 *, int);
	int (*lock)(struct file___161 *, int, struct file_lock___161 *);
	ssize_t (*sendpage)(struct file___161 *, struct page___161 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___161 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___161 *, int, struct file_lock___161 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___161 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___161 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___161 *, long int, struct file_lock___161 **, void **);
	long int (*fallocate)(struct file___161 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___151 *, struct file___161 *);
	ssize_t (*copy_file_range)(struct file___161 *, loff_t, struct file___161 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___161 *, loff_t, struct file___161 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___161 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___160 {
	u64 seqnum;
	struct vm_area_struct___161 *vmas[4];
};

struct page_frag___160 {
	struct page___161 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___98;

struct debug_info___98 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___98 *hbp_break[16];
	struct perf_event___98 *hbp_watch[16];
};

struct thread_struct___98 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___98 debug;
	long: 64;
};

struct mm_struct___160;

struct mem_cgroup___73;

struct pid___126;

struct cred___156;

struct nsproxy___152;

struct signal_struct___142;

struct bio_list___78;

struct backing_dev_info___78;

struct css_set___136;

struct perf_event_context___98;

struct task_struct___161 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___161 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___160 *mm;
	struct mm_struct___160 *active_mm;
	struct vmacache___160 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___161 *real_parent;
	struct task_struct___161 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___161 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___73 *active_memcg;
	long int rh_reserved2;
	struct pid___126 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___126 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___126 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___156 *ptracer_cred;
	const struct cred___156 *real_cred;
	const struct cred___156 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___152 *nsproxy;
	struct signal_struct___142 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___161 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___78 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___78 *backing_dev_info;
	struct io_context___38 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___136 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___98 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___160 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___73 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___161 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___98 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___98 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___161 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___98)(struct perf_event___98 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___98;

struct fasync_struct___160;

struct pid_namespace___126;

struct trace_event_call___91;

struct perf_cgroup___98;

struct perf_event___98 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___98 *group_leader;
	struct pmu___98 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___98 hw;
	struct perf_event_context___98 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___98 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___161 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___160 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___98 *);
	struct callback_head callback_head;
	struct pid_namespace___126 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___98 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___98 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___91 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___98 *cgrp;
	struct list_head sb_list;
};

struct dentry_operations___160;

struct super_block___160;

struct dentry___160 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___160 *d_parent;
	struct qstr d_name;
	struct inode___161 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___160 *d_op;
	struct super_block___160 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct rw_semaphore___161 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___161 *owner;
};

struct address_space_operations___160;

struct address_space___160 {
	struct inode___161 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___161 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___160 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___160;

struct bdi_writeback___78;

struct block_device___161;

struct inode___161 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___160 *i_op;
	struct super_block___160 *i_sb;
	struct address_space___160 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___161 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___78 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___161 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___160 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___161 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___160;

struct dentry_operations___160 {
	int (*d_revalidate)(struct dentry___160 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___160 *, unsigned int);
	int (*d_hash)(const struct dentry___160 *, struct qstr *);
	int (*d_compare)(const struct dentry___160 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___160 *);
	int (*d_init)(struct dentry___160 *);
	void (*d_release)(struct dentry___160 *);
	void (*d_prune)(struct dentry___160 *);
	void (*d_iput)(struct dentry___160 *, struct inode___161 *);
	char * (*d_dname)(struct dentry___160 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___160 *);
	int (*d_manage)(const struct path___160 *, bool);
	struct dentry___160 * (*d_real)(struct dentry___160 *, const struct inode___161 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___160;

struct mem_dqinfo___160 {
	struct quota_format_type___160 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___160;

struct quota_info___160 {
	unsigned int flags;
	struct rw_semaphore___161 dqio_sem;
	struct inode___161 *files[3];
	struct mem_dqinfo___160 info[3];
	const struct quota_format_ops___160 *ops[3];
};

struct rcuwait___160 {
	struct task_struct___161 *task;
};

struct percpu_rw_semaphore___160 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___161 rw_sem;
	struct rcuwait___160 writer;
	int readers_block;
};

struct sb_writers___160 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___160 rw_sem[3];
};

struct shrink_control___73;

struct shrinker___73 {
	long unsigned int (*count_objects)(struct shrinker___73 *, struct shrink_control___73 *);
	long unsigned int (*scan_objects)(struct shrinker___73 *, struct shrink_control___73 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___160;

struct super_operations___160;

struct dquot_operations___160;

struct quotactl_ops___160;

struct xattr_handler___15;

struct user_namespace___140;

struct super_block___160 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___160 *s_type;
	const struct super_operations___160 *s_op;
	const struct dquot_operations___160 *dq_op;
	const struct quotactl_ops___160 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___160 *s_root;
	struct rw_semaphore___161 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___15 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___161 *s_bdev;
	struct backing_dev_info___78 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___160 s_dquot;
	struct sb_writers___160 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___160 *s_d_op;
	int cleancache_poolid;
	struct shrinker___73 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___140 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct path___160 {
	struct vfsmount *mnt;
	struct dentry___160 *dentry;
};

struct key___156;

struct ucounts___140;

struct user_namespace___140 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___140 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___4 ns;
	long unsigned int flags;
	struct key___156 *persistent_keyring_register;
	struct rw_semaphore___161 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___140 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct shrink_control___73 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___73 *memcg;
};

struct cgroup___136;

struct cgroup_subsys___136;

struct cgroup_subsys_state___136 {
	struct cgroup___136 *cgroup;
	struct cgroup_subsys___136 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___136 *parent;
};

struct kernfs_node___157;

struct cgroup_file___136 {
	struct kernfs_node___157 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___73;

struct mem_cgroup___73 {
	struct cgroup_subsys_state___136 css;
	struct mem_cgroup_id___11 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___136 events_file;
	struct cgroup_file___136 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___161 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___73 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___161 *pgtable_t___160;

struct dev_pagemap___158;

struct page___161 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___160 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___161 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___160 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___160 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___158 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___73 *mem_cgroup;
};

struct pglist_data___160;

struct lruvec___160 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___160 *pgdat;
};

struct zone___160 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___160 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___160 {
	struct zone___160 *zone;
	int zone_idx;
};

struct zonelist___160 {
	struct zoneref___160 _zonerefs[25];
};

struct pglist_data___160 {
	struct zone___160 node_zones[3];
	struct zonelist___160 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___161 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___161 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___160 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___161 {
	void *stack;
	struct task_struct___161 *task;
	long int status;
};

struct blocking_notifier_head___160 {
	struct rw_semaphore___161 rwsem;
	struct notifier_block *head;
};

struct upid___126 {
	int nr;
	struct pid_namespace___126 *ns;
};

struct pid_namespace___126 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___161 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___126 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___160 *proc_self;
	struct dentry___160 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___140 *user_ns;
	struct ucounts___140 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___4 ns;
};

struct pid___126 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___126 numbers[1];
};

struct vm_operations_struct___158;

struct vm_area_struct___161 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___161 *vm_next;
	struct vm_area_struct___161 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___160 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___158 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___161 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___160;

struct mm_struct___160 {
	struct {
		struct vm_area_struct___161 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___161 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___161 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___160 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___161 *owner;
		struct user_namespace___140 *user_ns;
		struct file___161 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___160 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___158)(struct vm_area_struct___161 *, long unsigned int, const struct page___161 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___158)(struct page___161 *, void *);

struct device___149;

struct dev_pagemap___158 {
	dev_page_fault_t___158 page_fault;
	dev_page_free_t___158 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___149 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct fown_struct___126 {
	rwlock_t lock;
	struct pid___126 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___161 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___160 f_path;
	struct inode___161 *f_inode;
	const struct file_operations___161 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___126 f_owner;
	const struct cred___156 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___160 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___158;

struct vm_operations_struct___158 {
	void (*open)(struct vm_area_struct___161 *);
	void (*close)(struct vm_area_struct___161 *);
	int (*split)(struct vm_area_struct___161 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___161 *);
	vm_fault_t (*fault)(struct vm_fault___158 *);
	vm_fault_t (*huge_fault)(struct vm_fault___158 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___158 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___161 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___158 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___158 *);
	int (*access)(struct vm_area_struct___161 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___161 *);
	int (*set_policy)(struct vm_area_struct___161 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___161 *, long unsigned int);
	struct page___161 * (*find_special_page)(struct vm_area_struct___161 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___160 {
	struct task_struct___161 *task;
	struct core_thread___160 *next;
};

struct core_state___160 {
	atomic_t nr_threads;
	struct core_thread___160 dumper;
	struct completion startup;
};

struct vm_fault___158 {
	struct vm_area_struct___161 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___161 *cow_page;
	struct mem_cgroup___73 *memcg;
	struct page___161 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___160 prealloc_pte;
};

struct user_struct___156 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___156 *uid_keyring;
	struct key___156 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___156 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___156 *session_keyring;
	struct key___156 *process_keyring;
	struct key___156 *thread_keyring;
	struct key___156 *request_key_auth;
	void *security;
	struct user_struct___156 *user;
	struct user_namespace___140 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___136;

struct nsproxy___152 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___126 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___136 *cgroup_ns;
};

struct signal_struct___142 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___161 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___161 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___126 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___126 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___160 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___126 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___78;

struct bio_list___78 {
	struct bio___78 *head;
	struct bio___78 *tail;
};

struct bdi_writeback_congested___78;

struct bdi_writeback___78 {
	struct backing_dev_info___78 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___78 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___136 *memcg_css;
	struct cgroup_subsys_state___136 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___78 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___78 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___149 *dev;
	struct device___149 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___160 *debug_dir;
	struct dentry___160 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___136 {
	struct cgroup_subsys_state___136 *subsys[13];
	refcount_t refcount;
	struct css_set___136 *dom_cset;
	struct cgroup___136 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___136 *mg_src_cgrp;
	struct cgroup___136 *mg_dst_cgrp;
	struct css_set___136 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___98 {
	struct pmu___98 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___161 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___98 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

union thread_union___143 {
	struct task_struct___161 task;
	long unsigned int stack[8192];
};

struct kiocb___161 {
	struct file___161 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___161 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___160 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___161 *ia_file;
};

struct dquot___160 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___160 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___160 {
	int qf_fmt_id;
	const struct quota_format_ops___160 *qf_ops;
	struct module___136 *qf_owner;
	struct quota_format_type___160 *qf_next;
};

struct quota_format_ops___160 {
	int (*check_quota_file)(struct super_block___160 *, int);
	int (*read_file_info)(struct super_block___160 *, int);
	int (*write_file_info)(struct super_block___160 *, int);
	int (*free_file_info)(struct super_block___160 *, int);
	int (*read_dqblk)(struct dquot___160 *);
	int (*commit_dqblk)(struct dquot___160 *);
	int (*release_dqblk)(struct dquot___160 *);
	int (*get_next_id)(struct super_block___160 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___160 {
	int (*write_dquot)(struct dquot___160 *);
	struct dquot___160 * (*alloc_dquot)(struct super_block___160 *, int);
	void (*destroy_dquot)(struct dquot___160 *);
	int (*acquire_dquot)(struct dquot___160 *);
	int (*release_dquot)(struct dquot___160 *);
	int (*mark_dirty)(struct dquot___160 *);
	int (*write_info)(struct super_block___160 *, int);
	qsize_t * (*get_reserved_space)(struct inode___161 *);
	int (*get_projid)(struct inode___161 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___161 *, qsize_t *);
	int (*get_next_id)(struct super_block___160 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___160 {
	int (*quota_on)(struct super_block___160 *, int, int, const struct path___160 *);
	int (*quota_off)(struct super_block___160 *, int);
	int (*quota_enable)(struct super_block___160 *, unsigned int);
	int (*quota_disable)(struct super_block___160 *, unsigned int);
	int (*quota_sync)(struct super_block___160 *, int);
	int (*set_info)(struct super_block___160 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___160 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___160 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___160 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___160 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___160 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___154;

struct kobj_type___154;

struct kobject___155 {
	const char *name;
	struct list_head entry;
	struct kobject___155 *parent;
	struct kset___154 *kset;
	struct kobj_type___154 *ktype;
	struct kernfs_node___157 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___133 {
	struct kobject___155 kobj;
	struct module___136 *mod;
	struct kobject___155 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___133 {
	struct module___136 *mod;
	struct latch_tree_node node;
};

struct module_layout___133 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___133 mtn;
};

struct module_attribute___133;

struct kernel_param___133;

struct module___136 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___133 mkobj;
	struct module_attribute___133 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___155 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___133 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___133 core_layout;
	struct module_layout___133 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___91 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___75;

struct swap_info_struct___54;

struct address_space_operations___160 {
	int (*writepage)(struct page___161 *, struct writeback_control___75 *);
	int (*readpage)(struct file___161 *, struct page___161 *);
	int (*writepages)(struct address_space___160 *, struct writeback_control___75 *);
	int (*set_page_dirty)(struct page___161 *);
	int (*readpages)(struct file___161 *, struct address_space___160 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___161 *, struct address_space___160 *, loff_t, unsigned int, unsigned int, struct page___161 **, void **);
	int (*write_end)(struct file___161 *, struct address_space___160 *, loff_t, unsigned int, unsigned int, struct page___161 *, void *);
	sector_t (*bmap)(struct address_space___160 *, sector_t);
	void (*invalidatepage)(struct page___161 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___161 *, gfp_t);
	void (*freepage)(struct page___161 *);
	ssize_t (*direct_IO)(struct kiocb___161 *, struct iov_iter___73 *);
	int (*migratepage)(struct address_space___160 *, struct page___161 *, struct page___161 *, enum migrate_mode);
	bool (*isolate_page)(struct page___161 *, isolate_mode_t);
	void (*putback_page)(struct page___161 *);
	int (*launder_page)(struct page___161 *);
	int (*is_partially_uptodate)(struct page___161 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___161 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___160 *, struct page___161 *);
	int (*swap_activate)(struct swap_info_struct___54 *, struct file___161 *, sector_t *);
	void (*swap_deactivate)(struct file___161 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___75 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___78 *wb;
	struct inode___161 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___78;

struct iov_iter___73 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___78 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct swap_info_struct___54 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___161 *bdev;
	struct file___161 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___161 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___161 *bd_inode;
	struct super_block___160 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___161 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___78 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___160 {
	struct dentry___160 * (*lookup)(struct inode___161 *, struct dentry___160 *, unsigned int);
	const char * (*get_link)(struct dentry___160 *, struct inode___161 *, struct delayed_call *);
	int (*permission)(struct inode___161 *, int);
	struct posix_acl * (*get_acl)(struct inode___161 *, int);
	int (*readlink)(struct dentry___160 *, char *, int);
	int (*create)(struct inode___161 *, struct dentry___160 *, umode_t, bool);
	int (*link)(struct dentry___160 *, struct inode___161 *, struct dentry___160 *);
	int (*unlink)(struct inode___161 *, struct dentry___160 *);
	int (*symlink)(struct inode___161 *, struct dentry___160 *, const char *);
	int (*mkdir)(struct inode___161 *, struct dentry___160 *, umode_t);
	int (*rmdir)(struct inode___161 *, struct dentry___160 *);
	int (*mknod)(struct inode___161 *, struct dentry___160 *, umode_t, dev_t);
	int (*rename)(struct inode___161 *, struct dentry___160 *, struct inode___161 *, struct dentry___160 *, unsigned int);
	int (*setattr)(struct dentry___160 *, struct iattr___160 *);
	int (*getattr)(const struct path___160 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___160 *, char *, size_t);
	int (*fiemap)(struct inode___161 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___161 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___161 *, struct dentry___160 *, struct file___161 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___161 *, struct dentry___160 *, umode_t);
	int (*set_acl)(struct inode___161 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___160 {
	void (*fl_copy_lock)(struct file_lock___161 *, struct file_lock___161 *);
	void (*fl_release_private)(struct file_lock___161 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___160;

struct file_lock___161 {
	struct file_lock___161 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___161 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___160 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___160 *fl_ops;
	const struct lock_manager_operations___160 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___160 {
	int (*lm_compare_owner)(struct file_lock___161 *, struct file_lock___161 *);
	long unsigned int (*lm_owner_key)(struct file_lock___161 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___161 *);
	int (*lm_grant)(struct file_lock___161 *, int);
	bool (*lm_break)(struct file_lock___161 *);
	int (*lm_change)(struct file_lock___161 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___161 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___160 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___160 *fa_next;
	struct file___161 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___160 {
	const char *name;
	int fs_flags;
	struct dentry___160 * (*mount)(struct file_system_type___160 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___160 *);
	struct module___136 *owner;
	struct file_system_type___160 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___160 {
	struct inode___161 * (*alloc_inode)(struct super_block___160 *);
	void (*destroy_inode)(struct inode___161 *);
	void (*dirty_inode)(struct inode___161 *, int);
	int (*write_inode)(struct inode___161 *, struct writeback_control___75 *);
	int (*drop_inode)(struct inode___161 *);
	void (*evict_inode)(struct inode___161 *);
	void (*put_super)(struct super_block___160 *);
	int (*sync_fs)(struct super_block___160 *, int);
	int (*freeze_super)(struct super_block___160 *);
	int (*freeze_fs)(struct super_block___160 *);
	int (*thaw_super)(struct super_block___160 *);
	int (*unfreeze_fs)(struct super_block___160 *);
	int (*statfs)(struct dentry___160 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___160 *, int *, char *);
	void (*umount_begin)(struct super_block___160 *);
	int (*show_options)(struct seq_file___151 *, struct dentry___160 *);
	int (*show_devname)(struct seq_file___151 *, struct dentry___160 *);
	int (*show_path)(struct seq_file___151 *, struct dentry___160 *);
	int (*show_stats)(struct seq_file___151 *, struct dentry___160 *);
	ssize_t (*quota_read)(struct super_block___160 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___160 *, int, const char *, size_t, loff_t);
	struct dquot___160 ** (*get_dquots)(struct inode___161 *);
	int (*bdev_try_to_free_page)(struct super_block___160 *, struct page___161 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___160 *, struct shrink_control___73 *);
	long int (*free_cached_objects)(struct super_block___160 *, struct shrink_control___73 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct xattr_handler___15 {
	const char *name;
	const char *prefix;
	int flags;
	bool (*list)(struct dentry___160 *);
	int (*get)(const struct xattr_handler___15 *, struct dentry___160 *, struct inode___161 *, const char *, void *, size_t);
	int (*set)(const struct xattr_handler___15 *, struct dentry___160 *, struct inode___161 *, const char *, const void *, size_t, int);
};

typedef void (*poll_queue_proc___107)(struct file___161 *, wait_queue_head_t *, struct poll_table_struct___108 *);

struct poll_table_struct___108 {
	poll_queue_proc___107 _qproc;
	__poll_t _key;
};

struct seq_operations___149;

struct seq_file___151 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___149 *op;
	int poll_event;
	const struct file___161 *file;
	void *private;
};

typedef void bio_end_io_t___78(struct bio___78 *);

struct bio_vec___78 {
	struct page___161 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___78;

struct bio_set___78;

struct bio___78 {
	struct bio___78 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___78 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___78 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___78 *bi_io_vec;
	struct bio_set___78 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___78 bi_inline_vecs[0];
};

struct dev_pm_info___149 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___149 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___149;

struct bus_type___149;

struct device_driver___149;

struct dev_pm_domain___149;

struct class___149;

struct attribute_group___150;

struct device___149 {
	struct device___149 *parent;
	struct device_private *p;
	struct kobject___155 kobj;
	const char *init_name;
	const struct device_type___149 *type;
	struct mutex mutex;
	struct bus_type___149 *bus;
	struct device_driver___149 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___149 power;
	struct dev_pm_domain___149 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___149 *class;
	const struct attribute_group___150 **groups;
	void (*release)(struct device___149 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct kobj_attribute___155 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___155 *, struct kobj_attribute___155 *, char *);
	ssize_t (*store)(struct kobject___155 *, struct kobj_attribute___155 *, const char *, size_t);
};

typedef void compound_page_dtor___158(struct page___161 *);

typedef int (*key_restrict_link_func_t___156)(struct key___156 *, const struct key_type *, const union key_payload *, struct key___156 *);

struct key_restriction___156;

struct key___156 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___161 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___156 *restrict_link;
};

struct key_restriction___156 {
	key_restrict_link_func_t___156 check;
	struct key___156 *key;
	struct key_type *keytype;
};

struct bin_attribute___149;

struct attribute_group___150 {
	const char *name;
	umode_t (*is_visible)(struct kobject___155 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___155 *, struct bin_attribute___149 *, int);
	struct attribute **attrs;
	struct bin_attribute___149 **bin_attrs;
};

struct seq_operations___149 {
	void * (*start)(struct seq_file___151 *, loff_t *);
	void (*stop)(struct seq_file___151 *, void *);
	void * (*next)(struct seq_file___151 *, void *, loff_t *);
	int (*show)(struct seq_file___151 *, void *);
};

struct cgroup_namespace___136 {
	refcount_t count;
	struct ns_common___4 ns;
	struct user_namespace___140 *user_ns;
	struct ucounts___140 *ucounts;
	struct css_set___136 *root_cset;
};

struct ucounts___140 {
	struct hlist_node node;
	struct user_namespace___140 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct kernfs_root___157;

struct kernfs_elem_dir___157 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___157 *root;
};

struct kernfs_syscall_ops___157;

struct kernfs_root___157 {
	struct kernfs_node___157 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___157 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___157 {
	struct kernfs_node___157 *target_kn;
};

struct kernfs_ops___157;

struct kernfs_elem_attr___157 {
	const struct kernfs_ops___157 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___157 *notify_next;
};

struct kernfs_node___157 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___157 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___157 dir;
		struct kernfs_elem_symlink___157 symlink;
		struct kernfs_elem_attr___157 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___157;

struct kernfs_ops___157 {
	int (*open)(struct kernfs_open_file___157 *);
	void (*release)(struct kernfs_open_file___157 *);
	int (*seq_show)(struct seq_file___151 *, void *);
	void * (*seq_start)(struct seq_file___151 *, loff_t *);
	void * (*seq_next)(struct seq_file___151 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___151 *, void *);
	ssize_t (*read)(struct kernfs_open_file___157 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___157 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___157 *, struct vm_area_struct___161 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___157 *, struct poll_table_struct___108 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___157 {
	int (*remount_fs)(struct kernfs_root___157 *, int *, char *);
	int (*show_options)(struct seq_file___151 *, struct kernfs_root___157 *);
	int (*mkdir)(struct kernfs_node___157 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___157 *);
	int (*rename)(struct kernfs_node___157 *, struct kernfs_node___157 *, const char *);
	int (*show_path)(struct seq_file___151 *, struct kernfs_node___157 *, struct kernfs_root___157 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___157 {
	struct kernfs_node___157 *kn;
	struct file___161 *file;
	struct seq_file___151 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___158 *vm_ops;
};

struct bin_attribute___149 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___161 *, struct kobject___155 *, struct bin_attribute___149 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___161 *, struct kobject___155 *, struct bin_attribute___149 *, char *, loff_t, size_t);
	int (*mmap)(struct file___161 *, struct kobject___155 *, struct bin_attribute___149 *, struct vm_area_struct___161 *);
};

struct sysfs_ops___154 {
	ssize_t (*show)(struct kobject___155 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___155 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___154;

struct kset___154 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___155 kobj;
	const struct kset_uevent_ops___154 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___154 {
	void (*release)(struct kobject___155 *);
	const struct sysfs_ops___154 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___10 * (*child_ns_type)(struct kobject___155 *);
	const void * (*namespace)(struct kobject___155 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___154 {
	int (* const filter)(struct kset___154 *, struct kobject___155 *);
	const char * (* const name)(struct kset___154 *, struct kobject___155 *);
	int (* const uevent)(struct kset___154 *, struct kobject___155 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___133 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___133 *);
	int (*get)(char *, const struct kernel_param___133 *);
	void (*free)(void *);
};

struct kparam_array___133;

struct kernel_param___133 {
	const char *name;
	struct module___136 *mod;
	const struct kernel_param_ops___133 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___133 *arr;
	};
};

struct kparam_array___133 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___133 *ops;
	void *elem;
};

struct module_attribute___133 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___133 *, struct module_kobject___133 *, char *);
	ssize_t (*store)(struct module_attribute___133 *, struct module_kobject___133 *, const char *, size_t);
	void (*setup)(struct module___136 *, const char *);
	int (*test)(struct module___136 *);
	void (*free)(struct module___136 *);
};

struct trace_event_class___91;

struct trace_event_call___91 {
	struct list_head list;
	struct trace_event_class___91 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___20 *prog_array;
	int (*perf_perm)(struct trace_event_call___91 *, struct perf_event___98 *);
};

struct dev_pm_ops___149 {
	int (*prepare)(struct device___149 *);
	void (*complete)(struct device___149 *);
	int (*suspend)(struct device___149 *);
	int (*resume)(struct device___149 *);
	int (*freeze)(struct device___149 *);
	int (*thaw)(struct device___149 *);
	int (*poweroff)(struct device___149 *);
	int (*restore)(struct device___149 *);
	int (*suspend_late)(struct device___149 *);
	int (*resume_early)(struct device___149 *);
	int (*freeze_late)(struct device___149 *);
	int (*thaw_early)(struct device___149 *);
	int (*poweroff_late)(struct device___149 *);
	int (*restore_early)(struct device___149 *);
	int (*suspend_noirq)(struct device___149 *);
	int (*resume_noirq)(struct device___149 *);
	int (*freeze_noirq)(struct device___149 *);
	int (*thaw_noirq)(struct device___149 *);
	int (*poweroff_noirq)(struct device___149 *);
	int (*restore_noirq)(struct device___149 *);
	int (*runtime_suspend)(struct device___149 *);
	int (*runtime_resume)(struct device___149 *);
	int (*runtime_idle)(struct device___149 *);
};

struct dev_pm_domain___149 {
	struct dev_pm_ops___149 ops;
	void (*detach)(struct device___149 *, bool);
	int (*activate)(struct device___149 *);
	void (*sync)(struct device___149 *);
	void (*dismiss)(struct device___149 *);
};

struct bus_type___149 {
	const char *name;
	const char *dev_name;
	struct device___149 *dev_root;
	const struct attribute_group___150 **bus_groups;
	const struct attribute_group___150 **dev_groups;
	const struct attribute_group___150 **drv_groups;
	int (*match)(struct device___149 *, struct device_driver___149 *);
	int (*uevent)(struct device___149 *, struct kobj_uevent_env *);
	int (*probe)(struct device___149 *);
	int (*remove)(struct device___149 *);
	void (*shutdown)(struct device___149 *);
	int (*online)(struct device___149 *);
	int (*offline)(struct device___149 *);
	int (*suspend)(struct device___149 *, pm_message_t);
	int (*resume)(struct device___149 *);
	int (*num_vf)(struct device___149 *);
	int (*dma_configure)(struct device___149 *);
	const struct dev_pm_ops___149 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___149 {
	const char *name;
	struct bus_type___149 *bus;
	struct module___136 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___149 *);
	int (*remove)(struct device___149 *);
	void (*shutdown)(struct device___149 *);
	int (*suspend)(struct device___149 *, pm_message_t);
	int (*resume)(struct device___149 *);
	const struct attribute_group___150 **groups;
	const struct dev_pm_ops___149 *pm;
	void (*coredump)(struct device___149 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___149 {
	const char *name;
	const struct attribute_group___150 **groups;
	int (*uevent)(struct device___149 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___149 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___149 *);
	const struct dev_pm_ops___149 *pm;
};

struct class___149 {
	const char *name;
	struct module___136 *owner;
	const struct attribute_group___150 **class_groups;
	const struct attribute_group___150 **dev_groups;
	struct kobject___155 *dev_kobj;
	int (*dev_uevent)(struct device___149 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___149 *, umode_t *);
	void (*class_release)(struct class___149 *);
	void (*dev_release)(struct device___149 *);
	int (*shutdown_pre)(struct device___149 *);
	const struct kobj_ns_type_operations___10 *ns_type;
	const void * (*namespace)(struct device___149 *);
	const struct dev_pm_ops___149 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___127 {
	struct device___149 dev;
};

struct bpf_map___136;

struct bpf_map_ops___136 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___136 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___136 *, struct file___161 *);
	void (*map_free)(struct bpf_map___136 *);
	int (*map_get_next_key)(struct bpf_map___136 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___136 *);
	void * (*map_lookup_elem)(struct bpf_map___136 *, void *);
	int (*map_update_elem)(struct bpf_map___136 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___136 *, void *);
	int (*map_push_elem)(struct bpf_map___136 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___136 *, void *);
	int (*map_peek_elem)(struct bpf_map___136 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___136 *, struct file___161 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___136 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___136 *, void *, struct seq_file___151 *);
	int (*map_check_btf)(const struct bpf_map___136 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___136 {
	const struct bpf_map_ops___136 *ops;
	struct bpf_map___136 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___156 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___136;

typedef void (*kthread_work_func_t___136)(struct kthread_work___136 *);

struct kthread_worker___136;

struct kthread_work___136 {
	struct list_head node;
	kthread_work_func_t___136 func;
	struct kthread_worker___136 *worker;
	int canceling;
};

struct kthread_worker___136 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___161 *task;
	struct kthread_work___136 *current_work;
};

struct kthread_delayed_work___136 {
	struct kthread_work___136 work;
	struct timer_list timer;
};

struct psi_group___136 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___136 *poll_kworker;
	struct kthread_delayed_work___136 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___136;

struct cgroup_rstat_cpu___136;

struct cgroup___136 {
	struct cgroup_subsys_state___136 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___157 *kn;
	struct cgroup_file___136 procs_file;
	struct cgroup_file___136 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___136 *subsys[13];
	struct cgroup_root___136 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___136 *dom_cgrp;
	struct cgroup_rstat_cpu___136 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___20 bpf;
	atomic_t congestion_count;
	struct cgroup___136 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___136 psi;
	int ancestor_ids[0];
};

struct cftype___136;

struct cgroup_subsys___136 {
	struct cgroup_subsys_state___136 * (*css_alloc)(struct cgroup_subsys_state___136 *);
	int (*css_online)(struct cgroup_subsys_state___136 *);
	void (*css_offline)(struct cgroup_subsys_state___136 *);
	void (*css_released)(struct cgroup_subsys_state___136 *);
	void (*css_free)(struct cgroup_subsys_state___136 *);
	void (*css_reset)(struct cgroup_subsys_state___136 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___136 *, int);
	int (*css_extra_stat_show)(struct seq_file___151 *, struct cgroup_subsys_state___136 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___161 *);
	void (*cancel_fork)(struct task_struct___161 *);
	void (*fork)(struct task_struct___161 *);
	void (*exit)(struct task_struct___161 *);
	void (*free)(struct task_struct___161 *);
	void (*bind)(struct cgroup_subsys_state___136 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___136 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___136 *dfl_cftypes;
	struct cftype___136 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___136 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___136 *updated_children;
	struct cgroup___136 *updated_next;
};

struct cgroup_root___136 {
	struct kernfs_root___157 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___136 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___136 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___136 *ss;
	struct list_head node;
	struct kernfs_ops___157 *kf_ops;
	int (*open)(struct kernfs_open_file___157 *);
	void (*release)(struct kernfs_open_file___157 *);
	u64 (*read_u64)(struct cgroup_subsys_state___136 *, struct cftype___136 *);
	s64 (*read_s64)(struct cgroup_subsys_state___136 *, struct cftype___136 *);
	int (*seq_show)(struct seq_file___151 *, void *);
	void * (*seq_start)(struct seq_file___151 *, loff_t *);
	void * (*seq_next)(struct seq_file___151 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___151 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___136 *, struct cftype___136 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___136 *, struct cftype___136 *, s64);
	ssize_t (*write)(struct kernfs_open_file___157 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___157 *, struct poll_table_struct___108 *);
};

struct perf_cpu_context___98;

struct pmu___98 {
	struct list_head entry;
	struct module___136 *module;
	struct device___149 *dev;
	const struct attribute_group___150 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___98 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___98 *);
	void (*pmu_disable)(struct pmu___98 *);
	int (*event_init)(struct perf_event___98 *);
	void (*event_mapped)(struct perf_event___98 *, struct mm_struct___160 *);
	void (*event_unmapped)(struct perf_event___98 *, struct mm_struct___160 *);
	int (*add)(struct perf_event___98 *, int);
	void (*del)(struct perf_event___98 *, int);
	void (*start)(struct perf_event___98 *, int);
	void (*stop)(struct perf_event___98 *, int);
	void (*read)(struct perf_event___98 *);
	void (*start_txn)(struct pmu___98 *, unsigned int);
	int (*commit_txn)(struct pmu___98 *);
	void (*cancel_txn)(struct pmu___98 *);
	int (*event_idx)(struct perf_event___98 *);
	void (*sched_task)(struct perf_event_context___98 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___98 *);
	int (*filter_match)(struct perf_event___98 *);
	int (*check_period)(struct perf_event___98 *, u64);
};

struct perf_cpu_context___98 {
	struct perf_event_context___98 ctx;
	struct perf_event_context___98 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___98 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___98 {
	struct cgroup_subsys_state___136 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___91 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___91 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___91 *);
	struct list_head * (*get_fields)(struct trace_event_call___91 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___91 *);
};

struct syscall_metadata___37 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___91 *enter_event;
	struct trace_event_call___91 *exit_event;
};

struct hstate___33 {
	int next_nid_to_alloc;
	int next_nid_to_free;
	unsigned int order;
	long unsigned int mask;
	long unsigned int max_huge_pages;
	long unsigned int nr_huge_pages;
	long unsigned int free_huge_pages;
	long unsigned int resv_huge_pages;
	long unsigned int surplus_huge_pages;
	long unsigned int nr_overcommit_huge_pages;
	struct list_head hugepage_activelist;
	struct list_head hugepage_freelists[8];
	unsigned int nr_huge_pages_node[8];
	unsigned int free_huge_pages_node[8];
	unsigned int surplus_huge_pages_node[8];
	struct cftype___136 cgroup_files[5];
	char name[32];
};

struct hugetlbfs_inode_info {
	struct shared_policy policy;
	struct inode___161 vfs_inode;
	unsigned int seals;
};

struct bdi_writeback_congested___78 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___78 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___78 {
	struct bio___78 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___78 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___78 bip_inline_vecs[0];
};

struct bio_set___78 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___78 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___73 {
	struct mem_cgroup___73 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___73 {
	struct lruvec___160 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___73 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___73 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct shmem_inode_info___2 {
	spinlock_t lock;
	unsigned int seals;
	long unsigned int flags;
	long unsigned int alloced;
	long unsigned int swapped;
	struct list_head shrinklist;
	struct list_head swaplist;
	struct shared_policy policy;
	struct simple_xattrs xattrs;
	struct inode___161 vfs_inode;
};

struct module___137;

struct file___162;

struct kiocb___162;

struct iov_iter___74;

struct poll_table_struct___109;

struct vm_area_struct___162;

struct inode___162;

struct file_lock___162;

struct page___162;

struct seq_file___152;

struct file_operations___162 {
	struct module___137 *owner;
	loff_t (*llseek)(struct file___162 *, loff_t, int);
	ssize_t (*read)(struct file___162 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___162 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___162 *, struct iov_iter___74 *);
	ssize_t (*write_iter)(struct kiocb___162 *, struct iov_iter___74 *);
	int (*iopoll)(struct kiocb___162 *, bool);
	int (*iterate)(struct file___162 *, struct dir_context *);
	int (*iterate_shared)(struct file___162 *, struct dir_context *);
	__poll_t (*poll)(struct file___162 *, struct poll_table_struct___109 *);
	long int (*unlocked_ioctl)(struct file___162 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___162 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___162 *, struct vm_area_struct___162 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___162 *, struct file___162 *);
	int (*flush)(struct file___162 *, fl_owner_t);
	int (*release)(struct inode___162 *, struct file___162 *);
	int (*fsync)(struct file___162 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___162 *, int);
	int (*lock)(struct file___162 *, int, struct file_lock___162 *);
	ssize_t (*sendpage)(struct file___162 *, struct page___162 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___162 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___162 *, int, struct file_lock___162 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___162 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___162 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___162 *, long int, struct file_lock___162 **, void **);
	long int (*fallocate)(struct file___162 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___152 *, struct file___162 *);
	ssize_t (*copy_file_range)(struct file___162 *, loff_t, struct file___162 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___162 *, loff_t, struct file___162 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___162 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___161 {
	u64 seqnum;
	struct vm_area_struct___162 *vmas[4];
};

struct page_frag___161 {
	struct page___162 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___99;

struct debug_info___99 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___99 *hbp_break[16];
	struct perf_event___99 *hbp_watch[16];
};

struct thread_struct___99 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___99 debug;
	long: 64;
};

struct mm_struct___161;

struct pid___127;

struct cred___157;

struct fs_struct___7;

struct files_struct___6;

struct nsproxy___153;

struct signal_struct___143;

struct bio_list___79;

struct backing_dev_info___79;

struct io_context___39;

struct css_set___137;

struct perf_event_context___99;

struct request_queue___36;

struct vm_struct___118;

struct task_struct___162 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___162 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___161 *mm;
	struct mm_struct___161 *active_mm;
	struct vmacache___161 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___162 *real_parent;
	struct task_struct___162 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___162 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___127 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___127 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___127 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___157 *ptracer_cred;
	const struct cred___157 *real_cred;
	const struct cred___157 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct___7 *fs;
	struct files_struct___6 *files;
	struct nsproxy___153 *nsproxy;
	struct signal_struct___143 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___162 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___79 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___79 *backing_dev_info;
	struct io_context___39 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___137 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___99 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___161 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___36 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___162 *oom_reaper_list;
	struct vm_struct___118 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___99 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___99 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___162 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___99)(struct perf_event___99 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___99;

struct fasync_struct___161;

struct pid_namespace___127;

struct trace_event_call___92;

struct perf_cgroup___99;

struct perf_event___99 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___99 *group_leader;
	struct pmu___99 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___99 hw;
	struct perf_event_context___99 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___99 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___162 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___161 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___99 *);
	struct callback_head callback_head;
	struct pid_namespace___127 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___99 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___99 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___92 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___99 *cgrp;
	struct list_head sb_list;
};

typedef struct page___162 *pgtable_t___161;

struct address_space___161;

struct dev_pagemap___159;

struct page___162 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___161 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___162 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___161 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___161 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___159 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___161;

struct lruvec___161 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___161 *pgdat;
};

struct zone___161 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___161 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___161 {
	struct zone___161 *zone;
	int zone_idx;
};

struct zonelist___161 {
	struct zoneref___161 _zonerefs[25];
};

struct pglist_data___161 {
	struct zone___161 node_zones[3];
	struct zonelist___161 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___162 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___162 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___161 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___162 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___162 *owner;
};

struct secondary_data___162 {
	void *stack;
	struct task_struct___162 *task;
	long int status;
};

struct blocking_notifier_head___161 {
	struct rw_semaphore___162 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___159;

struct vm_area_struct___162 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___162 *vm_next;
	struct vm_area_struct___162 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___161 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___159 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___162 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___161;

struct user_namespace___141;

struct mm_struct___161 {
	struct {
		struct vm_area_struct___162 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___162 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___162 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___161 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___162 *owner;
		struct user_namespace___141 *user_ns;
		struct file___162 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___161 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___161;

struct address_space___161 {
	struct inode___162 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___162 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___161 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___159)(struct vm_area_struct___162 *, long unsigned int, const struct page___162 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___159)(struct page___162 *, void *);

struct device___150;

struct dev_pagemap___159 {
	dev_page_fault_t___159 page_fault;
	dev_page_free_t___159 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___150 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct vfsmount___21;

struct dentry___161;

struct path___161 {
	struct vfsmount___21 *mnt;
	struct dentry___161 *dentry;
};

struct fown_struct___127 {
	rwlock_t lock;
	struct pid___127 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___162 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___161 f_path;
	struct inode___162 *f_inode;
	const struct file_operations___162 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___127 f_owner;
	const struct cred___157 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___161 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___159;

struct vm_operations_struct___159 {
	void (*open)(struct vm_area_struct___162 *);
	void (*close)(struct vm_area_struct___162 *);
	int (*split)(struct vm_area_struct___162 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___162 *);
	vm_fault_t (*fault)(struct vm_fault___159 *);
	vm_fault_t (*huge_fault)(struct vm_fault___159 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___159 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___162 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___159 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___159 *);
	int (*access)(struct vm_area_struct___162 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___162 *);
	int (*set_policy)(struct vm_area_struct___162 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___162 *, long unsigned int);
	struct page___162 * (*find_special_page)(struct vm_area_struct___162 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___161 {
	struct task_struct___162 *task;
	struct core_thread___161 *next;
};

struct core_state___161 {
	atomic_t nr_threads;
	struct core_thread___161 dumper;
	struct completion startup;
};

struct key___157;

struct ucounts___141;

struct user_namespace___141 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___141 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___4 ns;
	long unsigned int flags;
	struct key___157 *persistent_keyring_register;
	struct rw_semaphore___162 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___141 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___159 {
	struct vm_area_struct___162 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___162 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___162 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___161 prealloc_pte;
};

struct upid___127 {
	int nr;
	struct pid_namespace___127 *ns;
};

struct pid_namespace___127 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___162 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___127 *parent;
	struct vfsmount___21 *proc_mnt;
	struct dentry___161 *proc_self;
	struct dentry___161 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___141 *user_ns;
	struct ucounts___141 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___4 ns;
};

struct pid___127 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___127 numbers[1];
};

struct user_struct___157 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___157 *uid_keyring;
	struct key___157 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___157 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___157 *session_keyring;
	struct key___157 *process_keyring;
	struct key___157 *thread_keyring;
	struct key___157 *request_key_auth;
	void *security;
	struct user_struct___157 *user;
	struct user_namespace___141 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct fs_struct___7 {
	int users;
	spinlock_t lock;
	seqcount_t seq;
	int umask;
	int in_exec;
	struct path___161 root;
	struct path___161 pwd;
};

struct fdtable___6 {
	unsigned int max_fds;
	struct file___162 **fd;
	long unsigned int *close_on_exec;
	long unsigned int *open_fds;
	long unsigned int *full_fds_bits;
	struct callback_head rcu;
};

struct files_struct___6 {
	atomic_t count;
	bool resize_in_progress;
	wait_queue_head_t resize_wait;
	struct fdtable___6 *fdt;
	struct fdtable___6 fdtab;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t file_lock;
	unsigned int next_fd;
	long unsigned int close_on_exec_init[1];
	long unsigned int open_fds_init[1];
	long unsigned int full_fds_bits_init[1];
	struct file___162 *fd_array[64];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cgroup_namespace___137;

struct nsproxy___153 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___127 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___137 *cgroup_ns;
};

struct tty_struct___16;

struct signal_struct___143 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___162 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___162 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___127 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___127 *tty_old_pgrp;
	int leader;
	struct tty_struct___16 *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___161 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___127 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___79;

struct bio_list___79 {
	struct bio___79 *head;
	struct bio___79 *tail;
};

struct bdi_writeback_congested___79;

struct cgroup_subsys_state___137;

struct bdi_writeback___79 {
	struct backing_dev_info___79 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___79 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___137 *memcg_css;
	struct cgroup_subsys_state___137 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___79 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___79 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___150 *dev;
	struct device___150 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___161 *debug_dir;
	struct dentry___161 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___39;

struct io_context___39 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___39 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___137;

struct css_set___137 {
	struct cgroup_subsys_state___137 *subsys[13];
	refcount_t refcount;
	struct css_set___137 *dom_cset;
	struct cgroup___137 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___137 *mg_src_cgrp;
	struct cgroup___137 *mg_dst_cgrp;
	struct css_set___137 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___99 {
	struct pmu___99 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___162 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___99 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

typedef blk_qc_t make_request_fn___35(struct request_queue___36 *, struct bio___79 *);

struct request___36;

typedef int dma_drain_needed_fn___35(struct request___36 *);

struct kset___155;

struct kobj_type___155;

struct kernfs_node___158;

struct kobject___156 {
	const char *name;
	struct list_head entry;
	struct kobject___156 *parent;
	struct kset___155 *kset;
	struct kobj_type___155 *ktype;
	struct kernfs_node___158 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___35;

struct bsg_class_device___35 {
	struct device___150 *class_dev;
	int minor;
	struct request_queue___36 *queue;
	const struct bsg_ops___35 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___79 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___79 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___35;

struct blkcg_gq___26;

struct request_queue___36 {
	struct list_head queue_head;
	struct request___36 *last_merge;
	struct elevator_queue___35 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___35 *make_request_fn;
	dma_drain_needed_fn___35 *dma_drain_needed;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___79 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___156 kobj;
	struct kobject___156 *mq_kobj;
	struct blk_integrity integrity;
	struct device___150 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___26 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide36;
		union {		};
	};
	struct bsg_class_device___35 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___79 bio_split;
	struct dentry___161 *debugfs_dir;
	struct dentry___161 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___118 {
	struct vm_struct___118 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___162 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___144 {
	struct task_struct___162 task;
	long unsigned int stack[8192];
};

struct dev_pm_info___150 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___150 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___150;

struct bus_type___150;

struct device_driver___150;

struct dev_pm_domain___150;

struct fwnode_handle___107;

struct class___150;

struct attribute_group___151;

struct device___150 {
	struct device___150 *parent;
	struct device_private *p;
	struct kobject___156 kobj;
	const char *init_name;
	const struct device_type___150 *type;
	struct mutex mutex;
	struct bus_type___150 *bus;
	struct device_driver___150 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___150 power;
	struct dev_pm_domain___150 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___107 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___150 *class;
	const struct attribute_group___151 **groups;
	void (*release)(struct device___150 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___161;

struct super_block___161;

struct dentry___161 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___161 *d_parent;
	struct qstr d_name;
	struct inode___162 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___161 *d_op;
	struct super_block___161 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___161;

struct block_device___162;

struct cdev___30;

struct inode___162 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___161 *i_op;
	struct super_block___161 *i_sb;
	struct address_space___161 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___162 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___79 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___162 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___161 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___162 *i_bdev;
		struct cdev___30 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___161 {
	int (*d_revalidate)(struct dentry___161 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___161 *, unsigned int);
	int (*d_hash)(const struct dentry___161 *, struct qstr *);
	int (*d_compare)(const struct dentry___161 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___161 *);
	int (*d_init)(struct dentry___161 *);
	void (*d_release)(struct dentry___161 *);
	void (*d_prune)(struct dentry___161 *);
	void (*d_iput)(struct dentry___161 *, struct inode___162 *);
	char * (*d_dname)(struct dentry___161 *, char *, int);
	struct vfsmount___21 * (*d_automount)(struct path___161 *);
	int (*d_manage)(const struct path___161 *, bool);
	struct dentry___161 * (*d_real)(struct dentry___161 *, const struct inode___162 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___161;

struct mem_dqinfo___161 {
	struct quota_format_type___161 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___161;

struct quota_info___161 {
	unsigned int flags;
	struct rw_semaphore___162 dqio_sem;
	struct inode___162 *files[3];
	struct mem_dqinfo___161 info[3];
	const struct quota_format_ops___161 *ops[3];
};

struct rcuwait___161 {
	struct task_struct___162 *task;
};

struct percpu_rw_semaphore___161 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___162 rw_sem;
	struct rcuwait___161 writer;
	int readers_block;
};

struct sb_writers___161 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___161 rw_sem[3];
};

struct file_system_type___161;

struct super_operations___161;

struct dquot_operations___161;

struct quotactl_ops___161;

struct super_block___161 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___161 *s_type;
	const struct super_operations___161 *s_op;
	const struct dquot_operations___161 *dq_op;
	const struct quotactl_ops___161 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___161 *s_root;
	struct rw_semaphore___162 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___162 *s_bdev;
	struct backing_dev_info___79 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___161 s_dquot;
	struct sb_writers___161 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___161 *s_d_op;
	int cleancache_poolid;
	struct shrinker___73 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___141 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___21 {
	struct dentry___161 *mnt_root;
	struct super_block___161 *mnt_sb;
	int mnt_flags;
};

struct io_cq___39 {
	struct request_queue___36 *q;
	struct io_context___39 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___6 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___162 {
	struct file___162 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___162 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___161 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___162 *ia_file;
};

struct dquot___161 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___161 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___161 {
	int qf_fmt_id;
	const struct quota_format_ops___161 *qf_ops;
	struct module___137 *qf_owner;
	struct quota_format_type___161 *qf_next;
};

struct quota_format_ops___161 {
	int (*check_quota_file)(struct super_block___161 *, int);
	int (*read_file_info)(struct super_block___161 *, int);
	int (*write_file_info)(struct super_block___161 *, int);
	int (*free_file_info)(struct super_block___161 *, int);
	int (*read_dqblk)(struct dquot___161 *);
	int (*commit_dqblk)(struct dquot___161 *);
	int (*release_dqblk)(struct dquot___161 *);
	int (*get_next_id)(struct super_block___161 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___161 {
	int (*write_dquot)(struct dquot___161 *);
	struct dquot___161 * (*alloc_dquot)(struct super_block___161 *, int);
	void (*destroy_dquot)(struct dquot___161 *);
	int (*acquire_dquot)(struct dquot___161 *);
	int (*release_dquot)(struct dquot___161 *);
	int (*mark_dirty)(struct dquot___161 *);
	int (*write_info)(struct super_block___161 *, int);
	qsize_t * (*get_reserved_space)(struct inode___162 *);
	int (*get_projid)(struct inode___162 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___162 *, qsize_t *);
	int (*get_next_id)(struct super_block___161 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___161 {
	int (*quota_on)(struct super_block___161 *, int, int, const struct path___161 *);
	int (*quota_off)(struct super_block___161 *, int);
	int (*quota_enable)(struct super_block___161 *, unsigned int);
	int (*quota_disable)(struct super_block___161 *, unsigned int);
	int (*quota_sync)(struct super_block___161 *, int);
	int (*set_info)(struct super_block___161 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___161 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___161 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___161 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___161 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___161 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___134 {
	struct kobject___156 kobj;
	struct module___137 *mod;
	struct kobject___156 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___134 {
	struct module___137 *mod;
	struct latch_tree_node node;
};

struct module_layout___134 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___134 mtn;
};

struct module_attribute___134;

struct kernel_param___134;

struct module___137 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___134 mkobj;
	struct module_attribute___134 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___156 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___134 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___134 core_layout;
	struct module_layout___134 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___92 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___76;

struct address_space_operations___161 {
	int (*writepage)(struct page___162 *, struct writeback_control___76 *);
	int (*readpage)(struct file___162 *, struct page___162 *);
	int (*writepages)(struct address_space___161 *, struct writeback_control___76 *);
	int (*set_page_dirty)(struct page___162 *);
	int (*readpages)(struct file___162 *, struct address_space___161 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___162 *, struct address_space___161 *, loff_t, unsigned int, unsigned int, struct page___162 **, void **);
	int (*write_end)(struct file___162 *, struct address_space___161 *, loff_t, unsigned int, unsigned int, struct page___162 *, void *);
	sector_t (*bmap)(struct address_space___161 *, sector_t);
	void (*invalidatepage)(struct page___162 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___162 *, gfp_t);
	void (*freepage)(struct page___162 *);
	ssize_t (*direct_IO)(struct kiocb___162 *, struct iov_iter___74 *);
	int (*migratepage)(struct address_space___161 *, struct page___162 *, struct page___162 *, enum migrate_mode);
	bool (*isolate_page)(struct page___162 *, isolate_mode_t);
	void (*putback_page)(struct page___162 *);
	int (*launder_page)(struct page___162 *);
	int (*is_partially_uptodate)(struct page___162 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___162 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___161 *, struct page___162 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___162 *, sector_t *);
	void (*swap_deactivate)(struct file___162 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___76 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___79 *wb;
	struct inode___162 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___79;

struct iov_iter___74 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___79 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct hd_struct___36;

struct gendisk___36;

struct block_device___162 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___162 *bd_inode;
	struct super_block___161 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___162 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___36 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___36 *bd_disk;
	struct request_queue___36 *bd_queue;
	struct backing_dev_info___79 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct hd_struct___36 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___150 __dev;
	struct kobject___156 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___36;

struct block_device_operations___36;

struct gendisk___36 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___36 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___36 *part_tbl;
	struct hd_struct___36 part0;
	const struct block_device_operations___36 *fops;
	struct request_queue___36 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___162 lookup_sem;
	struct kobject___156 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___156 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___30 {
	struct kobject___156 kobj;
	struct module___137 *owner;
	const struct file_operations___162 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___161 {
	struct dentry___161 * (*lookup)(struct inode___162 *, struct dentry___161 *, unsigned int);
	const char * (*get_link)(struct dentry___161 *, struct inode___162 *, struct delayed_call *);
	int (*permission)(struct inode___162 *, int);
	struct posix_acl * (*get_acl)(struct inode___162 *, int);
	int (*readlink)(struct dentry___161 *, char *, int);
	int (*create)(struct inode___162 *, struct dentry___161 *, umode_t, bool);
	int (*link)(struct dentry___161 *, struct inode___162 *, struct dentry___161 *);
	int (*unlink)(struct inode___162 *, struct dentry___161 *);
	int (*symlink)(struct inode___162 *, struct dentry___161 *, const char *);
	int (*mkdir)(struct inode___162 *, struct dentry___161 *, umode_t);
	int (*rmdir)(struct inode___162 *, struct dentry___161 *);
	int (*mknod)(struct inode___162 *, struct dentry___161 *, umode_t, dev_t);
	int (*rename)(struct inode___162 *, struct dentry___161 *, struct inode___162 *, struct dentry___161 *, unsigned int);
	int (*setattr)(struct dentry___161 *, struct iattr___161 *);
	int (*getattr)(const struct path___161 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___161 *, char *, size_t);
	int (*fiemap)(struct inode___162 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___162 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___162 *, struct dentry___161 *, struct file___162 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___162 *, struct dentry___161 *, umode_t);
	int (*set_acl)(struct inode___162 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___161 {
	void (*fl_copy_lock)(struct file_lock___162 *, struct file_lock___162 *);
	void (*fl_release_private)(struct file_lock___162 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___161;

struct file_lock___162 {
	struct file_lock___162 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___162 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___161 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___161 *fl_ops;
	const struct lock_manager_operations___161 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___161 {
	int (*lm_compare_owner)(struct file_lock___162 *, struct file_lock___162 *);
	long unsigned int (*lm_owner_key)(struct file_lock___162 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___162 *);
	int (*lm_grant)(struct file_lock___162 *, int);
	bool (*lm_break)(struct file_lock___162 *);
	int (*lm_change)(struct file_lock___162 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___162 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___161 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___161 *fa_next;
	struct file___162 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___161 {
	const char *name;
	int fs_flags;
	struct dentry___161 * (*mount)(struct file_system_type___161 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___161 *);
	struct module___137 *owner;
	struct file_system_type___161 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___161 {
	struct inode___162 * (*alloc_inode)(struct super_block___161 *);
	void (*destroy_inode)(struct inode___162 *);
	void (*dirty_inode)(struct inode___162 *, int);
	int (*write_inode)(struct inode___162 *, struct writeback_control___76 *);
	int (*drop_inode)(struct inode___162 *);
	void (*evict_inode)(struct inode___162 *);
	void (*put_super)(struct super_block___161 *);
	int (*sync_fs)(struct super_block___161 *, int);
	int (*freeze_super)(struct super_block___161 *);
	int (*freeze_fs)(struct super_block___161 *);
	int (*thaw_super)(struct super_block___161 *);
	int (*unfreeze_fs)(struct super_block___161 *);
	int (*statfs)(struct dentry___161 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___161 *, int *, char *);
	void (*umount_begin)(struct super_block___161 *);
	int (*show_options)(struct seq_file___152 *, struct dentry___161 *);
	int (*show_devname)(struct seq_file___152 *, struct dentry___161 *);
	int (*show_path)(struct seq_file___152 *, struct dentry___161 *);
	int (*show_stats)(struct seq_file___152 *, struct dentry___161 *);
	ssize_t (*quota_read)(struct super_block___161 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___161 *, int, const char *, size_t, loff_t);
	struct dquot___161 ** (*get_dquots)(struct inode___162 *);
	int (*bdev_try_to_free_page)(struct super_block___161 *, struct page___162 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___161 *, struct shrink_control___73 *);
	long int (*free_cached_objects)(struct super_block___161 *, struct shrink_control___73 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___108)(struct file___162 *, wait_queue_head_t *, struct poll_table_struct___109 *);

struct poll_table_struct___109 {
	poll_queue_proc___108 _qproc;
	__poll_t _key;
};

struct seq_operations___150;

struct seq_file___152 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___150 *op;
	int poll_event;
	const struct file___162 *file;
	void *private;
};

enum {
	FILE_CREATED = 1,
	FILE_OPENED = 2,
};

typedef void bio_end_io_t___79(struct bio___79 *);

struct bio_vec___79 {
	struct page___162 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___79;

struct bio___79 {
	struct bio___79 *bi_next;
	struct gendisk___36 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___79 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___26 *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___79 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___79 *bi_io_vec;
	struct bio_set___79 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___79 bi_inline_vecs[0];
};

struct kobj_attribute___156 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___156 *, struct kobj_attribute___156 *, char *);
	ssize_t (*store)(struct kobject___156 *, struct kobj_attribute___156 *, const char *, size_t);
};

typedef void compound_page_dtor___159(struct page___162 *);

struct fd___10 {
	struct file___162 *file;
	unsigned int flags;
};

struct cgroup_namespace___137 {
	refcount_t count;
	struct ns_common___4 ns;
	struct user_namespace___141 *user_ns;
	struct ucounts___141 *ucounts;
	struct css_set___137 *root_cset;
};

struct key_restriction___157;

struct key___157 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___162 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___157 *restrict_link;
};

struct ucounts___141 {
	struct hlist_node node;
	struct user_namespace___141 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct seq_operations___150 {
	void * (*start)(struct seq_file___152 *, loff_t *);
	void (*stop)(struct seq_file___152 *, void *);
	void * (*next)(struct seq_file___152 *, void *, loff_t *);
	int (*show)(struct seq_file___152 *, void *);
};

typedef int (*key_restrict_link_func_t___157)(struct key___157 *, const struct key_type *, const union key_payload *, struct key___157 *);

struct key_restriction___157 {
	key_restrict_link_func_t___157 check;
	struct key___157 *key;
	struct key_type *keytype;
};

struct tty_driver___16;

struct tty_operations___16;

struct tty_ldisc___16;

struct tty_port___16;

struct tty_struct___16 {
	int magic;
	struct kref kref;
	struct device___150 *dev;
	struct tty_driver___16 *driver;
	const struct tty_operations___16 *ops;
	int index;
	struct ld_semaphore ldisc_sem;
	struct tty_ldisc___16 *ldisc;
	struct mutex atomic_write_lock;
	struct mutex legacy_mutex;
	struct mutex throttle_mutex;
	struct rw_semaphore___162 termios_rwsem;
	struct mutex winsize_mutex;
	spinlock_t ctrl_lock;
	spinlock_t flow_lock;
	struct ktermios termios;
	struct ktermios termios_locked;
	struct termiox *termiox;
	char name[64];
	struct pid___127 *pgrp;
	struct pid___127 *session;
	long unsigned int flags;
	int count;
	struct winsize winsize;
	long unsigned int stopped: 1;
	long unsigned int flow_stopped: 1;
	int: 30;
	long unsigned int unused: 62;
	int hw_stopped;
	long unsigned int ctrl_status: 8;
	long unsigned int packet: 1;
	int: 23;
	long unsigned int unused_ctrl: 55;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___16 *link;
	struct fasync_struct___161 *fasync;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	spinlock_t files_lock;
	struct list_head tty_files;
	int closing;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___16 *port;
};

struct kernfs_root___158;

struct kernfs_elem_dir___158 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___158 *root;
};

struct kernfs_syscall_ops___158;

struct kernfs_root___158 {
	struct kernfs_node___158 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___158 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___158 {
	struct kernfs_node___158 *target_kn;
};

struct kernfs_ops___158;

struct kernfs_elem_attr___158 {
	const struct kernfs_ops___158 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___158 *notify_next;
};

struct kernfs_node___158 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___158 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___158 dir;
		struct kernfs_elem_symlink___158 symlink;
		struct kernfs_elem_attr___158 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___158;

struct kernfs_ops___158 {
	int (*open)(struct kernfs_open_file___158 *);
	void (*release)(struct kernfs_open_file___158 *);
	int (*seq_show)(struct seq_file___152 *, void *);
	void * (*seq_start)(struct seq_file___152 *, loff_t *);
	void * (*seq_next)(struct seq_file___152 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___152 *, void *);
	ssize_t (*read)(struct kernfs_open_file___158 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___158 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___158 *, struct vm_area_struct___162 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___158 *, struct poll_table_struct___109 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___158 {
	int (*remount_fs)(struct kernfs_root___158 *, int *, char *);
	int (*show_options)(struct seq_file___152 *, struct kernfs_root___158 *);
	int (*mkdir)(struct kernfs_node___158 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___158 *);
	int (*rename)(struct kernfs_node___158 *, struct kernfs_node___158 *, const char *);
	int (*show_path)(struct seq_file___152 *, struct kernfs_node___158 *, struct kernfs_root___158 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___158 {
	struct kernfs_node___158 *kn;
	struct file___162 *file;
	struct seq_file___152 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___159 *vm_ops;
};

struct bin_attribute___150;

struct attribute_group___151 {
	const char *name;
	umode_t (*is_visible)(struct kobject___156 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___156 *, struct bin_attribute___150 *, int);
	struct attribute **attrs;
	struct bin_attribute___150 **bin_attrs;
};

struct bin_attribute___150 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___162 *, struct kobject___156 *, struct bin_attribute___150 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___162 *, struct kobject___156 *, struct bin_attribute___150 *, char *, loff_t, size_t);
	int (*mmap)(struct file___162 *, struct kobject___156 *, struct bin_attribute___150 *, struct vm_area_struct___162 *);
};

struct sysfs_ops___155 {
	ssize_t (*show)(struct kobject___156 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___156 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___155;

struct kset___155 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___156 kobj;
	const struct kset_uevent_ops___155 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___155 {
	void (*release)(struct kobject___156 *);
	const struct sysfs_ops___155 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___10 * (*child_ns_type)(struct kobject___156 *);
	const void * (*namespace)(struct kobject___156 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___155 {
	int (* const filter)(struct kset___155 *, struct kobject___156 *);
	const char * (* const name)(struct kset___155 *, struct kobject___156 *);
	int (* const uevent)(struct kset___155 *, struct kobject___156 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___134 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___134 *);
	int (*get)(char *, const struct kernel_param___134 *);
	void (*free)(void *);
};

struct kparam_array___134;

struct kernel_param___134 {
	const char *name;
	struct module___137 *mod;
	const struct kernel_param_ops___134 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___134 *arr;
	};
};

struct kparam_array___134 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___134 *ops;
	void *elem;
};

struct module_attribute___134 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___134 *, struct module_kobject___134 *, char *);
	ssize_t (*store)(struct module_attribute___134 *, struct module_kobject___134 *, const char *, size_t);
	void (*setup)(struct module___137 *, const char *);
	int (*test)(struct module___137 *);
	void (*free)(struct module___137 *);
};

struct trace_event_class___92;

struct trace_event_call___92 {
	struct list_head list;
	struct trace_event_class___92 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___20 *prog_array;
	int (*perf_perm)(struct trace_event_call___92 *, struct perf_event___99 *);
};

struct dev_pm_ops___150 {
	int (*prepare)(struct device___150 *);
	void (*complete)(struct device___150 *);
	int (*suspend)(struct device___150 *);
	int (*resume)(struct device___150 *);
	int (*freeze)(struct device___150 *);
	int (*thaw)(struct device___150 *);
	int (*poweroff)(struct device___150 *);
	int (*restore)(struct device___150 *);
	int (*suspend_late)(struct device___150 *);
	int (*resume_early)(struct device___150 *);
	int (*freeze_late)(struct device___150 *);
	int (*thaw_early)(struct device___150 *);
	int (*poweroff_late)(struct device___150 *);
	int (*restore_early)(struct device___150 *);
	int (*suspend_noirq)(struct device___150 *);
	int (*resume_noirq)(struct device___150 *);
	int (*freeze_noirq)(struct device___150 *);
	int (*thaw_noirq)(struct device___150 *);
	int (*poweroff_noirq)(struct device___150 *);
	int (*restore_noirq)(struct device___150 *);
	int (*runtime_suspend)(struct device___150 *);
	int (*runtime_resume)(struct device___150 *);
	int (*runtime_idle)(struct device___150 *);
};

struct dev_pm_domain___150 {
	struct dev_pm_ops___150 ops;
	void (*detach)(struct device___150 *, bool);
	int (*activate)(struct device___150 *);
	void (*sync)(struct device___150 *);
	void (*dismiss)(struct device___150 *);
};

struct bus_type___150 {
	const char *name;
	const char *dev_name;
	struct device___150 *dev_root;
	const struct attribute_group___151 **bus_groups;
	const struct attribute_group___151 **dev_groups;
	const struct attribute_group___151 **drv_groups;
	int (*match)(struct device___150 *, struct device_driver___150 *);
	int (*uevent)(struct device___150 *, struct kobj_uevent_env *);
	int (*probe)(struct device___150 *);
	int (*remove)(struct device___150 *);
	void (*shutdown)(struct device___150 *);
	int (*online)(struct device___150 *);
	int (*offline)(struct device___150 *);
	int (*suspend)(struct device___150 *, pm_message_t);
	int (*resume)(struct device___150 *);
	int (*num_vf)(struct device___150 *);
	int (*dma_configure)(struct device___150 *);
	const struct dev_pm_ops___150 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___150 {
	const char *name;
	struct bus_type___150 *bus;
	struct module___137 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___150 *);
	int (*remove)(struct device___150 *);
	void (*shutdown)(struct device___150 *);
	int (*suspend)(struct device___150 *, pm_message_t);
	int (*resume)(struct device___150 *);
	const struct attribute_group___151 **groups;
	const struct dev_pm_ops___150 *pm;
	void (*coredump)(struct device___150 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___150 {
	const char *name;
	const struct attribute_group___151 **groups;
	int (*uevent)(struct device___150 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___150 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___150 *);
	const struct dev_pm_ops___150 *pm;
};

struct class___150 {
	const char *name;
	struct module___137 *owner;
	const struct attribute_group___151 **class_groups;
	const struct attribute_group___151 **dev_groups;
	struct kobject___156 *dev_kobj;
	int (*dev_uevent)(struct device___150 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___150 *, umode_t *);
	void (*class_release)(struct class___150 *);
	void (*dev_release)(struct device___150 *);
	int (*shutdown_pre)(struct device___150 *);
	const struct kobj_ns_type_operations___10 *ns_type;
	const void * (*namespace)(struct device___150 *);
	const struct dev_pm_ops___150 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct fwnode_operations___107;

struct fwnode_handle___107 {
	struct fwnode_handle___107 *secondary;
	const struct fwnode_operations___107 *ops;
};

struct tty_operations___16 {
	struct tty_struct___16 * (*lookup)(struct tty_driver___16 *, struct file___162 *, int);
	int (*install)(struct tty_driver___16 *, struct tty_struct___16 *);
	void (*remove)(struct tty_driver___16 *, struct tty_struct___16 *);
	int (*open)(struct tty_struct___16 *, struct file___162 *);
	void (*close)(struct tty_struct___16 *, struct file___162 *);
	void (*shutdown)(struct tty_struct___16 *);
	void (*cleanup)(struct tty_struct___16 *);
	int (*write)(struct tty_struct___16 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___16 *, unsigned char);
	void (*flush_chars)(struct tty_struct___16 *);
	int (*write_room)(struct tty_struct___16 *);
	int (*chars_in_buffer)(struct tty_struct___16 *);
	int (*ioctl)(struct tty_struct___16 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___16 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___16 *, struct ktermios *);
	void (*throttle)(struct tty_struct___16 *);
	void (*unthrottle)(struct tty_struct___16 *);
	void (*stop)(struct tty_struct___16 *);
	void (*start)(struct tty_struct___16 *);
	void (*hangup)(struct tty_struct___16 *);
	int (*break_ctl)(struct tty_struct___16 *, int);
	void (*flush_buffer)(struct tty_struct___16 *);
	void (*set_ldisc)(struct tty_struct___16 *);
	void (*wait_until_sent)(struct tty_struct___16 *, int);
	void (*send_xchar)(struct tty_struct___16 *, char);
	int (*tiocmget)(struct tty_struct___16 *);
	int (*tiocmset)(struct tty_struct___16 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___16 *, struct winsize *);
	int (*set_termiox)(struct tty_struct___16 *, struct termiox *);
	int (*get_icount)(struct tty_struct___16 *, struct serial_icounter_struct *);
	void (*show_fdinfo)(struct tty_struct___16 *, struct seq_file___152 *);
	int (*poll_init)(struct tty_driver___16 *, int, char *);
	int (*poll_get_char)(struct tty_driver___16 *, int);
	void (*poll_put_char)(struct tty_driver___16 *, int, char);
	int (*proc_show)(struct seq_file___152 *, void *);
};

struct tty_driver___16 {
	int magic;
	struct kref kref;
	struct cdev___30 **cdevs;
	struct module___137 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___16 *other;
	struct tty_struct___16 **ttys;
	struct tty_port___16 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___16 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___16;

struct tty_port_client_operations___16;

struct tty_port___16 {
	struct tty_bufhead buf;
	struct tty_struct___16 *tty;
	struct tty_struct___16 *itty;
	const struct tty_port_operations___16 *ops;
	const struct tty_port_client_operations___16 *client_ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	unsigned char low_latency: 1;
	struct mutex mutex;
	struct mutex buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
	void *client_data;
};

struct tty_ldisc_ops___16 {
	int magic;
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___16 *);
	void (*close)(struct tty_struct___16 *);
	void (*flush_buffer)(struct tty_struct___16 *);
	ssize_t (*read)(struct tty_struct___16 *, struct file___162 *, unsigned char *, size_t);
	ssize_t (*write)(struct tty_struct___16 *, struct file___162 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___16 *, struct file___162 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___16 *, struct file___162 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___16 *, struct ktermios *);
	__poll_t (*poll)(struct tty_struct___16 *, struct file___162 *, struct poll_table_struct___109 *);
	int (*hangup)(struct tty_struct___16 *);
	void (*receive_buf)(struct tty_struct___16 *, const unsigned char *, char *, int);
	void (*write_wakeup)(struct tty_struct___16 *);
	void (*dcd_change)(struct tty_struct___16 *, unsigned int);
	int (*receive_buf2)(struct tty_struct___16 *, const unsigned char *, char *, int);
	struct module___137 *owner;
	int refcount;
};

struct tty_ldisc___16 {
	struct tty_ldisc_ops___16 *ops;
	struct tty_struct___16 *tty;
};

struct tty_port_operations___16 {
	int (*carrier_raised)(struct tty_port___16 *);
	void (*dtr_rts)(struct tty_port___16 *, int);
	void (*shutdown)(struct tty_port___16 *);
	int (*activate)(struct tty_port___16 *, struct tty_struct___16 *);
	void (*destruct)(struct tty_port___16 *);
};

struct tty_port_client_operations___16 {
	int (*receive_buf)(struct tty_port___16 *, const unsigned char *, const unsigned char *, size_t);
	void (*write_wakeup)(struct tty_port___16 *);
};

struct bio_integrity_payload___79 {
	struct bio___79 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___79 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___79 bip_inline_vecs[0];
};

struct blkcg___26;

struct blkg_policy_data___26;

struct blkcg_gq___26 {
	struct request_queue___36 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___26 *blkcg;
	struct bdi_writeback_congested___79 *wb_congested;
	struct blkcg_gq___26 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_rwstat stat_bytes;
	struct blkg_rwstat stat_ios;
	struct blkg_policy_data___26 *pd[5];
	struct callback_head callback_head;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
};

struct disk_part_tbl___36 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___36 *last_lookup;
	struct hd_struct___36 *part[0];
};

struct block_device_operations___36 {
	int (*open)(struct block_device___162 *, fmode_t);
	void (*release)(struct gendisk___36 *, fmode_t);
	int (*rw_page)(struct block_device___162 *, sector_t, struct page___162 *, unsigned int);
	int (*ioctl)(struct block_device___162 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___162 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___36 *, unsigned int);
	int (*media_changed)(struct gendisk___36 *);
	void (*unlock_native_capacity)(struct gendisk___36 *);
	int (*revalidate_disk)(struct gendisk___36 *);
	int (*getgeo)(struct block_device___162 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___162 *, long unsigned int);
	int (*report_zones)(struct gendisk___36 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___137 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bdi_writeback_congested___79 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___79 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct cgroup_subsys___137;

struct cgroup_subsys_state___137 {
	struct cgroup___137 *cgroup;
	struct cgroup_subsys___137 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___137 *parent;
};

struct bsg_ops___35 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___36 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___36 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___36 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___35(struct request___36 *, blk_status_t);

struct request___36 {
	struct request_queue___36 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___79 *bio;
	struct bio___79 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___79 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___39 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___35 *saved_end_io;
		} flush;
	};
	struct gendisk___36 *rq_disk;
	struct hd_struct___36 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___35 *end_io;
	void *end_io_data;
	struct request___36 *next_rq;
};

struct fwnode_reference_args___107;

struct fwnode_endpoint___107;

struct fwnode_operations___107 {
	struct fwnode_handle___107 * (*get)(struct fwnode_handle___107 *);
	void (*put)(struct fwnode_handle___107 *);
	bool (*device_is_available)(const struct fwnode_handle___107 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___107 *, const struct device___150 *);
	bool (*property_present)(const struct fwnode_handle___107 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___107 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___107 *, const char *, const char **, size_t);
	struct fwnode_handle___107 * (*get_parent)(const struct fwnode_handle___107 *);
	struct fwnode_handle___107 * (*get_next_child_node)(const struct fwnode_handle___107 *, struct fwnode_handle___107 *);
	struct fwnode_handle___107 * (*get_named_child_node)(const struct fwnode_handle___107 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___107 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___107 *);
	struct fwnode_handle___107 * (*graph_get_next_endpoint)(const struct fwnode_handle___107 *, struct fwnode_handle___107 *);
	struct fwnode_handle___107 * (*graph_get_remote_endpoint)(const struct fwnode_handle___107 *);
	struct fwnode_handle___107 * (*graph_get_port_parent)(struct fwnode_handle___107 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___107 *, struct fwnode_endpoint___107 *);
};

struct fwnode_endpoint___107 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___107 *local_fwnode;
};

struct fwnode_reference_args___107 {
	struct fwnode_handle___107 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct elevator_type___35;

struct elevator_mq_ops___35 {
	int (*init_sched)(struct request_queue___36 *, struct elevator_type___35 *);
	void (*exit_sched)(struct elevator_queue___35 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	bool (*allow_merge)(struct request_queue___36 *, struct request___36 *, struct bio___79 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx *, struct bio___79 *);
	int (*request_merge)(struct request_queue___36 *, struct request___36 **, struct bio___79 *);
	void (*request_merged)(struct request_queue___36 *, struct request___36 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___36 *, struct request___36 *, struct request___36 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___36 *, struct bio___79 *);
	void (*finish_request)(struct request___36 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___36 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___36 *, u64);
	void (*started_request)(struct request___36 *);
	void (*requeue_request)(struct request___36 *);
	struct request___36 * (*former_request)(struct request_queue___36 *, struct request___36 *);
	struct request___36 * (*next_request)(struct request_queue___36 *, struct request___36 *);
	void (*init_icq)(struct io_cq___39 *);
	void (*exit_icq)(struct io_cq___39 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide35;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___35;

struct elevator_type___35 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___35 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___35 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___137 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___35 {
	struct elevator_type___35 *type;
	void *elevator_data;
	struct kobject___156 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___35 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___35 *, char *);
	ssize_t (*store)(struct elevator_queue___35 *, const char *, size_t);
};

struct bpf_map___137;

struct bpf_map_ops___137 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___137 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___137 *, struct file___162 *);
	void (*map_free)(struct bpf_map___137 *);
	int (*map_get_next_key)(struct bpf_map___137 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___137 *);
	void * (*map_lookup_elem)(struct bpf_map___137 *, void *);
	int (*map_update_elem)(struct bpf_map___137 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___137 *, void *);
	int (*map_push_elem)(struct bpf_map___137 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___137 *, void *);
	int (*map_peek_elem)(struct bpf_map___137 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___137 *, struct file___162 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___137 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___137 *, void *, struct seq_file___152 *);
	int (*map_check_btf)(const struct bpf_map___137 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___137 {
	const struct bpf_map_ops___137 *ops;
	struct bpf_map___137 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___157 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___137;

typedef void (*kthread_work_func_t___137)(struct kthread_work___137 *);

struct kthread_worker___137;

struct kthread_work___137 {
	struct list_head node;
	kthread_work_func_t___137 func;
	struct kthread_worker___137 *worker;
	int canceling;
};

struct kthread_worker___137 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___162 *task;
	struct kthread_work___137 *current_work;
};

struct kthread_delayed_work___137 {
	struct kthread_work___137 work;
	struct timer_list timer;
};

struct psi_group___137 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___137 *poll_kworker;
	struct kthread_delayed_work___137 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___137 {
	struct kernfs_node___158 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_root___137;

struct cgroup_rstat_cpu___137;

struct cgroup___137 {
	struct cgroup_subsys_state___137 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___158 *kn;
	struct cgroup_file___137 procs_file;
	struct cgroup_file___137 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___137 *subsys[13];
	struct cgroup_root___137 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___137 *dom_cgrp;
	struct cgroup_rstat_cpu___137 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___20 bpf;
	atomic_t congestion_count;
	struct cgroup___137 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___137 psi;
	int ancestor_ids[0];
};

struct cftype___137;

struct cgroup_subsys___137 {
	struct cgroup_subsys_state___137 * (*css_alloc)(struct cgroup_subsys_state___137 *);
	int (*css_online)(struct cgroup_subsys_state___137 *);
	void (*css_offline)(struct cgroup_subsys_state___137 *);
	void (*css_released)(struct cgroup_subsys_state___137 *);
	void (*css_free)(struct cgroup_subsys_state___137 *);
	void (*css_reset)(struct cgroup_subsys_state___137 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___137 *, int);
	int (*css_extra_stat_show)(struct seq_file___152 *, struct cgroup_subsys_state___137 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___162 *);
	void (*cancel_fork)(struct task_struct___162 *);
	void (*fork)(struct task_struct___162 *);
	void (*exit)(struct task_struct___162 *);
	void (*free)(struct task_struct___162 *);
	void (*bind)(struct cgroup_subsys_state___137 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___137 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___137 *dfl_cftypes;
	struct cftype___137 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___137 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___137 *updated_children;
	struct cgroup___137 *updated_next;
};

struct cgroup_root___137 {
	struct kernfs_root___158 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___137 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___137 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___137 *ss;
	struct list_head node;
	struct kernfs_ops___158 *kf_ops;
	int (*open)(struct kernfs_open_file___158 *);
	void (*release)(struct kernfs_open_file___158 *);
	u64 (*read_u64)(struct cgroup_subsys_state___137 *, struct cftype___137 *);
	s64 (*read_s64)(struct cgroup_subsys_state___137 *, struct cftype___137 *);
	int (*seq_show)(struct seq_file___152 *, void *);
	void * (*seq_start)(struct seq_file___152 *, loff_t *);
	void * (*seq_next)(struct seq_file___152 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___152 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___137 *, struct cftype___137 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___137 *, struct cftype___137 *, s64);
	ssize_t (*write)(struct kernfs_open_file___158 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___158 *, struct poll_table_struct___109 *);
};

struct blkcg_policy_data___26;

struct blkcg___26 {
	struct cgroup_subsys_state___137 css;
	spinlock_t lock;
	struct xarray blkg_tree;
	struct blkcg_gq___26 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___26 *cpd[5];
	struct list_head all_blkcgs_node;
	struct list_head cgwb_list;
	refcount_t cgwb_refcnt;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct blkcg_policy_data___26 {
	struct blkcg___26 *blkcg;
	int plid;
};

struct blkg_policy_data___26 {
	struct blkcg_gq___26 *blkg;
	int plid;
};

struct node___128 {
	struct device___150 dev;
};

struct perf_cpu_context___99;

struct pmu___99 {
	struct list_head entry;
	struct module___137 *module;
	struct device___150 *dev;
	const struct attribute_group___151 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___99 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___99 *);
	void (*pmu_disable)(struct pmu___99 *);
	int (*event_init)(struct perf_event___99 *);
	void (*event_mapped)(struct perf_event___99 *, struct mm_struct___161 *);
	void (*event_unmapped)(struct perf_event___99 *, struct mm_struct___161 *);
	int (*add)(struct perf_event___99 *, int);
	void (*del)(struct perf_event___99 *, int);
	void (*start)(struct perf_event___99 *, int);
	void (*stop)(struct perf_event___99 *, int);
	void (*read)(struct perf_event___99 *);
	void (*start_txn)(struct pmu___99 *, unsigned int);
	int (*commit_txn)(struct pmu___99 *);
	void (*cancel_txn)(struct pmu___99 *);
	int (*event_idx)(struct perf_event___99 *);
	void (*sched_task)(struct perf_event_context___99 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___99 *);
	int (*filter_match)(struct perf_event___99 *);
	int (*check_period)(struct perf_event___99 *, u64);
};

struct perf_cpu_context___99 {
	struct perf_event_context___99 ctx;
	struct perf_event_context___99 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___99 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___99 {
	struct cgroup_subsys_state___137 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___92 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___92 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___92 *);
	struct list_head * (*get_fields)(struct trace_event_call___92 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___92 *);
};

struct syscall_metadata___38 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___92 *enter_event;
	struct trace_event_call___92 *exit_event;
};

struct kimage___13;

typedef void *kexec_load_t___13(struct kimage___13 *, char *, long unsigned int, char *, long unsigned int, char *, long unsigned int);

struct kexec_file_ops___14 {
	kexec_probe_t *probe;
	kexec_load_t___13 *load;
	kexec_cleanup_t *cleanup;
};

struct kimage___13 {
	kimage_entry_t head;
	kimage_entry_t *entry;
	kimage_entry_t *last_entry;
	long unsigned int start;
	struct page___162 *control_code_page;
	struct page___162 *swap_page;
	void *vmcoreinfo_data_copy;
	long unsigned int nr_segments;
	struct kexec_segment segment[16];
	struct list_head control_pages;
	struct list_head dest_pages;
	struct list_head unusable_pages;
	long unsigned int control_page;
	unsigned int type: 1;
	unsigned int preserve_context: 1;
	unsigned int file_mode: 1;
	struct kimage_arch arch;
	void *kernel_buf;
	long unsigned int kernel_buf_len;
	void *initrd_buf;
	long unsigned int initrd_buf_len;
	char *cmdline_buf;
	long unsigned int cmdline_buf_len;
	const struct kexec_file_ops___14 *fops;
	void *image_loader_data;
	struct purgatory_info purgatory_info;
};

struct open_flags {
	int open_flag;
	umode_t mode;
	int acc_mode;
	int intent;
	int lookup_flags;
};

struct module___138;

struct file___163;

struct kiocb___163;

struct iov_iter___75;

struct poll_table_struct___110;

struct vm_area_struct___163;

struct inode___163;

struct file_lock___163;

struct page___163;

struct pipe_inode_info___36;

struct seq_file___153;

struct file_operations___163 {
	struct module___138 *owner;
	loff_t (*llseek)(struct file___163 *, loff_t, int);
	ssize_t (*read)(struct file___163 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___163 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___163 *, struct iov_iter___75 *);
	ssize_t (*write_iter)(struct kiocb___163 *, struct iov_iter___75 *);
	int (*iopoll)(struct kiocb___163 *, bool);
	int (*iterate)(struct file___163 *, struct dir_context *);
	int (*iterate_shared)(struct file___163 *, struct dir_context *);
	__poll_t (*poll)(struct file___163 *, struct poll_table_struct___110 *);
	long int (*unlocked_ioctl)(struct file___163 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___163 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___163 *, struct vm_area_struct___163 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___163 *, struct file___163 *);
	int (*flush)(struct file___163 *, fl_owner_t);
	int (*release)(struct inode___163 *, struct file___163 *);
	int (*fsync)(struct file___163 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___163 *, int);
	int (*lock)(struct file___163 *, int, struct file_lock___163 *);
	ssize_t (*sendpage)(struct file___163 *, struct page___163 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___163 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___163 *, int, struct file_lock___163 *);
	ssize_t (*splice_write)(struct pipe_inode_info___36 *, struct file___163 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___163 *, loff_t *, struct pipe_inode_info___36 *, size_t, unsigned int);
	int (*setlease)(struct file___163 *, long int, struct file_lock___163 **, void **);
	long int (*fallocate)(struct file___163 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___153 *, struct file___163 *);
	ssize_t (*copy_file_range)(struct file___163 *, loff_t, struct file___163 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___163 *, loff_t, struct file___163 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___163 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___162 {
	u64 seqnum;
	struct vm_area_struct___163 *vmas[4];
};

struct page_frag___162 {
	struct page___163 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___100;

struct debug_info___100 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___100 *hbp_break[16];
	struct perf_event___100 *hbp_watch[16];
};

struct thread_struct___100 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___100 debug;
	long: 64;
};

struct mm_struct___162;

struct pid___128;

struct cred___158;

struct nsproxy___154;

struct signal_struct___144;

struct css_set___138;

struct perf_event_context___100;

struct task_struct___163 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___163 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___162 *mm;
	struct mm_struct___162 *active_mm;
	struct vmacache___162 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___163 *real_parent;
	struct task_struct___163 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___163 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___128 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___128 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___128 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___158 *ptracer_cred;
	const struct cred___158 *real_cred;
	const struct cred___158 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___154 *nsproxy;
	struct signal_struct___144 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___163 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___39 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___138 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___100 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___36 *splice_pipe;
	struct page_frag___162 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___163 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___100 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___100 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___163 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___100)(struct perf_event___100 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___100;

struct fasync_struct___162;

struct pid_namespace___128;

struct trace_event_call___93;

struct perf_cgroup___100;

struct perf_event___100 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___100 *group_leader;
	struct pmu___100 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___100 hw;
	struct perf_event_context___100 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___100 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___163 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___162 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___100 *);
	struct callback_head callback_head;
	struct pid_namespace___128 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___100 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___100 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___93 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___100 *cgrp;
	struct list_head sb_list;
};

typedef struct page___163 *pgtable_t___162;

struct address_space___162;

struct dev_pagemap___160;

struct page___163 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___162 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___163 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___162 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___162 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___160 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___162;

struct lruvec___162 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___162 *pgdat;
};

struct zone___162 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___162 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___162 {
	struct zone___162 *zone;
	int zone_idx;
};

struct zonelist___162 {
	struct zoneref___162 _zonerefs[25];
};

struct pglist_data___162 {
	struct zone___162 node_zones[3];
	struct zonelist___162 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___163 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___163 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___162 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___163 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___163 *owner;
};

struct secondary_data___163 {
	void *stack;
	struct task_struct___163 *task;
	long int status;
};

struct blocking_notifier_head___162 {
	struct rw_semaphore___163 rwsem;
	struct notifier_block *head;
};

struct key___158;

struct ucounts___142;

struct user_namespace___142 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___142 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___4 ns;
	long unsigned int flags;
	struct key___158 *persistent_keyring_register;
	struct rw_semaphore___163 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___142 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct upid___128 {
	int nr;
	struct pid_namespace___128 *ns;
};

struct vfsmount___22;

struct dentry___162;

struct pid_namespace___128 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___163 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___128 *parent;
	struct vfsmount___22 *proc_mnt;
	struct dentry___162 *proc_self;
	struct dentry___162 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___142 *user_ns;
	struct ucounts___142 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___4 ns;
};

struct pid___128 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___128 numbers[1];
};

struct user_struct___158 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___158 *uid_keyring;
	struct key___158 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___160;

struct vm_area_struct___163 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___163 *vm_next;
	struct vm_area_struct___163 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___162 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___160 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___163 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___162;

struct mm_struct___162 {
	struct {
		struct vm_area_struct___163 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___163 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___163 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___162 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___163 *owner;
		struct user_namespace___142 *user_ns;
		struct file___163 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___162 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___158 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___158 *session_keyring;
	struct key___158 *process_keyring;
	struct key___158 *thread_keyring;
	struct key___158 *request_key_auth;
	void *security;
	struct user_struct___158 *user;
	struct user_namespace___142 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___138;

struct nsproxy___154 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___128 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___138 *cgroup_ns;
};

struct signal_struct___144 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___163 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___163 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___128 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___128 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___162 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___128 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___138;

struct cgroup___138;

struct css_set___138 {
	struct cgroup_subsys_state___138 *subsys[13];
	refcount_t refcount;
	struct css_set___138 *dom_cset;
	struct cgroup___138 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___138 *mg_src_cgrp;
	struct cgroup___138 *mg_dst_cgrp;
	struct css_set___138 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___100 {
	struct pmu___100 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___163 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___100 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___36;

struct pipe_inode_info___36 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___163 *tmp_page;
	struct fasync_struct___162 *fasync_readers;
	struct fasync_struct___162 *fasync_writers;
	struct pipe_buffer___36 *bufs;
	struct user_struct___158 *user;
};

union thread_union___145 {
	struct task_struct___163 task;
	long unsigned int stack[8192];
};

struct fd___11 {
	struct file___163 *file;
	unsigned int flags;
};

struct path___162 {
	struct vfsmount___22 *mnt;
	struct dentry___162 *dentry;
};

struct fown_struct___128 {
	rwlock_t lock;
	struct pid___128 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___163 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___162 f_path;
	struct inode___163 *f_inode;
	const struct file_operations___163 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___128 f_owner;
	const struct cred___158 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___162 *f_mapping;
	errseq_t f_wb_err;
};

struct address_space_operations___162;

struct address_space___162 {
	struct inode___163 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___163 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___162 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___160)(struct vm_area_struct___163 *, long unsigned int, const struct page___163 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___160)(struct page___163 *, void *);

struct device___151;

struct dev_pagemap___160 {
	dev_page_fault_t___160 page_fault;
	dev_page_free_t___160 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___151 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct vm_fault___160;

struct vm_operations_struct___160 {
	void (*open)(struct vm_area_struct___163 *);
	void (*close)(struct vm_area_struct___163 *);
	int (*split)(struct vm_area_struct___163 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___163 *);
	vm_fault_t (*fault)(struct vm_fault___160 *);
	vm_fault_t (*huge_fault)(struct vm_fault___160 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___160 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___163 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___160 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___160 *);
	int (*access)(struct vm_area_struct___163 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___163 *);
	int (*set_policy)(struct vm_area_struct___163 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___163 *, long unsigned int);
	struct page___163 * (*find_special_page)(struct vm_area_struct___163 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___162 {
	struct task_struct___163 *task;
	struct core_thread___162 *next;
};

struct core_state___162 {
	atomic_t nr_threads;
	struct core_thread___162 dumper;
	struct completion startup;
};

struct vm_fault___160 {
	struct vm_area_struct___163 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___163 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___163 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___162 prealloc_pte;
};

struct kset___156;

struct kobj_type___156;

struct kernfs_node___159;

struct kobject___157 {
	const char *name;
	struct list_head entry;
	struct kobject___157 *parent;
	struct kset___156 *kset;
	struct kobj_type___156 *ktype;
	struct kernfs_node___159 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___135 {
	struct kobject___157 kobj;
	struct module___138 *mod;
	struct kobject___157 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___135 {
	struct module___138 *mod;
	struct latch_tree_node node;
};

struct module_layout___135 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___135 mtn;
};

struct module_attribute___135;

struct kernel_param___135;

struct module___138 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___135 mkobj;
	struct module_attribute___135 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___157 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___135 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___135 core_layout;
	struct module_layout___135 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___93 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct iov_iter___75 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___3 *bvec;
		struct pipe_inode_info___36 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct dentry_operations___162;

struct super_block___162;

struct dentry___162 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___162 *d_parent;
	struct qstr d_name;
	struct inode___163 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___162 *d_op;
	struct super_block___162 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___162;

struct block_device___163;

struct inode___163 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___162 *i_op;
	struct super_block___162 *i_sb;
	struct address_space___162 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___163 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___163 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___162 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___36 *i_pipe;
		struct block_device___163 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___162 {
	int (*d_revalidate)(struct dentry___162 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___162 *, unsigned int);
	int (*d_hash)(const struct dentry___162 *, struct qstr *);
	int (*d_compare)(const struct dentry___162 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___162 *);
	int (*d_init)(struct dentry___162 *);
	void (*d_release)(struct dentry___162 *);
	void (*d_prune)(struct dentry___162 *);
	void (*d_iput)(struct dentry___162 *, struct inode___163 *);
	char * (*d_dname)(struct dentry___162 *, char *, int);
	struct vfsmount___22 * (*d_automount)(struct path___162 *);
	int (*d_manage)(const struct path___162 *, bool);
	struct dentry___162 * (*d_real)(struct dentry___162 *, const struct inode___163 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___162;

struct mem_dqinfo___162 {
	struct quota_format_type___162 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___162;

struct quota_info___162 {
	unsigned int flags;
	struct rw_semaphore___163 dqio_sem;
	struct inode___163 *files[3];
	struct mem_dqinfo___162 info[3];
	const struct quota_format_ops___162 *ops[3];
};

struct rcuwait___162 {
	struct task_struct___163 *task;
};

struct percpu_rw_semaphore___162 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___163 rw_sem;
	struct rcuwait___162 writer;
	int readers_block;
};

struct sb_writers___162 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___162 rw_sem[3];
};

struct file_system_type___162;

struct super_operations___162;

struct dquot_operations___162;

struct quotactl_ops___162;

struct super_block___162 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___162 *s_type;
	const struct super_operations___162 *s_op;
	const struct dquot_operations___162 *dq_op;
	const struct quotactl_ops___162 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___162 *s_root;
	struct rw_semaphore___163 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___163 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___162 s_dquot;
	struct sb_writers___162 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___162 *s_d_op;
	int cleancache_poolid;
	struct shrinker___73 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___142 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___22 {
	struct dentry___162 *mnt_root;
	struct super_block___162 *mnt_sb;
	int mnt_flags;
};

struct file_dedupe_range_info {
	__s64 dest_fd;
	__u64 dest_offset;
	__u64 bytes_deduped;
	__s32 status;
	__u32 reserved;
};

struct file_dedupe_range {
	__u64 src_offset;
	__u64 src_length;
	__u16 dest_count;
	__u16 reserved1;
	__u32 reserved2;
	struct file_dedupe_range_info info[0];
};

typedef int __kernel_rwf_t;

typedef __kernel_rwf_t rwf_t;

struct kiocb___163 {
	struct file___163 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___163 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___162 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___163 *ia_file;
};

struct dquot___162 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___162 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___162 {
	int qf_fmt_id;
	const struct quota_format_ops___162 *qf_ops;
	struct module___138 *qf_owner;
	struct quota_format_type___162 *qf_next;
};

struct quota_format_ops___162 {
	int (*check_quota_file)(struct super_block___162 *, int);
	int (*read_file_info)(struct super_block___162 *, int);
	int (*write_file_info)(struct super_block___162 *, int);
	int (*free_file_info)(struct super_block___162 *, int);
	int (*read_dqblk)(struct dquot___162 *);
	int (*commit_dqblk)(struct dquot___162 *);
	int (*release_dqblk)(struct dquot___162 *);
	int (*get_next_id)(struct super_block___162 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___162 {
	int (*write_dquot)(struct dquot___162 *);
	struct dquot___162 * (*alloc_dquot)(struct super_block___162 *, int);
	void (*destroy_dquot)(struct dquot___162 *);
	int (*acquire_dquot)(struct dquot___162 *);
	int (*release_dquot)(struct dquot___162 *);
	int (*mark_dirty)(struct dquot___162 *);
	int (*write_info)(struct super_block___162 *, int);
	qsize_t * (*get_reserved_space)(struct inode___163 *);
	int (*get_projid)(struct inode___163 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___163 *, qsize_t *);
	int (*get_next_id)(struct super_block___162 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___162 {
	int (*quota_on)(struct super_block___162 *, int, int, const struct path___162 *);
	int (*quota_off)(struct super_block___162 *, int);
	int (*quota_enable)(struct super_block___162 *, unsigned int);
	int (*quota_disable)(struct super_block___162 *, unsigned int);
	int (*quota_sync)(struct super_block___162 *, int);
	int (*set_info)(struct super_block___162 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___162 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___162 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___162 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___162 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___162 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___162 {
	int (*writepage)(struct page___163 *, struct writeback_control___3 *);
	int (*readpage)(struct file___163 *, struct page___163 *);
	int (*writepages)(struct address_space___162 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___163 *);
	int (*readpages)(struct file___163 *, struct address_space___162 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___163 *, struct address_space___162 *, loff_t, unsigned int, unsigned int, struct page___163 **, void **);
	int (*write_end)(struct file___163 *, struct address_space___162 *, loff_t, unsigned int, unsigned int, struct page___163 *, void *);
	sector_t (*bmap)(struct address_space___162 *, sector_t);
	void (*invalidatepage)(struct page___163 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___163 *, gfp_t);
	void (*freepage)(struct page___163 *);
	ssize_t (*direct_IO)(struct kiocb___163 *, struct iov_iter___75 *);
	int (*migratepage)(struct address_space___162 *, struct page___163 *, struct page___163 *, enum migrate_mode);
	bool (*isolate_page)(struct page___163 *, isolate_mode_t);
	void (*putback_page)(struct page___163 *);
	int (*launder_page)(struct page___163 *);
	int (*is_partially_uptodate)(struct page___163 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___163 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___162 *, struct page___163 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___163 *, sector_t *);
	void (*swap_deactivate)(struct file___163 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___163 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___163 *bd_inode;
	struct super_block___162 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___163 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___162 {
	struct dentry___162 * (*lookup)(struct inode___163 *, struct dentry___162 *, unsigned int);
	const char * (*get_link)(struct dentry___162 *, struct inode___163 *, struct delayed_call *);
	int (*permission)(struct inode___163 *, int);
	struct posix_acl * (*get_acl)(struct inode___163 *, int);
	int (*readlink)(struct dentry___162 *, char *, int);
	int (*create)(struct inode___163 *, struct dentry___162 *, umode_t, bool);
	int (*link)(struct dentry___162 *, struct inode___163 *, struct dentry___162 *);
	int (*unlink)(struct inode___163 *, struct dentry___162 *);
	int (*symlink)(struct inode___163 *, struct dentry___162 *, const char *);
	int (*mkdir)(struct inode___163 *, struct dentry___162 *, umode_t);
	int (*rmdir)(struct inode___163 *, struct dentry___162 *);
	int (*mknod)(struct inode___163 *, struct dentry___162 *, umode_t, dev_t);
	int (*rename)(struct inode___163 *, struct dentry___162 *, struct inode___163 *, struct dentry___162 *, unsigned int);
	int (*setattr)(struct dentry___162 *, struct iattr___162 *);
	int (*getattr)(const struct path___162 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___162 *, char *, size_t);
	int (*fiemap)(struct inode___163 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___163 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___163 *, struct dentry___162 *, struct file___163 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___163 *, struct dentry___162 *, umode_t);
	int (*set_acl)(struct inode___163 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___162 {
	void (*fl_copy_lock)(struct file_lock___163 *, struct file_lock___163 *);
	void (*fl_release_private)(struct file_lock___163 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___162;

struct file_lock___163 {
	struct file_lock___163 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___163 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___162 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___162 *fl_ops;
	const struct lock_manager_operations___162 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___162 {
	int (*lm_compare_owner)(struct file_lock___163 *, struct file_lock___163 *);
	long unsigned int (*lm_owner_key)(struct file_lock___163 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___163 *);
	int (*lm_grant)(struct file_lock___163 *, int);
	bool (*lm_break)(struct file_lock___163 *);
	int (*lm_change)(struct file_lock___163 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___163 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___162 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___162 *fa_next;
	struct file___163 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___162 {
	const char *name;
	int fs_flags;
	struct dentry___162 * (*mount)(struct file_system_type___162 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___162 *);
	struct module___138 *owner;
	struct file_system_type___162 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___162 {
	struct inode___163 * (*alloc_inode)(struct super_block___162 *);
	void (*destroy_inode)(struct inode___163 *);
	void (*dirty_inode)(struct inode___163 *, int);
	int (*write_inode)(struct inode___163 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___163 *);
	void (*evict_inode)(struct inode___163 *);
	void (*put_super)(struct super_block___162 *);
	int (*sync_fs)(struct super_block___162 *, int);
	int (*freeze_super)(struct super_block___162 *);
	int (*freeze_fs)(struct super_block___162 *);
	int (*thaw_super)(struct super_block___162 *);
	int (*unfreeze_fs)(struct super_block___162 *);
	int (*statfs)(struct dentry___162 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___162 *, int *, char *);
	void (*umount_begin)(struct super_block___162 *);
	int (*show_options)(struct seq_file___153 *, struct dentry___162 *);
	int (*show_devname)(struct seq_file___153 *, struct dentry___162 *);
	int (*show_path)(struct seq_file___153 *, struct dentry___162 *);
	int (*show_stats)(struct seq_file___153 *, struct dentry___162 *);
	ssize_t (*quota_read)(struct super_block___162 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___162 *, int, const char *, size_t, loff_t);
	struct dquot___162 ** (*get_dquots)(struct inode___163 *);
	int (*bdev_try_to_free_page)(struct super_block___162 *, struct page___163 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___162 *, struct shrink_control___73 *);
	long int (*free_cached_objects)(struct super_block___162 *, struct shrink_control___73 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___109)(struct file___163 *, wait_queue_head_t *, struct poll_table_struct___110 *);

struct poll_table_struct___110 {
	poll_queue_proc___109 _qproc;
	__poll_t _key;
};

struct seq_operations___151;

struct seq_file___153 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___151 *op;
	int poll_event;
	const struct file___163 *file;
	void *private;
};

struct cgroup_namespace___138 {
	refcount_t count;
	struct ns_common___4 ns;
	struct user_namespace___142 *user_ns;
	struct ucounts___142 *ucounts;
	struct css_set___138 *root_cset;
};

struct key_restriction___158;

struct key___158 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___163 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___158 *restrict_link;
};

struct ucounts___142 {
	struct hlist_node node;
	struct user_namespace___142 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct seq_operations___151 {
	void * (*start)(struct seq_file___153 *, loff_t *);
	void (*stop)(struct seq_file___153 *, void *);
	void * (*next)(struct seq_file___153 *, void *, loff_t *);
	int (*show)(struct seq_file___153 *, void *);
};

typedef int (*key_restrict_link_func_t___158)(struct key___158 *, const struct key_type *, const union key_payload *, struct key___158 *);

struct key_restriction___158 {
	key_restrict_link_func_t___158 check;
	struct key___158 *key;
	struct key_type *keytype;
};

struct dev_pm_info___151 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___151 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___151;

struct bus_type___151;

struct device_driver___151;

struct dev_pm_domain___151;

struct class___151;

struct attribute_group___152;

struct device___151 {
	struct device___151 *parent;
	struct device_private *p;
	struct kobject___157 kobj;
	const char *init_name;
	const struct device_type___151 *type;
	struct mutex mutex;
	struct bus_type___151 *bus;
	struct device_driver___151 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___151 power;
	struct dev_pm_domain___151 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___151 *class;
	const struct attribute_group___152 **groups;
	void (*release)(struct device___151 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct kobj_attribute___157 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___157 *, struct kobj_attribute___157 *, char *);
	ssize_t (*store)(struct kobject___157 *, struct kobj_attribute___157 *, const char *, size_t);
};

typedef void compound_page_dtor___160(struct page___163 *);

struct kernfs_root___159;

struct kernfs_elem_dir___159 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___159 *root;
};

struct kernfs_syscall_ops___159;

struct kernfs_root___159 {
	struct kernfs_node___159 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___159 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___159 {
	struct kernfs_node___159 *target_kn;
};

struct kernfs_ops___159;

struct kernfs_elem_attr___159 {
	const struct kernfs_ops___159 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___159 *notify_next;
};

struct kernfs_node___159 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___159 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___159 dir;
		struct kernfs_elem_symlink___159 symlink;
		struct kernfs_elem_attr___159 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___159;

struct kernfs_ops___159 {
	int (*open)(struct kernfs_open_file___159 *);
	void (*release)(struct kernfs_open_file___159 *);
	int (*seq_show)(struct seq_file___153 *, void *);
	void * (*seq_start)(struct seq_file___153 *, loff_t *);
	void * (*seq_next)(struct seq_file___153 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___153 *, void *);
	ssize_t (*read)(struct kernfs_open_file___159 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___159 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___159 *, struct vm_area_struct___163 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___159 *, struct poll_table_struct___110 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___159 {
	int (*remount_fs)(struct kernfs_root___159 *, int *, char *);
	int (*show_options)(struct seq_file___153 *, struct kernfs_root___159 *);
	int (*mkdir)(struct kernfs_node___159 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___159 *);
	int (*rename)(struct kernfs_node___159 *, struct kernfs_node___159 *, const char *);
	int (*show_path)(struct seq_file___153 *, struct kernfs_node___159 *, struct kernfs_root___159 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___159 {
	struct kernfs_node___159 *kn;
	struct file___163 *file;
	struct seq_file___153 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___160 *vm_ops;
};

struct bin_attribute___151;

struct attribute_group___152 {
	const char *name;
	umode_t (*is_visible)(struct kobject___157 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___157 *, struct bin_attribute___151 *, int);
	struct attribute **attrs;
	struct bin_attribute___151 **bin_attrs;
};

struct bin_attribute___151 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___163 *, struct kobject___157 *, struct bin_attribute___151 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___163 *, struct kobject___157 *, struct bin_attribute___151 *, char *, loff_t, size_t);
	int (*mmap)(struct file___163 *, struct kobject___157 *, struct bin_attribute___151 *, struct vm_area_struct___163 *);
};

struct sysfs_ops___156 {
	ssize_t (*show)(struct kobject___157 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___157 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___156;

struct kset___156 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___157 kobj;
	const struct kset_uevent_ops___156 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___156 {
	void (*release)(struct kobject___157 *);
	const struct sysfs_ops___156 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___10 * (*child_ns_type)(struct kobject___157 *);
	const void * (*namespace)(struct kobject___157 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___156 {
	int (* const filter)(struct kset___156 *, struct kobject___157 *);
	const char * (* const name)(struct kset___156 *, struct kobject___157 *);
	int (* const uevent)(struct kset___156 *, struct kobject___157 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___135 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___135 *);
	int (*get)(char *, const struct kernel_param___135 *);
	void (*free)(void *);
};

struct kparam_array___135;

struct kernel_param___135 {
	const char *name;
	struct module___138 *mod;
	const struct kernel_param_ops___135 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___135 *arr;
	};
};

struct kparam_array___135 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___135 *ops;
	void *elem;
};

struct module_attribute___135 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___135 *, struct module_kobject___135 *, char *);
	ssize_t (*store)(struct module_attribute___135 *, struct module_kobject___135 *, const char *, size_t);
	void (*setup)(struct module___138 *, const char *);
	int (*test)(struct module___138 *);
	void (*free)(struct module___138 *);
};

struct trace_event_class___93;

struct trace_event_call___93 {
	struct list_head list;
	struct trace_event_class___93 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___20 *prog_array;
	int (*perf_perm)(struct trace_event_call___93 *, struct perf_event___100 *);
};

struct dev_pm_ops___151 {
	int (*prepare)(struct device___151 *);
	void (*complete)(struct device___151 *);
	int (*suspend)(struct device___151 *);
	int (*resume)(struct device___151 *);
	int (*freeze)(struct device___151 *);
	int (*thaw)(struct device___151 *);
	int (*poweroff)(struct device___151 *);
	int (*restore)(struct device___151 *);
	int (*suspend_late)(struct device___151 *);
	int (*resume_early)(struct device___151 *);
	int (*freeze_late)(struct device___151 *);
	int (*thaw_early)(struct device___151 *);
	int (*poweroff_late)(struct device___151 *);
	int (*restore_early)(struct device___151 *);
	int (*suspend_noirq)(struct device___151 *);
	int (*resume_noirq)(struct device___151 *);
	int (*freeze_noirq)(struct device___151 *);
	int (*thaw_noirq)(struct device___151 *);
	int (*poweroff_noirq)(struct device___151 *);
	int (*restore_noirq)(struct device___151 *);
	int (*runtime_suspend)(struct device___151 *);
	int (*runtime_resume)(struct device___151 *);
	int (*runtime_idle)(struct device___151 *);
};

struct dev_pm_domain___151 {
	struct dev_pm_ops___151 ops;
	void (*detach)(struct device___151 *, bool);
	int (*activate)(struct device___151 *);
	void (*sync)(struct device___151 *);
	void (*dismiss)(struct device___151 *);
};

struct bus_type___151 {
	const char *name;
	const char *dev_name;
	struct device___151 *dev_root;
	const struct attribute_group___152 **bus_groups;
	const struct attribute_group___152 **dev_groups;
	const struct attribute_group___152 **drv_groups;
	int (*match)(struct device___151 *, struct device_driver___151 *);
	int (*uevent)(struct device___151 *, struct kobj_uevent_env *);
	int (*probe)(struct device___151 *);
	int (*remove)(struct device___151 *);
	void (*shutdown)(struct device___151 *);
	int (*online)(struct device___151 *);
	int (*offline)(struct device___151 *);
	int (*suspend)(struct device___151 *, pm_message_t);
	int (*resume)(struct device___151 *);
	int (*num_vf)(struct device___151 *);
	int (*dma_configure)(struct device___151 *);
	const struct dev_pm_ops___151 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___151 {
	const char *name;
	struct bus_type___151 *bus;
	struct module___138 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___151 *);
	int (*remove)(struct device___151 *);
	void (*shutdown)(struct device___151 *);
	int (*suspend)(struct device___151 *, pm_message_t);
	int (*resume)(struct device___151 *);
	const struct attribute_group___152 **groups;
	const struct dev_pm_ops___151 *pm;
	void (*coredump)(struct device___151 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___151 {
	const char *name;
	const struct attribute_group___152 **groups;
	int (*uevent)(struct device___151 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___151 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___151 *);
	const struct dev_pm_ops___151 *pm;
};

struct class___151 {
	const char *name;
	struct module___138 *owner;
	const struct attribute_group___152 **class_groups;
	const struct attribute_group___152 **dev_groups;
	struct kobject___157 *dev_kobj;
	int (*dev_uevent)(struct device___151 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___151 *, umode_t *);
	void (*class_release)(struct class___151 *);
	void (*dev_release)(struct device___151 *);
	int (*shutdown_pre)(struct device___151 *);
	const struct kobj_ns_type_operations___10 *ns_type;
	const void * (*namespace)(struct device___151 *);
	const struct dev_pm_ops___151 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___129 {
	struct device___151 dev;
};

struct bpf_map___138;

struct bpf_map_ops___138 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___138 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___138 *, struct file___163 *);
	void (*map_free)(struct bpf_map___138 *);
	int (*map_get_next_key)(struct bpf_map___138 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___138 *);
	void * (*map_lookup_elem)(struct bpf_map___138 *, void *);
	int (*map_update_elem)(struct bpf_map___138 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___138 *, void *);
	int (*map_push_elem)(struct bpf_map___138 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___138 *, void *);
	int (*map_peek_elem)(struct bpf_map___138 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___138 *, struct file___163 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___138 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___138 *, void *, struct seq_file___153 *);
	int (*map_check_btf)(const struct bpf_map___138 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___138 {
	const struct bpf_map_ops___138 *ops;
	struct bpf_map___138 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___158 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___138;

typedef void (*kthread_work_func_t___138)(struct kthread_work___138 *);

struct kthread_worker___138;

struct kthread_work___138 {
	struct list_head node;
	kthread_work_func_t___138 func;
	struct kthread_worker___138 *worker;
	int canceling;
};

struct kthread_worker___138 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___163 *task;
	struct kthread_work___138 *current_work;
};

struct kthread_delayed_work___138 {
	struct kthread_work___138 work;
	struct timer_list timer;
};

struct psi_group___138 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___138 *poll_kworker;
	struct kthread_delayed_work___138 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___138 {
	struct kernfs_node___159 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___138;

struct cgroup_subsys_state___138 {
	struct cgroup___138 *cgroup;
	struct cgroup_subsys___138 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___138 *parent;
};

struct cgroup_root___138;

struct cgroup_rstat_cpu___138;

struct cgroup___138 {
	struct cgroup_subsys_state___138 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___159 *kn;
	struct cgroup_file___138 procs_file;
	struct cgroup_file___138 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___138 *subsys[13];
	struct cgroup_root___138 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___138 *dom_cgrp;
	struct cgroup_rstat_cpu___138 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___20 bpf;
	atomic_t congestion_count;
	struct cgroup___138 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___138 psi;
	int ancestor_ids[0];
};

struct cftype___138;

struct cgroup_subsys___138 {
	struct cgroup_subsys_state___138 * (*css_alloc)(struct cgroup_subsys_state___138 *);
	int (*css_online)(struct cgroup_subsys_state___138 *);
	void (*css_offline)(struct cgroup_subsys_state___138 *);
	void (*css_released)(struct cgroup_subsys_state___138 *);
	void (*css_free)(struct cgroup_subsys_state___138 *);
	void (*css_reset)(struct cgroup_subsys_state___138 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___138 *, int);
	int (*css_extra_stat_show)(struct seq_file___153 *, struct cgroup_subsys_state___138 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___163 *);
	void (*cancel_fork)(struct task_struct___163 *);
	void (*fork)(struct task_struct___163 *);
	void (*exit)(struct task_struct___163 *);
	void (*free)(struct task_struct___163 *);
	void (*bind)(struct cgroup_subsys_state___138 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___138 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___138 *dfl_cftypes;
	struct cftype___138 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___138 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___138 *updated_children;
	struct cgroup___138 *updated_next;
};

struct cgroup_root___138 {
	struct kernfs_root___159 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___138 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___138 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___138 *ss;
	struct list_head node;
	struct kernfs_ops___159 *kf_ops;
	int (*open)(struct kernfs_open_file___159 *);
	void (*release)(struct kernfs_open_file___159 *);
	u64 (*read_u64)(struct cgroup_subsys_state___138 *, struct cftype___138 *);
	s64 (*read_s64)(struct cgroup_subsys_state___138 *, struct cftype___138 *);
	int (*seq_show)(struct seq_file___153 *, void *);
	void * (*seq_start)(struct seq_file___153 *, loff_t *);
	void * (*seq_next)(struct seq_file___153 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___153 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___138 *, struct cftype___138 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___138 *, struct cftype___138 *, s64);
	ssize_t (*write)(struct kernfs_open_file___159 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___159 *, struct poll_table_struct___110 *);
};

struct perf_cpu_context___100;

struct pmu___100 {
	struct list_head entry;
	struct module___138 *module;
	struct device___151 *dev;
	const struct attribute_group___152 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___100 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___100 *);
	void (*pmu_disable)(struct pmu___100 *);
	int (*event_init)(struct perf_event___100 *);
	void (*event_mapped)(struct perf_event___100 *, struct mm_struct___162 *);
	void (*event_unmapped)(struct perf_event___100 *, struct mm_struct___162 *);
	int (*add)(struct perf_event___100 *, int);
	void (*del)(struct perf_event___100 *, int);
	void (*start)(struct perf_event___100 *, int);
	void (*stop)(struct perf_event___100 *, int);
	void (*read)(struct perf_event___100 *);
	void (*start_txn)(struct pmu___100 *, unsigned int);
	int (*commit_txn)(struct pmu___100 *);
	void (*cancel_txn)(struct pmu___100 *);
	int (*event_idx)(struct perf_event___100 *);
	void (*sched_task)(struct perf_event_context___100 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___100 *);
	int (*filter_match)(struct perf_event___100 *);
	int (*check_period)(struct perf_event___100 *, u64);
};

struct perf_cpu_context___100 {
	struct perf_event_context___100 ctx;
	struct perf_event_context___100 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___100 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___100 {
	struct cgroup_subsys_state___138 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___93 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___93 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___93 *);
	struct list_head * (*get_fields)(struct trace_event_call___93 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___93 *);
};

struct syscall_metadata___39 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___93 *enter_event;
	struct trace_event_call___93 *exit_event;
};

typedef int filler_t___4(void *, struct page___163 *);

struct pipe_buf_operations___36;

struct pipe_buffer___36 {
	struct page___163 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___36 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___36 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___36 *, struct pipe_buffer___36 *);
	void (*release)(struct pipe_inode_info___36 *, struct pipe_buffer___36 *);
	int (*steal)(struct pipe_inode_info___36 *, struct pipe_buffer___36 *);
	union {
		bool (*get)(struct pipe_inode_info___36 *, struct pipe_buffer___36 *);
		struct {
			void (*get)(struct pipe_inode_info___36 *, struct pipe_buffer___36 *);
		} __UNIQUE_ID_rh_kabi_hide21;
		union {		};
	};
};

struct module___139;

struct file___164;

struct kiocb___164;

struct iov_iter___76;

struct vm_area_struct___164;

struct inode___164;

struct file_lock___164;

struct page___164;

struct seq_file___154;

struct file_operations___164 {
	struct module___139 *owner;
	loff_t (*llseek)(struct file___164 *, loff_t, int);
	ssize_t (*read)(struct file___164 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___164 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___164 *, struct iov_iter___76 *);
	ssize_t (*write_iter)(struct kiocb___164 *, struct iov_iter___76 *);
	int (*iopoll)(struct kiocb___164 *, bool);
	int (*iterate)(struct file___164 *, struct dir_context *);
	int (*iterate_shared)(struct file___164 *, struct dir_context *);
	__poll_t (*poll)(struct file___164 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___164 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___164 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___164 *, struct vm_area_struct___164 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___164 *, struct file___164 *);
	int (*flush)(struct file___164 *, fl_owner_t);
	int (*release)(struct inode___164 *, struct file___164 *);
	int (*fsync)(struct file___164 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___164 *, int);
	int (*lock)(struct file___164 *, int, struct file_lock___164 *);
	ssize_t (*sendpage)(struct file___164 *, struct page___164 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___164 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___164 *, int, struct file_lock___164 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___164 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___164 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___164 *, long int, struct file_lock___164 **, void **);
	long int (*fallocate)(struct file___164 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___154 *, struct file___164 *);
	ssize_t (*copy_file_range)(struct file___164 *, loff_t, struct file___164 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___164 *, loff_t, struct file___164 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___164 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___163 {
	u64 seqnum;
	struct vm_area_struct___164 *vmas[4];
};

struct page_frag___163 {
	struct page___164 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___163;

struct mem_cgroup___74;

struct pid___129;

struct cred___159;

struct files_struct___7;

struct nsproxy___155;

struct signal_struct___145;

struct bio_list___80;

struct backing_dev_info___80;

struct css_set___139;

struct vm_struct___119;

struct task_struct___164 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___164 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___163 *mm;
	struct mm_struct___163 *active_mm;
	struct vmacache___163 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___164 *real_parent;
	struct task_struct___164 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___164 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___74 *active_memcg;
	long int rh_reserved2;
	struct pid___129 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___129 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___129 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___159 *ptracer_cred;
	const struct cred___159 *real_cred;
	const struct cred___159 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct___7 *files;
	struct nsproxy___155 *nsproxy;
	struct signal_struct___145 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___164 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___80 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___80 *backing_dev_info;
	struct io_context___39 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___139 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___163 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___74 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___164 *oom_reaper_list;
	struct vm_struct___119 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___100 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___164 *pgtable_t___163;

struct address_space___163;

struct dev_pagemap___161;

struct page___164 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___163 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___164 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___163 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___163 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___161 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___74 *mem_cgroup;
};

struct pglist_data___163;

struct lruvec___163 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___163 *pgdat;
};

struct zone___163 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___163 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___163 {
	struct zone___163 *zone;
	int zone_idx;
};

struct zonelist___163 {
	struct zoneref___163 _zonerefs[25];
};

struct pglist_data___163 {
	struct zone___163 node_zones[3];
	struct zonelist___163 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___164 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___164 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___163 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___164 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___164 *owner;
};

struct secondary_data___164 {
	void *stack;
	struct task_struct___164 *task;
	long int status;
};

struct blocking_notifier_head___163 {
	struct rw_semaphore___164 rwsem;
	struct notifier_block *head;
};

struct cgroup___139;

struct cgroup_subsys___139;

struct cgroup_subsys_state___139 {
	struct cgroup___139 *cgroup;
	struct cgroup_subsys___139 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___139 *parent;
};

struct kernfs_node___160;

struct cgroup_file___139 {
	struct kernfs_node___160 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___74;

struct mem_cgroup___74 {
	struct cgroup_subsys_state___139 css;
	struct mem_cgroup_id___5 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___139 events_file;
	struct cgroup_file___139 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___164 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___74 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct vfsmount___23;

struct dentry___163;

struct path___163 {
	struct vfsmount___23 *mnt;
	struct dentry___163 *dentry;
};

struct fown_struct___129 {
	rwlock_t lock;
	struct pid___129 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___164 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___163 f_path;
	struct inode___164 *f_inode;
	const struct file_operations___164 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___129 f_owner;
	const struct cred___159 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___163 *f_mapping;
	errseq_t f_wb_err;
};

struct dentry_operations___163;

struct super_block___163;

struct dentry___163 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___163 *d_parent;
	struct qstr d_name;
	struct inode___164 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___163 *d_op;
	struct super_block___163 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___163;

struct address_space___163 {
	struct inode___164 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___164 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___163 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___163;

struct bdi_writeback___80;

struct block_device___164;

struct cdev___31;

struct inode___164 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___163 *i_op;
	struct super_block___163 *i_sb;
	struct address_space___163 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___164 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___80 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___164 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___163 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___164 *i_bdev;
		struct cdev___31 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___163 {
	int (*d_revalidate)(struct dentry___163 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___163 *, unsigned int);
	int (*d_hash)(const struct dentry___163 *, struct qstr *);
	int (*d_compare)(const struct dentry___163 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___163 *);
	int (*d_init)(struct dentry___163 *);
	void (*d_release)(struct dentry___163 *);
	void (*d_prune)(struct dentry___163 *);
	void (*d_iput)(struct dentry___163 *, struct inode___164 *);
	char * (*d_dname)(struct dentry___163 *, char *, int);
	struct vfsmount___23 * (*d_automount)(struct path___163 *);
	int (*d_manage)(const struct path___163 *, bool);
	struct dentry___163 * (*d_real)(struct dentry___163 *, const struct inode___164 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___163;

struct mem_dqinfo___163 {
	struct quota_format_type___163 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___163;

struct quota_info___163 {
	unsigned int flags;
	struct rw_semaphore___164 dqio_sem;
	struct inode___164 *files[3];
	struct mem_dqinfo___163 info[3];
	const struct quota_format_ops___163 *ops[3];
};

struct rcuwait___163 {
	struct task_struct___164 *task;
};

struct percpu_rw_semaphore___163 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___164 rw_sem;
	struct rcuwait___163 writer;
	int readers_block;
};

struct sb_writers___163 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___163 rw_sem[3];
};

struct shrink_control___74;

struct shrinker___74 {
	long unsigned int (*count_objects)(struct shrinker___74 *, struct shrink_control___74 *);
	long unsigned int (*scan_objects)(struct shrinker___74 *, struct shrink_control___74 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___163;

struct super_operations___163;

struct dquot_operations___163;

struct quotactl_ops___163;

struct user_namespace___143;

struct super_block___163 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___163 *s_type;
	const struct super_operations___163 *s_op;
	const struct dquot_operations___163 *dq_op;
	const struct quotactl_ops___163 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___163 *s_root;
	struct rw_semaphore___164 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___164 *s_bdev;
	struct backing_dev_info___80 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___163 s_dquot;
	struct sb_writers___163 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___163 *s_d_op;
	int cleancache_poolid;
	struct shrinker___74 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___143 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___23 {
	struct dentry___163 *mnt_root;
	struct super_block___163 *mnt_sb;
	int mnt_flags;
};

struct key___159;

struct ucounts___143;

struct user_namespace___143 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___143 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___4 ns;
	long unsigned int flags;
	struct key___159 *persistent_keyring_register;
	struct rw_semaphore___164 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___143 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct shrink_control___74 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___74 *memcg;
};

struct pid_namespace___129;

struct upid___129 {
	int nr;
	struct pid_namespace___129 *ns;
};

struct pid_namespace___129 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___164 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___129 *parent;
	struct vfsmount___23 *proc_mnt;
	struct dentry___163 *proc_self;
	struct dentry___163 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___143 *user_ns;
	struct ucounts___143 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___4 ns;
};

struct pid___129 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___129 numbers[1];
};

struct vm_operations_struct___161;

struct vm_area_struct___164 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___164 *vm_next;
	struct vm_area_struct___164 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___163 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___161 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___164 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___163;

struct mm_struct___163 {
	struct {
		struct vm_area_struct___164 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___164 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___164 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___163 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___164 *owner;
		struct user_namespace___143 *user_ns;
		struct file___164 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___163 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___161)(struct vm_area_struct___164 *, long unsigned int, const struct page___164 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___161)(struct page___164 *, void *);

struct device___152;

struct dev_pagemap___161 {
	dev_page_fault_t___161 page_fault;
	dev_page_free_t___161 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___152 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct vm_fault___161;

struct vm_operations_struct___161 {
	void (*open)(struct vm_area_struct___164 *);
	void (*close)(struct vm_area_struct___164 *);
	int (*split)(struct vm_area_struct___164 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___164 *);
	vm_fault_t (*fault)(struct vm_fault___161 *);
	vm_fault_t (*huge_fault)(struct vm_fault___161 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___161 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___164 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___161 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___161 *);
	int (*access)(struct vm_area_struct___164 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___164 *);
	int (*set_policy)(struct vm_area_struct___164 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___164 *, long unsigned int);
	struct page___164 * (*find_special_page)(struct vm_area_struct___164 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___163 {
	struct task_struct___164 *task;
	struct core_thread___163 *next;
};

struct core_state___163 {
	atomic_t nr_threads;
	struct core_thread___163 dumper;
	struct completion startup;
};

struct vm_fault___161 {
	struct vm_area_struct___164 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___164 *cow_page;
	struct mem_cgroup___74 *memcg;
	struct page___164 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___163 prealloc_pte;
};

struct user_struct___159 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___159 *uid_keyring;
	struct key___159 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___159 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___159 *session_keyring;
	struct key___159 *process_keyring;
	struct key___159 *thread_keyring;
	struct key___159 *request_key_auth;
	void *security;
	struct user_struct___159 *user;
	struct user_namespace___143 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct fdtable___7 {
	unsigned int max_fds;
	struct file___164 **fd;
	long unsigned int *close_on_exec;
	long unsigned int *open_fds;
	long unsigned int *full_fds_bits;
	struct callback_head rcu;
};

struct files_struct___7 {
	atomic_t count;
	bool resize_in_progress;
	wait_queue_head_t resize_wait;
	struct fdtable___7 *fdt;
	struct fdtable___7 fdtab;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t file_lock;
	unsigned int next_fd;
	long unsigned int close_on_exec_init[1];
	long unsigned int open_fds_init[1];
	long unsigned int full_fds_bits_init[1];
	struct file___164 *fd_array[64];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cgroup_namespace___139;

struct nsproxy___155 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___129 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___139 *cgroup_ns;
};

struct signal_struct___145 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___164 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___164 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___129 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___129 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___163 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___129 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___80;

struct bio_list___80 {
	struct bio___80 *head;
	struct bio___80 *tail;
};

struct bdi_writeback_congested___80;

struct bdi_writeback___80 {
	struct backing_dev_info___80 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___80 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___139 *memcg_css;
	struct cgroup_subsys_state___139 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___80 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___80 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___152 *dev;
	struct device___152 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___163 *debug_dir;
	struct dentry___163 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___139 {
	struct cgroup_subsys_state___139 *subsys[13];
	refcount_t refcount;
	struct css_set___139 *dom_cset;
	struct cgroup___139 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___139 *mg_src_cgrp;
	struct cgroup___139 *mg_dst_cgrp;
	struct css_set___139 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct vm_struct___119 {
	struct vm_struct___119 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___164 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___146 {
	struct task_struct___164 task;
	long unsigned int stack[8192];
};

struct kiocb___164 {
	struct file___164 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___164 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___163 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___164 *ia_file;
};

struct dquot___163 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___163 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___163 {
	int qf_fmt_id;
	const struct quota_format_ops___163 *qf_ops;
	struct module___139 *qf_owner;
	struct quota_format_type___163 *qf_next;
};

struct quota_format_ops___163 {
	int (*check_quota_file)(struct super_block___163 *, int);
	int (*read_file_info)(struct super_block___163 *, int);
	int (*write_file_info)(struct super_block___163 *, int);
	int (*free_file_info)(struct super_block___163 *, int);
	int (*read_dqblk)(struct dquot___163 *);
	int (*commit_dqblk)(struct dquot___163 *);
	int (*release_dqblk)(struct dquot___163 *);
	int (*get_next_id)(struct super_block___163 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___163 {
	int (*write_dquot)(struct dquot___163 *);
	struct dquot___163 * (*alloc_dquot)(struct super_block___163 *, int);
	void (*destroy_dquot)(struct dquot___163 *);
	int (*acquire_dquot)(struct dquot___163 *);
	int (*release_dquot)(struct dquot___163 *);
	int (*mark_dirty)(struct dquot___163 *);
	int (*write_info)(struct super_block___163 *, int);
	qsize_t * (*get_reserved_space)(struct inode___164 *);
	int (*get_projid)(struct inode___164 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___164 *, qsize_t *);
	int (*get_next_id)(struct super_block___163 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___163 {
	int (*quota_on)(struct super_block___163 *, int, int, const struct path___163 *);
	int (*quota_off)(struct super_block___163 *, int);
	int (*quota_enable)(struct super_block___163 *, unsigned int);
	int (*quota_disable)(struct super_block___163 *, unsigned int);
	int (*quota_sync)(struct super_block___163 *, int);
	int (*set_info)(struct super_block___163 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___163 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___163 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___163 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___163 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___163 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___157;

struct kobj_type___157;

struct kobject___158 {
	const char *name;
	struct list_head entry;
	struct kobject___158 *parent;
	struct kset___157 *kset;
	struct kobj_type___157 *ktype;
	struct kernfs_node___160 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___136 {
	struct kobject___158 kobj;
	struct module___139 *mod;
	struct kobject___158 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___136 {
	struct module___139 *mod;
	struct latch_tree_node node;
};

struct module_layout___136 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___136 mtn;
};

struct module_attribute___136;

struct kernel_param___136;

struct module___139 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___136 mkobj;
	struct module_attribute___136 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___158 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___136 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___136 core_layout;
	struct module_layout___136 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___77;

struct swap_info_struct___55;

struct address_space_operations___163 {
	int (*writepage)(struct page___164 *, struct writeback_control___77 *);
	int (*readpage)(struct file___164 *, struct page___164 *);
	int (*writepages)(struct address_space___163 *, struct writeback_control___77 *);
	int (*set_page_dirty)(struct page___164 *);
	int (*readpages)(struct file___164 *, struct address_space___163 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___164 *, struct address_space___163 *, loff_t, unsigned int, unsigned int, struct page___164 **, void **);
	int (*write_end)(struct file___164 *, struct address_space___163 *, loff_t, unsigned int, unsigned int, struct page___164 *, void *);
	sector_t (*bmap)(struct address_space___163 *, sector_t);
	void (*invalidatepage)(struct page___164 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___164 *, gfp_t);
	void (*freepage)(struct page___164 *);
	ssize_t (*direct_IO)(struct kiocb___164 *, struct iov_iter___76 *);
	int (*migratepage)(struct address_space___163 *, struct page___164 *, struct page___164 *, enum migrate_mode);
	bool (*isolate_page)(struct page___164 *, isolate_mode_t);
	void (*putback_page)(struct page___164 *);
	int (*launder_page)(struct page___164 *);
	int (*is_partially_uptodate)(struct page___164 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___164 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___163 *, struct page___164 *);
	int (*swap_activate)(struct swap_info_struct___55 *, struct file___164 *, sector_t *);
	void (*swap_deactivate)(struct file___164 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___77 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___80 *wb;
	struct inode___164 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___80;

struct iov_iter___76 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___80 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct swap_info_struct___55 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___164 *bdev;
	struct file___164 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___164 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___164 *bd_inode;
	struct super_block___163 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___164 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___80 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___31 {
	struct kobject___158 kobj;
	struct module___139 *owner;
	const struct file_operations___164 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___163 {
	struct dentry___163 * (*lookup)(struct inode___164 *, struct dentry___163 *, unsigned int);
	const char * (*get_link)(struct dentry___163 *, struct inode___164 *, struct delayed_call *);
	int (*permission)(struct inode___164 *, int);
	struct posix_acl * (*get_acl)(struct inode___164 *, int);
	int (*readlink)(struct dentry___163 *, char *, int);
	int (*create)(struct inode___164 *, struct dentry___163 *, umode_t, bool);
	int (*link)(struct dentry___163 *, struct inode___164 *, struct dentry___163 *);
	int (*unlink)(struct inode___164 *, struct dentry___163 *);
	int (*symlink)(struct inode___164 *, struct dentry___163 *, const char *);
	int (*mkdir)(struct inode___164 *, struct dentry___163 *, umode_t);
	int (*rmdir)(struct inode___164 *, struct dentry___163 *);
	int (*mknod)(struct inode___164 *, struct dentry___163 *, umode_t, dev_t);
	int (*rename)(struct inode___164 *, struct dentry___163 *, struct inode___164 *, struct dentry___163 *, unsigned int);
	int (*setattr)(struct dentry___163 *, struct iattr___163 *);
	int (*getattr)(const struct path___163 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___163 *, char *, size_t);
	int (*fiemap)(struct inode___164 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___164 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___164 *, struct dentry___163 *, struct file___164 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___164 *, struct dentry___163 *, umode_t);
	int (*set_acl)(struct inode___164 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___163 {
	void (*fl_copy_lock)(struct file_lock___164 *, struct file_lock___164 *);
	void (*fl_release_private)(struct file_lock___164 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___163;

struct lock_manager_operations___163;

struct file_lock___164 {
	struct file_lock___164 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___164 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___163 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___163 *fl_ops;
	const struct lock_manager_operations___163 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___163 {
	int (*lm_compare_owner)(struct file_lock___164 *, struct file_lock___164 *);
	long unsigned int (*lm_owner_key)(struct file_lock___164 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___164 *);
	int (*lm_grant)(struct file_lock___164 *, int);
	bool (*lm_break)(struct file_lock___164 *);
	int (*lm_change)(struct file_lock___164 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___164 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___163 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___163 *fa_next;
	struct file___164 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___163 {
	const char *name;
	int fs_flags;
	struct dentry___163 * (*mount)(struct file_system_type___163 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___163 *);
	struct module___139 *owner;
	struct file_system_type___163 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___163 {
	struct inode___164 * (*alloc_inode)(struct super_block___163 *);
	void (*destroy_inode)(struct inode___164 *);
	void (*dirty_inode)(struct inode___164 *, int);
	int (*write_inode)(struct inode___164 *, struct writeback_control___77 *);
	int (*drop_inode)(struct inode___164 *);
	void (*evict_inode)(struct inode___164 *);
	void (*put_super)(struct super_block___163 *);
	int (*sync_fs)(struct super_block___163 *, int);
	int (*freeze_super)(struct super_block___163 *);
	int (*freeze_fs)(struct super_block___163 *);
	int (*thaw_super)(struct super_block___163 *);
	int (*unfreeze_fs)(struct super_block___163 *);
	int (*statfs)(struct dentry___163 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___163 *, int *, char *);
	void (*umount_begin)(struct super_block___163 *);
	int (*show_options)(struct seq_file___154 *, struct dentry___163 *);
	int (*show_devname)(struct seq_file___154 *, struct dentry___163 *);
	int (*show_path)(struct seq_file___154 *, struct dentry___163 *);
	int (*show_stats)(struct seq_file___154 *, struct dentry___163 *);
	ssize_t (*quota_read)(struct super_block___163 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___163 *, int, const char *, size_t, loff_t);
	struct dquot___163 ** (*get_dquots)(struct inode___164 *);
	int (*bdev_try_to_free_page)(struct super_block___163 *, struct page___164 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___163 *, struct shrink_control___74 *);
	long int (*free_cached_objects)(struct super_block___163 *, struct shrink_control___74 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___152;

struct seq_file___154 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___152 *op;
	int poll_event;
	const struct file___164 *file;
	void *private;
};

typedef void bio_end_io_t___80(struct bio___80 *);

struct bio_vec___80 {
	struct page___164 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___80;

struct bio_set___80;

struct bio___80 {
	struct bio___80 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___80 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___80 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___80 *bi_io_vec;
	struct bio_set___80 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___80 bi_inline_vecs[0];
};

struct kernfs_root___160;

struct kernfs_elem_dir___160 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___160 *root;
};

struct kernfs_syscall_ops___160;

struct kernfs_root___160 {
	struct kernfs_node___160 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___160 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___160 {
	struct kernfs_node___160 *target_kn;
};

struct kernfs_ops___160;

struct kernfs_elem_attr___160 {
	const struct kernfs_ops___160 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___160 *notify_next;
};

struct kernfs_node___160 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___160 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___160 dir;
		struct kernfs_elem_symlink___160 symlink;
		struct kernfs_elem_attr___160 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___160;

struct kernfs_ops___160 {
	int (*open)(struct kernfs_open_file___160 *);
	void (*release)(struct kernfs_open_file___160 *);
	int (*seq_show)(struct seq_file___154 *, void *);
	void * (*seq_start)(struct seq_file___154 *, loff_t *);
	void * (*seq_next)(struct seq_file___154 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___154 *, void *);
	ssize_t (*read)(struct kernfs_open_file___160 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___160 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___160 *, struct vm_area_struct___164 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___160 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___160 {
	int (*remount_fs)(struct kernfs_root___160 *, int *, char *);
	int (*show_options)(struct seq_file___154 *, struct kernfs_root___160 *);
	int (*mkdir)(struct kernfs_node___160 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___160 *);
	int (*rename)(struct kernfs_node___160 *, struct kernfs_node___160 *, const char *);
	int (*show_path)(struct seq_file___154 *, struct kernfs_node___160 *, struct kernfs_root___160 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___160 {
	struct kernfs_node___160 *kn;
	struct file___164 *file;
	struct seq_file___154 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___161 *vm_ops;
};

struct bin_attribute___152;

struct attribute_group___153 {
	const char *name;
	umode_t (*is_visible)(struct kobject___158 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___158 *, struct bin_attribute___152 *, int);
	struct attribute **attrs;
	struct bin_attribute___152 **bin_attrs;
};

struct bin_attribute___152 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___164 *, struct kobject___158 *, struct bin_attribute___152 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___164 *, struct kobject___158 *, struct bin_attribute___152 *, char *, loff_t, size_t);
	int (*mmap)(struct file___164 *, struct kobject___158 *, struct bin_attribute___152 *, struct vm_area_struct___164 *);
};

struct sysfs_ops___157 {
	ssize_t (*show)(struct kobject___158 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___158 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___157;

struct kset___157 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___158 kobj;
	const struct kset_uevent_ops___157 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___157 {
	void (*release)(struct kobject___158 *);
	const struct sysfs_ops___157 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___10 * (*child_ns_type)(struct kobject___158 *);
	const void * (*namespace)(struct kobject___158 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___157 {
	int (* const filter)(struct kset___157 *, struct kobject___158 *);
	const char * (* const name)(struct kset___157 *, struct kobject___158 *);
	int (* const uevent)(struct kset___157 *, struct kobject___158 *, struct kobj_uevent_env *);
};

struct kobj_attribute___158 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___158 *, struct kobj_attribute___158 *, char *);
	ssize_t (*store)(struct kobject___158 *, struct kobj_attribute___158 *, const char *, size_t);
};

struct kernel_param_ops___136 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___136 *);
	int (*get)(char *, const struct kernel_param___136 *);
	void (*free)(void *);
};

struct kparam_array___136;

struct kernel_param___136 {
	const char *name;
	struct module___139 *mod;
	const struct kernel_param_ops___136 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___136 *arr;
	};
};

struct kparam_array___136 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___136 *ops;
	void *elem;
};

struct module_attribute___136 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___136 *, struct module_kobject___136 *, char *);
	ssize_t (*store)(struct module_attribute___136 *, struct module_kobject___136 *, const char *, size_t);
	void (*setup)(struct module___139 *, const char *);
	int (*test)(struct module___139 *);
	void (*free)(struct module___139 *);
};

typedef int (*key_restrict_link_func_t___159)(struct key___159 *, const struct key_type *, const union key_payload *, struct key___159 *);

struct key_restriction___159;

struct key___159 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___164 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___159 *restrict_link;
};

struct key_restriction___159 {
	key_restrict_link_func_t___159 check;
	struct key___159 *key;
	struct key_type *keytype;
};

struct dev_pm_info___152 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___152 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___152;

struct bus_type___152;

struct device_driver___152;

struct dev_pm_domain___152;

struct fwnode_handle___108;

struct class___152;

struct device___152 {
	struct device___152 *parent;
	struct device_private *p;
	struct kobject___158 kobj;
	const char *init_name;
	const struct device_type___152 *type;
	struct mutex mutex;
	struct bus_type___152 *bus;
	struct device_driver___152 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___152 power;
	struct dev_pm_domain___152 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___108 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___152 *class;
	const struct attribute_group___153 **groups;
	void (*release)(struct device___152 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

typedef void compound_page_dtor___161(struct page___164 *);

struct dev_pm_ops___152 {
	int (*prepare)(struct device___152 *);
	void (*complete)(struct device___152 *);
	int (*suspend)(struct device___152 *);
	int (*resume)(struct device___152 *);
	int (*freeze)(struct device___152 *);
	int (*thaw)(struct device___152 *);
	int (*poweroff)(struct device___152 *);
	int (*restore)(struct device___152 *);
	int (*suspend_late)(struct device___152 *);
	int (*resume_early)(struct device___152 *);
	int (*freeze_late)(struct device___152 *);
	int (*thaw_early)(struct device___152 *);
	int (*poweroff_late)(struct device___152 *);
	int (*restore_early)(struct device___152 *);
	int (*suspend_noirq)(struct device___152 *);
	int (*resume_noirq)(struct device___152 *);
	int (*freeze_noirq)(struct device___152 *);
	int (*thaw_noirq)(struct device___152 *);
	int (*poweroff_noirq)(struct device___152 *);
	int (*restore_noirq)(struct device___152 *);
	int (*runtime_suspend)(struct device___152 *);
	int (*runtime_resume)(struct device___152 *);
	int (*runtime_idle)(struct device___152 *);
};

struct dev_pm_domain___152 {
	struct dev_pm_ops___152 ops;
	void (*detach)(struct device___152 *, bool);
	int (*activate)(struct device___152 *);
	void (*sync)(struct device___152 *);
	void (*dismiss)(struct device___152 *);
};

struct bus_type___152 {
	const char *name;
	const char *dev_name;
	struct device___152 *dev_root;
	const struct attribute_group___153 **bus_groups;
	const struct attribute_group___153 **dev_groups;
	const struct attribute_group___153 **drv_groups;
	int (*match)(struct device___152 *, struct device_driver___152 *);
	int (*uevent)(struct device___152 *, struct kobj_uevent_env *);
	int (*probe)(struct device___152 *);
	int (*remove)(struct device___152 *);
	void (*shutdown)(struct device___152 *);
	int (*online)(struct device___152 *);
	int (*offline)(struct device___152 *);
	int (*suspend)(struct device___152 *, pm_message_t);
	int (*resume)(struct device___152 *);
	int (*num_vf)(struct device___152 *);
	int (*dma_configure)(struct device___152 *);
	const struct dev_pm_ops___152 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___152 {
	const char *name;
	struct bus_type___152 *bus;
	struct module___139 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___152 *);
	int (*remove)(struct device___152 *);
	void (*shutdown)(struct device___152 *);
	int (*suspend)(struct device___152 *, pm_message_t);
	int (*resume)(struct device___152 *);
	const struct attribute_group___153 **groups;
	const struct dev_pm_ops___152 *pm;
	void (*coredump)(struct device___152 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___152 {
	const char *name;
	const struct attribute_group___153 **groups;
	int (*uevent)(struct device___152 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___152 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___152 *);
	const struct dev_pm_ops___152 *pm;
};

struct class___152 {
	const char *name;
	struct module___139 *owner;
	const struct attribute_group___153 **class_groups;
	const struct attribute_group___153 **dev_groups;
	struct kobject___158 *dev_kobj;
	int (*dev_uevent)(struct device___152 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___152 *, umode_t *);
	void (*class_release)(struct class___152 *);
	void (*dev_release)(struct device___152 *);
	int (*shutdown_pre)(struct device___152 *);
	const struct kobj_ns_type_operations___10 *ns_type;
	const void * (*namespace)(struct device___152 *);
	const struct dev_pm_ops___152 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct fwnode_operations___108;

struct fwnode_handle___108 {
	struct fwnode_handle___108 *secondary;
	const struct fwnode_operations___108 *ops;
};

struct cgroup_namespace___139 {
	refcount_t count;
	struct ns_common___4 ns;
	struct user_namespace___143 *user_ns;
	struct ucounts___143 *ucounts;
	struct css_set___139 *root_cset;
};

struct ucounts___143 {
	struct hlist_node node;
	struct user_namespace___143 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct seq_operations___152 {
	void * (*start)(struct seq_file___154 *, loff_t *);
	void (*stop)(struct seq_file___154 *, void *);
	void * (*next)(struct seq_file___154 *, void *, loff_t *);
	int (*show)(struct seq_file___154 *, void *);
};

struct fwnode_reference_args___108;

struct fwnode_endpoint___108;

struct fwnode_operations___108 {
	struct fwnode_handle___108 * (*get)(struct fwnode_handle___108 *);
	void (*put)(struct fwnode_handle___108 *);
	bool (*device_is_available)(const struct fwnode_handle___108 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___108 *, const struct device___152 *);
	bool (*property_present)(const struct fwnode_handle___108 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___108 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___108 *, const char *, const char **, size_t);
	struct fwnode_handle___108 * (*get_parent)(const struct fwnode_handle___108 *);
	struct fwnode_handle___108 * (*get_next_child_node)(const struct fwnode_handle___108 *, struct fwnode_handle___108 *);
	struct fwnode_handle___108 * (*get_named_child_node)(const struct fwnode_handle___108 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___108 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___108 *);
	struct fwnode_handle___108 * (*graph_get_next_endpoint)(const struct fwnode_handle___108 *, struct fwnode_handle___108 *);
	struct fwnode_handle___108 * (*graph_get_remote_endpoint)(const struct fwnode_handle___108 *);
	struct fwnode_handle___108 * (*graph_get_port_parent)(struct fwnode_handle___108 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___108 *, struct fwnode_endpoint___108 *);
};

struct fwnode_endpoint___108 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___108 *local_fwnode;
};

struct fwnode_reference_args___108 {
	struct fwnode_handle___108 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct kimage___14;

typedef void *kexec_load_t___14(struct kimage___14 *, char *, long unsigned int, char *, long unsigned int, char *, long unsigned int);

struct kexec_file_ops___15 {
	kexec_probe_t *probe;
	kexec_load_t___14 *load;
	kexec_cleanup_t *cleanup;
};

struct kimage___14 {
	kimage_entry_t head;
	kimage_entry_t *entry;
	kimage_entry_t *last_entry;
	long unsigned int start;
	struct page___164 *control_code_page;
	struct page___164 *swap_page;
	void *vmcoreinfo_data_copy;
	long unsigned int nr_segments;
	struct kexec_segment segment[16];
	struct list_head control_pages;
	struct list_head dest_pages;
	struct list_head unusable_pages;
	long unsigned int control_page;
	unsigned int type: 1;
	unsigned int preserve_context: 1;
	unsigned int file_mode: 1;
	struct kimage_arch arch;
	void *kernel_buf;
	long unsigned int kernel_buf_len;
	void *initrd_buf;
	long unsigned int initrd_buf_len;
	char *cmdline_buf;
	long unsigned int cmdline_buf_len;
	const struct kexec_file_ops___15 *fops;
	void *image_loader_data;
	struct purgatory_info purgatory_info;
};

struct bpf_map___139;

struct bpf_map_ops___139 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___139 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___139 *, struct file___164 *);
	void (*map_free)(struct bpf_map___139 *);
	int (*map_get_next_key)(struct bpf_map___139 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___139 *);
	void * (*map_lookup_elem)(struct bpf_map___139 *, void *);
	int (*map_update_elem)(struct bpf_map___139 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___139 *, void *);
	int (*map_push_elem)(struct bpf_map___139 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___139 *, void *);
	int (*map_peek_elem)(struct bpf_map___139 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___139 *, struct file___164 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___139 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___139 *, void *, struct seq_file___154 *);
	int (*map_check_btf)(const struct bpf_map___139 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___139 {
	const struct bpf_map_ops___139 *ops;
	struct bpf_map___139 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___159 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___139;

typedef void (*kthread_work_func_t___139)(struct kthread_work___139 *);

struct kthread_worker___139;

struct kthread_work___139 {
	struct list_head node;
	kthread_work_func_t___139 func;
	struct kthread_worker___139 *worker;
	int canceling;
};

struct kthread_worker___139 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___164 *task;
	struct kthread_work___139 *current_work;
};

struct kthread_delayed_work___139 {
	struct kthread_work___139 work;
	struct timer_list timer;
};

struct psi_group___139 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___139 *poll_kworker;
	struct kthread_delayed_work___139 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___139;

struct cgroup_rstat_cpu___139;

struct cgroup___139 {
	struct cgroup_subsys_state___139 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___160 *kn;
	struct cgroup_file___139 procs_file;
	struct cgroup_file___139 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___139 *subsys[13];
	struct cgroup_root___139 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___139 *dom_cgrp;
	struct cgroup_rstat_cpu___139 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___20 bpf;
	atomic_t congestion_count;
	struct cgroup___139 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___139 psi;
	int ancestor_ids[0];
};

struct cftype___139;

struct cgroup_subsys___139 {
	struct cgroup_subsys_state___139 * (*css_alloc)(struct cgroup_subsys_state___139 *);
	int (*css_online)(struct cgroup_subsys_state___139 *);
	void (*css_offline)(struct cgroup_subsys_state___139 *);
	void (*css_released)(struct cgroup_subsys_state___139 *);
	void (*css_free)(struct cgroup_subsys_state___139 *);
	void (*css_reset)(struct cgroup_subsys_state___139 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___139 *, int);
	int (*css_extra_stat_show)(struct seq_file___154 *, struct cgroup_subsys_state___139 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___164 *);
	void (*cancel_fork)(struct task_struct___164 *);
	void (*fork)(struct task_struct___164 *);
	void (*exit)(struct task_struct___164 *);
	void (*free)(struct task_struct___164 *);
	void (*bind)(struct cgroup_subsys_state___139 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___139 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___139 *dfl_cftypes;
	struct cftype___139 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___139 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___139 *updated_children;
	struct cgroup___139 *updated_next;
};

struct cgroup_root___139 {
	struct kernfs_root___160 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___139 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___139 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___139 *ss;
	struct list_head node;
	struct kernfs_ops___160 *kf_ops;
	int (*open)(struct kernfs_open_file___160 *);
	void (*release)(struct kernfs_open_file___160 *);
	u64 (*read_u64)(struct cgroup_subsys_state___139 *, struct cftype___139 *);
	s64 (*read_s64)(struct cgroup_subsys_state___139 *, struct cftype___139 *);
	int (*seq_show)(struct seq_file___154 *, void *);
	void * (*seq_start)(struct seq_file___154 *, loff_t *);
	void * (*seq_next)(struct seq_file___154 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___154 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___139 *, struct cftype___139 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___139 *, struct cftype___139 *, s64);
	ssize_t (*write)(struct kernfs_open_file___160 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___160 *, struct poll_table_struct___6 *);
};

struct bdi_writeback_congested___80 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___80 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___80 {
	struct bio___80 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___80 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___80 bip_inline_vecs[0];
};

struct bio_set___80 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___80 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___74 {
	struct mem_cgroup___74 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___74 {
	struct lruvec___163 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___74 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___74 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct node___130 {
	struct device___152 dev;
};

struct file___165;

struct kiocb___165;

struct iov_iter___77;

struct vm_area_struct___165;

struct inode___165;

struct file_lock___165;

struct page___165;

struct seq_file___155;

struct file_operations___165 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___165 *, loff_t, int);
	ssize_t (*read)(struct file___165 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___165 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___165 *, struct iov_iter___77 *);
	ssize_t (*write_iter)(struct kiocb___165 *, struct iov_iter___77 *);
	int (*iopoll)(struct kiocb___165 *, bool);
	int (*iterate)(struct file___165 *, struct dir_context *);
	int (*iterate_shared)(struct file___165 *, struct dir_context *);
	__poll_t (*poll)(struct file___165 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___165 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___165 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___165 *, struct vm_area_struct___165 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___165 *, struct file___165 *);
	int (*flush)(struct file___165 *, fl_owner_t);
	int (*release)(struct inode___165 *, struct file___165 *);
	int (*fsync)(struct file___165 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___165 *, int);
	int (*lock)(struct file___165 *, int, struct file_lock___165 *);
	ssize_t (*sendpage)(struct file___165 *, struct page___165 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___165 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___165 *, int, struct file_lock___165 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___165 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___165 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___165 *, long int, struct file_lock___165 **, void **);
	long int (*fallocate)(struct file___165 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___155 *, struct file___165 *);
	ssize_t (*copy_file_range)(struct file___165 *, loff_t, struct file___165 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___165 *, loff_t, struct file___165 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___165 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___164 {
	u64 seqnum;
	struct vm_area_struct___165 *vmas[4];
};

struct page_frag___164 {
	struct page___165 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___164;

struct pid___130;

struct cred___160;

struct nsproxy___156;

struct signal_struct___146;

struct bio_list___81;

struct backing_dev_info___81;

struct io_context___40;

struct css_set___140;

struct request_queue___37;

struct vm_struct___120;

struct task_struct___165 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___165 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___164 *mm;
	struct mm_struct___164 *active_mm;
	struct vmacache___164 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___165 *real_parent;
	struct task_struct___165 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___165 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___130 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___130 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___130 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___160 *ptracer_cred;
	const struct cred___160 *real_cred;
	const struct cred___160 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___156 *nsproxy;
	struct signal_struct___146 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___165 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___81 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___81 *backing_dev_info;
	struct io_context___40 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___140 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___164 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___37 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___165 *oom_reaper_list;
	struct vm_struct___120 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___100 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___165 *pgtable_t___164;

struct address_space___164;

struct dev_pagemap___162;

struct page___165 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___164 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___165 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___164 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___164 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___162 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___164;

struct lruvec___164 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___164 *pgdat;
};

struct zone___164 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___164 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___164 {
	struct zone___164 *zone;
	int zone_idx;
};

struct zonelist___164 {
	struct zoneref___164 _zonerefs[25];
};

struct pglist_data___164 {
	struct zone___164 node_zones[3];
	struct zonelist___164 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___165 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___165 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___164 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___165 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___165 *owner;
};

struct secondary_data___165 {
	void *stack;
	struct task_struct___165 *task;
	long int status;
};

struct blocking_notifier_head___164 {
	struct rw_semaphore___165 rwsem;
	struct notifier_block *head;
};

struct pid_namespace___130;

struct upid___130 {
	int nr;
	struct pid_namespace___130 *ns;
};

struct vfsmount___24;

struct dentry___164;

struct user_namespace___144;

struct ucounts___144;

struct pid_namespace___130 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___165 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___130 *parent;
	struct vfsmount___24 *proc_mnt;
	struct dentry___164 *proc_self;
	struct dentry___164 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___144 *user_ns;
	struct ucounts___144 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___4 ns;
};

struct pid___130 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___130 numbers[1];
};

struct key___160;

struct user_namespace___144 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___144 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___4 ns;
	long unsigned int flags;
	struct key___160 *persistent_keyring_register;
	struct rw_semaphore___165 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___144 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct user_struct___160 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___160 *uid_keyring;
	struct key___160 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___162;

struct vm_area_struct___165 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___165 *vm_next;
	struct vm_area_struct___165 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___164 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___162 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___165 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___164;

struct mm_struct___164 {
	struct {
		struct vm_area_struct___165 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___165 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___165 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___164 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___165 *owner;
		struct user_namespace___144 *user_ns;
		struct file___165 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___164 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___160 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___160 *session_keyring;
	struct key___160 *process_keyring;
	struct key___160 *thread_keyring;
	struct key___160 *request_key_auth;
	void *security;
	struct user_struct___160 *user;
	struct user_namespace___144 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___140;

struct nsproxy___156 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___130 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___140 *cgroup_ns;
};

struct signal_struct___146 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___165 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___165 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___130 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___130 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___164 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___130 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide40;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___81;

struct bio_list___81 {
	struct bio___81 *head;
	struct bio___81 *tail;
};

struct bdi_writeback_congested___81;

struct cgroup_subsys_state___140;

struct bdi_writeback___81 {
	struct backing_dev_info___81 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___81 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___140 *memcg_css;
	struct cgroup_subsys_state___140 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___153;

struct backing_dev_info___81 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___81 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___153 *dev;
	struct device___153 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___164 *debug_dir;
	struct dentry___164 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___40;

struct io_context___40 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___40 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___140;

struct css_set___140 {
	struct cgroup_subsys_state___140 *subsys[13];
	refcount_t refcount;
	struct css_set___140 *dom_cset;
	struct cgroup___140 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___140 *mg_src_cgrp;
	struct cgroup___140 *mg_dst_cgrp;
	struct css_set___140 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

typedef blk_qc_t make_request_fn___36(struct request_queue___37 *, struct bio___81 *);

struct request___37;

typedef int dma_drain_needed_fn___36(struct request___37 *);

struct kset___158;

struct kobj_type___158;

struct kernfs_node___161;

struct kobject___159 {
	const char *name;
	struct list_head entry;
	struct kobject___159 *parent;
	struct kset___158 *kset;
	struct kobj_type___158 *ktype;
	struct kernfs_node___161 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___36;

struct bsg_class_device___36 {
	struct device___153 *class_dev;
	int minor;
	struct request_queue___37 *queue;
	const struct bsg_ops___36 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___81 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___81 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___36;

struct blkcg_gq___27;

struct request_queue___37 {
	struct list_head queue_head;
	struct request___37 *last_merge;
	struct elevator_queue___36 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___36 *make_request_fn;
	dma_drain_needed_fn___36 *dma_drain_needed;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___81 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___159 kobj;
	struct kobject___159 *mq_kobj;
	struct blk_integrity integrity;
	struct device___153 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___27 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	struct bsg_class_device___36 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___81 bio_split;
	struct dentry___164 *debugfs_dir;
	struct dentry___164 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___120 {
	struct vm_struct___120 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___165 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___147 {
	struct task_struct___165 task;
	long unsigned int stack[8192];
};

struct bio_vec___81 {
	struct page___165 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

typedef void bio_end_io_t___81(struct bio___81 *);

struct gendisk___37;

struct bio_integrity_payload___81;

struct bio___81 {
	struct bio___81 *bi_next;
	struct gendisk___37 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___81 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___27 *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___81 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___81 *bi_io_vec;
	struct bio_set___81 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___81 bi_inline_vecs[0];
};

struct bio_integrity_payload___81 {
	struct bio___81 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___81 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___81 bip_inline_vecs[0];
};

struct dev_pm_info___153 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___153 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___153;

struct bus_type___153;

struct device_driver___153;

struct dev_pm_domain___153;

struct fwnode_handle___109;

struct class___153;

struct attribute_group___154;

struct device___153 {
	struct device___153 *parent;
	struct device_private *p;
	struct kobject___159 kobj;
	const char *init_name;
	const struct device_type___153 *type;
	struct mutex mutex;
	struct bus_type___153 *bus;
	struct device_driver___153 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___153 power;
	struct dev_pm_domain___153 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___109 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___153 *class;
	const struct attribute_group___154 **groups;
	void (*release)(struct device___153 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___37 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___153 __dev;
	struct kobject___159 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___37;

struct block_device_operations___37;

struct gendisk___37 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___37 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___37 *part_tbl;
	struct hd_struct___37 part0;
	const struct block_device_operations___37 *fops;
	struct request_queue___37 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___165 lookup_sem;
	struct kobject___159 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___159 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct blkcg___27;

struct blkg_policy_data___27;

struct blkcg_gq___27 {
	struct request_queue___37 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___27 *blkcg;
	struct bdi_writeback_congested___81 *wb_congested;
	struct blkcg_gq___27 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_rwstat stat_bytes;
	struct blkg_rwstat stat_ios;
	struct blkg_policy_data___27 *pd[5];
	struct callback_head callback_head;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
};

struct dev_pm_ops___153;

struct device_type___153 {
	const char *name;
	const struct attribute_group___154 **groups;
	int (*uevent)(struct device___153 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___153 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___153 *);
	const struct dev_pm_ops___153 *pm;
};

struct class___153 {
	const char *name;
	struct module___11 *owner;
	const struct attribute_group___154 **class_groups;
	const struct attribute_group___154 **dev_groups;
	struct kobject___159 *dev_kobj;
	int (*dev_uevent)(struct device___153 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___153 *, umode_t *);
	void (*class_release)(struct class___153 *);
	void (*dev_release)(struct device___153 *);
	int (*shutdown_pre)(struct device___153 *);
	const struct kobj_ns_type_operations___10 *ns_type;
	const void * (*namespace)(struct device___153 *);
	const struct dev_pm_ops___153 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct kernfs_root___161;

struct kernfs_elem_dir___161 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___161 *root;
};

struct kernfs_syscall_ops___161;

struct kernfs_root___161 {
	struct kernfs_node___161 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___161 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___161 {
	struct kernfs_node___161 *target_kn;
};

struct kernfs_ops___161;

struct kernfs_elem_attr___161 {
	const struct kernfs_ops___161 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___161 *notify_next;
};

struct kernfs_node___161 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___161 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___161 dir;
		struct kernfs_elem_symlink___161 symlink;
		struct kernfs_elem_attr___161 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___161;

struct kernfs_ops___161 {
	int (*open)(struct kernfs_open_file___161 *);
	void (*release)(struct kernfs_open_file___161 *);
	int (*seq_show)(struct seq_file___155 *, void *);
	void * (*seq_start)(struct seq_file___155 *, loff_t *);
	void * (*seq_next)(struct seq_file___155 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___155 *, void *);
	ssize_t (*read)(struct kernfs_open_file___161 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___161 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___161 *, struct vm_area_struct___165 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___161 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___161 {
	int (*remount_fs)(struct kernfs_root___161 *, int *, char *);
	int (*show_options)(struct seq_file___155 *, struct kernfs_root___161 *);
	int (*mkdir)(struct kernfs_node___161 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___161 *);
	int (*rename)(struct kernfs_node___161 *, struct kernfs_node___161 *, const char *);
	int (*show_path)(struct seq_file___155 *, struct kernfs_node___161 *, struct kernfs_root___161 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___153;

struct seq_file___155 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___153 *op;
	int poll_event;
	const struct file___165 *file;
	void *private;
};

struct kernfs_open_file___161 {
	struct kernfs_node___161 *kn;
	struct file___165 *file;
	struct seq_file___155 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___162 *vm_ops;
};

struct path___164 {
	struct vfsmount___24 *mnt;
	struct dentry___164 *dentry;
};

struct fown_struct___130 {
	rwlock_t lock;
	struct pid___130 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___165 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___164 f_path;
	struct inode___165 *f_inode;
	const struct file_operations___165 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___130 f_owner;
	const struct cred___160 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___164 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___162;

struct vm_operations_struct___162 {
	void (*open)(struct vm_area_struct___165 *);
	void (*close)(struct vm_area_struct___165 *);
	int (*split)(struct vm_area_struct___165 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___165 *);
	vm_fault_t (*fault)(struct vm_fault___162 *);
	vm_fault_t (*huge_fault)(struct vm_fault___162 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___162 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___165 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___162 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___162 *);
	int (*access)(struct vm_area_struct___165 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___165 *);
	int (*set_policy)(struct vm_area_struct___165 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___165 *, long unsigned int);
	struct page___165 * (*find_special_page)(struct vm_area_struct___165 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___153;

struct attribute_group___154 {
	const char *name;
	umode_t (*is_visible)(struct kobject___159 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___159 *, struct bin_attribute___153 *, int);
	struct attribute **attrs;
	struct bin_attribute___153 **bin_attrs;
};

struct bin_attribute___153 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___165 *, struct kobject___159 *, struct bin_attribute___153 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___165 *, struct kobject___159 *, struct bin_attribute___153 *, char *, loff_t, size_t);
	int (*mmap)(struct file___165 *, struct kobject___159 *, struct bin_attribute___153 *, struct vm_area_struct___165 *);
};

struct sysfs_ops___158 {
	ssize_t (*show)(struct kobject___159 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___159 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___158;

struct kset___158 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___159 kobj;
	const struct kset_uevent_ops___158 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___158 {
	void (*release)(struct kobject___159 *);
	const struct sysfs_ops___158 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___10 * (*child_ns_type)(struct kobject___159 *);
	const void * (*namespace)(struct kobject___159 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___158 {
	int (* const filter)(struct kset___158 *, struct kobject___159 *);
	const char * (* const name)(struct kset___158 *, struct kobject___159 *);
	int (* const uevent)(struct kset___158 *, struct kobject___159 *, struct kobj_uevent_env *);
};

struct kobj_attribute___159 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___159 *, struct kobj_attribute___159 *, char *);
	ssize_t (*store)(struct kobject___159 *, struct kobj_attribute___159 *, const char *, size_t);
};

struct dev_pm_ops___153 {
	int (*prepare)(struct device___153 *);
	void (*complete)(struct device___153 *);
	int (*suspend)(struct device___153 *);
	int (*resume)(struct device___153 *);
	int (*freeze)(struct device___153 *);
	int (*thaw)(struct device___153 *);
	int (*poweroff)(struct device___153 *);
	int (*restore)(struct device___153 *);
	int (*suspend_late)(struct device___153 *);
	int (*resume_early)(struct device___153 *);
	int (*freeze_late)(struct device___153 *);
	int (*thaw_early)(struct device___153 *);
	int (*poweroff_late)(struct device___153 *);
	int (*restore_early)(struct device___153 *);
	int (*suspend_noirq)(struct device___153 *);
	int (*resume_noirq)(struct device___153 *);
	int (*freeze_noirq)(struct device___153 *);
	int (*thaw_noirq)(struct device___153 *);
	int (*poweroff_noirq)(struct device___153 *);
	int (*restore_noirq)(struct device___153 *);
	int (*runtime_suspend)(struct device___153 *);
	int (*runtime_resume)(struct device___153 *);
	int (*runtime_idle)(struct device___153 *);
};

struct dev_pm_domain___153 {
	struct dev_pm_ops___153 ops;
	void (*detach)(struct device___153 *, bool);
	int (*activate)(struct device___153 *);
	void (*sync)(struct device___153 *);
	void (*dismiss)(struct device___153 *);
};

struct bus_type___153 {
	const char *name;
	const char *dev_name;
	struct device___153 *dev_root;
	const struct attribute_group___154 **bus_groups;
	const struct attribute_group___154 **dev_groups;
	const struct attribute_group___154 **drv_groups;
	int (*match)(struct device___153 *, struct device_driver___153 *);
	int (*uevent)(struct device___153 *, struct kobj_uevent_env *);
	int (*probe)(struct device___153 *);
	int (*remove)(struct device___153 *);
	void (*shutdown)(struct device___153 *);
	int (*online)(struct device___153 *);
	int (*offline)(struct device___153 *);
	int (*suspend)(struct device___153 *, pm_message_t);
	int (*resume)(struct device___153 *);
	int (*num_vf)(struct device___153 *);
	int (*dma_configure)(struct device___153 *);
	const struct dev_pm_ops___153 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___153 {
	const char *name;
	struct bus_type___153 *bus;
	struct module___11 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___153 *);
	int (*remove)(struct device___153 *);
	void (*shutdown)(struct device___153 *);
	int (*suspend)(struct device___153 *, pm_message_t);
	int (*resume)(struct device___153 *);
	const struct attribute_group___154 **groups;
	const struct dev_pm_ops___153 *pm;
	void (*coredump)(struct device___153 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct fwnode_operations___109;

struct fwnode_handle___109 {
	struct fwnode_handle___109 *secondary;
	const struct fwnode_operations___109 *ops;
};

struct dentry_operations___164;

struct super_block___164;

struct dentry___164 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___164 *d_parent;
	struct qstr d_name;
	struct inode___165 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___164 *d_op;
	struct super_block___164 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___164;

struct address_space___164 {
	struct inode___165 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___165 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___164 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___164;

struct block_device___165;

struct inode___165 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___164 *i_op;
	struct super_block___164 *i_sb;
	struct address_space___164 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___165 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___81 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___165 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___164 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___165 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___164 {
	int (*d_revalidate)(struct dentry___164 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___164 *, unsigned int);
	int (*d_hash)(const struct dentry___164 *, struct qstr *);
	int (*d_compare)(const struct dentry___164 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___164 *);
	int (*d_init)(struct dentry___164 *);
	void (*d_release)(struct dentry___164 *);
	void (*d_prune)(struct dentry___164 *);
	void (*d_iput)(struct dentry___164 *, struct inode___165 *);
	char * (*d_dname)(struct dentry___164 *, char *, int);
	struct vfsmount___24 * (*d_automount)(struct path___164 *);
	int (*d_manage)(const struct path___164 *, bool);
	struct dentry___164 * (*d_real)(struct dentry___164 *, const struct inode___165 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___164;

struct mem_dqinfo___164 {
	struct quota_format_type___164 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___164;

struct quota_info___164 {
	unsigned int flags;
	struct rw_semaphore___165 dqio_sem;
	struct inode___165 *files[3];
	struct mem_dqinfo___164 info[3];
	const struct quota_format_ops___164 *ops[3];
};

struct rcuwait___164 {
	struct task_struct___165 *task;
};

struct percpu_rw_semaphore___164 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___165 rw_sem;
	struct rcuwait___164 writer;
	int readers_block;
};

struct sb_writers___164 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___164 rw_sem[3];
};

struct file_system_type___164;

struct super_operations___164;

struct dquot_operations___164;

struct quotactl_ops___164;

struct export_operations___5;

struct super_block___164 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___164 *s_type;
	const struct super_operations___164 *s_op;
	const struct dquot_operations___164 *dq_op;
	const struct quotactl_ops___164 *s_qcop;
	const struct export_operations___5 *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___164 *s_root;
	struct rw_semaphore___165 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___165 *s_bdev;
	struct backing_dev_info___81 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___164 s_dquot;
	struct sb_writers___164 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___164 *s_d_op;
	int cleancache_poolid;
	struct shrinker___74 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___144 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___24 {
	struct dentry___164 *mnt_root;
	struct super_block___164 *mnt_sb;
	int mnt_flags;
};

typedef int (*dev_page_fault_t___162)(struct vm_area_struct___165 *, long unsigned int, const struct page___165 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___162)(struct page___165 *, void *);

struct dev_pagemap___162 {
	dev_page_fault_t___162 page_fault;
	dev_page_free_t___162 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___153 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___164 {
	struct task_struct___165 *task;
	struct core_thread___164 *next;
};

struct core_state___164 {
	atomic_t nr_threads;
	struct core_thread___164 dumper;
	struct completion startup;
};

struct vm_fault___162 {
	struct vm_area_struct___165 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___165 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___165 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___164 prealloc_pte;
};

struct io_cq___40 {
	struct request_queue___37 *q;
	struct io_context___40 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___6 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___165 {
	struct file___165 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___165 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___164 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___165 *ia_file;
};

struct dquot___164 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___164 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___164 {
	int qf_fmt_id;
	const struct quota_format_ops___164 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___164 *qf_next;
};

struct quota_format_ops___164 {
	int (*check_quota_file)(struct super_block___164 *, int);
	int (*read_file_info)(struct super_block___164 *, int);
	int (*write_file_info)(struct super_block___164 *, int);
	int (*free_file_info)(struct super_block___164 *, int);
	int (*read_dqblk)(struct dquot___164 *);
	int (*commit_dqblk)(struct dquot___164 *);
	int (*release_dqblk)(struct dquot___164 *);
	int (*get_next_id)(struct super_block___164 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___164 {
	int (*write_dquot)(struct dquot___164 *);
	struct dquot___164 * (*alloc_dquot)(struct super_block___164 *, int);
	void (*destroy_dquot)(struct dquot___164 *);
	int (*acquire_dquot)(struct dquot___164 *);
	int (*release_dquot)(struct dquot___164 *);
	int (*mark_dirty)(struct dquot___164 *);
	int (*write_info)(struct super_block___164 *, int);
	qsize_t * (*get_reserved_space)(struct inode___165 *);
	int (*get_projid)(struct inode___165 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___165 *, qsize_t *);
	int (*get_next_id)(struct super_block___164 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___164 {
	int (*quota_on)(struct super_block___164 *, int, int, const struct path___164 *);
	int (*quota_off)(struct super_block___164 *, int);
	int (*quota_enable)(struct super_block___164 *, unsigned int);
	int (*quota_disable)(struct super_block___164 *, unsigned int);
	int (*quota_sync)(struct super_block___164 *, int);
	int (*set_info)(struct super_block___164 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___164 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___164 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___164 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___164 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___164 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___78;

struct address_space_operations___164 {
	int (*writepage)(struct page___165 *, struct writeback_control___78 *);
	int (*readpage)(struct file___165 *, struct page___165 *);
	int (*writepages)(struct address_space___164 *, struct writeback_control___78 *);
	int (*set_page_dirty)(struct page___165 *);
	int (*readpages)(struct file___165 *, struct address_space___164 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___165 *, struct address_space___164 *, loff_t, unsigned int, unsigned int, struct page___165 **, void **);
	int (*write_end)(struct file___165 *, struct address_space___164 *, loff_t, unsigned int, unsigned int, struct page___165 *, void *);
	sector_t (*bmap)(struct address_space___164 *, sector_t);
	void (*invalidatepage)(struct page___165 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___165 *, gfp_t);
	void (*freepage)(struct page___165 *);
	ssize_t (*direct_IO)(struct kiocb___165 *, struct iov_iter___77 *);
	int (*migratepage)(struct address_space___164 *, struct page___165 *, struct page___165 *, enum migrate_mode);
	bool (*isolate_page)(struct page___165 *, isolate_mode_t);
	void (*putback_page)(struct page___165 *);
	int (*launder_page)(struct page___165 *);
	int (*is_partially_uptodate)(struct page___165 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___165 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___164 *, struct page___165 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___165 *, sector_t *);
	void (*swap_deactivate)(struct file___165 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___78 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___81 *wb;
	struct inode___165 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct iov_iter___77 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___81 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___165 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___165 *bd_inode;
	struct super_block___164 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___165 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___37 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___37 *bd_disk;
	struct request_queue___37 *bd_queue;
	struct backing_dev_info___81 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___164 {
	struct dentry___164 * (*lookup)(struct inode___165 *, struct dentry___164 *, unsigned int);
	const char * (*get_link)(struct dentry___164 *, struct inode___165 *, struct delayed_call *);
	int (*permission)(struct inode___165 *, int);
	struct posix_acl * (*get_acl)(struct inode___165 *, int);
	int (*readlink)(struct dentry___164 *, char *, int);
	int (*create)(struct inode___165 *, struct dentry___164 *, umode_t, bool);
	int (*link)(struct dentry___164 *, struct inode___165 *, struct dentry___164 *);
	int (*unlink)(struct inode___165 *, struct dentry___164 *);
	int (*symlink)(struct inode___165 *, struct dentry___164 *, const char *);
	int (*mkdir)(struct inode___165 *, struct dentry___164 *, umode_t);
	int (*rmdir)(struct inode___165 *, struct dentry___164 *);
	int (*mknod)(struct inode___165 *, struct dentry___164 *, umode_t, dev_t);
	int (*rename)(struct inode___165 *, struct dentry___164 *, struct inode___165 *, struct dentry___164 *, unsigned int);
	int (*setattr)(struct dentry___164 *, struct iattr___164 *);
	int (*getattr)(const struct path___164 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___164 *, char *, size_t);
	int (*fiemap)(struct inode___165 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___165 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___165 *, struct dentry___164 *, struct file___165 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___165 *, struct dentry___164 *, umode_t);
	int (*set_acl)(struct inode___165 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___164 {
	void (*fl_copy_lock)(struct file_lock___165 *, struct file_lock___165 *);
	void (*fl_release_private)(struct file_lock___165 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___164;

struct lock_manager_operations___164;

struct file_lock___165 {
	struct file_lock___165 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___165 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___164 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___164 *fl_ops;
	const struct lock_manager_operations___164 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___164 {
	int (*lm_compare_owner)(struct file_lock___165 *, struct file_lock___165 *);
	long unsigned int (*lm_owner_key)(struct file_lock___165 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___165 *);
	int (*lm_grant)(struct file_lock___165 *, int);
	bool (*lm_break)(struct file_lock___165 *);
	int (*lm_change)(struct file_lock___165 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___165 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___164 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___164 *fa_next;
	struct file___165 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___164 {
	const char *name;
	int fs_flags;
	struct dentry___164 * (*mount)(struct file_system_type___164 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___164 *);
	struct module___11 *owner;
	struct file_system_type___164 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___164 {
	struct inode___165 * (*alloc_inode)(struct super_block___164 *);
	void (*destroy_inode)(struct inode___165 *);
	void (*dirty_inode)(struct inode___165 *, int);
	int (*write_inode)(struct inode___165 *, struct writeback_control___78 *);
	int (*drop_inode)(struct inode___165 *);
	void (*evict_inode)(struct inode___165 *);
	void (*put_super)(struct super_block___164 *);
	int (*sync_fs)(struct super_block___164 *, int);
	int (*freeze_super)(struct super_block___164 *);
	int (*freeze_fs)(struct super_block___164 *);
	int (*thaw_super)(struct super_block___164 *);
	int (*unfreeze_fs)(struct super_block___164 *);
	int (*statfs)(struct dentry___164 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___164 *, int *, char *);
	void (*umount_begin)(struct super_block___164 *);
	int (*show_options)(struct seq_file___155 *, struct dentry___164 *);
	int (*show_devname)(struct seq_file___155 *, struct dentry___164 *);
	int (*show_path)(struct seq_file___155 *, struct dentry___164 *);
	int (*show_stats)(struct seq_file___155 *, struct dentry___164 *);
	ssize_t (*quota_read)(struct super_block___164 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___164 *, int, const char *, size_t, loff_t);
	struct dquot___164 ** (*get_dquots)(struct inode___165 *);
	int (*bdev_try_to_free_page)(struct super_block___164 *, struct page___165 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___164 *, struct shrink_control___74 *);
	long int (*free_cached_objects)(struct super_block___164 *, struct shrink_control___74 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct export_operations___5 {
	int (*encode_fh)(struct inode___165 *, __u32 *, int *, struct inode___165 *);
	struct dentry___164 * (*fh_to_dentry)(struct super_block___164 *, struct fid *, int, int);
	struct dentry___164 * (*fh_to_parent)(struct super_block___164 *, struct fid *, int, int);
	int (*get_name)(struct dentry___164 *, char *, struct dentry___164 *);
	struct dentry___164 * (*get_parent)(struct dentry___164 *);
	int (*commit_metadata)(struct inode___165 *);
	int (*get_uuid)(struct super_block___164 *, u8 *, u32 *, u64 *);
	int (*map_blocks)(struct inode___165 *, loff_t, u64, struct iomap *, bool, u32 *);
	int (*commit_blocks)(struct inode___165 *, struct iomap *, int, struct iattr___164 *);
};

struct disk_part_tbl___37 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___37 *last_lookup;
	struct hd_struct___37 *part[0];
};

struct block_device_operations___37 {
	int (*open)(struct block_device___165 *, fmode_t);
	void (*release)(struct gendisk___37 *, fmode_t);
	int (*rw_page)(struct block_device___165 *, sector_t, struct page___165 *, unsigned int);
	int (*ioctl)(struct block_device___165 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___165 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___37 *, unsigned int);
	int (*media_changed)(struct gendisk___37 *);
	void (*unlock_native_capacity)(struct gendisk___37 *);
	int (*revalidate_disk)(struct gendisk___37 *);
	int (*getgeo)(struct block_device___165 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___165 *, long unsigned int);
	int (*report_zones)(struct gendisk___37 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___11 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___162(struct page___165 *);

struct bdi_writeback_congested___81 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___81 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct cgroup_subsys___140;

struct cgroup_subsys_state___140 {
	struct cgroup___140 *cgroup;
	struct cgroup_subsys___140 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___140 *parent;
};

struct bsg_ops___36 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___37 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___37 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___37 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___36(struct request___37 *, blk_status_t);

struct request___37 {
	struct request_queue___37 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___81 *bio;
	struct bio___81 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___81 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___40 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___36 *saved_end_io;
		} flush;
	};
	struct gendisk___37 *rq_disk;
	struct hd_struct___37 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___36 *end_io;
	void *end_io_data;
	struct request___37 *next_rq;
};

struct fwnode_reference_args___109;

struct fwnode_endpoint___109;

struct fwnode_operations___109 {
	struct fwnode_handle___109 * (*get)(struct fwnode_handle___109 *);
	void (*put)(struct fwnode_handle___109 *);
	bool (*device_is_available)(const struct fwnode_handle___109 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___109 *, const struct device___153 *);
	bool (*property_present)(const struct fwnode_handle___109 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___109 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___109 *, const char *, const char **, size_t);
	struct fwnode_handle___109 * (*get_parent)(const struct fwnode_handle___109 *);
	struct fwnode_handle___109 * (*get_next_child_node)(const struct fwnode_handle___109 *, struct fwnode_handle___109 *);
	struct fwnode_handle___109 * (*get_named_child_node)(const struct fwnode_handle___109 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___109 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___109 *);
	struct fwnode_handle___109 * (*graph_get_next_endpoint)(const struct fwnode_handle___109 *, struct fwnode_handle___109 *);
	struct fwnode_handle___109 * (*graph_get_remote_endpoint)(const struct fwnode_handle___109 *);
	struct fwnode_handle___109 * (*graph_get_port_parent)(struct fwnode_handle___109 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___109 *, struct fwnode_endpoint___109 *);
};

struct fwnode_endpoint___109 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___109 *local_fwnode;
};

struct fwnode_reference_args___109 {
	struct fwnode_handle___109 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct elevator_type___36;

struct elevator_mq_ops___36 {
	int (*init_sched)(struct request_queue___37 *, struct elevator_type___36 *);
	void (*exit_sched)(struct elevator_queue___36 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	bool (*allow_merge)(struct request_queue___37 *, struct request___37 *, struct bio___81 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx *, struct bio___81 *);
	int (*request_merge)(struct request_queue___37 *, struct request___37 **, struct bio___81 *);
	void (*request_merged)(struct request_queue___37 *, struct request___37 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___37 *, struct request___37 *, struct request___37 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___37 *, struct bio___81 *);
	void (*finish_request)(struct request___37 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___37 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___37 *, u64);
	void (*started_request)(struct request___37 *);
	void (*requeue_request)(struct request___37 *);
	struct request___37 * (*former_request)(struct request_queue___37 *, struct request___37 *);
	struct request___37 * (*next_request)(struct request_queue___37 *, struct request___37 *);
	void (*init_icq)(struct io_cq___40 *);
	void (*exit_icq)(struct io_cq___40 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___36;

struct elevator_type___36 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___36 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___36 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___11 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___36 {
	struct elevator_type___36 *type;
	void *elevator_data;
	struct kobject___159 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___36 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___36 *, char *);
	ssize_t (*store)(struct elevator_queue___36 *, const char *, size_t);
};

typedef int (*key_restrict_link_func_t___160)(struct key___160 *, const struct key_type *, const union key_payload *, struct key___160 *);

struct key_restriction___160;

struct key___160 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___165 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___160 *restrict_link;
};

struct key_restriction___160 {
	key_restrict_link_func_t___160 check;
	struct key___160 *key;
	struct key_type *keytype;
};

struct seq_operations___153 {
	void * (*start)(struct seq_file___155 *, loff_t *);
	void (*stop)(struct seq_file___155 *, void *);
	void * (*next)(struct seq_file___155 *, void *, loff_t *);
	int (*show)(struct seq_file___155 *, void *);
};

struct cgroup_namespace___140 {
	refcount_t count;
	struct ns_common___4 ns;
	struct user_namespace___144 *user_ns;
	struct ucounts___144 *ucounts;
	struct css_set___140 *root_cset;
};

struct ucounts___144 {
	struct hlist_node node;
	struct user_namespace___144 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___140;

struct bpf_map_ops___140 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___140 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___140 *, struct file___165 *);
	void (*map_free)(struct bpf_map___140 *);
	int (*map_get_next_key)(struct bpf_map___140 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___140 *);
	void * (*map_lookup_elem)(struct bpf_map___140 *, void *);
	int (*map_update_elem)(struct bpf_map___140 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___140 *, void *);
	int (*map_push_elem)(struct bpf_map___140 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___140 *, void *);
	int (*map_peek_elem)(struct bpf_map___140 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___140 *, struct file___165 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___140 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___140 *, void *, struct seq_file___155 *);
	int (*map_check_btf)(const struct bpf_map___140 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___140 {
	const struct bpf_map_ops___140 *ops;
	struct bpf_map___140 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___160 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___140;

typedef void (*kthread_work_func_t___140)(struct kthread_work___140 *);

struct kthread_worker___140;

struct kthread_work___140 {
	struct list_head node;
	kthread_work_func_t___140 func;
	struct kthread_worker___140 *worker;
	int canceling;
};

struct kthread_worker___140 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___165 *task;
	struct kthread_work___140 *current_work;
};

struct kthread_delayed_work___140 {
	struct kthread_work___140 work;
	struct timer_list timer;
};

struct psi_group___140 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___140 *poll_kworker;
	struct kthread_delayed_work___140 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___140 {
	struct kernfs_node___161 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_root___140;

struct cgroup_rstat_cpu___140;

struct cgroup___140 {
	struct cgroup_subsys_state___140 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___161 *kn;
	struct cgroup_file___140 procs_file;
	struct cgroup_file___140 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___140 *subsys[13];
	struct cgroup_root___140 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___140 *dom_cgrp;
	struct cgroup_rstat_cpu___140 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___20 bpf;
	atomic_t congestion_count;
	struct cgroup___140 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___140 psi;
	int ancestor_ids[0];
};

struct cftype___140;

struct cgroup_subsys___140 {
	struct cgroup_subsys_state___140 * (*css_alloc)(struct cgroup_subsys_state___140 *);
	int (*css_online)(struct cgroup_subsys_state___140 *);
	void (*css_offline)(struct cgroup_subsys_state___140 *);
	void (*css_released)(struct cgroup_subsys_state___140 *);
	void (*css_free)(struct cgroup_subsys_state___140 *);
	void (*css_reset)(struct cgroup_subsys_state___140 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___140 *, int);
	int (*css_extra_stat_show)(struct seq_file___155 *, struct cgroup_subsys_state___140 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___165 *);
	void (*cancel_fork)(struct task_struct___165 *);
	void (*fork)(struct task_struct___165 *);
	void (*exit)(struct task_struct___165 *);
	void (*free)(struct task_struct___165 *);
	void (*bind)(struct cgroup_subsys_state___140 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___140 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___140 *dfl_cftypes;
	struct cftype___140 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___140 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___140 *updated_children;
	struct cgroup___140 *updated_next;
};

struct cgroup_root___140 {
	struct kernfs_root___161 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___140 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___140 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___140 *ss;
	struct list_head node;
	struct kernfs_ops___161 *kf_ops;
	int (*open)(struct kernfs_open_file___161 *);
	void (*release)(struct kernfs_open_file___161 *);
	u64 (*read_u64)(struct cgroup_subsys_state___140 *, struct cftype___140 *);
	s64 (*read_s64)(struct cgroup_subsys_state___140 *, struct cftype___140 *);
	int (*seq_show)(struct seq_file___155 *, void *);
	void * (*seq_start)(struct seq_file___155 *, loff_t *);
	void * (*seq_next)(struct seq_file___155 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___155 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___140 *, struct cftype___140 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___140 *, struct cftype___140 *, s64);
	ssize_t (*write)(struct kernfs_open_file___161 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___161 *, struct poll_table_struct___6 *);
};

struct blkcg_policy_data___27;

struct blkcg___27 {
	struct cgroup_subsys_state___140 css;
	spinlock_t lock;
	struct xarray blkg_tree;
	struct blkcg_gq___27 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___27 *cpd[5];
	struct list_head all_blkcgs_node;
	struct list_head cgwb_list;
	refcount_t cgwb_refcnt;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct blkcg_policy_data___27 {
	struct blkcg___27 *blkcg;
	int plid;
};

struct blkg_policy_data___27 {
	struct blkcg_gq___27 *blkg;
	int plid;
};

struct module___140;

struct file___166;

struct kiocb___166;

struct vm_area_struct___166;

struct inode___166;

struct file_lock___166;

struct page___166;

struct seq_file___156;

struct file_operations___166 {
	struct module___140 *owner;
	loff_t (*llseek)(struct file___166 *, loff_t, int);
	ssize_t (*read)(struct file___166 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___166 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___166 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___166 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___166 *, bool);
	int (*iterate)(struct file___166 *, struct dir_context *);
	int (*iterate_shared)(struct file___166 *, struct dir_context *);
	__poll_t (*poll)(struct file___166 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___166 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___166 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___166 *, struct vm_area_struct___166 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___166 *, struct file___166 *);
	int (*flush)(struct file___166 *, fl_owner_t);
	int (*release)(struct inode___166 *, struct file___166 *);
	int (*fsync)(struct file___166 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___166 *, int);
	int (*lock)(struct file___166 *, int, struct file_lock___166 *);
	ssize_t (*sendpage)(struct file___166 *, struct page___166 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___166 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___166 *, int, struct file_lock___166 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___166 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___166 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___166 *, long int, struct file_lock___166 **, void **);
	long int (*fallocate)(struct file___166 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___156 *, struct file___166 *);
	ssize_t (*copy_file_range)(struct file___166 *, loff_t, struct file___166 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___166 *, loff_t, struct file___166 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___166 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___165 {
	u64 seqnum;
	struct vm_area_struct___166 *vmas[4];
};

struct page_frag___165 {
	struct page___166 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___165;

struct cred___161;

struct nsproxy___157;

struct bio_list___82;

struct backing_dev_info___82;

struct io_context___41;

struct css_set___141;

struct request_queue___38;

struct vm_struct___121;

struct task_struct___166 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___166 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___165 *mm;
	struct mm_struct___165 *active_mm;
	struct vmacache___165 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___166 *real_parent;
	struct task_struct___166 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___166 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___130 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___130 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___130 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___161 *ptracer_cred;
	const struct cred___161 *real_cred;
	const struct cred___161 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___157 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___166 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___82 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___82 *backing_dev_info;
	struct io_context___41 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___141 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___165 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___38 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___166 *oom_reaper_list;
	struct vm_struct___121 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___100 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___165;

struct super_block___165;

struct dentry___165 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___165 *d_parent;
	struct qstr d_name;
	struct inode___166 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___165 *d_op;
	struct super_block___165 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct rw_semaphore___166 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___166 *owner;
};

struct address_space_operations___165;

struct address_space___165 {
	struct inode___166 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___166 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___165 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___165;

struct bdi_writeback___82;

struct block_device___166;

struct cdev___32;

struct inode___166 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___165 *i_op;
	struct super_block___165 *i_sb;
	struct address_space___165 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___166 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___82 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___166 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___165 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___166 *i_bdev;
		struct cdev___32 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___165;

struct dentry_operations___165 {
	int (*d_revalidate)(struct dentry___165 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___165 *, unsigned int);
	int (*d_hash)(const struct dentry___165 *, struct qstr *);
	int (*d_compare)(const struct dentry___165 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___165 *);
	int (*d_init)(struct dentry___165 *);
	void (*d_release)(struct dentry___165 *);
	void (*d_prune)(struct dentry___165 *);
	void (*d_iput)(struct dentry___165 *, struct inode___166 *);
	char * (*d_dname)(struct dentry___165 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___165 *);
	int (*d_manage)(const struct path___165 *, bool);
	struct dentry___165 * (*d_real)(struct dentry___165 *, const struct inode___166 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___165;

struct mem_dqinfo___165 {
	struct quota_format_type___165 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___165;

struct quota_info___165 {
	unsigned int flags;
	struct rw_semaphore___166 dqio_sem;
	struct inode___166 *files[3];
	struct mem_dqinfo___165 info[3];
	const struct quota_format_ops___165 *ops[3];
};

struct rcuwait___165 {
	struct task_struct___166 *task;
};

struct percpu_rw_semaphore___165 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___166 rw_sem;
	struct rcuwait___165 writer;
	int readers_block;
};

struct sb_writers___165 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___165 rw_sem[3];
};

struct file_system_type___165;

struct super_operations___165;

struct dquot_operations___165;

struct quotactl_ops___165;

struct user_namespace___145;

struct super_block___165 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___165 *s_type;
	const struct super_operations___165 *s_op;
	const struct dquot_operations___165 *dq_op;
	const struct quotactl_ops___165 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___165 *s_root;
	struct rw_semaphore___166 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___166 *s_bdev;
	struct backing_dev_info___82 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___165 s_dquot;
	struct sb_writers___165 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___165 *s_d_op;
	int cleancache_poolid;
	struct shrinker___74 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___145 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct path___165 {
	struct vfsmount *mnt;
	struct dentry___165 *dentry;
};

struct key___161;

struct ucounts___145;

struct user_namespace___145 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___145 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___4 ns;
	long unsigned int flags;
	struct key___161 *persistent_keyring_register;
	struct rw_semaphore___166 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___145 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___166 *pgtable_t___165;

struct dev_pagemap___163;

struct page___166 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___165 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___166 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___165 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___165 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___163 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___165;

struct lruvec___165 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___165 *pgdat;
};

struct zone___165 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___165 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___165 {
	struct zone___165 *zone;
	int zone_idx;
};

struct zonelist___165 {
	struct zoneref___165 _zonerefs[25];
};

struct pglist_data___165 {
	struct zone___165 node_zones[3];
	struct zonelist___165 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___166 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___166 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___165 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___166 {
	void *stack;
	struct task_struct___166 *task;
	long int status;
};

struct blocking_notifier_head___165 {
	struct rw_semaphore___166 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___163;

struct vm_area_struct___166 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___166 *vm_next;
	struct vm_area_struct___166 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___165 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___163 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___166 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___165;

struct mm_struct___165 {
	struct {
		struct vm_area_struct___166 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___166 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___166 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___165 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___166 *owner;
		struct user_namespace___145 *user_ns;
		struct file___166 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___165 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___163)(struct vm_area_struct___166 *, long unsigned int, const struct page___166 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___163)(struct page___166 *, void *);

struct device___154;

struct dev_pagemap___163 {
	dev_page_fault_t___163 page_fault;
	dev_page_free_t___163 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___154 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct file___166 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___165 f_path;
	struct inode___166 *f_inode;
	const struct file_operations___166 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___130 f_owner;
	const struct cred___161 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___165 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___163;

struct vm_operations_struct___163 {
	void (*open)(struct vm_area_struct___166 *);
	void (*close)(struct vm_area_struct___166 *);
	int (*split)(struct vm_area_struct___166 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___166 *);
	vm_fault_t (*fault)(struct vm_fault___163 *);
	vm_fault_t (*huge_fault)(struct vm_fault___163 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___163 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___166 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___163 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___163 *);
	int (*access)(struct vm_area_struct___166 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___166 *);
	int (*set_policy)(struct vm_area_struct___166 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___166 *, long unsigned int);
	struct page___166 * (*find_special_page)(struct vm_area_struct___166 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___165 {
	struct task_struct___166 *task;
	struct core_thread___165 *next;
};

struct core_state___165 {
	atomic_t nr_threads;
	struct core_thread___165 dumper;
	struct completion startup;
};

struct vm_fault___163 {
	struct vm_area_struct___166 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___166 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___166 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___165 prealloc_pte;
};

struct user_struct___161 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___161 *uid_keyring;
	struct key___161 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___161 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___161 *session_keyring;
	struct key___161 *process_keyring;
	struct key___161 *thread_keyring;
	struct key___161 *request_key_auth;
	void *security;
	struct user_struct___161 *user;
	struct user_namespace___145 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___141;

struct nsproxy___157 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___141 *cgroup_ns;
};

struct bio___82;

struct bio_list___82 {
	struct bio___82 *head;
	struct bio___82 *tail;
};

struct bdi_writeback_congested___82;

struct cgroup_subsys_state___141;

struct bdi_writeback___82 {
	struct backing_dev_info___82 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___82 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___141 *memcg_css;
	struct cgroup_subsys_state___141 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___82 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___82 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___154 *dev;
	struct device___154 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___165 *debug_dir;
	struct dentry___165 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___41;

struct io_context___41 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___41 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___141;

struct css_set___141 {
	struct cgroup_subsys_state___141 *subsys[13];
	refcount_t refcount;
	struct css_set___141 *dom_cset;
	struct cgroup___141 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___141 *mg_src_cgrp;
	struct cgroup___141 *mg_dst_cgrp;
	struct css_set___141 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

typedef blk_qc_t make_request_fn___37(struct request_queue___38 *, struct bio___82 *);

struct request___38;

typedef int dma_drain_needed_fn___37(struct request___38 *);

struct kset___159;

struct kobj_type___159;

struct kernfs_node___162;

struct kobject___160 {
	const char *name;
	struct list_head entry;
	struct kobject___160 *parent;
	struct kset___159 *kset;
	struct kobj_type___159 *ktype;
	struct kernfs_node___162 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___37;

struct bsg_class_device___37 {
	struct device___154 *class_dev;
	int minor;
	struct request_queue___38 *queue;
	const struct bsg_ops___37 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___82 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___82 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___37;

struct blkcg_gq___28;

struct request_queue___38 {
	struct list_head queue_head;
	struct request___38 *last_merge;
	struct elevator_queue___37 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___37 *make_request_fn;
	dma_drain_needed_fn___37 *dma_drain_needed;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___82 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___160 kobj;
	struct kobject___160 *mq_kobj;
	struct blk_integrity integrity;
	struct device___154 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___28 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	struct bsg_class_device___37 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___82 bio_split;
	struct dentry___165 *debugfs_dir;
	struct dentry___165 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___121 {
	struct vm_struct___121 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___166 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct io_cq___41 {
	struct request_queue___38 *q;
	struct io_context___41 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___6 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___166 {
	struct file___166 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___166 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___165 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___166 *ia_file;
};

struct dquot___165 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___165 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___165 {
	int qf_fmt_id;
	const struct quota_format_ops___165 *qf_ops;
	struct module___140 *qf_owner;
	struct quota_format_type___165 *qf_next;
};

struct quota_format_ops___165 {
	int (*check_quota_file)(struct super_block___165 *, int);
	int (*read_file_info)(struct super_block___165 *, int);
	int (*write_file_info)(struct super_block___165 *, int);
	int (*free_file_info)(struct super_block___165 *, int);
	int (*read_dqblk)(struct dquot___165 *);
	int (*commit_dqblk)(struct dquot___165 *);
	int (*release_dqblk)(struct dquot___165 *);
	int (*get_next_id)(struct super_block___165 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___165 {
	int (*write_dquot)(struct dquot___165 *);
	struct dquot___165 * (*alloc_dquot)(struct super_block___165 *, int);
	void (*destroy_dquot)(struct dquot___165 *);
	int (*acquire_dquot)(struct dquot___165 *);
	int (*release_dquot)(struct dquot___165 *);
	int (*mark_dirty)(struct dquot___165 *);
	int (*write_info)(struct super_block___165 *, int);
	qsize_t * (*get_reserved_space)(struct inode___166 *);
	int (*get_projid)(struct inode___166 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___166 *, qsize_t *);
	int (*get_next_id)(struct super_block___165 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___165 {
	int (*quota_on)(struct super_block___165 *, int, int, const struct path___165 *);
	int (*quota_off)(struct super_block___165 *, int);
	int (*quota_enable)(struct super_block___165 *, unsigned int);
	int (*quota_disable)(struct super_block___165 *, unsigned int);
	int (*quota_sync)(struct super_block___165 *, int);
	int (*set_info)(struct super_block___165 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___165 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___165 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___165 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___165 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___165 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___137 {
	struct kobject___160 kobj;
	struct module___140 *mod;
	struct kobject___160 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___137 {
	struct module___140 *mod;
	struct latch_tree_node node;
};

struct module_layout___137 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___137 mtn;
};

struct module_attribute___137;

struct kernel_param___137;

struct module___140 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___137 mkobj;
	struct module_attribute___137 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___160 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___137 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___137 core_layout;
	struct module_layout___137 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___79;

struct address_space_operations___165 {
	int (*writepage)(struct page___166 *, struct writeback_control___79 *);
	int (*readpage)(struct file___166 *, struct page___166 *);
	int (*writepages)(struct address_space___165 *, struct writeback_control___79 *);
	int (*set_page_dirty)(struct page___166 *);
	int (*readpages)(struct file___166 *, struct address_space___165 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___166 *, struct address_space___165 *, loff_t, unsigned int, unsigned int, struct page___166 **, void **);
	int (*write_end)(struct file___166 *, struct address_space___165 *, loff_t, unsigned int, unsigned int, struct page___166 *, void *);
	sector_t (*bmap)(struct address_space___165 *, sector_t);
	void (*invalidatepage)(struct page___166 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___166 *, gfp_t);
	void (*freepage)(struct page___166 *);
	ssize_t (*direct_IO)(struct kiocb___166 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___165 *, struct page___166 *, struct page___166 *, enum migrate_mode);
	bool (*isolate_page)(struct page___166 *, isolate_mode_t);
	void (*putback_page)(struct page___166 *);
	int (*launder_page)(struct page___166 *);
	int (*is_partially_uptodate)(struct page___166 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___166 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___165 *, struct page___166 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___166 *, sector_t *);
	void (*swap_deactivate)(struct file___166 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___79 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___82 *wb;
	struct inode___166 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct hd_struct___38;

struct gendisk___38;

struct block_device___166 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___166 *bd_inode;
	struct super_block___165 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___166 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___38 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___38 *bd_disk;
	struct request_queue___38 *bd_queue;
	struct backing_dev_info___82 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___154 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___154 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___154;

struct bus_type___154;

struct device_driver___154;

struct dev_pm_domain___154;

struct fwnode_handle___110;

struct class___154;

struct attribute_group___155;

struct device___154 {
	struct device___154 *parent;
	struct device_private *p;
	struct kobject___160 kobj;
	const char *init_name;
	const struct device_type___154 *type;
	struct mutex mutex;
	struct bus_type___154 *bus;
	struct device_driver___154 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___154 power;
	struct dev_pm_domain___154 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___110 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___154 *class;
	const struct attribute_group___155 **groups;
	void (*release)(struct device___154 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___38 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___154 __dev;
	struct kobject___160 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___38;

struct block_device_operations___38;

struct gendisk___38 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___38 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___38 *part_tbl;
	struct hd_struct___38 part0;
	const struct block_device_operations___38 *fops;
	struct request_queue___38 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___166 lookup_sem;
	struct kobject___160 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___160 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___32 {
	struct kobject___160 kobj;
	struct module___140 *owner;
	const struct file_operations___166 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___165 {
	struct dentry___165 * (*lookup)(struct inode___166 *, struct dentry___165 *, unsigned int);
	const char * (*get_link)(struct dentry___165 *, struct inode___166 *, struct delayed_call *);
	int (*permission)(struct inode___166 *, int);
	struct posix_acl * (*get_acl)(struct inode___166 *, int);
	int (*readlink)(struct dentry___165 *, char *, int);
	int (*create)(struct inode___166 *, struct dentry___165 *, umode_t, bool);
	int (*link)(struct dentry___165 *, struct inode___166 *, struct dentry___165 *);
	int (*unlink)(struct inode___166 *, struct dentry___165 *);
	int (*symlink)(struct inode___166 *, struct dentry___165 *, const char *);
	int (*mkdir)(struct inode___166 *, struct dentry___165 *, umode_t);
	int (*rmdir)(struct inode___166 *, struct dentry___165 *);
	int (*mknod)(struct inode___166 *, struct dentry___165 *, umode_t, dev_t);
	int (*rename)(struct inode___166 *, struct dentry___165 *, struct inode___166 *, struct dentry___165 *, unsigned int);
	int (*setattr)(struct dentry___165 *, struct iattr___165 *);
	int (*getattr)(const struct path___165 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___165 *, char *, size_t);
	int (*fiemap)(struct inode___166 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___166 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___166 *, struct dentry___165 *, struct file___166 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___166 *, struct dentry___165 *, umode_t);
	int (*set_acl)(struct inode___166 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___165 {
	void (*fl_copy_lock)(struct file_lock___166 *, struct file_lock___166 *);
	void (*fl_release_private)(struct file_lock___166 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___165;

struct lock_manager_operations___165;

struct file_lock___166 {
	struct file_lock___166 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___166 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___165 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___165 *fl_ops;
	const struct lock_manager_operations___165 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___165 {
	int (*lm_compare_owner)(struct file_lock___166 *, struct file_lock___166 *);
	long unsigned int (*lm_owner_key)(struct file_lock___166 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___166 *);
	int (*lm_grant)(struct file_lock___166 *, int);
	bool (*lm_break)(struct file_lock___166 *);
	int (*lm_change)(struct file_lock___166 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___166 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___165 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___165 *fa_next;
	struct file___166 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___165 {
	const char *name;
	int fs_flags;
	struct dentry___165 * (*mount)(struct file_system_type___165 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___165 *);
	struct module___140 *owner;
	struct file_system_type___165 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___165 {
	struct inode___166 * (*alloc_inode)(struct super_block___165 *);
	void (*destroy_inode)(struct inode___166 *);
	void (*dirty_inode)(struct inode___166 *, int);
	int (*write_inode)(struct inode___166 *, struct writeback_control___79 *);
	int (*drop_inode)(struct inode___166 *);
	void (*evict_inode)(struct inode___166 *);
	void (*put_super)(struct super_block___165 *);
	int (*sync_fs)(struct super_block___165 *, int);
	int (*freeze_super)(struct super_block___165 *);
	int (*freeze_fs)(struct super_block___165 *);
	int (*thaw_super)(struct super_block___165 *);
	int (*unfreeze_fs)(struct super_block___165 *);
	int (*statfs)(struct dentry___165 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___165 *, int *, char *);
	void (*umount_begin)(struct super_block___165 *);
	int (*show_options)(struct seq_file___156 *, struct dentry___165 *);
	int (*show_devname)(struct seq_file___156 *, struct dentry___165 *);
	int (*show_path)(struct seq_file___156 *, struct dentry___165 *);
	int (*show_stats)(struct seq_file___156 *, struct dentry___165 *);
	ssize_t (*quota_read)(struct super_block___165 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___165 *, int, const char *, size_t, loff_t);
	struct dquot___165 ** (*get_dquots)(struct inode___166 *);
	int (*bdev_try_to_free_page)(struct super_block___165 *, struct page___166 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___165 *, struct shrink_control___74 *);
	long int (*free_cached_objects)(struct super_block___165 *, struct shrink_control___74 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___154;

struct seq_file___156 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___154 *op;
	int poll_event;
	const struct file___166 *file;
	void *private;
};

typedef void bio_end_io_t___82(struct bio___82 *);

struct bio_vec___82 {
	struct page___166 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___82;

struct bio___82 {
	struct bio___82 *bi_next;
	struct gendisk___38 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___82 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___28 *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___82 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___82 *bi_io_vec;
	struct bio_set___82 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___82 bi_inline_vecs[0];
};

struct kernfs_root___162;

struct kernfs_elem_dir___162 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___162 *root;
};

struct kernfs_syscall_ops___162;

struct kernfs_root___162 {
	struct kernfs_node___162 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___162 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___162 {
	struct kernfs_node___162 *target_kn;
};

struct kernfs_ops___162;

struct kernfs_elem_attr___162 {
	const struct kernfs_ops___162 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___162 *notify_next;
};

struct kernfs_node___162 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___162 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___162 dir;
		struct kernfs_elem_symlink___162 symlink;
		struct kernfs_elem_attr___162 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___162;

struct kernfs_ops___162 {
	int (*open)(struct kernfs_open_file___162 *);
	void (*release)(struct kernfs_open_file___162 *);
	int (*seq_show)(struct seq_file___156 *, void *);
	void * (*seq_start)(struct seq_file___156 *, loff_t *);
	void * (*seq_next)(struct seq_file___156 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___156 *, void *);
	ssize_t (*read)(struct kernfs_open_file___162 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___162 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___162 *, struct vm_area_struct___166 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___162 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___162 {
	int (*remount_fs)(struct kernfs_root___162 *, int *, char *);
	int (*show_options)(struct seq_file___156 *, struct kernfs_root___162 *);
	int (*mkdir)(struct kernfs_node___162 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___162 *);
	int (*rename)(struct kernfs_node___162 *, struct kernfs_node___162 *, const char *);
	int (*show_path)(struct seq_file___156 *, struct kernfs_node___162 *, struct kernfs_root___162 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___162 {
	struct kernfs_node___162 *kn;
	struct file___166 *file;
	struct seq_file___156 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___163 *vm_ops;
};

struct bin_attribute___154;

struct attribute_group___155 {
	const char *name;
	umode_t (*is_visible)(struct kobject___160 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___160 *, struct bin_attribute___154 *, int);
	struct attribute **attrs;
	struct bin_attribute___154 **bin_attrs;
};

struct bin_attribute___154 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___166 *, struct kobject___160 *, struct bin_attribute___154 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___166 *, struct kobject___160 *, struct bin_attribute___154 *, char *, loff_t, size_t);
	int (*mmap)(struct file___166 *, struct kobject___160 *, struct bin_attribute___154 *, struct vm_area_struct___166 *);
};

struct sysfs_ops___159 {
	ssize_t (*show)(struct kobject___160 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___160 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___159;

struct kset___159 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___160 kobj;
	const struct kset_uevent_ops___159 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___159 {
	void (*release)(struct kobject___160 *);
	const struct sysfs_ops___159 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___10 * (*child_ns_type)(struct kobject___160 *);
	const void * (*namespace)(struct kobject___160 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___159 {
	int (* const filter)(struct kset___159 *, struct kobject___160 *);
	const char * (* const name)(struct kset___159 *, struct kobject___160 *);
	int (* const uevent)(struct kset___159 *, struct kobject___160 *, struct kobj_uevent_env *);
};

struct kobj_attribute___160 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___160 *, struct kobj_attribute___160 *, char *);
	ssize_t (*store)(struct kobject___160 *, struct kobj_attribute___160 *, const char *, size_t);
};

struct kernel_param_ops___137 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___137 *);
	int (*get)(char *, const struct kernel_param___137 *);
	void (*free)(void *);
};

struct kparam_array___137;

struct kernel_param___137 {
	const char *name;
	struct module___140 *mod;
	const struct kernel_param_ops___137 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___137 *arr;
	};
};

struct kparam_array___137 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___137 *ops;
	void *elem;
};

struct module_attribute___137 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___137 *, struct module_kobject___137 *, char *);
	ssize_t (*store)(struct module_attribute___137 *, struct module_kobject___137 *, const char *, size_t);
	void (*setup)(struct module___140 *, const char *);
	int (*test)(struct module___140 *);
	void (*free)(struct module___140 *);
};

typedef int (*key_restrict_link_func_t___161)(struct key___161 *, const struct key_type *, const union key_payload *, struct key___161 *);

struct key_restriction___161;

struct key___161 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___166 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___161 *restrict_link;
};

struct key_restriction___161 {
	key_restrict_link_func_t___161 check;
	struct key___161 *key;
	struct key_type *keytype;
};

struct seq_operations___154 {
	void * (*start)(struct seq_file___156 *, loff_t *);
	void (*stop)(struct seq_file___156 *, void *);
	void * (*next)(struct seq_file___156 *, void *, loff_t *);
	int (*show)(struct seq_file___156 *, void *);
};

struct dev_pm_ops___154 {
	int (*prepare)(struct device___154 *);
	void (*complete)(struct device___154 *);
	int (*suspend)(struct device___154 *);
	int (*resume)(struct device___154 *);
	int (*freeze)(struct device___154 *);
	int (*thaw)(struct device___154 *);
	int (*poweroff)(struct device___154 *);
	int (*restore)(struct device___154 *);
	int (*suspend_late)(struct device___154 *);
	int (*resume_early)(struct device___154 *);
	int (*freeze_late)(struct device___154 *);
	int (*thaw_early)(struct device___154 *);
	int (*poweroff_late)(struct device___154 *);
	int (*restore_early)(struct device___154 *);
	int (*suspend_noirq)(struct device___154 *);
	int (*resume_noirq)(struct device___154 *);
	int (*freeze_noirq)(struct device___154 *);
	int (*thaw_noirq)(struct device___154 *);
	int (*poweroff_noirq)(struct device___154 *);
	int (*restore_noirq)(struct device___154 *);
	int (*runtime_suspend)(struct device___154 *);
	int (*runtime_resume)(struct device___154 *);
	int (*runtime_idle)(struct device___154 *);
};

struct dev_pm_domain___154 {
	struct dev_pm_ops___154 ops;
	void (*detach)(struct device___154 *, bool);
	int (*activate)(struct device___154 *);
	void (*sync)(struct device___154 *);
	void (*dismiss)(struct device___154 *);
};

struct bus_type___154 {
	const char *name;
	const char *dev_name;
	struct device___154 *dev_root;
	const struct attribute_group___155 **bus_groups;
	const struct attribute_group___155 **dev_groups;
	const struct attribute_group___155 **drv_groups;
	int (*match)(struct device___154 *, struct device_driver___154 *);
	int (*uevent)(struct device___154 *, struct kobj_uevent_env *);
	int (*probe)(struct device___154 *);
	int (*remove)(struct device___154 *);
	void (*shutdown)(struct device___154 *);
	int (*online)(struct device___154 *);
	int (*offline)(struct device___154 *);
	int (*suspend)(struct device___154 *, pm_message_t);
	int (*resume)(struct device___154 *);
	int (*num_vf)(struct device___154 *);
	int (*dma_configure)(struct device___154 *);
	const struct dev_pm_ops___154 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___154 {
	const char *name;
	struct bus_type___154 *bus;
	struct module___140 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___154 *);
	int (*remove)(struct device___154 *);
	void (*shutdown)(struct device___154 *);
	int (*suspend)(struct device___154 *, pm_message_t);
	int (*resume)(struct device___154 *);
	const struct attribute_group___155 **groups;
	const struct dev_pm_ops___154 *pm;
	void (*coredump)(struct device___154 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___154 {
	const char *name;
	const struct attribute_group___155 **groups;
	int (*uevent)(struct device___154 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___154 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___154 *);
	const struct dev_pm_ops___154 *pm;
};

struct class___154 {
	const char *name;
	struct module___140 *owner;
	const struct attribute_group___155 **class_groups;
	const struct attribute_group___155 **dev_groups;
	struct kobject___160 *dev_kobj;
	int (*dev_uevent)(struct device___154 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___154 *, umode_t *);
	void (*class_release)(struct class___154 *);
	void (*dev_release)(struct device___154 *);
	int (*shutdown_pre)(struct device___154 *);
	const struct kobj_ns_type_operations___10 *ns_type;
	const void * (*namespace)(struct device___154 *);
	const struct dev_pm_ops___154 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct fwnode_operations___110;

struct fwnode_handle___110 {
	struct fwnode_handle___110 *secondary;
	const struct fwnode_operations___110 *ops;
};

struct bio_integrity_payload___82 {
	struct bio___82 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___82 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___82 bip_inline_vecs[0];
};

struct blkcg___28;

struct blkg_policy_data___28;

struct blkcg_gq___28 {
	struct request_queue___38 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___28 *blkcg;
	struct bdi_writeback_congested___82 *wb_congested;
	struct blkcg_gq___28 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_rwstat stat_bytes;
	struct blkg_rwstat stat_ios;
	struct blkg_policy_data___28 *pd[5];
	struct callback_head callback_head;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
};

struct disk_part_tbl___38 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___38 *last_lookup;
	struct hd_struct___38 *part[0];
};

struct block_device_operations___38 {
	int (*open)(struct block_device___166 *, fmode_t);
	void (*release)(struct gendisk___38 *, fmode_t);
	int (*rw_page)(struct block_device___166 *, sector_t, struct page___166 *, unsigned int);
	int (*ioctl)(struct block_device___166 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___166 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___38 *, unsigned int);
	int (*media_changed)(struct gendisk___38 *);
	void (*unlock_native_capacity)(struct gendisk___38 *);
	int (*revalidate_disk)(struct gendisk___38 *);
	int (*getgeo)(struct block_device___166 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___166 *, long unsigned int);
	int (*report_zones)(struct gendisk___38 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___140 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___163(struct page___166 *);

struct bdi_writeback_congested___82 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___82 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct cgroup_subsys___141;

struct cgroup_subsys_state___141 {
	struct cgroup___141 *cgroup;
	struct cgroup_subsys___141 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___141 *parent;
};

struct bsg_ops___37 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___38 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___38 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___38 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___37(struct request___38 *, blk_status_t);

struct request___38 {
	struct request_queue___38 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___82 *bio;
	struct bio___82 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___82 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___41 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___37 *saved_end_io;
		} flush;
	};
	struct gendisk___38 *rq_disk;
	struct hd_struct___38 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___37 *end_io;
	void *end_io_data;
	struct request___38 *next_rq;
};

struct fwnode_reference_args___110;

struct fwnode_endpoint___110;

struct fwnode_operations___110 {
	struct fwnode_handle___110 * (*get)(struct fwnode_handle___110 *);
	void (*put)(struct fwnode_handle___110 *);
	bool (*device_is_available)(const struct fwnode_handle___110 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___110 *, const struct device___154 *);
	bool (*property_present)(const struct fwnode_handle___110 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___110 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___110 *, const char *, const char **, size_t);
	struct fwnode_handle___110 * (*get_parent)(const struct fwnode_handle___110 *);
	struct fwnode_handle___110 * (*get_next_child_node)(const struct fwnode_handle___110 *, struct fwnode_handle___110 *);
	struct fwnode_handle___110 * (*get_named_child_node)(const struct fwnode_handle___110 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___110 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___110 *);
	struct fwnode_handle___110 * (*graph_get_next_endpoint)(const struct fwnode_handle___110 *, struct fwnode_handle___110 *);
	struct fwnode_handle___110 * (*graph_get_remote_endpoint)(const struct fwnode_handle___110 *);
	struct fwnode_handle___110 * (*graph_get_port_parent)(struct fwnode_handle___110 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___110 *, struct fwnode_endpoint___110 *);
};

struct fwnode_endpoint___110 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___110 *local_fwnode;
};

struct fwnode_reference_args___110 {
	struct fwnode_handle___110 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct elevator_type___37;

struct elevator_mq_ops___37 {
	int (*init_sched)(struct request_queue___38 *, struct elevator_type___37 *);
	void (*exit_sched)(struct elevator_queue___37 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	bool (*allow_merge)(struct request_queue___38 *, struct request___38 *, struct bio___82 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx *, struct bio___82 *);
	int (*request_merge)(struct request_queue___38 *, struct request___38 **, struct bio___82 *);
	void (*request_merged)(struct request_queue___38 *, struct request___38 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___38 *, struct request___38 *, struct request___38 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___38 *, struct bio___82 *);
	void (*finish_request)(struct request___38 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___38 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___38 *, u64);
	void (*started_request)(struct request___38 *);
	void (*requeue_request)(struct request___38 *);
	struct request___38 * (*former_request)(struct request_queue___38 *, struct request___38 *);
	struct request___38 * (*next_request)(struct request_queue___38 *, struct request___38 *);
	void (*init_icq)(struct io_cq___41 *);
	void (*exit_icq)(struct io_cq___41 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___37;

struct elevator_type___37 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___37 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___37 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___140 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___37 {
	struct elevator_type___37 *type;
	void *elevator_data;
	struct kobject___160 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___37 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___37 *, char *);
	ssize_t (*store)(struct elevator_queue___37 *, const char *, size_t);
};

struct cgroup_namespace___141 {
	refcount_t count;
	struct ns_common___4 ns;
	struct user_namespace___145 *user_ns;
	struct ucounts___145 *ucounts;
	struct css_set___141 *root_cset;
};

struct ucounts___145 {
	struct hlist_node node;
	struct user_namespace___145 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___141;

struct bpf_map_ops___141 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___141 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___141 *, struct file___166 *);
	void (*map_free)(struct bpf_map___141 *);
	int (*map_get_next_key)(struct bpf_map___141 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___141 *);
	void * (*map_lookup_elem)(struct bpf_map___141 *, void *);
	int (*map_update_elem)(struct bpf_map___141 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___141 *, void *);
	int (*map_push_elem)(struct bpf_map___141 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___141 *, void *);
	int (*map_peek_elem)(struct bpf_map___141 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___141 *, struct file___166 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___141 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___141 *, void *, struct seq_file___156 *);
	int (*map_check_btf)(const struct bpf_map___141 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___141 {
	const struct bpf_map_ops___141 *ops;
	struct bpf_map___141 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___161 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___141;

typedef void (*kthread_work_func_t___141)(struct kthread_work___141 *);

struct kthread_worker___141;

struct kthread_work___141 {
	struct list_head node;
	kthread_work_func_t___141 func;
	struct kthread_worker___141 *worker;
	int canceling;
};

struct kthread_worker___141 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___166 *task;
	struct kthread_work___141 *current_work;
};

struct kthread_delayed_work___141 {
	struct kthread_work___141 work;
	struct timer_list timer;
};

struct psi_group___141 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___141 *poll_kworker;
	struct kthread_delayed_work___141 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___141 {
	struct kernfs_node___162 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_root___141;

struct cgroup_rstat_cpu___141;

struct cgroup___141 {
	struct cgroup_subsys_state___141 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___162 *kn;
	struct cgroup_file___141 procs_file;
	struct cgroup_file___141 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___141 *subsys[13];
	struct cgroup_root___141 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___141 *dom_cgrp;
	struct cgroup_rstat_cpu___141 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___20 bpf;
	atomic_t congestion_count;
	struct cgroup___141 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___141 psi;
	int ancestor_ids[0];
};

struct cftype___141;

struct cgroup_subsys___141 {
	struct cgroup_subsys_state___141 * (*css_alloc)(struct cgroup_subsys_state___141 *);
	int (*css_online)(struct cgroup_subsys_state___141 *);
	void (*css_offline)(struct cgroup_subsys_state___141 *);
	void (*css_released)(struct cgroup_subsys_state___141 *);
	void (*css_free)(struct cgroup_subsys_state___141 *);
	void (*css_reset)(struct cgroup_subsys_state___141 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___141 *, int);
	int (*css_extra_stat_show)(struct seq_file___156 *, struct cgroup_subsys_state___141 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___166 *);
	void (*cancel_fork)(struct task_struct___166 *);
	void (*fork)(struct task_struct___166 *);
	void (*exit)(struct task_struct___166 *);
	void (*free)(struct task_struct___166 *);
	void (*bind)(struct cgroup_subsys_state___141 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___141 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___141 *dfl_cftypes;
	struct cftype___141 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___141 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___141 *updated_children;
	struct cgroup___141 *updated_next;
};

struct cgroup_root___141 {
	struct kernfs_root___162 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___141 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___141 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___141 *ss;
	struct list_head node;
	struct kernfs_ops___162 *kf_ops;
	int (*open)(struct kernfs_open_file___162 *);
	void (*release)(struct kernfs_open_file___162 *);
	u64 (*read_u64)(struct cgroup_subsys_state___141 *, struct cftype___141 *);
	s64 (*read_s64)(struct cgroup_subsys_state___141 *, struct cftype___141 *);
	int (*seq_show)(struct seq_file___156 *, void *);
	void * (*seq_start)(struct seq_file___156 *, loff_t *);
	void * (*seq_next)(struct seq_file___156 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___156 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___141 *, struct cftype___141 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___141 *, struct cftype___141 *, s64);
	ssize_t (*write)(struct kernfs_open_file___162 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___162 *, struct poll_table_struct___6 *);
};

struct blkcg_policy_data___28;

struct blkcg___28 {
	struct cgroup_subsys_state___141 css;
	spinlock_t lock;
	struct xarray blkg_tree;
	struct blkcg_gq___28 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___28 *cpd[5];
	struct list_head all_blkcgs_node;
	struct list_head cgwb_list;
	refcount_t cgwb_refcnt;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct blkcg_policy_data___28 {
	struct blkcg___28 *blkcg;
	int plid;
};

struct blkg_policy_data___28 {
	struct blkcg_gq___28 *blkg;
	int plid;
};

struct kobj_map;

struct char_device_struct {
	struct char_device_struct *next;
	unsigned int major;
	unsigned int baseminor;
	int minorct;
	char name[64];
	struct cdev___32 *cdev;
};

struct module___141;

struct file___167;

struct kiocb___167;

struct poll_table_struct___111;

struct vm_area_struct___167;

struct inode___167;

struct file_lock___167;

struct page___167;

struct seq_file___157;

struct file_operations___167 {
	struct module___141 *owner;
	loff_t (*llseek)(struct file___167 *, loff_t, int);
	ssize_t (*read)(struct file___167 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___167 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___167 *, struct iov_iter___77 *);
	ssize_t (*write_iter)(struct kiocb___167 *, struct iov_iter___77 *);
	int (*iopoll)(struct kiocb___167 *, bool);
	int (*iterate)(struct file___167 *, struct dir_context *);
	int (*iterate_shared)(struct file___167 *, struct dir_context *);
	__poll_t (*poll)(struct file___167 *, struct poll_table_struct___111 *);
	long int (*unlocked_ioctl)(struct file___167 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___167 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___167 *, struct vm_area_struct___167 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___167 *, struct file___167 *);
	int (*flush)(struct file___167 *, fl_owner_t);
	int (*release)(struct inode___167 *, struct file___167 *);
	int (*fsync)(struct file___167 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___167 *, int);
	int (*lock)(struct file___167 *, int, struct file_lock___167 *);
	ssize_t (*sendpage)(struct file___167 *, struct page___167 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___167 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___167 *, int, struct file_lock___167 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___167 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___167 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___167 *, long int, struct file_lock___167 **, void **);
	long int (*fallocate)(struct file___167 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___157 *, struct file___167 *);
	ssize_t (*copy_file_range)(struct file___167 *, loff_t, struct file___167 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___167 *, loff_t, struct file___167 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___167 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___166 {
	u64 seqnum;
	struct vm_area_struct___167 *vmas[4];
};

struct page_frag___166 {
	struct page___167 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___101;

struct debug_info___101 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___101 *hbp_break[16];
	struct perf_event___101 *hbp_watch[16];
};

struct thread_struct___101 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___101 debug;
	long: 64;
};

struct mm_struct___166;

struct pid___131;

struct cred___162;

struct nsproxy___158;

struct signal_struct___147;

struct css_set___142;

struct perf_event_context___101;

struct task_struct___167 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___167 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___166 *mm;
	struct mm_struct___166 *active_mm;
	struct vmacache___166 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___167 *real_parent;
	struct task_struct___167 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___167 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___131 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___131 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___131 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___162 *ptracer_cred;
	const struct cred___162 *real_cred;
	const struct cred___162 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___158 *nsproxy;
	struct signal_struct___147 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___167 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___41 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___142 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___101 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___166 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___167 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___101 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___101 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___167 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___101)(struct perf_event___101 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___101;

struct fasync_struct___166;

struct pid_namespace___131;

struct trace_event_call___94;

struct perf_cgroup___101;

struct perf_event___101 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___101 *group_leader;
	struct pmu___101 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___101 hw;
	struct perf_event_context___101 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___101 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___167 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___166 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___101 *);
	struct callback_head callback_head;
	struct pid_namespace___131 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___101 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___101 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___94 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___101 *cgrp;
	struct list_head sb_list;
};

typedef struct page___167 *pgtable_t___166;

struct address_space___166;

struct dev_pagemap___164;

struct page___167 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___166 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___167 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___166 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___166 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___164 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___166;

struct lruvec___166 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___166 *pgdat;
};

struct zone___166 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___166 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___166 {
	struct zone___166 *zone;
	int zone_idx;
};

struct zonelist___166 {
	struct zoneref___166 _zonerefs[25];
};

struct pglist_data___166 {
	struct zone___166 node_zones[3];
	struct zonelist___166 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___167 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___167 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___166 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___167 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___167 *owner;
};

struct secondary_data___167 {
	void *stack;
	struct task_struct___167 *task;
	long int status;
};

struct blocking_notifier_head___166 {
	struct rw_semaphore___167 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___164;

struct vm_area_struct___167 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___167 *vm_next;
	struct vm_area_struct___167 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___166 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___164 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___167 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___166;

struct user_namespace___146;

struct mm_struct___166 {
	struct {
		struct vm_area_struct___167 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___167 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___167 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___166 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___167 *owner;
		struct user_namespace___146 *user_ns;
		struct file___167 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___166 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___166;

struct address_space___166 {
	struct inode___167 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___167 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___166 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___164)(struct vm_area_struct___167 *, long unsigned int, const struct page___167 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___164)(struct page___167 *, void *);

struct device___155;

struct dev_pagemap___164 {
	dev_page_fault_t___164 page_fault;
	dev_page_free_t___164 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___155 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct dentry___166;

struct path___166 {
	struct vfsmount *mnt;
	struct dentry___166 *dentry;
};

struct fown_struct___131 {
	rwlock_t lock;
	struct pid___131 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___167 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___166 f_path;
	struct inode___167 *f_inode;
	const struct file_operations___167 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___131 f_owner;
	const struct cred___162 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___166 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___164;

struct vm_operations_struct___164 {
	void (*open)(struct vm_area_struct___167 *);
	void (*close)(struct vm_area_struct___167 *);
	int (*split)(struct vm_area_struct___167 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___167 *);
	vm_fault_t (*fault)(struct vm_fault___164 *);
	vm_fault_t (*huge_fault)(struct vm_fault___164 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___164 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___167 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___164 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___164 *);
	int (*access)(struct vm_area_struct___167 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___167 *);
	int (*set_policy)(struct vm_area_struct___167 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___167 *, long unsigned int);
	struct page___167 * (*find_special_page)(struct vm_area_struct___167 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___166 {
	struct task_struct___167 *task;
	struct core_thread___166 *next;
};

struct core_state___166 {
	atomic_t nr_threads;
	struct core_thread___166 dumper;
	struct completion startup;
};

struct key___162;

struct ucounts___146;

struct user_namespace___146 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___146 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___4 ns;
	long unsigned int flags;
	struct key___162 *persistent_keyring_register;
	struct rw_semaphore___167 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___146 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___164 {
	struct vm_area_struct___167 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___167 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___167 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___166 prealloc_pte;
};

struct upid___131 {
	int nr;
	struct pid_namespace___131 *ns;
};

struct pid_namespace___131 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___167 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___131 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___166 *proc_self;
	struct dentry___166 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___146 *user_ns;
	struct ucounts___146 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___4 ns;
};

struct pid___131 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___131 numbers[1];
};

struct user_struct___162 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___162 *uid_keyring;
	struct key___162 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___162 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___162 *session_keyring;
	struct key___162 *process_keyring;
	struct key___162 *thread_keyring;
	struct key___162 *request_key_auth;
	void *security;
	struct user_struct___162 *user;
	struct user_namespace___146 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___142;

struct nsproxy___158 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___131 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___142 *cgroup_ns;
};

struct signal_struct___147 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___167 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___167 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___131 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___131 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___166 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___131 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___142;

struct cgroup___142;

struct css_set___142 {
	struct cgroup_subsys_state___142 *subsys[13];
	refcount_t refcount;
	struct css_set___142 *dom_cset;
	struct cgroup___142 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___142 *mg_src_cgrp;
	struct cgroup___142 *mg_dst_cgrp;
	struct css_set___142 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___101 {
	struct pmu___101 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___167 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___101 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

union thread_union___148 {
	struct task_struct___167 task;
	long unsigned int stack[8192];
};

struct kset___160;

struct kobj_type___160;

struct kernfs_node___163;

struct kobject___161 {
	const char *name;
	struct list_head entry;
	struct kobject___161 *parent;
	struct kset___160 *kset;
	struct kobj_type___160 *ktype;
	struct kernfs_node___163 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___155 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___155 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___155;

struct bus_type___155;

struct device_driver___155;

struct dev_pm_domain___155;

struct class___155;

struct attribute_group___156;

struct device___155 {
	struct device___155 *parent;
	struct device_private *p;
	struct kobject___161 kobj;
	const char *init_name;
	const struct device_type___155 *type;
	struct mutex mutex;
	struct bus_type___155 *bus;
	struct device_driver___155 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___155 power;
	struct dev_pm_domain___155 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___155 *class;
	const struct attribute_group___156 **groups;
	void (*release)(struct device___155 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___166;

struct super_block___166;

struct dentry___166 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___166 *d_parent;
	struct qstr d_name;
	struct inode___167 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___166 *d_op;
	struct super_block___166 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___166;

struct block_device___167;

struct inode___167 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___166 *i_op;
	struct super_block___166 *i_sb;
	struct address_space___166 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___167 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___167 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___166 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___167 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___166 {
	int (*d_revalidate)(struct dentry___166 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___166 *, unsigned int);
	int (*d_hash)(const struct dentry___166 *, struct qstr *);
	int (*d_compare)(const struct dentry___166 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___166 *);
	int (*d_init)(struct dentry___166 *);
	void (*d_release)(struct dentry___166 *);
	void (*d_prune)(struct dentry___166 *);
	void (*d_iput)(struct dentry___166 *, struct inode___167 *);
	char * (*d_dname)(struct dentry___166 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___166 *);
	int (*d_manage)(const struct path___166 *, bool);
	struct dentry___166 * (*d_real)(struct dentry___166 *, const struct inode___167 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___166;

struct mem_dqinfo___166 {
	struct quota_format_type___166 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___166;

struct quota_info___166 {
	unsigned int flags;
	struct rw_semaphore___167 dqio_sem;
	struct inode___167 *files[3];
	struct mem_dqinfo___166 info[3];
	const struct quota_format_ops___166 *ops[3];
};

struct rcuwait___166 {
	struct task_struct___167 *task;
};

struct percpu_rw_semaphore___166 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___167 rw_sem;
	struct rcuwait___166 writer;
	int readers_block;
};

struct sb_writers___166 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___166 rw_sem[3];
};

struct file_system_type___166;

struct super_operations___166;

struct dquot_operations___166;

struct quotactl_ops___166;

struct super_block___166 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___166 *s_type;
	const struct super_operations___166 *s_op;
	const struct dquot_operations___166 *dq_op;
	const struct quotactl_ops___166 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___166 *s_root;
	struct rw_semaphore___167 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___167 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___166 s_dquot;
	struct sb_writers___166 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___166 *s_d_op;
	int cleancache_poolid;
	struct shrinker___74 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___146 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct stat {
	long unsigned int st_dev;
	long unsigned int st_ino;
	unsigned int st_mode;
	unsigned int st_nlink;
	unsigned int st_uid;
	unsigned int st_gid;
	long unsigned int st_rdev;
	long unsigned int __pad1;
	long int st_size;
	int st_blksize;
	int __pad2;
	long int st_blocks;
	long int st_atime;
	long unsigned int st_atime_nsec;
	long int st_mtime;
	long unsigned int st_mtime_nsec;
	long int st_ctime;
	long unsigned int st_ctime_nsec;
	unsigned int __unused4;
	unsigned int __unused5;
};

struct statx_timestamp {
	__s64 tv_sec;
	__u32 tv_nsec;
	__s32 __reserved;
};

struct statx {
	__u32 stx_mask;
	__u32 stx_blksize;
	__u64 stx_attributes;
	__u32 stx_nlink;
	__u32 stx_uid;
	__u32 stx_gid;
	__u16 stx_mode;
	__u16 __spare0[1];
	__u64 stx_ino;
	__u64 stx_size;
	__u64 stx_blocks;
	__u64 stx_attributes_mask;
	struct statx_timestamp stx_atime;
	struct statx_timestamp stx_btime;
	struct statx_timestamp stx_ctime;
	struct statx_timestamp stx_mtime;
	__u32 stx_rdev_major;
	__u32 stx_rdev_minor;
	__u32 stx_dev_major;
	__u32 stx_dev_minor;
	__u64 __spare2[14];
};

struct kiocb___167 {
	struct file___167 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___167 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___166 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___167 *ia_file;
};

struct dquot___166 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___166 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___166 {
	int qf_fmt_id;
	const struct quota_format_ops___166 *qf_ops;
	struct module___141 *qf_owner;
	struct quota_format_type___166 *qf_next;
};

struct quota_format_ops___166 {
	int (*check_quota_file)(struct super_block___166 *, int);
	int (*read_file_info)(struct super_block___166 *, int);
	int (*write_file_info)(struct super_block___166 *, int);
	int (*free_file_info)(struct super_block___166 *, int);
	int (*read_dqblk)(struct dquot___166 *);
	int (*commit_dqblk)(struct dquot___166 *);
	int (*release_dqblk)(struct dquot___166 *);
	int (*get_next_id)(struct super_block___166 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___166 {
	int (*write_dquot)(struct dquot___166 *);
	struct dquot___166 * (*alloc_dquot)(struct super_block___166 *, int);
	void (*destroy_dquot)(struct dquot___166 *);
	int (*acquire_dquot)(struct dquot___166 *);
	int (*release_dquot)(struct dquot___166 *);
	int (*mark_dirty)(struct dquot___166 *);
	int (*write_info)(struct super_block___166 *, int);
	qsize_t * (*get_reserved_space)(struct inode___167 *);
	int (*get_projid)(struct inode___167 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___167 *, qsize_t *);
	int (*get_next_id)(struct super_block___166 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___166 {
	int (*quota_on)(struct super_block___166 *, int, int, const struct path___166 *);
	int (*quota_off)(struct super_block___166 *, int);
	int (*quota_enable)(struct super_block___166 *, unsigned int);
	int (*quota_disable)(struct super_block___166 *, unsigned int);
	int (*quota_sync)(struct super_block___166 *, int);
	int (*set_info)(struct super_block___166 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___166 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___166 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___166 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___166 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___166 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___138 {
	struct kobject___161 kobj;
	struct module___141 *mod;
	struct kobject___161 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___138 {
	struct module___141 *mod;
	struct latch_tree_node node;
};

struct module_layout___138 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___138 mtn;
};

struct module_attribute___138;

struct kernel_param___138;

struct module___141 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___138 mkobj;
	struct module_attribute___138 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___161 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___138 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___138 core_layout;
	struct module_layout___138 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___94 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___166 {
	int (*writepage)(struct page___167 *, struct writeback_control___3 *);
	int (*readpage)(struct file___167 *, struct page___167 *);
	int (*writepages)(struct address_space___166 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___167 *);
	int (*readpages)(struct file___167 *, struct address_space___166 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___167 *, struct address_space___166 *, loff_t, unsigned int, unsigned int, struct page___167 **, void **);
	int (*write_end)(struct file___167 *, struct address_space___166 *, loff_t, unsigned int, unsigned int, struct page___167 *, void *);
	sector_t (*bmap)(struct address_space___166 *, sector_t);
	void (*invalidatepage)(struct page___167 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___167 *, gfp_t);
	void (*freepage)(struct page___167 *);
	ssize_t (*direct_IO)(struct kiocb___167 *, struct iov_iter___77 *);
	int (*migratepage)(struct address_space___166 *, struct page___167 *, struct page___167 *, enum migrate_mode);
	bool (*isolate_page)(struct page___167 *, isolate_mode_t);
	void (*putback_page)(struct page___167 *);
	int (*launder_page)(struct page___167 *);
	int (*is_partially_uptodate)(struct page___167 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___167 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___166 *, struct page___167 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___167 *, sector_t *);
	void (*swap_deactivate)(struct file___167 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___167 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___167 *bd_inode;
	struct super_block___166 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___167 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___166 {
	struct dentry___166 * (*lookup)(struct inode___167 *, struct dentry___166 *, unsigned int);
	const char * (*get_link)(struct dentry___166 *, struct inode___167 *, struct delayed_call *);
	int (*permission)(struct inode___167 *, int);
	struct posix_acl * (*get_acl)(struct inode___167 *, int);
	int (*readlink)(struct dentry___166 *, char *, int);
	int (*create)(struct inode___167 *, struct dentry___166 *, umode_t, bool);
	int (*link)(struct dentry___166 *, struct inode___167 *, struct dentry___166 *);
	int (*unlink)(struct inode___167 *, struct dentry___166 *);
	int (*symlink)(struct inode___167 *, struct dentry___166 *, const char *);
	int (*mkdir)(struct inode___167 *, struct dentry___166 *, umode_t);
	int (*rmdir)(struct inode___167 *, struct dentry___166 *);
	int (*mknod)(struct inode___167 *, struct dentry___166 *, umode_t, dev_t);
	int (*rename)(struct inode___167 *, struct dentry___166 *, struct inode___167 *, struct dentry___166 *, unsigned int);
	int (*setattr)(struct dentry___166 *, struct iattr___166 *);
	int (*getattr)(const struct path___166 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___166 *, char *, size_t);
	int (*fiemap)(struct inode___167 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___167 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___167 *, struct dentry___166 *, struct file___167 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___167 *, struct dentry___166 *, umode_t);
	int (*set_acl)(struct inode___167 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___166 {
	void (*fl_copy_lock)(struct file_lock___167 *, struct file_lock___167 *);
	void (*fl_release_private)(struct file_lock___167 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___166;

struct file_lock___167 {
	struct file_lock___167 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___167 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___166 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___166 *fl_ops;
	const struct lock_manager_operations___166 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___166 {
	int (*lm_compare_owner)(struct file_lock___167 *, struct file_lock___167 *);
	long unsigned int (*lm_owner_key)(struct file_lock___167 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___167 *);
	int (*lm_grant)(struct file_lock___167 *, int);
	bool (*lm_break)(struct file_lock___167 *);
	int (*lm_change)(struct file_lock___167 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___167 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___166 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___166 *fa_next;
	struct file___167 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___166 {
	const char *name;
	int fs_flags;
	struct dentry___166 * (*mount)(struct file_system_type___166 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___166 *);
	struct module___141 *owner;
	struct file_system_type___166 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___166 {
	struct inode___167 * (*alloc_inode)(struct super_block___166 *);
	void (*destroy_inode)(struct inode___167 *);
	void (*dirty_inode)(struct inode___167 *, int);
	int (*write_inode)(struct inode___167 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___167 *);
	void (*evict_inode)(struct inode___167 *);
	void (*put_super)(struct super_block___166 *);
	int (*sync_fs)(struct super_block___166 *, int);
	int (*freeze_super)(struct super_block___166 *);
	int (*freeze_fs)(struct super_block___166 *);
	int (*thaw_super)(struct super_block___166 *);
	int (*unfreeze_fs)(struct super_block___166 *);
	int (*statfs)(struct dentry___166 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___166 *, int *, char *);
	void (*umount_begin)(struct super_block___166 *);
	int (*show_options)(struct seq_file___157 *, struct dentry___166 *);
	int (*show_devname)(struct seq_file___157 *, struct dentry___166 *);
	int (*show_path)(struct seq_file___157 *, struct dentry___166 *);
	int (*show_stats)(struct seq_file___157 *, struct dentry___166 *);
	ssize_t (*quota_read)(struct super_block___166 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___166 *, int, const char *, size_t, loff_t);
	struct dquot___166 ** (*get_dquots)(struct inode___167 *);
	int (*bdev_try_to_free_page)(struct super_block___166 *, struct page___167 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___166 *, struct shrink_control___74 *);
	long int (*free_cached_objects)(struct super_block___166 *, struct shrink_control___74 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___110)(struct file___167 *, wait_queue_head_t *, struct poll_table_struct___111 *);

struct poll_table_struct___111 {
	poll_queue_proc___110 _qproc;
	__poll_t _key;
};

struct seq_operations___155;

struct seq_file___157 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___155 *op;
	int poll_event;
	const struct file___167 *file;
	void *private;
};

struct kobj_attribute___161 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___161 *, struct kobj_attribute___161 *, char *);
	ssize_t (*store)(struct kobject___161 *, struct kobj_attribute___161 *, const char *, size_t);
};

typedef void compound_page_dtor___164(struct page___167 *);

struct fd___12 {
	struct file___167 *file;
	unsigned int flags;
};

typedef int (*key_restrict_link_func_t___162)(struct key___162 *, const struct key_type *, const union key_payload *, struct key___162 *);

struct key_restriction___162;

struct key___162 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___167 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___162 *restrict_link;
};

struct key_restriction___162 {
	key_restrict_link_func_t___162 check;
	struct key___162 *key;
	struct key_type *keytype;
};

struct seq_operations___155 {
	void * (*start)(struct seq_file___157 *, loff_t *);
	void (*stop)(struct seq_file___157 *, void *);
	void * (*next)(struct seq_file___157 *, void *, loff_t *);
	int (*show)(struct seq_file___157 *, void *);
};

struct cgroup_namespace___142 {
	refcount_t count;
	struct ns_common___4 ns;
	struct user_namespace___146 *user_ns;
	struct ucounts___146 *ucounts;
	struct css_set___142 *root_cset;
};

struct ucounts___146 {
	struct hlist_node node;
	struct user_namespace___146 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct kernfs_root___163;

struct kernfs_elem_dir___163 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___163 *root;
};

struct kernfs_syscall_ops___163;

struct kernfs_root___163 {
	struct kernfs_node___163 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___163 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___163 {
	struct kernfs_node___163 *target_kn;
};

struct kernfs_ops___163;

struct kernfs_elem_attr___163 {
	const struct kernfs_ops___163 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___163 *notify_next;
};

struct kernfs_node___163 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___163 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___163 dir;
		struct kernfs_elem_symlink___163 symlink;
		struct kernfs_elem_attr___163 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___163;

struct kernfs_ops___163 {
	int (*open)(struct kernfs_open_file___163 *);
	void (*release)(struct kernfs_open_file___163 *);
	int (*seq_show)(struct seq_file___157 *, void *);
	void * (*seq_start)(struct seq_file___157 *, loff_t *);
	void * (*seq_next)(struct seq_file___157 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___157 *, void *);
	ssize_t (*read)(struct kernfs_open_file___163 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___163 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___163 *, struct vm_area_struct___167 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___163 *, struct poll_table_struct___111 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___163 {
	int (*remount_fs)(struct kernfs_root___163 *, int *, char *);
	int (*show_options)(struct seq_file___157 *, struct kernfs_root___163 *);
	int (*mkdir)(struct kernfs_node___163 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___163 *);
	int (*rename)(struct kernfs_node___163 *, struct kernfs_node___163 *, const char *);
	int (*show_path)(struct seq_file___157 *, struct kernfs_node___163 *, struct kernfs_root___163 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___163 {
	struct kernfs_node___163 *kn;
	struct file___167 *file;
	struct seq_file___157 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___164 *vm_ops;
};

struct bin_attribute___155;

struct attribute_group___156 {
	const char *name;
	umode_t (*is_visible)(struct kobject___161 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___161 *, struct bin_attribute___155 *, int);
	struct attribute **attrs;
	struct bin_attribute___155 **bin_attrs;
};

struct bin_attribute___155 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___167 *, struct kobject___161 *, struct bin_attribute___155 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___167 *, struct kobject___161 *, struct bin_attribute___155 *, char *, loff_t, size_t);
	int (*mmap)(struct file___167 *, struct kobject___161 *, struct bin_attribute___155 *, struct vm_area_struct___167 *);
};

struct sysfs_ops___160 {
	ssize_t (*show)(struct kobject___161 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___161 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___160;

struct kset___160 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___161 kobj;
	const struct kset_uevent_ops___160 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___160 {
	void (*release)(struct kobject___161 *);
	const struct sysfs_ops___160 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___10 * (*child_ns_type)(struct kobject___161 *);
	const void * (*namespace)(struct kobject___161 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___160 {
	int (* const filter)(struct kset___160 *, struct kobject___161 *);
	const char * (* const name)(struct kset___160 *, struct kobject___161 *);
	int (* const uevent)(struct kset___160 *, struct kobject___161 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___138 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___138 *);
	int (*get)(char *, const struct kernel_param___138 *);
	void (*free)(void *);
};

struct kparam_array___138;

struct kernel_param___138 {
	const char *name;
	struct module___141 *mod;
	const struct kernel_param_ops___138 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___138 *arr;
	};
};

struct kparam_array___138 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___138 *ops;
	void *elem;
};

struct module_attribute___138 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___138 *, struct module_kobject___138 *, char *);
	ssize_t (*store)(struct module_attribute___138 *, struct module_kobject___138 *, const char *, size_t);
	void (*setup)(struct module___141 *, const char *);
	int (*test)(struct module___141 *);
	void (*free)(struct module___141 *);
};

struct trace_event_class___94;

struct trace_event_call___94 {
	struct list_head list;
	struct trace_event_class___94 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___20 *prog_array;
	int (*perf_perm)(struct trace_event_call___94 *, struct perf_event___101 *);
};

struct dev_pm_ops___155 {
	int (*prepare)(struct device___155 *);
	void (*complete)(struct device___155 *);
	int (*suspend)(struct device___155 *);
	int (*resume)(struct device___155 *);
	int (*freeze)(struct device___155 *);
	int (*thaw)(struct device___155 *);
	int (*poweroff)(struct device___155 *);
	int (*restore)(struct device___155 *);
	int (*suspend_late)(struct device___155 *);
	int (*resume_early)(struct device___155 *);
	int (*freeze_late)(struct device___155 *);
	int (*thaw_early)(struct device___155 *);
	int (*poweroff_late)(struct device___155 *);
	int (*restore_early)(struct device___155 *);
	int (*suspend_noirq)(struct device___155 *);
	int (*resume_noirq)(struct device___155 *);
	int (*freeze_noirq)(struct device___155 *);
	int (*thaw_noirq)(struct device___155 *);
	int (*poweroff_noirq)(struct device___155 *);
	int (*restore_noirq)(struct device___155 *);
	int (*runtime_suspend)(struct device___155 *);
	int (*runtime_resume)(struct device___155 *);
	int (*runtime_idle)(struct device___155 *);
};

struct dev_pm_domain___155 {
	struct dev_pm_ops___155 ops;
	void (*detach)(struct device___155 *, bool);
	int (*activate)(struct device___155 *);
	void (*sync)(struct device___155 *);
	void (*dismiss)(struct device___155 *);
};

struct bus_type___155 {
	const char *name;
	const char *dev_name;
	struct device___155 *dev_root;
	const struct attribute_group___156 **bus_groups;
	const struct attribute_group___156 **dev_groups;
	const struct attribute_group___156 **drv_groups;
	int (*match)(struct device___155 *, struct device_driver___155 *);
	int (*uevent)(struct device___155 *, struct kobj_uevent_env *);
	int (*probe)(struct device___155 *);
	int (*remove)(struct device___155 *);
	void (*shutdown)(struct device___155 *);
	int (*online)(struct device___155 *);
	int (*offline)(struct device___155 *);
	int (*suspend)(struct device___155 *, pm_message_t);
	int (*resume)(struct device___155 *);
	int (*num_vf)(struct device___155 *);
	int (*dma_configure)(struct device___155 *);
	const struct dev_pm_ops___155 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___155 {
	const char *name;
	struct bus_type___155 *bus;
	struct module___141 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___155 *);
	int (*remove)(struct device___155 *);
	void (*shutdown)(struct device___155 *);
	int (*suspend)(struct device___155 *, pm_message_t);
	int (*resume)(struct device___155 *);
	const struct attribute_group___156 **groups;
	const struct dev_pm_ops___155 *pm;
	void (*coredump)(struct device___155 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___155 {
	const char *name;
	const struct attribute_group___156 **groups;
	int (*uevent)(struct device___155 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___155 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___155 *);
	const struct dev_pm_ops___155 *pm;
};

struct class___155 {
	const char *name;
	struct module___141 *owner;
	const struct attribute_group___156 **class_groups;
	const struct attribute_group___156 **dev_groups;
	struct kobject___161 *dev_kobj;
	int (*dev_uevent)(struct device___155 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___155 *, umode_t *);
	void (*class_release)(struct class___155 *);
	void (*dev_release)(struct device___155 *);
	int (*shutdown_pre)(struct device___155 *);
	const struct kobj_ns_type_operations___10 *ns_type;
	const void * (*namespace)(struct device___155 *);
	const struct dev_pm_ops___155 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___131 {
	struct device___155 dev;
};

struct bpf_map___142;

struct bpf_map_ops___142 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___142 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___142 *, struct file___167 *);
	void (*map_free)(struct bpf_map___142 *);
	int (*map_get_next_key)(struct bpf_map___142 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___142 *);
	void * (*map_lookup_elem)(struct bpf_map___142 *, void *);
	int (*map_update_elem)(struct bpf_map___142 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___142 *, void *);
	int (*map_push_elem)(struct bpf_map___142 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___142 *, void *);
	int (*map_peek_elem)(struct bpf_map___142 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___142 *, struct file___167 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___142 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___142 *, void *, struct seq_file___157 *);
	int (*map_check_btf)(const struct bpf_map___142 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___142 {
	const struct bpf_map_ops___142 *ops;
	struct bpf_map___142 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___162 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___142;

typedef void (*kthread_work_func_t___142)(struct kthread_work___142 *);

struct kthread_worker___142;

struct kthread_work___142 {
	struct list_head node;
	kthread_work_func_t___142 func;
	struct kthread_worker___142 *worker;
	int canceling;
};

struct kthread_worker___142 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___167 *task;
	struct kthread_work___142 *current_work;
};

struct kthread_delayed_work___142 {
	struct kthread_work___142 work;
	struct timer_list timer;
};

struct psi_group___142 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___142 *poll_kworker;
	struct kthread_delayed_work___142 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___142 {
	struct kernfs_node___163 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___142;

struct cgroup_subsys_state___142 {
	struct cgroup___142 *cgroup;
	struct cgroup_subsys___142 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___142 *parent;
};

struct cgroup_root___142;

struct cgroup_rstat_cpu___142;

struct cgroup___142 {
	struct cgroup_subsys_state___142 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___163 *kn;
	struct cgroup_file___142 procs_file;
	struct cgroup_file___142 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___142 *subsys[13];
	struct cgroup_root___142 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___142 *dom_cgrp;
	struct cgroup_rstat_cpu___142 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___20 bpf;
	atomic_t congestion_count;
	struct cgroup___142 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___142 psi;
	int ancestor_ids[0];
};

struct cftype___142;

struct cgroup_subsys___142 {
	struct cgroup_subsys_state___142 * (*css_alloc)(struct cgroup_subsys_state___142 *);
	int (*css_online)(struct cgroup_subsys_state___142 *);
	void (*css_offline)(struct cgroup_subsys_state___142 *);
	void (*css_released)(struct cgroup_subsys_state___142 *);
	void (*css_free)(struct cgroup_subsys_state___142 *);
	void (*css_reset)(struct cgroup_subsys_state___142 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___142 *, int);
	int (*css_extra_stat_show)(struct seq_file___157 *, struct cgroup_subsys_state___142 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___167 *);
	void (*cancel_fork)(struct task_struct___167 *);
	void (*fork)(struct task_struct___167 *);
	void (*exit)(struct task_struct___167 *);
	void (*free)(struct task_struct___167 *);
	void (*bind)(struct cgroup_subsys_state___142 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___142 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___142 *dfl_cftypes;
	struct cftype___142 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___142 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___142 *updated_children;
	struct cgroup___142 *updated_next;
};

struct cgroup_root___142 {
	struct kernfs_root___163 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___142 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___142 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___142 *ss;
	struct list_head node;
	struct kernfs_ops___163 *kf_ops;
	int (*open)(struct kernfs_open_file___163 *);
	void (*release)(struct kernfs_open_file___163 *);
	u64 (*read_u64)(struct cgroup_subsys_state___142 *, struct cftype___142 *);
	s64 (*read_s64)(struct cgroup_subsys_state___142 *, struct cftype___142 *);
	int (*seq_show)(struct seq_file___157 *, void *);
	void * (*seq_start)(struct seq_file___157 *, loff_t *);
	void * (*seq_next)(struct seq_file___157 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___157 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___142 *, struct cftype___142 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___142 *, struct cftype___142 *, s64);
	ssize_t (*write)(struct kernfs_open_file___163 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___163 *, struct poll_table_struct___111 *);
};

struct perf_cpu_context___101;

struct pmu___101 {
	struct list_head entry;
	struct module___141 *module;
	struct device___155 *dev;
	const struct attribute_group___156 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___101 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___101 *);
	void (*pmu_disable)(struct pmu___101 *);
	int (*event_init)(struct perf_event___101 *);
	void (*event_mapped)(struct perf_event___101 *, struct mm_struct___166 *);
	void (*event_unmapped)(struct perf_event___101 *, struct mm_struct___166 *);
	int (*add)(struct perf_event___101 *, int);
	void (*del)(struct perf_event___101 *, int);
	void (*start)(struct perf_event___101 *, int);
	void (*stop)(struct perf_event___101 *, int);
	void (*read)(struct perf_event___101 *);
	void (*start_txn)(struct pmu___101 *, unsigned int);
	int (*commit_txn)(struct pmu___101 *);
	void (*cancel_txn)(struct pmu___101 *);
	int (*event_idx)(struct perf_event___101 *);
	void (*sched_task)(struct perf_event_context___101 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___101 *);
	int (*filter_match)(struct perf_event___101 *);
	int (*check_period)(struct perf_event___101 *, u64);
};

struct perf_cpu_context___101 {
	struct perf_event_context___101 ctx;
	struct perf_event_context___101 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___101 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___101 {
	struct cgroup_subsys_state___142 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___94 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___94 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___94 *);
	struct list_head * (*get_fields)(struct trace_event_call___94 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___94 *);
};

struct syscall_metadata___40 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___94 *enter_event;
	struct trace_event_call___94 *exit_event;
};

typedef short unsigned int ushort;

struct module___142;

struct file___168;

struct kiocb___168;

struct iov_iter___78;

struct poll_table_struct___112;

struct vm_area_struct___168;

struct inode___168;

struct file_lock___168;

struct page___168;

struct pipe_inode_info___37;

struct seq_file___158;

struct file_operations___168 {
	struct module___142 *owner;
	loff_t (*llseek)(struct file___168 *, loff_t, int);
	ssize_t (*read)(struct file___168 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___168 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___168 *, struct iov_iter___78 *);
	ssize_t (*write_iter)(struct kiocb___168 *, struct iov_iter___78 *);
	int (*iopoll)(struct kiocb___168 *, bool);
	int (*iterate)(struct file___168 *, struct dir_context *);
	int (*iterate_shared)(struct file___168 *, struct dir_context *);
	__poll_t (*poll)(struct file___168 *, struct poll_table_struct___112 *);
	long int (*unlocked_ioctl)(struct file___168 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___168 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___168 *, struct vm_area_struct___168 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___168 *, struct file___168 *);
	int (*flush)(struct file___168 *, fl_owner_t);
	int (*release)(struct inode___168 *, struct file___168 *);
	int (*fsync)(struct file___168 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___168 *, int);
	int (*lock)(struct file___168 *, int, struct file_lock___168 *);
	ssize_t (*sendpage)(struct file___168 *, struct page___168 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___168 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___168 *, int, struct file_lock___168 *);
	ssize_t (*splice_write)(struct pipe_inode_info___37 *, struct file___168 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___168 *, loff_t *, struct pipe_inode_info___37 *, size_t, unsigned int);
	int (*setlease)(struct file___168 *, long int, struct file_lock___168 **, void **);
	long int (*fallocate)(struct file___168 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___158 *, struct file___168 *);
	ssize_t (*copy_file_range)(struct file___168 *, loff_t, struct file___168 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___168 *, loff_t, struct file___168 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___168 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___167 {
	u64 seqnum;
	struct vm_area_struct___168 *vmas[4];
};

struct page_frag___167 {
	struct page___168 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___102;

struct debug_info___102 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___102 *hbp_break[16];
	struct perf_event___102 *hbp_watch[16];
};

struct thread_struct___102 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___102 debug;
	long: 64;
};

struct mm_struct___167;

struct mem_cgroup___75;

struct pid___132;

struct cred___163;

struct fs_struct___8;

struct files_struct___8;

struct nsproxy___159;

struct signal_struct___148;

struct bio_list___83;

struct backing_dev_info___83;

struct io_context___42;

struct css_set___143;

struct perf_event_context___102;

struct request_queue___39;

struct vm_struct___122;

struct task_struct___168 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___168 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___167 *mm;
	struct mm_struct___167 *active_mm;
	struct vmacache___167 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___168 *real_parent;
	struct task_struct___168 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___168 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___75 *active_memcg;
	long int rh_reserved2;
	struct pid___132 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___132 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___132 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___163 *ptracer_cred;
	const struct cred___163 *real_cred;
	const struct cred___163 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct___8 *fs;
	struct files_struct___8 *files;
	struct nsproxy___159 *nsproxy;
	struct signal_struct___148 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___168 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___83 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___83 *backing_dev_info;
	struct io_context___42 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___143 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___102 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___37 *splice_pipe;
	struct page_frag___167 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___75 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___39 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___168 *oom_reaper_list;
	struct vm_struct___122 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___102 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___102 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___168 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___102)(struct perf_event___102 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___102;

struct fasync_struct___167;

struct pid_namespace___132;

struct trace_event_call___95;

struct perf_cgroup___102;

struct perf_event___102 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___102 *group_leader;
	struct pmu___102 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___102 hw;
	struct perf_event_context___102 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___102 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___168 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___167 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___102 *);
	struct callback_head callback_head;
	struct pid_namespace___132 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___102 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___102 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___95 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___102 *cgrp;
	struct list_head sb_list;
};

typedef struct page___168 *pgtable_t___167;

struct address_space___167;

struct dev_pagemap___165;

struct page___168 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___167 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___168 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___167 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___167 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___165 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___75 *mem_cgroup;
};

struct pglist_data___167;

struct lruvec___167 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___167 *pgdat;
};

struct zone___167 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___167 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___167 {
	struct zone___167 *zone;
	int zone_idx;
};

struct zonelist___167 {
	struct zoneref___167 _zonerefs[25];
};

struct pglist_data___167 {
	struct zone___167 node_zones[3];
	struct zonelist___167 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___168 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___168 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___167 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___168 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___168 *owner;
};

struct secondary_data___168 {
	void *stack;
	struct task_struct___168 *task;
	long int status;
};

struct blocking_notifier_head___167 {
	struct rw_semaphore___168 rwsem;
	struct notifier_block *head;
};

struct cgroup___143;

struct cgroup_subsys___143;

struct cgroup_subsys_state___143 {
	struct cgroup___143 *cgroup;
	struct cgroup_subsys___143 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___143 *parent;
};

struct kernfs_node___164;

struct cgroup_file___143 {
	struct kernfs_node___164 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___75;

struct mem_cgroup___75 {
	struct cgroup_subsys_state___143 css;
	struct mem_cgroup_id___6 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___143 events_file;
	struct cgroup_file___143 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___168 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___75 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fd___13 {
	struct file___168 *file;
	unsigned int flags;
};

struct vfsmount___25;

struct dentry___167;

struct path___167 {
	struct vfsmount___25 *mnt;
	struct dentry___167 *dentry;
};

struct fown_struct___132 {
	rwlock_t lock;
	struct pid___132 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___168 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___167 f_path;
	struct inode___168 *f_inode;
	const struct file_operations___168 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___132 f_owner;
	const struct cred___163 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___167 *f_mapping;
	errseq_t f_wb_err;
};

struct dentry_operations___167;

struct super_block___167;

struct dentry___167 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___167 *d_parent;
	struct qstr d_name;
	struct inode___168 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___167 *d_op;
	struct super_block___167 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___167;

struct address_space___167 {
	struct inode___168 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___168 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___167 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___167;

struct bdi_writeback___83;

struct block_device___168;

struct inode___168 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___167 *i_op;
	struct super_block___167 *i_sb;
	struct address_space___167 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___168 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___83 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___168 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___167 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___37 *i_pipe;
		struct block_device___168 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___167 {
	int (*d_revalidate)(struct dentry___167 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___167 *, unsigned int);
	int (*d_hash)(const struct dentry___167 *, struct qstr *);
	int (*d_compare)(const struct dentry___167 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___167 *);
	int (*d_init)(struct dentry___167 *);
	void (*d_release)(struct dentry___167 *);
	void (*d_prune)(struct dentry___167 *);
	void (*d_iput)(struct dentry___167 *, struct inode___168 *);
	char * (*d_dname)(struct dentry___167 *, char *, int);
	struct vfsmount___25 * (*d_automount)(struct path___167 *);
	int (*d_manage)(const struct path___167 *, bool);
	struct dentry___167 * (*d_real)(struct dentry___167 *, const struct inode___168 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___167;

struct mem_dqinfo___167 {
	struct quota_format_type___167 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___167;

struct quota_info___167 {
	unsigned int flags;
	struct rw_semaphore___168 dqio_sem;
	struct inode___168 *files[3];
	struct mem_dqinfo___167 info[3];
	const struct quota_format_ops___167 *ops[3];
};

struct rcuwait___167 {
	struct task_struct___168 *task;
};

struct percpu_rw_semaphore___167 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___168 rw_sem;
	struct rcuwait___167 writer;
	int readers_block;
};

struct sb_writers___167 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___167 rw_sem[3];
};

struct shrink_control___75;

struct shrinker___75 {
	long unsigned int (*count_objects)(struct shrinker___75 *, struct shrink_control___75 *);
	long unsigned int (*scan_objects)(struct shrinker___75 *, struct shrink_control___75 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___167;

struct super_operations___167;

struct dquot_operations___167;

struct quotactl_ops___167;

struct user_namespace___147;

struct super_block___167 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___167 *s_type;
	const struct super_operations___167 *s_op;
	const struct dquot_operations___167 *dq_op;
	const struct quotactl_ops___167 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___167 *s_root;
	struct rw_semaphore___168 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___168 *s_bdev;
	struct backing_dev_info___83 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___167 s_dquot;
	struct sb_writers___167 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___167 *s_d_op;
	int cleancache_poolid;
	struct shrinker___75 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___147 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___25 {
	struct dentry___167 *mnt_root;
	struct super_block___167 *mnt_sb;
	int mnt_flags;
};

struct key___163;

struct ucounts___147;

struct user_namespace___147 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___147 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___4 ns;
	long unsigned int flags;
	struct key___163 *persistent_keyring_register;
	struct rw_semaphore___168 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___147 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct shrink_control___75 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___75 *memcg;
};

struct upid___132 {
	int nr;
	struct pid_namespace___132 *ns;
};

struct pid_namespace___132 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___168 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___132 *parent;
	struct vfsmount___25 *proc_mnt;
	struct dentry___167 *proc_self;
	struct dentry___167 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___147 *user_ns;
	struct ucounts___147 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___4 ns;
};

struct pid___132 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___132 numbers[1];
};

struct vm_operations_struct___165;

struct vm_area_struct___168 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___168 *vm_next;
	struct vm_area_struct___168 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___167 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___165 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___168 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct linux_binfmt___17;

struct core_state___167;

struct mm_struct___167 {
	struct {
		struct vm_area_struct___168 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___168 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___168 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___17 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___167 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___168 *owner;
		struct user_namespace___147 *user_ns;
		struct file___168 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___167 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___165)(struct vm_area_struct___168 *, long unsigned int, const struct page___168 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___165)(struct page___168 *, void *);

struct device___156;

struct dev_pagemap___165 {
	dev_page_fault_t___165 page_fault;
	dev_page_free_t___165 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___156 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct vm_fault___165;

struct vm_operations_struct___165 {
	void (*open)(struct vm_area_struct___168 *);
	void (*close)(struct vm_area_struct___168 *);
	int (*split)(struct vm_area_struct___168 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___168 *);
	vm_fault_t (*fault)(struct vm_fault___165 *);
	vm_fault_t (*huge_fault)(struct vm_fault___165 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___165 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___168 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___165 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___165 *);
	int (*access)(struct vm_area_struct___168 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___168 *);
	int (*set_policy)(struct vm_area_struct___168 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___168 *, long unsigned int);
	struct page___168 * (*find_special_page)(struct vm_area_struct___168 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___167 {
	struct task_struct___168 *task;
	struct core_thread___167 *next;
};

struct core_state___167 {
	atomic_t nr_threads;
	struct core_thread___167 dumper;
	struct completion startup;
};

struct linux_binprm___18;

struct coredump_params___17;

struct linux_binfmt___17 {
	struct list_head lh;
	struct module___142 *module;
	int (*load_binary)(struct linux_binprm___18 *);
	int (*load_shlib)(struct file___168 *);
	int (*core_dump)(struct coredump_params___17 *);
	long unsigned int min_coredump;
};

struct vm_fault___165 {
	struct vm_area_struct___168 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___168 *cow_page;
	struct mem_cgroup___75 *memcg;
	struct page___168 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___167 prealloc_pte;
};

struct user_struct___163 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___163 *uid_keyring;
	struct key___163 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___163 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___163 *session_keyring;
	struct key___163 *process_keyring;
	struct key___163 *thread_keyring;
	struct key___163 *request_key_auth;
	void *security;
	struct user_struct___163 *user;
	struct user_namespace___147 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct fs_struct___8 {
	int users;
	spinlock_t lock;
	seqcount_t seq;
	int umask;
	int in_exec;
	struct path___167 root;
	struct path___167 pwd;
};

struct fdtable___8 {
	unsigned int max_fds;
	struct file___168 **fd;
	long unsigned int *close_on_exec;
	long unsigned int *open_fds;
	long unsigned int *full_fds_bits;
	struct callback_head rcu;
};

struct files_struct___8 {
	atomic_t count;
	bool resize_in_progress;
	wait_queue_head_t resize_wait;
	struct fdtable___8 *fdt;
	struct fdtable___8 fdtab;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t file_lock;
	unsigned int next_fd;
	long unsigned int close_on_exec_init[1];
	long unsigned int open_fds_init[1];
	long unsigned int full_fds_bits_init[1];
	struct file___168 *fd_array[64];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct uts_namespace___21;

struct cgroup_namespace___143;

struct nsproxy___159 {
	atomic_t count;
	struct uts_namespace___21 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___132 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___143 *cgroup_ns;
};

struct signal_struct___148 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___168 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___168 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___132 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___132 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___167 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___132 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___83;

struct bio_list___83 {
	struct bio___83 *head;
	struct bio___83 *tail;
};

struct bdi_writeback_congested___83;

struct bdi_writeback___83 {
	struct backing_dev_info___83 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___83 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___143 *memcg_css;
	struct cgroup_subsys_state___143 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___83 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___83 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___156 *dev;
	struct device___156 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___167 *debug_dir;
	struct dentry___167 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___42;

struct io_context___42 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___42 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___143 {
	struct cgroup_subsys_state___143 *subsys[13];
	refcount_t refcount;
	struct css_set___143 *dom_cset;
	struct cgroup___143 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___143 *mg_src_cgrp;
	struct cgroup___143 *mg_dst_cgrp;
	struct css_set___143 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___102 {
	struct pmu___102 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___168 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___102 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___37;

struct pipe_inode_info___37 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___168 *tmp_page;
	struct fasync_struct___167 *fasync_readers;
	struct fasync_struct___167 *fasync_writers;
	struct pipe_buffer___37 *bufs;
	struct user_struct___163 *user;
};

typedef blk_qc_t make_request_fn___38(struct request_queue___39 *, struct bio___83 *);

struct request___39;

typedef int dma_drain_needed_fn___38(struct request___39 *);

struct kset___161;

struct kobj_type___161;

struct kobject___162 {
	const char *name;
	struct list_head entry;
	struct kobject___162 *parent;
	struct kset___161 *kset;
	struct kobj_type___161 *ktype;
	struct kernfs_node___164 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___38;

struct bsg_class_device___38 {
	struct device___156 *class_dev;
	int minor;
	struct request_queue___39 *queue;
	const struct bsg_ops___38 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___83 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___83 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___38;

struct blkcg_gq___29;

struct request_queue___39 {
	struct list_head queue_head;
	struct request___39 *last_merge;
	struct elevator_queue___38 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___38 *make_request_fn;
	dma_drain_needed_fn___38 *dma_drain_needed;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___83 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___162 kobj;
	struct kobject___162 *mq_kobj;
	struct blk_integrity integrity;
	struct device___156 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___29 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide40;
		union {		};
	};
	struct bsg_class_device___38 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___83 bio_split;
	struct dentry___167 *debugfs_dir;
	struct dentry___167 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___122 {
	struct vm_struct___122 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___168 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___149 {
	struct task_struct___168 task;
	long unsigned int stack[8192];
};

struct io_cq___42 {
	struct request_queue___39 *q;
	struct io_context___42 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___6 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___168 {
	struct file___168 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___168 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___167 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___168 *ia_file;
};

struct dquot___167 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___167 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___167 {
	int qf_fmt_id;
	const struct quota_format_ops___167 *qf_ops;
	struct module___142 *qf_owner;
	struct quota_format_type___167 *qf_next;
};

struct quota_format_ops___167 {
	int (*check_quota_file)(struct super_block___167 *, int);
	int (*read_file_info)(struct super_block___167 *, int);
	int (*write_file_info)(struct super_block___167 *, int);
	int (*free_file_info)(struct super_block___167 *, int);
	int (*read_dqblk)(struct dquot___167 *);
	int (*commit_dqblk)(struct dquot___167 *);
	int (*release_dqblk)(struct dquot___167 *);
	int (*get_next_id)(struct super_block___167 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___167 {
	int (*write_dquot)(struct dquot___167 *);
	struct dquot___167 * (*alloc_dquot)(struct super_block___167 *, int);
	void (*destroy_dquot)(struct dquot___167 *);
	int (*acquire_dquot)(struct dquot___167 *);
	int (*release_dquot)(struct dquot___167 *);
	int (*mark_dirty)(struct dquot___167 *);
	int (*write_info)(struct super_block___167 *, int);
	qsize_t * (*get_reserved_space)(struct inode___168 *);
	int (*get_projid)(struct inode___168 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___168 *, qsize_t *);
	int (*get_next_id)(struct super_block___167 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___167 {
	int (*quota_on)(struct super_block___167 *, int, int, const struct path___167 *);
	int (*quota_off)(struct super_block___167 *, int);
	int (*quota_enable)(struct super_block___167 *, unsigned int);
	int (*quota_disable)(struct super_block___167 *, unsigned int);
	int (*quota_sync)(struct super_block___167 *, int);
	int (*set_info)(struct super_block___167 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___167 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___167 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___167 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___167 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___167 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___139 {
	struct kobject___162 kobj;
	struct module___142 *mod;
	struct kobject___162 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___139 {
	struct module___142 *mod;
	struct latch_tree_node node;
};

struct module_layout___139 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___139 mtn;
};

struct module_attribute___139;

struct kernel_param___139;

struct module___142 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___139 mkobj;
	struct module_attribute___139 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___162 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___139 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___139 core_layout;
	struct module_layout___139 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___95 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___80;

struct swap_info_struct___56;

struct address_space_operations___167 {
	int (*writepage)(struct page___168 *, struct writeback_control___80 *);
	int (*readpage)(struct file___168 *, struct page___168 *);
	int (*writepages)(struct address_space___167 *, struct writeback_control___80 *);
	int (*set_page_dirty)(struct page___168 *);
	int (*readpages)(struct file___168 *, struct address_space___167 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___168 *, struct address_space___167 *, loff_t, unsigned int, unsigned int, struct page___168 **, void **);
	int (*write_end)(struct file___168 *, struct address_space___167 *, loff_t, unsigned int, unsigned int, struct page___168 *, void *);
	sector_t (*bmap)(struct address_space___167 *, sector_t);
	void (*invalidatepage)(struct page___168 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___168 *, gfp_t);
	void (*freepage)(struct page___168 *);
	ssize_t (*direct_IO)(struct kiocb___168 *, struct iov_iter___78 *);
	int (*migratepage)(struct address_space___167 *, struct page___168 *, struct page___168 *, enum migrate_mode);
	bool (*isolate_page)(struct page___168 *, isolate_mode_t);
	void (*putback_page)(struct page___168 *);
	int (*launder_page)(struct page___168 *);
	int (*is_partially_uptodate)(struct page___168 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___168 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___167 *, struct page___168 *);
	int (*swap_activate)(struct swap_info_struct___56 *, struct file___168 *, sector_t *);
	void (*swap_deactivate)(struct file___168 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___80 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___83 *wb;
	struct inode___168 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___83;

struct iov_iter___78 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___83 *bvec;
		struct pipe_inode_info___37 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct swap_info_struct___56 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___168 *bdev;
	struct file___168 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct hd_struct___39;

struct gendisk___39;

struct block_device___168 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___168 *bd_inode;
	struct super_block___167 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___168 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___39 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___39 *bd_disk;
	struct request_queue___39 *bd_queue;
	struct backing_dev_info___83 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___156 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___156 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___156;

struct bus_type___156;

struct device_driver___156;

struct dev_pm_domain___156;

struct fwnode_handle___111;

struct class___156;

struct attribute_group___157;

struct device___156 {
	struct device___156 *parent;
	struct device_private *p;
	struct kobject___162 kobj;
	const char *init_name;
	const struct device_type___156 *type;
	struct mutex mutex;
	struct bus_type___156 *bus;
	struct device_driver___156 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___156 power;
	struct dev_pm_domain___156 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___111 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___156 *class;
	const struct attribute_group___157 **groups;
	void (*release)(struct device___156 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___39 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___156 __dev;
	struct kobject___162 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___39;

struct block_device_operations___39;

struct gendisk___39 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___39 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___39 *part_tbl;
	struct hd_struct___39 part0;
	const struct block_device_operations___39 *fops;
	struct request_queue___39 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___168 lookup_sem;
	struct kobject___162 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___162 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___167 {
	struct dentry___167 * (*lookup)(struct inode___168 *, struct dentry___167 *, unsigned int);
	const char * (*get_link)(struct dentry___167 *, struct inode___168 *, struct delayed_call *);
	int (*permission)(struct inode___168 *, int);
	struct posix_acl * (*get_acl)(struct inode___168 *, int);
	int (*readlink)(struct dentry___167 *, char *, int);
	int (*create)(struct inode___168 *, struct dentry___167 *, umode_t, bool);
	int (*link)(struct dentry___167 *, struct inode___168 *, struct dentry___167 *);
	int (*unlink)(struct inode___168 *, struct dentry___167 *);
	int (*symlink)(struct inode___168 *, struct dentry___167 *, const char *);
	int (*mkdir)(struct inode___168 *, struct dentry___167 *, umode_t);
	int (*rmdir)(struct inode___168 *, struct dentry___167 *);
	int (*mknod)(struct inode___168 *, struct dentry___167 *, umode_t, dev_t);
	int (*rename)(struct inode___168 *, struct dentry___167 *, struct inode___168 *, struct dentry___167 *, unsigned int);
	int (*setattr)(struct dentry___167 *, struct iattr___167 *);
	int (*getattr)(const struct path___167 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___167 *, char *, size_t);
	int (*fiemap)(struct inode___168 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___168 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___168 *, struct dentry___167 *, struct file___168 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___168 *, struct dentry___167 *, umode_t);
	int (*set_acl)(struct inode___168 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___167 {
	void (*fl_copy_lock)(struct file_lock___168 *, struct file_lock___168 *);
	void (*fl_release_private)(struct file_lock___168 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___167;

struct file_lock___168 {
	struct file_lock___168 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___168 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___167 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___167 *fl_ops;
	const struct lock_manager_operations___167 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___167 {
	int (*lm_compare_owner)(struct file_lock___168 *, struct file_lock___168 *);
	long unsigned int (*lm_owner_key)(struct file_lock___168 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___168 *);
	int (*lm_grant)(struct file_lock___168 *, int);
	bool (*lm_break)(struct file_lock___168 *);
	int (*lm_change)(struct file_lock___168 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___168 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___167 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___167 *fa_next;
	struct file___168 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___167 {
	const char *name;
	int fs_flags;
	struct dentry___167 * (*mount)(struct file_system_type___167 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___167 *);
	struct module___142 *owner;
	struct file_system_type___167 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___167 {
	struct inode___168 * (*alloc_inode)(struct super_block___167 *);
	void (*destroy_inode)(struct inode___168 *);
	void (*dirty_inode)(struct inode___168 *, int);
	int (*write_inode)(struct inode___168 *, struct writeback_control___80 *);
	int (*drop_inode)(struct inode___168 *);
	void (*evict_inode)(struct inode___168 *);
	void (*put_super)(struct super_block___167 *);
	int (*sync_fs)(struct super_block___167 *, int);
	int (*freeze_super)(struct super_block___167 *);
	int (*freeze_fs)(struct super_block___167 *);
	int (*thaw_super)(struct super_block___167 *);
	int (*unfreeze_fs)(struct super_block___167 *);
	int (*statfs)(struct dentry___167 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___167 *, int *, char *);
	void (*umount_begin)(struct super_block___167 *);
	int (*show_options)(struct seq_file___158 *, struct dentry___167 *);
	int (*show_devname)(struct seq_file___158 *, struct dentry___167 *);
	int (*show_path)(struct seq_file___158 *, struct dentry___167 *);
	int (*show_stats)(struct seq_file___158 *, struct dentry___167 *);
	ssize_t (*quota_read)(struct super_block___167 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___167 *, int, const char *, size_t, loff_t);
	struct dquot___167 ** (*get_dquots)(struct inode___168 *);
	int (*bdev_try_to_free_page)(struct super_block___167 *, struct page___168 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___167 *, struct shrink_control___75 *);
	long int (*free_cached_objects)(struct super_block___167 *, struct shrink_control___75 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___111)(struct file___168 *, wait_queue_head_t *, struct poll_table_struct___112 *);

struct poll_table_struct___112 {
	poll_queue_proc___111 _qproc;
	__poll_t _key;
};

struct seq_operations___156;

struct seq_file___158 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___156 *op;
	int poll_event;
	const struct file___168 *file;
	void *private;
};

typedef void bio_end_io_t___83(struct bio___83 *);

struct bio_vec___83 {
	struct page___168 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___83;

struct bio___83 {
	struct bio___83 *bi_next;
	struct gendisk___39 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___83 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___29 *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___83 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___83 *bi_io_vec;
	struct bio_set___83 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___83 bi_inline_vecs[0];
};

struct kobj_attribute___162 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___162 *, struct kobj_attribute___162 *, char *);
	ssize_t (*store)(struct kobject___162 *, struct kobj_attribute___162 *, const char *, size_t);
};

typedef void compound_page_dtor___165(struct page___168 *);

typedef int (*key_restrict_link_func_t___163)(struct key___163 *, const struct key_type *, const union key_payload *, struct key___163 *);

struct key_restriction___163;

struct key___163 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___168 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___163 *restrict_link;
};

struct key_restriction___163 {
	key_restrict_link_func_t___163 check;
	struct key___163 *key;
	struct key_type *keytype;
};

struct seq_operations___156 {
	void * (*start)(struct seq_file___158 *, loff_t *);
	void (*stop)(struct seq_file___158 *, void *);
	void * (*next)(struct seq_file___158 *, void *, loff_t *);
	int (*show)(struct seq_file___158 *, void *);
};

struct kernfs_root___164;

struct kernfs_elem_dir___164 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___164 *root;
};

struct kernfs_syscall_ops___164;

struct kernfs_root___164 {
	struct kernfs_node___164 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___164 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___164 {
	struct kernfs_node___164 *target_kn;
};

struct kernfs_ops___164;

struct kernfs_elem_attr___164 {
	const struct kernfs_ops___164 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___164 *notify_next;
};

struct kernfs_node___164 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___164 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___164 dir;
		struct kernfs_elem_symlink___164 symlink;
		struct kernfs_elem_attr___164 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___164;

struct kernfs_ops___164 {
	int (*open)(struct kernfs_open_file___164 *);
	void (*release)(struct kernfs_open_file___164 *);
	int (*seq_show)(struct seq_file___158 *, void *);
	void * (*seq_start)(struct seq_file___158 *, loff_t *);
	void * (*seq_next)(struct seq_file___158 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___158 *, void *);
	ssize_t (*read)(struct kernfs_open_file___164 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___164 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___164 *, struct vm_area_struct___168 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___164 *, struct poll_table_struct___112 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___164 {
	int (*remount_fs)(struct kernfs_root___164 *, int *, char *);
	int (*show_options)(struct seq_file___158 *, struct kernfs_root___164 *);
	int (*mkdir)(struct kernfs_node___164 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___164 *);
	int (*rename)(struct kernfs_node___164 *, struct kernfs_node___164 *, const char *);
	int (*show_path)(struct seq_file___158 *, struct kernfs_node___164 *, struct kernfs_root___164 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___164 {
	struct kernfs_node___164 *kn;
	struct file___168 *file;
	struct seq_file___158 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___165 *vm_ops;
};

struct uts_namespace___21 {
	struct kref kref;
	struct new_utsname name;
	struct user_namespace___147 *user_ns;
	struct ucounts___147 *ucounts;
	struct ns_common___4 ns;
};

struct cgroup_namespace___143 {
	refcount_t count;
	struct ns_common___4 ns;
	struct user_namespace___147 *user_ns;
	struct ucounts___147 *ucounts;
	struct css_set___143 *root_cset;
};

struct ucounts___147 {
	struct hlist_node node;
	struct user_namespace___147 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___143;

struct bpf_map_ops___143 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___143 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___143 *, struct file___168 *);
	void (*map_free)(struct bpf_map___143 *);
	int (*map_get_next_key)(struct bpf_map___143 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___143 *);
	void * (*map_lookup_elem)(struct bpf_map___143 *, void *);
	int (*map_update_elem)(struct bpf_map___143 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___143 *, void *);
	int (*map_push_elem)(struct bpf_map___143 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___143 *, void *);
	int (*map_peek_elem)(struct bpf_map___143 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___143 *, struct file___168 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___143 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___143 *, void *, struct seq_file___158 *);
	int (*map_check_btf)(const struct bpf_map___143 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___143 {
	const struct bpf_map_ops___143 *ops;
	struct bpf_map___143 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___163 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___143;

typedef void (*kthread_work_func_t___143)(struct kthread_work___143 *);

struct kthread_worker___143;

struct kthread_work___143 {
	struct list_head node;
	kthread_work_func_t___143 func;
	struct kthread_worker___143 *worker;
	int canceling;
};

struct kthread_worker___143 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___168 *task;
	struct kthread_work___143 *current_work;
};

struct kthread_delayed_work___143 {
	struct kthread_work___143 work;
	struct timer_list timer;
};

struct psi_group___143 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___143 *poll_kworker;
	struct kthread_delayed_work___143 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___143;

struct cgroup_rstat_cpu___143;

struct cgroup___143 {
	struct cgroup_subsys_state___143 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___164 *kn;
	struct cgroup_file___143 procs_file;
	struct cgroup_file___143 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___143 *subsys[13];
	struct cgroup_root___143 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___143 *dom_cgrp;
	struct cgroup_rstat_cpu___143 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___20 bpf;
	atomic_t congestion_count;
	struct cgroup___143 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___143 psi;
	int ancestor_ids[0];
};

struct cftype___143;

struct cgroup_subsys___143 {
	struct cgroup_subsys_state___143 * (*css_alloc)(struct cgroup_subsys_state___143 *);
	int (*css_online)(struct cgroup_subsys_state___143 *);
	void (*css_offline)(struct cgroup_subsys_state___143 *);
	void (*css_released)(struct cgroup_subsys_state___143 *);
	void (*css_free)(struct cgroup_subsys_state___143 *);
	void (*css_reset)(struct cgroup_subsys_state___143 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___143 *, int);
	int (*css_extra_stat_show)(struct seq_file___158 *, struct cgroup_subsys_state___143 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___168 *);
	void (*cancel_fork)(struct task_struct___168 *);
	void (*fork)(struct task_struct___168 *);
	void (*exit)(struct task_struct___168 *);
	void (*free)(struct task_struct___168 *);
	void (*bind)(struct cgroup_subsys_state___143 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___143 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___143 *dfl_cftypes;
	struct cftype___143 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___143 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___143 *updated_children;
	struct cgroup___143 *updated_next;
};

struct cgroup_root___143 {
	struct kernfs_root___164 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___143 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___143 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___143 *ss;
	struct list_head node;
	struct kernfs_ops___164 *kf_ops;
	int (*open)(struct kernfs_open_file___164 *);
	void (*release)(struct kernfs_open_file___164 *);
	u64 (*read_u64)(struct cgroup_subsys_state___143 *, struct cftype___143 *);
	s64 (*read_s64)(struct cgroup_subsys_state___143 *, struct cftype___143 *);
	int (*seq_show)(struct seq_file___158 *, void *);
	void * (*seq_start)(struct seq_file___158 *, loff_t *);
	void * (*seq_next)(struct seq_file___158 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___158 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___143 *, struct cftype___143 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___143 *, struct cftype___143 *, s64);
	ssize_t (*write)(struct kernfs_open_file___164 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___164 *, struct poll_table_struct___112 *);
};

struct bdi_writeback_congested___83 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___83 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___83 {
	struct bio___83 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___83 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___83 bip_inline_vecs[0];
};

struct blkcg___29;

struct blkg_policy_data___29;

struct blkcg_gq___29 {
	struct request_queue___39 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___29 *blkcg;
	struct bdi_writeback_congested___83 *wb_congested;
	struct blkcg_gq___29 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_rwstat stat_bytes;
	struct blkg_rwstat stat_ios;
	struct blkg_policy_data___29 *pd[5];
	struct callback_head callback_head;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
};

struct mem_cgroup_reclaim_iter___75 {
	struct mem_cgroup___75 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___75 {
	struct lruvec___167 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___75 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___75 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct bin_attribute___156;

struct attribute_group___157 {
	const char *name;
	umode_t (*is_visible)(struct kobject___162 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___162 *, struct bin_attribute___156 *, int);
	struct attribute **attrs;
	struct bin_attribute___156 **bin_attrs;
};

struct bin_attribute___156 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___168 *, struct kobject___162 *, struct bin_attribute___156 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___168 *, struct kobject___162 *, struct bin_attribute___156 *, char *, loff_t, size_t);
	int (*mmap)(struct file___168 *, struct kobject___162 *, struct bin_attribute___156 *, struct vm_area_struct___168 *);
};

struct sysfs_ops___161 {
	ssize_t (*show)(struct kobject___162 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___162 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___161;

struct kset___161 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___162 kobj;
	const struct kset_uevent_ops___161 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___161 {
	void (*release)(struct kobject___162 *);
	const struct sysfs_ops___161 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___10 * (*child_ns_type)(struct kobject___162 *);
	const void * (*namespace)(struct kobject___162 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___161 {
	int (* const filter)(struct kset___161 *, struct kobject___162 *);
	const char * (* const name)(struct kset___161 *, struct kobject___162 *);
	int (* const uevent)(struct kset___161 *, struct kobject___162 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___156 {
	int (*prepare)(struct device___156 *);
	void (*complete)(struct device___156 *);
	int (*suspend)(struct device___156 *);
	int (*resume)(struct device___156 *);
	int (*freeze)(struct device___156 *);
	int (*thaw)(struct device___156 *);
	int (*poweroff)(struct device___156 *);
	int (*restore)(struct device___156 *);
	int (*suspend_late)(struct device___156 *);
	int (*resume_early)(struct device___156 *);
	int (*freeze_late)(struct device___156 *);
	int (*thaw_early)(struct device___156 *);
	int (*poweroff_late)(struct device___156 *);
	int (*restore_early)(struct device___156 *);
	int (*suspend_noirq)(struct device___156 *);
	int (*resume_noirq)(struct device___156 *);
	int (*freeze_noirq)(struct device___156 *);
	int (*thaw_noirq)(struct device___156 *);
	int (*poweroff_noirq)(struct device___156 *);
	int (*restore_noirq)(struct device___156 *);
	int (*runtime_suspend)(struct device___156 *);
	int (*runtime_resume)(struct device___156 *);
	int (*runtime_idle)(struct device___156 *);
};

struct dev_pm_domain___156 {
	struct dev_pm_ops___156 ops;
	void (*detach)(struct device___156 *, bool);
	int (*activate)(struct device___156 *);
	void (*sync)(struct device___156 *);
	void (*dismiss)(struct device___156 *);
};

struct bus_type___156 {
	const char *name;
	const char *dev_name;
	struct device___156 *dev_root;
	const struct attribute_group___157 **bus_groups;
	const struct attribute_group___157 **dev_groups;
	const struct attribute_group___157 **drv_groups;
	int (*match)(struct device___156 *, struct device_driver___156 *);
	int (*uevent)(struct device___156 *, struct kobj_uevent_env *);
	int (*probe)(struct device___156 *);
	int (*remove)(struct device___156 *);
	void (*shutdown)(struct device___156 *);
	int (*online)(struct device___156 *);
	int (*offline)(struct device___156 *);
	int (*suspend)(struct device___156 *, pm_message_t);
	int (*resume)(struct device___156 *);
	int (*num_vf)(struct device___156 *);
	int (*dma_configure)(struct device___156 *);
	const struct dev_pm_ops___156 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___156 {
	const char *name;
	struct bus_type___156 *bus;
	struct module___142 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___156 *);
	int (*remove)(struct device___156 *);
	void (*shutdown)(struct device___156 *);
	int (*suspend)(struct device___156 *, pm_message_t);
	int (*resume)(struct device___156 *);
	const struct attribute_group___157 **groups;
	const struct dev_pm_ops___156 *pm;
	void (*coredump)(struct device___156 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___156 {
	const char *name;
	const struct attribute_group___157 **groups;
	int (*uevent)(struct device___156 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___156 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___156 *);
	const struct dev_pm_ops___156 *pm;
};

struct class___156 {
	const char *name;
	struct module___142 *owner;
	const struct attribute_group___157 **class_groups;
	const struct attribute_group___157 **dev_groups;
	struct kobject___162 *dev_kobj;
	int (*dev_uevent)(struct device___156 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___156 *, umode_t *);
	void (*class_release)(struct class___156 *);
	void (*dev_release)(struct device___156 *);
	int (*shutdown_pre)(struct device___156 *);
	const struct kobj_ns_type_operations___10 *ns_type;
	const void * (*namespace)(struct device___156 *);
	const struct dev_pm_ops___156 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct fwnode_operations___111;

struct fwnode_handle___111 {
	struct fwnode_handle___111 *secondary;
	const struct fwnode_operations___111 *ops;
};

struct node___132 {
	struct device___156 dev;
};

struct kernel_param_ops___139 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___139 *);
	int (*get)(char *, const struct kernel_param___139 *);
	void (*free)(void *);
};

struct kparam_array___139;

struct kernel_param___139 {
	const char *name;
	struct module___142 *mod;
	const struct kernel_param_ops___139 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___139 *arr;
	};
};

struct kparam_array___139 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___139 *ops;
	void *elem;
};

struct module_attribute___139 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___139 *, struct module_kobject___139 *, char *);
	ssize_t (*store)(struct module_attribute___139 *, struct module_kobject___139 *, const char *, size_t);
	void (*setup)(struct module___142 *, const char *);
	int (*test)(struct module___142 *);
	void (*free)(struct module___142 *);
};

struct trace_event_class___95;

struct trace_event_call___95 {
	struct list_head list;
	struct trace_event_class___95 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___20 *prog_array;
	int (*perf_perm)(struct trace_event_call___95 *, struct perf_event___102 *);
};

struct perf_cpu_context___102;

struct pmu___102 {
	struct list_head entry;
	struct module___142 *module;
	struct device___156 *dev;
	const struct attribute_group___157 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___102 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___102 *);
	void (*pmu_disable)(struct pmu___102 *);
	int (*event_init)(struct perf_event___102 *);
	void (*event_mapped)(struct perf_event___102 *, struct mm_struct___167 *);
	void (*event_unmapped)(struct perf_event___102 *, struct mm_struct___167 *);
	int (*add)(struct perf_event___102 *, int);
	void (*del)(struct perf_event___102 *, int);
	void (*start)(struct perf_event___102 *, int);
	void (*stop)(struct perf_event___102 *, int);
	void (*read)(struct perf_event___102 *);
	void (*start_txn)(struct pmu___102 *, unsigned int);
	int (*commit_txn)(struct pmu___102 *);
	void (*cancel_txn)(struct pmu___102 *);
	int (*event_idx)(struct perf_event___102 *);
	void (*sched_task)(struct perf_event_context___102 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___102 *);
	int (*filter_match)(struct perf_event___102 *);
	int (*check_period)(struct perf_event___102 *, u64);
};

struct perf_cpu_context___102 {
	struct perf_event_context___102 ctx;
	struct perf_event_context___102 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___102 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___102 {
	struct cgroup_subsys_state___143 css;
	struct perf_cgroup_info *info;
};

struct linux_binprm___18 {
	char buf[256];
	struct vm_area_struct___168 *vma;
	long unsigned int vma_pages;
	struct mm_struct___167 *mm;
	long unsigned int p;
	unsigned int called_set_creds: 1;
	unsigned int cap_elevated: 1;
	unsigned int secureexec: 1;
	unsigned int recursion_depth;
	struct file___168 *file;
	struct cred___163 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
};

struct coredump_params___17 {
	union {
		const kernel_siginfo_t *siginfo;
		struct {
			const siginfo_t *siginfo;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	struct pt_regs *regs;
	struct file___168 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
};

struct trace_event_class___95 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___95 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___95 *);
	struct list_head * (*get_fields)(struct trace_event_call___95 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___95 *);
};

struct syscall_metadata___41 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___95 *enter_event;
	struct trace_event_call___95 *exit_event;
};

struct disk_part_tbl___39 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___39 *last_lookup;
	struct hd_struct___39 *part[0];
};

struct block_device_operations___39 {
	int (*open)(struct block_device___168 *, fmode_t);
	void (*release)(struct gendisk___39 *, fmode_t);
	int (*rw_page)(struct block_device___168 *, sector_t, struct page___168 *, unsigned int);
	int (*ioctl)(struct block_device___168 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___168 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___39 *, unsigned int);
	int (*media_changed)(struct gendisk___39 *);
	void (*unlock_native_capacity)(struct gendisk___39 *);
	int (*revalidate_disk)(struct gendisk___39 *);
	int (*getgeo)(struct block_device___168 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___168 *, long unsigned int);
	int (*report_zones)(struct gendisk___39 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___142 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___38 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___39 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___39 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___39 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___38(struct request___39 *, blk_status_t);

struct request___39 {
	struct request_queue___39 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___83 *bio;
	struct bio___83 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___83 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___42 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___38 *saved_end_io;
		} flush;
	};
	struct gendisk___39 *rq_disk;
	struct hd_struct___39 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___38 *end_io;
	void *end_io_data;
	struct request___39 *next_rq;
};

struct fwnode_reference_args___111;

struct fwnode_endpoint___111;

struct fwnode_operations___111 {
	struct fwnode_handle___111 * (*get)(struct fwnode_handle___111 *);
	void (*put)(struct fwnode_handle___111 *);
	bool (*device_is_available)(const struct fwnode_handle___111 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___111 *, const struct device___156 *);
	bool (*property_present)(const struct fwnode_handle___111 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___111 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___111 *, const char *, const char **, size_t);
	struct fwnode_handle___111 * (*get_parent)(const struct fwnode_handle___111 *);
	struct fwnode_handle___111 * (*get_next_child_node)(const struct fwnode_handle___111 *, struct fwnode_handle___111 *);
	struct fwnode_handle___111 * (*get_named_child_node)(const struct fwnode_handle___111 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___111 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___111 *);
	struct fwnode_handle___111 * (*graph_get_next_endpoint)(const struct fwnode_handle___111 *, struct fwnode_handle___111 *);
	struct fwnode_handle___111 * (*graph_get_remote_endpoint)(const struct fwnode_handle___111 *);
	struct fwnode_handle___111 * (*graph_get_port_parent)(struct fwnode_handle___111 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___111 *, struct fwnode_endpoint___111 *);
};

struct fwnode_endpoint___111 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___111 *local_fwnode;
};

struct fwnode_reference_args___111 {
	struct fwnode_handle___111 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct elevator_type___38;

struct elevator_mq_ops___38 {
	int (*init_sched)(struct request_queue___39 *, struct elevator_type___38 *);
	void (*exit_sched)(struct elevator_queue___38 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	bool (*allow_merge)(struct request_queue___39 *, struct request___39 *, struct bio___83 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx *, struct bio___83 *);
	int (*request_merge)(struct request_queue___39 *, struct request___39 **, struct bio___83 *);
	void (*request_merged)(struct request_queue___39 *, struct request___39 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___39 *, struct request___39 *, struct request___39 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___39 *, struct bio___83 *);
	void (*finish_request)(struct request___39 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___39 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___39 *, u64);
	void (*started_request)(struct request___39 *);
	void (*requeue_request)(struct request___39 *);
	struct request___39 * (*former_request)(struct request_queue___39 *, struct request___39 *);
	struct request___39 * (*next_request)(struct request_queue___39 *, struct request___39 *);
	void (*init_icq)(struct io_cq___42 *);
	void (*exit_icq)(struct io_cq___42 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide39;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___38;

struct elevator_type___38 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___38 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___38 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___142 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___38 {
	struct elevator_type___38 *type;
	void *elevator_data;
	struct kobject___162 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___38 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___38 *, char *);
	ssize_t (*store)(struct elevator_queue___38 *, const char *, size_t);
};

struct blkcg_policy_data___29;

struct blkcg___29 {
	struct cgroup_subsys_state___143 css;
	spinlock_t lock;
	struct xarray blkg_tree;
	struct blkcg_gq___29 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___29 *cpd[5];
	struct list_head all_blkcgs_node;
	struct list_head cgwb_list;
	refcount_t cgwb_refcnt;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct blkcg_policy_data___29 {
	struct blkcg___29 *blkcg;
	int plid;
};

struct blkg_policy_data___29 {
	struct blkcg_gq___29 *blkg;
	int plid;
};

struct pipe_buf_operations___37;

struct pipe_buffer___37 {
	struct page___168 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___37 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___37 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___37 *, struct pipe_buffer___37 *);
	void (*release)(struct pipe_inode_info___37 *, struct pipe_buffer___37 *);
	int (*steal)(struct pipe_inode_info___37 *, struct pipe_buffer___37 *);
	union {
		bool (*get)(struct pipe_inode_info___37 *, struct pipe_buffer___37 *);
		struct {
			void (*get)(struct pipe_inode_info___37 *, struct pipe_buffer___37 *);
		} __UNIQUE_ID_rh_kabi_hide51;
		union {		};
	};
};

struct mmu_gather_batch___7 {
	struct mmu_gather_batch___7 *next;
	unsigned int nr;
	unsigned int max;
	struct page___168 *pages[0];
};

struct mmu_gather___7 {
	struct mm_struct___167 *mm;
	struct mmu_table_batch *batch;
	long unsigned int start;
	long unsigned int end;
	unsigned int fullmm: 1;
	unsigned int need_flush_all: 1;
	struct mmu_gather_batch___7 *active;
	struct mmu_gather_batch___7 local;
	struct page___168 *__pages[8];
	unsigned int batch_count;
	int page_size;
};

struct user_arg_ptr {
	union {
		const char * const *native;
	} ptr;
};

struct module___143;

struct file___169;

struct kiocb___169;

struct iov_iter___79;

struct poll_table_struct___113;

struct vm_area_struct___169;

struct inode___169;

struct file_lock___169;

struct page___169;

struct pipe_inode_info___38;

struct seq_file___159;

struct file_operations___169 {
	struct module___143 *owner;
	loff_t (*llseek)(struct file___169 *, loff_t, int);
	ssize_t (*read)(struct file___169 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___169 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___169 *, struct iov_iter___79 *);
	ssize_t (*write_iter)(struct kiocb___169 *, struct iov_iter___79 *);
	int (*iopoll)(struct kiocb___169 *, bool);
	int (*iterate)(struct file___169 *, struct dir_context *);
	int (*iterate_shared)(struct file___169 *, struct dir_context *);
	__poll_t (*poll)(struct file___169 *, struct poll_table_struct___113 *);
	long int (*unlocked_ioctl)(struct file___169 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___169 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___169 *, struct vm_area_struct___169 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___169 *, struct file___169 *);
	int (*flush)(struct file___169 *, fl_owner_t);
	int (*release)(struct inode___169 *, struct file___169 *);
	int (*fsync)(struct file___169 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___169 *, int);
	int (*lock)(struct file___169 *, int, struct file_lock___169 *);
	ssize_t (*sendpage)(struct file___169 *, struct page___169 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___169 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___169 *, int, struct file_lock___169 *);
	ssize_t (*splice_write)(struct pipe_inode_info___38 *, struct file___169 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___169 *, loff_t *, struct pipe_inode_info___38 *, size_t, unsigned int);
	int (*setlease)(struct file___169 *, long int, struct file_lock___169 **, void **);
	long int (*fallocate)(struct file___169 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___159 *, struct file___169 *);
	ssize_t (*copy_file_range)(struct file___169 *, loff_t, struct file___169 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___169 *, loff_t, struct file___169 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___169 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___168 {
	u64 seqnum;
	struct vm_area_struct___169 *vmas[4];
};

struct page_frag___168 {
	struct page___169 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___103;

struct debug_info___103 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___103 *hbp_break[16];
	struct perf_event___103 *hbp_watch[16];
};

struct thread_struct___103 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___103 debug;
	long: 64;
};

struct mm_struct___168;

struct mem_cgroup___76;

struct pid___133;

struct cred___164;

struct nsproxy___160;

struct signal_struct___149;

struct bio_list___84;

struct backing_dev_info___84;

struct css_set___144;

struct perf_event_context___103;

struct task_struct___169 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___169 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___168 *mm;
	struct mm_struct___168 *active_mm;
	struct vmacache___168 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___169 *real_parent;
	struct task_struct___169 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___169 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___76 *active_memcg;
	long int rh_reserved2;
	struct pid___133 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___133 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___133 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___164 *ptracer_cred;
	const struct cred___164 *real_cred;
	const struct cred___164 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___160 *nsproxy;
	struct signal_struct___149 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___169 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___84 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___84 *backing_dev_info;
	struct io_context___42 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___144 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___103 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___38 *splice_pipe;
	struct page_frag___168 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___76 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___169 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___103 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___103 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___169 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___103)(struct perf_event___103 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___103;

struct fasync_struct___168;

struct pid_namespace___133;

struct trace_event_call___96;

struct perf_cgroup___103;

struct perf_event___103 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___103 *group_leader;
	struct pmu___103 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___103 hw;
	struct perf_event_context___103 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___103 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___169 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___168 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___103 *);
	struct callback_head callback_head;
	struct pid_namespace___133 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___103 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___103 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___96 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___103 *cgrp;
	struct list_head sb_list;
};

typedef struct page___169 *pgtable_t___168;

struct address_space___168;

struct dev_pagemap___166;

struct page___169 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___168 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___169 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___168 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___168 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___166 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___76 *mem_cgroup;
};

struct pglist_data___168;

struct lruvec___168 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___168 *pgdat;
};

struct zone___168 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___168 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___168 {
	struct zone___168 *zone;
	int zone_idx;
};

struct zonelist___168 {
	struct zoneref___168 _zonerefs[25];
};

struct pglist_data___168 {
	struct zone___168 node_zones[3];
	struct zonelist___168 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___169 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___169 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___168 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___169 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___169 *owner;
};

struct secondary_data___169 {
	void *stack;
	struct task_struct___169 *task;
	long int status;
};

struct blocking_notifier_head___168 {
	struct rw_semaphore___169 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___166;

struct vm_area_struct___169 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___169 *vm_next;
	struct vm_area_struct___169 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___168 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___166 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___169 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___168;

struct user_namespace___148;

struct mm_struct___168 {
	struct {
		struct vm_area_struct___169 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___169 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___169 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___168 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___169 *owner;
		struct user_namespace___148 *user_ns;
		struct file___169 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___168 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___168;

struct address_space___168 {
	struct inode___169 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___169 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___168 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___166)(struct vm_area_struct___169 *, long unsigned int, const struct page___169 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___166)(struct page___169 *, void *);

struct device___157;

struct dev_pagemap___166 {
	dev_page_fault_t___166 page_fault;
	dev_page_free_t___166 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___157 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct cgroup___144;

struct cgroup_subsys___144;

struct cgroup_subsys_state___144 {
	struct cgroup___144 *cgroup;
	struct cgroup_subsys___144 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___144 *parent;
};

struct kernfs_node___165;

struct cgroup_file___144 {
	struct kernfs_node___165 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___76;

struct mem_cgroup___76 {
	struct cgroup_subsys_state___144 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___144 events_file;
	struct cgroup_file___144 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___169 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___76 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct vfsmount___26;

struct dentry___168;

struct path___168 {
	struct vfsmount___26 *mnt;
	struct dentry___168 *dentry;
};

struct fown_struct___133 {
	rwlock_t lock;
	struct pid___133 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___169 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___168 f_path;
	struct inode___169 *f_inode;
	const struct file_operations___169 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___133 f_owner;
	const struct cred___164 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___168 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___166;

struct vm_operations_struct___166 {
	void (*open)(struct vm_area_struct___169 *);
	void (*close)(struct vm_area_struct___169 *);
	int (*split)(struct vm_area_struct___169 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___169 *);
	vm_fault_t (*fault)(struct vm_fault___166 *);
	vm_fault_t (*huge_fault)(struct vm_fault___166 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___166 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___169 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___166 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___166 *);
	int (*access)(struct vm_area_struct___169 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___169 *);
	int (*set_policy)(struct vm_area_struct___169 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___169 *, long unsigned int);
	struct page___169 * (*find_special_page)(struct vm_area_struct___169 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___168 {
	struct task_struct___169 *task;
	struct core_thread___168 *next;
};

struct core_state___168 {
	atomic_t nr_threads;
	struct core_thread___168 dumper;
	struct completion startup;
};

struct key___164;

struct ucounts___148;

struct user_namespace___148 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___148 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___4 ns;
	long unsigned int flags;
	struct key___164 *persistent_keyring_register;
	struct rw_semaphore___169 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___148 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___166 {
	struct vm_area_struct___169 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___169 *cow_page;
	struct mem_cgroup___76 *memcg;
	struct page___169 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___168 prealloc_pte;
};

struct shrink_control___76 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___76 *memcg;
};

struct shrinker___76 {
	long unsigned int (*count_objects)(struct shrinker___76 *, struct shrink_control___76 *);
	long unsigned int (*scan_objects)(struct shrinker___76 *, struct shrink_control___76 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct upid___133 {
	int nr;
	struct pid_namespace___133 *ns;
};

struct pid_namespace___133 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___169 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___133 *parent;
	struct vfsmount___26 *proc_mnt;
	struct dentry___168 *proc_self;
	struct dentry___168 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___148 *user_ns;
	struct ucounts___148 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___4 ns;
};

struct pid___133 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___133 numbers[1];
};

struct user_struct___164 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___164 *uid_keyring;
	struct key___164 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___164 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___164 *session_keyring;
	struct key___164 *process_keyring;
	struct key___164 *thread_keyring;
	struct key___164 *request_key_auth;
	void *security;
	struct user_struct___164 *user;
	struct user_namespace___148 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___144;

struct nsproxy___160 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___133 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___144 *cgroup_ns;
};

struct signal_struct___149 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___169 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___169 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___133 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___133 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___168 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___133 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___84;

struct bio_list___84 {
	struct bio___84 *head;
	struct bio___84 *tail;
};

struct bdi_writeback_congested___84;

struct bdi_writeback___84 {
	struct backing_dev_info___84 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___84 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___144 *memcg_css;
	struct cgroup_subsys_state___144 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___84 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___84 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___157 *dev;
	struct device___157 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___168 *debug_dir;
	struct dentry___168 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___144 {
	struct cgroup_subsys_state___144 *subsys[13];
	refcount_t refcount;
	struct css_set___144 *dom_cset;
	struct cgroup___144 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___144 *mg_src_cgrp;
	struct cgroup___144 *mg_dst_cgrp;
	struct css_set___144 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___103 {
	struct pmu___103 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___169 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___103 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___38;

struct pipe_inode_info___38 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___169 *tmp_page;
	struct fasync_struct___168 *fasync_readers;
	struct fasync_struct___168 *fasync_writers;
	struct pipe_buffer___38 *bufs;
	struct user_struct___164 *user;
};

union thread_union___150 {
	struct task_struct___169 task;
	long unsigned int stack[8192];
};

struct kset___162;

struct kobj_type___162;

struct kobject___163 {
	const char *name;
	struct list_head entry;
	struct kobject___163 *parent;
	struct kset___162 *kset;
	struct kobj_type___162 *ktype;
	struct kernfs_node___165 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___157 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___157 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___157;

struct bus_type___157;

struct device_driver___157;

struct dev_pm_domain___157;

struct class___157;

struct attribute_group___158;

struct device___157 {
	struct device___157 *parent;
	struct device_private *p;
	struct kobject___163 kobj;
	const char *init_name;
	const struct device_type___157 *type;
	struct mutex mutex;
	struct bus_type___157 *bus;
	struct device_driver___157 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___157 power;
	struct dev_pm_domain___157 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___157 *class;
	const struct attribute_group___158 **groups;
	void (*release)(struct device___157 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___168;

struct super_block___168;

struct dentry___168 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___168 *d_parent;
	struct qstr d_name;
	struct inode___169 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___168 *d_op;
	struct super_block___168 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___168;

struct block_device___169;

struct inode___169 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___168 *i_op;
	struct super_block___168 *i_sb;
	struct address_space___168 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___169 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___84 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___169 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___168 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___38 *i_pipe;
		struct block_device___169 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___168 {
	int (*d_revalidate)(struct dentry___168 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___168 *, unsigned int);
	int (*d_hash)(const struct dentry___168 *, struct qstr *);
	int (*d_compare)(const struct dentry___168 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___168 *);
	int (*d_init)(struct dentry___168 *);
	void (*d_release)(struct dentry___168 *);
	void (*d_prune)(struct dentry___168 *);
	void (*d_iput)(struct dentry___168 *, struct inode___169 *);
	char * (*d_dname)(struct dentry___168 *, char *, int);
	struct vfsmount___26 * (*d_automount)(struct path___168 *);
	int (*d_manage)(const struct path___168 *, bool);
	struct dentry___168 * (*d_real)(struct dentry___168 *, const struct inode___169 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___168;

struct mem_dqinfo___168 {
	struct quota_format_type___168 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___168;

struct quota_info___168 {
	unsigned int flags;
	struct rw_semaphore___169 dqio_sem;
	struct inode___169 *files[3];
	struct mem_dqinfo___168 info[3];
	const struct quota_format_ops___168 *ops[3];
};

struct rcuwait___168 {
	struct task_struct___169 *task;
};

struct percpu_rw_semaphore___168 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___169 rw_sem;
	struct rcuwait___168 writer;
	int readers_block;
};

struct sb_writers___168 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___168 rw_sem[3];
};

struct file_system_type___168;

struct super_operations___168;

struct dquot_operations___168;

struct quotactl_ops___168;

struct super_block___168 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___168 *s_type;
	const struct super_operations___168 *s_op;
	const struct dquot_operations___168 *dq_op;
	const struct quotactl_ops___168 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___168 *s_root;
	struct rw_semaphore___169 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___169 *s_bdev;
	struct backing_dev_info___84 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___168 s_dquot;
	struct sb_writers___168 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___168 *s_d_op;
	int cleancache_poolid;
	struct shrinker___76 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___148 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___26 {
	struct dentry___168 *mnt_root;
	struct super_block___168 *mnt_sb;
	int mnt_flags;
};

struct kiocb___169 {
	struct file___169 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___169 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___168 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___169 *ia_file;
};

struct dquot___168 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___168 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___168 {
	int qf_fmt_id;
	const struct quota_format_ops___168 *qf_ops;
	struct module___143 *qf_owner;
	struct quota_format_type___168 *qf_next;
};

struct quota_format_ops___168 {
	int (*check_quota_file)(struct super_block___168 *, int);
	int (*read_file_info)(struct super_block___168 *, int);
	int (*write_file_info)(struct super_block___168 *, int);
	int (*free_file_info)(struct super_block___168 *, int);
	int (*read_dqblk)(struct dquot___168 *);
	int (*commit_dqblk)(struct dquot___168 *);
	int (*release_dqblk)(struct dquot___168 *);
	int (*get_next_id)(struct super_block___168 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___168 {
	int (*write_dquot)(struct dquot___168 *);
	struct dquot___168 * (*alloc_dquot)(struct super_block___168 *, int);
	void (*destroy_dquot)(struct dquot___168 *);
	int (*acquire_dquot)(struct dquot___168 *);
	int (*release_dquot)(struct dquot___168 *);
	int (*mark_dirty)(struct dquot___168 *);
	int (*write_info)(struct super_block___168 *, int);
	qsize_t * (*get_reserved_space)(struct inode___169 *);
	int (*get_projid)(struct inode___169 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___169 *, qsize_t *);
	int (*get_next_id)(struct super_block___168 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___168 {
	int (*quota_on)(struct super_block___168 *, int, int, const struct path___168 *);
	int (*quota_off)(struct super_block___168 *, int);
	int (*quota_enable)(struct super_block___168 *, unsigned int);
	int (*quota_disable)(struct super_block___168 *, unsigned int);
	int (*quota_sync)(struct super_block___168 *, int);
	int (*set_info)(struct super_block___168 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___168 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___168 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___168 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___168 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___168 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___140 {
	struct kobject___163 kobj;
	struct module___143 *mod;
	struct kobject___163 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___140 {
	struct module___143 *mod;
	struct latch_tree_node node;
};

struct module_layout___140 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___140 mtn;
};

struct module_attribute___140;

struct kernel_param___140;

struct module___143 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___140 mkobj;
	struct module_attribute___140 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___163 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___140 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___140 core_layout;
	struct module_layout___140 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___96 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___81;

struct address_space_operations___168 {
	int (*writepage)(struct page___169 *, struct writeback_control___81 *);
	int (*readpage)(struct file___169 *, struct page___169 *);
	int (*writepages)(struct address_space___168 *, struct writeback_control___81 *);
	int (*set_page_dirty)(struct page___169 *);
	int (*readpages)(struct file___169 *, struct address_space___168 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___169 *, struct address_space___168 *, loff_t, unsigned int, unsigned int, struct page___169 **, void **);
	int (*write_end)(struct file___169 *, struct address_space___168 *, loff_t, unsigned int, unsigned int, struct page___169 *, void *);
	sector_t (*bmap)(struct address_space___168 *, sector_t);
	void (*invalidatepage)(struct page___169 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___169 *, gfp_t);
	void (*freepage)(struct page___169 *);
	ssize_t (*direct_IO)(struct kiocb___169 *, struct iov_iter___79 *);
	int (*migratepage)(struct address_space___168 *, struct page___169 *, struct page___169 *, enum migrate_mode);
	bool (*isolate_page)(struct page___169 *, isolate_mode_t);
	void (*putback_page)(struct page___169 *);
	int (*launder_page)(struct page___169 *);
	int (*is_partially_uptodate)(struct page___169 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___169 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___168 *, struct page___169 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___169 *, sector_t *);
	void (*swap_deactivate)(struct file___169 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___81 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___84 *wb;
	struct inode___169 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___84;

struct iov_iter___79 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___84 *bvec;
		struct pipe_inode_info___38 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___169 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___169 *bd_inode;
	struct super_block___168 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___169 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___84 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___168 {
	struct dentry___168 * (*lookup)(struct inode___169 *, struct dentry___168 *, unsigned int);
	const char * (*get_link)(struct dentry___168 *, struct inode___169 *, struct delayed_call *);
	int (*permission)(struct inode___169 *, int);
	struct posix_acl * (*get_acl)(struct inode___169 *, int);
	int (*readlink)(struct dentry___168 *, char *, int);
	int (*create)(struct inode___169 *, struct dentry___168 *, umode_t, bool);
	int (*link)(struct dentry___168 *, struct inode___169 *, struct dentry___168 *);
	int (*unlink)(struct inode___169 *, struct dentry___168 *);
	int (*symlink)(struct inode___169 *, struct dentry___168 *, const char *);
	int (*mkdir)(struct inode___169 *, struct dentry___168 *, umode_t);
	int (*rmdir)(struct inode___169 *, struct dentry___168 *);
	int (*mknod)(struct inode___169 *, struct dentry___168 *, umode_t, dev_t);
	int (*rename)(struct inode___169 *, struct dentry___168 *, struct inode___169 *, struct dentry___168 *, unsigned int);
	int (*setattr)(struct dentry___168 *, struct iattr___168 *);
	int (*getattr)(const struct path___168 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___168 *, char *, size_t);
	int (*fiemap)(struct inode___169 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___169 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___169 *, struct dentry___168 *, struct file___169 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___169 *, struct dentry___168 *, umode_t);
	int (*set_acl)(struct inode___169 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

enum inode_i_mutex_lock_class {
	I_MUTEX_NORMAL = 0,
	I_MUTEX_PARENT = 1,
	I_MUTEX_CHILD = 2,
	I_MUTEX_XATTR = 3,
	I_MUTEX_NONDIR2 = 4,
	I_MUTEX_PARENT2 = 5,
};

struct file_lock_operations___168 {
	void (*fl_copy_lock)(struct file_lock___169 *, struct file_lock___169 *);
	void (*fl_release_private)(struct file_lock___169 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___168;

struct file_lock___169 {
	struct file_lock___169 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___169 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___168 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___168 *fl_ops;
	const struct lock_manager_operations___168 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___168 {
	int (*lm_compare_owner)(struct file_lock___169 *, struct file_lock___169 *);
	long unsigned int (*lm_owner_key)(struct file_lock___169 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___169 *);
	int (*lm_grant)(struct file_lock___169 *, int);
	bool (*lm_break)(struct file_lock___169 *);
	int (*lm_change)(struct file_lock___169 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___169 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___168 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___168 *fa_next;
	struct file___169 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___168 {
	const char *name;
	int fs_flags;
	struct dentry___168 * (*mount)(struct file_system_type___168 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___168 *);
	struct module___143 *owner;
	struct file_system_type___168 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___168 {
	struct inode___169 * (*alloc_inode)(struct super_block___168 *);
	void (*destroy_inode)(struct inode___169 *);
	void (*dirty_inode)(struct inode___169 *, int);
	int (*write_inode)(struct inode___169 *, struct writeback_control___81 *);
	int (*drop_inode)(struct inode___169 *);
	void (*evict_inode)(struct inode___169 *);
	void (*put_super)(struct super_block___168 *);
	int (*sync_fs)(struct super_block___168 *, int);
	int (*freeze_super)(struct super_block___168 *);
	int (*freeze_fs)(struct super_block___168 *);
	int (*thaw_super)(struct super_block___168 *);
	int (*unfreeze_fs)(struct super_block___168 *);
	int (*statfs)(struct dentry___168 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___168 *, int *, char *);
	void (*umount_begin)(struct super_block___168 *);
	int (*show_options)(struct seq_file___159 *, struct dentry___168 *);
	int (*show_devname)(struct seq_file___159 *, struct dentry___168 *);
	int (*show_path)(struct seq_file___159 *, struct dentry___168 *);
	int (*show_stats)(struct seq_file___159 *, struct dentry___168 *);
	ssize_t (*quota_read)(struct super_block___168 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___168 *, int, const char *, size_t, loff_t);
	struct dquot___168 ** (*get_dquots)(struct inode___169 *);
	int (*bdev_try_to_free_page)(struct super_block___168 *, struct page___169 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___168 *, struct shrink_control___76 *);
	long int (*free_cached_objects)(struct super_block___168 *, struct shrink_control___76 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___112)(struct file___169 *, wait_queue_head_t *, struct poll_table_struct___113 *);

struct poll_table_struct___113 {
	poll_queue_proc___112 _qproc;
	__poll_t _key;
};

struct seq_operations___157;

struct seq_file___159 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___157 *op;
	int poll_event;
	const struct file___169 *file;
	void *private;
};

typedef void bio_end_io_t___84(struct bio___84 *);

struct bio_vec___84 {
	struct page___169 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___84;

struct bio_set___84;

struct bio___84 {
	struct bio___84 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___84 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___84 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___84 *bi_io_vec;
	struct bio_set___84 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___84 bi_inline_vecs[0];
};

struct kobj_attribute___163 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___163 *, struct kobj_attribute___163 *, char *);
	ssize_t (*store)(struct kobject___163 *, struct kobj_attribute___163 *, const char *, size_t);
};

typedef void compound_page_dtor___166(struct page___169 *);

typedef struct poll_table_struct___113 poll_table___12;

struct kernfs_root___165;

struct kernfs_elem_dir___165 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___165 *root;
};

struct kernfs_syscall_ops___165;

struct kernfs_root___165 {
	struct kernfs_node___165 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___165 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___165 {
	struct kernfs_node___165 *target_kn;
};

struct kernfs_ops___165;

struct kernfs_elem_attr___165 {
	const struct kernfs_ops___165 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___165 *notify_next;
};

struct kernfs_node___165 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___165 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___165 dir;
		struct kernfs_elem_symlink___165 symlink;
		struct kernfs_elem_attr___165 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___165;

struct kernfs_ops___165 {
	int (*open)(struct kernfs_open_file___165 *);
	void (*release)(struct kernfs_open_file___165 *);
	int (*seq_show)(struct seq_file___159 *, void *);
	void * (*seq_start)(struct seq_file___159 *, loff_t *);
	void * (*seq_next)(struct seq_file___159 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___159 *, void *);
	ssize_t (*read)(struct kernfs_open_file___165 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___165 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___165 *, struct vm_area_struct___169 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___165 *, struct poll_table_struct___113 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___165 {
	int (*remount_fs)(struct kernfs_root___165 *, int *, char *);
	int (*show_options)(struct seq_file___159 *, struct kernfs_root___165 *);
	int (*mkdir)(struct kernfs_node___165 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___165 *);
	int (*rename)(struct kernfs_node___165 *, struct kernfs_node___165 *, const char *);
	int (*show_path)(struct seq_file___159 *, struct kernfs_node___165 *, struct kernfs_root___165 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___165 {
	struct kernfs_node___165 *kn;
	struct file___169 *file;
	struct seq_file___159 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___166 *vm_ops;
};

struct bin_attribute___157;

struct attribute_group___158 {
	const char *name;
	umode_t (*is_visible)(struct kobject___163 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___163 *, struct bin_attribute___157 *, int);
	struct attribute **attrs;
	struct bin_attribute___157 **bin_attrs;
};

struct bin_attribute___157 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___169 *, struct kobject___163 *, struct bin_attribute___157 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___169 *, struct kobject___163 *, struct bin_attribute___157 *, char *, loff_t, size_t);
	int (*mmap)(struct file___169 *, struct kobject___163 *, struct bin_attribute___157 *, struct vm_area_struct___169 *);
};

struct sysfs_ops___162 {
	ssize_t (*show)(struct kobject___163 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___163 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___162;

struct kset___162 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___163 kobj;
	const struct kset_uevent_ops___162 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___162 {
	void (*release)(struct kobject___163 *);
	const struct sysfs_ops___162 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___10 * (*child_ns_type)(struct kobject___163 *);
	const void * (*namespace)(struct kobject___163 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___162 {
	int (* const filter)(struct kset___162 *, struct kobject___163 *);
	const char * (* const name)(struct kset___162 *, struct kobject___163 *);
	int (* const uevent)(struct kset___162 *, struct kobject___163 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___140 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___140 *);
	int (*get)(char *, const struct kernel_param___140 *);
	void (*free)(void *);
};

struct kparam_array___140;

struct kernel_param___140 {
	const char *name;
	struct module___143 *mod;
	const struct kernel_param_ops___140 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___140 *arr;
	};
};

struct kparam_array___140 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___140 *ops;
	void *elem;
};

struct module_attribute___140 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___140 *, struct module_kobject___140 *, char *);
	ssize_t (*store)(struct module_attribute___140 *, struct module_kobject___140 *, const char *, size_t);
	void (*setup)(struct module___143 *, const char *);
	int (*test)(struct module___143 *);
	void (*free)(struct module___143 *);
};

struct trace_event_class___96;

struct trace_event_call___96 {
	struct list_head list;
	struct trace_event_class___96 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___20 *prog_array;
	int (*perf_perm)(struct trace_event_call___96 *, struct perf_event___103 *);
};

struct pipe_buf_operations___38;

struct pipe_buffer___38 {
	struct page___169 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___38 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___38 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___38 *, struct pipe_buffer___38 *);
	void (*release)(struct pipe_inode_info___38 *, struct pipe_buffer___38 *);
	int (*steal)(struct pipe_inode_info___38 *, struct pipe_buffer___38 *);
	union {
		bool (*get)(struct pipe_inode_info___38 *, struct pipe_buffer___38 *);
		struct {
			void (*get)(struct pipe_inode_info___38 *, struct pipe_buffer___38 *);
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
};

typedef int (*key_restrict_link_func_t___164)(struct key___164 *, const struct key_type *, const union key_payload *, struct key___164 *);

struct key_restriction___164;

struct key___164 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___169 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___164 *restrict_link;
};

struct key_restriction___164 {
	key_restrict_link_func_t___164 check;
	struct key___164 *key;
	struct key_type *keytype;
};

struct cgroup_namespace___144 {
	refcount_t count;
	struct ns_common___4 ns;
	struct user_namespace___148 *user_ns;
	struct ucounts___148 *ucounts;
	struct css_set___144 *root_cset;
};

struct ucounts___148 {
	struct hlist_node node;
	struct user_namespace___148 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct seq_operations___157 {
	void * (*start)(struct seq_file___159 *, loff_t *);
	void (*stop)(struct seq_file___159 *, void *);
	void * (*next)(struct seq_file___159 *, void *, loff_t *);
	int (*show)(struct seq_file___159 *, void *);
};

struct dev_pm_ops___157 {
	int (*prepare)(struct device___157 *);
	void (*complete)(struct device___157 *);
	int (*suspend)(struct device___157 *);
	int (*resume)(struct device___157 *);
	int (*freeze)(struct device___157 *);
	int (*thaw)(struct device___157 *);
	int (*poweroff)(struct device___157 *);
	int (*restore)(struct device___157 *);
	int (*suspend_late)(struct device___157 *);
	int (*resume_early)(struct device___157 *);
	int (*freeze_late)(struct device___157 *);
	int (*thaw_early)(struct device___157 *);
	int (*poweroff_late)(struct device___157 *);
	int (*restore_early)(struct device___157 *);
	int (*suspend_noirq)(struct device___157 *);
	int (*resume_noirq)(struct device___157 *);
	int (*freeze_noirq)(struct device___157 *);
	int (*thaw_noirq)(struct device___157 *);
	int (*poweroff_noirq)(struct device___157 *);
	int (*restore_noirq)(struct device___157 *);
	int (*runtime_suspend)(struct device___157 *);
	int (*runtime_resume)(struct device___157 *);
	int (*runtime_idle)(struct device___157 *);
};

struct dev_pm_domain___157 {
	struct dev_pm_ops___157 ops;
	void (*detach)(struct device___157 *, bool);
	int (*activate)(struct device___157 *);
	void (*sync)(struct device___157 *);
	void (*dismiss)(struct device___157 *);
};

struct bus_type___157 {
	const char *name;
	const char *dev_name;
	struct device___157 *dev_root;
	const struct attribute_group___158 **bus_groups;
	const struct attribute_group___158 **dev_groups;
	const struct attribute_group___158 **drv_groups;
	int (*match)(struct device___157 *, struct device_driver___157 *);
	int (*uevent)(struct device___157 *, struct kobj_uevent_env *);
	int (*probe)(struct device___157 *);
	int (*remove)(struct device___157 *);
	void (*shutdown)(struct device___157 *);
	int (*online)(struct device___157 *);
	int (*offline)(struct device___157 *);
	int (*suspend)(struct device___157 *, pm_message_t);
	int (*resume)(struct device___157 *);
	int (*num_vf)(struct device___157 *);
	int (*dma_configure)(struct device___157 *);
	const struct dev_pm_ops___157 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___157 {
	const char *name;
	struct bus_type___157 *bus;
	struct module___143 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___157 *);
	int (*remove)(struct device___157 *);
	void (*shutdown)(struct device___157 *);
	int (*suspend)(struct device___157 *, pm_message_t);
	int (*resume)(struct device___157 *);
	const struct attribute_group___158 **groups;
	const struct dev_pm_ops___157 *pm;
	void (*coredump)(struct device___157 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___157 {
	const char *name;
	const struct attribute_group___158 **groups;
	int (*uevent)(struct device___157 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___157 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___157 *);
	const struct dev_pm_ops___157 *pm;
};

struct class___157 {
	const char *name;
	struct module___143 *owner;
	const struct attribute_group___158 **class_groups;
	const struct attribute_group___158 **dev_groups;
	struct kobject___163 *dev_kobj;
	int (*dev_uevent)(struct device___157 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___157 *, umode_t *);
	void (*class_release)(struct class___157 *);
	void (*dev_release)(struct device___157 *);
	int (*shutdown_pre)(struct device___157 *);
	const struct kobj_ns_type_operations___10 *ns_type;
	const void * (*namespace)(struct device___157 *);
	const struct dev_pm_ops___157 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___133 {
	struct device___157 dev;
};

struct bpf_map___144;

struct bpf_map_ops___144 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___144 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___144 *, struct file___169 *);
	void (*map_free)(struct bpf_map___144 *);
	int (*map_get_next_key)(struct bpf_map___144 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___144 *);
	void * (*map_lookup_elem)(struct bpf_map___144 *, void *);
	int (*map_update_elem)(struct bpf_map___144 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___144 *, void *);
	int (*map_push_elem)(struct bpf_map___144 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___144 *, void *);
	int (*map_peek_elem)(struct bpf_map___144 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___144 *, struct file___169 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___144 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___144 *, void *, struct seq_file___159 *);
	int (*map_check_btf)(const struct bpf_map___144 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___144 {
	const struct bpf_map_ops___144 *ops;
	struct bpf_map___144 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___164 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___144;

typedef void (*kthread_work_func_t___144)(struct kthread_work___144 *);

struct kthread_worker___144;

struct kthread_work___144 {
	struct list_head node;
	kthread_work_func_t___144 func;
	struct kthread_worker___144 *worker;
	int canceling;
};

struct kthread_worker___144 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___169 *task;
	struct kthread_work___144 *current_work;
};

struct kthread_delayed_work___144 {
	struct kthread_work___144 work;
	struct timer_list timer;
};

struct psi_group___144 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___144 *poll_kworker;
	struct kthread_delayed_work___144 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___144;

struct cgroup_rstat_cpu___144;

struct cgroup___144 {
	struct cgroup_subsys_state___144 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___165 *kn;
	struct cgroup_file___144 procs_file;
	struct cgroup_file___144 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___144 *subsys[13];
	struct cgroup_root___144 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___144 *dom_cgrp;
	struct cgroup_rstat_cpu___144 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___20 bpf;
	atomic_t congestion_count;
	struct cgroup___144 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___144 psi;
	int ancestor_ids[0];
};

struct cftype___144;

struct cgroup_subsys___144 {
	struct cgroup_subsys_state___144 * (*css_alloc)(struct cgroup_subsys_state___144 *);
	int (*css_online)(struct cgroup_subsys_state___144 *);
	void (*css_offline)(struct cgroup_subsys_state___144 *);
	void (*css_released)(struct cgroup_subsys_state___144 *);
	void (*css_free)(struct cgroup_subsys_state___144 *);
	void (*css_reset)(struct cgroup_subsys_state___144 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___144 *, int);
	int (*css_extra_stat_show)(struct seq_file___159 *, struct cgroup_subsys_state___144 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___169 *);
	void (*cancel_fork)(struct task_struct___169 *);
	void (*fork)(struct task_struct___169 *);
	void (*exit)(struct task_struct___169 *);
	void (*free)(struct task_struct___169 *);
	void (*bind)(struct cgroup_subsys_state___144 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___144 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___144 *dfl_cftypes;
	struct cftype___144 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___144 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___144 *updated_children;
	struct cgroup___144 *updated_next;
};

struct cgroup_root___144 {
	struct kernfs_root___165 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___144 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___144 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___144 *ss;
	struct list_head node;
	struct kernfs_ops___165 *kf_ops;
	int (*open)(struct kernfs_open_file___165 *);
	void (*release)(struct kernfs_open_file___165 *);
	u64 (*read_u64)(struct cgroup_subsys_state___144 *, struct cftype___144 *);
	s64 (*read_s64)(struct cgroup_subsys_state___144 *, struct cftype___144 *);
	int (*seq_show)(struct seq_file___159 *, void *);
	void * (*seq_start)(struct seq_file___159 *, loff_t *);
	void * (*seq_next)(struct seq_file___159 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___159 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___144 *, struct cftype___144 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___144 *, struct cftype___144 *, s64);
	ssize_t (*write)(struct kernfs_open_file___165 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___165 *, struct poll_table_struct___113 *);
};

struct perf_cpu_context___103;

struct pmu___103 {
	struct list_head entry;
	struct module___143 *module;
	struct device___157 *dev;
	const struct attribute_group___158 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___103 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___103 *);
	void (*pmu_disable)(struct pmu___103 *);
	int (*event_init)(struct perf_event___103 *);
	void (*event_mapped)(struct perf_event___103 *, struct mm_struct___168 *);
	void (*event_unmapped)(struct perf_event___103 *, struct mm_struct___168 *);
	int (*add)(struct perf_event___103 *, int);
	void (*del)(struct perf_event___103 *, int);
	void (*start)(struct perf_event___103 *, int);
	void (*stop)(struct perf_event___103 *, int);
	void (*read)(struct perf_event___103 *);
	void (*start_txn)(struct pmu___103 *, unsigned int);
	int (*commit_txn)(struct pmu___103 *);
	void (*cancel_txn)(struct pmu___103 *);
	int (*event_idx)(struct perf_event___103 *);
	void (*sched_task)(struct perf_event_context___103 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___103 *);
	int (*filter_match)(struct perf_event___103 *);
	int (*check_period)(struct perf_event___103 *, u64);
};

struct perf_cpu_context___103 {
	struct perf_event_context___103 ctx;
	struct perf_event_context___103 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___103 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___103 {
	struct cgroup_subsys_state___144 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___96 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___96 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___96 *);
	struct list_head * (*get_fields)(struct trace_event_call___96 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___96 *);
};

struct syscall_metadata___42 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___96 *enter_event;
	struct trace_event_call___96 *exit_event;
};

struct bdi_writeback_congested___84 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___84 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___84 {
	struct bio___84 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___84 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___84 bip_inline_vecs[0];
};

struct bio_set___84 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___84 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___76 {
	struct mem_cgroup___76 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___76 {
	struct lruvec___168 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___76 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___76 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct module___144;

struct file___170;

struct kiocb___170;

struct iov_iter___80;

struct poll_table_struct___114;

struct vm_area_struct___170;

struct inode___170;

struct file_lock___170;

struct page___170;

struct pipe_inode_info___39;

struct seq_file___160;

struct file_operations___170 {
	struct module___144 *owner;
	loff_t (*llseek)(struct file___170 *, loff_t, int);
	ssize_t (*read)(struct file___170 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___170 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___170 *, struct iov_iter___80 *);
	ssize_t (*write_iter)(struct kiocb___170 *, struct iov_iter___80 *);
	int (*iopoll)(struct kiocb___170 *, bool);
	int (*iterate)(struct file___170 *, struct dir_context *);
	int (*iterate_shared)(struct file___170 *, struct dir_context *);
	__poll_t (*poll)(struct file___170 *, struct poll_table_struct___114 *);
	long int (*unlocked_ioctl)(struct file___170 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___170 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___170 *, struct vm_area_struct___170 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___170 *, struct file___170 *);
	int (*flush)(struct file___170 *, fl_owner_t);
	int (*release)(struct inode___170 *, struct file___170 *);
	int (*fsync)(struct file___170 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___170 *, int);
	int (*lock)(struct file___170 *, int, struct file_lock___170 *);
	ssize_t (*sendpage)(struct file___170 *, struct page___170 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___170 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___170 *, int, struct file_lock___170 *);
	ssize_t (*splice_write)(struct pipe_inode_info___39 *, struct file___170 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___170 *, loff_t *, struct pipe_inode_info___39 *, size_t, unsigned int);
	int (*setlease)(struct file___170 *, long int, struct file_lock___170 **, void **);
	long int (*fallocate)(struct file___170 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___160 *, struct file___170 *);
	ssize_t (*copy_file_range)(struct file___170 *, loff_t, struct file___170 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___170 *, loff_t, struct file___170 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___170 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___169 {
	u64 seqnum;
	struct vm_area_struct___170 *vmas[4];
};

struct page_frag___169 {
	struct page___170 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___104;

struct debug_info___104 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___104 *hbp_break[16];
	struct perf_event___104 *hbp_watch[16];
};

struct thread_struct___104 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___104 debug;
	long: 64;
};

struct mm_struct___169;

struct pid___134;

struct cred___165;

struct nameidata___2;

struct fs_struct___9;

struct nsproxy___161;

struct signal_struct___150;

struct css_set___145;

struct perf_event_context___104;

struct vm_struct___123;

struct task_struct___170 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___170 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___169 *mm;
	struct mm_struct___169 *active_mm;
	struct vmacache___169 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___170 *real_parent;
	struct task_struct___170 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___170 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___134 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___134 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___134 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___165 *ptracer_cred;
	const struct cred___165 *real_cred;
	const struct cred___165 *cred;
	char comm[16];
	struct nameidata___2 *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct___9 *fs;
	struct files_struct *files;
	struct nsproxy___161 *nsproxy;
	struct signal_struct___150 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___170 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___42 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___145 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___104 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___39 *splice_pipe;
	struct page_frag___169 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___170 *oom_reaper_list;
	struct vm_struct___123 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___104 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___104 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___170 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___104)(struct perf_event___104 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___104;

struct fasync_struct___169;

struct pid_namespace___134;

struct trace_event_call___97;

struct perf_cgroup___104;

struct perf_event___104 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___104 *group_leader;
	struct pmu___104 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___104 hw;
	struct perf_event_context___104 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___104 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___170 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___169 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___104 *);
	struct callback_head callback_head;
	struct pid_namespace___134 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___104 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___104 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___97 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___104 *cgrp;
	struct list_head sb_list;
};

typedef struct page___170 *pgtable_t___169;

struct address_space___169;

struct dev_pagemap___167;

struct page___170 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___169 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___170 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___169 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___169 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___167 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___169;

struct lruvec___169 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___169 *pgdat;
};

struct zone___169 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___169 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___169 {
	struct zone___169 *zone;
	int zone_idx;
};

struct zonelist___169 {
	struct zoneref___169 _zonerefs[25];
};

struct pglist_data___169 {
	struct zone___169 node_zones[3];
	struct zonelist___169 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___170 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___170 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___169 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___170 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___170 *owner;
};

struct secondary_data___170 {
	void *stack;
	struct task_struct___170 *task;
	long int status;
};

struct blocking_notifier_head___169 {
	struct rw_semaphore___170 rwsem;
	struct notifier_block *head;
};

struct dentry_operations___169;

struct super_block___169;

struct dentry___169 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___169 *d_parent;
	struct qstr d_name;
	struct inode___170 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___169 *d_op;
	struct super_block___169 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___169;

struct address_space___169 {
	struct inode___170 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___170 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___169 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___169;

struct block_device___170;

struct inode___170 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___169 *i_op;
	struct super_block___169 *i_sb;
	struct address_space___169 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___170 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___170 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___169 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___39 *i_pipe;
		struct block_device___170 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vfsmount___27;

struct path___169;

struct dentry_operations___169 {
	int (*d_revalidate)(struct dentry___169 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___169 *, unsigned int);
	int (*d_hash)(const struct dentry___169 *, struct qstr *);
	int (*d_compare)(const struct dentry___169 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___169 *);
	int (*d_init)(struct dentry___169 *);
	void (*d_release)(struct dentry___169 *);
	void (*d_prune)(struct dentry___169 *);
	void (*d_iput)(struct dentry___169 *, struct inode___170 *);
	char * (*d_dname)(struct dentry___169 *, char *, int);
	struct vfsmount___27 * (*d_automount)(struct path___169 *);
	int (*d_manage)(const struct path___169 *, bool);
	struct dentry___169 * (*d_real)(struct dentry___169 *, const struct inode___170 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___169;

struct mem_dqinfo___169 {
	struct quota_format_type___169 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___169;

struct quota_info___169 {
	unsigned int flags;
	struct rw_semaphore___170 dqio_sem;
	struct inode___170 *files[3];
	struct mem_dqinfo___169 info[3];
	const struct quota_format_ops___169 *ops[3];
};

struct rcuwait___169 {
	struct task_struct___170 *task;
};

struct percpu_rw_semaphore___169 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___170 rw_sem;
	struct rcuwait___169 writer;
	int readers_block;
};

struct sb_writers___169 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___169 rw_sem[3];
};

struct file_system_type___169;

struct super_operations___169;

struct dquot_operations___169;

struct quotactl_ops___169;

struct user_namespace___149;

struct super_block___169 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___169 *s_type;
	const struct super_operations___169 *s_op;
	const struct dquot_operations___169 *dq_op;
	const struct quotactl_ops___169 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___169 *s_root;
	struct rw_semaphore___170 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___170 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___169 s_dquot;
	struct sb_writers___169 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___169 *s_d_op;
	int cleancache_poolid;
	struct shrinker___76 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___149 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___27 {
	struct dentry___169 *mnt_root;
	struct super_block___169 *mnt_sb;
	int mnt_flags;
};

struct path___169 {
	struct vfsmount___27 *mnt;
	struct dentry___169 *dentry;
};

struct name_snapshot {
	const unsigned char *name;
	unsigned char inline_name[32];
};

struct key___165;

struct ucounts___149;

struct user_namespace___149 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___149 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___4 ns;
	long unsigned int flags;
	struct key___165 *persistent_keyring_register;
	struct rw_semaphore___170 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___149 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct upid___134 {
	int nr;
	struct pid_namespace___134 *ns;
};

struct pid_namespace___134 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___170 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___134 *parent;
	struct vfsmount___27 *proc_mnt;
	struct dentry___169 *proc_self;
	struct dentry___169 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___149 *user_ns;
	struct ucounts___149 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___4 ns;
};

struct pid___134 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___134 numbers[1];
};

struct vm_operations_struct___167;

struct vm_area_struct___170 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___170 *vm_next;
	struct vm_area_struct___170 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___169 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___167 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___170 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___169;

struct mm_struct___169 {
	struct {
		struct vm_area_struct___170 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___170 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___170 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___169 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___170 *owner;
		struct user_namespace___149 *user_ns;
		struct file___170 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___169 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___167)(struct vm_area_struct___170 *, long unsigned int, const struct page___170 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___167)(struct page___170 *, void *);

struct device___158;

struct dev_pagemap___167 {
	dev_page_fault_t___167 page_fault;
	dev_page_free_t___167 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___158 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct fown_struct___134 {
	rwlock_t lock;
	struct pid___134 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___170 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___169 f_path;
	struct inode___170 *f_inode;
	const struct file_operations___170 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___134 f_owner;
	const struct cred___165 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___169 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___167;

struct vm_operations_struct___167 {
	void (*open)(struct vm_area_struct___170 *);
	void (*close)(struct vm_area_struct___170 *);
	int (*split)(struct vm_area_struct___170 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___170 *);
	vm_fault_t (*fault)(struct vm_fault___167 *);
	vm_fault_t (*huge_fault)(struct vm_fault___167 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___167 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___170 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___167 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___167 *);
	int (*access)(struct vm_area_struct___170 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___170 *);
	int (*set_policy)(struct vm_area_struct___170 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___170 *, long unsigned int);
	struct page___170 * (*find_special_page)(struct vm_area_struct___170 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___169 {
	struct task_struct___170 *task;
	struct core_thread___169 *next;
};

struct core_state___169 {
	atomic_t nr_threads;
	struct core_thread___169 dumper;
	struct completion startup;
};

struct vm_fault___167 {
	struct vm_area_struct___170 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___170 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___170 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___169 prealloc_pte;
};

struct user_struct___165 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___165 *uid_keyring;
	struct key___165 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___165 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___165 *session_keyring;
	struct key___165 *process_keyring;
	struct key___165 *thread_keyring;
	struct key___165 *request_key_auth;
	void *security;
	struct user_struct___165 *user;
	struct user_namespace___149 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct saved {
	struct path___169 link;
	struct delayed_call done;
	const char *name;
	unsigned int seq;
};

struct nameidata___2 {
	struct path___169 path;
	struct qstr last;
	struct path___169 root;
	struct inode___170 *inode;
	unsigned int flags;
	unsigned int seq;
	unsigned int m_seq;
	int last_type;
	unsigned int depth;
	int total_link_count;
	struct saved *stack;
	struct saved internal[2];
	struct filename *name;
	struct nameidata___2 *saved;
	struct inode___170 *link_inode;
	unsigned int root_seq;
	int dfd;
};

struct fs_struct___9 {
	int users;
	spinlock_t lock;
	seqcount_t seq;
	int umask;
	int in_exec;
	struct path___169 root;
	struct path___169 pwd;
};

struct uts_namespace___22;

struct mnt_namespace___2;

struct net___31;

struct cgroup_namespace___145;

struct nsproxy___161 {
	atomic_t count;
	struct uts_namespace___22 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace___2 *mnt_ns;
	struct pid_namespace___134 *pid_ns_for_children;
	struct net___31 *net_ns;
	struct cgroup_namespace___145 *cgroup_ns;
};

struct signal_struct___150 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___170 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___170 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___134 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___134 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___169 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___134 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___145;

struct cgroup___145;

struct css_set___145 {
	struct cgroup_subsys_state___145 *subsys[13];
	refcount_t refcount;
	struct css_set___145 *dom_cset;
	struct cgroup___145 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___145 *mg_src_cgrp;
	struct cgroup___145 *mg_dst_cgrp;
	struct css_set___145 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___104 {
	struct pmu___104 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___170 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___104 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___39;

struct pipe_inode_info___39 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___170 *tmp_page;
	struct fasync_struct___169 *fasync_readers;
	struct fasync_struct___169 *fasync_writers;
	struct pipe_buffer___39 *bufs;
	struct user_struct___165 *user;
};

struct vm_struct___123 {
	struct vm_struct___123 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___170 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___151 {
	struct task_struct___170 task;
	long unsigned int stack[8192];
};

struct kiocb___170 {
	struct file___170 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___170 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___169 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___170 *ia_file;
};

struct dquot___169 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___169 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___169 {
	int qf_fmt_id;
	const struct quota_format_ops___169 *qf_ops;
	struct module___144 *qf_owner;
	struct quota_format_type___169 *qf_next;
};

struct quota_format_ops___169 {
	int (*check_quota_file)(struct super_block___169 *, int);
	int (*read_file_info)(struct super_block___169 *, int);
	int (*write_file_info)(struct super_block___169 *, int);
	int (*free_file_info)(struct super_block___169 *, int);
	int (*read_dqblk)(struct dquot___169 *);
	int (*commit_dqblk)(struct dquot___169 *);
	int (*release_dqblk)(struct dquot___169 *);
	int (*get_next_id)(struct super_block___169 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___169 {
	int (*write_dquot)(struct dquot___169 *);
	struct dquot___169 * (*alloc_dquot)(struct super_block___169 *, int);
	void (*destroy_dquot)(struct dquot___169 *);
	int (*acquire_dquot)(struct dquot___169 *);
	int (*release_dquot)(struct dquot___169 *);
	int (*mark_dirty)(struct dquot___169 *);
	int (*write_info)(struct super_block___169 *, int);
	qsize_t * (*get_reserved_space)(struct inode___170 *);
	int (*get_projid)(struct inode___170 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___170 *, qsize_t *);
	int (*get_next_id)(struct super_block___169 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___169 {
	int (*quota_on)(struct super_block___169 *, int, int, const struct path___169 *);
	int (*quota_off)(struct super_block___169 *, int);
	int (*quota_enable)(struct super_block___169 *, unsigned int);
	int (*quota_disable)(struct super_block___169 *, unsigned int);
	int (*quota_sync)(struct super_block___169 *, int);
	int (*set_info)(struct super_block___169 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___169 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___169 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___169 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___169 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___169 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___163;

struct kobj_type___163;

struct kernfs_node___166;

struct kobject___164 {
	const char *name;
	struct list_head entry;
	struct kobject___164 *parent;
	struct kset___163 *kset;
	struct kobj_type___163 *ktype;
	struct kernfs_node___166 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___141 {
	struct kobject___164 kobj;
	struct module___144 *mod;
	struct kobject___164 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___141 {
	struct module___144 *mod;
	struct latch_tree_node node;
};

struct module_layout___141 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___141 mtn;
};

struct module_attribute___141;

struct kernel_param___141;

struct module___144 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___141 mkobj;
	struct module_attribute___141 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___164 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___141 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___141 core_layout;
	struct module_layout___141 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___97 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___169 {
	int (*writepage)(struct page___170 *, struct writeback_control___3 *);
	int (*readpage)(struct file___170 *, struct page___170 *);
	int (*writepages)(struct address_space___169 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___170 *);
	int (*readpages)(struct file___170 *, struct address_space___169 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___170 *, struct address_space___169 *, loff_t, unsigned int, unsigned int, struct page___170 **, void **);
	int (*write_end)(struct file___170 *, struct address_space___169 *, loff_t, unsigned int, unsigned int, struct page___170 *, void *);
	sector_t (*bmap)(struct address_space___169 *, sector_t);
	void (*invalidatepage)(struct page___170 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___170 *, gfp_t);
	void (*freepage)(struct page___170 *);
	ssize_t (*direct_IO)(struct kiocb___170 *, struct iov_iter___80 *);
	int (*migratepage)(struct address_space___169 *, struct page___170 *, struct page___170 *, enum migrate_mode);
	bool (*isolate_page)(struct page___170 *, isolate_mode_t);
	void (*putback_page)(struct page___170 *);
	int (*launder_page)(struct page___170 *);
	int (*is_partially_uptodate)(struct page___170 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___170 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___169 *, struct page___170 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___170 *, sector_t *);
	void (*swap_deactivate)(struct file___170 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct iov_iter___80 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___3 *bvec;
		struct pipe_inode_info___39 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___170 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___170 *bd_inode;
	struct super_block___169 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___170 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___169 {
	struct dentry___169 * (*lookup)(struct inode___170 *, struct dentry___169 *, unsigned int);
	const char * (*get_link)(struct dentry___169 *, struct inode___170 *, struct delayed_call *);
	int (*permission)(struct inode___170 *, int);
	struct posix_acl * (*get_acl)(struct inode___170 *, int);
	int (*readlink)(struct dentry___169 *, char *, int);
	int (*create)(struct inode___170 *, struct dentry___169 *, umode_t, bool);
	int (*link)(struct dentry___169 *, struct inode___170 *, struct dentry___169 *);
	int (*unlink)(struct inode___170 *, struct dentry___169 *);
	int (*symlink)(struct inode___170 *, struct dentry___169 *, const char *);
	int (*mkdir)(struct inode___170 *, struct dentry___169 *, umode_t);
	int (*rmdir)(struct inode___170 *, struct dentry___169 *);
	int (*mknod)(struct inode___170 *, struct dentry___169 *, umode_t, dev_t);
	int (*rename)(struct inode___170 *, struct dentry___169 *, struct inode___170 *, struct dentry___169 *, unsigned int);
	int (*setattr)(struct dentry___169 *, struct iattr___169 *);
	int (*getattr)(const struct path___169 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___169 *, char *, size_t);
	int (*fiemap)(struct inode___170 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___170 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___170 *, struct dentry___169 *, struct file___170 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___170 *, struct dentry___169 *, umode_t);
	int (*set_acl)(struct inode___170 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___169 {
	void (*fl_copy_lock)(struct file_lock___170 *, struct file_lock___170 *);
	void (*fl_release_private)(struct file_lock___170 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___169;

struct file_lock___170 {
	struct file_lock___170 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___170 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___169 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___169 *fl_ops;
	const struct lock_manager_operations___169 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___169 {
	int (*lm_compare_owner)(struct file_lock___170 *, struct file_lock___170 *);
	long unsigned int (*lm_owner_key)(struct file_lock___170 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___170 *);
	int (*lm_grant)(struct file_lock___170 *, int);
	bool (*lm_break)(struct file_lock___170 *);
	int (*lm_change)(struct file_lock___170 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___170 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___169 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___169 *fa_next;
	struct file___170 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___169 {
	const char *name;
	int fs_flags;
	struct dentry___169 * (*mount)(struct file_system_type___169 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___169 *);
	struct module___144 *owner;
	struct file_system_type___169 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___169 {
	struct inode___170 * (*alloc_inode)(struct super_block___169 *);
	void (*destroy_inode)(struct inode___170 *);
	void (*dirty_inode)(struct inode___170 *, int);
	int (*write_inode)(struct inode___170 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___170 *);
	void (*evict_inode)(struct inode___170 *);
	void (*put_super)(struct super_block___169 *);
	int (*sync_fs)(struct super_block___169 *, int);
	int (*freeze_super)(struct super_block___169 *);
	int (*freeze_fs)(struct super_block___169 *);
	int (*thaw_super)(struct super_block___169 *);
	int (*unfreeze_fs)(struct super_block___169 *);
	int (*statfs)(struct dentry___169 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___169 *, int *, char *);
	void (*umount_begin)(struct super_block___169 *);
	int (*show_options)(struct seq_file___160 *, struct dentry___169 *);
	int (*show_devname)(struct seq_file___160 *, struct dentry___169 *);
	int (*show_path)(struct seq_file___160 *, struct dentry___169 *);
	int (*show_stats)(struct seq_file___160 *, struct dentry___169 *);
	ssize_t (*quota_read)(struct super_block___169 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___169 *, int, const char *, size_t, loff_t);
	struct dquot___169 ** (*get_dquots)(struct inode___170 *);
	int (*bdev_try_to_free_page)(struct super_block___169 *, struct page___170 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___169 *, struct shrink_control___76 *);
	long int (*free_cached_objects)(struct super_block___169 *, struct shrink_control___76 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___113)(struct file___170 *, wait_queue_head_t *, struct poll_table_struct___114 *);

struct poll_table_struct___114 {
	poll_queue_proc___113 _qproc;
	__poll_t _key;
};

struct seq_operations___158;

struct seq_file___160 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___158 *op;
	int poll_event;
	const struct file___170 *file;
	void *private;
};

enum {
	LAST_NORM = 0,
	LAST_ROOT = 1,
	LAST_DOT = 2,
	LAST_DOTDOT = 3,
	LAST_BIND = 4,
};

struct dev_pm_info___158 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___158 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___158;

struct bus_type___158;

struct device_driver___158;

struct dev_pm_domain___158;

struct dma_map_ops___39;

struct fwnode_handle___112;

struct class___158;

struct attribute_group___159;

struct device___158 {
	struct device___158 *parent;
	struct device_private *p;
	struct kobject___164 kobj;
	const char *init_name;
	const struct device_type___158 *type;
	struct mutex mutex;
	struct bus_type___158 *bus;
	struct device_driver___158 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___158 power;
	struct dev_pm_domain___158 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___39 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___112 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___158 *class;
	const struct attribute_group___159 **groups;
	void (*release)(struct device___158 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct kobj_attribute___164 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___164 *, struct kobj_attribute___164 *, char *);
	ssize_t (*store)(struct kobject___164 *, struct kobj_attribute___164 *, const char *, size_t);
};

typedef void compound_page_dtor___167(struct page___170 *);

typedef int filler_t___5(void *, struct page___170 *);

struct uts_namespace___22 {
	struct kref kref;
	struct new_utsname name;
	struct user_namespace___149 *user_ns;
	struct ucounts___149 *ucounts;
	struct ns_common___4 ns;
};

struct mount;

struct mnt_namespace___2 {
	atomic_t count;
	struct ns_common___4 ns;
	struct mount *root;
	struct list_head list;
	struct user_namespace___149 *user_ns;
	struct ucounts___149 *ucounts;
	u64 seq;
	wait_queue_head_t poll;
	u64 event;
	unsigned int mounts;
	unsigned int pending_mounts;
};

struct dst_ops___29 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___29 *);
	struct dst_entry___2 * (*check)(struct dst_entry___2 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___2 *);
	unsigned int (*mtu)(const struct dst_entry___2 *);
	u32 * (*cow_metrics)(struct dst_entry___2 *, long unsigned int);
	void (*destroy)(struct dst_entry___2 *);
	void (*ifdown)(struct dst_entry___2 *, struct net_device *, int);
	struct dst_entry___2 * (*negative_advice)(struct dst_entry___2 *);
	void (*link_failure)(struct sk_buff___24 *);
	void (*update_pmtu)(struct dst_entry___2 *, struct sock *, struct sk_buff___24 *, u32);
	void (*redirect)(struct dst_entry___2 *, struct sock *, struct sk_buff___24 *);
	int (*local_out)(struct net___31 *, struct sock *, struct sk_buff___24 *);
	struct neighbour___2 * (*neigh_lookup)(const struct dst_entry___2 *, struct sk_buff___24 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___2 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___29 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___21 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___29 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct sock *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops *notifier_ops;
	struct fib_notifier_ops *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_xfrm___29 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___29 xfrm4_dst_ops;
	struct dst_ops___29 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct net___31 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___149 *user_ns;
	struct ucounts___149 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___4 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___21 ipv4;
	struct netns_ipv6___29 ipv6;
	struct netns_sctp___10 sctp;
	struct netns_nf nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___21 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock *nfnl;
	struct sock *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___29 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cgroup_namespace___145 {
	refcount_t count;
	struct ns_common___4 ns;
	struct user_namespace___149 *user_ns;
	struct ucounts___149 *ucounts;
	struct css_set___145 *root_cset;
};

struct key_restriction___165;

struct key___165 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___170 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___165 *restrict_link;
};

struct ucounts___149 {
	struct hlist_node node;
	struct user_namespace___149 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct seq_operations___158 {
	void * (*start)(struct seq_file___160 *, loff_t *);
	void (*stop)(struct seq_file___160 *, void *);
	void * (*next)(struct seq_file___160 *, void *, loff_t *);
	int (*show)(struct seq_file___160 *, void *);
};

typedef int (*key_restrict_link_func_t___165)(struct key___165 *, const struct key_type *, const union key_payload *, struct key___165 *);

struct key_restriction___165 {
	key_restrict_link_func_t___165 check;
	struct key___165 *key;
	struct key_type *keytype;
};

struct fwnode_operations___112;

struct fwnode_handle___112 {
	struct fwnode_handle___112 *secondary;
	const struct fwnode_operations___112 *ops;
};

struct fwnode_reference_args___112;

struct fwnode_endpoint___112;

struct fwnode_operations___112 {
	struct fwnode_handle___112 * (*get)(struct fwnode_handle___112 *);
	void (*put)(struct fwnode_handle___112 *);
	bool (*device_is_available)(const struct fwnode_handle___112 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___112 *, const struct device___158 *);
	bool (*property_present)(const struct fwnode_handle___112 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___112 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___112 *, const char *, const char **, size_t);
	struct fwnode_handle___112 * (*get_parent)(const struct fwnode_handle___112 *);
	struct fwnode_handle___112 * (*get_next_child_node)(const struct fwnode_handle___112 *, struct fwnode_handle___112 *);
	struct fwnode_handle___112 * (*get_named_child_node)(const struct fwnode_handle___112 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___112 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___112 *);
	struct fwnode_handle___112 * (*graph_get_next_endpoint)(const struct fwnode_handle___112 *, struct fwnode_handle___112 *);
	struct fwnode_handle___112 * (*graph_get_remote_endpoint)(const struct fwnode_handle___112 *);
	struct fwnode_handle___112 * (*graph_get_port_parent)(struct fwnode_handle___112 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___112 *, struct fwnode_endpoint___112 *);
};

struct fwnode_endpoint___112 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___112 *local_fwnode;
};

struct fwnode_reference_args___112 {
	struct fwnode_handle___112 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct kernfs_root___166;

struct kernfs_elem_dir___166 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___166 *root;
};

struct kernfs_syscall_ops___166;

struct kernfs_root___166 {
	struct kernfs_node___166 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___166 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___166 {
	struct kernfs_node___166 *target_kn;
};

struct kernfs_ops___166;

struct kernfs_elem_attr___166 {
	const struct kernfs_ops___166 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___166 *notify_next;
};

struct kernfs_node___166 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___166 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___166 dir;
		struct kernfs_elem_symlink___166 symlink;
		struct kernfs_elem_attr___166 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___166;

struct kernfs_ops___166 {
	int (*open)(struct kernfs_open_file___166 *);
	void (*release)(struct kernfs_open_file___166 *);
	int (*seq_show)(struct seq_file___160 *, void *);
	void * (*seq_start)(struct seq_file___160 *, loff_t *);
	void * (*seq_next)(struct seq_file___160 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___160 *, void *);
	ssize_t (*read)(struct kernfs_open_file___166 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___166 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___166 *, struct vm_area_struct___170 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___166 *, struct poll_table_struct___114 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___166 {
	int (*remount_fs)(struct kernfs_root___166 *, int *, char *);
	int (*show_options)(struct seq_file___160 *, struct kernfs_root___166 *);
	int (*mkdir)(struct kernfs_node___166 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___166 *);
	int (*rename)(struct kernfs_node___166 *, struct kernfs_node___166 *, const char *);
	int (*show_path)(struct seq_file___160 *, struct kernfs_node___166 *, struct kernfs_root___166 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___166 {
	struct kernfs_node___166 *kn;
	struct file___170 *file;
	struct seq_file___160 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___167 *vm_ops;
};

struct bin_attribute___158;

struct attribute_group___159 {
	const char *name;
	umode_t (*is_visible)(struct kobject___164 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___164 *, struct bin_attribute___158 *, int);
	struct attribute **attrs;
	struct bin_attribute___158 **bin_attrs;
};

struct bin_attribute___158 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___170 *, struct kobject___164 *, struct bin_attribute___158 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___170 *, struct kobject___164 *, struct bin_attribute___158 *, char *, loff_t, size_t);
	int (*mmap)(struct file___170 *, struct kobject___164 *, struct bin_attribute___158 *, struct vm_area_struct___170 *);
};

struct sysfs_ops___163 {
	ssize_t (*show)(struct kobject___164 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___164 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___163;

struct kset___163 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___164 kobj;
	const struct kset_uevent_ops___163 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___163 {
	void (*release)(struct kobject___164 *);
	const struct sysfs_ops___163 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___10 * (*child_ns_type)(struct kobject___164 *);
	const void * (*namespace)(struct kobject___164 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___163 {
	int (* const filter)(struct kset___163 *, struct kobject___164 *);
	const char * (* const name)(struct kset___163 *, struct kobject___164 *);
	int (* const uevent)(struct kset___163 *, struct kobject___164 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___141 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___141 *);
	int (*get)(char *, const struct kernel_param___141 *);
	void (*free)(void *);
};

struct kparam_array___141;

struct kernel_param___141 {
	const char *name;
	struct module___144 *mod;
	const struct kernel_param_ops___141 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___141 *arr;
	};
};

struct kparam_array___141 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___141 *ops;
	void *elem;
};

struct module_attribute___141 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___141 *, struct module_kobject___141 *, char *);
	ssize_t (*store)(struct module_attribute___141 *, struct module_kobject___141 *, const char *, size_t);
	void (*setup)(struct module___144 *, const char *);
	int (*test)(struct module___144 *);
	void (*free)(struct module___144 *);
};

struct trace_event_class___97;

struct trace_event_call___97 {
	struct list_head list;
	struct trace_event_class___97 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___20 *prog_array;
	int (*perf_perm)(struct trace_event_call___97 *, struct perf_event___104 *);
};

struct kimage___15;

typedef void *kexec_load_t___15(struct kimage___15 *, char *, long unsigned int, char *, long unsigned int, char *, long unsigned int);

struct kexec_file_ops___16 {
	kexec_probe_t *probe;
	kexec_load_t___15 *load;
	kexec_cleanup_t *cleanup;
};

struct kimage___15 {
	kimage_entry_t head;
	kimage_entry_t *entry;
	kimage_entry_t *last_entry;
	long unsigned int start;
	struct page___170 *control_code_page;
	struct page___170 *swap_page;
	void *vmcoreinfo_data_copy;
	long unsigned int nr_segments;
	struct kexec_segment segment[16];
	struct list_head control_pages;
	struct list_head dest_pages;
	struct list_head unusable_pages;
	long unsigned int control_page;
	unsigned int type: 1;
	unsigned int preserve_context: 1;
	unsigned int file_mode: 1;
	struct kimage_arch arch;
	void *kernel_buf;
	long unsigned int kernel_buf_len;
	void *initrd_buf;
	long unsigned int initrd_buf_len;
	char *cmdline_buf;
	long unsigned int cmdline_buf_len;
	const struct kexec_file_ops___16 *fops;
	void *image_loader_data;
	struct purgatory_info purgatory_info;
};

struct dev_pm_ops___158 {
	int (*prepare)(struct device___158 *);
	void (*complete)(struct device___158 *);
	int (*suspend)(struct device___158 *);
	int (*resume)(struct device___158 *);
	int (*freeze)(struct device___158 *);
	int (*thaw)(struct device___158 *);
	int (*poweroff)(struct device___158 *);
	int (*restore)(struct device___158 *);
	int (*suspend_late)(struct device___158 *);
	int (*resume_early)(struct device___158 *);
	int (*freeze_late)(struct device___158 *);
	int (*thaw_early)(struct device___158 *);
	int (*poweroff_late)(struct device___158 *);
	int (*restore_early)(struct device___158 *);
	int (*suspend_noirq)(struct device___158 *);
	int (*resume_noirq)(struct device___158 *);
	int (*freeze_noirq)(struct device___158 *);
	int (*thaw_noirq)(struct device___158 *);
	int (*poweroff_noirq)(struct device___158 *);
	int (*restore_noirq)(struct device___158 *);
	int (*runtime_suspend)(struct device___158 *);
	int (*runtime_resume)(struct device___158 *);
	int (*runtime_idle)(struct device___158 *);
};

struct dev_pm_domain___158 {
	struct dev_pm_ops___158 ops;
	void (*detach)(struct device___158 *, bool);
	int (*activate)(struct device___158 *);
	void (*sync)(struct device___158 *);
	void (*dismiss)(struct device___158 *);
};

struct bus_type___158 {
	const char *name;
	const char *dev_name;
	struct device___158 *dev_root;
	const struct attribute_group___159 **bus_groups;
	const struct attribute_group___159 **dev_groups;
	const struct attribute_group___159 **drv_groups;
	int (*match)(struct device___158 *, struct device_driver___158 *);
	int (*uevent)(struct device___158 *, struct kobj_uevent_env *);
	int (*probe)(struct device___158 *);
	int (*remove)(struct device___158 *);
	void (*shutdown)(struct device___158 *);
	int (*online)(struct device___158 *);
	int (*offline)(struct device___158 *);
	int (*suspend)(struct device___158 *, pm_message_t);
	int (*resume)(struct device___158 *);
	int (*num_vf)(struct device___158 *);
	int (*dma_configure)(struct device___158 *);
	const struct dev_pm_ops___158 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___158 {
	const char *name;
	struct bus_type___158 *bus;
	struct module___144 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___158 *);
	int (*remove)(struct device___158 *);
	void (*shutdown)(struct device___158 *);
	int (*suspend)(struct device___158 *, pm_message_t);
	int (*resume)(struct device___158 *);
	const struct attribute_group___159 **groups;
	const struct dev_pm_ops___158 *pm;
	void (*coredump)(struct device___158 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___158 {
	const char *name;
	const struct attribute_group___159 **groups;
	int (*uevent)(struct device___158 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___158 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___158 *);
	const struct dev_pm_ops___158 *pm;
};

struct class___158 {
	const char *name;
	struct module___144 *owner;
	const struct attribute_group___159 **class_groups;
	const struct attribute_group___159 **dev_groups;
	struct kobject___164 *dev_kobj;
	int (*dev_uevent)(struct device___158 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___158 *, umode_t *);
	void (*class_release)(struct class___158 *);
	void (*dev_release)(struct device___158 *);
	int (*shutdown_pre)(struct device___158 *);
	const struct kobj_ns_type_operations___10 *ns_type;
	const void * (*namespace)(struct device___158 *);
	const struct dev_pm_ops___158 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___39 {
	void * (*alloc)(struct device___158 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___158 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___158 *, struct vm_area_struct___170 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___158 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___158 *, struct page___170 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___158 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___158 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___158 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___158 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___158 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___158 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___158 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___158 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___158 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___158 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___158 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___158 *, u64);
	u64 (*get_required_mask)(struct device___158 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct node___134 {
	struct device___158 dev;
};

struct fd___14 {
	struct file___170 *file;
	unsigned int flags;
};

struct bpf_map___145;

struct bpf_map_ops___145 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___145 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___145 *, struct file___170 *);
	void (*map_free)(struct bpf_map___145 *);
	int (*map_get_next_key)(struct bpf_map___145 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___145 *);
	void * (*map_lookup_elem)(struct bpf_map___145 *, void *);
	int (*map_update_elem)(struct bpf_map___145 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___145 *, void *);
	int (*map_push_elem)(struct bpf_map___145 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___145 *, void *);
	int (*map_peek_elem)(struct bpf_map___145 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___145 *, struct file___170 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___145 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___145 *, void *, struct seq_file___160 *);
	int (*map_check_btf)(const struct bpf_map___145 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___145 {
	const struct bpf_map_ops___145 *ops;
	struct bpf_map___145 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___165 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___145;

typedef void (*kthread_work_func_t___145)(struct kthread_work___145 *);

struct kthread_worker___145;

struct kthread_work___145 {
	struct list_head node;
	kthread_work_func_t___145 func;
	struct kthread_worker___145 *worker;
	int canceling;
};

struct kthread_worker___145 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___170 *task;
	struct kthread_work___145 *current_work;
};

struct kthread_delayed_work___145 {
	struct kthread_work___145 work;
	struct timer_list timer;
};

struct psi_group___145 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___145 *poll_kworker;
	struct kthread_delayed_work___145 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___145 {
	struct kernfs_node___166 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___145;

struct cgroup_subsys_state___145 {
	struct cgroup___145 *cgroup;
	struct cgroup_subsys___145 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___145 *parent;
};

struct cgroup_root___145;

struct cgroup_rstat_cpu___145;

struct cgroup___145 {
	struct cgroup_subsys_state___145 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___166 *kn;
	struct cgroup_file___145 procs_file;
	struct cgroup_file___145 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___145 *subsys[13];
	struct cgroup_root___145 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___145 *dom_cgrp;
	struct cgroup_rstat_cpu___145 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___20 bpf;
	atomic_t congestion_count;
	struct cgroup___145 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___145 psi;
	int ancestor_ids[0];
};

struct cftype___145;

struct cgroup_subsys___145 {
	struct cgroup_subsys_state___145 * (*css_alloc)(struct cgroup_subsys_state___145 *);
	int (*css_online)(struct cgroup_subsys_state___145 *);
	void (*css_offline)(struct cgroup_subsys_state___145 *);
	void (*css_released)(struct cgroup_subsys_state___145 *);
	void (*css_free)(struct cgroup_subsys_state___145 *);
	void (*css_reset)(struct cgroup_subsys_state___145 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___145 *, int);
	int (*css_extra_stat_show)(struct seq_file___160 *, struct cgroup_subsys_state___145 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___170 *);
	void (*cancel_fork)(struct task_struct___170 *);
	void (*fork)(struct task_struct___170 *);
	void (*exit)(struct task_struct___170 *);
	void (*free)(struct task_struct___170 *);
	void (*bind)(struct cgroup_subsys_state___145 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___145 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___145 *dfl_cftypes;
	struct cftype___145 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___145 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___145 *updated_children;
	struct cgroup___145 *updated_next;
};

struct cgroup_root___145 {
	struct kernfs_root___166 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___145 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___145 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___145 *ss;
	struct list_head node;
	struct kernfs_ops___166 *kf_ops;
	int (*open)(struct kernfs_open_file___166 *);
	void (*release)(struct kernfs_open_file___166 *);
	u64 (*read_u64)(struct cgroup_subsys_state___145 *, struct cftype___145 *);
	s64 (*read_s64)(struct cgroup_subsys_state___145 *, struct cftype___145 *);
	int (*seq_show)(struct seq_file___160 *, void *);
	void * (*seq_start)(struct seq_file___160 *, loff_t *);
	void * (*seq_next)(struct seq_file___160 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___160 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___145 *, struct cftype___145 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___145 *, struct cftype___145 *, s64);
	ssize_t (*write)(struct kernfs_open_file___166 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___166 *, struct poll_table_struct___114 *);
};

struct perf_cpu_context___104;

struct pmu___104 {
	struct list_head entry;
	struct module___144 *module;
	struct device___158 *dev;
	const struct attribute_group___159 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___104 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___104 *);
	void (*pmu_disable)(struct pmu___104 *);
	int (*event_init)(struct perf_event___104 *);
	void (*event_mapped)(struct perf_event___104 *, struct mm_struct___169 *);
	void (*event_unmapped)(struct perf_event___104 *, struct mm_struct___169 *);
	int (*add)(struct perf_event___104 *, int);
	void (*del)(struct perf_event___104 *, int);
	void (*start)(struct perf_event___104 *, int);
	void (*stop)(struct perf_event___104 *, int);
	void (*read)(struct perf_event___104 *);
	void (*start_txn)(struct pmu___104 *, unsigned int);
	int (*commit_txn)(struct pmu___104 *);
	void (*cancel_txn)(struct pmu___104 *);
	int (*event_idx)(struct perf_event___104 *);
	void (*sched_task)(struct perf_event_context___104 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___104 *);
	int (*filter_match)(struct perf_event___104 *);
	int (*check_period)(struct perf_event___104 *, u64);
};

struct perf_cpu_context___104 {
	struct perf_event_context___104 ctx;
	struct perf_event_context___104 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___104 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___104 {
	struct cgroup_subsys_state___145 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___97 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___97 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___97 *);
	struct list_head * (*get_fields)(struct trace_event_call___97 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___97 *);
};

struct syscall_metadata___43 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___97 *enter_event;
	struct trace_event_call___97 *exit_event;
};

struct pipe_buf_operations___39;

struct pipe_buffer___39 {
	struct page___170 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___39 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___39 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___39 *, struct pipe_buffer___39 *);
	void (*release)(struct pipe_inode_info___39 *, struct pipe_buffer___39 *);
	int (*steal)(struct pipe_inode_info___39 *, struct pipe_buffer___39 *);
	union {
		bool (*get)(struct pipe_inode_info___39 *, struct pipe_buffer___39 *);
		struct {
			void (*get)(struct pipe_inode_info___39 *, struct pipe_buffer___39 *);
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
};

struct mnt_pcp;

struct mountpoint;

struct mount {
	struct hlist_node mnt_hash;
	struct mount *mnt_parent;
	struct dentry___169 *mnt_mountpoint;
	struct vfsmount___27 mnt;
	union {
		struct callback_head mnt_rcu;
		struct llist_node mnt_llist;
	};
	struct mnt_pcp *mnt_pcp;
	struct list_head mnt_mounts;
	struct list_head mnt_child;
	struct list_head mnt_instance;
	const char *mnt_devname;
	struct list_head mnt_list;
	struct list_head mnt_expire;
	struct list_head mnt_share;
	struct list_head mnt_slave_list;
	struct list_head mnt_slave;
	struct mount *mnt_master;
	struct mnt_namespace___2 *mnt_ns;
	struct mountpoint *mnt_mp;
	struct hlist_node mnt_mp_list;
	struct list_head mnt_umounting;
	struct fsnotify_mark_connector *mnt_fsnotify_marks;
	__u32 mnt_fsnotify_mask;
	int mnt_id;
	int mnt_group_id;
	int mnt_expiry_mark;
	struct hlist_head mnt_pins;
	struct fs_pin mnt_umount;
	struct dentry___169 *mnt_ex_mountpoint;
};

struct mnt_pcp {
	int mnt_count;
	int mnt_writers;
};

struct mountpoint {
	struct hlist_node m_hash;
	struct dentry___169 *m_dentry;
	struct hlist_head m_list;
	int m_count;
};

enum {
	WALK_FOLLOW = 1,
	WALK_MORE = 2,
};

struct word_at_a_time {
	const long unsigned int one_bits;
	const long unsigned int high_bits;
};

struct module___145;

struct file___171;

struct kiocb___171;

struct iov_iter___81;

struct poll_table_struct___115;

struct vm_area_struct___171;

struct inode___171;

struct file_lock___171;

struct page___171;

struct pipe_inode_info___40;

struct seq_file___161;

struct file_operations___171 {
	struct module___145 *owner;
	loff_t (*llseek)(struct file___171 *, loff_t, int);
	ssize_t (*read)(struct file___171 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___171 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___171 *, struct iov_iter___81 *);
	ssize_t (*write_iter)(struct kiocb___171 *, struct iov_iter___81 *);
	int (*iopoll)(struct kiocb___171 *, bool);
	int (*iterate)(struct file___171 *, struct dir_context *);
	int (*iterate_shared)(struct file___171 *, struct dir_context *);
	__poll_t (*poll)(struct file___171 *, struct poll_table_struct___115 *);
	long int (*unlocked_ioctl)(struct file___171 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___171 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___171 *, struct vm_area_struct___171 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___171 *, struct file___171 *);
	int (*flush)(struct file___171 *, fl_owner_t);
	int (*release)(struct inode___171 *, struct file___171 *);
	int (*fsync)(struct file___171 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___171 *, int);
	int (*lock)(struct file___171 *, int, struct file_lock___171 *);
	ssize_t (*sendpage)(struct file___171 *, struct page___171 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___171 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___171 *, int, struct file_lock___171 *);
	ssize_t (*splice_write)(struct pipe_inode_info___40 *, struct file___171 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___171 *, loff_t *, struct pipe_inode_info___40 *, size_t, unsigned int);
	int (*setlease)(struct file___171 *, long int, struct file_lock___171 **, void **);
	long int (*fallocate)(struct file___171 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___161 *, struct file___171 *);
	ssize_t (*copy_file_range)(struct file___171 *, loff_t, struct file___171 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___171 *, loff_t, struct file___171 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___171 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___170 {
	u64 seqnum;
	struct vm_area_struct___171 *vmas[4];
};

struct page_frag___170 {
	struct page___171 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___105;

struct debug_info___105 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___105 *hbp_break[16];
	struct perf_event___105 *hbp_watch[16];
};

struct thread_struct___105 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___105 debug;
	long: 64;
};

struct mm_struct___170;

struct pid___135;

struct cred___166;

struct files_struct___9;

struct nsproxy___162;

struct signal_struct___151;

struct css_set___146;

struct perf_event_context___105;

struct task_struct___171 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___171 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___170 *mm;
	struct mm_struct___170 *active_mm;
	struct vmacache___170 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___171 *real_parent;
	struct task_struct___171 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___171 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___135 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___135 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___135 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___166 *ptracer_cred;
	const struct cred___166 *real_cred;
	const struct cred___166 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct___9 *files;
	struct nsproxy___162 *nsproxy;
	struct signal_struct___151 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___171 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___42 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___146 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___105 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___40 *splice_pipe;
	struct page_frag___170 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___171 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___105 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___105 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___171 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___105)(struct perf_event___105 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___105;

struct fasync_struct___170;

struct pid_namespace___135;

struct trace_event_call___98;

struct perf_cgroup___105;

struct perf_event___105 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___105 *group_leader;
	struct pmu___105 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___105 hw;
	struct perf_event_context___105 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___105 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___171 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___170 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___105 *);
	struct callback_head callback_head;
	struct pid_namespace___135 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___105 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___105 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___98 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___105 *cgrp;
	struct list_head sb_list;
};

struct dentry_operations___170;

struct super_block___170;

struct dentry___170 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___170 *d_parent;
	struct qstr d_name;
	struct inode___171 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___170 *d_op;
	struct super_block___170 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct rw_semaphore___171 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___171 *owner;
};

struct address_space_operations___170;

struct address_space___170 {
	struct inode___171 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___171 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___170 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___170;

struct block_device___171;

struct inode___171 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___170 *i_op;
	struct super_block___170 *i_sb;
	struct address_space___170 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___171 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___171 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___170 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___40 *i_pipe;
		struct block_device___171 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___170;

struct dentry_operations___170 {
	int (*d_revalidate)(struct dentry___170 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___170 *, unsigned int);
	int (*d_hash)(const struct dentry___170 *, struct qstr *);
	int (*d_compare)(const struct dentry___170 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___170 *);
	int (*d_init)(struct dentry___170 *);
	void (*d_release)(struct dentry___170 *);
	void (*d_prune)(struct dentry___170 *);
	void (*d_iput)(struct dentry___170 *, struct inode___171 *);
	char * (*d_dname)(struct dentry___170 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___170 *);
	int (*d_manage)(const struct path___170 *, bool);
	struct dentry___170 * (*d_real)(struct dentry___170 *, const struct inode___171 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___170;

struct mem_dqinfo___170 {
	struct quota_format_type___170 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___170;

struct quota_info___170 {
	unsigned int flags;
	struct rw_semaphore___171 dqio_sem;
	struct inode___171 *files[3];
	struct mem_dqinfo___170 info[3];
	const struct quota_format_ops___170 *ops[3];
};

struct rcuwait___170 {
	struct task_struct___171 *task;
};

struct percpu_rw_semaphore___170 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___171 rw_sem;
	struct rcuwait___170 writer;
	int readers_block;
};

struct sb_writers___170 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___170 rw_sem[3];
};

struct file_system_type___170;

struct super_operations___170;

struct dquot_operations___170;

struct quotactl_ops___170;

struct user_namespace___150;

struct super_block___170 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___170 *s_type;
	const struct super_operations___170 *s_op;
	const struct dquot_operations___170 *dq_op;
	const struct quotactl_ops___170 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___170 *s_root;
	struct rw_semaphore___171 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___171 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___170 s_dquot;
	struct sb_writers___170 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___170 *s_d_op;
	int cleancache_poolid;
	struct shrinker___76 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___150 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct path___170 {
	struct vfsmount *mnt;
	struct dentry___170 *dentry;
};

struct key___166;

struct ucounts___150;

struct user_namespace___150 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___150 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___4 ns;
	long unsigned int flags;
	struct key___166 *persistent_keyring_register;
	struct rw_semaphore___171 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___150 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___171 *pgtable_t___170;

struct dev_pagemap___168;

struct page___171 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___170 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___171 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___170 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___170 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___168 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___170;

struct lruvec___170 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___170 *pgdat;
};

struct zone___170 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___170 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___170 {
	struct zone___170 *zone;
	int zone_idx;
};

struct zonelist___170 {
	struct zoneref___170 _zonerefs[25];
};

struct pglist_data___170 {
	struct zone___170 node_zones[3];
	struct zonelist___170 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___171 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___171 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___170 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___171 {
	void *stack;
	struct task_struct___171 *task;
	long int status;
};

struct blocking_notifier_head___170 {
	struct rw_semaphore___171 rwsem;
	struct notifier_block *head;
};

struct upid___135 {
	int nr;
	struct pid_namespace___135 *ns;
};

struct pid_namespace___135 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___171 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___135 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___170 *proc_self;
	struct dentry___170 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___150 *user_ns;
	struct ucounts___150 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___4 ns;
};

struct pid___135 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___135 numbers[1];
};

struct vm_operations_struct___168;

struct vm_area_struct___171 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___171 *vm_next;
	struct vm_area_struct___171 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___170 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___168 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___171 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___170;

struct mm_struct___170 {
	struct {
		struct vm_area_struct___171 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___171 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___171 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___170 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___171 *owner;
		struct user_namespace___150 *user_ns;
		struct file___171 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___170 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___168)(struct vm_area_struct___171 *, long unsigned int, const struct page___171 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___168)(struct page___171 *, void *);

struct device___159;

struct dev_pagemap___168 {
	dev_page_fault_t___168 page_fault;
	dev_page_free_t___168 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___159 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct fown_struct___135 {
	rwlock_t lock;
	struct pid___135 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___171 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___170 f_path;
	struct inode___171 *f_inode;
	const struct file_operations___171 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___135 f_owner;
	const struct cred___166 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___170 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___168;

struct vm_operations_struct___168 {
	void (*open)(struct vm_area_struct___171 *);
	void (*close)(struct vm_area_struct___171 *);
	int (*split)(struct vm_area_struct___171 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___171 *);
	vm_fault_t (*fault)(struct vm_fault___168 *);
	vm_fault_t (*huge_fault)(struct vm_fault___168 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___168 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___171 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___168 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___168 *);
	int (*access)(struct vm_area_struct___171 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___171 *);
	int (*set_policy)(struct vm_area_struct___171 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___171 *, long unsigned int);
	struct page___171 * (*find_special_page)(struct vm_area_struct___171 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___170 {
	struct task_struct___171 *task;
	struct core_thread___170 *next;
};

struct core_state___170 {
	atomic_t nr_threads;
	struct core_thread___170 dumper;
	struct completion startup;
};

struct vm_fault___168 {
	struct vm_area_struct___171 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___171 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___171 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___170 prealloc_pte;
};

struct f_owner_ex {
	int type;
	__kernel_pid_t pid;
};

struct flock {
	short int l_type;
	short int l_whence;
	__kernel_off_t l_start;
	__kernel_off_t l_len;
	__kernel_pid_t l_pid;
};

struct user_struct___166 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___166 *uid_keyring;
	struct key___166 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___166 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___166 *session_keyring;
	struct key___166 *process_keyring;
	struct key___166 *thread_keyring;
	struct key___166 *request_key_auth;
	void *security;
	struct user_struct___166 *user;
	struct user_namespace___150 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct fdtable___9 {
	unsigned int max_fds;
	struct file___171 **fd;
	long unsigned int *close_on_exec;
	long unsigned int *open_fds;
	long unsigned int *full_fds_bits;
	struct callback_head rcu;
};

struct files_struct___9 {
	atomic_t count;
	bool resize_in_progress;
	wait_queue_head_t resize_wait;
	struct fdtable___9 *fdt;
	struct fdtable___9 fdtab;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t file_lock;
	unsigned int next_fd;
	long unsigned int close_on_exec_init[1];
	long unsigned int open_fds_init[1];
	long unsigned int full_fds_bits_init[1];
	struct file___171 *fd_array[64];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cgroup_namespace___146;

struct nsproxy___162 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___135 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___146 *cgroup_ns;
};

struct signal_struct___151 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___171 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___171 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___135 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___135 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___170 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___135 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___146;

struct cgroup___146;

struct css_set___146 {
	struct cgroup_subsys_state___146 *subsys[13];
	refcount_t refcount;
	struct css_set___146 *dom_cset;
	struct cgroup___146 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___146 *mg_src_cgrp;
	struct cgroup___146 *mg_dst_cgrp;
	struct css_set___146 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___105 {
	struct pmu___105 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___171 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___105 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___40;

struct pipe_inode_info___40 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___171 *tmp_page;
	struct fasync_struct___170 *fasync_readers;
	struct fasync_struct___170 *fasync_writers;
	struct pipe_buffer___40 *bufs;
	struct user_struct___166 *user;
};

union thread_union___152 {
	struct task_struct___171 task;
	long unsigned int stack[8192];
};

struct kiocb___171 {
	struct file___171 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___171 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___170 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___171 *ia_file;
};

struct dquot___170 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___170 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___170 {
	int qf_fmt_id;
	const struct quota_format_ops___170 *qf_ops;
	struct module___145 *qf_owner;
	struct quota_format_type___170 *qf_next;
};

struct quota_format_ops___170 {
	int (*check_quota_file)(struct super_block___170 *, int);
	int (*read_file_info)(struct super_block___170 *, int);
	int (*write_file_info)(struct super_block___170 *, int);
	int (*free_file_info)(struct super_block___170 *, int);
	int (*read_dqblk)(struct dquot___170 *);
	int (*commit_dqblk)(struct dquot___170 *);
	int (*release_dqblk)(struct dquot___170 *);
	int (*get_next_id)(struct super_block___170 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___170 {
	int (*write_dquot)(struct dquot___170 *);
	struct dquot___170 * (*alloc_dquot)(struct super_block___170 *, int);
	void (*destroy_dquot)(struct dquot___170 *);
	int (*acquire_dquot)(struct dquot___170 *);
	int (*release_dquot)(struct dquot___170 *);
	int (*mark_dirty)(struct dquot___170 *);
	int (*write_info)(struct super_block___170 *, int);
	qsize_t * (*get_reserved_space)(struct inode___171 *);
	int (*get_projid)(struct inode___171 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___171 *, qsize_t *);
	int (*get_next_id)(struct super_block___170 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___170 {
	int (*quota_on)(struct super_block___170 *, int, int, const struct path___170 *);
	int (*quota_off)(struct super_block___170 *, int);
	int (*quota_enable)(struct super_block___170 *, unsigned int);
	int (*quota_disable)(struct super_block___170 *, unsigned int);
	int (*quota_sync)(struct super_block___170 *, int);
	int (*set_info)(struct super_block___170 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___170 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___170 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___170 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___170 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___170 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___164;

struct kobj_type___164;

struct kernfs_node___167;

struct kobject___165 {
	const char *name;
	struct list_head entry;
	struct kobject___165 *parent;
	struct kset___164 *kset;
	struct kobj_type___164 *ktype;
	struct kernfs_node___167 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___142 {
	struct kobject___165 kobj;
	struct module___145 *mod;
	struct kobject___165 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___142 {
	struct module___145 *mod;
	struct latch_tree_node node;
};

struct module_layout___142 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___142 mtn;
};

struct module_attribute___142;

struct kernel_param___142;

struct module___145 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___142 mkobj;
	struct module_attribute___142 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___165 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___142 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___142 core_layout;
	struct module_layout___142 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___98 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___170 {
	int (*writepage)(struct page___171 *, struct writeback_control___3 *);
	int (*readpage)(struct file___171 *, struct page___171 *);
	int (*writepages)(struct address_space___170 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___171 *);
	int (*readpages)(struct file___171 *, struct address_space___170 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___171 *, struct address_space___170 *, loff_t, unsigned int, unsigned int, struct page___171 **, void **);
	int (*write_end)(struct file___171 *, struct address_space___170 *, loff_t, unsigned int, unsigned int, struct page___171 *, void *);
	sector_t (*bmap)(struct address_space___170 *, sector_t);
	void (*invalidatepage)(struct page___171 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___171 *, gfp_t);
	void (*freepage)(struct page___171 *);
	ssize_t (*direct_IO)(struct kiocb___171 *, struct iov_iter___81 *);
	int (*migratepage)(struct address_space___170 *, struct page___171 *, struct page___171 *, enum migrate_mode);
	bool (*isolate_page)(struct page___171 *, isolate_mode_t);
	void (*putback_page)(struct page___171 *);
	int (*launder_page)(struct page___171 *);
	int (*is_partially_uptodate)(struct page___171 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___171 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___170 *, struct page___171 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___171 *, sector_t *);
	void (*swap_deactivate)(struct file___171 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct iov_iter___81 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___3 *bvec;
		struct pipe_inode_info___40 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___171 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___171 *bd_inode;
	struct super_block___170 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___171 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___170 {
	struct dentry___170 * (*lookup)(struct inode___171 *, struct dentry___170 *, unsigned int);
	const char * (*get_link)(struct dentry___170 *, struct inode___171 *, struct delayed_call *);
	int (*permission)(struct inode___171 *, int);
	struct posix_acl * (*get_acl)(struct inode___171 *, int);
	int (*readlink)(struct dentry___170 *, char *, int);
	int (*create)(struct inode___171 *, struct dentry___170 *, umode_t, bool);
	int (*link)(struct dentry___170 *, struct inode___171 *, struct dentry___170 *);
	int (*unlink)(struct inode___171 *, struct dentry___170 *);
	int (*symlink)(struct inode___171 *, struct dentry___170 *, const char *);
	int (*mkdir)(struct inode___171 *, struct dentry___170 *, umode_t);
	int (*rmdir)(struct inode___171 *, struct dentry___170 *);
	int (*mknod)(struct inode___171 *, struct dentry___170 *, umode_t, dev_t);
	int (*rename)(struct inode___171 *, struct dentry___170 *, struct inode___171 *, struct dentry___170 *, unsigned int);
	int (*setattr)(struct dentry___170 *, struct iattr___170 *);
	int (*getattr)(const struct path___170 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___170 *, char *, size_t);
	int (*fiemap)(struct inode___171 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___171 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___171 *, struct dentry___170 *, struct file___171 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___171 *, struct dentry___170 *, umode_t);
	int (*set_acl)(struct inode___171 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___170 {
	void (*fl_copy_lock)(struct file_lock___171 *, struct file_lock___171 *);
	void (*fl_release_private)(struct file_lock___171 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___170;

struct file_lock___171 {
	struct file_lock___171 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___171 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___170 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___170 *fl_ops;
	const struct lock_manager_operations___170 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___170 {
	int (*lm_compare_owner)(struct file_lock___171 *, struct file_lock___171 *);
	long unsigned int (*lm_owner_key)(struct file_lock___171 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___171 *);
	int (*lm_grant)(struct file_lock___171 *, int);
	bool (*lm_break)(struct file_lock___171 *);
	int (*lm_change)(struct file_lock___171 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___171 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___170 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___170 *fa_next;
	struct file___171 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___170 {
	const char *name;
	int fs_flags;
	struct dentry___170 * (*mount)(struct file_system_type___170 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___170 *);
	struct module___145 *owner;
	struct file_system_type___170 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___170 {
	struct inode___171 * (*alloc_inode)(struct super_block___170 *);
	void (*destroy_inode)(struct inode___171 *);
	void (*dirty_inode)(struct inode___171 *, int);
	int (*write_inode)(struct inode___171 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___171 *);
	void (*evict_inode)(struct inode___171 *);
	void (*put_super)(struct super_block___170 *);
	int (*sync_fs)(struct super_block___170 *, int);
	int (*freeze_super)(struct super_block___170 *);
	int (*freeze_fs)(struct super_block___170 *);
	int (*thaw_super)(struct super_block___170 *);
	int (*unfreeze_fs)(struct super_block___170 *);
	int (*statfs)(struct dentry___170 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___170 *, int *, char *);
	void (*umount_begin)(struct super_block___170 *);
	int (*show_options)(struct seq_file___161 *, struct dentry___170 *);
	int (*show_devname)(struct seq_file___161 *, struct dentry___170 *);
	int (*show_path)(struct seq_file___161 *, struct dentry___170 *);
	int (*show_stats)(struct seq_file___161 *, struct dentry___170 *);
	ssize_t (*quota_read)(struct super_block___170 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___170 *, int, const char *, size_t, loff_t);
	struct dquot___170 ** (*get_dquots)(struct inode___171 *);
	int (*bdev_try_to_free_page)(struct super_block___170 *, struct page___171 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___170 *, struct shrink_control___76 *);
	long int (*free_cached_objects)(struct super_block___170 *, struct shrink_control___76 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___114)(struct file___171 *, wait_queue_head_t *, struct poll_table_struct___115 *);

struct poll_table_struct___115 {
	poll_queue_proc___114 _qproc;
	__poll_t _key;
};

struct seq_operations___159;

struct seq_file___161 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___159 *op;
	int poll_event;
	const struct file___171 *file;
	void *private;
};

typedef int (*key_restrict_link_func_t___166)(struct key___166 *, const struct key_type *, const union key_payload *, struct key___166 *);

struct key_restriction___166;

struct key___166 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___171 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___166 *restrict_link;
};

struct key_restriction___166 {
	key_restrict_link_func_t___166 check;
	struct key___166 *key;
	struct key_type *keytype;
};

struct dev_pm_info___159 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___159 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___159;

struct bus_type___159;

struct device_driver___159;

struct dev_pm_domain___159;

struct class___159;

struct attribute_group___160;

struct device___159 {
	struct device___159 *parent;
	struct device_private *p;
	struct kobject___165 kobj;
	const char *init_name;
	const struct device_type___159 *type;
	struct mutex mutex;
	struct bus_type___159 *bus;
	struct device_driver___159 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___159 power;
	struct dev_pm_domain___159 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___159 *class;
	const struct attribute_group___160 **groups;
	void (*release)(struct device___159 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct kobj_attribute___165 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___165 *, struct kobj_attribute___165 *, char *);
	ssize_t (*store)(struct kobject___165 *, struct kobj_attribute___165 *, const char *, size_t);
};

typedef void compound_page_dtor___168(struct page___171 *);

struct seq_operations___159 {
	void * (*start)(struct seq_file___161 *, loff_t *);
	void (*stop)(struct seq_file___161 *, void *);
	void * (*next)(struct seq_file___161 *, void *, loff_t *);
	int (*show)(struct seq_file___161 *, void *);
};

struct cgroup_namespace___146 {
	refcount_t count;
	struct ns_common___4 ns;
	struct user_namespace___150 *user_ns;
	struct ucounts___150 *ucounts;
	struct css_set___146 *root_cset;
};

struct ucounts___150 {
	struct hlist_node node;
	struct user_namespace___150 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct kernfs_root___167;

struct kernfs_elem_dir___167 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___167 *root;
};

struct kernfs_syscall_ops___167;

struct kernfs_root___167 {
	struct kernfs_node___167 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___167 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___167 {
	struct kernfs_node___167 *target_kn;
};

struct kernfs_ops___167;

struct kernfs_elem_attr___167 {
	const struct kernfs_ops___167 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___167 *notify_next;
};

struct kernfs_node___167 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___167 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___167 dir;
		struct kernfs_elem_symlink___167 symlink;
		struct kernfs_elem_attr___167 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___167;

struct kernfs_ops___167 {
	int (*open)(struct kernfs_open_file___167 *);
	void (*release)(struct kernfs_open_file___167 *);
	int (*seq_show)(struct seq_file___161 *, void *);
	void * (*seq_start)(struct seq_file___161 *, loff_t *);
	void * (*seq_next)(struct seq_file___161 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___161 *, void *);
	ssize_t (*read)(struct kernfs_open_file___167 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___167 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___167 *, struct vm_area_struct___171 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___167 *, struct poll_table_struct___115 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___167 {
	int (*remount_fs)(struct kernfs_root___167 *, int *, char *);
	int (*show_options)(struct seq_file___161 *, struct kernfs_root___167 *);
	int (*mkdir)(struct kernfs_node___167 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___167 *);
	int (*rename)(struct kernfs_node___167 *, struct kernfs_node___167 *, const char *);
	int (*show_path)(struct seq_file___161 *, struct kernfs_node___167 *, struct kernfs_root___167 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___167 {
	struct kernfs_node___167 *kn;
	struct file___171 *file;
	struct seq_file___161 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___168 *vm_ops;
};

struct bin_attribute___159;

struct attribute_group___160 {
	const char *name;
	umode_t (*is_visible)(struct kobject___165 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___165 *, struct bin_attribute___159 *, int);
	struct attribute **attrs;
	struct bin_attribute___159 **bin_attrs;
};

struct bin_attribute___159 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___171 *, struct kobject___165 *, struct bin_attribute___159 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___171 *, struct kobject___165 *, struct bin_attribute___159 *, char *, loff_t, size_t);
	int (*mmap)(struct file___171 *, struct kobject___165 *, struct bin_attribute___159 *, struct vm_area_struct___171 *);
};

struct sysfs_ops___164 {
	ssize_t (*show)(struct kobject___165 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___165 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___164;

struct kset___164 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___165 kobj;
	const struct kset_uevent_ops___164 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___164 {
	void (*release)(struct kobject___165 *);
	const struct sysfs_ops___164 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___10 * (*child_ns_type)(struct kobject___165 *);
	const void * (*namespace)(struct kobject___165 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___164 {
	int (* const filter)(struct kset___164 *, struct kobject___165 *);
	const char * (* const name)(struct kset___164 *, struct kobject___165 *);
	int (* const uevent)(struct kset___164 *, struct kobject___165 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___142 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___142 *);
	int (*get)(char *, const struct kernel_param___142 *);
	void (*free)(void *);
};

struct kparam_array___142;

struct kernel_param___142 {
	const char *name;
	struct module___145 *mod;
	const struct kernel_param_ops___142 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___142 *arr;
	};
};

struct kparam_array___142 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___142 *ops;
	void *elem;
};

struct module_attribute___142 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___142 *, struct module_kobject___142 *, char *);
	ssize_t (*store)(struct module_attribute___142 *, struct module_kobject___142 *, const char *, size_t);
	void (*setup)(struct module___145 *, const char *);
	int (*test)(struct module___145 *);
	void (*free)(struct module___145 *);
};

struct trace_event_class___98;

struct trace_event_call___98 {
	struct list_head list;
	struct trace_event_class___98 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___20 *prog_array;
	int (*perf_perm)(struct trace_event_call___98 *, struct perf_event___105 *);
};

struct dev_pm_ops___159 {
	int (*prepare)(struct device___159 *);
	void (*complete)(struct device___159 *);
	int (*suspend)(struct device___159 *);
	int (*resume)(struct device___159 *);
	int (*freeze)(struct device___159 *);
	int (*thaw)(struct device___159 *);
	int (*poweroff)(struct device___159 *);
	int (*restore)(struct device___159 *);
	int (*suspend_late)(struct device___159 *);
	int (*resume_early)(struct device___159 *);
	int (*freeze_late)(struct device___159 *);
	int (*thaw_early)(struct device___159 *);
	int (*poweroff_late)(struct device___159 *);
	int (*restore_early)(struct device___159 *);
	int (*suspend_noirq)(struct device___159 *);
	int (*resume_noirq)(struct device___159 *);
	int (*freeze_noirq)(struct device___159 *);
	int (*thaw_noirq)(struct device___159 *);
	int (*poweroff_noirq)(struct device___159 *);
	int (*restore_noirq)(struct device___159 *);
	int (*runtime_suspend)(struct device___159 *);
	int (*runtime_resume)(struct device___159 *);
	int (*runtime_idle)(struct device___159 *);
};

struct dev_pm_domain___159 {
	struct dev_pm_ops___159 ops;
	void (*detach)(struct device___159 *, bool);
	int (*activate)(struct device___159 *);
	void (*sync)(struct device___159 *);
	void (*dismiss)(struct device___159 *);
};

struct bus_type___159 {
	const char *name;
	const char *dev_name;
	struct device___159 *dev_root;
	const struct attribute_group___160 **bus_groups;
	const struct attribute_group___160 **dev_groups;
	const struct attribute_group___160 **drv_groups;
	int (*match)(struct device___159 *, struct device_driver___159 *);
	int (*uevent)(struct device___159 *, struct kobj_uevent_env *);
	int (*probe)(struct device___159 *);
	int (*remove)(struct device___159 *);
	void (*shutdown)(struct device___159 *);
	int (*online)(struct device___159 *);
	int (*offline)(struct device___159 *);
	int (*suspend)(struct device___159 *, pm_message_t);
	int (*resume)(struct device___159 *);
	int (*num_vf)(struct device___159 *);
	int (*dma_configure)(struct device___159 *);
	const struct dev_pm_ops___159 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___159 {
	const char *name;
	struct bus_type___159 *bus;
	struct module___145 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___159 *);
	int (*remove)(struct device___159 *);
	void (*shutdown)(struct device___159 *);
	int (*suspend)(struct device___159 *, pm_message_t);
	int (*resume)(struct device___159 *);
	const struct attribute_group___160 **groups;
	const struct dev_pm_ops___159 *pm;
	void (*coredump)(struct device___159 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___159 {
	const char *name;
	const struct attribute_group___160 **groups;
	int (*uevent)(struct device___159 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___159 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___159 *);
	const struct dev_pm_ops___159 *pm;
};

struct class___159 {
	const char *name;
	struct module___145 *owner;
	const struct attribute_group___160 **class_groups;
	const struct attribute_group___160 **dev_groups;
	struct kobject___165 *dev_kobj;
	int (*dev_uevent)(struct device___159 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___159 *, umode_t *);
	void (*class_release)(struct class___159 *);
	void (*dev_release)(struct device___159 *);
	int (*shutdown_pre)(struct device___159 *);
	const struct kobj_ns_type_operations___10 *ns_type;
	const void * (*namespace)(struct device___159 *);
	const struct dev_pm_ops___159 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___135 {
	struct device___159 dev;
};

struct fd___15 {
	struct file___171 *file;
	unsigned int flags;
};

struct bpf_map___146;

struct bpf_map_ops___146 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___146 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___146 *, struct file___171 *);
	void (*map_free)(struct bpf_map___146 *);
	int (*map_get_next_key)(struct bpf_map___146 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___146 *);
	void * (*map_lookup_elem)(struct bpf_map___146 *, void *);
	int (*map_update_elem)(struct bpf_map___146 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___146 *, void *);
	int (*map_push_elem)(struct bpf_map___146 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___146 *, void *);
	int (*map_peek_elem)(struct bpf_map___146 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___146 *, struct file___171 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___146 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___146 *, void *, struct seq_file___161 *);
	int (*map_check_btf)(const struct bpf_map___146 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___146 {
	const struct bpf_map_ops___146 *ops;
	struct bpf_map___146 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___166 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___146;

typedef void (*kthread_work_func_t___146)(struct kthread_work___146 *);

struct kthread_worker___146;

struct kthread_work___146 {
	struct list_head node;
	kthread_work_func_t___146 func;
	struct kthread_worker___146 *worker;
	int canceling;
};

struct kthread_worker___146 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___171 *task;
	struct kthread_work___146 *current_work;
};

struct kthread_delayed_work___146 {
	struct kthread_work___146 work;
	struct timer_list timer;
};

struct psi_group___146 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___146 *poll_kworker;
	struct kthread_delayed_work___146 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___146 {
	struct kernfs_node___167 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___146;

struct cgroup_subsys_state___146 {
	struct cgroup___146 *cgroup;
	struct cgroup_subsys___146 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___146 *parent;
};

struct cgroup_root___146;

struct cgroup_rstat_cpu___146;

struct cgroup___146 {
	struct cgroup_subsys_state___146 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___167 *kn;
	struct cgroup_file___146 procs_file;
	struct cgroup_file___146 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___146 *subsys[13];
	struct cgroup_root___146 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___146 *dom_cgrp;
	struct cgroup_rstat_cpu___146 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___20 bpf;
	atomic_t congestion_count;
	struct cgroup___146 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___146 psi;
	int ancestor_ids[0];
};

struct cftype___146;

struct cgroup_subsys___146 {
	struct cgroup_subsys_state___146 * (*css_alloc)(struct cgroup_subsys_state___146 *);
	int (*css_online)(struct cgroup_subsys_state___146 *);
	void (*css_offline)(struct cgroup_subsys_state___146 *);
	void (*css_released)(struct cgroup_subsys_state___146 *);
	void (*css_free)(struct cgroup_subsys_state___146 *);
	void (*css_reset)(struct cgroup_subsys_state___146 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___146 *, int);
	int (*css_extra_stat_show)(struct seq_file___161 *, struct cgroup_subsys_state___146 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___171 *);
	void (*cancel_fork)(struct task_struct___171 *);
	void (*fork)(struct task_struct___171 *);
	void (*exit)(struct task_struct___171 *);
	void (*free)(struct task_struct___171 *);
	void (*bind)(struct cgroup_subsys_state___146 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___146 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___146 *dfl_cftypes;
	struct cftype___146 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___146 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___146 *updated_children;
	struct cgroup___146 *updated_next;
};

struct cgroup_root___146 {
	struct kernfs_root___167 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___146 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___146 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___146 *ss;
	struct list_head node;
	struct kernfs_ops___167 *kf_ops;
	int (*open)(struct kernfs_open_file___167 *);
	void (*release)(struct kernfs_open_file___167 *);
	u64 (*read_u64)(struct cgroup_subsys_state___146 *, struct cftype___146 *);
	s64 (*read_s64)(struct cgroup_subsys_state___146 *, struct cftype___146 *);
	int (*seq_show)(struct seq_file___161 *, void *);
	void * (*seq_start)(struct seq_file___161 *, loff_t *);
	void * (*seq_next)(struct seq_file___161 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___161 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___146 *, struct cftype___146 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___146 *, struct cftype___146 *, s64);
	ssize_t (*write)(struct kernfs_open_file___167 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___167 *, struct poll_table_struct___115 *);
};

struct perf_cpu_context___105;

struct pmu___105 {
	struct list_head entry;
	struct module___145 *module;
	struct device___159 *dev;
	const struct attribute_group___160 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___105 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___105 *);
	void (*pmu_disable)(struct pmu___105 *);
	int (*event_init)(struct perf_event___105 *);
	void (*event_mapped)(struct perf_event___105 *, struct mm_struct___170 *);
	void (*event_unmapped)(struct perf_event___105 *, struct mm_struct___170 *);
	int (*add)(struct perf_event___105 *, int);
	void (*del)(struct perf_event___105 *, int);
	void (*start)(struct perf_event___105 *, int);
	void (*stop)(struct perf_event___105 *, int);
	void (*read)(struct perf_event___105 *);
	void (*start_txn)(struct pmu___105 *, unsigned int);
	int (*commit_txn)(struct pmu___105 *);
	void (*cancel_txn)(struct pmu___105 *);
	int (*event_idx)(struct perf_event___105 *);
	void (*sched_task)(struct perf_event_context___105 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___105 *);
	int (*filter_match)(struct perf_event___105 *);
	int (*check_period)(struct perf_event___105 *, u64);
};

struct perf_cpu_context___105 {
	struct perf_event_context___105 ctx;
	struct perf_event_context___105 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___105 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___105 {
	struct cgroup_subsys_state___146 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___98 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___98 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___98 *);
	struct list_head * (*get_fields)(struct trace_event_call___98 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___98 *);
};

struct syscall_metadata___44 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___98 *enter_event;
	struct trace_event_call___98 *exit_event;
};

struct pipe_buf_operations___40;

struct pipe_buffer___40 {
	struct page___171 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___40 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___40 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___40 *, struct pipe_buffer___40 *);
	void (*release)(struct pipe_inode_info___40 *, struct pipe_buffer___40 *);
	int (*steal)(struct pipe_inode_info___40 *, struct pipe_buffer___40 *);
	union {
		bool (*get)(struct pipe_inode_info___40 *, struct pipe_buffer___40 *);
		struct {
			void (*get)(struct pipe_inode_info___40 *, struct pipe_buffer___40 *);
		} __UNIQUE_ID_rh_kabi_hide21;
		union {		};
	};
};

struct fiemap {
	__u64 fm_start;
	__u64 fm_length;
	__u32 fm_flags;
	__u32 fm_mapped_extents;
	__u32 fm_extent_count;
	__u32 fm_reserved;
	struct fiemap_extent fm_extents[0];
};

struct file_clone_range {
	__s64 src_fd;
	__u64 src_offset;
	__u64 src_length;
	__u64 dest_offset;
};

struct buffer_head___2;

typedef int get_block_t(struct inode___150 *, sector_t, struct buffer_head___2 *, int);

typedef void bh_end_io_t___2(struct buffer_head___2 *, int);

struct buffer_head___2 {
	long unsigned int b_state;
	struct buffer_head___2 *b_this_page;
	struct page___150 *b_page;
	sector_t b_blocknr;
	size_t b_size;
	char *b_data;
	struct block_device___150 *b_bdev;
	bh_end_io_t___2 *b_end_io;
	void *b_private;
	struct list_head b_assoc_buffers;
	struct address_space___149 *b_assoc_map;
	atomic_t b_count;
};

struct fd___16 {
	struct file___150 *file;
	unsigned int flags;
};

struct space_resv {
	__s16 l_type;
	__s16 l_whence;
	__s64 l_start;
	__s64 l_len;
	__s32 l_sysid;
	__u32 l_pid;
	__s32 l_pad[4];
};

struct fd___17 {
	struct file___39 *file;
	unsigned int flags;
};

struct linux_dirent64 {
	u64 d_ino;
	s64 d_off;
	short unsigned int d_reclen;
	unsigned char d_type;
	char d_name[0];
};

struct linux_dirent {
	long unsigned int d_ino;
	long unsigned int d_off;
	short unsigned int d_reclen;
	char d_name[1];
};

struct getdents_callback {
	struct dir_context ctx;
	struct linux_dirent *current_dir;
	struct linux_dirent *previous;
	int count;
	int error;
};

struct getdents_callback64 {
	struct dir_context ctx;
	struct linux_dirent64 *current_dir;
	struct linux_dirent64 *previous;
	int count;
	int error;
};

typedef struct {
	long unsigned int fds_bits[16];
} __kernel_fd_set;

typedef __kernel_fd_set fd_set;

struct module___146;

struct file___172;

struct kiocb___172;

struct iov_iter___82;

struct poll_table_struct___116;

struct vm_area_struct___172;

struct inode___172;

struct file_lock___172;

struct page___172;

struct pipe_inode_info___41;

struct seq_file___162;

struct file_operations___172 {
	struct module___146 *owner;
	loff_t (*llseek)(struct file___172 *, loff_t, int);
	ssize_t (*read)(struct file___172 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___172 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___172 *, struct iov_iter___82 *);
	ssize_t (*write_iter)(struct kiocb___172 *, struct iov_iter___82 *);
	int (*iopoll)(struct kiocb___172 *, bool);
	int (*iterate)(struct file___172 *, struct dir_context *);
	int (*iterate_shared)(struct file___172 *, struct dir_context *);
	__poll_t (*poll)(struct file___172 *, struct poll_table_struct___116 *);
	long int (*unlocked_ioctl)(struct file___172 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___172 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___172 *, struct vm_area_struct___172 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___172 *, struct file___172 *);
	int (*flush)(struct file___172 *, fl_owner_t);
	int (*release)(struct inode___172 *, struct file___172 *);
	int (*fsync)(struct file___172 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___172 *, int);
	int (*lock)(struct file___172 *, int, struct file_lock___172 *);
	ssize_t (*sendpage)(struct file___172 *, struct page___172 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___172 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___172 *, int, struct file_lock___172 *);
	ssize_t (*splice_write)(struct pipe_inode_info___41 *, struct file___172 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___172 *, loff_t *, struct pipe_inode_info___41 *, size_t, unsigned int);
	int (*setlease)(struct file___172 *, long int, struct file_lock___172 **, void **);
	long int (*fallocate)(struct file___172 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___162 *, struct file___172 *);
	ssize_t (*copy_file_range)(struct file___172 *, loff_t, struct file___172 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___172 *, loff_t, struct file___172 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___172 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___171 {
	u64 seqnum;
	struct vm_area_struct___172 *vmas[4];
};

struct page_frag___171 {
	struct page___172 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___106;

struct debug_info___106 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___106 *hbp_break[16];
	struct perf_event___106 *hbp_watch[16];
};

struct thread_struct___106 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___106 debug;
	long: 64;
};

struct mm_struct___171;

struct mem_cgroup___77;

struct pid___136;

struct cred___167;

struct files_struct___10;

struct nsproxy___163;

struct signal_struct___152;

struct bio_list___85;

struct backing_dev_info___85;

struct css_set___147;

struct perf_event_context___106;

struct vm_struct___124;

struct task_struct___172 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___172 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___171 *mm;
	struct mm_struct___171 *active_mm;
	struct vmacache___171 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___172 *real_parent;
	struct task_struct___172 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___172 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___77 *active_memcg;
	long int rh_reserved2;
	struct pid___136 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___136 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___136 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___167 *ptracer_cred;
	const struct cred___167 *real_cred;
	const struct cred___167 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct___10 *files;
	struct nsproxy___163 *nsproxy;
	struct signal_struct___152 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___172 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___85 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___85 *backing_dev_info;
	struct io_context___42 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___147 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___106 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___41 *splice_pipe;
	struct page_frag___171 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___77 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___172 *oom_reaper_list;
	struct vm_struct___124 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___106 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___106 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___172 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___106)(struct perf_event___106 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___106;

struct fasync_struct___171;

struct pid_namespace___136;

struct bpf_prog___21;

struct trace_event_call___99;

struct perf_cgroup___106;

struct perf_event___106 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___106 *group_leader;
	struct pmu___106 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___106 hw;
	struct perf_event_context___106 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___106 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___172 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___171 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___106 *);
	struct callback_head callback_head;
	struct pid_namespace___136 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___106 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___106 orig_overflow_handler;
	struct bpf_prog___21 *prog;
	struct trace_event_call___99 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___106 *cgrp;
	struct list_head sb_list;
};

struct key___167;

struct user_struct___167 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___167 *uid_keyring;
	struct key___167 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct upid___136 {
	int nr;
	struct pid_namespace___136 *ns;
};

struct dentry___171;

struct user_namespace___151;

struct ucounts___151;

struct pid_namespace___136 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___172 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___136 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___171 *proc_self;
	struct dentry___171 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___151 *user_ns;
	struct ucounts___151 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___4 ns;
};

struct pid___136 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___136 numbers[1];
};

struct rw_semaphore___172 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___172 *owner;
};

struct user_namespace___151 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___151 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___4 ns;
	long unsigned int flags;
	struct key___167 *persistent_keyring_register;
	struct rw_semaphore___172 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___151 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct secondary_data___172 {
	void *stack;
	struct task_struct___172 *task;
	long int status;
};

typedef struct page___172 *pgtable_t___171;

struct address_space___171;

struct dev_pagemap___169;

struct page___172 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___171 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___172 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___171 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___171 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___169 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___77 *mem_cgroup;
};

struct vm_operations_struct___169;

struct vm_area_struct___172 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___172 *vm_next;
	struct vm_area_struct___172 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___171 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___169 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___172 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___171;

struct mm_struct___171 {
	struct {
		struct vm_area_struct___172 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___172 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___172 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___171 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___172 *owner;
		struct user_namespace___151 *user_ns;
		struct file___172 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___171 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup___147;

struct cgroup_subsys___147;

struct cgroup_subsys_state___147 {
	struct cgroup___147 *cgroup;
	struct cgroup_subsys___147 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___147 *parent;
};

struct kernfs_node___168;

struct cgroup_file___147 {
	struct kernfs_node___168 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___77;

struct mem_cgroup___77 {
	struct cgroup_subsys_state___147 css;
	struct mem_cgroup_id___14 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___147 events_file;
	struct cgroup_file___147 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___172 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___77 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cred___167 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___167 *session_keyring;
	struct key___167 *process_keyring;
	struct key___167 *thread_keyring;
	struct key___167 *request_key_auth;
	void *security;
	struct user_struct___167 *user;
	struct user_namespace___151 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct fdtable___10 {
	unsigned int max_fds;
	struct file___172 **fd;
	long unsigned int *close_on_exec;
	long unsigned int *open_fds;
	long unsigned int *full_fds_bits;
	struct callback_head rcu;
};

struct files_struct___10 {
	atomic_t count;
	bool resize_in_progress;
	wait_queue_head_t resize_wait;
	struct fdtable___10 *fdt;
	struct fdtable___10 fdtab;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t file_lock;
	unsigned int next_fd;
	long unsigned int close_on_exec_init[1];
	long unsigned int open_fds_init[1];
	long unsigned int full_fds_bits_init[1];
	struct file___172 *fd_array[64];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net___32;

struct cgroup_namespace___147;

struct nsproxy___163 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___136 *pid_ns_for_children;
	struct net___32 *net_ns;
	struct cgroup_namespace___147 *cgroup_ns;
};

struct signal_struct___152 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___172 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___172 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___136 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___136 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___171 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___136 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___85;

struct bio_list___85 {
	struct bio___85 *head;
	struct bio___85 *tail;
};

struct bdi_writeback_congested___85;

struct bdi_writeback___85 {
	struct backing_dev_info___85 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___85 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___147 *memcg_css;
	struct cgroup_subsys_state___147 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___160;

struct backing_dev_info___85 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___85 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___160 *dev;
	struct device___160 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___171 *debug_dir;
	struct dentry___171 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___147 {
	struct cgroup_subsys_state___147 *subsys[13];
	refcount_t refcount;
	struct css_set___147 *dom_cset;
	struct cgroup___147 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___147 *mg_src_cgrp;
	struct cgroup___147 *mg_dst_cgrp;
	struct css_set___147 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___106 {
	struct pmu___106 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___172 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___106 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___41;

struct pipe_inode_info___41 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___172 *tmp_page;
	struct fasync_struct___171 *fasync_readers;
	struct fasync_struct___171 *fasync_writers;
	struct pipe_buffer___41 *bufs;
	struct user_struct___167 *user;
};

struct vm_struct___124 {
	struct vm_struct___124 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___172 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___153 {
	struct task_struct___172 task;
	long unsigned int stack[8192];
};

typedef int (*key_restrict_link_func_t___167)(struct key___167 *, const struct key_type *, const union key_payload *, struct key___167 *);

struct key_restriction___167;

struct key___167 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___172 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___167 *restrict_link;
};

struct key_restriction___167 {
	key_restrict_link_func_t___167 check;
	struct key___167 *key;
	struct key_type *keytype;
};

struct dentry_operations___171;

struct super_block___171;

struct dentry___171 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___171 *d_parent;
	struct qstr d_name;
	struct inode___172 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___171 *d_op;
	struct super_block___171 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___171;

struct address_space___171 {
	struct inode___172 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___172 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___171 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___171;

struct block_device___172;

struct inode___172 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___171 *i_op;
	struct super_block___171 *i_sb;
	struct address_space___171 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___172 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___85 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___172 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___171 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___41 *i_pipe;
		struct block_device___172 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___171;

struct dentry_operations___171 {
	int (*d_revalidate)(struct dentry___171 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___171 *, unsigned int);
	int (*d_hash)(const struct dentry___171 *, struct qstr *);
	int (*d_compare)(const struct dentry___171 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___171 *);
	int (*d_init)(struct dentry___171 *);
	void (*d_release)(struct dentry___171 *);
	void (*d_prune)(struct dentry___171 *);
	void (*d_iput)(struct dentry___171 *, struct inode___172 *);
	char * (*d_dname)(struct dentry___171 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___171 *);
	int (*d_manage)(const struct path___171 *, bool);
	struct dentry___171 * (*d_real)(struct dentry___171 *, const struct inode___172 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___171;

struct mem_dqinfo___171 {
	struct quota_format_type___171 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___171;

struct quota_info___171 {
	unsigned int flags;
	struct rw_semaphore___172 dqio_sem;
	struct inode___172 *files[3];
	struct mem_dqinfo___171 info[3];
	const struct quota_format_ops___171 *ops[3];
};

struct rcuwait___171 {
	struct task_struct___172 *task;
};

struct percpu_rw_semaphore___171 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___172 rw_sem;
	struct rcuwait___171 writer;
	int readers_block;
};

struct sb_writers___171 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___171 rw_sem[3];
};

struct shrink_control___77;

struct shrinker___77 {
	long unsigned int (*count_objects)(struct shrinker___77 *, struct shrink_control___77 *);
	long unsigned int (*scan_objects)(struct shrinker___77 *, struct shrink_control___77 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___171;

struct super_operations___171;

struct dquot_operations___171;

struct quotactl_ops___171;

struct super_block___171 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___171 *s_type;
	const struct super_operations___171 *s_op;
	const struct dquot_operations___171 *dq_op;
	const struct quotactl_ops___171 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___171 *s_root;
	struct rw_semaphore___172 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___172 *s_bdev;
	struct backing_dev_info___85 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___171 s_dquot;
	struct sb_writers___171 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___171 *s_d_op;
	int cleancache_poolid;
	struct shrinker___77 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___151 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct path___171 {
	struct vfsmount *mnt;
	struct dentry___171 *dentry;
};

struct shrink_control___77 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___77 *memcg;
};

struct pglist_data___171;

struct lruvec___171 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___171 *pgdat;
};

struct zone___171 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___171 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___171 {
	struct zone___171 *zone;
	int zone_idx;
};

struct zonelist___171 {
	struct zoneref___171 _zonerefs[25];
};

struct pglist_data___171 {
	struct zone___171 node_zones[3];
	struct zonelist___171 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___172 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___172 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___171 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___171 {
	struct rw_semaphore___172 rwsem;
	struct notifier_block *head;
};

typedef int (*dev_page_fault_t___169)(struct vm_area_struct___172 *, long unsigned int, const struct page___172 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___169)(struct page___172 *, void *);

struct dev_pagemap___169 {
	dev_page_fault_t___169 page_fault;
	dev_page_free_t___169 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___160 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct fown_struct___136 {
	rwlock_t lock;
	struct pid___136 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___172 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___171 f_path;
	struct inode___172 *f_inode;
	const struct file_operations___172 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___136 f_owner;
	const struct cred___167 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___171 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___169;

struct vm_operations_struct___169 {
	void (*open)(struct vm_area_struct___172 *);
	void (*close)(struct vm_area_struct___172 *);
	int (*split)(struct vm_area_struct___172 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___172 *);
	vm_fault_t (*fault)(struct vm_fault___169 *);
	vm_fault_t (*huge_fault)(struct vm_fault___169 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___169 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___172 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___169 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___169 *);
	int (*access)(struct vm_area_struct___172 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___172 *);
	int (*set_policy)(struct vm_area_struct___172 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___172 *, long unsigned int);
	struct page___172 * (*find_special_page)(struct vm_area_struct___172 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___171 {
	struct task_struct___172 *task;
	struct core_thread___171 *next;
};

struct core_state___171 {
	atomic_t nr_threads;
	struct core_thread___171 dumper;
	struct completion startup;
};

struct vm_fault___169 {
	struct vm_area_struct___172 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___172 *cow_page;
	struct mem_cgroup___77 *memcg;
	struct page___172 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___171 prealloc_pte;
};

struct kiocb___172 {
	struct file___172 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___172 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___171 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___172 *ia_file;
};

struct dquot___171 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___171 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___171 {
	int qf_fmt_id;
	const struct quota_format_ops___171 *qf_ops;
	struct module___146 *qf_owner;
	struct quota_format_type___171 *qf_next;
};

struct quota_format_ops___171 {
	int (*check_quota_file)(struct super_block___171 *, int);
	int (*read_file_info)(struct super_block___171 *, int);
	int (*write_file_info)(struct super_block___171 *, int);
	int (*free_file_info)(struct super_block___171 *, int);
	int (*read_dqblk)(struct dquot___171 *);
	int (*commit_dqblk)(struct dquot___171 *);
	int (*release_dqblk)(struct dquot___171 *);
	int (*get_next_id)(struct super_block___171 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___171 {
	int (*write_dquot)(struct dquot___171 *);
	struct dquot___171 * (*alloc_dquot)(struct super_block___171 *, int);
	void (*destroy_dquot)(struct dquot___171 *);
	int (*acquire_dquot)(struct dquot___171 *);
	int (*release_dquot)(struct dquot___171 *);
	int (*mark_dirty)(struct dquot___171 *);
	int (*write_info)(struct super_block___171 *, int);
	qsize_t * (*get_reserved_space)(struct inode___172 *);
	int (*get_projid)(struct inode___172 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___172 *, qsize_t *);
	int (*get_next_id)(struct super_block___171 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___171 {
	int (*quota_on)(struct super_block___171 *, int, int, const struct path___171 *);
	int (*quota_off)(struct super_block___171 *, int);
	int (*quota_enable)(struct super_block___171 *, unsigned int);
	int (*quota_disable)(struct super_block___171 *, unsigned int);
	int (*quota_sync)(struct super_block___171 *, int);
	int (*set_info)(struct super_block___171 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___171 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___171 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___171 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___171 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___171 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___165;

struct kobj_type___165;

struct kobject___166 {
	const char *name;
	struct list_head entry;
	struct kobject___166 *parent;
	struct kset___165 *kset;
	struct kobj_type___165 *ktype;
	struct kernfs_node___168 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___143 {
	struct kobject___166 kobj;
	struct module___146 *mod;
	struct kobject___166 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___143 {
	struct module___146 *mod;
	struct latch_tree_node node;
};

struct module_layout___143 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___143 mtn;
};

struct module_attribute___143;

struct kernel_param___143;

struct module___146 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___143 mkobj;
	struct module_attribute___143 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___166 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___143 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___143 core_layout;
	struct module_layout___143 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___99 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___82;

struct address_space_operations___171 {
	int (*writepage)(struct page___172 *, struct writeback_control___82 *);
	int (*readpage)(struct file___172 *, struct page___172 *);
	int (*writepages)(struct address_space___171 *, struct writeback_control___82 *);
	int (*set_page_dirty)(struct page___172 *);
	int (*readpages)(struct file___172 *, struct address_space___171 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___172 *, struct address_space___171 *, loff_t, unsigned int, unsigned int, struct page___172 **, void **);
	int (*write_end)(struct file___172 *, struct address_space___171 *, loff_t, unsigned int, unsigned int, struct page___172 *, void *);
	sector_t (*bmap)(struct address_space___171 *, sector_t);
	void (*invalidatepage)(struct page___172 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___172 *, gfp_t);
	void (*freepage)(struct page___172 *);
	ssize_t (*direct_IO)(struct kiocb___172 *, struct iov_iter___82 *);
	int (*migratepage)(struct address_space___171 *, struct page___172 *, struct page___172 *, enum migrate_mode);
	bool (*isolate_page)(struct page___172 *, isolate_mode_t);
	void (*putback_page)(struct page___172 *);
	int (*launder_page)(struct page___172 *);
	int (*is_partially_uptodate)(struct page___172 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___172 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___171 *, struct page___172 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___172 *, sector_t *);
	void (*swap_deactivate)(struct file___172 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___82 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___85 *wb;
	struct inode___172 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___85;

struct iov_iter___82 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___85 *bvec;
		struct pipe_inode_info___41 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___172 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___172 *bd_inode;
	struct super_block___171 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___172 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___85 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___171 {
	struct dentry___171 * (*lookup)(struct inode___172 *, struct dentry___171 *, unsigned int);
	const char * (*get_link)(struct dentry___171 *, struct inode___172 *, struct delayed_call *);
	int (*permission)(struct inode___172 *, int);
	struct posix_acl * (*get_acl)(struct inode___172 *, int);
	int (*readlink)(struct dentry___171 *, char *, int);
	int (*create)(struct inode___172 *, struct dentry___171 *, umode_t, bool);
	int (*link)(struct dentry___171 *, struct inode___172 *, struct dentry___171 *);
	int (*unlink)(struct inode___172 *, struct dentry___171 *);
	int (*symlink)(struct inode___172 *, struct dentry___171 *, const char *);
	int (*mkdir)(struct inode___172 *, struct dentry___171 *, umode_t);
	int (*rmdir)(struct inode___172 *, struct dentry___171 *);
	int (*mknod)(struct inode___172 *, struct dentry___171 *, umode_t, dev_t);
	int (*rename)(struct inode___172 *, struct dentry___171 *, struct inode___172 *, struct dentry___171 *, unsigned int);
	int (*setattr)(struct dentry___171 *, struct iattr___171 *);
	int (*getattr)(const struct path___171 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___171 *, char *, size_t);
	int (*fiemap)(struct inode___172 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___172 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___172 *, struct dentry___171 *, struct file___172 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___172 *, struct dentry___171 *, umode_t);
	int (*set_acl)(struct inode___172 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___171 {
	void (*fl_copy_lock)(struct file_lock___172 *, struct file_lock___172 *);
	void (*fl_release_private)(struct file_lock___172 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___171;

struct file_lock___172 {
	struct file_lock___172 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___172 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___171 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___171 *fl_ops;
	const struct lock_manager_operations___171 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___171 {
	int (*lm_compare_owner)(struct file_lock___172 *, struct file_lock___172 *);
	long unsigned int (*lm_owner_key)(struct file_lock___172 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___172 *);
	int (*lm_grant)(struct file_lock___172 *, int);
	bool (*lm_break)(struct file_lock___172 *);
	int (*lm_change)(struct file_lock___172 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___172 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___171 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___171 *fa_next;
	struct file___172 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___171 {
	const char *name;
	int fs_flags;
	struct dentry___171 * (*mount)(struct file_system_type___171 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___171 *);
	struct module___146 *owner;
	struct file_system_type___171 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___171 {
	struct inode___172 * (*alloc_inode)(struct super_block___171 *);
	void (*destroy_inode)(struct inode___172 *);
	void (*dirty_inode)(struct inode___172 *, int);
	int (*write_inode)(struct inode___172 *, struct writeback_control___82 *);
	int (*drop_inode)(struct inode___172 *);
	void (*evict_inode)(struct inode___172 *);
	void (*put_super)(struct super_block___171 *);
	int (*sync_fs)(struct super_block___171 *, int);
	int (*freeze_super)(struct super_block___171 *);
	int (*freeze_fs)(struct super_block___171 *);
	int (*thaw_super)(struct super_block___171 *);
	int (*unfreeze_fs)(struct super_block___171 *);
	int (*statfs)(struct dentry___171 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___171 *, int *, char *);
	void (*umount_begin)(struct super_block___171 *);
	int (*show_options)(struct seq_file___162 *, struct dentry___171 *);
	int (*show_devname)(struct seq_file___162 *, struct dentry___171 *);
	int (*show_path)(struct seq_file___162 *, struct dentry___171 *);
	int (*show_stats)(struct seq_file___162 *, struct dentry___171 *);
	ssize_t (*quota_read)(struct super_block___171 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___171 *, int, const char *, size_t, loff_t);
	struct dquot___171 ** (*get_dquots)(struct inode___172 *);
	int (*bdev_try_to_free_page)(struct super_block___171 *, struct page___172 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___171 *, struct shrink_control___77 *);
	long int (*free_cached_objects)(struct super_block___171 *, struct shrink_control___77 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___115)(struct file___172 *, wait_queue_head_t *, struct poll_table_struct___116 *);

struct poll_table_struct___116 {
	poll_queue_proc___115 _qproc;
	__poll_t _key;
};

struct seq_operations___160;

struct seq_file___162 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___160 *op;
	int poll_event;
	const struct file___172 *file;
	void *private;
};

typedef void bio_end_io_t___85(struct bio___85 *);

struct bio_vec___85 {
	struct page___172 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___85;

struct bio_set___85;

struct bio___85 {
	struct bio___85 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___85 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___85 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___85 *bi_io_vec;
	struct bio_set___85 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___85 bi_inline_vecs[0];
};

struct dev_pm_info___160 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___160 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___160;

struct bus_type___160;

struct device_driver___160;

struct dev_pm_domain___160;

struct dma_map_ops___40;

struct fwnode_handle___113;

struct class___160;

struct attribute_group___161;

struct device___160 {
	struct device___160 *parent;
	struct device_private *p;
	struct kobject___166 kobj;
	const char *init_name;
	const struct device_type___160 *type;
	struct mutex mutex;
	struct bus_type___160 *bus;
	struct device_driver___160 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___160 power;
	struct dev_pm_domain___160 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___40 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___113 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___160 *class;
	const struct attribute_group___161 **groups;
	void (*release)(struct device___160 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct kobj_attribute___166 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___166 *, struct kobj_attribute___166 *, char *);
	ssize_t (*store)(struct kobject___166 *, struct kobj_attribute___166 *, const char *, size_t);
};

typedef void compound_page_dtor___169(struct page___172 *);

struct seq_operations___160 {
	void * (*start)(struct seq_file___162 *, loff_t *);
	void (*stop)(struct seq_file___162 *, void *);
	void * (*next)(struct seq_file___162 *, void *, loff_t *);
	int (*show)(struct seq_file___162 *, void *);
};

typedef struct poll_table_struct___116 poll_table___13;

struct poll_table_entry {
	struct file___172 *filp;
	__poll_t key;
	wait_queue_entry_t wait;
	wait_queue_head_t *wait_address;
};

struct poll_table_page;

struct poll_wqueues {
	poll_table___13 pt;
	struct poll_table_page *table;
	struct task_struct___172 *polling_task;
	int triggered;
	int error;
	int inline_index;
	struct poll_table_entry inline_entries[9];
};

struct poll_table_page {
	struct poll_table_page *next;
	struct poll_table_entry *entry;
	struct poll_table_entry entries[0];
};

struct inet_frags___22;

struct netns_frags___22 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___22 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ip_ra_chain___2;

struct fib_rules_ops___11;

struct sock___13;

struct fib_notifier_ops___11;

struct netns_ipv4___22 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___2 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___11 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___13 *fibnl;
	struct sock___13 **icmp_sk;
	struct sock___13 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___13 **tcp_sk;
	struct netns_frags___22 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___11 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___11 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___11 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct dst_entry___12;

struct net_device___26;

struct sk_buff___25;

struct neighbour___12;

struct dst_ops___30 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___30 *);
	struct dst_entry___12 * (*check)(struct dst_entry___12 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___12 *);
	unsigned int (*mtu)(const struct dst_entry___12 *);
	u32 * (*cow_metrics)(struct dst_entry___12 *, long unsigned int);
	void (*destroy)(struct dst_entry___12 *);
	void (*ifdown)(struct dst_entry___12 *, struct net_device___26 *, int);
	struct dst_entry___12 * (*negative_advice)(struct dst_entry___12 *);
	void (*link_failure)(struct sk_buff___25 *);
	void (*update_pmtu)(struct dst_entry___12 *, struct sock___13 *, struct sk_buff___25 *, u32);
	void (*redirect)(struct dst_entry___12 *, struct sock___13 *, struct sk_buff___25 *);
	int (*local_out)(struct net___32 *, struct sock___13 *, struct sk_buff___25 *);
	struct neighbour___12 * (*neigh_lookup)(const struct dst_entry___12 *, struct sk_buff___25 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___12 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___30 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___22 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___30 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___11 *fib6_rules_ops;
	struct sock___13 **icmp_sk;
	struct sock___13 *ndisc_sk;
	struct sock___13 *tcp_sk;
	struct sock___13 *igmp_sk;
	struct sock___13 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___11 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___11 *notifier_ops;
	struct fib_notifier_ops___11 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___11 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___13 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___22 {
	struct netns_frags___22 frags;
};

struct netns_xfrm___30 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___13 *nlsk;
	struct sock___13 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___30 xfrm4_dst_ops;
	struct dst_ops___30 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct net___32 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___151 *user_ns;
	struct ucounts___151 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___4 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___13 *rtnl;
	struct sock___13 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___26 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___22 ipv4;
	struct netns_ipv6___30 ipv6;
	struct netns_sctp___11 sctp;
	struct netns_nf nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___22 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___13 *nfnl;
	struct sock___13 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___30 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___13 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___21 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cgroup_namespace___147 {
	refcount_t count;
	struct ns_common___4 ns;
	struct user_namespace___151 *user_ns;
	struct ucounts___151 *ucounts;
	struct css_set___147 *root_cset;
};

struct ucounts___151 {
	struct hlist_node node;
	struct user_namespace___151 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct kernfs_root___168;

struct kernfs_elem_dir___168 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___168 *root;
};

struct kernfs_syscall_ops___168;

struct kernfs_root___168 {
	struct kernfs_node___168 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___168 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___168 {
	struct kernfs_node___168 *target_kn;
};

struct kernfs_ops___168;

struct kernfs_elem_attr___168 {
	const struct kernfs_ops___168 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___168 *notify_next;
};

struct kernfs_node___168 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___168 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___168 dir;
		struct kernfs_elem_symlink___168 symlink;
		struct kernfs_elem_attr___168 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___168;

struct kernfs_ops___168 {
	int (*open)(struct kernfs_open_file___168 *);
	void (*release)(struct kernfs_open_file___168 *);
	int (*seq_show)(struct seq_file___162 *, void *);
	void * (*seq_start)(struct seq_file___162 *, loff_t *);
	void * (*seq_next)(struct seq_file___162 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___162 *, void *);
	ssize_t (*read)(struct kernfs_open_file___168 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___168 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___168 *, struct vm_area_struct___172 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___168 *, struct poll_table_struct___116 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___168 {
	int (*remount_fs)(struct kernfs_root___168 *, int *, char *);
	int (*show_options)(struct seq_file___162 *, struct kernfs_root___168 *);
	int (*mkdir)(struct kernfs_node___168 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___168 *);
	int (*rename)(struct kernfs_node___168 *, struct kernfs_node___168 *, const char *);
	int (*show_path)(struct seq_file___162 *, struct kernfs_node___168 *, struct kernfs_root___168 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___168 {
	struct kernfs_node___168 *kn;
	struct file___172 *file;
	struct seq_file___162 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___169 *vm_ops;
};

struct kobj_ns_type_operations___11 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___13 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___32 *net;
} possible_net_t___23;

struct proto___11;

struct sock_common___11 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___11 *skc_prot;
	possible_net_t___23 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___13 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff_head___22 {
	struct sk_buff___25 *next;
	struct sk_buff___25 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___11;

struct socket_wq___11;

struct socket___11;

struct sock___13 {
	struct sock_common___11 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___22 sk_error_queue;
	struct sk_buff_head___22 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___25 *head;
		struct sk_buff___25 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___11 *sk_filter;
	union {
		struct socket_wq___11 *sk_wq;
		struct socket_wq___11 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___12 *sk_rx_dst;
	struct dst_entry___12 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___25 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___22 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___171 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___11 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___136 *sk_peer_pid;
	const struct cred___167 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___11 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___77 *sk_memcg;
	void (*sk_state_change)(struct sock___13 *);
	void (*sk_data_ready)(struct sock___13 *);
	void (*sk_write_space)(struct sock___13 *);
	void (*sk_error_report)(struct sock___13 *);
	int (*sk_backlog_rcv)(struct sock___13 *, struct sk_buff___25 *);
	struct sk_buff___25 * (*sk_validate_xmit_skb)(struct sock___13 *, struct net_device___26 *, struct sk_buff___25 *);
	void (*sk_destruct)(struct sock___13 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct bin_attribute___160;

struct attribute_group___161 {
	const char *name;
	umode_t (*is_visible)(struct kobject___166 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___166 *, struct bin_attribute___160 *, int);
	struct attribute **attrs;
	struct bin_attribute___160 **bin_attrs;
};

struct bin_attribute___160 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___172 *, struct kobject___166 *, struct bin_attribute___160 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___172 *, struct kobject___166 *, struct bin_attribute___160 *, char *, loff_t, size_t);
	int (*mmap)(struct file___172 *, struct kobject___166 *, struct bin_attribute___160 *, struct vm_area_struct___172 *);
};

struct sysfs_ops___165 {
	ssize_t (*show)(struct kobject___166 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___166 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___165;

struct kset___165 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___166 kobj;
	const struct kset_uevent_ops___165 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___165 {
	void (*release)(struct kobject___166 *);
	const struct sysfs_ops___165 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___11 * (*child_ns_type)(struct kobject___166 *);
	const void * (*namespace)(struct kobject___166 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___165 {
	int (* const filter)(struct kset___165 *, struct kobject___166 *);
	const char * (* const name)(struct kset___165 *, struct kobject___166 *);
	int (* const uevent)(struct kset___165 *, struct kobject___166 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___143 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___143 *);
	int (*get)(char *, const struct kernel_param___143 *);
	void (*free)(void *);
};

struct kparam_array___143;

struct kernel_param___143 {
	const char *name;
	struct module___146 *mod;
	const struct kernel_param_ops___143 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___143 *arr;
	};
};

struct kparam_array___143 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___143 *ops;
	void *elem;
};

struct module_attribute___143 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___143 *, struct module_kobject___143 *, char *);
	ssize_t (*store)(struct module_attribute___143 *, struct module_kobject___143 *, const char *, size_t);
	void (*setup)(struct module___146 *, const char *);
	int (*test)(struct module___146 *);
	void (*free)(struct module___146 *);
};

struct trace_event_class___99;

struct bpf_prog_array___21;

struct trace_event_call___99 {
	struct list_head list;
	struct trace_event_class___99 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___21 *prog_array;
	int (*perf_perm)(struct trace_event_call___99 *, struct perf_event___106 *);
};

struct msghdr___11 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___82 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___172 *msg_iocb;
};

struct dev_pm_ops___160 {
	int (*prepare)(struct device___160 *);
	void (*complete)(struct device___160 *);
	int (*suspend)(struct device___160 *);
	int (*resume)(struct device___160 *);
	int (*freeze)(struct device___160 *);
	int (*thaw)(struct device___160 *);
	int (*poweroff)(struct device___160 *);
	int (*restore)(struct device___160 *);
	int (*suspend_late)(struct device___160 *);
	int (*resume_early)(struct device___160 *);
	int (*freeze_late)(struct device___160 *);
	int (*thaw_early)(struct device___160 *);
	int (*poweroff_late)(struct device___160 *);
	int (*restore_early)(struct device___160 *);
	int (*suspend_noirq)(struct device___160 *);
	int (*resume_noirq)(struct device___160 *);
	int (*freeze_noirq)(struct device___160 *);
	int (*thaw_noirq)(struct device___160 *);
	int (*poweroff_noirq)(struct device___160 *);
	int (*restore_noirq)(struct device___160 *);
	int (*runtime_suspend)(struct device___160 *);
	int (*runtime_resume)(struct device___160 *);
	int (*runtime_idle)(struct device___160 *);
};

struct dev_pm_domain___160 {
	struct dev_pm_ops___160 ops;
	void (*detach)(struct device___160 *, bool);
	int (*activate)(struct device___160 *);
	void (*sync)(struct device___160 *);
	void (*dismiss)(struct device___160 *);
};

struct bus_type___160 {
	const char *name;
	const char *dev_name;
	struct device___160 *dev_root;
	const struct attribute_group___161 **bus_groups;
	const struct attribute_group___161 **dev_groups;
	const struct attribute_group___161 **drv_groups;
	int (*match)(struct device___160 *, struct device_driver___160 *);
	int (*uevent)(struct device___160 *, struct kobj_uevent_env *);
	int (*probe)(struct device___160 *);
	int (*remove)(struct device___160 *);
	void (*shutdown)(struct device___160 *);
	int (*online)(struct device___160 *);
	int (*offline)(struct device___160 *);
	int (*suspend)(struct device___160 *, pm_message_t);
	int (*resume)(struct device___160 *);
	int (*num_vf)(struct device___160 *);
	int (*dma_configure)(struct device___160 *);
	const struct dev_pm_ops___160 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___160 {
	const char *name;
	struct bus_type___160 *bus;
	struct module___146 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___160 *);
	int (*remove)(struct device___160 *);
	void (*shutdown)(struct device___160 *);
	int (*suspend)(struct device___160 *, pm_message_t);
	int (*resume)(struct device___160 *);
	const struct attribute_group___161 **groups;
	const struct dev_pm_ops___160 *pm;
	void (*coredump)(struct device___160 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___160 {
	const char *name;
	const struct attribute_group___161 **groups;
	int (*uevent)(struct device___160 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___160 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___160 *);
	const struct dev_pm_ops___160 *pm;
};

struct class___160 {
	const char *name;
	struct module___146 *owner;
	const struct attribute_group___161 **class_groups;
	const struct attribute_group___161 **dev_groups;
	struct kobject___166 *dev_kobj;
	int (*dev_uevent)(struct device___160 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___160 *, umode_t *);
	void (*class_release)(struct class___160 *);
	void (*dev_release)(struct device___160 *);
	int (*shutdown_pre)(struct device___160 *);
	const struct kobj_ns_type_operations___11 *ns_type;
	const void * (*namespace)(struct device___160 *);
	const struct dev_pm_ops___160 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___40 {
	void * (*alloc)(struct device___160 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___160 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___160 *, struct vm_area_struct___172 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___160 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___160 *, struct page___172 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___160 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___160 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___160 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___160 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___160 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___160 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide21;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___160 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___160 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___160 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___160 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___160 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___160 *, u64);
	u64 (*get_required_mask)(struct device___160 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___113;

struct fwnode_handle___113 {
	struct fwnode_handle___113 *secondary;
	const struct fwnode_operations___113 *ops;
};

struct node___136 {
	struct device___160 dev;
};

struct fd___18 {
	struct file___172 *file;
	unsigned int flags;
};

struct bpf_map___147;

struct bpf_map_ops___147 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___147 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___147 *, struct file___172 *);
	void (*map_free)(struct bpf_map___147 *);
	int (*map_get_next_key)(struct bpf_map___147 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___147 *);
	void * (*map_lookup_elem)(struct bpf_map___147 *, void *);
	int (*map_update_elem)(struct bpf_map___147 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___147 *, void *);
	int (*map_push_elem)(struct bpf_map___147 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___147 *, void *);
	int (*map_peek_elem)(struct bpf_map___147 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___147 *, struct file___172 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___147 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___147 *, void *, struct seq_file___162 *);
	int (*map_check_btf)(const struct bpf_map___147 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___147 {
	const struct bpf_map_ops___147 *ops;
	struct bpf_map___147 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___167 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___22;

struct bpf_map_dev_ops___22 {
	int (*map_get_next_key)(struct bpf_offloaded_map___22 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___22 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___22 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___22 *, void *);
};

struct bpf_offloaded_map___22 {
	struct bpf_map___147 map;
	struct net_device___26 *netdev;
	const struct bpf_map_dev_ops___22 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

typedef rx_handler_result_t rx_handler_func_t___22(struct sk_buff___25 **);

struct net_device_ops___22;

struct ethtool_ops___22;

struct l3mdev_ops___12;

struct ndisc_ops___6;

struct xfrmdev_ops___22;

struct tlsdev_ops___22;

struct header_ops___22;

struct inet6_dev___6;

struct netdev_rx_queue___22;

struct mini_Qdisc___21;

struct netdev_queue___22;

struct Qdisc___21;

struct rtnl_link_ops___21;

struct dcbnl_rtnl_ops___22;

struct net_device___26 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___22 *netdev_ops;
	const struct ethtool_ops___22 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___12 *l3mdev_ops;
	const struct ndisc_ops___6 *ndisc_ops;
	const struct xfrmdev_ops___22 *xfrmdev_ops;
	const struct tlsdev_ops___22 *tlsdev_ops;
	const struct header_ops___22 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___165 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___6 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___22 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___21 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___22 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___21 *miniq_ingress;
	struct netdev_queue___22 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___22 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___21 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___21 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___22 = 0,
		NETREG_REGISTERED___22 = 1,
		NETREG_UNREGISTERING___22 = 2,
		NETREG_UNREGISTERED___22 = 3,
		NETREG_RELEASED___22 = 4,
		NETREG_DUMMY___22 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___22 = 0,
		RTNL_LINK_INITIALIZING___22 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___26 *);
	struct netpoll_info *npinfo;
	possible_net_t___23 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___160 dev;
	const struct attribute_group___161 *sysfs_groups[4];
	const struct attribute_group___161 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___21 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___22 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide37;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct bpf_prog_ops___21 {
	int (*test_run)(struct bpf_prog___21 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_aux___21;

struct bpf_prog___21 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___21 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

struct bpf_verifier_ops___21 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___21 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___21 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___21 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___21 *, u32 *);
};

struct bpf_prog_offload_ops___21 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___21 *);
	int (*translate)(struct bpf_prog___21 *);
	void (*destroy)(struct bpf_prog___21 *);
};

struct bpf_prog_offload___21 {
	struct bpf_prog___21 *prog;
	struct net_device___26 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___21 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___21 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___21 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___21 *ops;
	struct bpf_map___147 **used_maps;
	struct bpf_prog___21 *prog;
	struct user_struct___167 *user;
	u64 load_time;
	struct bpf_map___147 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___21 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___21 {
	struct bpf_prog___21 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___21 {
	struct callback_head rcu;
	struct bpf_prog_array_item___21 items[0];
};

struct cgroup_bpf___21 {
	struct bpf_prog_array___21 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___21 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___147;

typedef void (*kthread_work_func_t___147)(struct kthread_work___147 *);

struct kthread_worker___147;

struct kthread_work___147 {
	struct list_head node;
	kthread_work_func_t___147 func;
	struct kthread_worker___147 *worker;
	int canceling;
};

struct kthread_worker___147 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___172 *task;
	struct kthread_work___147 *current_work;
};

struct kthread_delayed_work___147 {
	struct kthread_work___147 work;
	struct timer_list timer;
};

struct psi_group___147 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___147 *poll_kworker;
	struct kthread_delayed_work___147 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___147;

struct cgroup_rstat_cpu___147;

struct cgroup___147 {
	struct cgroup_subsys_state___147 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___168 *kn;
	struct cgroup_file___147 procs_file;
	struct cgroup_file___147 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___147 *subsys[13];
	struct cgroup_root___147 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___147 *dom_cgrp;
	struct cgroup_rstat_cpu___147 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___21 bpf;
	atomic_t congestion_count;
	struct cgroup___147 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___147 psi;
	int ancestor_ids[0];
};

struct cftype___147;

struct cgroup_subsys___147 {
	struct cgroup_subsys_state___147 * (*css_alloc)(struct cgroup_subsys_state___147 *);
	int (*css_online)(struct cgroup_subsys_state___147 *);
	void (*css_offline)(struct cgroup_subsys_state___147 *);
	void (*css_released)(struct cgroup_subsys_state___147 *);
	void (*css_free)(struct cgroup_subsys_state___147 *);
	void (*css_reset)(struct cgroup_subsys_state___147 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___147 *, int);
	int (*css_extra_stat_show)(struct seq_file___162 *, struct cgroup_subsys_state___147 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___172 *);
	void (*cancel_fork)(struct task_struct___172 *);
	void (*fork)(struct task_struct___172 *);
	void (*exit)(struct task_struct___172 *);
	void (*free)(struct task_struct___172 *);
	void (*bind)(struct cgroup_subsys_state___147 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___147 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___147 *dfl_cftypes;
	struct cftype___147 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___147 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___147 *updated_children;
	struct cgroup___147 *updated_next;
};

struct cgroup_root___147 {
	struct kernfs_root___168 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___147 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___147 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___147 *ss;
	struct list_head node;
	struct kernfs_ops___168 *kf_ops;
	int (*open)(struct kernfs_open_file___168 *);
	void (*release)(struct kernfs_open_file___168 *);
	u64 (*read_u64)(struct cgroup_subsys_state___147 *, struct cftype___147 *);
	s64 (*read_s64)(struct cgroup_subsys_state___147 *, struct cftype___147 *);
	int (*seq_show)(struct seq_file___162 *, void *);
	void * (*seq_start)(struct seq_file___162 *, loff_t *);
	void * (*seq_next)(struct seq_file___162 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___162 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___147 *, struct cftype___147 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___147 *, struct cftype___147 *, s64);
	ssize_t (*write)(struct kernfs_open_file___168 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___168 *, struct poll_table_struct___116 *);
};

struct perf_cpu_context___106;

struct pmu___106 {
	struct list_head entry;
	struct module___146 *module;
	struct device___160 *dev;
	const struct attribute_group___161 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___106 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___106 *);
	void (*pmu_disable)(struct pmu___106 *);
	int (*event_init)(struct perf_event___106 *);
	void (*event_mapped)(struct perf_event___106 *, struct mm_struct___171 *);
	void (*event_unmapped)(struct perf_event___106 *, struct mm_struct___171 *);
	int (*add)(struct perf_event___106 *, int);
	void (*del)(struct perf_event___106 *, int);
	void (*start)(struct perf_event___106 *, int);
	void (*stop)(struct perf_event___106 *, int);
	void (*read)(struct perf_event___106 *);
	void (*start_txn)(struct pmu___106 *, unsigned int);
	int (*commit_txn)(struct pmu___106 *);
	void (*cancel_txn)(struct pmu___106 *);
	int (*event_idx)(struct perf_event___106 *);
	void (*sched_task)(struct perf_event_context___106 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___106 *);
	int (*filter_match)(struct perf_event___106 *);
	int (*check_period)(struct perf_event___106 *, u64);
};

struct perf_cpu_context___106 {
	struct perf_event_context___106 ctx;
	struct perf_event_context___106 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___106 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___106 {
	struct cgroup_subsys_state___147 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___99 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___99 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___99 *);
	struct list_head * (*get_fields)(struct trace_event_call___99 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___99 *);
};

struct syscall_metadata___45 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___99 *enter_event;
	struct trace_event_call___99 *exit_event;
};

struct socket_wq___11 {
	wait_queue_head_t wait;
	struct fasync_struct___171 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___11;

struct socket___11 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___11 *wq;
	struct file___172 *file;
	struct sock___13 *sk;
	const struct proto_ops___11 *ops;
};

typedef int (*sk_read_actor_t___11)(read_descriptor_t *, struct sk_buff___25 *, unsigned int, size_t);

struct proto_ops___11 {
	int family;
	struct module___146 *owner;
	int (*release)(struct socket___11 *);
	int (*bind)(struct socket___11 *, struct sockaddr *, int);
	int (*connect)(struct socket___11 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___11 *, struct socket___11 *);
	int (*accept)(struct socket___11 *, struct socket___11 *, int, bool);
	int (*getname)(struct socket___11 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___172 *, struct socket___11 *, struct poll_table_struct___116 *);
	int (*ioctl)(struct socket___11 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___11 *, int);
	int (*shutdown)(struct socket___11 *, int);
	int (*setsockopt)(struct socket___11 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___11 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___11 *, struct msghdr___11 *, size_t);
	int (*recvmsg)(struct socket___11 *, struct msghdr___11 *, size_t, int);
	int (*mmap)(struct file___172 *, struct socket___11 *, struct vm_area_struct___172 *);
	ssize_t (*sendpage)(struct socket___11 *, struct page___172 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___11 *, loff_t *, struct pipe_inode_info___41 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___13 *, int);
	int (*peek_len)(struct socket___11 *);
	int (*read_sock)(struct sock___13 *, read_descriptor_t *, sk_read_actor_t___11);
	int (*sendpage_locked)(struct sock___13 *, struct page___172 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___13 *, struct msghdr___11 *, size_t);
	int (*set_rcvlowat)(struct sock___13 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct nf_bridge_info___22;

struct sk_buff___25 {
	union {
		struct {
			struct sk_buff___25 *next;
			struct sk_buff___25 *prev;
			union {
				struct net_device___26 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___13 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___25 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___22 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct fwnode_reference_args___113;

struct fwnode_endpoint___113;

struct fwnode_operations___113 {
	struct fwnode_handle___113 * (*get)(struct fwnode_handle___113 *);
	void (*put)(struct fwnode_handle___113 *);
	bool (*device_is_available)(const struct fwnode_handle___113 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___113 *, const struct device___160 *);
	bool (*property_present)(const struct fwnode_handle___113 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___113 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___113 *, const char *, const char **, size_t);
	struct fwnode_handle___113 * (*get_parent)(const struct fwnode_handle___113 *);
	struct fwnode_handle___113 * (*get_next_child_node)(const struct fwnode_handle___113 *, struct fwnode_handle___113 *);
	struct fwnode_handle___113 * (*get_named_child_node)(const struct fwnode_handle___113 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___113 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___113 *);
	struct fwnode_handle___113 * (*graph_get_next_endpoint)(const struct fwnode_handle___113 *, struct fwnode_handle___113 *);
	struct fwnode_handle___113 * (*graph_get_remote_endpoint)(const struct fwnode_handle___113 *);
	struct fwnode_handle___113 * (*graph_get_port_parent)(struct fwnode_handle___113 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___113 *, struct fwnode_endpoint___113 *);
};

struct fwnode_endpoint___113 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___113 *local_fwnode;
};

struct fwnode_reference_args___113 {
	struct fwnode_handle___113 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___41;

struct pipe_buffer___41 {
	struct page___172 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___41 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___41 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___41 *, struct pipe_buffer___41 *);
	void (*release)(struct pipe_inode_info___41 *, struct pipe_buffer___41 *);
	int (*steal)(struct pipe_inode_info___41 *, struct pipe_buffer___41 *);
	union {
		bool (*get)(struct pipe_inode_info___41 *, struct pipe_buffer___41 *);
		struct {
			void (*get)(struct pipe_inode_info___41 *, struct pipe_buffer___41 *);
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
};

struct nf_bridge_info___22 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___22 = 0,
		BRNF_PROTO_8021Q___22 = 1,
		BRNF_PROTO_PPPOE___22 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___26 *physindev;
	struct net_device___26 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

struct ethtool_ops___22 {
	int (*get_settings)(struct net_device___26 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___26 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___26 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___26 *);
	void (*get_regs)(struct net_device___26 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___26 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___26 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___26 *);
	void (*set_msglevel)(struct net_device___26 *, u32);
	int (*nway_reset)(struct net_device___26 *);
	u32 (*get_link)(struct net_device___26 *);
	int (*get_eeprom_len)(struct net_device___26 *);
	int (*get_eeprom)(struct net_device___26 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___26 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___26 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___26 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___26 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___26 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___26 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___26 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___26 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___26 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___26 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___26 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___26 *);
	void (*complete)(struct net_device___26 *);
	u32 (*get_priv_flags)(struct net_device___26 *);
	int (*set_priv_flags)(struct net_device___26 *, u32);
	int (*get_sset_count)(struct net_device___26 *, int);
	int (*get_rxnfc)(struct net_device___26 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___26 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___26 *, struct ethtool_flash *);
	int (*reset)(struct net_device___26 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___26 *);
	u32 (*get_rxfh_indir_size)(struct net_device___26 *);
	int (*get_rxfh)(struct net_device___26 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___26 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___26 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___26 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___26 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___26 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___26 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___26 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___26 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___26 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___26 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___26 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___26 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___26 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___26 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___26 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___26 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___26 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___26 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___26 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___26 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___26 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	int (*get_fecparam)(struct net_device___26 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___26 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___26 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___26 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___26 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___22;

struct inet_frags___22 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___22 *, const void *);
	void (*destructor)(struct inet_frag_queue___22 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___22 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___25 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___25 *fragments_tail;
	struct sk_buff___25 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___22 *net;
	struct callback_head rcu;
};

struct ip_ra_chain___2 {
	struct ip_ra_chain___2 *next;
	struct sock___13 *sk;
	union {
		void (*destructor)(struct sock___13 *);
		struct sock___13 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___11;

struct fib_lookup_arg___11;

struct fib_rules_ops___11 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___11 *, struct flowi *, int, struct fib_lookup_arg___11 *);
	bool (*suppress)(struct fib_rule___11 *, struct fib_lookup_arg___11 *);
	int (*match)(struct fib_rule___11 *, struct flowi *, int);
	int (*configure)(struct fib_rule___11 *, struct sk_buff___25 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___11 *);
	int (*compare)(struct fib_rule___11 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___11 *, struct sk_buff___25 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___11 *);
	void (*flush_cache)(struct fib_rules_ops___11 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___146 *owner;
	struct net___32 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___11 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___32 *);
	int (*fib_dump)(struct net___32 *, struct notifier_block *);
	struct module___146 *owner;
	struct callback_head rcu;
};

struct dst_entry___12 {
	struct net_device___26 *dev;
	struct dst_ops___30 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___25 *);
	int (*output)(struct net___32 *, struct sock___13 *, struct sk_buff___25 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___11;

struct neigh_parms___12;

struct neigh_ops___11;

struct neighbour___12 {
	struct neighbour___12 *next;
	struct neigh_table___11 *tbl;
	struct neigh_parms___12 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___22 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___12 *, struct sk_buff___25 *);
	const struct neigh_ops___11 *ops;
	struct callback_head rcu;
	struct net_device___26 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct pernet_operations___22 {
	struct list_head list;
	int (*init)(struct net___32 *);
	void (*exit)(struct net___32 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___22 {
	int (*ieee_getets)(struct net_device___26 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___26 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___26 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___26 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___26 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___26 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___26 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___26 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___26 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___26 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___26 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___26 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___26 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___26 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___26 *);
	u8 (*setstate)(struct net_device___26 *, u8);
	void (*getpermhwaddr)(struct net_device___26 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___26 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___26 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___26 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___26 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___26 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___26 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___26 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___26 *, int, u8 *);
	void (*setpfccfg)(struct net_device___26 *, int, u8);
	void (*getpfccfg)(struct net_device___26 *, int, u8 *);
	u8 (*setall)(struct net_device___26 *);
	u8 (*getcap)(struct net_device___26 *, int, u8 *);
	int (*getnumtcs)(struct net_device___26 *, int, u8 *);
	int (*setnumtcs)(struct net_device___26 *, int, u8);
	u8 (*getpfcstate)(struct net_device___26 *);
	void (*setpfcstate)(struct net_device___26 *, u8);
	void (*getbcncfg)(struct net_device___26 *, int, u32 *);
	void (*setbcncfg)(struct net_device___26 *, int, u32);
	void (*getbcnrp)(struct net_device___26 *, int, u8 *);
	void (*setbcnrp)(struct net_device___26 *, int, u8);
	int (*setapp)(struct net_device___26 *, u8, u16, u8);
	int (*getapp)(struct net_device___26 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___26 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___26 *, int, u8);
	u8 (*getdcbx)(struct net_device___26 *);
	u8 (*setdcbx)(struct net_device___26 *, u8);
	int (*peer_getappinfo)(struct net_device___26 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___26 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___26 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___26 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___26 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___26 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct xdp_rxq_info___22 {
	struct net_device___26 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___22 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___26 *dev_rx;
};

struct netlink_callback___22 {
	struct sk_buff___25 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___22 *);
	int (*dump)(struct sk_buff___25 *, struct netlink_callback___22 *);
	int (*done)(struct netlink_callback___22 *);
	void *data;
	struct module___146 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___22 {
	int (*create)(struct sk_buff___25 *, struct net_device___26 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___25 *, unsigned char *);
	int (*cache)(const struct neighbour___12 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___26 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___22 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___22 *, int);
	int poll_owner;
	struct net_device___26 *dev;
	struct sk_buff___25 *gro_list;
	struct sk_buff___25 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___22 {
	struct net_device___26 *dev;
	struct Qdisc___21 *qdisc;
	struct Qdisc___21 *qdisc_sleeping;
	struct kobject___166 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___26 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___21 {
	struct sk_buff___25 *head;
	struct sk_buff___25 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___21;

struct Qdisc___21 {
	int (*enqueue)(struct sk_buff___25 *, struct Qdisc___21 *, struct sk_buff___25 **);
	struct sk_buff___25 * (*dequeue)(struct Qdisc___21 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___21 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___22 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___22 gso_skb;
	struct qdisc_skb_head___21 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___21 *next_sched;
	struct sk_buff_head___22 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___22 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___166 kobj;
	struct net_device___26 *dev;
	long: 64;
	struct xdp_rxq_info___22 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___22)(struct net_device___26 *, struct sk_buff___25 *, struct net_device___26 *);

struct netdev_bpf___22 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___21 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___21 *prog;
			const struct bpf_prog_offload_ops___21 *ops;
		} verifier;
		struct {
			struct bpf_prog___21 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___22 *offmap;
		};
		struct {
			struct xdp_umem *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___22 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___25 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___22 {
	int (*tls_dev_add)(struct net_device___26 *, struct sock___13 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___26 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___26 *, struct sock___13 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___22 {
	int (*ndo_init)(struct net_device___26 *);
	void (*ndo_uninit)(struct net_device___26 *);
	int (*ndo_open)(struct net_device___26 *);
	int (*ndo_stop)(struct net_device___26 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___25 *, struct net_device___26 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___25 *, struct net_device___26 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___26 *, struct sk_buff___25 *, struct net_device___26 *, select_queue_fallback_t___22);
	void (*ndo_change_rx_flags)(struct net_device___26 *, int);
	void (*ndo_set_rx_mode)(struct net_device___26 *);
	int (*ndo_set_mac_address)(struct net_device___26 *, void *);
	int (*ndo_validate_addr)(struct net_device___26 *);
	int (*ndo_do_ioctl)(struct net_device___26 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___26 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___26 *, int);
	int (*ndo_neigh_setup)(struct net_device___26 *, struct neigh_parms___12 *);
	void (*ndo_tx_timeout)(struct net_device___26 *);
	void (*ndo_get_stats64)(struct net_device___26 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___26 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___26 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___26 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___26 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___26 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___26 *);
	int (*ndo_netpoll_setup)(struct net_device___26 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___26 *);
	int (*ndo_set_vf_mac)(struct net_device___26 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___26 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___26 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___26 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___26 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___26 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___26 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___26 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___26 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___26 *, int, struct sk_buff___25 *);
	int (*ndo_set_vf_guid)(struct net_device___26 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___26 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___26 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___26 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___26 *, const struct sk_buff___25 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___26 *, struct net_device___26 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___26 *, struct net_device___26 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___26 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___26 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___26 *, struct neighbour___12 *);
	void (*ndo_neigh_destroy)(struct net_device___26 *, struct neighbour___12 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___26 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___26 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___26 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___25 *, struct netlink_callback___22 *, struct net_device___26 *, struct net_device___26 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___26 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___26 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide35;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___25 *, u32, u32, struct net_device___26 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___26 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___26 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___26 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___26 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___26 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___26 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___26 *, struct net_device___26 *);
	void (*ndo_dfwd_del_station)(struct net_device___26 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___26 *);
	int (*ndo_set_tx_maxrate)(struct net_device___26 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___26 *);
	int (*ndo_change_proto_down)(struct net_device___26 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___26 *, struct sk_buff___25 *);
	void (*ndo_set_rx_headroom)(struct net_device___26 *, int);
	int (*ndo_bpf)(struct net_device___26 *, struct netdev_bpf___22 *);
	int (*ndo_xdp_xmit)(struct net_device___26 *, int, struct xdp_frame___22 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___26 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___26 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide36;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___12 {
	possible_net_t___23 net;
	struct net_device___26 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___12 *);
	void (*neigh_cleanup)(struct neighbour___12 *);
	struct neigh_table___11 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___12 {
	u32 (*l3mdev_fib_table)(const struct net_device___26 *);
	struct sk_buff___25 * (*l3mdev_l3_rcv)(struct net_device___26 *, struct sk_buff___25 *, u16);
	struct sk_buff___25 * (*l3mdev_l3_out)(struct net_device___26 *, struct sock___13 *, struct sk_buff___25 *, u16);
	struct dst_entry___12 * (*l3mdev_link_scope_lookup)(const struct net_device___26 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct ndisc_ops___6 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___26 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___26 *, struct neighbour___12 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___26 *, u8, struct neighbour___12 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___26 *, struct sk_buff___25 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___32 *, struct net_device___26 *, const struct prefix_info *, struct inet6_dev___6 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___5;

struct inet6_dev___6 {
	struct net_device___26 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___5 *mc_list;
	struct ifmcaddr6___5 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	u8 rndid[8];
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___12 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
};

struct tcf_proto___21;

struct mini_Qdisc___21 {
	struct tcf_proto___21 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___21 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___26 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___32 *, struct net_device___26 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___26 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___26 *, struct list_head *);
	size_t (*get_size)(const struct net_device___26 *);
	int (*fill_info)(struct sk_buff___25 *, const struct net_device___26 *);
	size_t (*get_xstats_size)(const struct net_device___26 *);
	int (*fill_xstats)(struct sk_buff___25 *, const struct net_device___26 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___26 *, struct net_device___26 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___26 *, const struct net_device___26 *);
	int (*fill_slave_info)(struct sk_buff___25 *, const struct net_device___26 *, const struct net_device___26 *);
	struct net___32 * (*get_link_net)(const struct net_device___26 *);
	size_t (*get_linkxstats_size)(const struct net_device___26 *, int);
	int (*fill_linkxstats)(struct sk_buff___25 *, const struct net_device___26 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___22 {
	struct list_head poll_list;
	struct sk_buff_head___22 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___22 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___21 *output_queue;
	struct Qdisc___21 **output_queue_tailp;
	struct sk_buff___25 *completion_queue;
	struct sk_buff_head___22 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___22 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___22 input_pkt_queue;
	struct napi_struct___22 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bdi_writeback_congested___85 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___85 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___85 {
	struct bio___85 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___85 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___85 bip_inline_vecs[0];
};

struct bio_set___85 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___85 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___77 {
	struct mem_cgroup___77 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___77 {
	struct lruvec___171 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___77 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___77 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct gnet_dump___21 {
	spinlock_t *lock;
	struct sk_buff___25 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___21;

struct Qdisc_ops___21 {
	struct Qdisc_ops___21 *next;
	const struct Qdisc_class_ops___21 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___25 *, struct Qdisc___21 *, struct sk_buff___25 **);
	struct sk_buff___25 * (*dequeue)(struct Qdisc___21 *);
	struct sk_buff___25 * (*peek)(struct Qdisc___21 *);
	int (*init)(struct Qdisc___21 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___21 *);
	void (*destroy)(struct Qdisc___21 *);
	int (*change)(struct Qdisc___21 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___21 *);
	int (*change_tx_queue_len)(struct Qdisc___21 *, unsigned int);
	int (*dump)(struct Qdisc___21 *, struct sk_buff___25 *);
	int (*dump_stats)(struct Qdisc___21 *, struct gnet_dump___21 *);
	void (*ingress_block_set)(struct Qdisc___21 *, u32);
	void (*egress_block_set)(struct Qdisc___21 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___21 *);
	u32 (*egress_block_get)(struct Qdisc___21 *);
	struct module___146 *owner;
};

struct tcf_block___21;

struct Qdisc_class_ops___21 {
	unsigned int flags;
	struct netdev_queue___22 * (*select_queue)(struct Qdisc___21 *, struct tcmsg *);
	int (*graft)(struct Qdisc___21 *, long unsigned int, struct Qdisc___21 *, struct Qdisc___21 **, struct netlink_ext_ack *);
	struct Qdisc___21 * (*leaf)(struct Qdisc___21 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___21 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___21 *, u32);
	int (*change)(struct Qdisc___21 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___21 *, long unsigned int);
	void (*walk)(struct Qdisc___21 *, struct qdisc_walker *);
	struct tcf_block___21 * (*tcf_block)(struct Qdisc___21 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___21 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___21 *, long unsigned int);
	int (*dump)(struct Qdisc___21 *, long unsigned int, struct sk_buff___25 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___21 *, long unsigned int, struct gnet_dump___21 *);
};

struct tcf_chain___21;

struct tcf_block___21 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___32 *net;
	struct Qdisc___21 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___21 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___21;

struct tcf_proto_ops___21;

struct tcf_proto___21 {
	struct tcf_proto___21 *next;
	void *root;
	int (*classify)(struct sk_buff___25 *, const struct tcf_proto___21 *, struct tcf_result___21 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___21 *ops;
	struct tcf_chain___21 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___21 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___21 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___21 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___25 *, const struct tcf_proto___21 *, struct tcf_result___21 *);
	int (*init)(struct tcf_proto___21 *);
	void (*destroy)(struct tcf_proto___21 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___21 *, u32);
	void (*put)(struct tcf_proto___21 *, void *);
	int (*change)(struct net___32 *, struct sk_buff___25 *, struct tcf_proto___21 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___21 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___21 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___21 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___32 *, struct tcf_chain___21 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___32 *, struct tcf_proto___21 *, void *, struct sk_buff___25 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___25 *, struct net___32 *, void *);
	struct module___146 *owner;
	int flags;
};

struct tcf_chain___21 {
	struct mutex filter_chain_lock;
	struct tcf_proto___21 *filter_chain;
	struct list_head list;
	struct tcf_block___21 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___21 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___11 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___21 *prog;
};

struct bpf_redirect_info___21 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___147 *map;
	struct bpf_map___147 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___11;

struct neigh_hash_table___11;

struct neigh_table___11 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___26 *, __u32 *);
	bool (*key_eq)(const struct neighbour___12 *, const void *);
	int (*constructor)(struct neighbour___12 *);
	int (*pconstructor)(struct pneigh_entry___11 *);
	void (*pdestructor)(struct pneigh_entry___11 *);
	void (*proxy_redo)(struct sk_buff___25 *);
	char *id;
	struct neigh_parms___12 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___22 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___11 *nht;
	struct pneigh_entry___11 **phash_buckets;
};

struct neigh_ops___11 {
	int family;
	void (*solicit)(struct neighbour___12 *, struct sk_buff___25 *);
	void (*error_report)(struct neighbour___12 *, struct sk_buff___25 *);
	int (*output)(struct neighbour___12 *, struct sk_buff___25 *);
	int (*connected_output)(struct neighbour___12 *, struct sk_buff___25 *);
};

struct pneigh_entry___11 {
	struct pneigh_entry___11 *next;
	possible_net_t___23 net;
	struct net_device___26 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___11 {
	struct neighbour___12 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___11 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___11 *ctarget;
	struct net___32 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___11 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___11 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___6;

struct timewait_sock_ops___6;

struct proto___11 {
	void (*close)(struct sock___13 *, long int);
	int (*pre_connect)(struct sock___13 *, struct sockaddr *, int);
	int (*connect)(struct sock___13 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___13 *, int);
	struct sock___13 * (*accept)(struct sock___13 *, int, int *, bool);
	int (*ioctl)(struct sock___13 *, int, long unsigned int);
	int (*init)(struct sock___13 *);
	void (*destroy)(struct sock___13 *);
	void (*shutdown)(struct sock___13 *, int);
	int (*setsockopt)(struct sock___13 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___13 *, int, int, char *, int *);
	void (*keepalive)(struct sock___13 *, int);
	int (*sendmsg)(struct sock___13 *, struct msghdr___11 *, size_t);
	int (*recvmsg)(struct sock___13 *, struct msghdr___11 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___13 *, struct page___172 *, int, size_t, int);
	int (*bind)(struct sock___13 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___13 *, struct sk_buff___25 *);
	void (*release_cb)(struct sock___13 *);
	int (*hash)(struct sock___13 *);
	void (*unhash)(struct sock___13 *);
	void (*rehash)(struct sock___13 *);
	int (*get_port)(struct sock___13 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___13 *);
	bool (*stream_memory_read)(const struct sock___13 *);
	void (*enter_memory_pressure)(struct sock___13 *);
	void (*leave_memory_pressure)(struct sock___13 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___6 *rsk_prot;
	struct timewait_sock_ops___6 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___146 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___13 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct request_sock___5;

struct request_sock_ops___6 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___13 *, struct request_sock___5 *);
	void (*send_ack)(const struct sock___13 *, struct sk_buff___25 *, struct request_sock___5 *);
	void (*send_reset)(const struct sock___13 *, struct sk_buff___25 *);
	void (*destructor)(struct request_sock___5 *);
	void (*syn_ack_timeout)(const struct request_sock___5 *);
};

struct timewait_sock_ops___6 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___13 *, struct sock___13 *, void *);
	void (*twsk_destructor)(struct sock___13 *);
};

struct request_sock___5 {
	struct sock_common___11 __req_common;
	struct request_sock___5 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___6 *rsk_ops;
	struct sock___13 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___5 {
	struct in6_addr mca_addr;
	struct inet6_dev___6 *idev;
	struct ifmcaddr6___5 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ip6_ra_chain___5 {
	struct ip6_ra_chain___5 *next;
	struct sock___13 *sk;
	int sel;
	void (*destructor)(struct sock___13 *);
};

typedef struct {
	long unsigned int *in;
	long unsigned int *out;
	long unsigned int *ex;
	long unsigned int *res_in;
	long unsigned int *res_out;
	long unsigned int *res_ex;
} fd_set_bits;

struct poll_list {
	struct poll_list *next;
	int len;
	struct pollfd entries[0];
};

enum dentry_d_lock_class {
	DENTRY_D_LOCK_NORMAL = 0,
	DENTRY_D_LOCK_NESTED = 1,
};

struct mount___2;

struct mnt_namespace {
	atomic_t count;
	struct ns_common___4 ns;
	struct mount___2 *root;
	struct list_head list;
	struct user_namespace___141 *user_ns;
	struct ucounts___141 *ucounts;
	u64 seq;
	wait_queue_head_t poll;
	u64 event;
	unsigned int mounts;
	unsigned int pending_mounts;
};

struct mountpoint___2;

struct mount___2 {
	struct hlist_node mnt_hash;
	struct mount___2 *mnt_parent;
	struct dentry___161 *mnt_mountpoint;
	struct vfsmount___21 mnt;
	union {
		struct callback_head mnt_rcu;
		struct llist_node mnt_llist;
	};
	struct mnt_pcp *mnt_pcp;
	struct list_head mnt_mounts;
	struct list_head mnt_child;
	struct list_head mnt_instance;
	const char *mnt_devname;
	struct list_head mnt_list;
	struct list_head mnt_expire;
	struct list_head mnt_share;
	struct list_head mnt_slave_list;
	struct list_head mnt_slave;
	struct mount___2 *mnt_master;
	struct mnt_namespace *mnt_ns;
	struct mountpoint___2 *mnt_mp;
	struct hlist_node mnt_mp_list;
	struct list_head mnt_umounting;
	struct fsnotify_mark_connector *mnt_fsnotify_marks;
	__u32 mnt_fsnotify_mask;
	int mnt_id;
	int mnt_group_id;
	int mnt_expiry_mark;
	struct hlist_head mnt_pins;
	struct fs_pin mnt_umount;
	struct dentry___161 *mnt_ex_mountpoint;
};

struct mountpoint___2 {
	struct hlist_node m_hash;
	struct dentry___161 *m_dentry;
	struct hlist_head m_list;
	int m_count;
};

struct external_name {
	union {
		atomic_t count;
		struct callback_head head;
	} u;
	unsigned char name[0];
};

enum d_walk_ret {
	D_WALK_CONTINUE = 0,
	D_WALK_QUIT = 1,
	D_WALK_NORETRY = 2,
	D_WALK_SKIP = 3,
};

struct check_mount {
	struct vfsmount___21 *mnt;
	unsigned int mounted;
};

struct select_data {
	struct dentry___161 *start;
	struct list_head dispose;
	int found;
};

struct file___173;

struct kiocb___173;

struct iov_iter___83;

struct vm_area_struct___173;

struct inode___173;

struct file_lock___173;

struct page___173;

struct seq_file___163;

struct file_operations___173 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___173 *, loff_t, int);
	ssize_t (*read)(struct file___173 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___173 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___173 *, struct iov_iter___83 *);
	ssize_t (*write_iter)(struct kiocb___173 *, struct iov_iter___83 *);
	int (*iopoll)(struct kiocb___173 *, bool);
	int (*iterate)(struct file___173 *, struct dir_context *);
	int (*iterate_shared)(struct file___173 *, struct dir_context *);
	__poll_t (*poll)(struct file___173 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___173 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___173 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___173 *, struct vm_area_struct___173 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___173 *, struct file___173 *);
	int (*flush)(struct file___173 *, fl_owner_t);
	int (*release)(struct inode___173 *, struct file___173 *);
	int (*fsync)(struct file___173 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___173 *, int);
	int (*lock)(struct file___173 *, int, struct file_lock___173 *);
	ssize_t (*sendpage)(struct file___173 *, struct page___173 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___173 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___173 *, int, struct file_lock___173 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___173 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___173 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___173 *, long int, struct file_lock___173 **, void **);
	long int (*fallocate)(struct file___173 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___163 *, struct file___173 *);
	ssize_t (*copy_file_range)(struct file___173 *, loff_t, struct file___173 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___173 *, loff_t, struct file___173 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___173 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___172 {
	u64 seqnum;
	struct vm_area_struct___173 *vmas[4];
};

struct page_frag___172 {
	struct page___173 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___172;

struct mem_cgroup___78;

struct pid___137;

struct cred___168;

struct nsproxy___164;

struct signal_struct___153;

struct bio_list___86;

struct backing_dev_info___86;

struct io_context___43;

struct css_set___148;

struct request_queue___40;

struct vm_struct___125;

struct task_struct___173 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___173 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___172 *mm;
	struct mm_struct___172 *active_mm;
	struct vmacache___172 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___173 *real_parent;
	struct task_struct___173 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___173 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___78 *active_memcg;
	long int rh_reserved2;
	struct pid___137 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___137 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___137 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___168 *ptracer_cred;
	const struct cred___168 *real_cred;
	const struct cred___168 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___164 *nsproxy;
	struct signal_struct___153 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___173 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___86 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___86 *backing_dev_info;
	struct io_context___43 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___148 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___172 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___78 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___40 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___173 *oom_reaper_list;
	struct vm_struct___125 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___106 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___172;

struct super_block___172;

struct dentry___172 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___172 *d_parent;
	struct qstr d_name;
	struct inode___173 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___172 *d_op;
	struct super_block___172 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct rw_semaphore___173 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___173 *owner;
};

struct address_space_operations___172;

struct address_space___172 {
	struct inode___173 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___173 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___172 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___172;

struct bdi_writeback___86;

struct block_device___173;

struct cdev___33;

struct inode___173 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___172 *i_op;
	struct super_block___172 *i_sb;
	struct address_space___172 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___173 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___86 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___173 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___172 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___173 *i_bdev;
		struct cdev___33 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vfsmount___28;

struct path___172;

struct dentry_operations___172 {
	int (*d_revalidate)(struct dentry___172 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___172 *, unsigned int);
	int (*d_hash)(const struct dentry___172 *, struct qstr *);
	int (*d_compare)(const struct dentry___172 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___172 *);
	int (*d_init)(struct dentry___172 *);
	void (*d_release)(struct dentry___172 *);
	void (*d_prune)(struct dentry___172 *);
	void (*d_iput)(struct dentry___172 *, struct inode___173 *);
	char * (*d_dname)(struct dentry___172 *, char *, int);
	struct vfsmount___28 * (*d_automount)(struct path___172 *);
	int (*d_manage)(const struct path___172 *, bool);
	struct dentry___172 * (*d_real)(struct dentry___172 *, const struct inode___173 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___172;

struct mem_dqinfo___172 {
	struct quota_format_type___172 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___172;

struct quota_info___172 {
	unsigned int flags;
	struct rw_semaphore___173 dqio_sem;
	struct inode___173 *files[3];
	struct mem_dqinfo___172 info[3];
	const struct quota_format_ops___172 *ops[3];
};

struct rcuwait___172 {
	struct task_struct___173 *task;
};

struct percpu_rw_semaphore___172 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___173 rw_sem;
	struct rcuwait___172 writer;
	int readers_block;
};

struct sb_writers___172 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___172 rw_sem[3];
};

struct shrink_control___78;

struct shrinker___78 {
	long unsigned int (*count_objects)(struct shrinker___78 *, struct shrink_control___78 *);
	long unsigned int (*scan_objects)(struct shrinker___78 *, struct shrink_control___78 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___172;

struct super_operations___172;

struct dquot_operations___172;

struct quotactl_ops___172;

struct user_namespace___152;

struct super_block___172 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___172 *s_type;
	const struct super_operations___172 *s_op;
	const struct dquot_operations___172 *dq_op;
	const struct quotactl_ops___172 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___172 *s_root;
	struct rw_semaphore___173 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___173 *s_bdev;
	struct backing_dev_info___86 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___172 s_dquot;
	struct sb_writers___172 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___172 *s_d_op;
	int cleancache_poolid;
	struct shrinker___78 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___152 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___28 {
	struct dentry___172 *mnt_root;
	struct super_block___172 *mnt_sb;
	int mnt_flags;
};

struct path___172 {
	struct vfsmount___28 *mnt;
	struct dentry___172 *dentry;
};

struct key___168;

struct ucounts___152;

struct user_namespace___152 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___152 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___4 ns;
	long unsigned int flags;
	struct key___168 *persistent_keyring_register;
	struct rw_semaphore___173 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___152 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct shrink_control___78 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___78 *memcg;
};

struct cgroup___148;

struct cgroup_subsys___148;

struct cgroup_subsys_state___148 {
	struct cgroup___148 *cgroup;
	struct cgroup_subsys___148 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___148 *parent;
};

struct kernfs_node___169;

struct cgroup_file___148 {
	struct kernfs_node___169 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___78;

struct mem_cgroup___78 {
	struct cgroup_subsys_state___148 css;
	struct mem_cgroup_id___17 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___148 events_file;
	struct cgroup_file___148 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___173 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___78 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___173 *pgtable_t___172;

struct dev_pagemap___170;

struct page___173 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___172 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___173 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___172 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___172 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___170 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___78 *mem_cgroup;
};

struct pglist_data___172;

struct lruvec___172 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___172 *pgdat;
};

struct zone___172 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___172 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___172 {
	struct zone___172 *zone;
	int zone_idx;
};

struct zonelist___172 {
	struct zoneref___172 _zonerefs[25];
};

struct pglist_data___172 {
	struct zone___172 node_zones[3];
	struct zonelist___172 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___173 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___173 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___172 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___173 {
	void *stack;
	struct task_struct___173 *task;
	long int status;
};

struct blocking_notifier_head___172 {
	struct rw_semaphore___173 rwsem;
	struct notifier_block *head;
};

struct pid_namespace___137;

struct upid___137 {
	int nr;
	struct pid_namespace___137 *ns;
};

struct pid_namespace___137 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___173 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___137 *parent;
	struct vfsmount___28 *proc_mnt;
	struct dentry___172 *proc_self;
	struct dentry___172 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___152 *user_ns;
	struct ucounts___152 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___4 ns;
};

struct pid___137 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___137 numbers[1];
};

struct vm_operations_struct___170;

struct vm_area_struct___173 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___173 *vm_next;
	struct vm_area_struct___173 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___172 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___170 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___173 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___172;

struct mm_struct___172 {
	struct {
		struct vm_area_struct___173 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___173 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___173 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___172 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___173 *owner;
		struct user_namespace___152 *user_ns;
		struct file___173 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___172 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___170)(struct vm_area_struct___173 *, long unsigned int, const struct page___173 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___170)(struct page___173 *, void *);

struct device___161;

struct dev_pagemap___170 {
	dev_page_fault_t___170 page_fault;
	dev_page_free_t___170 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___161 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct fown_struct___137 {
	rwlock_t lock;
	struct pid___137 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___173 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___172 f_path;
	struct inode___173 *f_inode;
	const struct file_operations___173 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___137 f_owner;
	const struct cred___168 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___172 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___170;

struct vm_operations_struct___170 {
	void (*open)(struct vm_area_struct___173 *);
	void (*close)(struct vm_area_struct___173 *);
	int (*split)(struct vm_area_struct___173 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___173 *);
	vm_fault_t (*fault)(struct vm_fault___170 *);
	vm_fault_t (*huge_fault)(struct vm_fault___170 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___170 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___173 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___170 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___170 *);
	int (*access)(struct vm_area_struct___173 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___173 *);
	int (*set_policy)(struct vm_area_struct___173 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___173 *, long unsigned int);
	struct page___173 * (*find_special_page)(struct vm_area_struct___173 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___172 {
	struct task_struct___173 *task;
	struct core_thread___172 *next;
};

struct core_state___172 {
	atomic_t nr_threads;
	struct core_thread___172 dumper;
	struct completion startup;
};

struct vm_fault___170 {
	struct vm_area_struct___173 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___173 *cow_page;
	struct mem_cgroup___78 *memcg;
	struct page___173 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___172 prealloc_pte;
};

struct user_struct___168 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___168 *uid_keyring;
	struct key___168 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___168 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___168 *session_keyring;
	struct key___168 *process_keyring;
	struct key___168 *thread_keyring;
	struct key___168 *request_key_auth;
	void *security;
	struct user_struct___168 *user;
	struct user_namespace___152 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___148;

struct nsproxy___164 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___137 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___148 *cgroup_ns;
};

struct signal_struct___153 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___173 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___173 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___137 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___137 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___172 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___137 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide41;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___86;

struct bio_list___86 {
	struct bio___86 *head;
	struct bio___86 *tail;
};

struct bdi_writeback_congested___86;

struct bdi_writeback___86 {
	struct backing_dev_info___86 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___86 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___148 *memcg_css;
	struct cgroup_subsys_state___148 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___86 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___86 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___161 *dev;
	struct device___161 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___172 *debug_dir;
	struct dentry___172 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___43;

struct io_context___43 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___43 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___148 {
	struct cgroup_subsys_state___148 *subsys[13];
	refcount_t refcount;
	struct css_set___148 *dom_cset;
	struct cgroup___148 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___148 *mg_src_cgrp;
	struct cgroup___148 *mg_dst_cgrp;
	struct css_set___148 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

typedef blk_qc_t make_request_fn___39(struct request_queue___40 *, struct bio___86 *);

struct request___40;

typedef int dma_drain_needed_fn___39(struct request___40 *);

struct kset___166;

struct kobj_type___166;

struct kobject___167 {
	const char *name;
	struct list_head entry;
	struct kobject___167 *parent;
	struct kset___166 *kset;
	struct kobj_type___166 *ktype;
	struct kernfs_node___169 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___39;

struct bsg_class_device___39 {
	struct device___161 *class_dev;
	int minor;
	struct request_queue___40 *queue;
	const struct bsg_ops___39 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___86 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___86 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___39;

struct blkcg_gq___30;

struct request_queue___40 {
	struct list_head queue_head;
	struct request___40 *last_merge;
	struct elevator_queue___39 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___39 *make_request_fn;
	dma_drain_needed_fn___39 *dma_drain_needed;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___86 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___167 kobj;
	struct kobject___167 *mq_kobj;
	struct blk_integrity integrity;
	struct device___161 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___30 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	struct bsg_class_device___39 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___86 bio_split;
	struct dentry___172 *debugfs_dir;
	struct dentry___172 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___125 {
	struct vm_struct___125 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___173 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___154 {
	struct task_struct___173 task;
	long unsigned int stack[8192];
};

struct io_cq___43 {
	struct request_queue___40 *q;
	struct io_context___43 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___6 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___173 {
	struct file___173 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___173 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___172 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___173 *ia_file;
};

struct dquot___172 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___172 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___172 {
	int qf_fmt_id;
	const struct quota_format_ops___172 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___172 *qf_next;
};

struct quota_format_ops___172 {
	int (*check_quota_file)(struct super_block___172 *, int);
	int (*read_file_info)(struct super_block___172 *, int);
	int (*write_file_info)(struct super_block___172 *, int);
	int (*free_file_info)(struct super_block___172 *, int);
	int (*read_dqblk)(struct dquot___172 *);
	int (*commit_dqblk)(struct dquot___172 *);
	int (*release_dqblk)(struct dquot___172 *);
	int (*get_next_id)(struct super_block___172 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___172 {
	int (*write_dquot)(struct dquot___172 *);
	struct dquot___172 * (*alloc_dquot)(struct super_block___172 *, int);
	void (*destroy_dquot)(struct dquot___172 *);
	int (*acquire_dquot)(struct dquot___172 *);
	int (*release_dquot)(struct dquot___172 *);
	int (*mark_dirty)(struct dquot___172 *);
	int (*write_info)(struct super_block___172 *, int);
	qsize_t * (*get_reserved_space)(struct inode___173 *);
	int (*get_projid)(struct inode___173 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___173 *, qsize_t *);
	int (*get_next_id)(struct super_block___172 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___172 {
	int (*quota_on)(struct super_block___172 *, int, int, const struct path___172 *);
	int (*quota_off)(struct super_block___172 *, int);
	int (*quota_enable)(struct super_block___172 *, unsigned int);
	int (*quota_disable)(struct super_block___172 *, unsigned int);
	int (*quota_sync)(struct super_block___172 *, int);
	int (*set_info)(struct super_block___172 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___172 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___172 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___172 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___172 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___172 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___83;

struct swap_info_struct___57;

struct address_space_operations___172 {
	int (*writepage)(struct page___173 *, struct writeback_control___83 *);
	int (*readpage)(struct file___173 *, struct page___173 *);
	int (*writepages)(struct address_space___172 *, struct writeback_control___83 *);
	int (*set_page_dirty)(struct page___173 *);
	int (*readpages)(struct file___173 *, struct address_space___172 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___173 *, struct address_space___172 *, loff_t, unsigned int, unsigned int, struct page___173 **, void **);
	int (*write_end)(struct file___173 *, struct address_space___172 *, loff_t, unsigned int, unsigned int, struct page___173 *, void *);
	sector_t (*bmap)(struct address_space___172 *, sector_t);
	void (*invalidatepage)(struct page___173 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___173 *, gfp_t);
	void (*freepage)(struct page___173 *);
	ssize_t (*direct_IO)(struct kiocb___173 *, struct iov_iter___83 *);
	int (*migratepage)(struct address_space___172 *, struct page___173 *, struct page___173 *, enum migrate_mode);
	bool (*isolate_page)(struct page___173 *, isolate_mode_t);
	void (*putback_page)(struct page___173 *);
	int (*launder_page)(struct page___173 *);
	int (*is_partially_uptodate)(struct page___173 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___173 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___172 *, struct page___173 *);
	int (*swap_activate)(struct swap_info_struct___57 *, struct file___173 *, sector_t *);
	void (*swap_deactivate)(struct file___173 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___83 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___86 *wb;
	struct inode___173 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___86;

struct iov_iter___83 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___86 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct swap_info_struct___57 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___173 *bdev;
	struct file___173 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct hd_struct___40;

struct gendisk___40;

struct block_device___173 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___173 *bd_inode;
	struct super_block___172 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___173 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___40 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___40 *bd_disk;
	struct request_queue___40 *bd_queue;
	struct backing_dev_info___86 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___161 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___161 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___161;

struct bus_type___161;

struct device_driver___161;

struct dev_pm_domain___161;

struct fwnode_handle___114;

struct class___161;

struct attribute_group___162;

struct device___161 {
	struct device___161 *parent;
	struct device_private *p;
	struct kobject___167 kobj;
	const char *init_name;
	const struct device_type___161 *type;
	struct mutex mutex;
	struct bus_type___161 *bus;
	struct device_driver___161 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___161 power;
	struct dev_pm_domain___161 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___114 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___161 *class;
	const struct attribute_group___162 **groups;
	void (*release)(struct device___161 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___40 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___161 __dev;
	struct kobject___167 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___40;

struct block_device_operations___40;

struct gendisk___40 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___40 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___40 *part_tbl;
	struct hd_struct___40 part0;
	const struct block_device_operations___40 *fops;
	struct request_queue___40 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___173 lookup_sem;
	struct kobject___167 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___167 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___33 {
	struct kobject___167 kobj;
	struct module___11 *owner;
	const struct file_operations___173 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___172 {
	struct dentry___172 * (*lookup)(struct inode___173 *, struct dentry___172 *, unsigned int);
	const char * (*get_link)(struct dentry___172 *, struct inode___173 *, struct delayed_call *);
	int (*permission)(struct inode___173 *, int);
	struct posix_acl * (*get_acl)(struct inode___173 *, int);
	int (*readlink)(struct dentry___172 *, char *, int);
	int (*create)(struct inode___173 *, struct dentry___172 *, umode_t, bool);
	int (*link)(struct dentry___172 *, struct inode___173 *, struct dentry___172 *);
	int (*unlink)(struct inode___173 *, struct dentry___172 *);
	int (*symlink)(struct inode___173 *, struct dentry___172 *, const char *);
	int (*mkdir)(struct inode___173 *, struct dentry___172 *, umode_t);
	int (*rmdir)(struct inode___173 *, struct dentry___172 *);
	int (*mknod)(struct inode___173 *, struct dentry___172 *, umode_t, dev_t);
	int (*rename)(struct inode___173 *, struct dentry___172 *, struct inode___173 *, struct dentry___172 *, unsigned int);
	int (*setattr)(struct dentry___172 *, struct iattr___172 *);
	int (*getattr)(const struct path___172 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___172 *, char *, size_t);
	int (*fiemap)(struct inode___173 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___173 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___173 *, struct dentry___172 *, struct file___173 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___173 *, struct dentry___172 *, umode_t);
	int (*set_acl)(struct inode___173 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___172 {
	void (*fl_copy_lock)(struct file_lock___173 *, struct file_lock___173 *);
	void (*fl_release_private)(struct file_lock___173 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___172;

struct lock_manager_operations___172;

struct file_lock___173 {
	struct file_lock___173 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___173 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___172 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___172 *fl_ops;
	const struct lock_manager_operations___172 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___172 {
	int (*lm_compare_owner)(struct file_lock___173 *, struct file_lock___173 *);
	long unsigned int (*lm_owner_key)(struct file_lock___173 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___173 *);
	int (*lm_grant)(struct file_lock___173 *, int);
	bool (*lm_break)(struct file_lock___173 *);
	int (*lm_change)(struct file_lock___173 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___173 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___172 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___172 *fa_next;
	struct file___173 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___172 {
	const char *name;
	int fs_flags;
	struct dentry___172 * (*mount)(struct file_system_type___172 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___172 *);
	struct module___11 *owner;
	struct file_system_type___172 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___172 {
	struct inode___173 * (*alloc_inode)(struct super_block___172 *);
	void (*destroy_inode)(struct inode___173 *);
	void (*dirty_inode)(struct inode___173 *, int);
	int (*write_inode)(struct inode___173 *, struct writeback_control___83 *);
	int (*drop_inode)(struct inode___173 *);
	void (*evict_inode)(struct inode___173 *);
	void (*put_super)(struct super_block___172 *);
	int (*sync_fs)(struct super_block___172 *, int);
	int (*freeze_super)(struct super_block___172 *);
	int (*freeze_fs)(struct super_block___172 *);
	int (*thaw_super)(struct super_block___172 *);
	int (*unfreeze_fs)(struct super_block___172 *);
	int (*statfs)(struct dentry___172 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___172 *, int *, char *);
	void (*umount_begin)(struct super_block___172 *);
	int (*show_options)(struct seq_file___163 *, struct dentry___172 *);
	int (*show_devname)(struct seq_file___163 *, struct dentry___172 *);
	int (*show_path)(struct seq_file___163 *, struct dentry___172 *);
	int (*show_stats)(struct seq_file___163 *, struct dentry___172 *);
	ssize_t (*quota_read)(struct super_block___172 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___172 *, int, const char *, size_t, loff_t);
	struct dquot___172 ** (*get_dquots)(struct inode___173 *);
	int (*bdev_try_to_free_page)(struct super_block___172 *, struct page___173 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___172 *, struct shrink_control___78 *);
	long int (*free_cached_objects)(struct super_block___172 *, struct shrink_control___78 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___161;

struct seq_file___163 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___161 *op;
	int poll_event;
	const struct file___173 *file;
	void *private;
};

enum file_time_flags {
	S_ATIME = 1,
	S_MTIME = 2,
	S_CTIME = 4,
	S_VERSION = 8,
};

typedef void bio_end_io_t___86(struct bio___86 *);

struct bio_vec___86 {
	struct page___173 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___86;

struct bio___86 {
	struct bio___86 *bi_next;
	struct gendisk___40 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___86 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___30 *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___86 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___86 *bi_io_vec;
	struct bio_set___86 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___86 bi_inline_vecs[0];
};

struct kobj_attribute___167 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___167 *, struct kobj_attribute___167 *, char *);
	ssize_t (*store)(struct kobject___167 *, struct kobj_attribute___167 *, const char *, size_t);
};

typedef void compound_page_dtor___170(struct page___173 *);

struct bio_integrity_payload___86 {
	struct bio___86 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___86 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___86 bip_inline_vecs[0];
};

struct blkcg___30;

struct blkg_policy_data___30;

struct blkcg_gq___30 {
	struct request_queue___40 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___30 *blkcg;
	struct bdi_writeback_congested___86 *wb_congested;
	struct blkcg_gq___30 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_rwstat stat_bytes;
	struct blkg_rwstat stat_ios;
	struct blkg_policy_data___30 *pd[5];
	struct callback_head callback_head;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
};

struct dev_pm_ops___161;

struct device_type___161 {
	const char *name;
	const struct attribute_group___162 **groups;
	int (*uevent)(struct device___161 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___161 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___161 *);
	const struct dev_pm_ops___161 *pm;
};

struct class___161 {
	const char *name;
	struct module___11 *owner;
	const struct attribute_group___162 **class_groups;
	const struct attribute_group___162 **dev_groups;
	struct kobject___167 *dev_kobj;
	int (*dev_uevent)(struct device___161 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___161 *, umode_t *);
	void (*class_release)(struct class___161 *);
	void (*dev_release)(struct device___161 *);
	int (*shutdown_pre)(struct device___161 *);
	const struct kobj_ns_type_operations___11 *ns_type;
	const void * (*namespace)(struct device___161 *);
	const struct dev_pm_ops___161 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct kernfs_root___169;

struct kernfs_elem_dir___169 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___169 *root;
};

struct kernfs_syscall_ops___169;

struct kernfs_root___169 {
	struct kernfs_node___169 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___169 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___169 {
	struct kernfs_node___169 *target_kn;
};

struct kernfs_ops___169;

struct kernfs_elem_attr___169 {
	const struct kernfs_ops___169 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___169 *notify_next;
};

struct kernfs_node___169 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___169 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___169 dir;
		struct kernfs_elem_symlink___169 symlink;
		struct kernfs_elem_attr___169 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___169;

struct kernfs_ops___169 {
	int (*open)(struct kernfs_open_file___169 *);
	void (*release)(struct kernfs_open_file___169 *);
	int (*seq_show)(struct seq_file___163 *, void *);
	void * (*seq_start)(struct seq_file___163 *, loff_t *);
	void * (*seq_next)(struct seq_file___163 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___163 *, void *);
	ssize_t (*read)(struct kernfs_open_file___169 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___169 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___169 *, struct vm_area_struct___173 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___169 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___169 {
	int (*remount_fs)(struct kernfs_root___169 *, int *, char *);
	int (*show_options)(struct seq_file___163 *, struct kernfs_root___169 *);
	int (*mkdir)(struct kernfs_node___169 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___169 *);
	int (*rename)(struct kernfs_node___169 *, struct kernfs_node___169 *, const char *);
	int (*show_path)(struct seq_file___163 *, struct kernfs_node___169 *, struct kernfs_root___169 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___169 {
	struct kernfs_node___169 *kn;
	struct file___173 *file;
	struct seq_file___163 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___170 *vm_ops;
};

struct bin_attribute___161;

struct attribute_group___162 {
	const char *name;
	umode_t (*is_visible)(struct kobject___167 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___167 *, struct bin_attribute___161 *, int);
	struct attribute **attrs;
	struct bin_attribute___161 **bin_attrs;
};

struct bin_attribute___161 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___173 *, struct kobject___167 *, struct bin_attribute___161 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___173 *, struct kobject___167 *, struct bin_attribute___161 *, char *, loff_t, size_t);
	int (*mmap)(struct file___173 *, struct kobject___167 *, struct bin_attribute___161 *, struct vm_area_struct___173 *);
};

struct sysfs_ops___166 {
	ssize_t (*show)(struct kobject___167 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___167 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___166;

struct kset___166 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___167 kobj;
	const struct kset_uevent_ops___166 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___166 {
	void (*release)(struct kobject___167 *);
	const struct sysfs_ops___166 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___11 * (*child_ns_type)(struct kobject___167 *);
	const void * (*namespace)(struct kobject___167 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___166 {
	int (* const filter)(struct kset___166 *, struct kobject___167 *);
	const char * (* const name)(struct kset___166 *, struct kobject___167 *);
	int (* const uevent)(struct kset___166 *, struct kobject___167 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___161 {
	int (*prepare)(struct device___161 *);
	void (*complete)(struct device___161 *);
	int (*suspend)(struct device___161 *);
	int (*resume)(struct device___161 *);
	int (*freeze)(struct device___161 *);
	int (*thaw)(struct device___161 *);
	int (*poweroff)(struct device___161 *);
	int (*restore)(struct device___161 *);
	int (*suspend_late)(struct device___161 *);
	int (*resume_early)(struct device___161 *);
	int (*freeze_late)(struct device___161 *);
	int (*thaw_early)(struct device___161 *);
	int (*poweroff_late)(struct device___161 *);
	int (*restore_early)(struct device___161 *);
	int (*suspend_noirq)(struct device___161 *);
	int (*resume_noirq)(struct device___161 *);
	int (*freeze_noirq)(struct device___161 *);
	int (*thaw_noirq)(struct device___161 *);
	int (*poweroff_noirq)(struct device___161 *);
	int (*restore_noirq)(struct device___161 *);
	int (*runtime_suspend)(struct device___161 *);
	int (*runtime_resume)(struct device___161 *);
	int (*runtime_idle)(struct device___161 *);
};

struct dev_pm_domain___161 {
	struct dev_pm_ops___161 ops;
	void (*detach)(struct device___161 *, bool);
	int (*activate)(struct device___161 *);
	void (*sync)(struct device___161 *);
	void (*dismiss)(struct device___161 *);
};

struct bus_type___161 {
	const char *name;
	const char *dev_name;
	struct device___161 *dev_root;
	const struct attribute_group___162 **bus_groups;
	const struct attribute_group___162 **dev_groups;
	const struct attribute_group___162 **drv_groups;
	int (*match)(struct device___161 *, struct device_driver___161 *);
	int (*uevent)(struct device___161 *, struct kobj_uevent_env *);
	int (*probe)(struct device___161 *);
	int (*remove)(struct device___161 *);
	void (*shutdown)(struct device___161 *);
	int (*online)(struct device___161 *);
	int (*offline)(struct device___161 *);
	int (*suspend)(struct device___161 *, pm_message_t);
	int (*resume)(struct device___161 *);
	int (*num_vf)(struct device___161 *);
	int (*dma_configure)(struct device___161 *);
	const struct dev_pm_ops___161 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___161 {
	const char *name;
	struct bus_type___161 *bus;
	struct module___11 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___161 *);
	int (*remove)(struct device___161 *);
	void (*shutdown)(struct device___161 *);
	int (*suspend)(struct device___161 *, pm_message_t);
	int (*resume)(struct device___161 *);
	const struct attribute_group___162 **groups;
	const struct dev_pm_ops___161 *pm;
	void (*coredump)(struct device___161 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct fwnode_operations___114;

struct fwnode_handle___114 {
	struct fwnode_handle___114 *secondary;
	const struct fwnode_operations___114 *ops;
};

struct disk_part_tbl___40 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___40 *last_lookup;
	struct hd_struct___40 *part[0];
};

struct block_device_operations___40 {
	int (*open)(struct block_device___173 *, fmode_t);
	void (*release)(struct gendisk___40 *, fmode_t);
	int (*rw_page)(struct block_device___173 *, sector_t, struct page___173 *, unsigned int);
	int (*ioctl)(struct block_device___173 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___173 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___40 *, unsigned int);
	int (*media_changed)(struct gendisk___40 *);
	void (*unlock_native_capacity)(struct gendisk___40 *);
	int (*revalidate_disk)(struct gendisk___40 *);
	int (*getgeo)(struct block_device___173 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___173 *, long unsigned int);
	int (*report_zones)(struct gendisk___40 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___11 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bdi_writeback_congested___86 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___86 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bsg_ops___39 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___40 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___40 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___40 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___39(struct request___40 *, blk_status_t);

struct request___40 {
	struct request_queue___40 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___86 *bio;
	struct bio___86 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___86 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___43 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___39 *saved_end_io;
		} flush;
	};
	struct gendisk___40 *rq_disk;
	struct hd_struct___40 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___39 *end_io;
	void *end_io_data;
	struct request___40 *next_rq;
};

struct fwnode_reference_args___114;

struct fwnode_endpoint___114;

struct fwnode_operations___114 {
	struct fwnode_handle___114 * (*get)(struct fwnode_handle___114 *);
	void (*put)(struct fwnode_handle___114 *);
	bool (*device_is_available)(const struct fwnode_handle___114 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___114 *, const struct device___161 *);
	bool (*property_present)(const struct fwnode_handle___114 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___114 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___114 *, const char *, const char **, size_t);
	struct fwnode_handle___114 * (*get_parent)(const struct fwnode_handle___114 *);
	struct fwnode_handle___114 * (*get_next_child_node)(const struct fwnode_handle___114 *, struct fwnode_handle___114 *);
	struct fwnode_handle___114 * (*get_named_child_node)(const struct fwnode_handle___114 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___114 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___114 *);
	struct fwnode_handle___114 * (*graph_get_next_endpoint)(const struct fwnode_handle___114 *, struct fwnode_handle___114 *);
	struct fwnode_handle___114 * (*graph_get_remote_endpoint)(const struct fwnode_handle___114 *);
	struct fwnode_handle___114 * (*graph_get_port_parent)(struct fwnode_handle___114 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___114 *, struct fwnode_endpoint___114 *);
};

struct fwnode_endpoint___114 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___114 *local_fwnode;
};

struct fwnode_reference_args___114 {
	struct fwnode_handle___114 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct elevator_type___39;

struct elevator_mq_ops___39 {
	int (*init_sched)(struct request_queue___40 *, struct elevator_type___39 *);
	void (*exit_sched)(struct elevator_queue___39 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	bool (*allow_merge)(struct request_queue___40 *, struct request___40 *, struct bio___86 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx *, struct bio___86 *);
	int (*request_merge)(struct request_queue___40 *, struct request___40 **, struct bio___86 *);
	void (*request_merged)(struct request_queue___40 *, struct request___40 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___40 *, struct request___40 *, struct request___40 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___40 *, struct bio___86 *);
	void (*finish_request)(struct request___40 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___40 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___40 *, u64);
	void (*started_request)(struct request___40 *);
	void (*requeue_request)(struct request___40 *);
	struct request___40 * (*former_request)(struct request_queue___40 *, struct request___40 *);
	struct request___40 * (*next_request)(struct request_queue___40 *, struct request___40 *);
	void (*init_icq)(struct io_cq___43 *);
	void (*exit_icq)(struct io_cq___43 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___39;

struct elevator_type___39 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___39 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___39 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___11 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___39 {
	struct elevator_type___39 *type;
	void *elevator_data;
	struct kobject___167 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___39 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___39 *, char *);
	ssize_t (*store)(struct elevator_queue___39 *, const char *, size_t);
};

typedef int (*key_restrict_link_func_t___168)(struct key___168 *, const struct key_type *, const union key_payload *, struct key___168 *);

struct key_restriction___168;

struct key___168 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___173 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___168 *restrict_link;
};

struct key_restriction___168 {
	key_restrict_link_func_t___168 check;
	struct key___168 *key;
	struct key_type *keytype;
};

struct seq_operations___161 {
	void * (*start)(struct seq_file___163 *, loff_t *);
	void (*stop)(struct seq_file___163 *, void *);
	void * (*next)(struct seq_file___163 *, void *, loff_t *);
	int (*show)(struct seq_file___163 *, void *);
};

struct cgroup_namespace___148 {
	refcount_t count;
	struct ns_common___4 ns;
	struct user_namespace___152 *user_ns;
	struct ucounts___152 *ucounts;
	struct css_set___148 *root_cset;
};

struct ucounts___152 {
	struct hlist_node node;
	struct user_namespace___152 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___148;

struct bpf_map_ops___148 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___148 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___148 *, struct file___173 *);
	void (*map_free)(struct bpf_map___148 *);
	int (*map_get_next_key)(struct bpf_map___148 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___148 *);
	void * (*map_lookup_elem)(struct bpf_map___148 *, void *);
	int (*map_update_elem)(struct bpf_map___148 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___148 *, void *);
	int (*map_push_elem)(struct bpf_map___148 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___148 *, void *);
	int (*map_peek_elem)(struct bpf_map___148 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___148 *, struct file___173 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___148 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___148 *, void *, struct seq_file___163 *);
	int (*map_check_btf)(const struct bpf_map___148 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___148 {
	const struct bpf_map_ops___148 *ops;
	struct bpf_map___148 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___168 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___148;

typedef void (*kthread_work_func_t___148)(struct kthread_work___148 *);

struct kthread_worker___148;

struct kthread_work___148 {
	struct list_head node;
	kthread_work_func_t___148 func;
	struct kthread_worker___148 *worker;
	int canceling;
};

struct kthread_worker___148 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___173 *task;
	struct kthread_work___148 *current_work;
};

struct kthread_delayed_work___148 {
	struct kthread_work___148 work;
	struct timer_list timer;
};

struct psi_group___148 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___148 *poll_kworker;
	struct kthread_delayed_work___148 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___148;

struct cgroup_rstat_cpu___148;

struct cgroup___148 {
	struct cgroup_subsys_state___148 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___169 *kn;
	struct cgroup_file___148 procs_file;
	struct cgroup_file___148 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___148 *subsys[13];
	struct cgroup_root___148 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___148 *dom_cgrp;
	struct cgroup_rstat_cpu___148 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___21 bpf;
	atomic_t congestion_count;
	struct cgroup___148 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___148 psi;
	int ancestor_ids[0];
};

struct cftype___148;

struct cgroup_subsys___148 {
	struct cgroup_subsys_state___148 * (*css_alloc)(struct cgroup_subsys_state___148 *);
	int (*css_online)(struct cgroup_subsys_state___148 *);
	void (*css_offline)(struct cgroup_subsys_state___148 *);
	void (*css_released)(struct cgroup_subsys_state___148 *);
	void (*css_free)(struct cgroup_subsys_state___148 *);
	void (*css_reset)(struct cgroup_subsys_state___148 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___148 *, int);
	int (*css_extra_stat_show)(struct seq_file___163 *, struct cgroup_subsys_state___148 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___173 *);
	void (*cancel_fork)(struct task_struct___173 *);
	void (*fork)(struct task_struct___173 *);
	void (*exit)(struct task_struct___173 *);
	void (*free)(struct task_struct___173 *);
	void (*bind)(struct cgroup_subsys_state___148 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___148 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___148 *dfl_cftypes;
	struct cftype___148 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___148 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___148 *updated_children;
	struct cgroup___148 *updated_next;
};

struct cgroup_root___148 {
	struct kernfs_root___169 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___148 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___148 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___148 *ss;
	struct list_head node;
	struct kernfs_ops___169 *kf_ops;
	int (*open)(struct kernfs_open_file___169 *);
	void (*release)(struct kernfs_open_file___169 *);
	u64 (*read_u64)(struct cgroup_subsys_state___148 *, struct cftype___148 *);
	s64 (*read_s64)(struct cgroup_subsys_state___148 *, struct cftype___148 *);
	int (*seq_show)(struct seq_file___163 *, void *);
	void * (*seq_start)(struct seq_file___163 *, loff_t *);
	void * (*seq_next)(struct seq_file___163 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___163 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___148 *, struct cftype___148 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___148 *, struct cftype___148 *, s64);
	ssize_t (*write)(struct kernfs_open_file___169 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___169 *, struct poll_table_struct___6 *);
};

struct blkcg_policy_data___30;

struct blkcg___30 {
	struct cgroup_subsys_state___148 css;
	spinlock_t lock;
	struct xarray blkg_tree;
	struct blkcg_gq___30 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___30 *cpd[5];
	struct list_head all_blkcgs_node;
	struct list_head cgwb_list;
	refcount_t cgwb_refcnt;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct blkcg_policy_data___30 {
	struct blkcg___30 *blkcg;
	int plid;
};

struct blkg_policy_data___30 {
	struct blkcg_gq___30 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___78 {
	struct mem_cgroup___78 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___78 {
	struct lruvec___172 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___78 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___78 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct node___137 {
	struct device___161 dev;
};

struct module___147;

struct file___174;

struct kiocb___174;

struct vm_area_struct___174;

struct inode___174;

struct file_lock___174;

struct page___174;

struct file_operations___174 {
	struct module___147 *owner;
	loff_t (*llseek)(struct file___174 *, loff_t, int);
	ssize_t (*read)(struct file___174 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___174 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___174 *, struct iov_iter___83 *);
	ssize_t (*write_iter)(struct kiocb___174 *, struct iov_iter___83 *);
	int (*iopoll)(struct kiocb___174 *, bool);
	int (*iterate)(struct file___174 *, struct dir_context *);
	int (*iterate_shared)(struct file___174 *, struct dir_context *);
	__poll_t (*poll)(struct file___174 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___174 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___174 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___174 *, struct vm_area_struct___174 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___174 *, struct file___174 *);
	int (*flush)(struct file___174 *, fl_owner_t);
	int (*release)(struct inode___174 *, struct file___174 *);
	int (*fsync)(struct file___174 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___174 *, int);
	int (*lock)(struct file___174 *, int, struct file_lock___174 *);
	ssize_t (*sendpage)(struct file___174 *, struct page___174 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___174 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___174 *, int, struct file_lock___174 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___174 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___174 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___174 *, long int, struct file_lock___174 **, void **);
	long int (*fallocate)(struct file___174 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___174 *);
	ssize_t (*copy_file_range)(struct file___174 *, loff_t, struct file___174 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___174 *, loff_t, struct file___174 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___174 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___173 {
	u64 seqnum;
	struct vm_area_struct___174 *vmas[4];
};

struct page_frag___173 {
	struct page___174 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___173;

struct pid___138;

struct cred___169;

struct nsproxy___165;

struct signal_struct___154;

struct vm_struct___126;

struct task_struct___174 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___174 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___173 *mm;
	struct mm_struct___173 *active_mm;
	struct vmacache___173 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___174 *real_parent;
	struct task_struct___174 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___174 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___138 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___138 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___138 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___169 *ptracer_cred;
	const struct cred___169 *real_cred;
	const struct cred___169 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___165 *nsproxy;
	struct signal_struct___154 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___174 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___43 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___173 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___174 *oom_reaper_list;
	struct vm_struct___126 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___106 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___174 *pgtable_t___173;

struct address_space___173;

struct dev_pagemap___171;

struct page___174 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___173 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___174 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___173 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___173 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___171 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___173;

struct lruvec___173 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___173 *pgdat;
};

struct zone___173 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___173 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___173 {
	struct zone___173 *zone;
	int zone_idx;
};

struct zonelist___173 {
	struct zoneref___173 _zonerefs[25];
};

struct pglist_data___173 {
	struct zone___173 node_zones[3];
	struct zonelist___173 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___174 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___174 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___173 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___174 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___174 *owner;
};

struct secondary_data___174 {
	void *stack;
	struct task_struct___174 *task;
	long int status;
};

struct blocking_notifier_head___173 {
	struct rw_semaphore___174 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___171;

struct vm_area_struct___174 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___174 *vm_next;
	struct vm_area_struct___174 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___173 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___171 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___174 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___173;

struct user_namespace___153;

struct mm_struct___173 {
	struct {
		struct vm_area_struct___174 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___174 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___174 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___173 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___174 *owner;
		struct user_namespace___153 *user_ns;
		struct file___174 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___173 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___173;

struct address_space___173 {
	struct inode___174 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___174 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___173 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___171)(struct vm_area_struct___174 *, long unsigned int, const struct page___174 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___171)(struct page___174 *, void *);

struct dev_pagemap___171 {
	dev_page_fault_t___171 page_fault;
	dev_page_free_t___171 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___6 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct dentry___173;

struct path___173 {
	struct vfsmount *mnt;
	struct dentry___173 *dentry;
};

struct fown_struct___138 {
	rwlock_t lock;
	struct pid___138 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___174 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___173 f_path;
	struct inode___174 *f_inode;
	const struct file_operations___174 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___138 f_owner;
	const struct cred___169 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___173 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___171;

struct vm_operations_struct___171 {
	void (*open)(struct vm_area_struct___174 *);
	void (*close)(struct vm_area_struct___174 *);
	int (*split)(struct vm_area_struct___174 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___174 *);
	vm_fault_t (*fault)(struct vm_fault___171 *);
	vm_fault_t (*huge_fault)(struct vm_fault___171 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___171 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___174 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___171 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___171 *);
	int (*access)(struct vm_area_struct___174 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___174 *);
	int (*set_policy)(struct vm_area_struct___174 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___174 *, long unsigned int);
	struct page___174 * (*find_special_page)(struct vm_area_struct___174 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___173 {
	struct task_struct___174 *task;
	struct core_thread___173 *next;
};

struct core_state___173 {
	atomic_t nr_threads;
	struct core_thread___173 dumper;
	struct completion startup;
};

struct key___169;

struct ucounts___153;

struct user_namespace___153 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___153 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___4 ns;
	long unsigned int flags;
	struct key___169 *persistent_keyring_register;
	struct rw_semaphore___174 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___153 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___171 {
	struct vm_area_struct___174 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___174 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___174 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___173 prealloc_pte;
};

struct pid_namespace___138;

struct upid___138 {
	int nr;
	struct pid_namespace___138 *ns;
};

struct pid_namespace___138 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___174 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___138 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___173 *proc_self;
	struct dentry___173 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___153 *user_ns;
	struct ucounts___153 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___4 ns;
};

struct pid___138 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___138 numbers[1];
};

struct user_struct___169 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___169 *uid_keyring;
	struct key___169 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___169 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___169 *session_keyring;
	struct key___169 *process_keyring;
	struct key___169 *thread_keyring;
	struct key___169 *request_key_auth;
	void *security;
	struct user_struct___169 *user;
	struct user_namespace___153 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct nsproxy___165 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___138 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct signal_struct___154 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___174 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___174 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___138 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___138 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___173 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___138 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_struct___126 {
	struct vm_struct___126 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___174 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___155 {
	struct task_struct___174 task;
	long unsigned int stack[8192];
};

struct dentry_operations___173;

struct super_block___173;

struct dentry___173 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___173 *d_parent;
	struct qstr d_name;
	struct inode___174 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___173 *d_op;
	struct super_block___173 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___173;

struct block_device___174;

struct inode___174 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___173 *i_op;
	struct super_block___173 *i_sb;
	struct address_space___173 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___174 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___174 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___173 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___174 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___173 {
	int (*d_revalidate)(struct dentry___173 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___173 *, unsigned int);
	int (*d_hash)(const struct dentry___173 *, struct qstr *);
	int (*d_compare)(const struct dentry___173 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___173 *);
	int (*d_init)(struct dentry___173 *);
	void (*d_release)(struct dentry___173 *);
	void (*d_prune)(struct dentry___173 *);
	void (*d_iput)(struct dentry___173 *, struct inode___174 *);
	char * (*d_dname)(struct dentry___173 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___173 *);
	int (*d_manage)(const struct path___173 *, bool);
	struct dentry___173 * (*d_real)(struct dentry___173 *, const struct inode___174 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___173;

struct mem_dqinfo___173 {
	struct quota_format_type___173 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___173;

struct quota_info___173 {
	unsigned int flags;
	struct rw_semaphore___174 dqio_sem;
	struct inode___174 *files[3];
	struct mem_dqinfo___173 info[3];
	const struct quota_format_ops___173 *ops[3];
};

struct rcuwait___173 {
	struct task_struct___174 *task;
};

struct percpu_rw_semaphore___173 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___174 rw_sem;
	struct rcuwait___173 writer;
	int readers_block;
};

struct sb_writers___173 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___173 rw_sem[3];
};

struct file_system_type___173;

struct super_operations___173;

struct dquot_operations___173;

struct quotactl_ops___173;

struct xattr_handler___16;

struct super_block___173 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___173 *s_type;
	const struct super_operations___173 *s_op;
	const struct dquot_operations___173 *dq_op;
	const struct quotactl_ops___173 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___173 *s_root;
	struct rw_semaphore___174 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___16 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___174 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___173 s_dquot;
	struct sb_writers___173 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___173 *s_d_op;
	int cleancache_poolid;
	struct shrinker___78 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___153 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___174 {
	struct file___174 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___174 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___173 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___174 *ia_file;
};

struct dquot___173 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___173 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___173 {
	int qf_fmt_id;
	const struct quota_format_ops___173 *qf_ops;
	struct module___147 *qf_owner;
	struct quota_format_type___173 *qf_next;
};

struct quota_format_ops___173 {
	int (*check_quota_file)(struct super_block___173 *, int);
	int (*read_file_info)(struct super_block___173 *, int);
	int (*write_file_info)(struct super_block___173 *, int);
	int (*free_file_info)(struct super_block___173 *, int);
	int (*read_dqblk)(struct dquot___173 *);
	int (*commit_dqblk)(struct dquot___173 *);
	int (*release_dqblk)(struct dquot___173 *);
	int (*get_next_id)(struct super_block___173 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___173 {
	int (*write_dquot)(struct dquot___173 *);
	struct dquot___173 * (*alloc_dquot)(struct super_block___173 *, int);
	void (*destroy_dquot)(struct dquot___173 *);
	int (*acquire_dquot)(struct dquot___173 *);
	int (*release_dquot)(struct dquot___173 *);
	int (*mark_dirty)(struct dquot___173 *);
	int (*write_info)(struct super_block___173 *, int);
	qsize_t * (*get_reserved_space)(struct inode___174 *);
	int (*get_projid)(struct inode___174 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___174 *, qsize_t *);
	int (*get_next_id)(struct super_block___173 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___173 {
	int (*quota_on)(struct super_block___173 *, int, int, const struct path___173 *);
	int (*quota_off)(struct super_block___173 *, int);
	int (*quota_enable)(struct super_block___173 *, unsigned int);
	int (*quota_disable)(struct super_block___173 *, unsigned int);
	int (*quota_sync)(struct super_block___173 *, int);
	int (*set_info)(struct super_block___173 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___173 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___173 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___173 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___173 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___173 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___167;

struct kobj_type___167;

struct kernfs_node___170;

struct kobject___168 {
	const char *name;
	struct list_head entry;
	struct kobject___168 *parent;
	struct kset___167 *kset;
	struct kobj_type___167 *ktype;
	struct kernfs_node___170 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___144 {
	struct kobject___168 kobj;
	struct module___147 *mod;
	struct kobject___168 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___144 {
	struct module___147 *mod;
	struct latch_tree_node node;
};

struct module_layout___144 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___144 mtn;
};

struct module_attribute___144;

struct kernel_param___144;

struct module___147 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___144 mkobj;
	struct module_attribute___144 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___168 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___144 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___144 core_layout;
	struct module_layout___144 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___173 {
	int (*writepage)(struct page___174 *, struct writeback_control___3 *);
	int (*readpage)(struct file___174 *, struct page___174 *);
	int (*writepages)(struct address_space___173 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___174 *);
	int (*readpages)(struct file___174 *, struct address_space___173 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___174 *, struct address_space___173 *, loff_t, unsigned int, unsigned int, struct page___174 **, void **);
	int (*write_end)(struct file___174 *, struct address_space___173 *, loff_t, unsigned int, unsigned int, struct page___174 *, void *);
	sector_t (*bmap)(struct address_space___173 *, sector_t);
	void (*invalidatepage)(struct page___174 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___174 *, gfp_t);
	void (*freepage)(struct page___174 *);
	ssize_t (*direct_IO)(struct kiocb___174 *, struct iov_iter___83 *);
	int (*migratepage)(struct address_space___173 *, struct page___174 *, struct page___174 *, enum migrate_mode);
	bool (*isolate_page)(struct page___174 *, isolate_mode_t);
	void (*putback_page)(struct page___174 *);
	int (*launder_page)(struct page___174 *);
	int (*is_partially_uptodate)(struct page___174 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___174 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___173 *, struct page___174 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___174 *, sector_t *);
	void (*swap_deactivate)(struct file___174 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___174 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___174 *bd_inode;
	struct super_block___173 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___174 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___173 {
	struct dentry___173 * (*lookup)(struct inode___174 *, struct dentry___173 *, unsigned int);
	const char * (*get_link)(struct dentry___173 *, struct inode___174 *, struct delayed_call *);
	int (*permission)(struct inode___174 *, int);
	struct posix_acl * (*get_acl)(struct inode___174 *, int);
	int (*readlink)(struct dentry___173 *, char *, int);
	int (*create)(struct inode___174 *, struct dentry___173 *, umode_t, bool);
	int (*link)(struct dentry___173 *, struct inode___174 *, struct dentry___173 *);
	int (*unlink)(struct inode___174 *, struct dentry___173 *);
	int (*symlink)(struct inode___174 *, struct dentry___173 *, const char *);
	int (*mkdir)(struct inode___174 *, struct dentry___173 *, umode_t);
	int (*rmdir)(struct inode___174 *, struct dentry___173 *);
	int (*mknod)(struct inode___174 *, struct dentry___173 *, umode_t, dev_t);
	int (*rename)(struct inode___174 *, struct dentry___173 *, struct inode___174 *, struct dentry___173 *, unsigned int);
	int (*setattr)(struct dentry___173 *, struct iattr___173 *);
	int (*getattr)(const struct path___173 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___173 *, char *, size_t);
	int (*fiemap)(struct inode___174 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___174 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___174 *, struct dentry___173 *, struct file___174 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___174 *, struct dentry___173 *, umode_t);
	int (*set_acl)(struct inode___174 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___173 {
	void (*fl_copy_lock)(struct file_lock___174 *, struct file_lock___174 *);
	void (*fl_release_private)(struct file_lock___174 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___173;

struct lock_manager_operations___173;

struct file_lock___174 {
	struct file_lock___174 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___174 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___173 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___173 *fl_ops;
	const struct lock_manager_operations___173 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___173 {
	int (*lm_compare_owner)(struct file_lock___174 *, struct file_lock___174 *);
	long unsigned int (*lm_owner_key)(struct file_lock___174 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___174 *);
	int (*lm_grant)(struct file_lock___174 *, int);
	bool (*lm_break)(struct file_lock___174 *);
	int (*lm_change)(struct file_lock___174 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___174 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___173 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___173 *fa_next;
	struct file___174 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___173 {
	const char *name;
	int fs_flags;
	struct dentry___173 * (*mount)(struct file_system_type___173 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___173 *);
	struct module___147 *owner;
	struct file_system_type___173 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___173 {
	struct inode___174 * (*alloc_inode)(struct super_block___173 *);
	void (*destroy_inode)(struct inode___174 *);
	void (*dirty_inode)(struct inode___174 *, int);
	int (*write_inode)(struct inode___174 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___174 *);
	void (*evict_inode)(struct inode___174 *);
	void (*put_super)(struct super_block___173 *);
	int (*sync_fs)(struct super_block___173 *, int);
	int (*freeze_super)(struct super_block___173 *);
	int (*freeze_fs)(struct super_block___173 *);
	int (*thaw_super)(struct super_block___173 *);
	int (*unfreeze_fs)(struct super_block___173 *);
	int (*statfs)(struct dentry___173 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___173 *, int *, char *);
	void (*umount_begin)(struct super_block___173 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___173 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___173 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___173 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___173 *);
	ssize_t (*quota_read)(struct super_block___173 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___173 *, int, const char *, size_t, loff_t);
	struct dquot___173 ** (*get_dquots)(struct inode___174 *);
	int (*bdev_try_to_free_page)(struct super_block___173 *, struct page___174 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___173 *, struct shrink_control___78 *);
	long int (*free_cached_objects)(struct super_block___173 *, struct shrink_control___78 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct xattr_handler___16 {
	const char *name;
	const char *prefix;
	int flags;
	bool (*list)(struct dentry___173 *);
	int (*get)(const struct xattr_handler___16 *, struct dentry___173 *, struct inode___174 *, const char *, void *, size_t);
	int (*set)(const struct xattr_handler___16 *, struct dentry___173 *, struct inode___174 *, const char *, const void *, size_t, int);
};

struct kobj_attribute___168 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___168 *, struct kobj_attribute___168 *, char *);
	ssize_t (*store)(struct kobject___168 *, struct kobj_attribute___168 *, const char *, size_t);
};

typedef void compound_page_dtor___171(struct page___174 *);

typedef int (*key_restrict_link_func_t___169)(struct key___169 *, const struct key_type *, const union key_payload *, struct key___169 *);

struct key_restriction___169;

struct key___169 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___174 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___169 *restrict_link;
};

struct key_restriction___169 {
	key_restrict_link_func_t___169 check;
	struct key___169 *key;
	struct key_type *keytype;
};

struct ucounts___153 {
	struct hlist_node node;
	struct user_namespace___153 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct kernfs_root___170;

struct kernfs_elem_dir___170 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___170 *root;
};

struct kernfs_syscall_ops___170;

struct kernfs_root___170 {
	struct kernfs_node___170 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___170 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___170 {
	struct kernfs_node___170 *target_kn;
};

struct kernfs_ops___170;

struct kernfs_elem_attr___170 {
	const struct kernfs_ops___170 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___170 *notify_next;
};

struct kernfs_node___170 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___170 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___170 dir;
		struct kernfs_elem_symlink___170 symlink;
		struct kernfs_elem_attr___170 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___170;

struct kernfs_ops___170 {
	int (*open)(struct kernfs_open_file___170 *);
	void (*release)(struct kernfs_open_file___170 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___170 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___170 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___170 *, struct vm_area_struct___174 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___170 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___170 {
	int (*remount_fs)(struct kernfs_root___170 *, int *, char *);
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___170 *);
	int (*mkdir)(struct kernfs_node___170 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___170 *);
	int (*rename)(struct kernfs_node___170 *, struct kernfs_node___170 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___170 *, struct kernfs_root___170 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___170 {
	struct kernfs_node___170 *kn;
	struct file___174 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___171 *vm_ops;
};

struct sysfs_ops___167 {
	ssize_t (*show)(struct kobject___168 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___168 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___167;

struct kset___167 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___168 kobj;
	const struct kset_uevent_ops___167 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___167 {
	void (*release)(struct kobject___168 *);
	const struct sysfs_ops___167 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___11 * (*child_ns_type)(struct kobject___168 *);
	const void * (*namespace)(struct kobject___168 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___167 {
	int (* const filter)(struct kset___167 *, struct kobject___168 *);
	const char * (* const name)(struct kset___167 *, struct kobject___168 *);
	int (* const uevent)(struct kset___167 *, struct kobject___168 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___144 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___144 *);
	int (*get)(char *, const struct kernel_param___144 *);
	void (*free)(void *);
};

struct kparam_array___144;

struct kernel_param___144 {
	const char *name;
	struct module___147 *mod;
	const struct kernel_param_ops___144 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___144 *arr;
	};
};

struct kparam_array___144 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___144 *ops;
	void *elem;
};

struct module_attribute___144 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___144 *, struct module_kobject___144 *, char *);
	ssize_t (*store)(struct module_attribute___144 *, struct module_kobject___144 *, const char *, size_t);
	void (*setup)(struct module___147 *, const char *);
	int (*test)(struct module___147 *);
	void (*free)(struct module___147 *);
};

struct kimage___16;

typedef void *kexec_load_t___16(struct kimage___16 *, char *, long unsigned int, char *, long unsigned int, char *, long unsigned int);

struct kexec_file_ops___17 {
	kexec_probe_t *probe;
	kexec_load_t___16 *load;
	kexec_cleanup_t *cleanup;
};

struct kimage___16 {
	kimage_entry_t head;
	kimage_entry_t *entry;
	kimage_entry_t *last_entry;
	long unsigned int start;
	struct page___174 *control_code_page;
	struct page___174 *swap_page;
	void *vmcoreinfo_data_copy;
	long unsigned int nr_segments;
	struct kexec_segment segment[16];
	struct list_head control_pages;
	struct list_head dest_pages;
	struct list_head unusable_pages;
	long unsigned int control_page;
	unsigned int type: 1;
	unsigned int preserve_context: 1;
	unsigned int file_mode: 1;
	struct kimage_arch arch;
	void *kernel_buf;
	long unsigned int kernel_buf_len;
	void *initrd_buf;
	long unsigned int initrd_buf_len;
	char *cmdline_buf;
	long unsigned int cmdline_buf_len;
	const struct kexec_file_ops___17 *fops;
	void *image_loader_data;
	struct purgatory_info purgatory_info;
};

struct module___148;

struct file___175;

struct kiocb___175;

struct poll_table_struct___117;

struct vm_area_struct___175;

struct inode___175;

struct file_lock___175;

struct page___175;

struct seq_file___164;

struct file_operations___175 {
	struct module___148 *owner;
	loff_t (*llseek)(struct file___175 *, loff_t, int);
	ssize_t (*read)(struct file___175 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___175 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___175 *, struct iov_iter___83 *);
	ssize_t (*write_iter)(struct kiocb___175 *, struct iov_iter___83 *);
	int (*iopoll)(struct kiocb___175 *, bool);
	int (*iterate)(struct file___175 *, struct dir_context *);
	int (*iterate_shared)(struct file___175 *, struct dir_context *);
	__poll_t (*poll)(struct file___175 *, struct poll_table_struct___117 *);
	long int (*unlocked_ioctl)(struct file___175 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___175 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___175 *, struct vm_area_struct___175 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___175 *, struct file___175 *);
	int (*flush)(struct file___175 *, fl_owner_t);
	int (*release)(struct inode___175 *, struct file___175 *);
	int (*fsync)(struct file___175 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___175 *, int);
	int (*lock)(struct file___175 *, int, struct file_lock___175 *);
	ssize_t (*sendpage)(struct file___175 *, struct page___175 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___175 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___175 *, int, struct file_lock___175 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___175 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___175 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___175 *, long int, struct file_lock___175 **, void **);
	long int (*fallocate)(struct file___175 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___164 *, struct file___175 *);
	ssize_t (*copy_file_range)(struct file___175 *, loff_t, struct file___175 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___175 *, loff_t, struct file___175 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___175 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___174 {
	u64 seqnum;
	struct vm_area_struct___175 *vmas[4];
};

struct page_frag___174 {
	struct page___175 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___107;

struct debug_info___107 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___107 *hbp_break[16];
	struct perf_event___107 *hbp_watch[16];
};

struct thread_struct___107 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___107 debug;
	long: 64;
};

struct mm_struct___174;

struct pid___139;

struct cred___170;

struct fs_struct___10;

struct nsproxy___166;

struct signal_struct___155;

struct css_set___149;

struct perf_event_context___107;

struct task_struct___175 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___175 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___174 *mm;
	struct mm_struct___174 *active_mm;
	struct vmacache___174 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___175 *real_parent;
	struct task_struct___175 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___175 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___139 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___139 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___139 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___170 *ptracer_cred;
	const struct cred___170 *real_cred;
	const struct cred___170 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct___10 *fs;
	struct files_struct *files;
	struct nsproxy___166 *nsproxy;
	struct signal_struct___155 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___175 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___43 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___149 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___107 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___174 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___175 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___107 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___107 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___175 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___107)(struct perf_event___107 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___107;

struct fasync_struct___174;

struct pid_namespace___139;

struct trace_event_call___100;

struct perf_cgroup___107;

struct perf_event___107 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___107 *group_leader;
	struct pmu___107 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___107 hw;
	struct perf_event_context___107 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___107 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___175 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___174 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___107 *);
	struct callback_head callback_head;
	struct pid_namespace___139 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___107 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___107 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___100 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___107 *cgrp;
	struct list_head sb_list;
};

struct dentry_operations___174;

struct super_block___174;

struct dentry___174 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___174 *d_parent;
	struct qstr d_name;
	struct inode___175 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___174 *d_op;
	struct super_block___174 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct rw_semaphore___175 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___175 *owner;
};

struct address_space_operations___174;

struct address_space___174 {
	struct inode___175 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___175 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___174 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___174;

struct block_device___175;

struct inode___175 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___174 *i_op;
	struct super_block___174 *i_sb;
	struct address_space___174 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___175 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___175 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___174 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___175 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vfsmount___29;

struct path___174;

struct dentry_operations___174 {
	int (*d_revalidate)(struct dentry___174 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___174 *, unsigned int);
	int (*d_hash)(const struct dentry___174 *, struct qstr *);
	int (*d_compare)(const struct dentry___174 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___174 *);
	int (*d_init)(struct dentry___174 *);
	void (*d_release)(struct dentry___174 *);
	void (*d_prune)(struct dentry___174 *);
	void (*d_iput)(struct dentry___174 *, struct inode___175 *);
	char * (*d_dname)(struct dentry___174 *, char *, int);
	struct vfsmount___29 * (*d_automount)(struct path___174 *);
	int (*d_manage)(const struct path___174 *, bool);
	struct dentry___174 * (*d_real)(struct dentry___174 *, const struct inode___175 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___174;

struct mem_dqinfo___174 {
	struct quota_format_type___174 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___174;

struct quota_info___174 {
	unsigned int flags;
	struct rw_semaphore___175 dqio_sem;
	struct inode___175 *files[3];
	struct mem_dqinfo___174 info[3];
	const struct quota_format_ops___174 *ops[3];
};

struct rcuwait___174 {
	struct task_struct___175 *task;
};

struct percpu_rw_semaphore___174 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___175 rw_sem;
	struct rcuwait___174 writer;
	int readers_block;
};

struct sb_writers___174 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___174 rw_sem[3];
};

struct file_system_type___174;

struct super_operations___174;

struct dquot_operations___174;

struct quotactl_ops___174;

struct user_namespace___154;

struct super_block___174 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___174 *s_type;
	const struct super_operations___174 *s_op;
	const struct dquot_operations___174 *dq_op;
	const struct quotactl_ops___174 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___174 *s_root;
	struct rw_semaphore___175 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___175 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___174 s_dquot;
	struct sb_writers___174 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___174 *s_d_op;
	int cleancache_poolid;
	struct shrinker___78 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___154 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___29 {
	struct dentry___174 *mnt_root;
	struct super_block___174 *mnt_sb;
	int mnt_flags;
};

struct path___174 {
	struct vfsmount___29 *mnt;
	struct dentry___174 *dentry;
};

struct proc_ns_operations___10;

struct ns_common___10 {
	atomic_long_t stashed;
	const struct proc_ns_operations___10 *ops;
	unsigned int inum;
};

struct key___170;

struct ucounts___154;

struct user_namespace___154 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___154 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___10 ns;
	long unsigned int flags;
	struct key___170 *persistent_keyring_register;
	struct rw_semaphore___175 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___154 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___175 *pgtable_t___174;

struct dev_pagemap___172;

struct page___175 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___174 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___175 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___174 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___174 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___172 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___174;

struct lruvec___174 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___174 *pgdat;
};

struct zone___174 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___174 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___174 {
	struct zone___174 *zone;
	int zone_idx;
};

struct zonelist___174 {
	struct zoneref___174 _zonerefs[25];
};

struct pglist_data___174 {
	struct zone___174 node_zones[3];
	struct zonelist___174 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___175 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___175 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___174 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___175 {
	void *stack;
	struct task_struct___175 *task;
	long int status;
};

struct blocking_notifier_head___174 {
	struct rw_semaphore___175 rwsem;
	struct notifier_block *head;
};

struct upid___139 {
	int nr;
	struct pid_namespace___139 *ns;
};

struct pid_namespace___139 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___175 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___139 *parent;
	struct vfsmount___29 *proc_mnt;
	struct dentry___174 *proc_self;
	struct dentry___174 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___154 *user_ns;
	struct ucounts___154 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___10 ns;
};

struct pid___139 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___139 numbers[1];
};

struct vm_operations_struct___172;

struct vm_area_struct___175 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___175 *vm_next;
	struct vm_area_struct___175 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___174 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___172 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___175 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___174;

struct mm_struct___174 {
	struct {
		struct vm_area_struct___175 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___175 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___175 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___174 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___175 *owner;
		struct user_namespace___154 *user_ns;
		struct file___175 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___174 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___172)(struct vm_area_struct___175 *, long unsigned int, const struct page___175 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___172)(struct page___175 *, void *);

struct device___162;

struct dev_pagemap___172 {
	dev_page_fault_t___172 page_fault;
	dev_page_free_t___172 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___162 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct fown_struct___139 {
	rwlock_t lock;
	struct pid___139 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___175 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___174 f_path;
	struct inode___175 *f_inode;
	const struct file_operations___175 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___139 f_owner;
	const struct cred___170 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___174 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___172;

struct vm_operations_struct___172 {
	void (*open)(struct vm_area_struct___175 *);
	void (*close)(struct vm_area_struct___175 *);
	int (*split)(struct vm_area_struct___175 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___175 *);
	vm_fault_t (*fault)(struct vm_fault___172 *);
	vm_fault_t (*huge_fault)(struct vm_fault___172 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___172 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___175 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___172 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___172 *);
	int (*access)(struct vm_area_struct___175 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___175 *);
	int (*set_policy)(struct vm_area_struct___175 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___175 *, long unsigned int);
	struct page___175 * (*find_special_page)(struct vm_area_struct___175 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___174 {
	struct task_struct___175 *task;
	struct core_thread___174 *next;
};

struct core_state___174 {
	atomic_t nr_threads;
	struct core_thread___174 dumper;
	struct completion startup;
};

struct vm_fault___172 {
	struct vm_area_struct___175 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___175 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___175 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___174 prealloc_pte;
};

struct user_struct___170 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___170 *uid_keyring;
	struct key___170 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___170 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___170 *session_keyring;
	struct key___170 *process_keyring;
	struct key___170 *thread_keyring;
	struct key___170 *request_key_auth;
	void *security;
	struct user_struct___170 *user;
	struct user_namespace___154 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct fs_struct___10 {
	int users;
	spinlock_t lock;
	seqcount_t seq;
	int umask;
	int in_exec;
	struct path___174 root;
	struct path___174 pwd;
};

struct mnt_namespace___3;

struct cgroup_namespace___149;

struct nsproxy___166 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace___3 *mnt_ns;
	struct pid_namespace___139 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___149 *cgroup_ns;
};

struct signal_struct___155 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___175 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___175 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___139 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___139 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___174 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___139 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___149;

struct cgroup___149;

struct css_set___149 {
	struct cgroup_subsys_state___149 *subsys[13];
	refcount_t refcount;
	struct css_set___149 *dom_cset;
	struct cgroup___149 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___149 *mg_src_cgrp;
	struct cgroup___149 *mg_dst_cgrp;
	struct css_set___149 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___107 {
	struct pmu___107 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___175 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___107 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

union thread_union___156 {
	struct task_struct___175 task;
	long unsigned int stack[8192];
};

struct kiocb___175 {
	struct file___175 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___175 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___174 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___175 *ia_file;
};

struct dquot___174 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___174 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___174 {
	int qf_fmt_id;
	const struct quota_format_ops___174 *qf_ops;
	struct module___148 *qf_owner;
	struct quota_format_type___174 *qf_next;
};

struct quota_format_ops___174 {
	int (*check_quota_file)(struct super_block___174 *, int);
	int (*read_file_info)(struct super_block___174 *, int);
	int (*write_file_info)(struct super_block___174 *, int);
	int (*free_file_info)(struct super_block___174 *, int);
	int (*read_dqblk)(struct dquot___174 *);
	int (*commit_dqblk)(struct dquot___174 *);
	int (*release_dqblk)(struct dquot___174 *);
	int (*get_next_id)(struct super_block___174 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___174 {
	int (*write_dquot)(struct dquot___174 *);
	struct dquot___174 * (*alloc_dquot)(struct super_block___174 *, int);
	void (*destroy_dquot)(struct dquot___174 *);
	int (*acquire_dquot)(struct dquot___174 *);
	int (*release_dquot)(struct dquot___174 *);
	int (*mark_dirty)(struct dquot___174 *);
	int (*write_info)(struct super_block___174 *, int);
	qsize_t * (*get_reserved_space)(struct inode___175 *);
	int (*get_projid)(struct inode___175 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___175 *, qsize_t *);
	int (*get_next_id)(struct super_block___174 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___174 {
	int (*quota_on)(struct super_block___174 *, int, int, const struct path___174 *);
	int (*quota_off)(struct super_block___174 *, int);
	int (*quota_enable)(struct super_block___174 *, unsigned int);
	int (*quota_disable)(struct super_block___174 *, unsigned int);
	int (*quota_sync)(struct super_block___174 *, int);
	int (*set_info)(struct super_block___174 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___174 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___174 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___174 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___174 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___174 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___168;

struct kobj_type___168;

struct kernfs_node___171;

struct kobject___169 {
	const char *name;
	struct list_head entry;
	struct kobject___169 *parent;
	struct kset___168 *kset;
	struct kobj_type___168 *ktype;
	struct kernfs_node___171 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___145 {
	struct kobject___169 kobj;
	struct module___148 *mod;
	struct kobject___169 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___145 {
	struct module___148 *mod;
	struct latch_tree_node node;
};

struct module_layout___145 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___145 mtn;
};

struct module_attribute___145;

struct kernel_param___145;

struct module___148 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___145 mkobj;
	struct module_attribute___145 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___169 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___145 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___145 core_layout;
	struct module_layout___145 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___100 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___174 {
	int (*writepage)(struct page___175 *, struct writeback_control___3 *);
	int (*readpage)(struct file___175 *, struct page___175 *);
	int (*writepages)(struct address_space___174 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___175 *);
	int (*readpages)(struct file___175 *, struct address_space___174 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___175 *, struct address_space___174 *, loff_t, unsigned int, unsigned int, struct page___175 **, void **);
	int (*write_end)(struct file___175 *, struct address_space___174 *, loff_t, unsigned int, unsigned int, struct page___175 *, void *);
	sector_t (*bmap)(struct address_space___174 *, sector_t);
	void (*invalidatepage)(struct page___175 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___175 *, gfp_t);
	void (*freepage)(struct page___175 *);
	ssize_t (*direct_IO)(struct kiocb___175 *, struct iov_iter___83 *);
	int (*migratepage)(struct address_space___174 *, struct page___175 *, struct page___175 *, enum migrate_mode);
	bool (*isolate_page)(struct page___175 *, isolate_mode_t);
	void (*putback_page)(struct page___175 *);
	int (*launder_page)(struct page___175 *);
	int (*is_partially_uptodate)(struct page___175 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___175 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___174 *, struct page___175 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___175 *, sector_t *);
	void (*swap_deactivate)(struct file___175 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___175 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___175 *bd_inode;
	struct super_block___174 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___175 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___174 {
	struct dentry___174 * (*lookup)(struct inode___175 *, struct dentry___174 *, unsigned int);
	const char * (*get_link)(struct dentry___174 *, struct inode___175 *, struct delayed_call *);
	int (*permission)(struct inode___175 *, int);
	struct posix_acl * (*get_acl)(struct inode___175 *, int);
	int (*readlink)(struct dentry___174 *, char *, int);
	int (*create)(struct inode___175 *, struct dentry___174 *, umode_t, bool);
	int (*link)(struct dentry___174 *, struct inode___175 *, struct dentry___174 *);
	int (*unlink)(struct inode___175 *, struct dentry___174 *);
	int (*symlink)(struct inode___175 *, struct dentry___174 *, const char *);
	int (*mkdir)(struct inode___175 *, struct dentry___174 *, umode_t);
	int (*rmdir)(struct inode___175 *, struct dentry___174 *);
	int (*mknod)(struct inode___175 *, struct dentry___174 *, umode_t, dev_t);
	int (*rename)(struct inode___175 *, struct dentry___174 *, struct inode___175 *, struct dentry___174 *, unsigned int);
	int (*setattr)(struct dentry___174 *, struct iattr___174 *);
	int (*getattr)(const struct path___174 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___174 *, char *, size_t);
	int (*fiemap)(struct inode___175 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___175 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___175 *, struct dentry___174 *, struct file___175 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___175 *, struct dentry___174 *, umode_t);
	int (*set_acl)(struct inode___175 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___174 {
	void (*fl_copy_lock)(struct file_lock___175 *, struct file_lock___175 *);
	void (*fl_release_private)(struct file_lock___175 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___174;

struct file_lock___175 {
	struct file_lock___175 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___175 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___174 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___174 *fl_ops;
	const struct lock_manager_operations___174 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___174 {
	int (*lm_compare_owner)(struct file_lock___175 *, struct file_lock___175 *);
	long unsigned int (*lm_owner_key)(struct file_lock___175 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___175 *);
	int (*lm_grant)(struct file_lock___175 *, int);
	bool (*lm_break)(struct file_lock___175 *);
	int (*lm_change)(struct file_lock___175 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___175 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___174 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___174 *fa_next;
	struct file___175 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___174 {
	const char *name;
	int fs_flags;
	struct dentry___174 * (*mount)(struct file_system_type___174 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___174 *);
	struct module___148 *owner;
	struct file_system_type___174 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___174 {
	struct inode___175 * (*alloc_inode)(struct super_block___174 *);
	void (*destroy_inode)(struct inode___175 *);
	void (*dirty_inode)(struct inode___175 *, int);
	int (*write_inode)(struct inode___175 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___175 *);
	void (*evict_inode)(struct inode___175 *);
	void (*put_super)(struct super_block___174 *);
	int (*sync_fs)(struct super_block___174 *, int);
	int (*freeze_super)(struct super_block___174 *);
	int (*freeze_fs)(struct super_block___174 *);
	int (*thaw_super)(struct super_block___174 *);
	int (*unfreeze_fs)(struct super_block___174 *);
	int (*statfs)(struct dentry___174 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___174 *, int *, char *);
	void (*umount_begin)(struct super_block___174 *);
	int (*show_options)(struct seq_file___164 *, struct dentry___174 *);
	int (*show_devname)(struct seq_file___164 *, struct dentry___174 *);
	int (*show_path)(struct seq_file___164 *, struct dentry___174 *);
	int (*show_stats)(struct seq_file___164 *, struct dentry___174 *);
	ssize_t (*quota_read)(struct super_block___174 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___174 *, int, const char *, size_t, loff_t);
	struct dquot___174 ** (*get_dquots)(struct inode___175 *);
	int (*bdev_try_to_free_page)(struct super_block___174 *, struct page___175 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___174 *, struct shrink_control___78 *);
	long int (*free_cached_objects)(struct super_block___174 *, struct shrink_control___78 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___116)(struct file___175 *, wait_queue_head_t *, struct poll_table_struct___117 *);

struct poll_table_struct___117 {
	poll_queue_proc___116 _qproc;
	__poll_t _key;
};

struct seq_operations___162;

struct seq_file___164 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___162 *op;
	int poll_event;
	const struct file___175 *file;
	void *private;
};

typedef int (*key_restrict_link_func_t___170)(struct key___170 *, const struct key_type *, const union key_payload *, struct key___170 *);

struct key_restriction___170;

struct key___170 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___175 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___170 *restrict_link;
};

struct key_restriction___170 {
	key_restrict_link_func_t___170 check;
	struct key___170 *key;
	struct key_type *keytype;
};

struct dev_pm_info___162 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___162 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___162;

struct bus_type___162;

struct device_driver___162;

struct dev_pm_domain___162;

struct class___162;

struct attribute_group___163;

struct device___162 {
	struct device___162 *parent;
	struct device_private *p;
	struct kobject___169 kobj;
	const char *init_name;
	const struct device_type___162 *type;
	struct mutex mutex;
	struct bus_type___162 *bus;
	struct device_driver___162 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___162 power;
	struct dev_pm_domain___162 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___162 *class;
	const struct attribute_group___163 **groups;
	void (*release)(struct device___162 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct kobj_attribute___169 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___169 *, struct kobj_attribute___169 *, char *);
	ssize_t (*store)(struct kobject___169 *, struct kobj_attribute___169 *, const char *, size_t);
};

typedef void compound_page_dtor___172(struct page___175 *);

struct seq_operations___162 {
	void * (*start)(struct seq_file___164 *, loff_t *);
	void (*stop)(struct seq_file___164 *, void *);
	void * (*next)(struct seq_file___164 *, void *, loff_t *);
	int (*show)(struct seq_file___164 *, void *);
};

struct mount___3;

struct mnt_namespace___3 {
	atomic_t count;
	struct ns_common___10 ns;
	struct mount___3 *root;
	struct list_head list;
	struct user_namespace___154 *user_ns;
	struct ucounts___154 *ucounts;
	u64 seq;
	wait_queue_head_t poll;
	u64 event;
	unsigned int mounts;
	unsigned int pending_mounts;
};

struct cgroup_namespace___149 {
	refcount_t count;
	struct ns_common___10 ns;
	struct user_namespace___154 *user_ns;
	struct ucounts___154 *ucounts;
	struct css_set___149 *root_cset;
};

struct proc_ns_operations___10 {
	const char *name;
	const char *real_ns_name;
	int type;
	struct ns_common___10 * (*get)(struct task_struct___175 *);
	void (*put)(struct ns_common___10 *);
	int (*install)(struct nsproxy___166 *, struct ns_common___10 *);
	struct user_namespace___154 * (*owner)(struct ns_common___10 *);
	struct ns_common___10 * (*get_parent)(struct ns_common___10 *);
};

struct ucounts___154 {
	struct hlist_node node;
	struct user_namespace___154 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct kernfs_root___171;

struct kernfs_elem_dir___171 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___171 *root;
};

struct kernfs_syscall_ops___171;

struct kernfs_root___171 {
	struct kernfs_node___171 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___171 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___171 {
	struct kernfs_node___171 *target_kn;
};

struct kernfs_ops___171;

struct kernfs_elem_attr___171 {
	const struct kernfs_ops___171 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___171 *notify_next;
};

struct kernfs_node___171 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___171 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___171 dir;
		struct kernfs_elem_symlink___171 symlink;
		struct kernfs_elem_attr___171 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___171;

struct kernfs_ops___171 {
	int (*open)(struct kernfs_open_file___171 *);
	void (*release)(struct kernfs_open_file___171 *);
	int (*seq_show)(struct seq_file___164 *, void *);
	void * (*seq_start)(struct seq_file___164 *, loff_t *);
	void * (*seq_next)(struct seq_file___164 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___164 *, void *);
	ssize_t (*read)(struct kernfs_open_file___171 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___171 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___171 *, struct vm_area_struct___175 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___171 *, struct poll_table_struct___117 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___171 {
	int (*remount_fs)(struct kernfs_root___171 *, int *, char *);
	int (*show_options)(struct seq_file___164 *, struct kernfs_root___171 *);
	int (*mkdir)(struct kernfs_node___171 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___171 *);
	int (*rename)(struct kernfs_node___171 *, struct kernfs_node___171 *, const char *);
	int (*show_path)(struct seq_file___164 *, struct kernfs_node___171 *, struct kernfs_root___171 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___171 {
	struct kernfs_node___171 *kn;
	struct file___175 *file;
	struct seq_file___164 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___172 *vm_ops;
};

struct bin_attribute___162;

struct attribute_group___163 {
	const char *name;
	umode_t (*is_visible)(struct kobject___169 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___169 *, struct bin_attribute___162 *, int);
	struct attribute **attrs;
	struct bin_attribute___162 **bin_attrs;
};

struct bin_attribute___162 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___175 *, struct kobject___169 *, struct bin_attribute___162 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___175 *, struct kobject___169 *, struct bin_attribute___162 *, char *, loff_t, size_t);
	int (*mmap)(struct file___175 *, struct kobject___169 *, struct bin_attribute___162 *, struct vm_area_struct___175 *);
};

struct sysfs_ops___168 {
	ssize_t (*show)(struct kobject___169 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___169 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___168;

struct kset___168 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___169 kobj;
	const struct kset_uevent_ops___168 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___168 {
	void (*release)(struct kobject___169 *);
	const struct sysfs_ops___168 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___11 * (*child_ns_type)(struct kobject___169 *);
	const void * (*namespace)(struct kobject___169 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___168 {
	int (* const filter)(struct kset___168 *, struct kobject___169 *);
	const char * (* const name)(struct kset___168 *, struct kobject___169 *);
	int (* const uevent)(struct kset___168 *, struct kobject___169 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___145 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___145 *);
	int (*get)(char *, const struct kernel_param___145 *);
	void (*free)(void *);
};

struct kparam_array___145;

struct kernel_param___145 {
	const char *name;
	struct module___148 *mod;
	const struct kernel_param_ops___145 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___145 *arr;
	};
};

struct kparam_array___145 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___145 *ops;
	void *elem;
};

struct module_attribute___145 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___145 *, struct module_kobject___145 *, char *);
	ssize_t (*store)(struct module_attribute___145 *, struct module_kobject___145 *, const char *, size_t);
	void (*setup)(struct module___148 *, const char *);
	int (*test)(struct module___148 *);
	void (*free)(struct module___148 *);
};

struct trace_event_class___100;

struct trace_event_call___100 {
	struct list_head list;
	struct trace_event_class___100 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___21 *prog_array;
	int (*perf_perm)(struct trace_event_call___100 *, struct perf_event___107 *);
};

struct dev_pm_ops___162 {
	int (*prepare)(struct device___162 *);
	void (*complete)(struct device___162 *);
	int (*suspend)(struct device___162 *);
	int (*resume)(struct device___162 *);
	int (*freeze)(struct device___162 *);
	int (*thaw)(struct device___162 *);
	int (*poweroff)(struct device___162 *);
	int (*restore)(struct device___162 *);
	int (*suspend_late)(struct device___162 *);
	int (*resume_early)(struct device___162 *);
	int (*freeze_late)(struct device___162 *);
	int (*thaw_early)(struct device___162 *);
	int (*poweroff_late)(struct device___162 *);
	int (*restore_early)(struct device___162 *);
	int (*suspend_noirq)(struct device___162 *);
	int (*resume_noirq)(struct device___162 *);
	int (*freeze_noirq)(struct device___162 *);
	int (*thaw_noirq)(struct device___162 *);
	int (*poweroff_noirq)(struct device___162 *);
	int (*restore_noirq)(struct device___162 *);
	int (*runtime_suspend)(struct device___162 *);
	int (*runtime_resume)(struct device___162 *);
	int (*runtime_idle)(struct device___162 *);
};

struct dev_pm_domain___162 {
	struct dev_pm_ops___162 ops;
	void (*detach)(struct device___162 *, bool);
	int (*activate)(struct device___162 *);
	void (*sync)(struct device___162 *);
	void (*dismiss)(struct device___162 *);
};

struct bus_type___162 {
	const char *name;
	const char *dev_name;
	struct device___162 *dev_root;
	const struct attribute_group___163 **bus_groups;
	const struct attribute_group___163 **dev_groups;
	const struct attribute_group___163 **drv_groups;
	int (*match)(struct device___162 *, struct device_driver___162 *);
	int (*uevent)(struct device___162 *, struct kobj_uevent_env *);
	int (*probe)(struct device___162 *);
	int (*remove)(struct device___162 *);
	void (*shutdown)(struct device___162 *);
	int (*online)(struct device___162 *);
	int (*offline)(struct device___162 *);
	int (*suspend)(struct device___162 *, pm_message_t);
	int (*resume)(struct device___162 *);
	int (*num_vf)(struct device___162 *);
	int (*dma_configure)(struct device___162 *);
	const struct dev_pm_ops___162 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___162 {
	const char *name;
	struct bus_type___162 *bus;
	struct module___148 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___162 *);
	int (*remove)(struct device___162 *);
	void (*shutdown)(struct device___162 *);
	int (*suspend)(struct device___162 *, pm_message_t);
	int (*resume)(struct device___162 *);
	const struct attribute_group___163 **groups;
	const struct dev_pm_ops___162 *pm;
	void (*coredump)(struct device___162 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___162 {
	const char *name;
	const struct attribute_group___163 **groups;
	int (*uevent)(struct device___162 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___162 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___162 *);
	const struct dev_pm_ops___162 *pm;
};

struct class___162 {
	const char *name;
	struct module___148 *owner;
	const struct attribute_group___163 **class_groups;
	const struct attribute_group___163 **dev_groups;
	struct kobject___169 *dev_kobj;
	int (*dev_uevent)(struct device___162 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___162 *, umode_t *);
	void (*class_release)(struct class___162 *);
	void (*dev_release)(struct device___162 *);
	int (*shutdown_pre)(struct device___162 *);
	const struct kobj_ns_type_operations___11 *ns_type;
	const void * (*namespace)(struct device___162 *);
	const struct dev_pm_ops___162 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___138 {
	struct device___162 dev;
};

struct bpf_map___149;

struct bpf_map_ops___149 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___149 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___149 *, struct file___175 *);
	void (*map_free)(struct bpf_map___149 *);
	int (*map_get_next_key)(struct bpf_map___149 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___149 *);
	void * (*map_lookup_elem)(struct bpf_map___149 *, void *);
	int (*map_update_elem)(struct bpf_map___149 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___149 *, void *);
	int (*map_push_elem)(struct bpf_map___149 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___149 *, void *);
	int (*map_peek_elem)(struct bpf_map___149 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___149 *, struct file___175 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___149 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___149 *, void *, struct seq_file___164 *);
	int (*map_check_btf)(const struct bpf_map___149 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___149 {
	const struct bpf_map_ops___149 *ops;
	struct bpf_map___149 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___170 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___149;

typedef void (*kthread_work_func_t___149)(struct kthread_work___149 *);

struct kthread_worker___149;

struct kthread_work___149 {
	struct list_head node;
	kthread_work_func_t___149 func;
	struct kthread_worker___149 *worker;
	int canceling;
};

struct kthread_worker___149 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___175 *task;
	struct kthread_work___149 *current_work;
};

struct kthread_delayed_work___149 {
	struct kthread_work___149 work;
	struct timer_list timer;
};

struct psi_group___149 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___149 *poll_kworker;
	struct kthread_delayed_work___149 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___149 {
	struct kernfs_node___171 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___149;

struct cgroup_subsys_state___149 {
	struct cgroup___149 *cgroup;
	struct cgroup_subsys___149 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___149 *parent;
};

struct cgroup_root___149;

struct cgroup_rstat_cpu___149;

struct cgroup___149 {
	struct cgroup_subsys_state___149 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___171 *kn;
	struct cgroup_file___149 procs_file;
	struct cgroup_file___149 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___149 *subsys[13];
	struct cgroup_root___149 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___149 *dom_cgrp;
	struct cgroup_rstat_cpu___149 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___21 bpf;
	atomic_t congestion_count;
	struct cgroup___149 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___149 psi;
	int ancestor_ids[0];
};

struct cftype___149;

struct cgroup_subsys___149 {
	struct cgroup_subsys_state___149 * (*css_alloc)(struct cgroup_subsys_state___149 *);
	int (*css_online)(struct cgroup_subsys_state___149 *);
	void (*css_offline)(struct cgroup_subsys_state___149 *);
	void (*css_released)(struct cgroup_subsys_state___149 *);
	void (*css_free)(struct cgroup_subsys_state___149 *);
	void (*css_reset)(struct cgroup_subsys_state___149 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___149 *, int);
	int (*css_extra_stat_show)(struct seq_file___164 *, struct cgroup_subsys_state___149 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___175 *);
	void (*cancel_fork)(struct task_struct___175 *);
	void (*fork)(struct task_struct___175 *);
	void (*exit)(struct task_struct___175 *);
	void (*free)(struct task_struct___175 *);
	void (*bind)(struct cgroup_subsys_state___149 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___149 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___149 *dfl_cftypes;
	struct cftype___149 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___149 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___149 *updated_children;
	struct cgroup___149 *updated_next;
};

struct cgroup_root___149 {
	struct kernfs_root___171 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___149 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___149 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___149 *ss;
	struct list_head node;
	struct kernfs_ops___171 *kf_ops;
	int (*open)(struct kernfs_open_file___171 *);
	void (*release)(struct kernfs_open_file___171 *);
	u64 (*read_u64)(struct cgroup_subsys_state___149 *, struct cftype___149 *);
	s64 (*read_s64)(struct cgroup_subsys_state___149 *, struct cftype___149 *);
	int (*seq_show)(struct seq_file___164 *, void *);
	void * (*seq_start)(struct seq_file___164 *, loff_t *);
	void * (*seq_next)(struct seq_file___164 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___164 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___149 *, struct cftype___149 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___149 *, struct cftype___149 *, s64);
	ssize_t (*write)(struct kernfs_open_file___171 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___171 *, struct poll_table_struct___117 *);
};

struct perf_cpu_context___107;

struct pmu___107 {
	struct list_head entry;
	struct module___148 *module;
	struct device___162 *dev;
	const struct attribute_group___163 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___107 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___107 *);
	void (*pmu_disable)(struct pmu___107 *);
	int (*event_init)(struct perf_event___107 *);
	void (*event_mapped)(struct perf_event___107 *, struct mm_struct___174 *);
	void (*event_unmapped)(struct perf_event___107 *, struct mm_struct___174 *);
	int (*add)(struct perf_event___107 *, int);
	void (*del)(struct perf_event___107 *, int);
	void (*start)(struct perf_event___107 *, int);
	void (*stop)(struct perf_event___107 *, int);
	void (*read)(struct perf_event___107 *);
	void (*start_txn)(struct pmu___107 *, unsigned int);
	int (*commit_txn)(struct pmu___107 *);
	void (*cancel_txn)(struct pmu___107 *);
	int (*event_idx)(struct perf_event___107 *);
	void (*sched_task)(struct perf_event_context___107 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___107 *);
	int (*filter_match)(struct perf_event___107 *);
	int (*check_period)(struct perf_event___107 *, u64);
};

struct perf_cpu_context___107 {
	struct perf_event_context___107 ctx;
	struct perf_event_context___107 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___107 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___107 {
	struct cgroup_subsys_state___149 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___100 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___100 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___100 *);
	struct list_head * (*get_fields)(struct trace_event_call___100 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___100 *);
};

struct syscall_metadata___46 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___100 *enter_event;
	struct trace_event_call___100 *exit_event;
};

struct mountpoint___3;

struct mount___3 {
	struct hlist_node mnt_hash;
	struct mount___3 *mnt_parent;
	struct dentry___174 *mnt_mountpoint;
	struct vfsmount___29 mnt;
	union {
		struct callback_head mnt_rcu;
		struct llist_node mnt_llist;
	};
	struct mnt_pcp *mnt_pcp;
	struct list_head mnt_mounts;
	struct list_head mnt_child;
	struct list_head mnt_instance;
	const char *mnt_devname;
	struct list_head mnt_list;
	struct list_head mnt_expire;
	struct list_head mnt_share;
	struct list_head mnt_slave_list;
	struct list_head mnt_slave;
	struct mount___3 *mnt_master;
	struct mnt_namespace___3 *mnt_ns;
	struct mountpoint___3 *mnt_mp;
	struct hlist_node mnt_mp_list;
	struct list_head mnt_umounting;
	struct fsnotify_mark_connector *mnt_fsnotify_marks;
	__u32 mnt_fsnotify_mask;
	int mnt_id;
	int mnt_group_id;
	int mnt_expiry_mark;
	struct hlist_head mnt_pins;
	struct fs_pin mnt_umount;
	struct dentry___174 *mnt_ex_mountpoint;
};

struct mountpoint___3 {
	struct hlist_node m_hash;
	struct dentry___174 *m_dentry;
	struct hlist_head m_list;
	int m_count;
};

struct proc_mounts {
	struct mnt_namespace___3 *ns;
	struct path___174 root;
	int (*show)(struct seq_file___164 *, struct vfsmount___29 *);
	void *cached_mount;
	u64 cached_event;
	loff_t cached_index;
};

enum umount_tree_flags {
	UMOUNT_SYNC = 1,
	UMOUNT_PROPAGATE = 2,
	UMOUNT_CONNECTED = 4,
};

struct module___149;

struct file___176;

struct kiocb___176;

struct poll_table_struct___118;

struct vm_area_struct___176;

struct inode___176;

struct file_lock___176;

struct page___176;

struct seq_file___165;

struct file_operations___176 {
	struct module___149 *owner;
	loff_t (*llseek)(struct file___176 *, loff_t, int);
	ssize_t (*read)(struct file___176 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___176 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___176 *, struct iov_iter___83 *);
	ssize_t (*write_iter)(struct kiocb___176 *, struct iov_iter___83 *);
	int (*iopoll)(struct kiocb___176 *, bool);
	int (*iterate)(struct file___176 *, struct dir_context *);
	int (*iterate_shared)(struct file___176 *, struct dir_context *);
	__poll_t (*poll)(struct file___176 *, struct poll_table_struct___118 *);
	long int (*unlocked_ioctl)(struct file___176 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___176 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___176 *, struct vm_area_struct___176 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___176 *, struct file___176 *);
	int (*flush)(struct file___176 *, fl_owner_t);
	int (*release)(struct inode___176 *, struct file___176 *);
	int (*fsync)(struct file___176 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___176 *, int);
	int (*lock)(struct file___176 *, int, struct file_lock___176 *);
	ssize_t (*sendpage)(struct file___176 *, struct page___176 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___176 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___176 *, int, struct file_lock___176 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___176 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___176 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___176 *, long int, struct file_lock___176 **, void **);
	long int (*fallocate)(struct file___176 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___165 *, struct file___176 *);
	ssize_t (*copy_file_range)(struct file___176 *, loff_t, struct file___176 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___176 *, loff_t, struct file___176 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___176 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___175 {
	u64 seqnum;
	struct vm_area_struct___176 *vmas[4];
};

struct page_frag___175 {
	struct page___176 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___108;

struct debug_info___108 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___108 *hbp_break[16];
	struct perf_event___108 *hbp_watch[16];
};

struct thread_struct___108 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___108 debug;
	long: 64;
};

struct mm_struct___175;

struct pid___140;

struct cred___171;

struct nsproxy___167;

struct signal_struct___156;

struct css_set___150;

struct perf_event_context___108;

struct vm_struct___127;

struct task_struct___176 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___176 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___175 *mm;
	struct mm_struct___175 *active_mm;
	struct vmacache___175 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___176 *real_parent;
	struct task_struct___176 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___176 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___140 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___140 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___140 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___171 *ptracer_cred;
	const struct cred___171 *real_cred;
	const struct cred___171 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___167 *nsproxy;
	struct signal_struct___156 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___176 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___43 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___150 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___108 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___175 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___176 *oom_reaper_list;
	struct vm_struct___127 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___108 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___108 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___176 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___108)(struct perf_event___108 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___108;

struct fasync_struct___175;

struct pid_namespace___140;

struct trace_event_call___101;

struct perf_cgroup___108;

struct perf_event___108 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___108 *group_leader;
	struct pmu___108 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___108 hw;
	struct perf_event_context___108 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___108 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___176 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___175 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___108 *);
	struct callback_head callback_head;
	struct pid_namespace___140 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___108 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___108 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___101 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___108 *cgrp;
	struct list_head sb_list;
};

struct dentry_operations___175;

struct super_block___175;

struct dentry___175 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___175 *d_parent;
	struct qstr d_name;
	struct inode___176 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___175 *d_op;
	struct super_block___175 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct rw_semaphore___176 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___176 *owner;
};

struct address_space_operations___175;

struct address_space___175 {
	struct inode___176 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___176 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___175 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___175;

struct block_device___176;

struct inode___176 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___175 *i_op;
	struct super_block___175 *i_sb;
	struct address_space___175 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___176 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___176 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___175 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___176 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vfsmount___30;

struct path___175;

struct dentry_operations___175 {
	int (*d_revalidate)(struct dentry___175 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___175 *, unsigned int);
	int (*d_hash)(const struct dentry___175 *, struct qstr *);
	int (*d_compare)(const struct dentry___175 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___175 *);
	int (*d_init)(struct dentry___175 *);
	void (*d_release)(struct dentry___175 *);
	void (*d_prune)(struct dentry___175 *);
	void (*d_iput)(struct dentry___175 *, struct inode___176 *);
	char * (*d_dname)(struct dentry___175 *, char *, int);
	struct vfsmount___30 * (*d_automount)(struct path___175 *);
	int (*d_manage)(const struct path___175 *, bool);
	struct dentry___175 * (*d_real)(struct dentry___175 *, const struct inode___176 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___175;

struct mem_dqinfo___175 {
	struct quota_format_type___175 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___175;

struct quota_info___175 {
	unsigned int flags;
	struct rw_semaphore___176 dqio_sem;
	struct inode___176 *files[3];
	struct mem_dqinfo___175 info[3];
	const struct quota_format_ops___175 *ops[3];
};

struct rcuwait___175 {
	struct task_struct___176 *task;
};

struct percpu_rw_semaphore___175 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___176 rw_sem;
	struct rcuwait___175 writer;
	int readers_block;
};

struct sb_writers___175 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___175 rw_sem[3];
};

struct file_system_type___175;

struct super_operations___175;

struct dquot_operations___175;

struct quotactl_ops___175;

struct xattr_handler___17;

struct user_namespace___155;

struct super_block___175 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___175 *s_type;
	const struct super_operations___175 *s_op;
	const struct dquot_operations___175 *dq_op;
	const struct quotactl_ops___175 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___175 *s_root;
	struct rw_semaphore___176 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___17 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___176 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___175 s_dquot;
	struct sb_writers___175 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___175 *s_d_op;
	int cleancache_poolid;
	struct shrinker___78 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___155 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___30 {
	struct dentry___175 *mnt_root;
	struct super_block___175 *mnt_sb;
	int mnt_flags;
};

struct path___175 {
	struct vfsmount___30 *mnt;
	struct dentry___175 *dentry;
};

struct key___171;

struct ucounts___155;

struct user_namespace___155 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___155 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___10 ns;
	long unsigned int flags;
	struct key___171 *persistent_keyring_register;
	struct rw_semaphore___176 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___155 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___176 *pgtable_t___175;

struct dev_pagemap___173;

struct page___176 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___175 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___176 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___175 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___175 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___173 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___175;

struct lruvec___175 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___175 *pgdat;
};

struct zone___175 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___175 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___175 {
	struct zone___175 *zone;
	int zone_idx;
};

struct zonelist___175 {
	struct zoneref___175 _zonerefs[25];
};

struct pglist_data___175 {
	struct zone___175 node_zones[3];
	struct zonelist___175 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___176 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___176 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___175 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___176 {
	void *stack;
	struct task_struct___176 *task;
	long int status;
};

struct blocking_notifier_head___175 {
	struct rw_semaphore___176 rwsem;
	struct notifier_block *head;
};

struct upid___140 {
	int nr;
	struct pid_namespace___140 *ns;
};

struct pid_namespace___140 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___176 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___140 *parent;
	struct vfsmount___30 *proc_mnt;
	struct dentry___175 *proc_self;
	struct dentry___175 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___155 *user_ns;
	struct ucounts___155 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___10 ns;
};

struct pid___140 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___140 numbers[1];
};

struct vm_operations_struct___173;

struct vm_area_struct___176 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___176 *vm_next;
	struct vm_area_struct___176 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___175 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___173 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___176 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___175;

struct mm_struct___175 {
	struct {
		struct vm_area_struct___176 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___176 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___176 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___175 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___176 *owner;
		struct user_namespace___155 *user_ns;
		struct file___176 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___175 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___173)(struct vm_area_struct___176 *, long unsigned int, const struct page___176 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___173)(struct page___176 *, void *);

struct device___163;

struct dev_pagemap___173 {
	dev_page_fault_t___173 page_fault;
	dev_page_free_t___173 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___163 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct fown_struct___140 {
	rwlock_t lock;
	struct pid___140 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___176 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___175 f_path;
	struct inode___176 *f_inode;
	const struct file_operations___176 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___140 f_owner;
	const struct cred___171 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___175 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___173;

struct vm_operations_struct___173 {
	void (*open)(struct vm_area_struct___176 *);
	void (*close)(struct vm_area_struct___176 *);
	int (*split)(struct vm_area_struct___176 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___176 *);
	vm_fault_t (*fault)(struct vm_fault___173 *);
	vm_fault_t (*huge_fault)(struct vm_fault___173 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___173 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___176 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___173 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___173 *);
	int (*access)(struct vm_area_struct___176 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___176 *);
	int (*set_policy)(struct vm_area_struct___176 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___176 *, long unsigned int);
	struct page___176 * (*find_special_page)(struct vm_area_struct___176 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___175 {
	struct task_struct___176 *task;
	struct core_thread___175 *next;
};

struct core_state___175 {
	atomic_t nr_threads;
	struct core_thread___175 dumper;
	struct completion startup;
};

struct vm_fault___173 {
	struct vm_area_struct___176 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___176 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___176 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___175 prealloc_pte;
};

struct user_struct___171 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___171 *uid_keyring;
	struct key___171 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___171 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___171 *session_keyring;
	struct key___171 *process_keyring;
	struct key___171 *thread_keyring;
	struct key___171 *request_key_auth;
	void *security;
	struct user_struct___171 *user;
	struct user_namespace___155 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___150;

struct nsproxy___167 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___140 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___150 *cgroup_ns;
};

struct signal_struct___156 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___176 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___176 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___140 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___140 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___175 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___140 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___150;

struct cgroup___150;

struct css_set___150 {
	struct cgroup_subsys_state___150 *subsys[13];
	refcount_t refcount;
	struct css_set___150 *dom_cset;
	struct cgroup___150 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___150 *mg_src_cgrp;
	struct cgroup___150 *mg_dst_cgrp;
	struct css_set___150 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___108 {
	struct pmu___108 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___176 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___108 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___127 {
	struct vm_struct___127 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___176 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___157 {
	struct task_struct___176 task;
	long unsigned int stack[8192];
};

struct kiocb___176 {
	struct file___176 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___176 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___175 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___176 *ia_file;
};

struct dquot___175 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___175 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___175 {
	int qf_fmt_id;
	const struct quota_format_ops___175 *qf_ops;
	struct module___149 *qf_owner;
	struct quota_format_type___175 *qf_next;
};

struct quota_format_ops___175 {
	int (*check_quota_file)(struct super_block___175 *, int);
	int (*read_file_info)(struct super_block___175 *, int);
	int (*write_file_info)(struct super_block___175 *, int);
	int (*free_file_info)(struct super_block___175 *, int);
	int (*read_dqblk)(struct dquot___175 *);
	int (*commit_dqblk)(struct dquot___175 *);
	int (*release_dqblk)(struct dquot___175 *);
	int (*get_next_id)(struct super_block___175 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___175 {
	int (*write_dquot)(struct dquot___175 *);
	struct dquot___175 * (*alloc_dquot)(struct super_block___175 *, int);
	void (*destroy_dquot)(struct dquot___175 *);
	int (*acquire_dquot)(struct dquot___175 *);
	int (*release_dquot)(struct dquot___175 *);
	int (*mark_dirty)(struct dquot___175 *);
	int (*write_info)(struct super_block___175 *, int);
	qsize_t * (*get_reserved_space)(struct inode___176 *);
	int (*get_projid)(struct inode___176 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___176 *, qsize_t *);
	int (*get_next_id)(struct super_block___175 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___175 {
	int (*quota_on)(struct super_block___175 *, int, int, const struct path___175 *);
	int (*quota_off)(struct super_block___175 *, int);
	int (*quota_enable)(struct super_block___175 *, unsigned int);
	int (*quota_disable)(struct super_block___175 *, unsigned int);
	int (*quota_sync)(struct super_block___175 *, int);
	int (*set_info)(struct super_block___175 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___175 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___175 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___175 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___175 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___175 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___169;

struct kobj_type___169;

struct kernfs_node___172;

struct kobject___170 {
	const char *name;
	struct list_head entry;
	struct kobject___170 *parent;
	struct kset___169 *kset;
	struct kobj_type___169 *ktype;
	struct kernfs_node___172 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___146 {
	struct kobject___170 kobj;
	struct module___149 *mod;
	struct kobject___170 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___146 {
	struct module___149 *mod;
	struct latch_tree_node node;
};

struct module_layout___146 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___146 mtn;
};

struct module_attribute___146;

struct kernel_param___146;

struct module___149 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___146 mkobj;
	struct module_attribute___146 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___170 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___146 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___146 core_layout;
	struct module_layout___146 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___101 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___175 {
	int (*writepage)(struct page___176 *, struct writeback_control___3 *);
	int (*readpage)(struct file___176 *, struct page___176 *);
	int (*writepages)(struct address_space___175 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___176 *);
	int (*readpages)(struct file___176 *, struct address_space___175 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___176 *, struct address_space___175 *, loff_t, unsigned int, unsigned int, struct page___176 **, void **);
	int (*write_end)(struct file___176 *, struct address_space___175 *, loff_t, unsigned int, unsigned int, struct page___176 *, void *);
	sector_t (*bmap)(struct address_space___175 *, sector_t);
	void (*invalidatepage)(struct page___176 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___176 *, gfp_t);
	void (*freepage)(struct page___176 *);
	ssize_t (*direct_IO)(struct kiocb___176 *, struct iov_iter___83 *);
	int (*migratepage)(struct address_space___175 *, struct page___176 *, struct page___176 *, enum migrate_mode);
	bool (*isolate_page)(struct page___176 *, isolate_mode_t);
	void (*putback_page)(struct page___176 *);
	int (*launder_page)(struct page___176 *);
	int (*is_partially_uptodate)(struct page___176 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___176 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___175 *, struct page___176 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___176 *, sector_t *);
	void (*swap_deactivate)(struct file___176 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___176 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___176 *bd_inode;
	struct super_block___175 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___176 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___175 {
	struct dentry___175 * (*lookup)(struct inode___176 *, struct dentry___175 *, unsigned int);
	const char * (*get_link)(struct dentry___175 *, struct inode___176 *, struct delayed_call *);
	int (*permission)(struct inode___176 *, int);
	struct posix_acl * (*get_acl)(struct inode___176 *, int);
	int (*readlink)(struct dentry___175 *, char *, int);
	int (*create)(struct inode___176 *, struct dentry___175 *, umode_t, bool);
	int (*link)(struct dentry___175 *, struct inode___176 *, struct dentry___175 *);
	int (*unlink)(struct inode___176 *, struct dentry___175 *);
	int (*symlink)(struct inode___176 *, struct dentry___175 *, const char *);
	int (*mkdir)(struct inode___176 *, struct dentry___175 *, umode_t);
	int (*rmdir)(struct inode___176 *, struct dentry___175 *);
	int (*mknod)(struct inode___176 *, struct dentry___175 *, umode_t, dev_t);
	int (*rename)(struct inode___176 *, struct dentry___175 *, struct inode___176 *, struct dentry___175 *, unsigned int);
	int (*setattr)(struct dentry___175 *, struct iattr___175 *);
	int (*getattr)(const struct path___175 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___175 *, char *, size_t);
	int (*fiemap)(struct inode___176 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___176 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___176 *, struct dentry___175 *, struct file___176 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___176 *, struct dentry___175 *, umode_t);
	int (*set_acl)(struct inode___176 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___175 {
	void (*fl_copy_lock)(struct file_lock___176 *, struct file_lock___176 *);
	void (*fl_release_private)(struct file_lock___176 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___175;

struct file_lock___176 {
	struct file_lock___176 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___176 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___175 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___175 *fl_ops;
	const struct lock_manager_operations___175 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___175 {
	int (*lm_compare_owner)(struct file_lock___176 *, struct file_lock___176 *);
	long unsigned int (*lm_owner_key)(struct file_lock___176 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___176 *);
	int (*lm_grant)(struct file_lock___176 *, int);
	bool (*lm_break)(struct file_lock___176 *);
	int (*lm_change)(struct file_lock___176 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___176 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___175 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___175 *fa_next;
	struct file___176 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___175 {
	const char *name;
	int fs_flags;
	struct dentry___175 * (*mount)(struct file_system_type___175 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___175 *);
	struct module___149 *owner;
	struct file_system_type___175 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___175 {
	struct inode___176 * (*alloc_inode)(struct super_block___175 *);
	void (*destroy_inode)(struct inode___176 *);
	void (*dirty_inode)(struct inode___176 *, int);
	int (*write_inode)(struct inode___176 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___176 *);
	void (*evict_inode)(struct inode___176 *);
	void (*put_super)(struct super_block___175 *);
	int (*sync_fs)(struct super_block___175 *, int);
	int (*freeze_super)(struct super_block___175 *);
	int (*freeze_fs)(struct super_block___175 *);
	int (*thaw_super)(struct super_block___175 *);
	int (*unfreeze_fs)(struct super_block___175 *);
	int (*statfs)(struct dentry___175 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___175 *, int *, char *);
	void (*umount_begin)(struct super_block___175 *);
	int (*show_options)(struct seq_file___165 *, struct dentry___175 *);
	int (*show_devname)(struct seq_file___165 *, struct dentry___175 *);
	int (*show_path)(struct seq_file___165 *, struct dentry___175 *);
	int (*show_stats)(struct seq_file___165 *, struct dentry___175 *);
	ssize_t (*quota_read)(struct super_block___175 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___175 *, int, const char *, size_t, loff_t);
	struct dquot___175 ** (*get_dquots)(struct inode___176 *);
	int (*bdev_try_to_free_page)(struct super_block___175 *, struct page___176 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___175 *, struct shrink_control___78 *);
	long int (*free_cached_objects)(struct super_block___175 *, struct shrink_control___78 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct xattr_handler___17 {
	const char *name;
	const char *prefix;
	int flags;
	bool (*list)(struct dentry___175 *);
	int (*get)(const struct xattr_handler___17 *, struct dentry___175 *, struct inode___176 *, const char *, void *, size_t);
	int (*set)(const struct xattr_handler___17 *, struct dentry___175 *, struct inode___176 *, const char *, const void *, size_t, int);
};

typedef void (*poll_queue_proc___117)(struct file___176 *, wait_queue_head_t *, struct poll_table_struct___118 *);

struct poll_table_struct___118 {
	poll_queue_proc___117 _qproc;
	__poll_t _key;
};

struct seq_operations___163;

struct seq_file___165 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___163 *op;
	int poll_event;
	const struct file___176 *file;
	void *private;
};

struct fd___19 {
	struct file___176 *file;
	unsigned int flags;
};

typedef int (*key_restrict_link_func_t___171)(struct key___171 *, const struct key_type *, const union key_payload *, struct key___171 *);

struct key_restriction___171;

struct key___171 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___176 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___171 *restrict_link;
};

struct key_restriction___171 {
	key_restrict_link_func_t___171 check;
	struct key___171 *key;
	struct key_type *keytype;
};

struct dev_pm_info___163 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___163 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___163;

struct bus_type___163;

struct device_driver___163;

struct dev_pm_domain___163;

struct class___163;

struct attribute_group___164;

struct device___163 {
	struct device___163 *parent;
	struct device_private *p;
	struct kobject___170 kobj;
	const char *init_name;
	const struct device_type___163 *type;
	struct mutex mutex;
	struct bus_type___163 *bus;
	struct device_driver___163 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___163 power;
	struct dev_pm_domain___163 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___163 *class;
	const struct attribute_group___164 **groups;
	void (*release)(struct device___163 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct kobj_attribute___170 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___170 *, struct kobj_attribute___170 *, char *);
	ssize_t (*store)(struct kobject___170 *, struct kobj_attribute___170 *, const char *, size_t);
};

typedef void compound_page_dtor___173(struct page___176 *);

struct seq_operations___163 {
	void * (*start)(struct seq_file___165 *, loff_t *);
	void (*stop)(struct seq_file___165 *, void *);
	void * (*next)(struct seq_file___165 *, void *, loff_t *);
	int (*show)(struct seq_file___165 *, void *);
};

struct cgroup_namespace___150 {
	refcount_t count;
	struct ns_common___10 ns;
	struct user_namespace___155 *user_ns;
	struct ucounts___155 *ucounts;
	struct css_set___150 *root_cset;
};

struct ucounts___155 {
	struct hlist_node node;
	struct user_namespace___155 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct kernfs_root___172;

struct kernfs_elem_dir___172 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___172 *root;
};

struct kernfs_syscall_ops___172;

struct kernfs_root___172 {
	struct kernfs_node___172 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___172 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___172 {
	struct kernfs_node___172 *target_kn;
};

struct kernfs_ops___172;

struct kernfs_elem_attr___172 {
	const struct kernfs_ops___172 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___172 *notify_next;
};

struct kernfs_node___172 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___172 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___172 dir;
		struct kernfs_elem_symlink___172 symlink;
		struct kernfs_elem_attr___172 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___172;

struct kernfs_ops___172 {
	int (*open)(struct kernfs_open_file___172 *);
	void (*release)(struct kernfs_open_file___172 *);
	int (*seq_show)(struct seq_file___165 *, void *);
	void * (*seq_start)(struct seq_file___165 *, loff_t *);
	void * (*seq_next)(struct seq_file___165 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___165 *, void *);
	ssize_t (*read)(struct kernfs_open_file___172 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___172 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___172 *, struct vm_area_struct___176 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___172 *, struct poll_table_struct___118 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___172 {
	int (*remount_fs)(struct kernfs_root___172 *, int *, char *);
	int (*show_options)(struct seq_file___165 *, struct kernfs_root___172 *);
	int (*mkdir)(struct kernfs_node___172 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___172 *);
	int (*rename)(struct kernfs_node___172 *, struct kernfs_node___172 *, const char *);
	int (*show_path)(struct seq_file___165 *, struct kernfs_node___172 *, struct kernfs_root___172 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___172 {
	struct kernfs_node___172 *kn;
	struct file___176 *file;
	struct seq_file___165 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___173 *vm_ops;
};

struct bin_attribute___163;

struct attribute_group___164 {
	const char *name;
	umode_t (*is_visible)(struct kobject___170 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___170 *, struct bin_attribute___163 *, int);
	struct attribute **attrs;
	struct bin_attribute___163 **bin_attrs;
};

struct bin_attribute___163 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___176 *, struct kobject___170 *, struct bin_attribute___163 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___176 *, struct kobject___170 *, struct bin_attribute___163 *, char *, loff_t, size_t);
	int (*mmap)(struct file___176 *, struct kobject___170 *, struct bin_attribute___163 *, struct vm_area_struct___176 *);
};

struct sysfs_ops___169 {
	ssize_t (*show)(struct kobject___170 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___170 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___169;

struct kset___169 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___170 kobj;
	const struct kset_uevent_ops___169 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___169 {
	void (*release)(struct kobject___170 *);
	const struct sysfs_ops___169 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___11 * (*child_ns_type)(struct kobject___170 *);
	const void * (*namespace)(struct kobject___170 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___169 {
	int (* const filter)(struct kset___169 *, struct kobject___170 *);
	const char * (* const name)(struct kset___169 *, struct kobject___170 *);
	int (* const uevent)(struct kset___169 *, struct kobject___170 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___146 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___146 *);
	int (*get)(char *, const struct kernel_param___146 *);
	void (*free)(void *);
};

struct kparam_array___146;

struct kernel_param___146 {
	const char *name;
	struct module___149 *mod;
	const struct kernel_param_ops___146 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___146 *arr;
	};
};

struct kparam_array___146 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___146 *ops;
	void *elem;
};

struct module_attribute___146 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___146 *, struct module_kobject___146 *, char *);
	ssize_t (*store)(struct module_attribute___146 *, struct module_kobject___146 *, const char *, size_t);
	void (*setup)(struct module___149 *, const char *);
	int (*test)(struct module___149 *);
	void (*free)(struct module___149 *);
};

struct trace_event_class___101;

struct trace_event_call___101 {
	struct list_head list;
	struct trace_event_class___101 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___21 *prog_array;
	int (*perf_perm)(struct trace_event_call___101 *, struct perf_event___108 *);
};

struct dev_pm_ops___163 {
	int (*prepare)(struct device___163 *);
	void (*complete)(struct device___163 *);
	int (*suspend)(struct device___163 *);
	int (*resume)(struct device___163 *);
	int (*freeze)(struct device___163 *);
	int (*thaw)(struct device___163 *);
	int (*poweroff)(struct device___163 *);
	int (*restore)(struct device___163 *);
	int (*suspend_late)(struct device___163 *);
	int (*resume_early)(struct device___163 *);
	int (*freeze_late)(struct device___163 *);
	int (*thaw_early)(struct device___163 *);
	int (*poweroff_late)(struct device___163 *);
	int (*restore_early)(struct device___163 *);
	int (*suspend_noirq)(struct device___163 *);
	int (*resume_noirq)(struct device___163 *);
	int (*freeze_noirq)(struct device___163 *);
	int (*thaw_noirq)(struct device___163 *);
	int (*poweroff_noirq)(struct device___163 *);
	int (*restore_noirq)(struct device___163 *);
	int (*runtime_suspend)(struct device___163 *);
	int (*runtime_resume)(struct device___163 *);
	int (*runtime_idle)(struct device___163 *);
};

struct dev_pm_domain___163 {
	struct dev_pm_ops___163 ops;
	void (*detach)(struct device___163 *, bool);
	int (*activate)(struct device___163 *);
	void (*sync)(struct device___163 *);
	void (*dismiss)(struct device___163 *);
};

struct bus_type___163 {
	const char *name;
	const char *dev_name;
	struct device___163 *dev_root;
	const struct attribute_group___164 **bus_groups;
	const struct attribute_group___164 **dev_groups;
	const struct attribute_group___164 **drv_groups;
	int (*match)(struct device___163 *, struct device_driver___163 *);
	int (*uevent)(struct device___163 *, struct kobj_uevent_env *);
	int (*probe)(struct device___163 *);
	int (*remove)(struct device___163 *);
	void (*shutdown)(struct device___163 *);
	int (*online)(struct device___163 *);
	int (*offline)(struct device___163 *);
	int (*suspend)(struct device___163 *, pm_message_t);
	int (*resume)(struct device___163 *);
	int (*num_vf)(struct device___163 *);
	int (*dma_configure)(struct device___163 *);
	const struct dev_pm_ops___163 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___163 {
	const char *name;
	struct bus_type___163 *bus;
	struct module___149 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___163 *);
	int (*remove)(struct device___163 *);
	void (*shutdown)(struct device___163 *);
	int (*suspend)(struct device___163 *, pm_message_t);
	int (*resume)(struct device___163 *);
	const struct attribute_group___164 **groups;
	const struct dev_pm_ops___163 *pm;
	void (*coredump)(struct device___163 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___163 {
	const char *name;
	const struct attribute_group___164 **groups;
	int (*uevent)(struct device___163 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___163 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___163 *);
	const struct dev_pm_ops___163 *pm;
};

struct class___163 {
	const char *name;
	struct module___149 *owner;
	const struct attribute_group___164 **class_groups;
	const struct attribute_group___164 **dev_groups;
	struct kobject___170 *dev_kobj;
	int (*dev_uevent)(struct device___163 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___163 *, umode_t *);
	void (*class_release)(struct class___163 *);
	void (*dev_release)(struct device___163 *);
	int (*shutdown_pre)(struct device___163 *);
	const struct kobj_ns_type_operations___11 *ns_type;
	const void * (*namespace)(struct device___163 *);
	const struct dev_pm_ops___163 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___139 {
	struct device___163 dev;
};

struct bpf_map___150;

struct bpf_map_ops___150 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___150 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___150 *, struct file___176 *);
	void (*map_free)(struct bpf_map___150 *);
	int (*map_get_next_key)(struct bpf_map___150 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___150 *);
	void * (*map_lookup_elem)(struct bpf_map___150 *, void *);
	int (*map_update_elem)(struct bpf_map___150 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___150 *, void *);
	int (*map_push_elem)(struct bpf_map___150 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___150 *, void *);
	int (*map_peek_elem)(struct bpf_map___150 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___150 *, struct file___176 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___150 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___150 *, void *, struct seq_file___165 *);
	int (*map_check_btf)(const struct bpf_map___150 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___150 {
	const struct bpf_map_ops___150 *ops;
	struct bpf_map___150 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___171 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___150;

typedef void (*kthread_work_func_t___150)(struct kthread_work___150 *);

struct kthread_worker___150;

struct kthread_work___150 {
	struct list_head node;
	kthread_work_func_t___150 func;
	struct kthread_worker___150 *worker;
	int canceling;
};

struct kthread_worker___150 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___176 *task;
	struct kthread_work___150 *current_work;
};

struct kthread_delayed_work___150 {
	struct kthread_work___150 work;
	struct timer_list timer;
};

struct psi_group___150 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___150 *poll_kworker;
	struct kthread_delayed_work___150 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___150 {
	struct kernfs_node___172 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___150;

struct cgroup_subsys_state___150 {
	struct cgroup___150 *cgroup;
	struct cgroup_subsys___150 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___150 *parent;
};

struct cgroup_root___150;

struct cgroup_rstat_cpu___150;

struct cgroup___150 {
	struct cgroup_subsys_state___150 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___172 *kn;
	struct cgroup_file___150 procs_file;
	struct cgroup_file___150 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___150 *subsys[13];
	struct cgroup_root___150 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___150 *dom_cgrp;
	struct cgroup_rstat_cpu___150 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___21 bpf;
	atomic_t congestion_count;
	struct cgroup___150 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___150 psi;
	int ancestor_ids[0];
};

struct cftype___150;

struct cgroup_subsys___150 {
	struct cgroup_subsys_state___150 * (*css_alloc)(struct cgroup_subsys_state___150 *);
	int (*css_online)(struct cgroup_subsys_state___150 *);
	void (*css_offline)(struct cgroup_subsys_state___150 *);
	void (*css_released)(struct cgroup_subsys_state___150 *);
	void (*css_free)(struct cgroup_subsys_state___150 *);
	void (*css_reset)(struct cgroup_subsys_state___150 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___150 *, int);
	int (*css_extra_stat_show)(struct seq_file___165 *, struct cgroup_subsys_state___150 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___176 *);
	void (*cancel_fork)(struct task_struct___176 *);
	void (*fork)(struct task_struct___176 *);
	void (*exit)(struct task_struct___176 *);
	void (*free)(struct task_struct___176 *);
	void (*bind)(struct cgroup_subsys_state___150 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___150 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___150 *dfl_cftypes;
	struct cftype___150 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___150 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___150 *updated_children;
	struct cgroup___150 *updated_next;
};

struct cgroup_root___150 {
	struct kernfs_root___172 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___150 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___150 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___150 *ss;
	struct list_head node;
	struct kernfs_ops___172 *kf_ops;
	int (*open)(struct kernfs_open_file___172 *);
	void (*release)(struct kernfs_open_file___172 *);
	u64 (*read_u64)(struct cgroup_subsys_state___150 *, struct cftype___150 *);
	s64 (*read_s64)(struct cgroup_subsys_state___150 *, struct cftype___150 *);
	int (*seq_show)(struct seq_file___165 *, void *);
	void * (*seq_start)(struct seq_file___165 *, loff_t *);
	void * (*seq_next)(struct seq_file___165 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___165 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___150 *, struct cftype___150 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___150 *, struct cftype___150 *, s64);
	ssize_t (*write)(struct kernfs_open_file___172 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___172 *, struct poll_table_struct___118 *);
};

struct perf_cpu_context___108;

struct pmu___108 {
	struct list_head entry;
	struct module___149 *module;
	struct device___163 *dev;
	const struct attribute_group___164 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___108 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___108 *);
	void (*pmu_disable)(struct pmu___108 *);
	int (*event_init)(struct perf_event___108 *);
	void (*event_mapped)(struct perf_event___108 *, struct mm_struct___175 *);
	void (*event_unmapped)(struct perf_event___108 *, struct mm_struct___175 *);
	int (*add)(struct perf_event___108 *, int);
	void (*del)(struct perf_event___108 *, int);
	void (*start)(struct perf_event___108 *, int);
	void (*stop)(struct perf_event___108 *, int);
	void (*read)(struct perf_event___108 *);
	void (*start_txn)(struct pmu___108 *, unsigned int);
	int (*commit_txn)(struct pmu___108 *);
	void (*cancel_txn)(struct pmu___108 *);
	int (*event_idx)(struct perf_event___108 *);
	void (*sched_task)(struct perf_event_context___108 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___108 *);
	int (*filter_match)(struct perf_event___108 *);
	int (*check_period)(struct perf_event___108 *, u64);
};

struct perf_cpu_context___108 {
	struct perf_event_context___108 ctx;
	struct perf_event_context___108 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___108 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___108 {
	struct cgroup_subsys_state___150 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___101 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___101 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___101 *);
	struct list_head * (*get_fields)(struct trace_event_call___101 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___101 *);
};

struct syscall_metadata___47 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___101 *enter_event;
	struct trace_event_call___101 *exit_event;
};

struct tree_descr___2 {
	const char *name;
	const struct file_operations___165 *ops;
	int mode;
};

struct simple_transaction_argresp {
	ssize_t size;
	char data[0];
};

struct simple_attr {
	int (*get)(void *, u64 *);
	int (*set)(void *, u64);
	char get_buf[24];
	char set_buf[24];
	void *data;
	const char *fmt;
	struct mutex mutex;
};

struct module___150;

struct file___177;

struct kiocb___177;

struct iov_iter___84;

struct poll_table_struct___119;

struct vm_area_struct___177;

struct inode___177;

struct file_lock___177;

struct page___177;

struct seq_file___166;

struct file_operations___177 {
	struct module___150 *owner;
	loff_t (*llseek)(struct file___177 *, loff_t, int);
	ssize_t (*read)(struct file___177 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___177 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___177 *, struct iov_iter___84 *);
	ssize_t (*write_iter)(struct kiocb___177 *, struct iov_iter___84 *);
	int (*iopoll)(struct kiocb___177 *, bool);
	int (*iterate)(struct file___177 *, struct dir_context *);
	int (*iterate_shared)(struct file___177 *, struct dir_context *);
	__poll_t (*poll)(struct file___177 *, struct poll_table_struct___119 *);
	long int (*unlocked_ioctl)(struct file___177 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___177 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___177 *, struct vm_area_struct___177 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___177 *, struct file___177 *);
	int (*flush)(struct file___177 *, fl_owner_t);
	int (*release)(struct inode___177 *, struct file___177 *);
	int (*fsync)(struct file___177 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___177 *, int);
	int (*lock)(struct file___177 *, int, struct file_lock___177 *);
	ssize_t (*sendpage)(struct file___177 *, struct page___177 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___177 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___177 *, int, struct file_lock___177 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___177 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___177 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___177 *, long int, struct file_lock___177 **, void **);
	long int (*fallocate)(struct file___177 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___166 *, struct file___177 *);
	ssize_t (*copy_file_range)(struct file___177 *, loff_t, struct file___177 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___177 *, loff_t, struct file___177 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___177 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___176 {
	u64 seqnum;
	struct vm_area_struct___177 *vmas[4];
};

struct page_frag___176 {
	struct page___177 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___109;

struct debug_info___109 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___109 *hbp_break[16];
	struct perf_event___109 *hbp_watch[16];
};

struct thread_struct___109 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___109 debug;
	long: 64;
};

struct mm_struct___176;

struct mem_cgroup___79;

struct pid___141;

struct cred___172;

struct nsproxy___168;

struct signal_struct___157;

struct bio_list___87;

struct backing_dev_info___87;

struct io_context___44;

struct css_set___151;

struct perf_event_context___109;

struct request_queue___41;

struct vm_struct___128;

struct task_struct___177 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___177 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___176 *mm;
	struct mm_struct___176 *active_mm;
	struct vmacache___176 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___177 *real_parent;
	struct task_struct___177 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___177 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___79 *active_memcg;
	long int rh_reserved2;
	struct pid___141 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___141 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___141 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___172 *ptracer_cred;
	const struct cred___172 *real_cred;
	const struct cred___172 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___168 *nsproxy;
	struct signal_struct___157 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___177 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___87 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___87 *backing_dev_info;
	struct io_context___44 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___151 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___109 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___176 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___79 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___41 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___177 *oom_reaper_list;
	struct vm_struct___128 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___109 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___109 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___177 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___109)(struct perf_event___109 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___109;

struct fasync_struct___176;

struct pid_namespace___141;

struct trace_event_call___102;

struct perf_cgroup___109;

struct perf_event___109 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___109 *group_leader;
	struct pmu___109 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___109 hw;
	struct perf_event_context___109 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___109 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___177 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___176 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___109 *);
	struct callback_head callback_head;
	struct pid_namespace___141 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___109 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___109 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___102 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___109 *cgrp;
	struct list_head sb_list;
};

typedef struct page___177 *pgtable_t___176;

struct address_space___176;

struct dev_pagemap___174;

struct page___177 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___176 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___177 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___176 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___176 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___174 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___79 *mem_cgroup;
};

struct pglist_data___176;

struct lruvec___176 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___176 *pgdat;
};

struct zone___176 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___176 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___176 {
	struct zone___176 *zone;
	int zone_idx;
};

struct zonelist___176 {
	struct zoneref___176 _zonerefs[25];
};

struct pglist_data___176 {
	struct zone___176 node_zones[3];
	struct zonelist___176 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___177 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___177 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___176 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___177 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___177 *owner;
};

struct secondary_data___177 {
	void *stack;
	struct task_struct___177 *task;
	long int status;
};

struct blocking_notifier_head___176 {
	struct rw_semaphore___177 rwsem;
	struct notifier_block *head;
};

struct cgroup___151;

struct cgroup_subsys___151;

struct cgroup_subsys_state___151 {
	struct cgroup___151 *cgroup;
	struct cgroup_subsys___151 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___151 *parent;
};

struct kernfs_node___173;

struct cgroup_file___151 {
	struct kernfs_node___173 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___79;

struct mem_cgroup___79 {
	struct cgroup_subsys_state___151 css;
	struct mem_cgroup_id___17 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___151 events_file;
	struct cgroup_file___151 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___177 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___79 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct upid___141 {
	int nr;
	struct pid_namespace___141 *ns;
};

struct dentry___176;

struct user_namespace___156;

struct ucounts___156;

struct pid_namespace___141 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___177 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___141 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___176 *proc_self;
	struct dentry___176 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___156 *user_ns;
	struct ucounts___156 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___10 ns;
};

struct pid___141 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___141 numbers[1];
};

struct key___172;

struct user_namespace___156 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___156 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___10 ns;
	long unsigned int flags;
	struct key___172 *persistent_keyring_register;
	struct rw_semaphore___177 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___156 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct user_struct___172 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___172 *uid_keyring;
	struct key___172 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___174;

struct vm_area_struct___177 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___177 *vm_next;
	struct vm_area_struct___177 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___176 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___174 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___177 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___176;

struct mm_struct___176 {
	struct {
		struct vm_area_struct___177 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___177 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___177 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___176 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___177 *owner;
		struct user_namespace___156 *user_ns;
		struct file___177 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___176 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___172 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___172 *session_keyring;
	struct key___172 *process_keyring;
	struct key___172 *thread_keyring;
	struct key___172 *request_key_auth;
	void *security;
	struct user_struct___172 *user;
	struct user_namespace___156 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___151;

struct nsproxy___168 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___141 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___151 *cgroup_ns;
};

struct signal_struct___157 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___177 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___177 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___141 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___141 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___176 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___141 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide45;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___87;

struct bio_list___87 {
	struct bio___87 *head;
	struct bio___87 *tail;
};

struct bdi_writeback_congested___87;

struct bdi_writeback___87 {
	struct backing_dev_info___87 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___87 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___151 *memcg_css;
	struct cgroup_subsys_state___151 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___164;

struct backing_dev_info___87 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___87 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___164 *dev;
	struct device___164 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___176 *debug_dir;
	struct dentry___176 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___44;

struct io_context___44 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___44 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___151 {
	struct cgroup_subsys_state___151 *subsys[13];
	refcount_t refcount;
	struct css_set___151 *dom_cset;
	struct cgroup___151 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___151 *mg_src_cgrp;
	struct cgroup___151 *mg_dst_cgrp;
	struct css_set___151 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___109 {
	struct pmu___109 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___177 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___109 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

typedef blk_qc_t make_request_fn___40(struct request_queue___41 *, struct bio___87 *);

struct request___41;

typedef int dma_drain_needed_fn___40(struct request___41 *);

struct kset___170;

struct kobj_type___170;

struct kobject___171 {
	const char *name;
	struct list_head entry;
	struct kobject___171 *parent;
	struct kset___170 *kset;
	struct kobj_type___170 *ktype;
	struct kernfs_node___173 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___40;

struct bsg_class_device___40 {
	struct device___164 *class_dev;
	int minor;
	struct request_queue___41 *queue;
	const struct bsg_ops___40 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___87 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___87 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___40;

struct blkcg_gq___31;

struct request_queue___41 {
	struct list_head queue_head;
	struct request___41 *last_merge;
	struct elevator_queue___40 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___40 *make_request_fn;
	dma_drain_needed_fn___40 *dma_drain_needed;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___87 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___171 kobj;
	struct kobject___171 *mq_kobj;
	struct blk_integrity integrity;
	struct device___164 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___31 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	struct bsg_class_device___40 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___87 bio_split;
	struct dentry___176 *debugfs_dir;
	struct dentry___176 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___128 {
	struct vm_struct___128 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___177 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___158 {
	struct task_struct___177 task;
	long unsigned int stack[8192];
};

struct dentry_operations___176;

struct super_block___176;

struct dentry___176 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___176 *d_parent;
	struct qstr d_name;
	struct inode___177 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___176 *d_op;
	struct super_block___176 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___176;

struct address_space___176 {
	struct inode___177 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___177 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___176 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___176;

struct block_device___177;

struct inode___177 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___176 *i_op;
	struct super_block___176 *i_sb;
	struct address_space___176 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___177 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___87 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___177 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___176 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___177 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___176;

struct dentry_operations___176 {
	int (*d_revalidate)(struct dentry___176 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___176 *, unsigned int);
	int (*d_hash)(const struct dentry___176 *, struct qstr *);
	int (*d_compare)(const struct dentry___176 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___176 *);
	int (*d_init)(struct dentry___176 *);
	void (*d_release)(struct dentry___176 *);
	void (*d_prune)(struct dentry___176 *);
	void (*d_iput)(struct dentry___176 *, struct inode___177 *);
	char * (*d_dname)(struct dentry___176 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___176 *);
	int (*d_manage)(const struct path___176 *, bool);
	struct dentry___176 * (*d_real)(struct dentry___176 *, const struct inode___177 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___176;

struct mem_dqinfo___176 {
	struct quota_format_type___176 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___176;

struct quota_info___176 {
	unsigned int flags;
	struct rw_semaphore___177 dqio_sem;
	struct inode___177 *files[3];
	struct mem_dqinfo___176 info[3];
	const struct quota_format_ops___176 *ops[3];
};

struct rcuwait___176 {
	struct task_struct___177 *task;
};

struct percpu_rw_semaphore___176 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___177 rw_sem;
	struct rcuwait___176 writer;
	int readers_block;
};

struct sb_writers___176 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___176 rw_sem[3];
};

struct shrink_control___79;

struct shrinker___79 {
	long unsigned int (*count_objects)(struct shrinker___79 *, struct shrink_control___79 *);
	long unsigned int (*scan_objects)(struct shrinker___79 *, struct shrink_control___79 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___176;

struct super_operations___176;

struct dquot_operations___176;

struct quotactl_ops___176;

struct super_block___176 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___176 *s_type;
	const struct super_operations___176 *s_op;
	const struct dquot_operations___176 *dq_op;
	const struct quotactl_ops___176 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___176 *s_root;
	struct rw_semaphore___177 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___177 *s_bdev;
	struct backing_dev_info___87 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___176 s_dquot;
	struct sb_writers___176 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___176 *s_d_op;
	int cleancache_poolid;
	struct shrinker___79 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___156 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct path___176 {
	struct vfsmount *mnt;
	struct dentry___176 *dentry;
};

struct shrink_control___79 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___79 *memcg;
};

typedef int (*dev_page_fault_t___174)(struct vm_area_struct___177 *, long unsigned int, const struct page___177 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___174)(struct page___177 *, void *);

struct dev_pagemap___174 {
	dev_page_fault_t___174 page_fault;
	dev_page_free_t___174 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___164 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct fown_struct___141 {
	rwlock_t lock;
	struct pid___141 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___177 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___176 f_path;
	struct inode___177 *f_inode;
	const struct file_operations___177 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___141 f_owner;
	const struct cred___172 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___176 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___174;

struct vm_operations_struct___174 {
	void (*open)(struct vm_area_struct___177 *);
	void (*close)(struct vm_area_struct___177 *);
	int (*split)(struct vm_area_struct___177 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___177 *);
	vm_fault_t (*fault)(struct vm_fault___174 *);
	vm_fault_t (*huge_fault)(struct vm_fault___174 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___174 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___177 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___174 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___174 *);
	int (*access)(struct vm_area_struct___177 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___177 *);
	int (*set_policy)(struct vm_area_struct___177 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___177 *, long unsigned int);
	struct page___177 * (*find_special_page)(struct vm_area_struct___177 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___176 {
	struct task_struct___177 *task;
	struct core_thread___176 *next;
};

struct core_state___176 {
	atomic_t nr_threads;
	struct core_thread___176 dumper;
	struct completion startup;
};

struct vm_fault___174 {
	struct vm_area_struct___177 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___177 *cow_page;
	struct mem_cgroup___79 *memcg;
	struct page___177 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___176 prealloc_pte;
};

struct io_cq___44 {
	struct request_queue___41 *q;
	struct io_context___44 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___6 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___177 {
	struct file___177 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___177 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___176 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___177 *ia_file;
};

struct dquot___176 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___176 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___176 {
	int qf_fmt_id;
	const struct quota_format_ops___176 *qf_ops;
	struct module___150 *qf_owner;
	struct quota_format_type___176 *qf_next;
};

struct quota_format_ops___176 {
	int (*check_quota_file)(struct super_block___176 *, int);
	int (*read_file_info)(struct super_block___176 *, int);
	int (*write_file_info)(struct super_block___176 *, int);
	int (*free_file_info)(struct super_block___176 *, int);
	int (*read_dqblk)(struct dquot___176 *);
	int (*commit_dqblk)(struct dquot___176 *);
	int (*release_dqblk)(struct dquot___176 *);
	int (*get_next_id)(struct super_block___176 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___176 {
	int (*write_dquot)(struct dquot___176 *);
	struct dquot___176 * (*alloc_dquot)(struct super_block___176 *, int);
	void (*destroy_dquot)(struct dquot___176 *);
	int (*acquire_dquot)(struct dquot___176 *);
	int (*release_dquot)(struct dquot___176 *);
	int (*mark_dirty)(struct dquot___176 *);
	int (*write_info)(struct super_block___176 *, int);
	qsize_t * (*get_reserved_space)(struct inode___177 *);
	int (*get_projid)(struct inode___177 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___177 *, qsize_t *);
	int (*get_next_id)(struct super_block___176 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___176 {
	int (*quota_on)(struct super_block___176 *, int, int, const struct path___176 *);
	int (*quota_off)(struct super_block___176 *, int);
	int (*quota_enable)(struct super_block___176 *, unsigned int);
	int (*quota_disable)(struct super_block___176 *, unsigned int);
	int (*quota_sync)(struct super_block___176 *, int);
	int (*set_info)(struct super_block___176 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___176 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___176 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___176 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___176 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___176 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___147 {
	struct kobject___171 kobj;
	struct module___150 *mod;
	struct kobject___171 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___147 {
	struct module___150 *mod;
	struct latch_tree_node node;
};

struct module_layout___147 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___147 mtn;
};

struct module_attribute___147;

struct kernel_param___147;

struct module___150 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___147 mkobj;
	struct module_attribute___147 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___171 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___147 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___147 core_layout;
	struct module_layout___147 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___102 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide43;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide44;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___84;

struct address_space_operations___176 {
	int (*writepage)(struct page___177 *, struct writeback_control___84 *);
	int (*readpage)(struct file___177 *, struct page___177 *);
	int (*writepages)(struct address_space___176 *, struct writeback_control___84 *);
	int (*set_page_dirty)(struct page___177 *);
	int (*readpages)(struct file___177 *, struct address_space___176 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___177 *, struct address_space___176 *, loff_t, unsigned int, unsigned int, struct page___177 **, void **);
	int (*write_end)(struct file___177 *, struct address_space___176 *, loff_t, unsigned int, unsigned int, struct page___177 *, void *);
	sector_t (*bmap)(struct address_space___176 *, sector_t);
	void (*invalidatepage)(struct page___177 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___177 *, gfp_t);
	void (*freepage)(struct page___177 *);
	ssize_t (*direct_IO)(struct kiocb___177 *, struct iov_iter___84 *);
	int (*migratepage)(struct address_space___176 *, struct page___177 *, struct page___177 *, enum migrate_mode);
	bool (*isolate_page)(struct page___177 *, isolate_mode_t);
	void (*putback_page)(struct page___177 *);
	int (*launder_page)(struct page___177 *);
	int (*is_partially_uptodate)(struct page___177 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___177 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___176 *, struct page___177 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___177 *, sector_t *);
	void (*swap_deactivate)(struct file___177 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___84 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___87 *wb;
	struct inode___177 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___87;

struct iov_iter___84 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___87 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct hd_struct___41;

struct gendisk___41;

struct block_device___177 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___177 *bd_inode;
	struct super_block___176 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___177 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___41 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___41 *bd_disk;
	struct request_queue___41 *bd_queue;
	struct backing_dev_info___87 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___164 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___164 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___164;

struct bus_type___164;

struct device_driver___164;

struct dev_pm_domain___164;

struct fwnode_handle___115;

struct class___164;

struct attribute_group___165;

struct device___164 {
	struct device___164 *parent;
	struct device_private *p;
	struct kobject___171 kobj;
	const char *init_name;
	const struct device_type___164 *type;
	struct mutex mutex;
	struct bus_type___164 *bus;
	struct device_driver___164 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___164 power;
	struct dev_pm_domain___164 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___115 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___164 *class;
	const struct attribute_group___165 **groups;
	void (*release)(struct device___164 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___41 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___164 __dev;
	struct kobject___171 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___41;

struct block_device_operations___41;

struct gendisk___41 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___41 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___41 *part_tbl;
	struct hd_struct___41 part0;
	const struct block_device_operations___41 *fops;
	struct request_queue___41 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___177 lookup_sem;
	struct kobject___171 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___171 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___176 {
	struct dentry___176 * (*lookup)(struct inode___177 *, struct dentry___176 *, unsigned int);
	const char * (*get_link)(struct dentry___176 *, struct inode___177 *, struct delayed_call *);
	int (*permission)(struct inode___177 *, int);
	struct posix_acl * (*get_acl)(struct inode___177 *, int);
	int (*readlink)(struct dentry___176 *, char *, int);
	int (*create)(struct inode___177 *, struct dentry___176 *, umode_t, bool);
	int (*link)(struct dentry___176 *, struct inode___177 *, struct dentry___176 *);
	int (*unlink)(struct inode___177 *, struct dentry___176 *);
	int (*symlink)(struct inode___177 *, struct dentry___176 *, const char *);
	int (*mkdir)(struct inode___177 *, struct dentry___176 *, umode_t);
	int (*rmdir)(struct inode___177 *, struct dentry___176 *);
	int (*mknod)(struct inode___177 *, struct dentry___176 *, umode_t, dev_t);
	int (*rename)(struct inode___177 *, struct dentry___176 *, struct inode___177 *, struct dentry___176 *, unsigned int);
	int (*setattr)(struct dentry___176 *, struct iattr___176 *);
	int (*getattr)(const struct path___176 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___176 *, char *, size_t);
	int (*fiemap)(struct inode___177 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___177 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___177 *, struct dentry___176 *, struct file___177 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___177 *, struct dentry___176 *, umode_t);
	int (*set_acl)(struct inode___177 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___176 {
	void (*fl_copy_lock)(struct file_lock___177 *, struct file_lock___177 *);
	void (*fl_release_private)(struct file_lock___177 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___176;

struct file_lock___177 {
	struct file_lock___177 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___177 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___176 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___176 *fl_ops;
	const struct lock_manager_operations___176 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___176 {
	int (*lm_compare_owner)(struct file_lock___177 *, struct file_lock___177 *);
	long unsigned int (*lm_owner_key)(struct file_lock___177 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___177 *);
	int (*lm_grant)(struct file_lock___177 *, int);
	bool (*lm_break)(struct file_lock___177 *);
	int (*lm_change)(struct file_lock___177 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___177 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___176 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___176 *fa_next;
	struct file___177 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___176 {
	const char *name;
	int fs_flags;
	struct dentry___176 * (*mount)(struct file_system_type___176 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___176 *);
	struct module___150 *owner;
	struct file_system_type___176 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___176 {
	struct inode___177 * (*alloc_inode)(struct super_block___176 *);
	void (*destroy_inode)(struct inode___177 *);
	void (*dirty_inode)(struct inode___177 *, int);
	int (*write_inode)(struct inode___177 *, struct writeback_control___84 *);
	int (*drop_inode)(struct inode___177 *);
	void (*evict_inode)(struct inode___177 *);
	void (*put_super)(struct super_block___176 *);
	int (*sync_fs)(struct super_block___176 *, int);
	int (*freeze_super)(struct super_block___176 *);
	int (*freeze_fs)(struct super_block___176 *);
	int (*thaw_super)(struct super_block___176 *);
	int (*unfreeze_fs)(struct super_block___176 *);
	int (*statfs)(struct dentry___176 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___176 *, int *, char *);
	void (*umount_begin)(struct super_block___176 *);
	int (*show_options)(struct seq_file___166 *, struct dentry___176 *);
	int (*show_devname)(struct seq_file___166 *, struct dentry___176 *);
	int (*show_path)(struct seq_file___166 *, struct dentry___176 *);
	int (*show_stats)(struct seq_file___166 *, struct dentry___176 *);
	ssize_t (*quota_read)(struct super_block___176 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___176 *, int, const char *, size_t, loff_t);
	struct dquot___176 ** (*get_dquots)(struct inode___177 *);
	int (*bdev_try_to_free_page)(struct super_block___176 *, struct page___177 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___176 *, struct shrink_control___79 *);
	long int (*free_cached_objects)(struct super_block___176 *, struct shrink_control___79 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___118)(struct file___177 *, wait_queue_head_t *, struct poll_table_struct___119 *);

struct poll_table_struct___119 {
	poll_queue_proc___118 _qproc;
	__poll_t _key;
};

struct seq_operations___164;

struct seq_file___166 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___164 *op;
	int poll_event;
	const struct file___177 *file;
	void *private;
};

typedef void bio_end_io_t___87(struct bio___87 *);

struct bio_vec___87 {
	struct page___177 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___87;

struct bio___87 {
	struct bio___87 *bi_next;
	struct gendisk___41 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___87 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___31 *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___87 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___87 *bi_io_vec;
	struct bio_set___87 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___87 bi_inline_vecs[0];
};

struct kobj_attribute___171 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___171 *, struct kobj_attribute___171 *, char *);
	ssize_t (*store)(struct kobject___171 *, struct kobj_attribute___171 *, const char *, size_t);
};

typedef void compound_page_dtor___174(struct page___177 *);

struct kthread_work___151;

typedef void (*kthread_work_func_t___151)(struct kthread_work___151 *);

struct kthread_worker___151;

struct kthread_work___151 {
	struct list_head node;
	kthread_work_func_t___151 func;
	struct kthread_worker___151 *worker;
	int canceling;
};

struct kthread_worker___151 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___177 *task;
	struct kthread_work___151 *current_work;
};

struct kthread_delayed_work___151 {
	struct kthread_work___151 work;
	struct timer_list timer;
};

struct bdi_writeback_congested___87 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___87 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___87 {
	struct bio___87 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___87 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___87 bip_inline_vecs[0];
};

struct blkcg___31;

struct blkg_policy_data___31;

struct blkcg_gq___31 {
	struct request_queue___41 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___31 *blkcg;
	struct bdi_writeback_congested___87 *wb_congested;
	struct blkcg_gq___31 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_rwstat stat_bytes;
	struct blkg_rwstat stat_ios;
	struct blkg_policy_data___31 *pd[5];
	struct callback_head callback_head;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
};

typedef int (*key_restrict_link_func_t___172)(struct key___172 *, const struct key_type *, const union key_payload *, struct key___172 *);

struct key_restriction___172;

struct key___172 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___177 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___172 *restrict_link;
};

struct key_restriction___172 {
	key_restrict_link_func_t___172 check;
	struct key___172 *key;
	struct key_type *keytype;
};

struct seq_operations___164 {
	void * (*start)(struct seq_file___166 *, loff_t *);
	void (*stop)(struct seq_file___166 *, void *);
	void * (*next)(struct seq_file___166 *, void *, loff_t *);
	int (*show)(struct seq_file___166 *, void *);
};

struct kernfs_root___173;

struct kernfs_elem_dir___173 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___173 *root;
};

struct kernfs_syscall_ops___173;

struct kernfs_root___173 {
	struct kernfs_node___173 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___173 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___173 {
	struct kernfs_node___173 *target_kn;
};

struct kernfs_ops___173;

struct kernfs_elem_attr___173 {
	const struct kernfs_ops___173 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___173 *notify_next;
};

struct kernfs_node___173 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___173 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___173 dir;
		struct kernfs_elem_symlink___173 symlink;
		struct kernfs_elem_attr___173 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___173;

struct kernfs_ops___173 {
	int (*open)(struct kernfs_open_file___173 *);
	void (*release)(struct kernfs_open_file___173 *);
	int (*seq_show)(struct seq_file___166 *, void *);
	void * (*seq_start)(struct seq_file___166 *, loff_t *);
	void * (*seq_next)(struct seq_file___166 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___166 *, void *);
	ssize_t (*read)(struct kernfs_open_file___173 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___173 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___173 *, struct vm_area_struct___177 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___173 *, struct poll_table_struct___119 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___173 {
	int (*remount_fs)(struct kernfs_root___173 *, int *, char *);
	int (*show_options)(struct seq_file___166 *, struct kernfs_root___173 *);
	int (*mkdir)(struct kernfs_node___173 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___173 *);
	int (*rename)(struct kernfs_node___173 *, struct kernfs_node___173 *, const char *);
	int (*show_path)(struct seq_file___166 *, struct kernfs_node___173 *, struct kernfs_root___173 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___173 {
	struct kernfs_node___173 *kn;
	struct file___177 *file;
	struct seq_file___166 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___174 *vm_ops;
};

struct cgroup_namespace___151 {
	refcount_t count;
	struct ns_common___10 ns;
	struct user_namespace___156 *user_ns;
	struct ucounts___156 *ucounts;
	struct css_set___151 *root_cset;
};

struct ucounts___156 {
	struct hlist_node node;
	struct user_namespace___156 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___151;

struct bpf_map_ops___151 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___151 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___151 *, struct file___177 *);
	void (*map_free)(struct bpf_map___151 *);
	int (*map_get_next_key)(struct bpf_map___151 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___151 *);
	void * (*map_lookup_elem)(struct bpf_map___151 *, void *);
	int (*map_update_elem)(struct bpf_map___151 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___151 *, void *);
	int (*map_push_elem)(struct bpf_map___151 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___151 *, void *);
	int (*map_peek_elem)(struct bpf_map___151 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___151 *, struct file___177 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___151 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___151 *, void *, struct seq_file___166 *);
	int (*map_check_btf)(const struct bpf_map___151 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___151 {
	const struct bpf_map_ops___151 *ops;
	struct bpf_map___151 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___172 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct psi_group___151 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___151 *poll_kworker;
	struct kthread_delayed_work___151 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___151;

struct cgroup_rstat_cpu___151;

struct cgroup___151 {
	struct cgroup_subsys_state___151 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___173 *kn;
	struct cgroup_file___151 procs_file;
	struct cgroup_file___151 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___151 *subsys[13];
	struct cgroup_root___151 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___151 *dom_cgrp;
	struct cgroup_rstat_cpu___151 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___21 bpf;
	atomic_t congestion_count;
	struct cgroup___151 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___151 psi;
	int ancestor_ids[0];
};

struct cftype___151;

struct cgroup_subsys___151 {
	struct cgroup_subsys_state___151 * (*css_alloc)(struct cgroup_subsys_state___151 *);
	int (*css_online)(struct cgroup_subsys_state___151 *);
	void (*css_offline)(struct cgroup_subsys_state___151 *);
	void (*css_released)(struct cgroup_subsys_state___151 *);
	void (*css_free)(struct cgroup_subsys_state___151 *);
	void (*css_reset)(struct cgroup_subsys_state___151 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___151 *, int);
	int (*css_extra_stat_show)(struct seq_file___166 *, struct cgroup_subsys_state___151 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___177 *);
	void (*cancel_fork)(struct task_struct___177 *);
	void (*fork)(struct task_struct___177 *);
	void (*exit)(struct task_struct___177 *);
	void (*free)(struct task_struct___177 *);
	void (*bind)(struct cgroup_subsys_state___151 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___151 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___151 *dfl_cftypes;
	struct cftype___151 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___151 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___151 *updated_children;
	struct cgroup___151 *updated_next;
};

struct cgroup_root___151 {
	struct kernfs_root___173 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___151 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___151 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___151 *ss;
	struct list_head node;
	struct kernfs_ops___173 *kf_ops;
	int (*open)(struct kernfs_open_file___173 *);
	void (*release)(struct kernfs_open_file___173 *);
	u64 (*read_u64)(struct cgroup_subsys_state___151 *, struct cftype___151 *);
	s64 (*read_s64)(struct cgroup_subsys_state___151 *, struct cftype___151 *);
	int (*seq_show)(struct seq_file___166 *, void *);
	void * (*seq_start)(struct seq_file___166 *, loff_t *);
	void * (*seq_next)(struct seq_file___166 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___166 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___151 *, struct cftype___151 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___151 *, struct cftype___151 *, s64);
	ssize_t (*write)(struct kernfs_open_file___173 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___173 *, struct poll_table_struct___119 *);
};

struct dev_pm_ops___164;

struct device_type___164 {
	const char *name;
	const struct attribute_group___165 **groups;
	int (*uevent)(struct device___164 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___164 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___164 *);
	const struct dev_pm_ops___164 *pm;
};

struct class___164 {
	const char *name;
	struct module___150 *owner;
	const struct attribute_group___165 **class_groups;
	const struct attribute_group___165 **dev_groups;
	struct kobject___171 *dev_kobj;
	int (*dev_uevent)(struct device___164 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___164 *, umode_t *);
	void (*class_release)(struct class___164 *);
	void (*dev_release)(struct device___164 *);
	int (*shutdown_pre)(struct device___164 *);
	const struct kobj_ns_type_operations___11 *ns_type;
	const void * (*namespace)(struct device___164 *);
	const struct dev_pm_ops___164 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct bin_attribute___164;

struct attribute_group___165 {
	const char *name;
	umode_t (*is_visible)(struct kobject___171 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___171 *, struct bin_attribute___164 *, int);
	struct attribute **attrs;
	struct bin_attribute___164 **bin_attrs;
};

struct bin_attribute___164 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___177 *, struct kobject___171 *, struct bin_attribute___164 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___177 *, struct kobject___171 *, struct bin_attribute___164 *, char *, loff_t, size_t);
	int (*mmap)(struct file___177 *, struct kobject___171 *, struct bin_attribute___164 *, struct vm_area_struct___177 *);
};

struct sysfs_ops___170 {
	ssize_t (*show)(struct kobject___171 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___171 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___170;

struct kset___170 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___171 kobj;
	const struct kset_uevent_ops___170 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___170 {
	void (*release)(struct kobject___171 *);
	const struct sysfs_ops___170 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___11 * (*child_ns_type)(struct kobject___171 *);
	const void * (*namespace)(struct kobject___171 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___170 {
	int (* const filter)(struct kset___170 *, struct kobject___171 *);
	const char * (* const name)(struct kset___170 *, struct kobject___171 *);
	int (* const uevent)(struct kset___170 *, struct kobject___171 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___164 {
	int (*prepare)(struct device___164 *);
	void (*complete)(struct device___164 *);
	int (*suspend)(struct device___164 *);
	int (*resume)(struct device___164 *);
	int (*freeze)(struct device___164 *);
	int (*thaw)(struct device___164 *);
	int (*poweroff)(struct device___164 *);
	int (*restore)(struct device___164 *);
	int (*suspend_late)(struct device___164 *);
	int (*resume_early)(struct device___164 *);
	int (*freeze_late)(struct device___164 *);
	int (*thaw_early)(struct device___164 *);
	int (*poweroff_late)(struct device___164 *);
	int (*restore_early)(struct device___164 *);
	int (*suspend_noirq)(struct device___164 *);
	int (*resume_noirq)(struct device___164 *);
	int (*freeze_noirq)(struct device___164 *);
	int (*thaw_noirq)(struct device___164 *);
	int (*poweroff_noirq)(struct device___164 *);
	int (*restore_noirq)(struct device___164 *);
	int (*runtime_suspend)(struct device___164 *);
	int (*runtime_resume)(struct device___164 *);
	int (*runtime_idle)(struct device___164 *);
};

struct dev_pm_domain___164 {
	struct dev_pm_ops___164 ops;
	void (*detach)(struct device___164 *, bool);
	int (*activate)(struct device___164 *);
	void (*sync)(struct device___164 *);
	void (*dismiss)(struct device___164 *);
};

struct bus_type___164 {
	const char *name;
	const char *dev_name;
	struct device___164 *dev_root;
	const struct attribute_group___165 **bus_groups;
	const struct attribute_group___165 **dev_groups;
	const struct attribute_group___165 **drv_groups;
	int (*match)(struct device___164 *, struct device_driver___164 *);
	int (*uevent)(struct device___164 *, struct kobj_uevent_env *);
	int (*probe)(struct device___164 *);
	int (*remove)(struct device___164 *);
	void (*shutdown)(struct device___164 *);
	int (*online)(struct device___164 *);
	int (*offline)(struct device___164 *);
	int (*suspend)(struct device___164 *, pm_message_t);
	int (*resume)(struct device___164 *);
	int (*num_vf)(struct device___164 *);
	int (*dma_configure)(struct device___164 *);
	const struct dev_pm_ops___164 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___164 {
	const char *name;
	struct bus_type___164 *bus;
	struct module___150 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___164 *);
	int (*remove)(struct device___164 *);
	void (*shutdown)(struct device___164 *);
	int (*suspend)(struct device___164 *, pm_message_t);
	int (*resume)(struct device___164 *);
	const struct attribute_group___165 **groups;
	const struct dev_pm_ops___164 *pm;
	void (*coredump)(struct device___164 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct fwnode_operations___115;

struct fwnode_handle___115 {
	struct fwnode_handle___115 *secondary;
	const struct fwnode_operations___115 *ops;
};

struct disk_part_tbl___41 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___41 *last_lookup;
	struct hd_struct___41 *part[0];
};

struct block_device_operations___41 {
	int (*open)(struct block_device___177 *, fmode_t);
	void (*release)(struct gendisk___41 *, fmode_t);
	int (*rw_page)(struct block_device___177 *, sector_t, struct page___177 *, unsigned int);
	int (*ioctl)(struct block_device___177 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___177 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___41 *, unsigned int);
	int (*media_changed)(struct gendisk___41 *);
	void (*unlock_native_capacity)(struct gendisk___41 *);
	int (*revalidate_disk)(struct gendisk___41 *);
	int (*getgeo)(struct block_device___177 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___177 *, long unsigned int);
	int (*report_zones)(struct gendisk___41 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___150 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___40 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___41 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___41 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___41 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___40(struct request___41 *, blk_status_t);

struct request___41 {
	struct request_queue___41 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___87 *bio;
	struct bio___87 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___87 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___44 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___40 *saved_end_io;
		} flush;
	};
	struct gendisk___41 *rq_disk;
	struct hd_struct___41 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___40 *end_io;
	void *end_io_data;
	struct request___41 *next_rq;
};

struct fwnode_reference_args___115;

struct fwnode_endpoint___115;

struct fwnode_operations___115 {
	struct fwnode_handle___115 * (*get)(struct fwnode_handle___115 *);
	void (*put)(struct fwnode_handle___115 *);
	bool (*device_is_available)(const struct fwnode_handle___115 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___115 *, const struct device___164 *);
	bool (*property_present)(const struct fwnode_handle___115 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___115 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___115 *, const char *, const char **, size_t);
	struct fwnode_handle___115 * (*get_parent)(const struct fwnode_handle___115 *);
	struct fwnode_handle___115 * (*get_next_child_node)(const struct fwnode_handle___115 *, struct fwnode_handle___115 *);
	struct fwnode_handle___115 * (*get_named_child_node)(const struct fwnode_handle___115 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___115 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___115 *);
	struct fwnode_handle___115 * (*graph_get_next_endpoint)(const struct fwnode_handle___115 *, struct fwnode_handle___115 *);
	struct fwnode_handle___115 * (*graph_get_remote_endpoint)(const struct fwnode_handle___115 *);
	struct fwnode_handle___115 * (*graph_get_port_parent)(struct fwnode_handle___115 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___115 *, struct fwnode_endpoint___115 *);
};

struct fwnode_endpoint___115 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___115 *local_fwnode;
};

struct fwnode_reference_args___115 {
	struct fwnode_handle___115 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct elevator_type___40;

struct elevator_mq_ops___40 {
	int (*init_sched)(struct request_queue___41 *, struct elevator_type___40 *);
	void (*exit_sched)(struct elevator_queue___40 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	bool (*allow_merge)(struct request_queue___41 *, struct request___41 *, struct bio___87 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx *, struct bio___87 *);
	int (*request_merge)(struct request_queue___41 *, struct request___41 **, struct bio___87 *);
	void (*request_merged)(struct request_queue___41 *, struct request___41 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___41 *, struct request___41 *, struct request___41 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___41 *, struct bio___87 *);
	void (*finish_request)(struct request___41 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___41 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___41 *, u64);
	void (*started_request)(struct request___41 *);
	void (*requeue_request)(struct request___41 *);
	struct request___41 * (*former_request)(struct request_queue___41 *, struct request___41 *);
	struct request___41 * (*next_request)(struct request_queue___41 *, struct request___41 *);
	void (*init_icq)(struct io_cq___44 *);
	void (*exit_icq)(struct io_cq___44 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___40;

struct elevator_type___40 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___40 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___40 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___150 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___40 {
	struct elevator_type___40 *type;
	void *elevator_data;
	struct kobject___171 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___40 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___40 *, char *);
	ssize_t (*store)(struct elevator_queue___40 *, const char *, size_t);
};

struct blkcg_policy_data___31;

struct blkcg___31 {
	struct cgroup_subsys_state___151 css;
	spinlock_t lock;
	struct xarray blkg_tree;
	struct blkcg_gq___31 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___31 *cpd[5];
	struct list_head all_blkcgs_node;
	struct list_head cgwb_list;
	refcount_t cgwb_refcnt;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct blkcg_policy_data___31 {
	struct blkcg___31 *blkcg;
	int plid;
};

struct blkg_policy_data___31 {
	struct blkcg_gq___31 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___79 {
	struct mem_cgroup___79 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___79 {
	struct lruvec___176 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___79 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___79 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct wb_completion {
	atomic_t cnt;
};

struct wb_writeback_work {
	long int nr_pages;
	struct super_block___176 *sb;
	long unsigned int *older_than_this;
	enum writeback_sync_modes sync_mode;
	unsigned int tagged_writepages: 1;
	unsigned int for_kupdate: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_background: 1;
	unsigned int for_sync: 1;
	unsigned int auto_free: 1;
	enum wb_reason reason;
	struct list_head list;
	struct wb_completion *done;
};

struct kernel_param_ops___147 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___147 *);
	int (*get)(char *, const struct kernel_param___147 *);
	void (*free)(void *);
};

struct kparam_array___147;

struct kernel_param___147 {
	const char *name;
	struct module___150 *mod;
	const struct kernel_param_ops___147 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___147 *arr;
	};
};

struct kparam_array___147 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___147 *ops;
	void *elem;
};

struct module_attribute___147 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___147 *, struct module_kobject___147 *, char *);
	ssize_t (*store)(struct module_attribute___147 *, struct module_kobject___147 *, const char *, size_t);
	void (*setup)(struct module___150 *, const char *);
	int (*test)(struct module___150 *);
	void (*free)(struct module___150 *);
};

struct trace_event_class___102;

struct trace_event_call___102 {
	struct list_head list;
	struct trace_event_class___102 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___21 *prog_array;
	int (*perf_perm)(struct trace_event_call___102 *, struct perf_event___109 *);
};

struct node___140 {
	struct device___164 dev;
};

struct perf_cpu_context___109;

struct pmu___109 {
	struct list_head entry;
	struct module___150 *module;
	struct device___164 *dev;
	const struct attribute_group___165 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___109 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___109 *);
	void (*pmu_disable)(struct pmu___109 *);
	int (*event_init)(struct perf_event___109 *);
	void (*event_mapped)(struct perf_event___109 *, struct mm_struct___176 *);
	void (*event_unmapped)(struct perf_event___109 *, struct mm_struct___176 *);
	int (*add)(struct perf_event___109 *, int);
	void (*del)(struct perf_event___109 *, int);
	void (*start)(struct perf_event___109 *, int);
	void (*stop)(struct perf_event___109 *, int);
	void (*read)(struct perf_event___109 *);
	void (*start_txn)(struct pmu___109 *, unsigned int);
	int (*commit_txn)(struct pmu___109 *);
	void (*cancel_txn)(struct pmu___109 *);
	int (*event_idx)(struct perf_event___109 *);
	void (*sched_task)(struct perf_event_context___109 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___109 *);
	int (*filter_match)(struct perf_event___109 *);
	int (*check_period)(struct perf_event___109 *, u64);
};

struct perf_cpu_context___109 {
	struct perf_event_context___109 ctx;
	struct perf_event_context___109 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___109 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___109 {
	struct cgroup_subsys_state___151 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___102 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___102 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___102 *);
	struct list_head * (*get_fields)(struct trace_event_call___102 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___102 *);
};

struct trace_event_file___43;

struct trace_event_buffer___35 {
	struct ring_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___43 *trace_file;
	void *entry;
	long unsigned int flags;
	int pc;
};

struct trace_event_file___43 {
	struct list_head list;
	struct trace_event_call___102 *event_call;
	struct event_filter *filter;
	struct dentry___176 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_writeback_dirty_page {
	struct trace_entry ent;
	char name[32];
	long unsigned int ino;
	long unsigned int index;
	char __data[0];
};

struct trace_event_raw_writeback_dirty_inode_template {
	struct trace_entry ent;
	char name[32];
	long unsigned int ino;
	long unsigned int state;
	long unsigned int flags;
	char __data[0];
};

struct trace_event_raw_writeback_write_inode_template {
	struct trace_entry ent;
	char name[32];
	long unsigned int ino;
	int sync_mode;
	unsigned int cgroup_ino;
	char __data[0];
};

struct trace_event_raw_writeback_work_class {
	struct trace_entry ent;
	char name[32];
	long int nr_pages;
	dev_t sb_dev;
	int sync_mode;
	int for_kupdate;
	int range_cyclic;
	int for_background;
	int reason;
	unsigned int cgroup_ino;
	char __data[0];
};

struct trace_event_raw_writeback_pages_written {
	struct trace_entry ent;
	long int pages;
	char __data[0];
};

struct trace_event_raw_writeback_class {
	struct trace_entry ent;
	char name[32];
	unsigned int cgroup_ino;
	char __data[0];
};

struct trace_event_raw_writeback_bdi_register {
	struct trace_entry ent;
	char name[32];
	char __data[0];
};

struct trace_event_raw_wbc_class {
	struct trace_entry ent;
	char name[32];
	long int nr_to_write;
	long int pages_skipped;
	int sync_mode;
	int for_kupdate;
	int for_background;
	int for_reclaim;
	int range_cyclic;
	long int range_start;
	long int range_end;
	unsigned int cgroup_ino;
	char __data[0];
};

struct trace_event_raw_writeback_queue_io {
	struct trace_entry ent;
	char name[32];
	long unsigned int older;
	long int age;
	int moved;
	int reason;
	unsigned int cgroup_ino;
	char __data[0];
};

struct trace_event_raw_global_dirty_state {
	struct trace_entry ent;
	long unsigned int nr_dirty;
	long unsigned int nr_writeback;
	long unsigned int nr_unstable;
	long unsigned int background_thresh;
	long unsigned int dirty_thresh;
	long unsigned int dirty_limit;
	long unsigned int nr_dirtied;
	long unsigned int nr_written;
	char __data[0];
};

struct trace_event_raw_bdi_dirty_ratelimit {
	struct trace_entry ent;
	char bdi[32];
	long unsigned int write_bw;
	long unsigned int avg_write_bw;
	long unsigned int dirty_rate;
	long unsigned int dirty_ratelimit;
	long unsigned int task_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	unsigned int cgroup_ino;
	char __data[0];
};

struct trace_event_raw_balance_dirty_pages {
	struct trace_entry ent;
	char bdi[32];
	long unsigned int limit;
	long unsigned int setpoint;
	long unsigned int dirty;
	long unsigned int bdi_setpoint;
	long unsigned int bdi_dirty;
	long unsigned int dirty_ratelimit;
	long unsigned int task_ratelimit;
	unsigned int dirtied;
	unsigned int dirtied_pause;
	long unsigned int paused;
	long int pause;
	long unsigned int period;
	long int think;
	unsigned int cgroup_ino;
	char __data[0];
};

struct trace_event_raw_writeback_sb_inodes_requeue {
	struct trace_entry ent;
	char name[32];
	long unsigned int ino;
	long unsigned int state;
	long unsigned int dirtied_when;
	unsigned int cgroup_ino;
	char __data[0];
};

struct trace_event_raw_writeback_congest_waited_template {
	struct trace_entry ent;
	unsigned int usec_timeout;
	unsigned int usec_delayed;
	char __data[0];
};

struct trace_event_raw_writeback_single_inode_template {
	struct trace_entry ent;
	char name[32];
	long unsigned int ino;
	long unsigned int state;
	long unsigned int dirtied_when;
	long unsigned int writeback_index;
	long int nr_to_write;
	long unsigned int wrote;
	unsigned int cgroup_ino;
	char __data[0];
};

struct trace_event_raw_writeback_inode_template {
	struct trace_entry ent;
	dev_t dev;
	long unsigned int ino;
	long unsigned int state;
	__u16 mode;
	long unsigned int dirtied_when;
	char __data[0];
};

struct trace_event_data_offsets_writeback_dirty_page {};

struct trace_event_data_offsets_writeback_dirty_inode_template {};

struct trace_event_data_offsets_writeback_write_inode_template {};

struct trace_event_data_offsets_writeback_work_class {};

struct trace_event_data_offsets_writeback_pages_written {};

struct trace_event_data_offsets_writeback_class {};

struct trace_event_data_offsets_writeback_bdi_register {};

struct trace_event_data_offsets_wbc_class {};

struct trace_event_data_offsets_writeback_queue_io {};

struct trace_event_data_offsets_global_dirty_state {};

struct trace_event_data_offsets_bdi_dirty_ratelimit {};

struct trace_event_data_offsets_balance_dirty_pages {};

struct trace_event_data_offsets_writeback_sb_inodes_requeue {};

struct trace_event_data_offsets_writeback_congest_waited_template {};

struct trace_event_data_offsets_writeback_single_inode_template {};

struct trace_event_data_offsets_writeback_inode_template {};

struct inode_switch_wbs_context {
	struct inode___177 *inode;
	struct bdi_writeback___87 *new_wb;
	struct callback_head callback_head;
	struct work_struct work;
};

typedef void (*poll_queue_proc___119)(struct file___177 *, wait_queue_head_t *, struct poll_table_struct___23 *);

struct module___151;

struct file___178;

struct kiocb___178;

struct iov_iter___85;

struct poll_table_struct___120;

struct vm_area_struct___178;

struct inode___178;

struct file_lock___178;

struct page___178;

struct pipe_inode_info___42;

struct seq_file___167;

struct file_operations___178 {
	struct module___151 *owner;
	loff_t (*llseek)(struct file___178 *, loff_t, int);
	ssize_t (*read)(struct file___178 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___178 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___178 *, struct iov_iter___85 *);
	ssize_t (*write_iter)(struct kiocb___178 *, struct iov_iter___85 *);
	int (*iopoll)(struct kiocb___178 *, bool);
	int (*iterate)(struct file___178 *, struct dir_context *);
	int (*iterate_shared)(struct file___178 *, struct dir_context *);
	__poll_t (*poll)(struct file___178 *, struct poll_table_struct___120 *);
	long int (*unlocked_ioctl)(struct file___178 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___178 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___178 *, struct vm_area_struct___178 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___178 *, struct file___178 *);
	int (*flush)(struct file___178 *, fl_owner_t);
	int (*release)(struct inode___178 *, struct file___178 *);
	int (*fsync)(struct file___178 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___178 *, int);
	int (*lock)(struct file___178 *, int, struct file_lock___178 *);
	ssize_t (*sendpage)(struct file___178 *, struct page___178 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___178 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___178 *, int, struct file_lock___178 *);
	ssize_t (*splice_write)(struct pipe_inode_info___42 *, struct file___178 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___178 *, loff_t *, struct pipe_inode_info___42 *, size_t, unsigned int);
	int (*setlease)(struct file___178 *, long int, struct file_lock___178 **, void **);
	long int (*fallocate)(struct file___178 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___167 *, struct file___178 *);
	ssize_t (*copy_file_range)(struct file___178 *, loff_t, struct file___178 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___178 *, loff_t, struct file___178 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___178 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio_vec___88 {
	struct page___178 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

typedef struct page___178 *pgtable_t___177;

struct address_space___177;

struct mm_struct___177;

struct dev_pagemap___175;

struct mem_cgroup___80;

struct page___178 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___177 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___178 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___177 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___177 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___175 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___80 *mem_cgroup;
};

struct vmacache___177 {
	u64 seqnum;
	struct vm_area_struct___178 *vmas[4];
};

struct page_frag___177 {
	struct page___178 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___110;

struct debug_info___110 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___110 *hbp_break[16];
	struct perf_event___110 *hbp_watch[16];
};

struct thread_struct___110 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___110 debug;
	long: 64;
};

struct pid___142;

struct cred___173;

struct nsproxy___169;

struct signal_struct___158;

struct bio_list___88;

struct backing_dev_info___88;

struct css_set___152;

struct perf_event_context___110;

struct task_struct___178 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___178 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___177 *mm;
	struct mm_struct___177 *active_mm;
	struct vmacache___177 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___178 *real_parent;
	struct task_struct___178 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___178 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___80 *active_memcg;
	long int rh_reserved2;
	struct pid___142 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___142 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___142 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___173 *ptracer_cred;
	const struct cred___173 *real_cred;
	const struct cred___173 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___169 *nsproxy;
	struct signal_struct___158 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___178 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___88 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___88 *backing_dev_info;
	struct io_context___44 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___152 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___110 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___42 *splice_pipe;
	struct page_frag___177 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___80 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___178 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___110 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___110 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___178 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___110)(struct perf_event___110 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___110;

struct fasync_struct___177;

struct pid_namespace___142;

struct trace_event_call___103;

struct perf_cgroup___110;

struct perf_event___110 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___110 *group_leader;
	struct pmu___110 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___110 hw;
	struct perf_event_context___110 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___110 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___178 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___177 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___110 *);
	struct callback_head callback_head;
	struct pid_namespace___142 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___110 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___110 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___103 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___110 *cgrp;
	struct list_head sb_list;
};

struct dentry_operations___177;

struct super_block___177;

struct dentry___177 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___177 *d_parent;
	struct qstr d_name;
	struct inode___178 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___177 *d_op;
	struct super_block___177 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct rw_semaphore___178 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___178 *owner;
};

struct address_space_operations___177;

struct address_space___177 {
	struct inode___178 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___178 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___177 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___177;

struct bdi_writeback___88;

struct block_device___178;

struct inode___178 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___177 *i_op;
	struct super_block___177 *i_sb;
	struct address_space___177 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___178 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___88 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___178 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___177 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___42 *i_pipe;
		struct block_device___178 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___177;

struct dentry_operations___177 {
	int (*d_revalidate)(struct dentry___177 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___177 *, unsigned int);
	int (*d_hash)(const struct dentry___177 *, struct qstr *);
	int (*d_compare)(const struct dentry___177 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___177 *);
	int (*d_init)(struct dentry___177 *);
	void (*d_release)(struct dentry___177 *);
	void (*d_prune)(struct dentry___177 *);
	void (*d_iput)(struct dentry___177 *, struct inode___178 *);
	char * (*d_dname)(struct dentry___177 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___177 *);
	int (*d_manage)(const struct path___177 *, bool);
	struct dentry___177 * (*d_real)(struct dentry___177 *, const struct inode___178 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___177;

struct mem_dqinfo___177 {
	struct quota_format_type___177 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___177;

struct quota_info___177 {
	unsigned int flags;
	struct rw_semaphore___178 dqio_sem;
	struct inode___178 *files[3];
	struct mem_dqinfo___177 info[3];
	const struct quota_format_ops___177 *ops[3];
};

struct rcuwait___177 {
	struct task_struct___178 *task;
};

struct percpu_rw_semaphore___177 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___178 rw_sem;
	struct rcuwait___177 writer;
	int readers_block;
};

struct sb_writers___177 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___177 rw_sem[3];
};

struct shrink_control___80;

struct shrinker___80 {
	long unsigned int (*count_objects)(struct shrinker___80 *, struct shrink_control___80 *);
	long unsigned int (*scan_objects)(struct shrinker___80 *, struct shrink_control___80 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___177;

struct super_operations___177;

struct dquot_operations___177;

struct quotactl_ops___177;

struct user_namespace___157;

struct super_block___177 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___177 *s_type;
	const struct super_operations___177 *s_op;
	const struct dquot_operations___177 *dq_op;
	const struct quotactl_ops___177 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___177 *s_root;
	struct rw_semaphore___178 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___178 *s_bdev;
	struct backing_dev_info___88 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___177 s_dquot;
	struct sb_writers___177 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___177 *s_d_op;
	int cleancache_poolid;
	struct shrinker___80 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___157 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct path___177 {
	struct vfsmount *mnt;
	struct dentry___177 *dentry;
};

struct key___173;

struct ucounts___157;

struct user_namespace___157 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___157 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___10 ns;
	long unsigned int flags;
	struct key___173 *persistent_keyring_register;
	struct rw_semaphore___178 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___157 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct shrink_control___80 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___80 *memcg;
};

struct cgroup___152;

struct cgroup_subsys___152;

struct cgroup_subsys_state___152 {
	struct cgroup___152 *cgroup;
	struct cgroup_subsys___152 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___152 *parent;
};

struct kernfs_node___174;

struct cgroup_file___152 {
	struct kernfs_node___174 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___80;

struct mem_cgroup___80 {
	struct cgroup_subsys_state___152 css;
	struct mem_cgroup_id___8 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___152 events_file;
	struct cgroup_file___152 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___178 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___80 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pglist_data___177;

struct lruvec___177 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___177 *pgdat;
};

struct zone___177 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___177 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___177 {
	struct zone___177 *zone;
	int zone_idx;
};

struct zonelist___177 {
	struct zoneref___177 _zonerefs[25];
};

struct pglist_data___177 {
	struct zone___177 node_zones[3];
	struct zonelist___177 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___178 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___178 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___177 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___178 {
	void *stack;
	struct task_struct___178 *task;
	long int status;
};

struct blocking_notifier_head___177 {
	struct rw_semaphore___178 rwsem;
	struct notifier_block *head;
};

struct upid___142 {
	int nr;
	struct pid_namespace___142 *ns;
};

struct pid_namespace___142 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___178 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___142 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___177 *proc_self;
	struct dentry___177 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___157 *user_ns;
	struct ucounts___157 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___10 ns;
};

struct pid___142 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___142 numbers[1];
};

struct vm_operations_struct___175;

struct vm_area_struct___178 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___178 *vm_next;
	struct vm_area_struct___178 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___177 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___175 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___178 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___177;

struct mm_struct___177 {
	struct {
		struct vm_area_struct___178 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___178 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___178 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___177 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___178 *owner;
		struct user_namespace___157 *user_ns;
		struct file___178 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___177 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___175)(struct vm_area_struct___178 *, long unsigned int, const struct page___178 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___175)(struct page___178 *, void *);

struct device___165;

struct dev_pagemap___175 {
	dev_page_fault_t___175 page_fault;
	dev_page_free_t___175 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___165 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct fown_struct___142 {
	rwlock_t lock;
	struct pid___142 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___178 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___177 f_path;
	struct inode___178 *f_inode;
	const struct file_operations___178 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___142 f_owner;
	const struct cred___173 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___177 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___175;

struct vm_operations_struct___175 {
	void (*open)(struct vm_area_struct___178 *);
	void (*close)(struct vm_area_struct___178 *);
	int (*split)(struct vm_area_struct___178 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___178 *);
	vm_fault_t (*fault)(struct vm_fault___175 *);
	vm_fault_t (*huge_fault)(struct vm_fault___175 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___175 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___178 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___175 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___175 *);
	int (*access)(struct vm_area_struct___178 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___178 *);
	int (*set_policy)(struct vm_area_struct___178 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___178 *, long unsigned int);
	struct page___178 * (*find_special_page)(struct vm_area_struct___178 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___177 {
	struct task_struct___178 *task;
	struct core_thread___177 *next;
};

struct core_state___177 {
	atomic_t nr_threads;
	struct core_thread___177 dumper;
	struct completion startup;
};

struct vm_fault___175 {
	struct vm_area_struct___178 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___178 *cow_page;
	struct mem_cgroup___80 *memcg;
	struct page___178 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___177 prealloc_pte;
};

struct user_struct___173 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___173 *uid_keyring;
	struct key___173 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___173 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___173 *session_keyring;
	struct key___173 *process_keyring;
	struct key___173 *thread_keyring;
	struct key___173 *request_key_auth;
	void *security;
	struct user_struct___173 *user;
	struct user_namespace___157 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___152;

struct nsproxy___169 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___142 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___152 *cgroup_ns;
};

struct signal_struct___158 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___178 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___178 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___142 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___142 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___177 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___142 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___88;

struct bio_list___88 {
	struct bio___88 *head;
	struct bio___88 *tail;
};

struct bdi_writeback_congested___88;

struct bdi_writeback___88 {
	struct backing_dev_info___88 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___88 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___152 *memcg_css;
	struct cgroup_subsys_state___152 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___88 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___88 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___165 *dev;
	struct device___165 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___177 *debug_dir;
	struct dentry___177 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___152 {
	struct cgroup_subsys_state___152 *subsys[13];
	refcount_t refcount;
	struct css_set___152 *dom_cset;
	struct cgroup___152 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___152 *mg_src_cgrp;
	struct cgroup___152 *mg_dst_cgrp;
	struct css_set___152 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___110 {
	struct pmu___110 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___178 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___110 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___42;

struct pipe_inode_info___42 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___178 *tmp_page;
	struct fasync_struct___177 *fasync_readers;
	struct fasync_struct___177 *fasync_writers;
	struct pipe_buffer___42 *bufs;
	struct user_struct___173 *user;
};

union thread_union___159 {
	struct task_struct___178 task;
	long unsigned int stack[8192];
};

struct kiocb___178 {
	struct file___178 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___178 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___177 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___178 *ia_file;
};

struct dquot___177 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___177 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___177 {
	int qf_fmt_id;
	const struct quota_format_ops___177 *qf_ops;
	struct module___151 *qf_owner;
	struct quota_format_type___177 *qf_next;
};

struct quota_format_ops___177 {
	int (*check_quota_file)(struct super_block___177 *, int);
	int (*read_file_info)(struct super_block___177 *, int);
	int (*write_file_info)(struct super_block___177 *, int);
	int (*free_file_info)(struct super_block___177 *, int);
	int (*read_dqblk)(struct dquot___177 *);
	int (*commit_dqblk)(struct dquot___177 *);
	int (*release_dqblk)(struct dquot___177 *);
	int (*get_next_id)(struct super_block___177 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___177 {
	int (*write_dquot)(struct dquot___177 *);
	struct dquot___177 * (*alloc_dquot)(struct super_block___177 *, int);
	void (*destroy_dquot)(struct dquot___177 *);
	int (*acquire_dquot)(struct dquot___177 *);
	int (*release_dquot)(struct dquot___177 *);
	int (*mark_dirty)(struct dquot___177 *);
	int (*write_info)(struct super_block___177 *, int);
	qsize_t * (*get_reserved_space)(struct inode___178 *);
	int (*get_projid)(struct inode___178 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___178 *, qsize_t *);
	int (*get_next_id)(struct super_block___177 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___177 {
	int (*quota_on)(struct super_block___177 *, int, int, const struct path___177 *);
	int (*quota_off)(struct super_block___177 *, int);
	int (*quota_enable)(struct super_block___177 *, unsigned int);
	int (*quota_disable)(struct super_block___177 *, unsigned int);
	int (*quota_sync)(struct super_block___177 *, int);
	int (*set_info)(struct super_block___177 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___177 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___177 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___177 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___177 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___177 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___171;

struct kobj_type___171;

struct kobject___172 {
	const char *name;
	struct list_head entry;
	struct kobject___172 *parent;
	struct kset___171 *kset;
	struct kobj_type___171 *ktype;
	struct kernfs_node___174 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___148 {
	struct kobject___172 kobj;
	struct module___151 *mod;
	struct kobject___172 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___148 {
	struct module___151 *mod;
	struct latch_tree_node node;
};

struct module_layout___148 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___148 mtn;
};

struct module_attribute___148;

struct kernel_param___148;

struct module___151 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___148 mkobj;
	struct module_attribute___148 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___172 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___148 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___148 core_layout;
	struct module_layout___148 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___103 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___85;

struct swap_info_struct___58;

struct address_space_operations___177 {
	int (*writepage)(struct page___178 *, struct writeback_control___85 *);
	int (*readpage)(struct file___178 *, struct page___178 *);
	int (*writepages)(struct address_space___177 *, struct writeback_control___85 *);
	int (*set_page_dirty)(struct page___178 *);
	int (*readpages)(struct file___178 *, struct address_space___177 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___178 *, struct address_space___177 *, loff_t, unsigned int, unsigned int, struct page___178 **, void **);
	int (*write_end)(struct file___178 *, struct address_space___177 *, loff_t, unsigned int, unsigned int, struct page___178 *, void *);
	sector_t (*bmap)(struct address_space___177 *, sector_t);
	void (*invalidatepage)(struct page___178 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___178 *, gfp_t);
	void (*freepage)(struct page___178 *);
	ssize_t (*direct_IO)(struct kiocb___178 *, struct iov_iter___85 *);
	int (*migratepage)(struct address_space___177 *, struct page___178 *, struct page___178 *, enum migrate_mode);
	bool (*isolate_page)(struct page___178 *, isolate_mode_t);
	void (*putback_page)(struct page___178 *);
	int (*launder_page)(struct page___178 *);
	int (*is_partially_uptodate)(struct page___178 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___178 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___177 *, struct page___178 *);
	int (*swap_activate)(struct swap_info_struct___58 *, struct file___178 *, sector_t *);
	void (*swap_deactivate)(struct file___178 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___85 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___88 *wb;
	struct inode___178 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct iov_iter___85 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___88 *bvec;
		struct pipe_inode_info___42 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct swap_info_struct___58 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___178 *bdev;
	struct file___178 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___178 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___178 *bd_inode;
	struct super_block___177 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___178 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___88 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___177 {
	struct dentry___177 * (*lookup)(struct inode___178 *, struct dentry___177 *, unsigned int);
	const char * (*get_link)(struct dentry___177 *, struct inode___178 *, struct delayed_call *);
	int (*permission)(struct inode___178 *, int);
	struct posix_acl * (*get_acl)(struct inode___178 *, int);
	int (*readlink)(struct dentry___177 *, char *, int);
	int (*create)(struct inode___178 *, struct dentry___177 *, umode_t, bool);
	int (*link)(struct dentry___177 *, struct inode___178 *, struct dentry___177 *);
	int (*unlink)(struct inode___178 *, struct dentry___177 *);
	int (*symlink)(struct inode___178 *, struct dentry___177 *, const char *);
	int (*mkdir)(struct inode___178 *, struct dentry___177 *, umode_t);
	int (*rmdir)(struct inode___178 *, struct dentry___177 *);
	int (*mknod)(struct inode___178 *, struct dentry___177 *, umode_t, dev_t);
	int (*rename)(struct inode___178 *, struct dentry___177 *, struct inode___178 *, struct dentry___177 *, unsigned int);
	int (*setattr)(struct dentry___177 *, struct iattr___177 *);
	int (*getattr)(const struct path___177 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___177 *, char *, size_t);
	int (*fiemap)(struct inode___178 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___178 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___178 *, struct dentry___177 *, struct file___178 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___178 *, struct dentry___177 *, umode_t);
	int (*set_acl)(struct inode___178 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___177 {
	void (*fl_copy_lock)(struct file_lock___178 *, struct file_lock___178 *);
	void (*fl_release_private)(struct file_lock___178 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___177;

struct file_lock___178 {
	struct file_lock___178 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___178 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___177 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___177 *fl_ops;
	const struct lock_manager_operations___177 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___177 {
	int (*lm_compare_owner)(struct file_lock___178 *, struct file_lock___178 *);
	long unsigned int (*lm_owner_key)(struct file_lock___178 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___178 *);
	int (*lm_grant)(struct file_lock___178 *, int);
	bool (*lm_break)(struct file_lock___178 *);
	int (*lm_change)(struct file_lock___178 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___178 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___177 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___177 *fa_next;
	struct file___178 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___177 {
	const char *name;
	int fs_flags;
	struct dentry___177 * (*mount)(struct file_system_type___177 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___177 *);
	struct module___151 *owner;
	struct file_system_type___177 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___177 {
	struct inode___178 * (*alloc_inode)(struct super_block___177 *);
	void (*destroy_inode)(struct inode___178 *);
	void (*dirty_inode)(struct inode___178 *, int);
	int (*write_inode)(struct inode___178 *, struct writeback_control___85 *);
	int (*drop_inode)(struct inode___178 *);
	void (*evict_inode)(struct inode___178 *);
	void (*put_super)(struct super_block___177 *);
	int (*sync_fs)(struct super_block___177 *, int);
	int (*freeze_super)(struct super_block___177 *);
	int (*freeze_fs)(struct super_block___177 *);
	int (*thaw_super)(struct super_block___177 *);
	int (*unfreeze_fs)(struct super_block___177 *);
	int (*statfs)(struct dentry___177 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___177 *, int *, char *);
	void (*umount_begin)(struct super_block___177 *);
	int (*show_options)(struct seq_file___167 *, struct dentry___177 *);
	int (*show_devname)(struct seq_file___167 *, struct dentry___177 *);
	int (*show_path)(struct seq_file___167 *, struct dentry___177 *);
	int (*show_stats)(struct seq_file___167 *, struct dentry___177 *);
	ssize_t (*quota_read)(struct super_block___177 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___177 *, int, const char *, size_t, loff_t);
	struct dquot___177 ** (*get_dquots)(struct inode___178 *);
	int (*bdev_try_to_free_page)(struct super_block___177 *, struct page___178 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___177 *, struct shrink_control___80 *);
	long int (*free_cached_objects)(struct super_block___177 *, struct shrink_control___80 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___120)(struct file___178 *, wait_queue_head_t *, struct poll_table_struct___120 *);

struct poll_table_struct___120 {
	poll_queue_proc___120 _qproc;
	__poll_t _key;
};

struct seq_operations___165;

struct seq_file___167 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___165 *op;
	int poll_event;
	const struct file___178 *file;
	void *private;
};

typedef void bio_end_io_t___88(struct bio___88 *);

struct bio_integrity_payload___88;

struct bio_set___88;

struct bio___88 {
	struct bio___88 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___88 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___88 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___88 *bi_io_vec;
	struct bio_set___88 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___88 bi_inline_vecs[0];
};

struct fd___20 {
	struct file___178 *file;
	unsigned int flags;
};

struct dev_pm_info___165 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___165 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___165;

struct bus_type___165;

struct device_driver___165;

struct dev_pm_domain___165;

struct class___165;

struct attribute_group___166;

struct device___165 {
	struct device___165 *parent;
	struct device_private *p;
	struct kobject___172 kobj;
	const char *init_name;
	const struct device_type___165 *type;
	struct mutex mutex;
	struct bus_type___165 *bus;
	struct device_driver___165 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___165 power;
	struct dev_pm_domain___165 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___165 *class;
	const struct attribute_group___166 **groups;
	void (*release)(struct device___165 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct kobj_attribute___172 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___172 *, struct kobj_attribute___172 *, char *);
	ssize_t (*store)(struct kobject___172 *, struct kobj_attribute___172 *, const char *, size_t);
};

typedef void compound_page_dtor___175(struct page___178 *);

struct pipe_buf_operations___42;

struct pipe_buffer___42 {
	struct page___178 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___42 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___42 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___42 *, struct pipe_buffer___42 *);
	void (*release)(struct pipe_inode_info___42 *, struct pipe_buffer___42 *);
	int (*steal)(struct pipe_inode_info___42 *, struct pipe_buffer___42 *);
	union {
		bool (*get)(struct pipe_inode_info___42 *, struct pipe_buffer___42 *);
		struct {
			void (*get)(struct pipe_inode_info___42 *, struct pipe_buffer___42 *);
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
};

struct splice_desc {
	size_t total_len;
	unsigned int len;
	unsigned int flags;
	union {
		void *userptr;
		struct file___178 *file;
		void *data;
	} u;
	loff_t pos;
	loff_t *opos;
	size_t num_spliced;
	bool need_wakeup;
};

struct splice_pipe_desc___3 {
	struct page___178 **pages;
	struct partial_page *partial;
	int nr_pages;
	unsigned int nr_pages_max;
	const struct pipe_buf_operations___42 *ops;
	void (*spd_release)(struct splice_pipe_desc___3 *, unsigned int);
};

typedef int splice_actor(struct pipe_inode_info___42 *, struct pipe_buffer___42 *, struct splice_desc *);

typedef int splice_direct_actor(struct pipe_inode_info___42 *, struct splice_desc *);

typedef int (*key_restrict_link_func_t___173)(struct key___173 *, const struct key_type *, const union key_payload *, struct key___173 *);

struct key_restriction___173;

struct key___173 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___178 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___173 *restrict_link;
};

struct key_restriction___173 {
	key_restrict_link_func_t___173 check;
	struct key___173 *key;
	struct key_type *keytype;
};

struct seq_operations___165 {
	void * (*start)(struct seq_file___167 *, loff_t *);
	void (*stop)(struct seq_file___167 *, void *);
	void * (*next)(struct seq_file___167 *, void *, loff_t *);
	int (*show)(struct seq_file___167 *, void *);
};

struct kernfs_root___174;

struct kernfs_elem_dir___174 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___174 *root;
};

struct kernfs_syscall_ops___174;

struct kernfs_root___174 {
	struct kernfs_node___174 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___174 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___174 {
	struct kernfs_node___174 *target_kn;
};

struct kernfs_ops___174;

struct kernfs_elem_attr___174 {
	const struct kernfs_ops___174 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___174 *notify_next;
};

struct kernfs_node___174 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___174 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___174 dir;
		struct kernfs_elem_symlink___174 symlink;
		struct kernfs_elem_attr___174 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___174;

struct kernfs_ops___174 {
	int (*open)(struct kernfs_open_file___174 *);
	void (*release)(struct kernfs_open_file___174 *);
	int (*seq_show)(struct seq_file___167 *, void *);
	void * (*seq_start)(struct seq_file___167 *, loff_t *);
	void * (*seq_next)(struct seq_file___167 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___167 *, void *);
	ssize_t (*read)(struct kernfs_open_file___174 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___174 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___174 *, struct vm_area_struct___178 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___174 *, struct poll_table_struct___120 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___174 {
	int (*remount_fs)(struct kernfs_root___174 *, int *, char *);
	int (*show_options)(struct seq_file___167 *, struct kernfs_root___174 *);
	int (*mkdir)(struct kernfs_node___174 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___174 *);
	int (*rename)(struct kernfs_node___174 *, struct kernfs_node___174 *, const char *);
	int (*show_path)(struct seq_file___167 *, struct kernfs_node___174 *, struct kernfs_root___174 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___174 {
	struct kernfs_node___174 *kn;
	struct file___178 *file;
	struct seq_file___167 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___175 *vm_ops;
};

struct cgroup_namespace___152 {
	refcount_t count;
	struct ns_common___10 ns;
	struct user_namespace___157 *user_ns;
	struct ucounts___157 *ucounts;
	struct css_set___152 *root_cset;
};

struct ucounts___157 {
	struct hlist_node node;
	struct user_namespace___157 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___152;

struct bpf_map_ops___152 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___152 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___152 *, struct file___178 *);
	void (*map_free)(struct bpf_map___152 *);
	int (*map_get_next_key)(struct bpf_map___152 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___152 *);
	void * (*map_lookup_elem)(struct bpf_map___152 *, void *);
	int (*map_update_elem)(struct bpf_map___152 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___152 *, void *);
	int (*map_push_elem)(struct bpf_map___152 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___152 *, void *);
	int (*map_peek_elem)(struct bpf_map___152 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___152 *, struct file___178 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___152 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___152 *, void *, struct seq_file___167 *);
	int (*map_check_btf)(const struct bpf_map___152 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___152 {
	const struct bpf_map_ops___152 *ops;
	struct bpf_map___152 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___173 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___152;

typedef void (*kthread_work_func_t___152)(struct kthread_work___152 *);

struct kthread_worker___152;

struct kthread_work___152 {
	struct list_head node;
	kthread_work_func_t___152 func;
	struct kthread_worker___152 *worker;
	int canceling;
};

struct kthread_worker___152 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___178 *task;
	struct kthread_work___152 *current_work;
};

struct kthread_delayed_work___152 {
	struct kthread_work___152 work;
	struct timer_list timer;
};

struct psi_group___152 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___152 *poll_kworker;
	struct kthread_delayed_work___152 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___152;

struct cgroup_rstat_cpu___152;

struct cgroup___152 {
	struct cgroup_subsys_state___152 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___174 *kn;
	struct cgroup_file___152 procs_file;
	struct cgroup_file___152 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___152 *subsys[13];
	struct cgroup_root___152 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___152 *dom_cgrp;
	struct cgroup_rstat_cpu___152 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___21 bpf;
	atomic_t congestion_count;
	struct cgroup___152 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___152 psi;
	int ancestor_ids[0];
};

struct cftype___152;

struct cgroup_subsys___152 {
	struct cgroup_subsys_state___152 * (*css_alloc)(struct cgroup_subsys_state___152 *);
	int (*css_online)(struct cgroup_subsys_state___152 *);
	void (*css_offline)(struct cgroup_subsys_state___152 *);
	void (*css_released)(struct cgroup_subsys_state___152 *);
	void (*css_free)(struct cgroup_subsys_state___152 *);
	void (*css_reset)(struct cgroup_subsys_state___152 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___152 *, int);
	int (*css_extra_stat_show)(struct seq_file___167 *, struct cgroup_subsys_state___152 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___178 *);
	void (*cancel_fork)(struct task_struct___178 *);
	void (*fork)(struct task_struct___178 *);
	void (*exit)(struct task_struct___178 *);
	void (*free)(struct task_struct___178 *);
	void (*bind)(struct cgroup_subsys_state___152 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___152 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___152 *dfl_cftypes;
	struct cftype___152 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___152 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___152 *updated_children;
	struct cgroup___152 *updated_next;
};

struct cgroup_root___152 {
	struct kernfs_root___174 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___152 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___152 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___152 *ss;
	struct list_head node;
	struct kernfs_ops___174 *kf_ops;
	int (*open)(struct kernfs_open_file___174 *);
	void (*release)(struct kernfs_open_file___174 *);
	u64 (*read_u64)(struct cgroup_subsys_state___152 *, struct cftype___152 *);
	s64 (*read_s64)(struct cgroup_subsys_state___152 *, struct cftype___152 *);
	int (*seq_show)(struct seq_file___167 *, void *);
	void * (*seq_start)(struct seq_file___167 *, loff_t *);
	void * (*seq_next)(struct seq_file___167 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___167 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___152 *, struct cftype___152 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___152 *, struct cftype___152 *, s64);
	ssize_t (*write)(struct kernfs_open_file___174 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___174 *, struct poll_table_struct___120 *);
};

struct bdi_writeback_congested___88 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___88 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___88 {
	struct bio___88 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___88 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___88 bip_inline_vecs[0];
};

struct bio_set___88 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___88 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___80 {
	struct mem_cgroup___80 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___80 {
	struct lruvec___177 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___80 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___80 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct bin_attribute___165;

struct attribute_group___166 {
	const char *name;
	umode_t (*is_visible)(struct kobject___172 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___172 *, struct bin_attribute___165 *, int);
	struct attribute **attrs;
	struct bin_attribute___165 **bin_attrs;
};

struct bin_attribute___165 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___178 *, struct kobject___172 *, struct bin_attribute___165 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___178 *, struct kobject___172 *, struct bin_attribute___165 *, char *, loff_t, size_t);
	int (*mmap)(struct file___178 *, struct kobject___172 *, struct bin_attribute___165 *, struct vm_area_struct___178 *);
};

struct sysfs_ops___171 {
	ssize_t (*show)(struct kobject___172 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___172 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___171;

struct kset___171 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___172 kobj;
	const struct kset_uevent_ops___171 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___171 {
	void (*release)(struct kobject___172 *);
	const struct sysfs_ops___171 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___11 * (*child_ns_type)(struct kobject___172 *);
	const void * (*namespace)(struct kobject___172 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___171 {
	int (* const filter)(struct kset___171 *, struct kobject___172 *);
	const char * (* const name)(struct kset___171 *, struct kobject___172 *);
	int (* const uevent)(struct kset___171 *, struct kobject___172 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___165 {
	int (*prepare)(struct device___165 *);
	void (*complete)(struct device___165 *);
	int (*suspend)(struct device___165 *);
	int (*resume)(struct device___165 *);
	int (*freeze)(struct device___165 *);
	int (*thaw)(struct device___165 *);
	int (*poweroff)(struct device___165 *);
	int (*restore)(struct device___165 *);
	int (*suspend_late)(struct device___165 *);
	int (*resume_early)(struct device___165 *);
	int (*freeze_late)(struct device___165 *);
	int (*thaw_early)(struct device___165 *);
	int (*poweroff_late)(struct device___165 *);
	int (*restore_early)(struct device___165 *);
	int (*suspend_noirq)(struct device___165 *);
	int (*resume_noirq)(struct device___165 *);
	int (*freeze_noirq)(struct device___165 *);
	int (*thaw_noirq)(struct device___165 *);
	int (*poweroff_noirq)(struct device___165 *);
	int (*restore_noirq)(struct device___165 *);
	int (*runtime_suspend)(struct device___165 *);
	int (*runtime_resume)(struct device___165 *);
	int (*runtime_idle)(struct device___165 *);
};

struct dev_pm_domain___165 {
	struct dev_pm_ops___165 ops;
	void (*detach)(struct device___165 *, bool);
	int (*activate)(struct device___165 *);
	void (*sync)(struct device___165 *);
	void (*dismiss)(struct device___165 *);
};

struct bus_type___165 {
	const char *name;
	const char *dev_name;
	struct device___165 *dev_root;
	const struct attribute_group___166 **bus_groups;
	const struct attribute_group___166 **dev_groups;
	const struct attribute_group___166 **drv_groups;
	int (*match)(struct device___165 *, struct device_driver___165 *);
	int (*uevent)(struct device___165 *, struct kobj_uevent_env *);
	int (*probe)(struct device___165 *);
	int (*remove)(struct device___165 *);
	void (*shutdown)(struct device___165 *);
	int (*online)(struct device___165 *);
	int (*offline)(struct device___165 *);
	int (*suspend)(struct device___165 *, pm_message_t);
	int (*resume)(struct device___165 *);
	int (*num_vf)(struct device___165 *);
	int (*dma_configure)(struct device___165 *);
	const struct dev_pm_ops___165 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___165 {
	const char *name;
	struct bus_type___165 *bus;
	struct module___151 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___165 *);
	int (*remove)(struct device___165 *);
	void (*shutdown)(struct device___165 *);
	int (*suspend)(struct device___165 *, pm_message_t);
	int (*resume)(struct device___165 *);
	const struct attribute_group___166 **groups;
	const struct dev_pm_ops___165 *pm;
	void (*coredump)(struct device___165 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___165 {
	const char *name;
	const struct attribute_group___166 **groups;
	int (*uevent)(struct device___165 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___165 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___165 *);
	const struct dev_pm_ops___165 *pm;
};

struct class___165 {
	const char *name;
	struct module___151 *owner;
	const struct attribute_group___166 **class_groups;
	const struct attribute_group___166 **dev_groups;
	struct kobject___172 *dev_kobj;
	int (*dev_uevent)(struct device___165 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___165 *, umode_t *);
	void (*class_release)(struct class___165 *);
	void (*dev_release)(struct device___165 *);
	int (*shutdown_pre)(struct device___165 *);
	const struct kobj_ns_type_operations___11 *ns_type;
	const void * (*namespace)(struct device___165 *);
	const struct dev_pm_ops___165 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___141 {
	struct device___165 dev;
};

struct kernel_param_ops___148 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___148 *);
	int (*get)(char *, const struct kernel_param___148 *);
	void (*free)(void *);
};

struct kparam_array___148;

struct kernel_param___148 {
	const char *name;
	struct module___151 *mod;
	const struct kernel_param_ops___148 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___148 *arr;
	};
};

struct kparam_array___148 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___148 *ops;
	void *elem;
};

struct module_attribute___148 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___148 *, struct module_kobject___148 *, char *);
	ssize_t (*store)(struct module_attribute___148 *, struct module_kobject___148 *, const char *, size_t);
	void (*setup)(struct module___151 *, const char *);
	int (*test)(struct module___151 *);
	void (*free)(struct module___151 *);
};

struct trace_event_class___103;

struct trace_event_call___103 {
	struct list_head list;
	struct trace_event_class___103 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___21 *prog_array;
	int (*perf_perm)(struct trace_event_call___103 *, struct perf_event___110 *);
};

struct perf_cpu_context___110;

struct pmu___110 {
	struct list_head entry;
	struct module___151 *module;
	struct device___165 *dev;
	const struct attribute_group___166 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___110 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___110 *);
	void (*pmu_disable)(struct pmu___110 *);
	int (*event_init)(struct perf_event___110 *);
	void (*event_mapped)(struct perf_event___110 *, struct mm_struct___177 *);
	void (*event_unmapped)(struct perf_event___110 *, struct mm_struct___177 *);
	int (*add)(struct perf_event___110 *, int);
	void (*del)(struct perf_event___110 *, int);
	void (*start)(struct perf_event___110 *, int);
	void (*stop)(struct perf_event___110 *, int);
	void (*read)(struct perf_event___110 *);
	void (*start_txn)(struct pmu___110 *, unsigned int);
	int (*commit_txn)(struct pmu___110 *);
	void (*cancel_txn)(struct pmu___110 *);
	int (*event_idx)(struct perf_event___110 *);
	void (*sched_task)(struct perf_event_context___110 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___110 *);
	int (*filter_match)(struct perf_event___110 *);
	int (*check_period)(struct perf_event___110 *, u64);
};

struct perf_cpu_context___110 {
	struct perf_event_context___110 ctx;
	struct perf_event_context___110 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___110 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___110 {
	struct cgroup_subsys_state___152 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___103 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___103 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___103 *);
	struct list_head * (*get_fields)(struct trace_event_call___103 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___103 *);
};

struct syscall_metadata___48 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___103 *enter_event;
	struct trace_event_call___103 *exit_event;
};

struct module___152;

struct file___179;

struct kiocb___179;

struct iov_iter___86;

struct poll_table_struct___121;

struct vm_area_struct___179;

struct inode___179;

struct file_lock___179;

struct page___179;

struct seq_file___168;

struct file_operations___179 {
	struct module___152 *owner;
	loff_t (*llseek)(struct file___179 *, loff_t, int);
	ssize_t (*read)(struct file___179 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___179 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___179 *, struct iov_iter___86 *);
	ssize_t (*write_iter)(struct kiocb___179 *, struct iov_iter___86 *);
	int (*iopoll)(struct kiocb___179 *, bool);
	int (*iterate)(struct file___179 *, struct dir_context *);
	int (*iterate_shared)(struct file___179 *, struct dir_context *);
	__poll_t (*poll)(struct file___179 *, struct poll_table_struct___121 *);
	long int (*unlocked_ioctl)(struct file___179 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___179 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___179 *, struct vm_area_struct___179 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___179 *, struct file___179 *);
	int (*flush)(struct file___179 *, fl_owner_t);
	int (*release)(struct inode___179 *, struct file___179 *);
	int (*fsync)(struct file___179 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___179 *, int);
	int (*lock)(struct file___179 *, int, struct file_lock___179 *);
	ssize_t (*sendpage)(struct file___179 *, struct page___179 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___179 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___179 *, int, struct file_lock___179 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___179 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___179 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___179 *, long int, struct file_lock___179 **, void **);
	long int (*fallocate)(struct file___179 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___168 *, struct file___179 *);
	ssize_t (*copy_file_range)(struct file___179 *, loff_t, struct file___179 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___179 *, loff_t, struct file___179 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___179 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct fd___21 {
	struct file___179 *file;
	unsigned int flags;
};

struct dentry___178;

struct path___178 {
	struct vfsmount *mnt;
	struct dentry___178 *dentry;
};

struct pid___143;

struct fown_struct___143 {
	rwlock_t lock;
	struct pid___143 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct cred___174;

struct address_space___178;

struct file___179 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___178 f_path;
	struct inode___179 *f_inode;
	const struct file_operations___179 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___143 f_owner;
	const struct cred___174 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___178 *f_mapping;
	errseq_t f_wb_err;
};

struct vmacache___178 {
	u64 seqnum;
	struct vm_area_struct___179 *vmas[4];
};

struct page_frag___178 {
	struct page___179 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___111;

struct debug_info___111 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___111 *hbp_break[16];
	struct perf_event___111 *hbp_watch[16];
};

struct thread_struct___111 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___111 debug;
	long: 64;
};

struct mm_struct___178;

struct nsproxy___170;

struct signal_struct___159;

struct bio_list___89;

struct backing_dev_info___89;

struct io_context___45;

struct css_set___153;

struct perf_event_context___111;

struct request_queue___42;

struct vm_struct___129;

struct task_struct___179 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___179 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___178 *mm;
	struct mm_struct___178 *active_mm;
	struct vmacache___178 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___179 *real_parent;
	struct task_struct___179 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___179 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___143 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___143 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___143 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___174 *ptracer_cred;
	const struct cred___174 *real_cred;
	const struct cred___174 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___170 *nsproxy;
	struct signal_struct___159 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___179 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___89 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___89 *backing_dev_info;
	struct io_context___45 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___153 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___111 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___178 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___42 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___179 *oom_reaper_list;
	struct vm_struct___129 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___111 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___111 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___179 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___111)(struct perf_event___111 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___111;

struct fasync_struct___178;

struct pid_namespace___143;

struct trace_event_call___104;

struct perf_cgroup___111;

struct perf_event___111 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___111 *group_leader;
	struct pmu___111 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___111 hw;
	struct perf_event_context___111 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___111 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___179 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___178 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___111 *);
	struct callback_head callback_head;
	struct pid_namespace___143 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___111 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___111 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___104 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___111 *cgrp;
	struct list_head sb_list;
};

struct dentry_operations___178;

struct super_block___178;

struct dentry___178 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___178 *d_parent;
	struct qstr d_name;
	struct inode___179 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___178 *d_op;
	struct super_block___178 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct rw_semaphore___179 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___179 *owner;
};

struct address_space_operations___178;

struct address_space___178 {
	struct inode___179 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___179 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___178 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___178;

struct bdi_writeback___89;

struct block_device___179;

struct inode___179 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___178 *i_op;
	struct super_block___178 *i_sb;
	struct address_space___178 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___179 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___89 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___179 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___178 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___179 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___178 {
	int (*d_revalidate)(struct dentry___178 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___178 *, unsigned int);
	int (*d_hash)(const struct dentry___178 *, struct qstr *);
	int (*d_compare)(const struct dentry___178 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___178 *);
	int (*d_init)(struct dentry___178 *);
	void (*d_release)(struct dentry___178 *);
	void (*d_prune)(struct dentry___178 *);
	void (*d_iput)(struct dentry___178 *, struct inode___179 *);
	char * (*d_dname)(struct dentry___178 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___178 *);
	int (*d_manage)(const struct path___178 *, bool);
	struct dentry___178 * (*d_real)(struct dentry___178 *, const struct inode___179 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___178;

struct mem_dqinfo___178 {
	struct quota_format_type___178 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___178;

struct quota_info___178 {
	unsigned int flags;
	struct rw_semaphore___179 dqio_sem;
	struct inode___179 *files[3];
	struct mem_dqinfo___178 info[3];
	const struct quota_format_ops___178 *ops[3];
};

struct rcuwait___178 {
	struct task_struct___179 *task;
};

struct percpu_rw_semaphore___178 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___179 rw_sem;
	struct rcuwait___178 writer;
	int readers_block;
};

struct sb_writers___178 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___178 rw_sem[3];
};

struct file_system_type___178;

struct super_operations___178;

struct dquot_operations___178;

struct quotactl_ops___178;

struct user_namespace___158;

struct super_block___178 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___178 *s_type;
	const struct super_operations___178 *s_op;
	const struct dquot_operations___178 *dq_op;
	const struct quotactl_ops___178 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___178 *s_root;
	struct rw_semaphore___179 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___179 *s_bdev;
	struct backing_dev_info___89 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___178 s_dquot;
	struct sb_writers___178 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___178 *s_d_op;
	int cleancache_poolid;
	struct shrinker___80 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___158 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct key___174;

struct ucounts___158;

struct user_namespace___158 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___158 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___10 ns;
	long unsigned int flags;
	struct key___174 *persistent_keyring_register;
	struct rw_semaphore___179 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___158 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___179 *pgtable_t___178;

struct dev_pagemap___176;

struct page___179 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___178 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___179 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___178 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___178 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___176 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___178;

struct lruvec___178 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___178 *pgdat;
};

struct zone___178 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___178 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___178 {
	struct zone___178 *zone;
	int zone_idx;
};

struct zonelist___178 {
	struct zoneref___178 _zonerefs[25];
};

struct pglist_data___178 {
	struct zone___178 node_zones[3];
	struct zonelist___178 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___179 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___179 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___178 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___179 {
	void *stack;
	struct task_struct___179 *task;
	long int status;
};

struct blocking_notifier_head___178 {
	struct rw_semaphore___179 rwsem;
	struct notifier_block *head;
};

struct upid___143 {
	int nr;
	struct pid_namespace___143 *ns;
};

struct pid_namespace___143 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___179 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___143 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___178 *proc_self;
	struct dentry___178 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___158 *user_ns;
	struct ucounts___158 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___10 ns;
};

struct pid___143 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___143 numbers[1];
};

struct vm_operations_struct___176;

struct vm_area_struct___179 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___179 *vm_next;
	struct vm_area_struct___179 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___178 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___176 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___179 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___178;

struct mm_struct___178 {
	struct {
		struct vm_area_struct___179 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___179 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___179 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___178 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___179 *owner;
		struct user_namespace___158 *user_ns;
		struct file___179 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___178 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___176)(struct vm_area_struct___179 *, long unsigned int, const struct page___179 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___176)(struct page___179 *, void *);

struct device___166;

struct dev_pagemap___176 {
	dev_page_fault_t___176 page_fault;
	dev_page_free_t___176 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___166 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct vm_fault___176;

struct vm_operations_struct___176 {
	void (*open)(struct vm_area_struct___179 *);
	void (*close)(struct vm_area_struct___179 *);
	int (*split)(struct vm_area_struct___179 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___179 *);
	vm_fault_t (*fault)(struct vm_fault___176 *);
	vm_fault_t (*huge_fault)(struct vm_fault___176 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___176 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___179 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___176 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___176 *);
	int (*access)(struct vm_area_struct___179 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___179 *);
	int (*set_policy)(struct vm_area_struct___179 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___179 *, long unsigned int);
	struct page___179 * (*find_special_page)(struct vm_area_struct___179 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___178 {
	struct task_struct___179 *task;
	struct core_thread___178 *next;
};

struct core_state___178 {
	atomic_t nr_threads;
	struct core_thread___178 dumper;
	struct completion startup;
};

struct vm_fault___176 {
	struct vm_area_struct___179 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___179 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___179 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___178 prealloc_pte;
};

struct user_struct___174 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___174 *uid_keyring;
	struct key___174 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___174 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___174 *session_keyring;
	struct key___174 *process_keyring;
	struct key___174 *thread_keyring;
	struct key___174 *request_key_auth;
	void *security;
	struct user_struct___174 *user;
	struct user_namespace___158 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___153;

struct nsproxy___170 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___143 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___153 *cgroup_ns;
};

struct signal_struct___159 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___179 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___179 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___143 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___143 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___178 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___143 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___89;

struct bio_list___89 {
	struct bio___89 *head;
	struct bio___89 *tail;
};

struct bdi_writeback_congested___89;

struct cgroup_subsys_state___153;

struct bdi_writeback___89 {
	struct backing_dev_info___89 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___89 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___153 *memcg_css;
	struct cgroup_subsys_state___153 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___89 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___89 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___166 *dev;
	struct device___166 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___178 *debug_dir;
	struct dentry___178 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___45;

struct io_context___45 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___45 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___153;

struct css_set___153 {
	struct cgroup_subsys_state___153 *subsys[13];
	refcount_t refcount;
	struct css_set___153 *dom_cset;
	struct cgroup___153 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___153 *mg_src_cgrp;
	struct cgroup___153 *mg_dst_cgrp;
	struct css_set___153 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___111 {
	struct pmu___111 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___179 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___111 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

typedef blk_qc_t make_request_fn___41(struct request_queue___42 *, struct bio___89 *);

struct request___42;

typedef int dma_drain_needed_fn___41(struct request___42 *);

struct kset___172;

struct kobj_type___172;

struct kernfs_node___175;

struct kobject___173 {
	const char *name;
	struct list_head entry;
	struct kobject___173 *parent;
	struct kset___172 *kset;
	struct kobj_type___172 *ktype;
	struct kernfs_node___175 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___41;

struct bsg_class_device___41 {
	struct device___166 *class_dev;
	int minor;
	struct request_queue___42 *queue;
	const struct bsg_ops___41 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___89 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___89 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___41;

struct blkcg_gq___32;

struct request_queue___42 {
	struct list_head queue_head;
	struct request___42 *last_merge;
	struct elevator_queue___41 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___41 *make_request_fn;
	dma_drain_needed_fn___41 *dma_drain_needed;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___89 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___173 kobj;
	struct kobject___173 *mq_kobj;
	struct blk_integrity integrity;
	struct device___166 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___32 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide38;
		union {		};
	};
	struct bsg_class_device___41 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___89 bio_split;
	struct dentry___178 *debugfs_dir;
	struct dentry___178 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___129 {
	struct vm_struct___129 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___179 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___160 {
	struct task_struct___179 task;
	long unsigned int stack[8192];
};

struct io_cq___45 {
	struct request_queue___42 *q;
	struct io_context___45 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___6 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___179 {
	struct file___179 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___179 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___178 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___179 *ia_file;
};

struct dquot___178 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___178 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___178 {
	int qf_fmt_id;
	const struct quota_format_ops___178 *qf_ops;
	struct module___152 *qf_owner;
	struct quota_format_type___178 *qf_next;
};

struct quota_format_ops___178 {
	int (*check_quota_file)(struct super_block___178 *, int);
	int (*read_file_info)(struct super_block___178 *, int);
	int (*write_file_info)(struct super_block___178 *, int);
	int (*free_file_info)(struct super_block___178 *, int);
	int (*read_dqblk)(struct dquot___178 *);
	int (*commit_dqblk)(struct dquot___178 *);
	int (*release_dqblk)(struct dquot___178 *);
	int (*get_next_id)(struct super_block___178 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___178 {
	int (*write_dquot)(struct dquot___178 *);
	struct dquot___178 * (*alloc_dquot)(struct super_block___178 *, int);
	void (*destroy_dquot)(struct dquot___178 *);
	int (*acquire_dquot)(struct dquot___178 *);
	int (*release_dquot)(struct dquot___178 *);
	int (*mark_dirty)(struct dquot___178 *);
	int (*write_info)(struct super_block___178 *, int);
	qsize_t * (*get_reserved_space)(struct inode___179 *);
	int (*get_projid)(struct inode___179 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___179 *, qsize_t *);
	int (*get_next_id)(struct super_block___178 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___178 {
	int (*quota_on)(struct super_block___178 *, int, int, const struct path___178 *);
	int (*quota_off)(struct super_block___178 *, int);
	int (*quota_enable)(struct super_block___178 *, unsigned int);
	int (*quota_disable)(struct super_block___178 *, unsigned int);
	int (*quota_sync)(struct super_block___178 *, int);
	int (*set_info)(struct super_block___178 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___178 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___178 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___178 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___178 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___178 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___149 {
	struct kobject___173 kobj;
	struct module___152 *mod;
	struct kobject___173 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___149 {
	struct module___152 *mod;
	struct latch_tree_node node;
};

struct module_layout___149 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___149 mtn;
};

struct module_attribute___149;

struct kernel_param___149;

struct module___152 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___149 mkobj;
	struct module_attribute___149 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___173 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___149 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___149 core_layout;
	struct module_layout___149 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___104 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___86;

struct address_space_operations___178 {
	int (*writepage)(struct page___179 *, struct writeback_control___86 *);
	int (*readpage)(struct file___179 *, struct page___179 *);
	int (*writepages)(struct address_space___178 *, struct writeback_control___86 *);
	int (*set_page_dirty)(struct page___179 *);
	int (*readpages)(struct file___179 *, struct address_space___178 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___179 *, struct address_space___178 *, loff_t, unsigned int, unsigned int, struct page___179 **, void **);
	int (*write_end)(struct file___179 *, struct address_space___178 *, loff_t, unsigned int, unsigned int, struct page___179 *, void *);
	sector_t (*bmap)(struct address_space___178 *, sector_t);
	void (*invalidatepage)(struct page___179 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___179 *, gfp_t);
	void (*freepage)(struct page___179 *);
	ssize_t (*direct_IO)(struct kiocb___179 *, struct iov_iter___86 *);
	int (*migratepage)(struct address_space___178 *, struct page___179 *, struct page___179 *, enum migrate_mode);
	bool (*isolate_page)(struct page___179 *, isolate_mode_t);
	void (*putback_page)(struct page___179 *);
	int (*launder_page)(struct page___179 *);
	int (*is_partially_uptodate)(struct page___179 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___179 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___178 *, struct page___179 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___179 *, sector_t *);
	void (*swap_deactivate)(struct file___179 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___86 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___89 *wb;
	struct inode___179 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___89;

struct iov_iter___86 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___89 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct hd_struct___42;

struct gendisk___42;

struct block_device___179 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___179 *bd_inode;
	struct super_block___178 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___179 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___42 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___42 *bd_disk;
	struct request_queue___42 *bd_queue;
	struct backing_dev_info___89 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___166 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___166 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___166;

struct bus_type___166;

struct device_driver___166;

struct dev_pm_domain___166;

struct fwnode_handle___116;

struct class___166;

struct attribute_group___167;

struct device___166 {
	struct device___166 *parent;
	struct device_private *p;
	struct kobject___173 kobj;
	const char *init_name;
	const struct device_type___166 *type;
	struct mutex mutex;
	struct bus_type___166 *bus;
	struct device_driver___166 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___166 power;
	struct dev_pm_domain___166 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___116 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___166 *class;
	const struct attribute_group___167 **groups;
	void (*release)(struct device___166 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___42 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___166 __dev;
	struct kobject___173 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___42;

struct block_device_operations___42;

struct gendisk___42 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___42 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___42 *part_tbl;
	struct hd_struct___42 part0;
	const struct block_device_operations___42 *fops;
	struct request_queue___42 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___179 lookup_sem;
	struct kobject___173 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___173 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___178 {
	struct dentry___178 * (*lookup)(struct inode___179 *, struct dentry___178 *, unsigned int);
	const char * (*get_link)(struct dentry___178 *, struct inode___179 *, struct delayed_call *);
	int (*permission)(struct inode___179 *, int);
	struct posix_acl * (*get_acl)(struct inode___179 *, int);
	int (*readlink)(struct dentry___178 *, char *, int);
	int (*create)(struct inode___179 *, struct dentry___178 *, umode_t, bool);
	int (*link)(struct dentry___178 *, struct inode___179 *, struct dentry___178 *);
	int (*unlink)(struct inode___179 *, struct dentry___178 *);
	int (*symlink)(struct inode___179 *, struct dentry___178 *, const char *);
	int (*mkdir)(struct inode___179 *, struct dentry___178 *, umode_t);
	int (*rmdir)(struct inode___179 *, struct dentry___178 *);
	int (*mknod)(struct inode___179 *, struct dentry___178 *, umode_t, dev_t);
	int (*rename)(struct inode___179 *, struct dentry___178 *, struct inode___179 *, struct dentry___178 *, unsigned int);
	int (*setattr)(struct dentry___178 *, struct iattr___178 *);
	int (*getattr)(const struct path___178 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___178 *, char *, size_t);
	int (*fiemap)(struct inode___179 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___179 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___179 *, struct dentry___178 *, struct file___179 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___179 *, struct dentry___178 *, umode_t);
	int (*set_acl)(struct inode___179 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___178 {
	void (*fl_copy_lock)(struct file_lock___179 *, struct file_lock___179 *);
	void (*fl_release_private)(struct file_lock___179 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___178;

struct file_lock___179 {
	struct file_lock___179 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___179 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___178 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___178 *fl_ops;
	const struct lock_manager_operations___178 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___178 {
	int (*lm_compare_owner)(struct file_lock___179 *, struct file_lock___179 *);
	long unsigned int (*lm_owner_key)(struct file_lock___179 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___179 *);
	int (*lm_grant)(struct file_lock___179 *, int);
	bool (*lm_break)(struct file_lock___179 *);
	int (*lm_change)(struct file_lock___179 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___179 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___178 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___178 *fa_next;
	struct file___179 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___178 {
	const char *name;
	int fs_flags;
	struct dentry___178 * (*mount)(struct file_system_type___178 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___178 *);
	struct module___152 *owner;
	struct file_system_type___178 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___178 {
	struct inode___179 * (*alloc_inode)(struct super_block___178 *);
	void (*destroy_inode)(struct inode___179 *);
	void (*dirty_inode)(struct inode___179 *, int);
	int (*write_inode)(struct inode___179 *, struct writeback_control___86 *);
	int (*drop_inode)(struct inode___179 *);
	void (*evict_inode)(struct inode___179 *);
	void (*put_super)(struct super_block___178 *);
	int (*sync_fs)(struct super_block___178 *, int);
	int (*freeze_super)(struct super_block___178 *);
	int (*freeze_fs)(struct super_block___178 *);
	int (*thaw_super)(struct super_block___178 *);
	int (*unfreeze_fs)(struct super_block___178 *);
	int (*statfs)(struct dentry___178 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___178 *, int *, char *);
	void (*umount_begin)(struct super_block___178 *);
	int (*show_options)(struct seq_file___168 *, struct dentry___178 *);
	int (*show_devname)(struct seq_file___168 *, struct dentry___178 *);
	int (*show_path)(struct seq_file___168 *, struct dentry___178 *);
	int (*show_stats)(struct seq_file___168 *, struct dentry___178 *);
	ssize_t (*quota_read)(struct super_block___178 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___178 *, int, const char *, size_t, loff_t);
	struct dquot___178 ** (*get_dquots)(struct inode___179 *);
	int (*bdev_try_to_free_page)(struct super_block___178 *, struct page___179 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___178 *, struct shrink_control___80 *);
	long int (*free_cached_objects)(struct super_block___178 *, struct shrink_control___80 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___121)(struct file___179 *, wait_queue_head_t *, struct poll_table_struct___121 *);

struct poll_table_struct___121 {
	poll_queue_proc___121 _qproc;
	__poll_t _key;
};

struct seq_operations___166;

struct seq_file___168 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___166 *op;
	int poll_event;
	const struct file___179 *file;
	void *private;
};

typedef void bio_end_io_t___89(struct bio___89 *);

struct bio_vec___89 {
	struct page___179 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___89;

struct bio___89 {
	struct bio___89 *bi_next;
	struct gendisk___42 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___89 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___32 *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___89 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___89 *bi_io_vec;
	struct bio_set___89 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___89 bi_inline_vecs[0];
};

struct bdi_writeback_congested___89 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___89 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct cgroup_subsys___153;

struct cgroup_subsys_state___153 {
	struct cgroup___153 *cgroup;
	struct cgroup_subsys___153 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___153 *parent;
};

struct bio_integrity_payload___89 {
	struct bio___89 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___89 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___89 bip_inline_vecs[0];
};

struct blkcg___32;

struct blkg_policy_data___32;

struct blkcg_gq___32 {
	struct request_queue___42 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___32 *blkcg;
	struct bdi_writeback_congested___89 *wb_congested;
	struct blkcg_gq___32 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_rwstat stat_bytes;
	struct blkg_rwstat stat_ios;
	struct blkg_policy_data___32 *pd[5];
	struct callback_head callback_head;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
};

typedef int (*key_restrict_link_func_t___174)(struct key___174 *, const struct key_type *, const union key_payload *, struct key___174 *);

struct key_restriction___174;

struct key___174 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___179 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___174 *restrict_link;
};

struct key_restriction___174 {
	key_restrict_link_func_t___174 check;
	struct key___174 *key;
	struct key_type *keytype;
};

struct seq_operations___166 {
	void * (*start)(struct seq_file___168 *, loff_t *);
	void (*stop)(struct seq_file___168 *, void *);
	void * (*next)(struct seq_file___168 *, void *, loff_t *);
	int (*show)(struct seq_file___168 *, void *);
};

struct kernfs_root___175;

struct kernfs_elem_dir___175 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___175 *root;
};

struct kernfs_syscall_ops___175;

struct kernfs_root___175 {
	struct kernfs_node___175 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___175 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___175 {
	struct kernfs_node___175 *target_kn;
};

struct kernfs_ops___175;

struct kernfs_elem_attr___175 {
	const struct kernfs_ops___175 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___175 *notify_next;
};

struct kernfs_node___175 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___175 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___175 dir;
		struct kernfs_elem_symlink___175 symlink;
		struct kernfs_elem_attr___175 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___175;

struct kernfs_ops___175 {
	int (*open)(struct kernfs_open_file___175 *);
	void (*release)(struct kernfs_open_file___175 *);
	int (*seq_show)(struct seq_file___168 *, void *);
	void * (*seq_start)(struct seq_file___168 *, loff_t *);
	void * (*seq_next)(struct seq_file___168 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___168 *, void *);
	ssize_t (*read)(struct kernfs_open_file___175 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___175 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___175 *, struct vm_area_struct___179 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___175 *, struct poll_table_struct___121 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___175 {
	int (*remount_fs)(struct kernfs_root___175 *, int *, char *);
	int (*show_options)(struct seq_file___168 *, struct kernfs_root___175 *);
	int (*mkdir)(struct kernfs_node___175 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___175 *);
	int (*rename)(struct kernfs_node___175 *, struct kernfs_node___175 *, const char *);
	int (*show_path)(struct seq_file___168 *, struct kernfs_node___175 *, struct kernfs_root___175 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___175 {
	struct kernfs_node___175 *kn;
	struct file___179 *file;
	struct seq_file___168 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___176 *vm_ops;
};

struct cgroup_namespace___153 {
	refcount_t count;
	struct ns_common___10 ns;
	struct user_namespace___158 *user_ns;
	struct ucounts___158 *ucounts;
	struct css_set___153 *root_cset;
};

struct ucounts___158 {
	struct hlist_node node;
	struct user_namespace___158 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___153;

struct bpf_map_ops___153 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___153 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___153 *, struct file___179 *);
	void (*map_free)(struct bpf_map___153 *);
	int (*map_get_next_key)(struct bpf_map___153 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___153 *);
	void * (*map_lookup_elem)(struct bpf_map___153 *, void *);
	int (*map_update_elem)(struct bpf_map___153 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___153 *, void *);
	int (*map_push_elem)(struct bpf_map___153 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___153 *, void *);
	int (*map_peek_elem)(struct bpf_map___153 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___153 *, struct file___179 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___153 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___153 *, void *, struct seq_file___168 *);
	int (*map_check_btf)(const struct bpf_map___153 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___153 {
	const struct bpf_map_ops___153 *ops;
	struct bpf_map___153 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___174 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___153;

typedef void (*kthread_work_func_t___153)(struct kthread_work___153 *);

struct kthread_worker___153;

struct kthread_work___153 {
	struct list_head node;
	kthread_work_func_t___153 func;
	struct kthread_worker___153 *worker;
	int canceling;
};

struct kthread_worker___153 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___179 *task;
	struct kthread_work___153 *current_work;
};

struct kthread_delayed_work___153 {
	struct kthread_work___153 work;
	struct timer_list timer;
};

struct psi_group___153 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___153 *poll_kworker;
	struct kthread_delayed_work___153 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___153 {
	struct kernfs_node___175 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_root___153;

struct cgroup_rstat_cpu___153;

struct cgroup___153 {
	struct cgroup_subsys_state___153 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___175 *kn;
	struct cgroup_file___153 procs_file;
	struct cgroup_file___153 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___153 *subsys[13];
	struct cgroup_root___153 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___153 *dom_cgrp;
	struct cgroup_rstat_cpu___153 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___21 bpf;
	atomic_t congestion_count;
	struct cgroup___153 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___153 psi;
	int ancestor_ids[0];
};

struct cftype___153;

struct cgroup_subsys___153 {
	struct cgroup_subsys_state___153 * (*css_alloc)(struct cgroup_subsys_state___153 *);
	int (*css_online)(struct cgroup_subsys_state___153 *);
	void (*css_offline)(struct cgroup_subsys_state___153 *);
	void (*css_released)(struct cgroup_subsys_state___153 *);
	void (*css_free)(struct cgroup_subsys_state___153 *);
	void (*css_reset)(struct cgroup_subsys_state___153 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___153 *, int);
	int (*css_extra_stat_show)(struct seq_file___168 *, struct cgroup_subsys_state___153 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___179 *);
	void (*cancel_fork)(struct task_struct___179 *);
	void (*fork)(struct task_struct___179 *);
	void (*exit)(struct task_struct___179 *);
	void (*free)(struct task_struct___179 *);
	void (*bind)(struct cgroup_subsys_state___153 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___153 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___153 *dfl_cftypes;
	struct cftype___153 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___153 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___153 *updated_children;
	struct cgroup___153 *updated_next;
};

struct cgroup_root___153 {
	struct kernfs_root___175 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___153 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___153 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___153 *ss;
	struct list_head node;
	struct kernfs_ops___175 *kf_ops;
	int (*open)(struct kernfs_open_file___175 *);
	void (*release)(struct kernfs_open_file___175 *);
	u64 (*read_u64)(struct cgroup_subsys_state___153 *, struct cftype___153 *);
	s64 (*read_s64)(struct cgroup_subsys_state___153 *, struct cftype___153 *);
	int (*seq_show)(struct seq_file___168 *, void *);
	void * (*seq_start)(struct seq_file___168 *, loff_t *);
	void * (*seq_next)(struct seq_file___168 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___168 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___153 *, struct cftype___153 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___153 *, struct cftype___153 *, s64);
	ssize_t (*write)(struct kernfs_open_file___175 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___175 *, struct poll_table_struct___121 *);
};

struct kobj_attribute___173 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___173 *, struct kobj_attribute___173 *, char *);
	ssize_t (*store)(struct kobject___173 *, struct kobj_attribute___173 *, const char *, size_t);
};

typedef void compound_page_dtor___176(struct page___179 *);

struct bin_attribute___166;

struct attribute_group___167 {
	const char *name;
	umode_t (*is_visible)(struct kobject___173 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___173 *, struct bin_attribute___166 *, int);
	struct attribute **attrs;
	struct bin_attribute___166 **bin_attrs;
};

struct bin_attribute___166 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___179 *, struct kobject___173 *, struct bin_attribute___166 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___179 *, struct kobject___173 *, struct bin_attribute___166 *, char *, loff_t, size_t);
	int (*mmap)(struct file___179 *, struct kobject___173 *, struct bin_attribute___166 *, struct vm_area_struct___179 *);
};

struct sysfs_ops___172 {
	ssize_t (*show)(struct kobject___173 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___173 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___172;

struct kset___172 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___173 kobj;
	const struct kset_uevent_ops___172 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___172 {
	void (*release)(struct kobject___173 *);
	const struct sysfs_ops___172 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___11 * (*child_ns_type)(struct kobject___173 *);
	const void * (*namespace)(struct kobject___173 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___172 {
	int (* const filter)(struct kset___172 *, struct kobject___173 *);
	const char * (* const name)(struct kset___172 *, struct kobject___173 *);
	int (* const uevent)(struct kset___172 *, struct kobject___173 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___149 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___149 *);
	int (*get)(char *, const struct kernel_param___149 *);
	void (*free)(void *);
};

struct kparam_array___149;

struct kernel_param___149 {
	const char *name;
	struct module___152 *mod;
	const struct kernel_param_ops___149 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___149 *arr;
	};
};

struct kparam_array___149 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___149 *ops;
	void *elem;
};

struct module_attribute___149 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___149 *, struct module_kobject___149 *, char *);
	ssize_t (*store)(struct module_attribute___149 *, struct module_kobject___149 *, const char *, size_t);
	void (*setup)(struct module___152 *, const char *);
	int (*test)(struct module___152 *);
	void (*free)(struct module___152 *);
};

struct trace_event_class___104;

struct trace_event_call___104 {
	struct list_head list;
	struct trace_event_class___104 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___21 *prog_array;
	int (*perf_perm)(struct trace_event_call___104 *, struct perf_event___111 *);
};

struct dev_pm_ops___166 {
	int (*prepare)(struct device___166 *);
	void (*complete)(struct device___166 *);
	int (*suspend)(struct device___166 *);
	int (*resume)(struct device___166 *);
	int (*freeze)(struct device___166 *);
	int (*thaw)(struct device___166 *);
	int (*poweroff)(struct device___166 *);
	int (*restore)(struct device___166 *);
	int (*suspend_late)(struct device___166 *);
	int (*resume_early)(struct device___166 *);
	int (*freeze_late)(struct device___166 *);
	int (*thaw_early)(struct device___166 *);
	int (*poweroff_late)(struct device___166 *);
	int (*restore_early)(struct device___166 *);
	int (*suspend_noirq)(struct device___166 *);
	int (*resume_noirq)(struct device___166 *);
	int (*freeze_noirq)(struct device___166 *);
	int (*thaw_noirq)(struct device___166 *);
	int (*poweroff_noirq)(struct device___166 *);
	int (*restore_noirq)(struct device___166 *);
	int (*runtime_suspend)(struct device___166 *);
	int (*runtime_resume)(struct device___166 *);
	int (*runtime_idle)(struct device___166 *);
};

struct dev_pm_domain___166 {
	struct dev_pm_ops___166 ops;
	void (*detach)(struct device___166 *, bool);
	int (*activate)(struct device___166 *);
	void (*sync)(struct device___166 *);
	void (*dismiss)(struct device___166 *);
};

struct bus_type___166 {
	const char *name;
	const char *dev_name;
	struct device___166 *dev_root;
	const struct attribute_group___167 **bus_groups;
	const struct attribute_group___167 **dev_groups;
	const struct attribute_group___167 **drv_groups;
	int (*match)(struct device___166 *, struct device_driver___166 *);
	int (*uevent)(struct device___166 *, struct kobj_uevent_env *);
	int (*probe)(struct device___166 *);
	int (*remove)(struct device___166 *);
	void (*shutdown)(struct device___166 *);
	int (*online)(struct device___166 *);
	int (*offline)(struct device___166 *);
	int (*suspend)(struct device___166 *, pm_message_t);
	int (*resume)(struct device___166 *);
	int (*num_vf)(struct device___166 *);
	int (*dma_configure)(struct device___166 *);
	const struct dev_pm_ops___166 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___166 {
	const char *name;
	struct bus_type___166 *bus;
	struct module___152 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___166 *);
	int (*remove)(struct device___166 *);
	void (*shutdown)(struct device___166 *);
	int (*suspend)(struct device___166 *, pm_message_t);
	int (*resume)(struct device___166 *);
	const struct attribute_group___167 **groups;
	const struct dev_pm_ops___166 *pm;
	void (*coredump)(struct device___166 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___166 {
	const char *name;
	const struct attribute_group___167 **groups;
	int (*uevent)(struct device___166 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___166 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___166 *);
	const struct dev_pm_ops___166 *pm;
};

struct class___166 {
	const char *name;
	struct module___152 *owner;
	const struct attribute_group___167 **class_groups;
	const struct attribute_group___167 **dev_groups;
	struct kobject___173 *dev_kobj;
	int (*dev_uevent)(struct device___166 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___166 *, umode_t *);
	void (*class_release)(struct class___166 *);
	void (*dev_release)(struct device___166 *);
	int (*shutdown_pre)(struct device___166 *);
	const struct kobj_ns_type_operations___11 *ns_type;
	const void * (*namespace)(struct device___166 *);
	const struct dev_pm_ops___166 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct fwnode_operations___116;

struct fwnode_handle___116 {
	struct fwnode_handle___116 *secondary;
	const struct fwnode_operations___116 *ops;
};

struct node___142 {
	struct device___166 dev;
};

struct perf_cpu_context___111;

struct pmu___111 {
	struct list_head entry;
	struct module___152 *module;
	struct device___166 *dev;
	const struct attribute_group___167 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___111 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___111 *);
	void (*pmu_disable)(struct pmu___111 *);
	int (*event_init)(struct perf_event___111 *);
	void (*event_mapped)(struct perf_event___111 *, struct mm_struct___178 *);
	void (*event_unmapped)(struct perf_event___111 *, struct mm_struct___178 *);
	int (*add)(struct perf_event___111 *, int);
	void (*del)(struct perf_event___111 *, int);
	void (*start)(struct perf_event___111 *, int);
	void (*stop)(struct perf_event___111 *, int);
	void (*read)(struct perf_event___111 *);
	void (*start_txn)(struct pmu___111 *, unsigned int);
	int (*commit_txn)(struct pmu___111 *);
	void (*cancel_txn)(struct pmu___111 *);
	int (*event_idx)(struct perf_event___111 *);
	void (*sched_task)(struct perf_event_context___111 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___111 *);
	int (*filter_match)(struct perf_event___111 *);
	int (*check_period)(struct perf_event___111 *, u64);
};

struct perf_cpu_context___111 {
	struct perf_event_context___111 ctx;
	struct perf_event_context___111 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___111 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___111 {
	struct cgroup_subsys_state___153 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___104 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___104 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___104 *);
	struct list_head * (*get_fields)(struct trace_event_call___104 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___104 *);
};

struct syscall_metadata___49 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___104 *enter_event;
	struct trace_event_call___104 *exit_event;
};

struct disk_part_tbl___42 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___42 *last_lookup;
	struct hd_struct___42 *part[0];
};

struct block_device_operations___42 {
	int (*open)(struct block_device___179 *, fmode_t);
	void (*release)(struct gendisk___42 *, fmode_t);
	int (*rw_page)(struct block_device___179 *, sector_t, struct page___179 *, unsigned int);
	int (*ioctl)(struct block_device___179 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___179 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___42 *, unsigned int);
	int (*media_changed)(struct gendisk___42 *);
	void (*unlock_native_capacity)(struct gendisk___42 *);
	int (*revalidate_disk)(struct gendisk___42 *);
	int (*getgeo)(struct block_device___179 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___179 *, long unsigned int);
	int (*report_zones)(struct gendisk___42 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___152 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___41 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___42 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___42 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___42 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___41(struct request___42 *, blk_status_t);

struct request___42 {
	struct request_queue___42 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___89 *bio;
	struct bio___89 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___89 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___45 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___41 *saved_end_io;
		} flush;
	};
	struct gendisk___42 *rq_disk;
	struct hd_struct___42 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___41 *end_io;
	void *end_io_data;
	struct request___42 *next_rq;
};

struct fwnode_reference_args___116;

struct fwnode_endpoint___116;

struct fwnode_operations___116 {
	struct fwnode_handle___116 * (*get)(struct fwnode_handle___116 *);
	void (*put)(struct fwnode_handle___116 *);
	bool (*device_is_available)(const struct fwnode_handle___116 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___116 *, const struct device___166 *);
	bool (*property_present)(const struct fwnode_handle___116 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___116 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___116 *, const char *, const char **, size_t);
	struct fwnode_handle___116 * (*get_parent)(const struct fwnode_handle___116 *);
	struct fwnode_handle___116 * (*get_next_child_node)(const struct fwnode_handle___116 *, struct fwnode_handle___116 *);
	struct fwnode_handle___116 * (*get_named_child_node)(const struct fwnode_handle___116 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___116 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___116 *);
	struct fwnode_handle___116 * (*graph_get_next_endpoint)(const struct fwnode_handle___116 *, struct fwnode_handle___116 *);
	struct fwnode_handle___116 * (*graph_get_remote_endpoint)(const struct fwnode_handle___116 *);
	struct fwnode_handle___116 * (*graph_get_port_parent)(struct fwnode_handle___116 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___116 *, struct fwnode_endpoint___116 *);
};

struct fwnode_endpoint___116 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___116 *local_fwnode;
};

struct fwnode_reference_args___116 {
	struct fwnode_handle___116 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct elevator_type___41;

struct elevator_mq_ops___41 {
	int (*init_sched)(struct request_queue___42 *, struct elevator_type___41 *);
	void (*exit_sched)(struct elevator_queue___41 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	bool (*allow_merge)(struct request_queue___42 *, struct request___42 *, struct bio___89 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx *, struct bio___89 *);
	int (*request_merge)(struct request_queue___42 *, struct request___42 **, struct bio___89 *);
	void (*request_merged)(struct request_queue___42 *, struct request___42 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___42 *, struct request___42 *, struct request___42 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___42 *, struct bio___89 *);
	void (*finish_request)(struct request___42 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___42 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___42 *, u64);
	void (*started_request)(struct request___42 *);
	void (*requeue_request)(struct request___42 *);
	struct request___42 * (*former_request)(struct request_queue___42 *, struct request___42 *);
	struct request___42 * (*next_request)(struct request_queue___42 *, struct request___42 *);
	void (*init_icq)(struct io_cq___45 *);
	void (*exit_icq)(struct io_cq___45 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide37;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___41;

struct elevator_type___41 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___41 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___41 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___152 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___41 {
	struct elevator_type___41 *type;
	void *elevator_data;
	struct kobject___173 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___41 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___41 *, char *);
	ssize_t (*store)(struct elevator_queue___41 *, const char *, size_t);
};

struct blkcg_policy_data___32;

struct blkcg___32 {
	struct cgroup_subsys_state___153 css;
	spinlock_t lock;
	struct xarray blkg_tree;
	struct blkcg_gq___32 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___32 *cpd[5];
	struct list_head all_blkcgs_node;
	struct list_head cgwb_list;
	refcount_t cgwb_refcnt;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct blkcg_policy_data___32 {
	struct blkcg___32 *blkcg;
	int plid;
};

struct blkg_policy_data___32 {
	struct blkcg_gq___32 *blkg;
	int plid;
};

struct file___180;

struct fd___22 {
	struct file___180 *file;
	unsigned int flags;
};

struct vfsmount___31;

struct dentry___179;

struct path___179 {
	struct vfsmount___31 *mnt;
	struct dentry___179 *dentry;
};

struct pid___144;

struct fown_struct___144 {
	rwlock_t lock;
	struct pid___144 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct inode___180;

struct file_operations___180;

struct cred___175;

struct address_space___179;

struct file___180 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___179 f_path;
	struct inode___180 *f_inode;
	const struct file_operations___180 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___144 f_owner;
	const struct cred___175 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___179 *f_mapping;
	errseq_t f_wb_err;
};

struct module___153;

struct kiocb___180;

struct poll_table_struct___122;

struct vm_area_struct___180;

struct file_lock___180;

struct page___180;

struct seq_file___169;

struct file_operations___180 {
	struct module___153 *owner;
	loff_t (*llseek)(struct file___180 *, loff_t, int);
	ssize_t (*read)(struct file___180 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___180 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___180 *, struct iov_iter___86 *);
	ssize_t (*write_iter)(struct kiocb___180 *, struct iov_iter___86 *);
	int (*iopoll)(struct kiocb___180 *, bool);
	int (*iterate)(struct file___180 *, struct dir_context *);
	int (*iterate_shared)(struct file___180 *, struct dir_context *);
	__poll_t (*poll)(struct file___180 *, struct poll_table_struct___122 *);
	long int (*unlocked_ioctl)(struct file___180 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___180 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___180 *, struct vm_area_struct___180 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___180 *, struct file___180 *);
	int (*flush)(struct file___180 *, fl_owner_t);
	int (*release)(struct inode___180 *, struct file___180 *);
	int (*fsync)(struct file___180 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___180 *, int);
	int (*lock)(struct file___180 *, int, struct file_lock___180 *);
	ssize_t (*sendpage)(struct file___180 *, struct page___180 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___180 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___180 *, int, struct file_lock___180 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___180 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___180 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___180 *, long int, struct file_lock___180 **, void **);
	long int (*fallocate)(struct file___180 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___169 *, struct file___180 *);
	ssize_t (*copy_file_range)(struct file___180 *, loff_t, struct file___180 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___180 *, loff_t, struct file___180 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___180 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___179 {
	u64 seqnum;
	struct vm_area_struct___180 *vmas[4];
};

struct page_frag___179 {
	struct page___180 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___112;

struct debug_info___112 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___112 *hbp_break[16];
	struct perf_event___112 *hbp_watch[16];
};

struct thread_struct___112 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___112 debug;
	long: 64;
};

struct mm_struct___179;

struct nsproxy___171;

struct signal_struct___160;

struct css_set___154;

struct perf_event_context___112;

struct task_struct___180 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___180 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___179 *mm;
	struct mm_struct___179 *active_mm;
	struct vmacache___179 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___180 *real_parent;
	struct task_struct___180 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___180 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___144 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___144 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___144 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___175 *ptracer_cred;
	const struct cred___175 *real_cred;
	const struct cred___175 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___171 *nsproxy;
	struct signal_struct___160 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___180 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___45 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___154 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___112 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___179 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___180 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___112 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___112 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___180 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___112)(struct perf_event___112 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___112;

struct fasync_struct___179;

struct pid_namespace___144;

struct trace_event_call___105;

struct perf_cgroup___112;

struct perf_event___112 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___112 *group_leader;
	struct pmu___112 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___112 hw;
	struct perf_event_context___112 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___112 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___180 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___179 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___112 *);
	struct callback_head callback_head;
	struct pid_namespace___144 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___112 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___112 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___105 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___112 *cgrp;
	struct list_head sb_list;
};

struct super_block___179;

struct vfsmount___31 {
	struct dentry___179 *mnt_root;
	struct super_block___179 *mnt_sb;
	int mnt_flags;
};

struct dentry_operations___179;

struct dentry___179 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___179 *d_parent;
	struct qstr d_name;
	struct inode___180 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___179 *d_op;
	struct super_block___179 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct rw_semaphore___180 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___180 *owner;
};

struct quota_format_type___179;

struct mem_dqinfo___179 {
	struct quota_format_type___179 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___179;

struct quota_info___179 {
	unsigned int flags;
	struct rw_semaphore___180 dqio_sem;
	struct inode___180 *files[3];
	struct mem_dqinfo___179 info[3];
	const struct quota_format_ops___179 *ops[3];
};

struct rcuwait___179 {
	struct task_struct___180 *task;
};

struct percpu_rw_semaphore___179 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___180 rw_sem;
	struct rcuwait___179 writer;
	int readers_block;
};

struct sb_writers___179 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___179 rw_sem[3];
};

struct file_system_type___179;

struct super_operations___179;

struct dquot_operations___179;

struct quotactl_ops___179;

struct block_device___180;

struct user_namespace___159;

struct super_block___179 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___179 *s_type;
	const struct super_operations___179 *s_op;
	const struct dquot_operations___179 *dq_op;
	const struct quotactl_ops___179 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___179 *s_root;
	struct rw_semaphore___180 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___180 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___179 s_dquot;
	struct sb_writers___179 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___179 *s_d_op;
	int cleancache_poolid;
	struct shrinker___80 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___159 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct address_space_operations___179;

struct address_space___179 {
	struct inode___180 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___180 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___179 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___179;

struct inode___180 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___179 *i_op;
	struct super_block___179 *i_sb;
	struct address_space___179 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___180 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___180 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___179 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___180 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___179 {
	int (*d_revalidate)(struct dentry___179 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___179 *, unsigned int);
	int (*d_hash)(const struct dentry___179 *, struct qstr *);
	int (*d_compare)(const struct dentry___179 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___179 *);
	int (*d_init)(struct dentry___179 *);
	void (*d_release)(struct dentry___179 *);
	void (*d_prune)(struct dentry___179 *);
	void (*d_iput)(struct dentry___179 *, struct inode___180 *);
	char * (*d_dname)(struct dentry___179 *, char *, int);
	struct vfsmount___31 * (*d_automount)(struct path___179 *);
	int (*d_manage)(const struct path___179 *, bool);
	struct dentry___179 * (*d_real)(struct dentry___179 *, const struct inode___180 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct key___175;

struct ucounts___159;

struct user_namespace___159 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___159 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___10 ns;
	long unsigned int flags;
	struct key___175 *persistent_keyring_register;
	struct rw_semaphore___180 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___159 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___180 *pgtable_t___179;

struct dev_pagemap___177;

struct page___180 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___179 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___180 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___179 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___179 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___177 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___179;

struct lruvec___179 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___179 *pgdat;
};

struct zone___179 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___179 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___179 {
	struct zone___179 *zone;
	int zone_idx;
};

struct zonelist___179 {
	struct zoneref___179 _zonerefs[25];
};

struct pglist_data___179 {
	struct zone___179 node_zones[3];
	struct zonelist___179 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___180 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___180 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___179 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___180 {
	void *stack;
	struct task_struct___180 *task;
	long int status;
};

struct blocking_notifier_head___179 {
	struct rw_semaphore___180 rwsem;
	struct notifier_block *head;
};

struct upid___144 {
	int nr;
	struct pid_namespace___144 *ns;
};

struct pid_namespace___144 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___180 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___144 *parent;
	struct vfsmount___31 *proc_mnt;
	struct dentry___179 *proc_self;
	struct dentry___179 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___159 *user_ns;
	struct ucounts___159 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___10 ns;
};

struct pid___144 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___144 numbers[1];
};

struct vm_operations_struct___177;

struct vm_area_struct___180 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___180 *vm_next;
	struct vm_area_struct___180 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___179 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___177 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___180 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___179;

struct mm_struct___179 {
	struct {
		struct vm_area_struct___180 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___180 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___180 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___179 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___180 *owner;
		struct user_namespace___159 *user_ns;
		struct file___180 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___179 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___177)(struct vm_area_struct___180 *, long unsigned int, const struct page___180 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___177)(struct page___180 *, void *);

struct device___167;

struct dev_pagemap___177 {
	dev_page_fault_t___177 page_fault;
	dev_page_free_t___177 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___167 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct vm_fault___177;

struct vm_operations_struct___177 {
	void (*open)(struct vm_area_struct___180 *);
	void (*close)(struct vm_area_struct___180 *);
	int (*split)(struct vm_area_struct___180 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___180 *);
	vm_fault_t (*fault)(struct vm_fault___177 *);
	vm_fault_t (*huge_fault)(struct vm_fault___177 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___177 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___180 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___177 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___177 *);
	int (*access)(struct vm_area_struct___180 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___180 *);
	int (*set_policy)(struct vm_area_struct___180 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___180 *, long unsigned int);
	struct page___180 * (*find_special_page)(struct vm_area_struct___180 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___179 {
	struct task_struct___180 *task;
	struct core_thread___179 *next;
};

struct core_state___179 {
	atomic_t nr_threads;
	struct core_thread___179 dumper;
	struct completion startup;
};

struct vm_fault___177 {
	struct vm_area_struct___180 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___180 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___180 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___179 prealloc_pte;
};

struct user_struct___175 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___175 *uid_keyring;
	struct key___175 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___175 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___175 *session_keyring;
	struct key___175 *process_keyring;
	struct key___175 *thread_keyring;
	struct key___175 *request_key_auth;
	void *security;
	struct user_struct___175 *user;
	struct user_namespace___159 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___154;

struct nsproxy___171 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___144 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___154 *cgroup_ns;
};

struct signal_struct___160 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___180 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___180 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___144 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___144 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___179 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___144 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___154;

struct cgroup___154;

struct css_set___154 {
	struct cgroup_subsys_state___154 *subsys[13];
	refcount_t refcount;
	struct css_set___154 *dom_cset;
	struct cgroup___154 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___154 *mg_src_cgrp;
	struct cgroup___154 *mg_dst_cgrp;
	struct css_set___154 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___112 {
	struct pmu___112 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___180 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___112 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

union thread_union___161 {
	struct task_struct___180 task;
	long unsigned int stack[8192];
};

struct kiocb___180 {
	struct file___180 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___180 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___179 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___180 *ia_file;
};

struct dquot___179 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___179 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___179 {
	int qf_fmt_id;
	const struct quota_format_ops___179 *qf_ops;
	struct module___153 *qf_owner;
	struct quota_format_type___179 *qf_next;
};

struct quota_format_ops___179 {
	int (*check_quota_file)(struct super_block___179 *, int);
	int (*read_file_info)(struct super_block___179 *, int);
	int (*write_file_info)(struct super_block___179 *, int);
	int (*free_file_info)(struct super_block___179 *, int);
	int (*read_dqblk)(struct dquot___179 *);
	int (*commit_dqblk)(struct dquot___179 *);
	int (*release_dqblk)(struct dquot___179 *);
	int (*get_next_id)(struct super_block___179 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___179 {
	int (*write_dquot)(struct dquot___179 *);
	struct dquot___179 * (*alloc_dquot)(struct super_block___179 *, int);
	void (*destroy_dquot)(struct dquot___179 *);
	int (*acquire_dquot)(struct dquot___179 *);
	int (*release_dquot)(struct dquot___179 *);
	int (*mark_dirty)(struct dquot___179 *);
	int (*write_info)(struct super_block___179 *, int);
	qsize_t * (*get_reserved_space)(struct inode___180 *);
	int (*get_projid)(struct inode___180 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___180 *, qsize_t *);
	int (*get_next_id)(struct super_block___179 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___179 {
	int (*quota_on)(struct super_block___179 *, int, int, const struct path___179 *);
	int (*quota_off)(struct super_block___179 *, int);
	int (*quota_enable)(struct super_block___179 *, unsigned int);
	int (*quota_disable)(struct super_block___179 *, unsigned int);
	int (*quota_sync)(struct super_block___179 *, int);
	int (*set_info)(struct super_block___179 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___179 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___179 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___179 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___179 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___179 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___173;

struct kobj_type___173;

struct kernfs_node___176;

struct kobject___174 {
	const char *name;
	struct list_head entry;
	struct kobject___174 *parent;
	struct kset___173 *kset;
	struct kobj_type___173 *ktype;
	struct kernfs_node___176 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___150 {
	struct kobject___174 kobj;
	struct module___153 *mod;
	struct kobject___174 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___150 {
	struct module___153 *mod;
	struct latch_tree_node node;
};

struct module_layout___150 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___150 mtn;
};

struct module_attribute___150;

struct kernel_param___150;

struct module___153 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___150 mkobj;
	struct module_attribute___150 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___174 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___150 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___150 core_layout;
	struct module_layout___150 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___105 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___179 {
	int (*writepage)(struct page___180 *, struct writeback_control___3 *);
	int (*readpage)(struct file___180 *, struct page___180 *);
	int (*writepages)(struct address_space___179 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___180 *);
	int (*readpages)(struct file___180 *, struct address_space___179 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___180 *, struct address_space___179 *, loff_t, unsigned int, unsigned int, struct page___180 **, void **);
	int (*write_end)(struct file___180 *, struct address_space___179 *, loff_t, unsigned int, unsigned int, struct page___180 *, void *);
	sector_t (*bmap)(struct address_space___179 *, sector_t);
	void (*invalidatepage)(struct page___180 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___180 *, gfp_t);
	void (*freepage)(struct page___180 *);
	ssize_t (*direct_IO)(struct kiocb___180 *, struct iov_iter___86 *);
	int (*migratepage)(struct address_space___179 *, struct page___180 *, struct page___180 *, enum migrate_mode);
	bool (*isolate_page)(struct page___180 *, isolate_mode_t);
	void (*putback_page)(struct page___180 *);
	int (*launder_page)(struct page___180 *);
	int (*is_partially_uptodate)(struct page___180 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___180 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___179 *, struct page___180 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___180 *, sector_t *);
	void (*swap_deactivate)(struct file___180 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___180 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___180 *bd_inode;
	struct super_block___179 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___180 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___179 {
	struct dentry___179 * (*lookup)(struct inode___180 *, struct dentry___179 *, unsigned int);
	const char * (*get_link)(struct dentry___179 *, struct inode___180 *, struct delayed_call *);
	int (*permission)(struct inode___180 *, int);
	struct posix_acl * (*get_acl)(struct inode___180 *, int);
	int (*readlink)(struct dentry___179 *, char *, int);
	int (*create)(struct inode___180 *, struct dentry___179 *, umode_t, bool);
	int (*link)(struct dentry___179 *, struct inode___180 *, struct dentry___179 *);
	int (*unlink)(struct inode___180 *, struct dentry___179 *);
	int (*symlink)(struct inode___180 *, struct dentry___179 *, const char *);
	int (*mkdir)(struct inode___180 *, struct dentry___179 *, umode_t);
	int (*rmdir)(struct inode___180 *, struct dentry___179 *);
	int (*mknod)(struct inode___180 *, struct dentry___179 *, umode_t, dev_t);
	int (*rename)(struct inode___180 *, struct dentry___179 *, struct inode___180 *, struct dentry___179 *, unsigned int);
	int (*setattr)(struct dentry___179 *, struct iattr___179 *);
	int (*getattr)(const struct path___179 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___179 *, char *, size_t);
	int (*fiemap)(struct inode___180 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___180 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___180 *, struct dentry___179 *, struct file___180 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___180 *, struct dentry___179 *, umode_t);
	int (*set_acl)(struct inode___180 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___179 {
	void (*fl_copy_lock)(struct file_lock___180 *, struct file_lock___180 *);
	void (*fl_release_private)(struct file_lock___180 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___179;

struct file_lock___180 {
	struct file_lock___180 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___180 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___179 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___179 *fl_ops;
	const struct lock_manager_operations___179 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___179 {
	int (*lm_compare_owner)(struct file_lock___180 *, struct file_lock___180 *);
	long unsigned int (*lm_owner_key)(struct file_lock___180 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___180 *);
	int (*lm_grant)(struct file_lock___180 *, int);
	bool (*lm_break)(struct file_lock___180 *);
	int (*lm_change)(struct file_lock___180 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___180 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___179 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___179 *fa_next;
	struct file___180 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___179 {
	const char *name;
	int fs_flags;
	struct dentry___179 * (*mount)(struct file_system_type___179 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___179 *);
	struct module___153 *owner;
	struct file_system_type___179 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___179 {
	struct inode___180 * (*alloc_inode)(struct super_block___179 *);
	void (*destroy_inode)(struct inode___180 *);
	void (*dirty_inode)(struct inode___180 *, int);
	int (*write_inode)(struct inode___180 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___180 *);
	void (*evict_inode)(struct inode___180 *);
	void (*put_super)(struct super_block___179 *);
	int (*sync_fs)(struct super_block___179 *, int);
	int (*freeze_super)(struct super_block___179 *);
	int (*freeze_fs)(struct super_block___179 *);
	int (*thaw_super)(struct super_block___179 *);
	int (*unfreeze_fs)(struct super_block___179 *);
	int (*statfs)(struct dentry___179 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___179 *, int *, char *);
	void (*umount_begin)(struct super_block___179 *);
	int (*show_options)(struct seq_file___169 *, struct dentry___179 *);
	int (*show_devname)(struct seq_file___169 *, struct dentry___179 *);
	int (*show_path)(struct seq_file___169 *, struct dentry___179 *);
	int (*show_stats)(struct seq_file___169 *, struct dentry___179 *);
	ssize_t (*quota_read)(struct super_block___179 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___179 *, int, const char *, size_t, loff_t);
	struct dquot___179 ** (*get_dquots)(struct inode___180 *);
	int (*bdev_try_to_free_page)(struct super_block___179 *, struct page___180 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___179 *, struct shrink_control___80 *);
	long int (*free_cached_objects)(struct super_block___179 *, struct shrink_control___80 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___122)(struct file___180 *, wait_queue_head_t *, struct poll_table_struct___122 *);

struct poll_table_struct___122 {
	poll_queue_proc___122 _qproc;
	__poll_t _key;
};

struct seq_operations___167;

struct seq_file___169 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___167 *op;
	int poll_event;
	const struct file___180 *file;
	void *private;
};

typedef int (*key_restrict_link_func_t___175)(struct key___175 *, const struct key_type *, const union key_payload *, struct key___175 *);

struct key_restriction___175;

struct key___175 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___180 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___175 *restrict_link;
};

struct key_restriction___175 {
	key_restrict_link_func_t___175 check;
	struct key___175 *key;
	struct key_type *keytype;
};

struct dev_pm_info___167 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___167 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___167;

struct bus_type___167;

struct device_driver___167;

struct dev_pm_domain___167;

struct class___167;

struct attribute_group___168;

struct device___167 {
	struct device___167 *parent;
	struct device_private *p;
	struct kobject___174 kobj;
	const char *init_name;
	const struct device_type___167 *type;
	struct mutex mutex;
	struct bus_type___167 *bus;
	struct device_driver___167 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___167 power;
	struct dev_pm_domain___167 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___167 *class;
	const struct attribute_group___168 **groups;
	void (*release)(struct device___167 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct kobj_attribute___174 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___174 *, struct kobj_attribute___174 *, char *);
	ssize_t (*store)(struct kobject___174 *, struct kobj_attribute___174 *, const char *, size_t);
};

typedef void compound_page_dtor___177(struct page___180 *);

struct seq_operations___167 {
	void * (*start)(struct seq_file___169 *, loff_t *);
	void (*stop)(struct seq_file___169 *, void *);
	void * (*next)(struct seq_file___169 *, void *, loff_t *);
	int (*show)(struct seq_file___169 *, void *);
};

struct cgroup_namespace___154 {
	refcount_t count;
	struct ns_common___10 ns;
	struct user_namespace___159 *user_ns;
	struct ucounts___159 *ucounts;
	struct css_set___154 *root_cset;
};

struct ucounts___159 {
	struct hlist_node node;
	struct user_namespace___159 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct kernfs_root___176;

struct kernfs_elem_dir___176 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___176 *root;
};

struct kernfs_syscall_ops___176;

struct kernfs_root___176 {
	struct kernfs_node___176 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___176 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___176 {
	struct kernfs_node___176 *target_kn;
};

struct kernfs_ops___176;

struct kernfs_elem_attr___176 {
	const struct kernfs_ops___176 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___176 *notify_next;
};

struct kernfs_node___176 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___176 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___176 dir;
		struct kernfs_elem_symlink___176 symlink;
		struct kernfs_elem_attr___176 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___176;

struct kernfs_ops___176 {
	int (*open)(struct kernfs_open_file___176 *);
	void (*release)(struct kernfs_open_file___176 *);
	int (*seq_show)(struct seq_file___169 *, void *);
	void * (*seq_start)(struct seq_file___169 *, loff_t *);
	void * (*seq_next)(struct seq_file___169 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___169 *, void *);
	ssize_t (*read)(struct kernfs_open_file___176 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___176 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___176 *, struct vm_area_struct___180 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___176 *, struct poll_table_struct___122 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___176 {
	int (*remount_fs)(struct kernfs_root___176 *, int *, char *);
	int (*show_options)(struct seq_file___169 *, struct kernfs_root___176 *);
	int (*mkdir)(struct kernfs_node___176 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___176 *);
	int (*rename)(struct kernfs_node___176 *, struct kernfs_node___176 *, const char *);
	int (*show_path)(struct seq_file___169 *, struct kernfs_node___176 *, struct kernfs_root___176 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___176 {
	struct kernfs_node___176 *kn;
	struct file___180 *file;
	struct seq_file___169 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___177 *vm_ops;
};

struct bin_attribute___167;

struct attribute_group___168 {
	const char *name;
	umode_t (*is_visible)(struct kobject___174 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___174 *, struct bin_attribute___167 *, int);
	struct attribute **attrs;
	struct bin_attribute___167 **bin_attrs;
};

struct bin_attribute___167 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___180 *, struct kobject___174 *, struct bin_attribute___167 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___180 *, struct kobject___174 *, struct bin_attribute___167 *, char *, loff_t, size_t);
	int (*mmap)(struct file___180 *, struct kobject___174 *, struct bin_attribute___167 *, struct vm_area_struct___180 *);
};

struct sysfs_ops___173 {
	ssize_t (*show)(struct kobject___174 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___174 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___173;

struct kset___173 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___174 kobj;
	const struct kset_uevent_ops___173 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___173 {
	void (*release)(struct kobject___174 *);
	const struct sysfs_ops___173 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___11 * (*child_ns_type)(struct kobject___174 *);
	const void * (*namespace)(struct kobject___174 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___173 {
	int (* const filter)(struct kset___173 *, struct kobject___174 *);
	const char * (* const name)(struct kset___173 *, struct kobject___174 *);
	int (* const uevent)(struct kset___173 *, struct kobject___174 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___150 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___150 *);
	int (*get)(char *, const struct kernel_param___150 *);
	void (*free)(void *);
};

struct kparam_array___150;

struct kernel_param___150 {
	const char *name;
	struct module___153 *mod;
	const struct kernel_param_ops___150 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___150 *arr;
	};
};

struct kparam_array___150 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___150 *ops;
	void *elem;
};

struct module_attribute___150 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___150 *, struct module_kobject___150 *, char *);
	ssize_t (*store)(struct module_attribute___150 *, struct module_kobject___150 *, const char *, size_t);
	void (*setup)(struct module___153 *, const char *);
	int (*test)(struct module___153 *);
	void (*free)(struct module___153 *);
};

struct trace_event_class___105;

struct trace_event_call___105 {
	struct list_head list;
	struct trace_event_class___105 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___21 *prog_array;
	int (*perf_perm)(struct trace_event_call___105 *, struct perf_event___112 *);
};

struct dev_pm_ops___167 {
	int (*prepare)(struct device___167 *);
	void (*complete)(struct device___167 *);
	int (*suspend)(struct device___167 *);
	int (*resume)(struct device___167 *);
	int (*freeze)(struct device___167 *);
	int (*thaw)(struct device___167 *);
	int (*poweroff)(struct device___167 *);
	int (*restore)(struct device___167 *);
	int (*suspend_late)(struct device___167 *);
	int (*resume_early)(struct device___167 *);
	int (*freeze_late)(struct device___167 *);
	int (*thaw_early)(struct device___167 *);
	int (*poweroff_late)(struct device___167 *);
	int (*restore_early)(struct device___167 *);
	int (*suspend_noirq)(struct device___167 *);
	int (*resume_noirq)(struct device___167 *);
	int (*freeze_noirq)(struct device___167 *);
	int (*thaw_noirq)(struct device___167 *);
	int (*poweroff_noirq)(struct device___167 *);
	int (*restore_noirq)(struct device___167 *);
	int (*runtime_suspend)(struct device___167 *);
	int (*runtime_resume)(struct device___167 *);
	int (*runtime_idle)(struct device___167 *);
};

struct dev_pm_domain___167 {
	struct dev_pm_ops___167 ops;
	void (*detach)(struct device___167 *, bool);
	int (*activate)(struct device___167 *);
	void (*sync)(struct device___167 *);
	void (*dismiss)(struct device___167 *);
};

struct bus_type___167 {
	const char *name;
	const char *dev_name;
	struct device___167 *dev_root;
	const struct attribute_group___168 **bus_groups;
	const struct attribute_group___168 **dev_groups;
	const struct attribute_group___168 **drv_groups;
	int (*match)(struct device___167 *, struct device_driver___167 *);
	int (*uevent)(struct device___167 *, struct kobj_uevent_env *);
	int (*probe)(struct device___167 *);
	int (*remove)(struct device___167 *);
	void (*shutdown)(struct device___167 *);
	int (*online)(struct device___167 *);
	int (*offline)(struct device___167 *);
	int (*suspend)(struct device___167 *, pm_message_t);
	int (*resume)(struct device___167 *);
	int (*num_vf)(struct device___167 *);
	int (*dma_configure)(struct device___167 *);
	const struct dev_pm_ops___167 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___167 {
	const char *name;
	struct bus_type___167 *bus;
	struct module___153 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___167 *);
	int (*remove)(struct device___167 *);
	void (*shutdown)(struct device___167 *);
	int (*suspend)(struct device___167 *, pm_message_t);
	int (*resume)(struct device___167 *);
	const struct attribute_group___168 **groups;
	const struct dev_pm_ops___167 *pm;
	void (*coredump)(struct device___167 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___167 {
	const char *name;
	const struct attribute_group___168 **groups;
	int (*uevent)(struct device___167 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___167 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___167 *);
	const struct dev_pm_ops___167 *pm;
};

struct class___167 {
	const char *name;
	struct module___153 *owner;
	const struct attribute_group___168 **class_groups;
	const struct attribute_group___168 **dev_groups;
	struct kobject___174 *dev_kobj;
	int (*dev_uevent)(struct device___167 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___167 *, umode_t *);
	void (*class_release)(struct class___167 *);
	void (*dev_release)(struct device___167 *);
	int (*shutdown_pre)(struct device___167 *);
	const struct kobj_ns_type_operations___11 *ns_type;
	const void * (*namespace)(struct device___167 *);
	const struct dev_pm_ops___167 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___143 {
	struct device___167 dev;
};

struct bpf_map___154;

struct bpf_map_ops___154 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___154 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___154 *, struct file___180 *);
	void (*map_free)(struct bpf_map___154 *);
	int (*map_get_next_key)(struct bpf_map___154 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___154 *);
	void * (*map_lookup_elem)(struct bpf_map___154 *, void *);
	int (*map_update_elem)(struct bpf_map___154 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___154 *, void *);
	int (*map_push_elem)(struct bpf_map___154 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___154 *, void *);
	int (*map_peek_elem)(struct bpf_map___154 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___154 *, struct file___180 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___154 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___154 *, void *, struct seq_file___169 *);
	int (*map_check_btf)(const struct bpf_map___154 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___154 {
	const struct bpf_map_ops___154 *ops;
	struct bpf_map___154 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___175 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___154;

typedef void (*kthread_work_func_t___154)(struct kthread_work___154 *);

struct kthread_worker___154;

struct kthread_work___154 {
	struct list_head node;
	kthread_work_func_t___154 func;
	struct kthread_worker___154 *worker;
	int canceling;
};

struct kthread_worker___154 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___180 *task;
	struct kthread_work___154 *current_work;
};

struct kthread_delayed_work___154 {
	struct kthread_work___154 work;
	struct timer_list timer;
};

struct psi_group___154 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___154 *poll_kworker;
	struct kthread_delayed_work___154 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___154 {
	struct kernfs_node___176 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___154;

struct cgroup_subsys_state___154 {
	struct cgroup___154 *cgroup;
	struct cgroup_subsys___154 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___154 *parent;
};

struct cgroup_root___154;

struct cgroup_rstat_cpu___154;

struct cgroup___154 {
	struct cgroup_subsys_state___154 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___176 *kn;
	struct cgroup_file___154 procs_file;
	struct cgroup_file___154 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___154 *subsys[13];
	struct cgroup_root___154 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___154 *dom_cgrp;
	struct cgroup_rstat_cpu___154 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___21 bpf;
	atomic_t congestion_count;
	struct cgroup___154 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___154 psi;
	int ancestor_ids[0];
};

struct cftype___154;

struct cgroup_subsys___154 {
	struct cgroup_subsys_state___154 * (*css_alloc)(struct cgroup_subsys_state___154 *);
	int (*css_online)(struct cgroup_subsys_state___154 *);
	void (*css_offline)(struct cgroup_subsys_state___154 *);
	void (*css_released)(struct cgroup_subsys_state___154 *);
	void (*css_free)(struct cgroup_subsys_state___154 *);
	void (*css_reset)(struct cgroup_subsys_state___154 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___154 *, int);
	int (*css_extra_stat_show)(struct seq_file___169 *, struct cgroup_subsys_state___154 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___180 *);
	void (*cancel_fork)(struct task_struct___180 *);
	void (*fork)(struct task_struct___180 *);
	void (*exit)(struct task_struct___180 *);
	void (*free)(struct task_struct___180 *);
	void (*bind)(struct cgroup_subsys_state___154 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___154 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___154 *dfl_cftypes;
	struct cftype___154 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___154 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___154 *updated_children;
	struct cgroup___154 *updated_next;
};

struct cgroup_root___154 {
	struct kernfs_root___176 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___154 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___154 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___154 *ss;
	struct list_head node;
	struct kernfs_ops___176 *kf_ops;
	int (*open)(struct kernfs_open_file___176 *);
	void (*release)(struct kernfs_open_file___176 *);
	u64 (*read_u64)(struct cgroup_subsys_state___154 *, struct cftype___154 *);
	s64 (*read_s64)(struct cgroup_subsys_state___154 *, struct cftype___154 *);
	int (*seq_show)(struct seq_file___169 *, void *);
	void * (*seq_start)(struct seq_file___169 *, loff_t *);
	void * (*seq_next)(struct seq_file___169 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___169 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___154 *, struct cftype___154 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___154 *, struct cftype___154 *, s64);
	ssize_t (*write)(struct kernfs_open_file___176 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___176 *, struct poll_table_struct___122 *);
};

struct perf_cpu_context___112;

struct pmu___112 {
	struct list_head entry;
	struct module___153 *module;
	struct device___167 *dev;
	const struct attribute_group___168 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___112 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___112 *);
	void (*pmu_disable)(struct pmu___112 *);
	int (*event_init)(struct perf_event___112 *);
	void (*event_mapped)(struct perf_event___112 *, struct mm_struct___179 *);
	void (*event_unmapped)(struct perf_event___112 *, struct mm_struct___179 *);
	int (*add)(struct perf_event___112 *, int);
	void (*del)(struct perf_event___112 *, int);
	void (*start)(struct perf_event___112 *, int);
	void (*stop)(struct perf_event___112 *, int);
	void (*read)(struct perf_event___112 *);
	void (*start_txn)(struct pmu___112 *, unsigned int);
	int (*commit_txn)(struct pmu___112 *);
	void (*cancel_txn)(struct pmu___112 *);
	int (*event_idx)(struct perf_event___112 *);
	void (*sched_task)(struct perf_event_context___112 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___112 *);
	int (*filter_match)(struct perf_event___112 *);
	int (*check_period)(struct perf_event___112 *, u64);
};

struct perf_cpu_context___112 {
	struct perf_event_context___112 ctx;
	struct perf_event_context___112 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___112 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___112 {
	struct cgroup_subsys_state___154 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___105 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___105 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___105 *);
	struct list_head * (*get_fields)(struct trace_event_call___105 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___105 *);
};

struct syscall_metadata___50 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___105 *enter_event;
	struct trace_event_call___105 *exit_event;
};

typedef int __kernel_daddr_t;

struct ustat {
	__kernel_daddr_t f_tfree;
	__kernel_ino_t f_tinode;
	char f_fname[6];
	char f_fpack[6];
};

struct statfs {
	__kernel_long_t f_type;
	__kernel_long_t f_bsize;
	__kernel_long_t f_blocks;
	__kernel_long_t f_bfree;
	__kernel_long_t f_bavail;
	__kernel_long_t f_files;
	__kernel_long_t f_ffree;
	__kernel_fsid_t f_fsid;
	__kernel_long_t f_namelen;
	__kernel_long_t f_frsize;
	__kernel_long_t f_flags;
	__kernel_long_t f_spare[4];
};

struct statfs64 {
	__kernel_long_t f_type;
	__kernel_long_t f_bsize;
	__u64 f_blocks;
	__u64 f_bfree;
	__u64 f_bavail;
	__u64 f_files;
	__u64 f_ffree;
	__kernel_fsid_t f_fsid;
	__kernel_long_t f_namelen;
	__kernel_long_t f_frsize;
	__kernel_long_t f_flags;
	__kernel_long_t f_spare[4];
};

typedef void (*poll_queue_proc___123)(struct file___179 *, wait_queue_head_t *, struct poll_table_struct___23 *);

typedef struct ns_common___10 *ns_get_path_helper_t(void *);

struct ns_get_path_task_args {
	const struct proc_ns_operations___10 *ns_ops;
	struct task_struct___175 *task;
};

struct module___154;

struct file___181;

struct kiocb___181;

struct iov_iter___87;

struct poll_table_struct___123;

struct vm_area_struct___181;

struct inode___181;

struct file_lock___181;

struct page___181;

struct seq_file___170;

struct file_operations___181 {
	struct module___154 *owner;
	loff_t (*llseek)(struct file___181 *, loff_t, int);
	ssize_t (*read)(struct file___181 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___181 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___181 *, struct iov_iter___87 *);
	ssize_t (*write_iter)(struct kiocb___181 *, struct iov_iter___87 *);
	int (*iopoll)(struct kiocb___181 *, bool);
	int (*iterate)(struct file___181 *, struct dir_context *);
	int (*iterate_shared)(struct file___181 *, struct dir_context *);
	__poll_t (*poll)(struct file___181 *, struct poll_table_struct___123 *);
	long int (*unlocked_ioctl)(struct file___181 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___181 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___181 *, struct vm_area_struct___181 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___181 *, struct file___181 *);
	int (*flush)(struct file___181 *, fl_owner_t);
	int (*release)(struct inode___181 *, struct file___181 *);
	int (*fsync)(struct file___181 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___181 *, int);
	int (*lock)(struct file___181 *, int, struct file_lock___181 *);
	ssize_t (*sendpage)(struct file___181 *, struct page___181 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___181 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___181 *, int, struct file_lock___181 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___181 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___181 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___181 *, long int, struct file_lock___181 **, void **);
	long int (*fallocate)(struct file___181 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___170 *, struct file___181 *);
	ssize_t (*copy_file_range)(struct file___181 *, loff_t, struct file___181 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___181 *, loff_t, struct file___181 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___181 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___180 {
	u64 seqnum;
	struct vm_area_struct___181 *vmas[4];
};

struct page_frag___180 {
	struct page___181 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___113;

struct debug_info___113 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___113 *hbp_break[16];
	struct perf_event___113 *hbp_watch[16];
};

struct thread_struct___113 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___113 debug;
	long: 64;
};

struct mm_struct___180;

struct mem_cgroup___81;

struct pid___145;

struct cred___176;

struct nsproxy___172;

struct signal_struct___161;

struct bio_list___90;

struct backing_dev_info___90;

struct io_context___46;

struct css_set___155;

struct perf_event_context___113;

struct request_queue___43;

struct vm_struct___130;

struct task_struct___181 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___181 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___180 *mm;
	struct mm_struct___180 *active_mm;
	struct vmacache___180 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___181 *real_parent;
	struct task_struct___181 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___181 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___81 *active_memcg;
	long int rh_reserved2;
	struct pid___145 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___145 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___145 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___176 *ptracer_cred;
	const struct cred___176 *real_cred;
	const struct cred___176 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___172 *nsproxy;
	struct signal_struct___161 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___181 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___90 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___90 *backing_dev_info;
	struct io_context___46 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___155 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___113 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___180 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___81 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___43 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___181 *oom_reaper_list;
	struct vm_struct___130 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___113 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___113 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___181 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___113)(struct perf_event___113 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___113;

struct fasync_struct___180;

struct pid_namespace___145;

struct trace_event_call___106;

struct perf_cgroup___113;

struct perf_event___113 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___113 *group_leader;
	struct pmu___113 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___113 hw;
	struct perf_event_context___113 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___113 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___181 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___180 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___113 *);
	struct callback_head callback_head;
	struct pid_namespace___145 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___113 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___113 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___106 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___113 *cgrp;
	struct list_head sb_list;
};

struct key___176;

struct user_struct___176 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___176 *uid_keyring;
	struct key___176 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct upid___145 {
	int nr;
	struct pid_namespace___145 *ns;
};

struct dentry___180;

struct user_namespace___160;

struct ucounts___160;

struct pid_namespace___145 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___181 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___145 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___180 *proc_self;
	struct dentry___180 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___160 *user_ns;
	struct ucounts___160 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___10 ns;
};

struct pid___145 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___145 numbers[1];
};

struct rw_semaphore___181 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___181 *owner;
};

struct user_namespace___160 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___160 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___10 ns;
	long unsigned int flags;
	struct key___176 *persistent_keyring_register;
	struct rw_semaphore___181 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___160 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct secondary_data___181 {
	void *stack;
	struct task_struct___181 *task;
	long int status;
};

typedef struct page___181 *pgtable_t___180;

struct address_space___180;

struct dev_pagemap___178;

struct page___181 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___180 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___181 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___180 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___180 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___178 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___81 *mem_cgroup;
};

struct vm_operations_struct___178;

struct vm_area_struct___181 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___181 *vm_next;
	struct vm_area_struct___181 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___180 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___178 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___181 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___180;

struct mm_struct___180 {
	struct {
		struct vm_area_struct___181 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___181 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___181 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___180 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___181 *owner;
		struct user_namespace___160 *user_ns;
		struct file___181 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___180 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup___155;

struct cgroup_subsys___155;

struct cgroup_subsys_state___155 {
	struct cgroup___155 *cgroup;
	struct cgroup_subsys___155 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___155 *parent;
};

struct kernfs_node___177;

struct cgroup_file___155 {
	struct kernfs_node___177 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___81;

struct mem_cgroup___81 {
	struct cgroup_subsys_state___155 css;
	struct mem_cgroup_id___18 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___155 events_file;
	struct cgroup_file___155 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___181 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___81 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cred___176 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___176 *session_keyring;
	struct key___176 *process_keyring;
	struct key___176 *thread_keyring;
	struct key___176 *request_key_auth;
	void *security;
	struct user_struct___176 *user;
	struct user_namespace___160 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___155;

struct nsproxy___172 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___145 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___155 *cgroup_ns;
};

struct signal_struct___161 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___181 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___181 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___145 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___145 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___180 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___145 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___90;

struct bio_list___90 {
	struct bio___90 *head;
	struct bio___90 *tail;
};

struct bdi_writeback_congested___90;

struct bdi_writeback___90 {
	struct backing_dev_info___90 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___90 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___155 *memcg_css;
	struct cgroup_subsys_state___155 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___168;

struct backing_dev_info___90 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___90 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___168 *dev;
	struct device___168 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___180 *debug_dir;
	struct dentry___180 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___46;

struct io_context___46 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___46 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___155 {
	struct cgroup_subsys_state___155 *subsys[13];
	refcount_t refcount;
	struct css_set___155 *dom_cset;
	struct cgroup___155 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___155 *mg_src_cgrp;
	struct cgroup___155 *mg_dst_cgrp;
	struct css_set___155 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___113 {
	struct pmu___113 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___181 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___113 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

typedef blk_qc_t make_request_fn___42(struct request_queue___43 *, struct bio___90 *);

struct request___43;

typedef int dma_drain_needed_fn___42(struct request___43 *);

struct kset___174;

struct kobj_type___174;

struct kobject___175 {
	const char *name;
	struct list_head entry;
	struct kobject___175 *parent;
	struct kset___174 *kset;
	struct kobj_type___174 *ktype;
	struct kernfs_node___177 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___42;

struct bsg_class_device___42 {
	struct device___168 *class_dev;
	int minor;
	struct request_queue___43 *queue;
	const struct bsg_ops___42 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___90 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___90 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___42;

struct blkcg_gq___33;

struct blk_trace___3;

struct request_queue___43 {
	struct list_head queue_head;
	struct request___43 *last_merge;
	struct elevator_queue___42 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___42 *make_request_fn;
	dma_drain_needed_fn___42 *dma_drain_needed;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___90 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___175 kobj;
	struct kobject___175 *mq_kobj;
	struct blk_integrity integrity;
	struct device___168 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___33 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace___3 *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide36;
		union {		};
	};
	struct bsg_class_device___42 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___90 bio_split;
	struct dentry___180 *debugfs_dir;
	struct dentry___180 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___130 {
	struct vm_struct___130 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___181 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___162 {
	struct task_struct___181 task;
	long unsigned int stack[8192];
};

typedef int (*key_restrict_link_func_t___176)(struct key___176 *, const struct key_type *, const union key_payload *, struct key___176 *);

struct key_restriction___176;

struct key___176 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___181 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___176 *restrict_link;
};

struct key_restriction___176 {
	key_restrict_link_func_t___176 check;
	struct key___176 *key;
	struct key_type *keytype;
};

struct dentry_operations___180;

struct super_block___180;

struct dentry___180 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___180 *d_parent;
	struct qstr d_name;
	struct inode___181 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___180 *d_op;
	struct super_block___180 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___180;

struct address_space___180 {
	struct inode___181 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___181 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___180 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___180;

struct block_device___181;

struct inode___181 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___180 *i_op;
	struct super_block___180 *i_sb;
	struct address_space___180 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___181 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___90 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___181 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___180 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___181 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___180;

struct dentry_operations___180 {
	int (*d_revalidate)(struct dentry___180 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___180 *, unsigned int);
	int (*d_hash)(const struct dentry___180 *, struct qstr *);
	int (*d_compare)(const struct dentry___180 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___180 *);
	int (*d_init)(struct dentry___180 *);
	void (*d_release)(struct dentry___180 *);
	void (*d_prune)(struct dentry___180 *);
	void (*d_iput)(struct dentry___180 *, struct inode___181 *);
	char * (*d_dname)(struct dentry___180 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___180 *);
	int (*d_manage)(const struct path___180 *, bool);
	struct dentry___180 * (*d_real)(struct dentry___180 *, const struct inode___181 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___180;

struct mem_dqinfo___180 {
	struct quota_format_type___180 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___180;

struct quota_info___180 {
	unsigned int flags;
	struct rw_semaphore___181 dqio_sem;
	struct inode___181 *files[3];
	struct mem_dqinfo___180 info[3];
	const struct quota_format_ops___180 *ops[3];
};

struct rcuwait___180 {
	struct task_struct___181 *task;
};

struct percpu_rw_semaphore___180 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___181 rw_sem;
	struct rcuwait___180 writer;
	int readers_block;
};

struct sb_writers___180 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___180 rw_sem[3];
};

struct shrink_control___81;

struct shrinker___81 {
	long unsigned int (*count_objects)(struct shrinker___81 *, struct shrink_control___81 *);
	long unsigned int (*scan_objects)(struct shrinker___81 *, struct shrink_control___81 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___180;

struct super_operations___180;

struct dquot_operations___180;

struct quotactl_ops___180;

struct super_block___180 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___180 *s_type;
	const struct super_operations___180 *s_op;
	const struct dquot_operations___180 *dq_op;
	const struct quotactl_ops___180 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___180 *s_root;
	struct rw_semaphore___181 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___181 *s_bdev;
	struct backing_dev_info___90 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___180 s_dquot;
	struct sb_writers___180 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___180 *s_d_op;
	int cleancache_poolid;
	struct shrinker___81 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___160 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct path___180 {
	struct vfsmount *mnt;
	struct dentry___180 *dentry;
};

struct shrink_control___81 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___81 *memcg;
};

struct pglist_data___180;

struct lruvec___180 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___180 *pgdat;
};

struct zone___180 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___180 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___180 {
	struct zone___180 *zone;
	int zone_idx;
};

struct zonelist___180 {
	struct zoneref___180 _zonerefs[25];
};

struct pglist_data___180 {
	struct zone___180 node_zones[3];
	struct zonelist___180 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___181 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___181 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___180 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___180 {
	struct rw_semaphore___181 rwsem;
	struct notifier_block *head;
};

typedef int (*dev_page_fault_t___178)(struct vm_area_struct___181 *, long unsigned int, const struct page___181 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___178)(struct page___181 *, void *);

struct dev_pagemap___178 {
	dev_page_fault_t___178 page_fault;
	dev_page_free_t___178 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___168 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct fown_struct___145 {
	rwlock_t lock;
	struct pid___145 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___181 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___180 f_path;
	struct inode___181 *f_inode;
	const struct file_operations___181 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___145 f_owner;
	const struct cred___176 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___180 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___178;

struct vm_operations_struct___178 {
	void (*open)(struct vm_area_struct___181 *);
	void (*close)(struct vm_area_struct___181 *);
	int (*split)(struct vm_area_struct___181 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___181 *);
	vm_fault_t (*fault)(struct vm_fault___178 *);
	vm_fault_t (*huge_fault)(struct vm_fault___178 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___178 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___181 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___178 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___178 *);
	int (*access)(struct vm_area_struct___181 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___181 *);
	int (*set_policy)(struct vm_area_struct___181 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___181 *, long unsigned int);
	struct page___181 * (*find_special_page)(struct vm_area_struct___181 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___180 {
	struct task_struct___181 *task;
	struct core_thread___180 *next;
};

struct core_state___180 {
	atomic_t nr_threads;
	struct core_thread___180 dumper;
	struct completion startup;
};

struct vm_fault___178 {
	struct vm_area_struct___181 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___181 *cow_page;
	struct mem_cgroup___81 *memcg;
	struct page___181 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___180 prealloc_pte;
};

struct io_cq___46 {
	struct request_queue___43 *q;
	struct io_context___46 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___6 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct buffer_head___3;

typedef int get_block_t___2(struct inode___181 *, sector_t, struct buffer_head___3 *, int);

typedef void bh_end_io_t___3(struct buffer_head___3 *, int);

struct buffer_head___3 {
	long unsigned int b_state;
	struct buffer_head___3 *b_this_page;
	struct page___181 *b_page;
	sector_t b_blocknr;
	size_t b_size;
	char *b_data;
	struct block_device___181 *b_bdev;
	bh_end_io_t___3 *b_end_io;
	void *b_private;
	struct list_head b_assoc_buffers;
	struct address_space___180 *b_assoc_map;
	atomic_t b_count;
};

struct kiocb___181 {
	struct file___181 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___181 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___180 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___181 *ia_file;
};

struct dquot___180 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___180 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___180 {
	int qf_fmt_id;
	const struct quota_format_ops___180 *qf_ops;
	struct module___154 *qf_owner;
	struct quota_format_type___180 *qf_next;
};

struct quota_format_ops___180 {
	int (*check_quota_file)(struct super_block___180 *, int);
	int (*read_file_info)(struct super_block___180 *, int);
	int (*write_file_info)(struct super_block___180 *, int);
	int (*free_file_info)(struct super_block___180 *, int);
	int (*read_dqblk)(struct dquot___180 *);
	int (*commit_dqblk)(struct dquot___180 *);
	int (*release_dqblk)(struct dquot___180 *);
	int (*get_next_id)(struct super_block___180 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___180 {
	int (*write_dquot)(struct dquot___180 *);
	struct dquot___180 * (*alloc_dquot)(struct super_block___180 *, int);
	void (*destroy_dquot)(struct dquot___180 *);
	int (*acquire_dquot)(struct dquot___180 *);
	int (*release_dquot)(struct dquot___180 *);
	int (*mark_dirty)(struct dquot___180 *);
	int (*write_info)(struct super_block___180 *, int);
	qsize_t * (*get_reserved_space)(struct inode___181 *);
	int (*get_projid)(struct inode___181 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___181 *, qsize_t *);
	int (*get_next_id)(struct super_block___180 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___180 {
	int (*quota_on)(struct super_block___180 *, int, int, const struct path___180 *);
	int (*quota_off)(struct super_block___180 *, int);
	int (*quota_enable)(struct super_block___180 *, unsigned int);
	int (*quota_disable)(struct super_block___180 *, unsigned int);
	int (*quota_sync)(struct super_block___180 *, int);
	int (*set_info)(struct super_block___180 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___180 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___180 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___180 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___180 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___180 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___151 {
	struct kobject___175 kobj;
	struct module___154 *mod;
	struct kobject___175 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___151 {
	struct module___154 *mod;
	struct latch_tree_node node;
};

struct module_layout___151 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___151 mtn;
};

struct module_attribute___151;

struct kernel_param___151;

struct module___154 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___151 mkobj;
	struct module_attribute___151 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___175 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___151 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___151 core_layout;
	struct module_layout___151 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___106 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___87;

struct swap_info_struct___59;

struct address_space_operations___180 {
	int (*writepage)(struct page___181 *, struct writeback_control___87 *);
	int (*readpage)(struct file___181 *, struct page___181 *);
	int (*writepages)(struct address_space___180 *, struct writeback_control___87 *);
	int (*set_page_dirty)(struct page___181 *);
	int (*readpages)(struct file___181 *, struct address_space___180 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___181 *, struct address_space___180 *, loff_t, unsigned int, unsigned int, struct page___181 **, void **);
	int (*write_end)(struct file___181 *, struct address_space___180 *, loff_t, unsigned int, unsigned int, struct page___181 *, void *);
	sector_t (*bmap)(struct address_space___180 *, sector_t);
	void (*invalidatepage)(struct page___181 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___181 *, gfp_t);
	void (*freepage)(struct page___181 *);
	ssize_t (*direct_IO)(struct kiocb___181 *, struct iov_iter___87 *);
	int (*migratepage)(struct address_space___180 *, struct page___181 *, struct page___181 *, enum migrate_mode);
	bool (*isolate_page)(struct page___181 *, isolate_mode_t);
	void (*putback_page)(struct page___181 *);
	int (*launder_page)(struct page___181 *);
	int (*is_partially_uptodate)(struct page___181 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___181 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___180 *, struct page___181 *);
	int (*swap_activate)(struct swap_info_struct___59 *, struct file___181 *, sector_t *);
	void (*swap_deactivate)(struct file___181 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___87 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___90 *wb;
	struct inode___181 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___90;

struct iov_iter___87 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___90 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct swap_info_struct___59 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___181 *bdev;
	struct file___181 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct hd_struct___43;

struct gendisk___43;

struct block_device___181 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___181 *bd_inode;
	struct super_block___180 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___181 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___43 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___43 *bd_disk;
	struct request_queue___43 *bd_queue;
	struct backing_dev_info___90 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___168 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___168 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___168;

struct bus_type___168;

struct device_driver___168;

struct dev_pm_domain___168;

struct fwnode_handle___117;

struct class___168;

struct attribute_group___169;

struct device___168 {
	struct device___168 *parent;
	struct device_private *p;
	struct kobject___175 kobj;
	const char *init_name;
	const struct device_type___168 *type;
	struct mutex mutex;
	struct bus_type___168 *bus;
	struct device_driver___168 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___168 power;
	struct dev_pm_domain___168 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___117 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___168 *class;
	const struct attribute_group___169 **groups;
	void (*release)(struct device___168 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___43 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___168 __dev;
	struct kobject___175 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___43;

struct block_device_operations___43;

struct gendisk___43 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___43 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___43 *part_tbl;
	struct hd_struct___43 part0;
	const struct block_device_operations___43 *fops;
	struct request_queue___43 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___181 lookup_sem;
	struct kobject___175 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___175 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___180 {
	struct dentry___180 * (*lookup)(struct inode___181 *, struct dentry___180 *, unsigned int);
	const char * (*get_link)(struct dentry___180 *, struct inode___181 *, struct delayed_call *);
	int (*permission)(struct inode___181 *, int);
	struct posix_acl * (*get_acl)(struct inode___181 *, int);
	int (*readlink)(struct dentry___180 *, char *, int);
	int (*create)(struct inode___181 *, struct dentry___180 *, umode_t, bool);
	int (*link)(struct dentry___180 *, struct inode___181 *, struct dentry___180 *);
	int (*unlink)(struct inode___181 *, struct dentry___180 *);
	int (*symlink)(struct inode___181 *, struct dentry___180 *, const char *);
	int (*mkdir)(struct inode___181 *, struct dentry___180 *, umode_t);
	int (*rmdir)(struct inode___181 *, struct dentry___180 *);
	int (*mknod)(struct inode___181 *, struct dentry___180 *, umode_t, dev_t);
	int (*rename)(struct inode___181 *, struct dentry___180 *, struct inode___181 *, struct dentry___180 *, unsigned int);
	int (*setattr)(struct dentry___180 *, struct iattr___180 *);
	int (*getattr)(const struct path___180 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___180 *, char *, size_t);
	int (*fiemap)(struct inode___181 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___181 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___181 *, struct dentry___180 *, struct file___181 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___181 *, struct dentry___180 *, umode_t);
	int (*set_acl)(struct inode___181 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___180 {
	void (*fl_copy_lock)(struct file_lock___181 *, struct file_lock___181 *);
	void (*fl_release_private)(struct file_lock___181 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___180;

struct file_lock___181 {
	struct file_lock___181 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___181 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___180 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___180 *fl_ops;
	const struct lock_manager_operations___180 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___180 {
	int (*lm_compare_owner)(struct file_lock___181 *, struct file_lock___181 *);
	long unsigned int (*lm_owner_key)(struct file_lock___181 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___181 *);
	int (*lm_grant)(struct file_lock___181 *, int);
	bool (*lm_break)(struct file_lock___181 *);
	int (*lm_change)(struct file_lock___181 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___181 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___180 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___180 *fa_next;
	struct file___181 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___180 {
	const char *name;
	int fs_flags;
	struct dentry___180 * (*mount)(struct file_system_type___180 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___180 *);
	struct module___154 *owner;
	struct file_system_type___180 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___180 {
	struct inode___181 * (*alloc_inode)(struct super_block___180 *);
	void (*destroy_inode)(struct inode___181 *);
	void (*dirty_inode)(struct inode___181 *, int);
	int (*write_inode)(struct inode___181 *, struct writeback_control___87 *);
	int (*drop_inode)(struct inode___181 *);
	void (*evict_inode)(struct inode___181 *);
	void (*put_super)(struct super_block___180 *);
	int (*sync_fs)(struct super_block___180 *, int);
	int (*freeze_super)(struct super_block___180 *);
	int (*freeze_fs)(struct super_block___180 *);
	int (*thaw_super)(struct super_block___180 *);
	int (*unfreeze_fs)(struct super_block___180 *);
	int (*statfs)(struct dentry___180 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___180 *, int *, char *);
	void (*umount_begin)(struct super_block___180 *);
	int (*show_options)(struct seq_file___170 *, struct dentry___180 *);
	int (*show_devname)(struct seq_file___170 *, struct dentry___180 *);
	int (*show_path)(struct seq_file___170 *, struct dentry___180 *);
	int (*show_stats)(struct seq_file___170 *, struct dentry___180 *);
	ssize_t (*quota_read)(struct super_block___180 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___180 *, int, const char *, size_t, loff_t);
	struct dquot___180 ** (*get_dquots)(struct inode___181 *);
	int (*bdev_try_to_free_page)(struct super_block___180 *, struct page___181 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___180 *, struct shrink_control___81 *);
	long int (*free_cached_objects)(struct super_block___180 *, struct shrink_control___81 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___124)(struct file___181 *, wait_queue_head_t *, struct poll_table_struct___123 *);

struct poll_table_struct___123 {
	poll_queue_proc___124 _qproc;
	__poll_t _key;
};

struct seq_operations___168;

struct seq_file___170 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___168 *op;
	int poll_event;
	const struct file___181 *file;
	void *private;
};

typedef void bio_end_io_t___90(struct bio___90 *);

struct bio_vec___90 {
	struct page___181 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___90;

struct bio___90 {
	struct bio___90 *bi_next;
	struct gendisk___43 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___90 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___33 *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___90 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___90 *bi_io_vec;
	struct bio_set___90 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___90 bi_inline_vecs[0];
};

struct kobj_attribute___175 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___175 *, struct kobj_attribute___175 *, char *);
	ssize_t (*store)(struct kobject___175 *, struct kobj_attribute___175 *, const char *, size_t);
};

typedef void compound_page_dtor___178(struct page___181 *);

struct seq_operations___168 {
	void * (*start)(struct seq_file___170 *, loff_t *);
	void (*stop)(struct seq_file___170 *, void *);
	void * (*next)(struct seq_file___170 *, void *, loff_t *);
	int (*show)(struct seq_file___170 *, void *);
};

struct cgroup_namespace___155 {
	refcount_t count;
	struct ns_common___10 ns;
	struct user_namespace___160 *user_ns;
	struct ucounts___160 *ucounts;
	struct css_set___155 *root_cset;
};

struct ucounts___160 {
	struct hlist_node node;
	struct user_namespace___160 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct kernfs_root___177;

struct kernfs_elem_dir___177 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___177 *root;
};

struct kernfs_syscall_ops___177;

struct kernfs_root___177 {
	struct kernfs_node___177 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___177 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___177 {
	struct kernfs_node___177 *target_kn;
};

struct kernfs_ops___177;

struct kernfs_elem_attr___177 {
	const struct kernfs_ops___177 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___177 *notify_next;
};

struct kernfs_node___177 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___177 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___177 dir;
		struct kernfs_elem_symlink___177 symlink;
		struct kernfs_elem_attr___177 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___177;

struct kernfs_ops___177 {
	int (*open)(struct kernfs_open_file___177 *);
	void (*release)(struct kernfs_open_file___177 *);
	int (*seq_show)(struct seq_file___170 *, void *);
	void * (*seq_start)(struct seq_file___170 *, loff_t *);
	void * (*seq_next)(struct seq_file___170 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___170 *, void *);
	ssize_t (*read)(struct kernfs_open_file___177 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___177 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___177 *, struct vm_area_struct___181 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___177 *, struct poll_table_struct___123 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___177 {
	int (*remount_fs)(struct kernfs_root___177 *, int *, char *);
	int (*show_options)(struct seq_file___170 *, struct kernfs_root___177 *);
	int (*mkdir)(struct kernfs_node___177 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___177 *);
	int (*rename)(struct kernfs_node___177 *, struct kernfs_node___177 *, const char *);
	int (*show_path)(struct seq_file___170 *, struct kernfs_node___177 *, struct kernfs_root___177 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___177 {
	struct kernfs_node___177 *kn;
	struct file___181 *file;
	struct seq_file___170 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___178 *vm_ops;
};

struct bin_attribute___168;

struct attribute_group___169 {
	const char *name;
	umode_t (*is_visible)(struct kobject___175 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___175 *, struct bin_attribute___168 *, int);
	struct attribute **attrs;
	struct bin_attribute___168 **bin_attrs;
};

struct bin_attribute___168 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___181 *, struct kobject___175 *, struct bin_attribute___168 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___181 *, struct kobject___175 *, struct bin_attribute___168 *, char *, loff_t, size_t);
	int (*mmap)(struct file___181 *, struct kobject___175 *, struct bin_attribute___168 *, struct vm_area_struct___181 *);
};

struct sysfs_ops___174 {
	ssize_t (*show)(struct kobject___175 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___175 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___174;

struct kset___174 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___175 kobj;
	const struct kset_uevent_ops___174 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___174 {
	void (*release)(struct kobject___175 *);
	const struct sysfs_ops___174 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___11 * (*child_ns_type)(struct kobject___175 *);
	const void * (*namespace)(struct kobject___175 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___174 {
	int (* const filter)(struct kset___174 *, struct kobject___175 *);
	const char * (* const name)(struct kset___174 *, struct kobject___175 *);
	int (* const uevent)(struct kset___174 *, struct kobject___175 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___151 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___151 *);
	int (*get)(char *, const struct kernel_param___151 *);
	void (*free)(void *);
};

struct kparam_array___151;

struct kernel_param___151 {
	const char *name;
	struct module___154 *mod;
	const struct kernel_param_ops___151 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___151 *arr;
	};
};

struct kparam_array___151 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___151 *ops;
	void *elem;
};

struct module_attribute___151 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___151 *, struct module_kobject___151 *, char *);
	ssize_t (*store)(struct module_attribute___151 *, struct module_kobject___151 *, const char *, size_t);
	void (*setup)(struct module___154 *, const char *);
	int (*test)(struct module___154 *);
	void (*free)(struct module___154 *);
};

struct trace_event_class___106;

struct trace_event_call___106 {
	struct list_head list;
	struct trace_event_class___106 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___21 *prog_array;
	int (*perf_perm)(struct trace_event_call___106 *, struct perf_event___113 *);
};

struct dev_pm_ops___168 {
	int (*prepare)(struct device___168 *);
	void (*complete)(struct device___168 *);
	int (*suspend)(struct device___168 *);
	int (*resume)(struct device___168 *);
	int (*freeze)(struct device___168 *);
	int (*thaw)(struct device___168 *);
	int (*poweroff)(struct device___168 *);
	int (*restore)(struct device___168 *);
	int (*suspend_late)(struct device___168 *);
	int (*resume_early)(struct device___168 *);
	int (*freeze_late)(struct device___168 *);
	int (*thaw_early)(struct device___168 *);
	int (*poweroff_late)(struct device___168 *);
	int (*restore_early)(struct device___168 *);
	int (*suspend_noirq)(struct device___168 *);
	int (*resume_noirq)(struct device___168 *);
	int (*freeze_noirq)(struct device___168 *);
	int (*thaw_noirq)(struct device___168 *);
	int (*poweroff_noirq)(struct device___168 *);
	int (*restore_noirq)(struct device___168 *);
	int (*runtime_suspend)(struct device___168 *);
	int (*runtime_resume)(struct device___168 *);
	int (*runtime_idle)(struct device___168 *);
};

struct dev_pm_domain___168 {
	struct dev_pm_ops___168 ops;
	void (*detach)(struct device___168 *, bool);
	int (*activate)(struct device___168 *);
	void (*sync)(struct device___168 *);
	void (*dismiss)(struct device___168 *);
};

struct bus_type___168 {
	const char *name;
	const char *dev_name;
	struct device___168 *dev_root;
	const struct attribute_group___169 **bus_groups;
	const struct attribute_group___169 **dev_groups;
	const struct attribute_group___169 **drv_groups;
	int (*match)(struct device___168 *, struct device_driver___168 *);
	int (*uevent)(struct device___168 *, struct kobj_uevent_env *);
	int (*probe)(struct device___168 *);
	int (*remove)(struct device___168 *);
	void (*shutdown)(struct device___168 *);
	int (*online)(struct device___168 *);
	int (*offline)(struct device___168 *);
	int (*suspend)(struct device___168 *, pm_message_t);
	int (*resume)(struct device___168 *);
	int (*num_vf)(struct device___168 *);
	int (*dma_configure)(struct device___168 *);
	const struct dev_pm_ops___168 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___168 {
	const char *name;
	struct bus_type___168 *bus;
	struct module___154 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___168 *);
	int (*remove)(struct device___168 *);
	void (*shutdown)(struct device___168 *);
	int (*suspend)(struct device___168 *, pm_message_t);
	int (*resume)(struct device___168 *);
	const struct attribute_group___169 **groups;
	const struct dev_pm_ops___168 *pm;
	void (*coredump)(struct device___168 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___168 {
	const char *name;
	const struct attribute_group___169 **groups;
	int (*uevent)(struct device___168 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___168 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___168 *);
	const struct dev_pm_ops___168 *pm;
};

struct class___168 {
	const char *name;
	struct module___154 *owner;
	const struct attribute_group___169 **class_groups;
	const struct attribute_group___169 **dev_groups;
	struct kobject___175 *dev_kobj;
	int (*dev_uevent)(struct device___168 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___168 *, umode_t *);
	void (*class_release)(struct class___168 *);
	void (*dev_release)(struct device___168 *);
	int (*shutdown_pre)(struct device___168 *);
	const struct kobj_ns_type_operations___11 *ns_type;
	const void * (*namespace)(struct device___168 *);
	const struct dev_pm_ops___168 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct fwnode_operations___117;

struct fwnode_handle___117 {
	struct fwnode_handle___117 *secondary;
	const struct fwnode_operations___117 *ops;
};

struct node___144 {
	struct device___168 dev;
};

struct bpf_map___155;

struct bpf_map_ops___155 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___155 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___155 *, struct file___181 *);
	void (*map_free)(struct bpf_map___155 *);
	int (*map_get_next_key)(struct bpf_map___155 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___155 *);
	void * (*map_lookup_elem)(struct bpf_map___155 *, void *);
	int (*map_update_elem)(struct bpf_map___155 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___155 *, void *);
	int (*map_push_elem)(struct bpf_map___155 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___155 *, void *);
	int (*map_peek_elem)(struct bpf_map___155 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___155 *, struct file___181 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___155 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___155 *, void *, struct seq_file___170 *);
	int (*map_check_btf)(const struct bpf_map___155 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___155 {
	const struct bpf_map_ops___155 *ops;
	struct bpf_map___155 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___176 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___155;

typedef void (*kthread_work_func_t___155)(struct kthread_work___155 *);

struct kthread_worker___155;

struct kthread_work___155 {
	struct list_head node;
	kthread_work_func_t___155 func;
	struct kthread_worker___155 *worker;
	int canceling;
};

struct kthread_worker___155 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___181 *task;
	struct kthread_work___155 *current_work;
};

struct kthread_delayed_work___155 {
	struct kthread_work___155 work;
	struct timer_list timer;
};

struct psi_group___155 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___155 *poll_kworker;
	struct kthread_delayed_work___155 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___155;

struct cgroup_rstat_cpu___155;

struct cgroup___155 {
	struct cgroup_subsys_state___155 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___177 *kn;
	struct cgroup_file___155 procs_file;
	struct cgroup_file___155 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___155 *subsys[13];
	struct cgroup_root___155 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___155 *dom_cgrp;
	struct cgroup_rstat_cpu___155 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___21 bpf;
	atomic_t congestion_count;
	struct cgroup___155 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___155 psi;
	int ancestor_ids[0];
};

struct cftype___155;

struct cgroup_subsys___155 {
	struct cgroup_subsys_state___155 * (*css_alloc)(struct cgroup_subsys_state___155 *);
	int (*css_online)(struct cgroup_subsys_state___155 *);
	void (*css_offline)(struct cgroup_subsys_state___155 *);
	void (*css_released)(struct cgroup_subsys_state___155 *);
	void (*css_free)(struct cgroup_subsys_state___155 *);
	void (*css_reset)(struct cgroup_subsys_state___155 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___155 *, int);
	int (*css_extra_stat_show)(struct seq_file___170 *, struct cgroup_subsys_state___155 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___181 *);
	void (*cancel_fork)(struct task_struct___181 *);
	void (*fork)(struct task_struct___181 *);
	void (*exit)(struct task_struct___181 *);
	void (*free)(struct task_struct___181 *);
	void (*bind)(struct cgroup_subsys_state___155 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___155 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___155 *dfl_cftypes;
	struct cftype___155 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___155 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___155 *updated_children;
	struct cgroup___155 *updated_next;
};

struct cgroup_root___155 {
	struct kernfs_root___177 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___155 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___155 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___155 *ss;
	struct list_head node;
	struct kernfs_ops___177 *kf_ops;
	int (*open)(struct kernfs_open_file___177 *);
	void (*release)(struct kernfs_open_file___177 *);
	u64 (*read_u64)(struct cgroup_subsys_state___155 *, struct cftype___155 *);
	s64 (*read_s64)(struct cgroup_subsys_state___155 *, struct cftype___155 *);
	int (*seq_show)(struct seq_file___170 *, void *);
	void * (*seq_start)(struct seq_file___170 *, loff_t *);
	void * (*seq_next)(struct seq_file___170 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___170 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___155 *, struct cftype___155 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___155 *, struct cftype___155 *, s64);
	ssize_t (*write)(struct kernfs_open_file___177 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___177 *, struct poll_table_struct___123 *);
};

struct perf_cpu_context___113;

struct pmu___113 {
	struct list_head entry;
	struct module___154 *module;
	struct device___168 *dev;
	const struct attribute_group___169 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___113 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___113 *);
	void (*pmu_disable)(struct pmu___113 *);
	int (*event_init)(struct perf_event___113 *);
	void (*event_mapped)(struct perf_event___113 *, struct mm_struct___180 *);
	void (*event_unmapped)(struct perf_event___113 *, struct mm_struct___180 *);
	int (*add)(struct perf_event___113 *, int);
	void (*del)(struct perf_event___113 *, int);
	void (*start)(struct perf_event___113 *, int);
	void (*stop)(struct perf_event___113 *, int);
	void (*read)(struct perf_event___113 *);
	void (*start_txn)(struct pmu___113 *, unsigned int);
	int (*commit_txn)(struct pmu___113 *);
	void (*cancel_txn)(struct pmu___113 *);
	int (*event_idx)(struct perf_event___113 *);
	void (*sched_task)(struct perf_event_context___113 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___113 *);
	int (*filter_match)(struct perf_event___113 *);
	int (*check_period)(struct perf_event___113 *, u64);
};

struct perf_cpu_context___113 {
	struct perf_event_context___113 ctx;
	struct perf_event_context___113 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___113 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___113 {
	struct cgroup_subsys_state___155 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___106 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___106 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___106 *);
	struct list_head * (*get_fields)(struct trace_event_call___106 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___106 *);
};

struct syscall_metadata___51 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___106 *enter_event;
	struct trace_event_call___106 *exit_event;
};

struct dax_device;

struct iomap_page_ops;

struct iomap___2 {
	u64 addr;
	loff_t offset;
	u64 length;
	u16 type;
	u16 flags;
	struct block_device___181 *bdev;
	struct dax_device *dax_dev;
	void *inline_data;
	void *private;
	const struct iomap_page_ops *page_ops;
};

struct iomap_page_ops {
	int (*page_prepare)(struct inode___181 *, loff_t, unsigned int, struct iomap___2 *);
	void (*page_done)(struct inode___181 *, loff_t, unsigned int, struct page___181 *, struct iomap___2 *);
};

struct bio_integrity_payload___90 {
	struct bio___90 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___90 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___90 bip_inline_vecs[0];
};

struct blkcg___33;

struct blkg_policy_data___33;

struct blkcg_gq___33 {
	struct request_queue___43 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___33 *blkcg;
	struct bdi_writeback_congested___90 *wb_congested;
	struct blkcg_gq___33 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_rwstat stat_bytes;
	struct blkg_rwstat stat_ios;
	struct blkg_policy_data___33 *pd[5];
	struct callback_head callback_head;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
};

struct disk_part_tbl___43 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___43 *last_lookup;
	struct hd_struct___43 *part[0];
};

struct block_device_operations___43 {
	int (*open)(struct block_device___181 *, fmode_t);
	void (*release)(struct gendisk___43 *, fmode_t);
	int (*rw_page)(struct block_device___181 *, sector_t, struct page___181 *, unsigned int);
	int (*ioctl)(struct block_device___181 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___181 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___43 *, unsigned int);
	int (*media_changed)(struct gendisk___43 *);
	void (*unlock_native_capacity)(struct gendisk___43 *);
	int (*revalidate_disk)(struct gendisk___43 *);
	int (*getgeo)(struct block_device___181 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___181 *, long unsigned int);
	int (*report_zones)(struct gendisk___43 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___154 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bdi_writeback_congested___90 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___90 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bsg_ops___42 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___43 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___43 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___43 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___42(struct request___43 *, blk_status_t);

struct request___43 {
	struct request_queue___43 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___90 *bio;
	struct bio___90 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___90 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___46 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___42 *saved_end_io;
		} flush;
	};
	struct gendisk___43 *rq_disk;
	struct hd_struct___43 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___42 *end_io;
	void *end_io_data;
	struct request___43 *next_rq;
};

struct fwnode_reference_args___117;

struct fwnode_endpoint___117;

struct fwnode_operations___117 {
	struct fwnode_handle___117 * (*get)(struct fwnode_handle___117 *);
	void (*put)(struct fwnode_handle___117 *);
	bool (*device_is_available)(const struct fwnode_handle___117 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___117 *, const struct device___168 *);
	bool (*property_present)(const struct fwnode_handle___117 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___117 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___117 *, const char *, const char **, size_t);
	struct fwnode_handle___117 * (*get_parent)(const struct fwnode_handle___117 *);
	struct fwnode_handle___117 * (*get_next_child_node)(const struct fwnode_handle___117 *, struct fwnode_handle___117 *);
	struct fwnode_handle___117 * (*get_named_child_node)(const struct fwnode_handle___117 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___117 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___117 *);
	struct fwnode_handle___117 * (*graph_get_next_endpoint)(const struct fwnode_handle___117 *, struct fwnode_handle___117 *);
	struct fwnode_handle___117 * (*graph_get_remote_endpoint)(const struct fwnode_handle___117 *);
	struct fwnode_handle___117 * (*graph_get_port_parent)(struct fwnode_handle___117 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___117 *, struct fwnode_endpoint___117 *);
};

struct fwnode_endpoint___117 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___117 *local_fwnode;
};

struct fwnode_reference_args___117 {
	struct fwnode_handle___117 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct elevator_type___42;

struct elevator_mq_ops___42 {
	int (*init_sched)(struct request_queue___43 *, struct elevator_type___42 *);
	void (*exit_sched)(struct elevator_queue___42 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	bool (*allow_merge)(struct request_queue___43 *, struct request___43 *, struct bio___90 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx *, struct bio___90 *);
	int (*request_merge)(struct request_queue___43 *, struct request___43 **, struct bio___90 *);
	void (*request_merged)(struct request_queue___43 *, struct request___43 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___43 *, struct request___43 *, struct request___43 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___43 *, struct bio___90 *);
	void (*finish_request)(struct request___43 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___43 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___43 *, u64);
	void (*started_request)(struct request___43 *);
	void (*requeue_request)(struct request___43 *);
	struct request___43 * (*former_request)(struct request_queue___43 *, struct request___43 *);
	struct request___43 * (*next_request)(struct request_queue___43 *, struct request___43 *);
	void (*init_icq)(struct io_cq___46 *);
	void (*exit_icq)(struct io_cq___46 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide35;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___42;

struct elevator_type___42 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___42 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___42 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___154 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___42 {
	struct elevator_type___42 *type;
	void *elevator_data;
	struct kobject___175 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___42 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___42 *, char *);
	ssize_t (*store)(struct elevator_queue___42 *, const char *, size_t);
};

struct rchan___3;

struct blk_trace___3 {
	int trace_state;
	struct rchan___3 *rchan;
	long unsigned int *sequence;
	unsigned char *msg_data;
	u16 act_mask;
	u64 start_lba;
	u64 end_lba;
	u32 pid;
	u32 dev;
	struct dentry___180 *dir;
	struct dentry___180 *dropped_file;
	struct dentry___180 *msg_file;
	struct list_head running_list;
	atomic_t dropped;
};

struct blkcg_policy_data___33;

struct blkcg___33 {
	struct cgroup_subsys_state___155 css;
	spinlock_t lock;
	struct xarray blkg_tree;
	struct blkcg_gq___33 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___33 *cpd[5];
	struct list_head all_blkcgs_node;
	struct list_head cgwb_list;
	refcount_t cgwb_refcnt;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct blkcg_policy_data___33 {
	struct blkcg___33 *blkcg;
	int plid;
};

struct blkg_policy_data___33 {
	struct blkcg_gq___33 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___81 {
	struct mem_cgroup___81 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___81 {
	struct lruvec___180 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___81 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___81 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct pagevec___8 {
	unsigned char nr;
	bool percpu_pvec_drained;
	struct page___181 *pages[15];
};

struct rchan_buf___3 {
	void *start;
	void *data;
	size_t offset;
	size_t subbufs_produced;
	size_t subbufs_consumed;
	struct rchan___3 *chan;
	wait_queue_head_t read_wait;
	struct irq_work wakeup_work;
	struct dentry___180 *dentry;
	struct kref kref;
	struct page___181 **page_array;
	unsigned int page_count;
	unsigned int finalized;
	size_t *padding;
	size_t prev_padding;
	size_t bytes_consumed;
	size_t early_bytes;
	unsigned int cpu;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
};

struct rchan_callbacks___3;

struct rchan___3 {
	u32 version;
	size_t subbuf_size;
	size_t n_subbufs;
	size_t alloc_size;
	struct rchan_callbacks___3 *cb;
	struct kref kref;
	void *private_data;
	size_t last_toobig;
	struct rchan_buf___3 **buf;
	int is_global;
	struct list_head list;
	struct dentry___180 *parent;
	int has_base_filename;
	char base_filename[255];
};

struct rchan_callbacks___3 {
	int (*subbuf_start)(struct rchan_buf___3 *, void *, void *, size_t);
	void (*buf_mapped)(struct rchan_buf___3 *, struct file___181 *);
	void (*buf_unmapped)(struct rchan_buf___3 *, struct file___181 *);
	struct dentry___180 * (*create_buf_file)(const char *, struct dentry___180 *, umode_t, struct rchan_buf___3 *, int *);
	int (*remove_buf_file)(struct dentry___180 *);
};

struct bh_lru {
	struct buffer_head___3 *bhs[16];
};

struct bh_accounting {
	int nr;
	int ratelimit;
};

struct module___155;

struct file___182;

struct kiocb___182;

struct iov_iter___88;

struct vm_area_struct___182;

struct inode___182;

struct file_lock___182;

struct page___182;

struct seq_file___171;

struct file_operations___182 {
	struct module___155 *owner;
	loff_t (*llseek)(struct file___182 *, loff_t, int);
	ssize_t (*read)(struct file___182 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___182 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___182 *, struct iov_iter___88 *);
	ssize_t (*write_iter)(struct kiocb___182 *, struct iov_iter___88 *);
	int (*iopoll)(struct kiocb___182 *, bool);
	int (*iterate)(struct file___182 *, struct dir_context *);
	int (*iterate_shared)(struct file___182 *, struct dir_context *);
	__poll_t (*poll)(struct file___182 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___182 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___182 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___182 *, struct vm_area_struct___182 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___182 *, struct file___182 *);
	int (*flush)(struct file___182 *, fl_owner_t);
	int (*release)(struct inode___182 *, struct file___182 *);
	int (*fsync)(struct file___182 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___182 *, int);
	int (*lock)(struct file___182 *, int, struct file_lock___182 *);
	ssize_t (*sendpage)(struct file___182 *, struct page___182 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___182 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___182 *, int, struct file_lock___182 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___182 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___182 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___182 *, long int, struct file_lock___182 **, void **);
	long int (*fallocate)(struct file___182 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___171 *, struct file___182 *);
	ssize_t (*copy_file_range)(struct file___182 *, loff_t, struct file___182 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___182 *, loff_t, struct file___182 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___182 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___181 {
	u64 seqnum;
	struct vm_area_struct___182 *vmas[4];
};

struct page_frag___181 {
	struct page___182 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___181;

struct mem_cgroup___82;

struct cred___177;

struct nsproxy___173;

struct bio_list___91;

struct backing_dev_info___91;

struct io_context___47;

struct css_set___156;

struct request_queue___44;

struct vm_struct___131;

struct task_struct___182 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___182 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___181 *mm;
	struct mm_struct___181 *active_mm;
	struct vmacache___181 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___182 *real_parent;
	struct task_struct___182 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___182 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___82 *active_memcg;
	long int rh_reserved2;
	struct pid___145 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___145 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___145 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___177 *ptracer_cred;
	const struct cred___177 *real_cred;
	const struct cred___177 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___173 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___182 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___91 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___91 *backing_dev_info;
	struct io_context___47 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___156 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___181 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___82 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___44 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___182 *oom_reaper_list;
	struct vm_struct___131 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___113 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___182 *pgtable_t___181;

struct address_space___181;

struct dev_pagemap___179;

struct page___182 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___181 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___182 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___181 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___181 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___179 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___82 *mem_cgroup;
};

struct pglist_data___181;

struct lruvec___181 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___181 *pgdat;
};

struct zone___181 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___181 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___181 {
	struct zone___181 *zone;
	int zone_idx;
};

struct zonelist___181 {
	struct zoneref___181 _zonerefs[25];
};

struct pglist_data___181 {
	struct zone___181 node_zones[3];
	struct zonelist___181 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___182 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___182 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___181 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___182 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___182 *owner;
};

struct secondary_data___182 {
	void *stack;
	struct task_struct___182 *task;
	long int status;
};

struct blocking_notifier_head___181 {
	struct rw_semaphore___182 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___179;

struct vm_area_struct___182 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___182 *vm_next;
	struct vm_area_struct___182 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___181 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___179 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___182 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___181;

struct user_namespace___161;

struct mm_struct___181 {
	struct {
		struct vm_area_struct___182 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___182 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___182 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___181 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___182 *owner;
		struct user_namespace___161 *user_ns;
		struct file___182 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___181 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___181;

struct address_space___181 {
	struct inode___182 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___182 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___181 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___179)(struct vm_area_struct___182 *, long unsigned int, const struct page___182 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___179)(struct page___182 *, void *);

struct device___169;

struct dev_pagemap___179 {
	dev_page_fault_t___179 page_fault;
	dev_page_free_t___179 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___169 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct cgroup___156;

struct cgroup_subsys___156;

struct cgroup_subsys_state___156 {
	struct cgroup___156 *cgroup;
	struct cgroup_subsys___156 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___156 *parent;
};

struct mem_cgroup_id___19 {
	int id;
	union {
		refcount_t ref;
		struct {
			atomic_t ref;
		} __UNIQUE_ID_rh_kabi_hide44;
		union {		};
	};
};

struct kernfs_node___178;

struct cgroup_file___156 {
	struct kernfs_node___178 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___82;

struct mem_cgroup___82 {
	struct cgroup_subsys_state___156 css;
	struct mem_cgroup_id___19 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___156 events_file;
	struct cgroup_file___156 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___182 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___82 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct vfsmount___32;

struct dentry___181;

struct path___181 {
	struct vfsmount___32 *mnt;
	struct dentry___181 *dentry;
};

struct file___182 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___181 f_path;
	struct inode___182 *f_inode;
	const struct file_operations___182 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___145 f_owner;
	const struct cred___177 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___181 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___179;

struct vm_operations_struct___179 {
	void (*open)(struct vm_area_struct___182 *);
	void (*close)(struct vm_area_struct___182 *);
	int (*split)(struct vm_area_struct___182 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___182 *);
	vm_fault_t (*fault)(struct vm_fault___179 *);
	vm_fault_t (*huge_fault)(struct vm_fault___179 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___179 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___182 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___179 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___179 *);
	int (*access)(struct vm_area_struct___182 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___182 *);
	int (*set_policy)(struct vm_area_struct___182 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___182 *, long unsigned int);
	struct page___182 * (*find_special_page)(struct vm_area_struct___182 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___181 {
	struct task_struct___182 *task;
	struct core_thread___181 *next;
};

struct core_state___181 {
	atomic_t nr_threads;
	struct core_thread___181 dumper;
	struct completion startup;
};

struct key___177;

struct ucounts___161;

struct user_namespace___161 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___161 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___10 ns;
	long unsigned int flags;
	struct key___177 *persistent_keyring_register;
	struct rw_semaphore___182 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___161 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___179 {
	struct vm_area_struct___182 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___182 *cow_page;
	struct mem_cgroup___82 *memcg;
	struct page___182 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___181 prealloc_pte;
};

struct shrink_control___82 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___82 *memcg;
};

struct shrinker___82 {
	long unsigned int (*count_objects)(struct shrinker___82 *, struct shrink_control___82 *);
	long unsigned int (*scan_objects)(struct shrinker___82 *, struct shrink_control___82 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct user_struct___177 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___177 *uid_keyring;
	struct key___177 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___177 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___177 *session_keyring;
	struct key___177 *process_keyring;
	struct key___177 *thread_keyring;
	struct key___177 *request_key_auth;
	void *security;
	struct user_struct___177 *user;
	struct user_namespace___161 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___156;

struct nsproxy___173 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___156 *cgroup_ns;
};

struct bio___91;

struct bio_list___91 {
	struct bio___91 *head;
	struct bio___91 *tail;
};

struct bdi_writeback_congested___91;

struct bdi_writeback___91 {
	struct backing_dev_info___91 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___91 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___156 *memcg_css;
	struct cgroup_subsys_state___156 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___91 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___91 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___169 *dev;
	struct device___169 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___181 *debug_dir;
	struct dentry___181 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___47;

struct io_context___47 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___47 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___156 {
	struct cgroup_subsys_state___156 *subsys[13];
	refcount_t refcount;
	struct css_set___156 *dom_cset;
	struct cgroup___156 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___156 *mg_src_cgrp;
	struct cgroup___156 *mg_dst_cgrp;
	struct css_set___156 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

typedef blk_qc_t make_request_fn___43(struct request_queue___44 *, struct bio___91 *);

struct request___44;

typedef int dma_drain_needed_fn___43(struct request___44 *);

struct kset___175;

struct kobj_type___175;

struct kobject___176 {
	const char *name;
	struct list_head entry;
	struct kobject___176 *parent;
	struct kset___175 *kset;
	struct kobj_type___175 *ktype;
	struct kernfs_node___178 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___43;

struct bsg_class_device___43 {
	struct device___169 *class_dev;
	int minor;
	struct request_queue___44 *queue;
	const struct bsg_ops___43 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___91 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___91 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___43;

struct blkcg_gq___34;

struct request_queue___44 {
	struct list_head queue_head;
	struct request___44 *last_merge;
	struct elevator_queue___43 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___43 *make_request_fn;
	dma_drain_needed_fn___43 *dma_drain_needed;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___91 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___176 kobj;
	struct kobject___176 *mq_kobj;
	struct blk_integrity integrity;
	struct device___169 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___34 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	struct bsg_class_device___43 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___91 bio_split;
	struct dentry___181 *debugfs_dir;
	struct dentry___181 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___131 {
	struct vm_struct___131 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___182 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dev_pm_info___169 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___169 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___169;

struct bus_type___169;

struct device_driver___169;

struct dev_pm_domain___169;

struct fwnode_handle___118;

struct class___169;

struct attribute_group___170;

struct device___169 {
	struct device___169 *parent;
	struct device_private *p;
	struct kobject___176 kobj;
	const char *init_name;
	const struct device_type___169 *type;
	struct mutex mutex;
	struct bus_type___169 *bus;
	struct device_driver___169 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___169 power;
	struct dev_pm_domain___169 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___118 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___169 *class;
	const struct attribute_group___170 **groups;
	void (*release)(struct device___169 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___181;

struct super_block___181;

struct dentry___181 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___181 *d_parent;
	struct qstr d_name;
	struct inode___182 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___181 *d_op;
	struct super_block___181 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___181;

struct block_device___182;

struct inode___182 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___181 *i_op;
	struct super_block___181 *i_sb;
	struct address_space___181 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___182 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___91 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___182 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___181 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___182 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___181 {
	int (*d_revalidate)(struct dentry___181 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___181 *, unsigned int);
	int (*d_hash)(const struct dentry___181 *, struct qstr *);
	int (*d_compare)(const struct dentry___181 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___181 *);
	int (*d_init)(struct dentry___181 *);
	void (*d_release)(struct dentry___181 *);
	void (*d_prune)(struct dentry___181 *);
	void (*d_iput)(struct dentry___181 *, struct inode___182 *);
	char * (*d_dname)(struct dentry___181 *, char *, int);
	struct vfsmount___32 * (*d_automount)(struct path___181 *);
	int (*d_manage)(const struct path___181 *, bool);
	struct dentry___181 * (*d_real)(struct dentry___181 *, const struct inode___182 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___181;

struct mem_dqinfo___181 {
	struct quota_format_type___181 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___181;

struct quota_info___181 {
	unsigned int flags;
	struct rw_semaphore___182 dqio_sem;
	struct inode___182 *files[3];
	struct mem_dqinfo___181 info[3];
	const struct quota_format_ops___181 *ops[3];
};

struct rcuwait___181 {
	struct task_struct___182 *task;
};

struct percpu_rw_semaphore___181 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___182 rw_sem;
	struct rcuwait___181 writer;
	int readers_block;
};

struct sb_writers___181 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___181 rw_sem[3];
};

struct file_system_type___181;

struct super_operations___181;

struct dquot_operations___181;

struct quotactl_ops___181;

struct export_operations___6;

struct super_block___181 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___181 *s_type;
	const struct super_operations___181 *s_op;
	const struct dquot_operations___181 *dq_op;
	const struct quotactl_ops___181 *s_qcop;
	const struct export_operations___6 *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___181 *s_root;
	struct rw_semaphore___182 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___182 *s_bdev;
	struct backing_dev_info___91 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___181 s_dquot;
	struct sb_writers___181 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___181 *s_d_op;
	int cleancache_poolid;
	struct shrinker___82 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___161 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___32 {
	struct dentry___181 *mnt_root;
	struct super_block___181 *mnt_sb;
	int mnt_flags;
};

struct io_cq___47 {
	struct request_queue___44 *q;
	struct io_context___47 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___6 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct buffer_head___4;

typedef void bh_end_io_t___4(struct buffer_head___4 *, int);

struct buffer_head___4 {
	long unsigned int b_state;
	struct buffer_head___4 *b_this_page;
	struct page___182 *b_page;
	sector_t b_blocknr;
	size_t b_size;
	char *b_data;
	struct block_device___182 *b_bdev;
	bh_end_io_t___4 *b_end_io;
	void *b_private;
	struct list_head b_assoc_buffers;
	struct address_space___181 *b_assoc_map;
	atomic_t b_count;
};

struct kiocb___182 {
	struct file___182 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___182 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___181 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___182 *ia_file;
};

struct dquot___181 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___181 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___181 {
	int qf_fmt_id;
	const struct quota_format_ops___181 *qf_ops;
	struct module___155 *qf_owner;
	struct quota_format_type___181 *qf_next;
};

struct quota_format_ops___181 {
	int (*check_quota_file)(struct super_block___181 *, int);
	int (*read_file_info)(struct super_block___181 *, int);
	int (*write_file_info)(struct super_block___181 *, int);
	int (*free_file_info)(struct super_block___181 *, int);
	int (*read_dqblk)(struct dquot___181 *);
	int (*commit_dqblk)(struct dquot___181 *);
	int (*release_dqblk)(struct dquot___181 *);
	int (*get_next_id)(struct super_block___181 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___181 {
	int (*write_dquot)(struct dquot___181 *);
	struct dquot___181 * (*alloc_dquot)(struct super_block___181 *, int);
	void (*destroy_dquot)(struct dquot___181 *);
	int (*acquire_dquot)(struct dquot___181 *);
	int (*release_dquot)(struct dquot___181 *);
	int (*mark_dirty)(struct dquot___181 *);
	int (*write_info)(struct super_block___181 *, int);
	qsize_t * (*get_reserved_space)(struct inode___182 *);
	int (*get_projid)(struct inode___182 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___182 *, qsize_t *);
	int (*get_next_id)(struct super_block___181 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___181 {
	int (*quota_on)(struct super_block___181 *, int, int, const struct path___181 *);
	int (*quota_off)(struct super_block___181 *, int);
	int (*quota_enable)(struct super_block___181 *, unsigned int);
	int (*quota_disable)(struct super_block___181 *, unsigned int);
	int (*quota_sync)(struct super_block___181 *, int);
	int (*set_info)(struct super_block___181 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___181 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___181 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___181 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___181 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___181 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___152 {
	struct kobject___176 kobj;
	struct module___155 *mod;
	struct kobject___176 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___152 {
	struct module___155 *mod;
	struct latch_tree_node node;
};

struct module_layout___152 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___152 mtn;
};

struct module_attribute___152;

struct kernel_param___152;

struct module___155 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___152 mkobj;
	struct module_attribute___152 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___176 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___152 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___152 core_layout;
	struct module_layout___152 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide40;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide41;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___88;

struct swap_info_struct___60;

struct address_space_operations___181 {
	int (*writepage)(struct page___182 *, struct writeback_control___88 *);
	int (*readpage)(struct file___182 *, struct page___182 *);
	int (*writepages)(struct address_space___181 *, struct writeback_control___88 *);
	int (*set_page_dirty)(struct page___182 *);
	int (*readpages)(struct file___182 *, struct address_space___181 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___182 *, struct address_space___181 *, loff_t, unsigned int, unsigned int, struct page___182 **, void **);
	int (*write_end)(struct file___182 *, struct address_space___181 *, loff_t, unsigned int, unsigned int, struct page___182 *, void *);
	sector_t (*bmap)(struct address_space___181 *, sector_t);
	void (*invalidatepage)(struct page___182 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___182 *, gfp_t);
	void (*freepage)(struct page___182 *);
	ssize_t (*direct_IO)(struct kiocb___182 *, struct iov_iter___88 *);
	int (*migratepage)(struct address_space___181 *, struct page___182 *, struct page___182 *, enum migrate_mode);
	bool (*isolate_page)(struct page___182 *, isolate_mode_t);
	void (*putback_page)(struct page___182 *);
	int (*launder_page)(struct page___182 *);
	int (*is_partially_uptodate)(struct page___182 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___182 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___181 *, struct page___182 *);
	int (*swap_activate)(struct swap_info_struct___60 *, struct file___182 *, sector_t *);
	void (*swap_deactivate)(struct file___182 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___88 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___91 *wb;
	struct inode___182 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___91;

struct iov_iter___88 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___91 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct swap_info_struct___60 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___182 *bdev;
	struct file___182 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct hd_struct___44;

struct gendisk___44;

struct block_device___182 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___182 *bd_inode;
	struct super_block___181 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___182 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___44 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___44 *bd_disk;
	struct request_queue___44 *bd_queue;
	struct backing_dev_info___91 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct hd_struct___44 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___169 __dev;
	struct kobject___176 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___44;

struct block_device_operations___44;

struct badblocks___2;

struct gendisk___44 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___44 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___44 *part_tbl;
	struct hd_struct___44 part0;
	const struct block_device_operations___44 *fops;
	struct request_queue___44 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___182 lookup_sem;
	struct kobject___176 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___176 integrity_kobj;
	int node_id;
	struct badblocks___2 *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___181 {
	struct dentry___181 * (*lookup)(struct inode___182 *, struct dentry___181 *, unsigned int);
	const char * (*get_link)(struct dentry___181 *, struct inode___182 *, struct delayed_call *);
	int (*permission)(struct inode___182 *, int);
	struct posix_acl * (*get_acl)(struct inode___182 *, int);
	int (*readlink)(struct dentry___181 *, char *, int);
	int (*create)(struct inode___182 *, struct dentry___181 *, umode_t, bool);
	int (*link)(struct dentry___181 *, struct inode___182 *, struct dentry___181 *);
	int (*unlink)(struct inode___182 *, struct dentry___181 *);
	int (*symlink)(struct inode___182 *, struct dentry___181 *, const char *);
	int (*mkdir)(struct inode___182 *, struct dentry___181 *, umode_t);
	int (*rmdir)(struct inode___182 *, struct dentry___181 *);
	int (*mknod)(struct inode___182 *, struct dentry___181 *, umode_t, dev_t);
	int (*rename)(struct inode___182 *, struct dentry___181 *, struct inode___182 *, struct dentry___181 *, unsigned int);
	int (*setattr)(struct dentry___181 *, struct iattr___181 *);
	int (*getattr)(const struct path___181 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___181 *, char *, size_t);
	int (*fiemap)(struct inode___182 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___182 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___182 *, struct dentry___181 *, struct file___182 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___182 *, struct dentry___181 *, umode_t);
	int (*set_acl)(struct inode___182 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___181 {
	void (*fl_copy_lock)(struct file_lock___182 *, struct file_lock___182 *);
	void (*fl_release_private)(struct file_lock___182 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___181;

struct lock_manager_operations___181;

struct file_lock___182 {
	struct file_lock___182 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___182 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___181 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___181 *fl_ops;
	const struct lock_manager_operations___181 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___181 {
	int (*lm_compare_owner)(struct file_lock___182 *, struct file_lock___182 *);
	long unsigned int (*lm_owner_key)(struct file_lock___182 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___182 *);
	int (*lm_grant)(struct file_lock___182 *, int);
	bool (*lm_break)(struct file_lock___182 *);
	int (*lm_change)(struct file_lock___182 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___182 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___181 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___181 *fa_next;
	struct file___182 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___181 {
	const char *name;
	int fs_flags;
	struct dentry___181 * (*mount)(struct file_system_type___181 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___181 *);
	struct module___155 *owner;
	struct file_system_type___181 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___181 {
	struct inode___182 * (*alloc_inode)(struct super_block___181 *);
	void (*destroy_inode)(struct inode___182 *);
	void (*dirty_inode)(struct inode___182 *, int);
	int (*write_inode)(struct inode___182 *, struct writeback_control___88 *);
	int (*drop_inode)(struct inode___182 *);
	void (*evict_inode)(struct inode___182 *);
	void (*put_super)(struct super_block___181 *);
	int (*sync_fs)(struct super_block___181 *, int);
	int (*freeze_super)(struct super_block___181 *);
	int (*freeze_fs)(struct super_block___181 *);
	int (*thaw_super)(struct super_block___181 *);
	int (*unfreeze_fs)(struct super_block___181 *);
	int (*statfs)(struct dentry___181 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___181 *, int *, char *);
	void (*umount_begin)(struct super_block___181 *);
	int (*show_options)(struct seq_file___171 *, struct dentry___181 *);
	int (*show_devname)(struct seq_file___171 *, struct dentry___181 *);
	int (*show_path)(struct seq_file___171 *, struct dentry___181 *);
	int (*show_stats)(struct seq_file___171 *, struct dentry___181 *);
	ssize_t (*quota_read)(struct super_block___181 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___181 *, int, const char *, size_t, loff_t);
	struct dquot___181 ** (*get_dquots)(struct inode___182 *);
	int (*bdev_try_to_free_page)(struct super_block___181 *, struct page___182 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___181 *, struct shrink_control___82 *);
	long int (*free_cached_objects)(struct super_block___181 *, struct shrink_control___82 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct export_operations___6 {
	int (*encode_fh)(struct inode___182 *, __u32 *, int *, struct inode___182 *);
	struct dentry___181 * (*fh_to_dentry)(struct super_block___181 *, struct fid *, int, int);
	struct dentry___181 * (*fh_to_parent)(struct super_block___181 *, struct fid *, int, int);
	int (*get_name)(struct dentry___181 *, char *, struct dentry___181 *);
	struct dentry___181 * (*get_parent)(struct dentry___181 *);
	int (*commit_metadata)(struct inode___182 *);
	int (*get_uuid)(struct super_block___181 *, u8 *, u32 *, u64 *);
	int (*map_blocks)(struct inode___182 *, loff_t, u64, struct iomap *, bool, u32 *);
	int (*commit_blocks)(struct inode___182 *, struct iomap *, int, struct iattr___181 *);
};

struct seq_operations___169;

struct seq_file___171 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___169 *op;
	int poll_event;
	const struct file___182 *file;
	void *private;
};

typedef void bio_end_io_t___91(struct bio___91 *);

struct bio_vec___91 {
	struct page___182 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___91;

struct bio___91 {
	struct bio___91 *bi_next;
	struct gendisk___44 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___91 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___34 *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___91 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___91 *bi_io_vec;
	struct bio_set___91 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___91 bi_inline_vecs[0];
};

struct kobj_attribute___176 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___176 *, struct kobj_attribute___176 *, char *);
	ssize_t (*store)(struct kobject___176 *, struct kobj_attribute___176 *, const char *, size_t);
};

typedef void compound_page_dtor___179(struct page___182 *);

struct bpf_map___156;

struct bpf_map_ops___156 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___156 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___156 *, struct file___182 *);
	void (*map_free)(struct bpf_map___156 *);
	int (*map_get_next_key)(struct bpf_map___156 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___156 *);
	void * (*map_lookup_elem)(struct bpf_map___156 *, void *);
	int (*map_update_elem)(struct bpf_map___156 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___156 *, void *);
	int (*map_push_elem)(struct bpf_map___156 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___156 *, void *);
	int (*map_peek_elem)(struct bpf_map___156 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___156 *, struct file___182 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___156 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___156 *, void *, struct seq_file___171 *);
	int (*map_check_btf)(const struct bpf_map___156 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___156 {
	const struct bpf_map_ops___156 *ops;
	struct bpf_map___156 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___177 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bio_integrity_payload___91 {
	struct bio___91 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___91 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___91 bip_inline_vecs[0];
};

struct blkcg___34;

struct blkg_policy_data___34;

struct blkcg_gq___34 {
	struct request_queue___44 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___34 *blkcg;
	struct bdi_writeback_congested___91 *wb_congested;
	struct blkcg_gq___34 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_rwstat stat_bytes;
	struct blkg_rwstat stat_ios;
	struct blkg_policy_data___34 *pd[5];
	struct callback_head callback_head;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
};

struct dev_pm_ops___169;

struct device_type___169 {
	const char *name;
	const struct attribute_group___170 **groups;
	int (*uevent)(struct device___169 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___169 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___169 *);
	const struct dev_pm_ops___169 *pm;
};

struct class___169 {
	const char *name;
	struct module___155 *owner;
	const struct attribute_group___170 **class_groups;
	const struct attribute_group___170 **dev_groups;
	struct kobject___176 *dev_kobj;
	int (*dev_uevent)(struct device___169 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___169 *, umode_t *);
	void (*class_release)(struct class___169 *);
	void (*dev_release)(struct device___169 *);
	int (*shutdown_pre)(struct device___169 *);
	const struct kobj_ns_type_operations___11 *ns_type;
	const void * (*namespace)(struct device___169 *);
	const struct dev_pm_ops___169 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct kernfs_root___178;

struct kernfs_elem_dir___178 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___178 *root;
};

struct kernfs_syscall_ops___178;

struct kernfs_root___178 {
	struct kernfs_node___178 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___178 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___178 {
	struct kernfs_node___178 *target_kn;
};

struct kernfs_ops___178;

struct kernfs_elem_attr___178 {
	const struct kernfs_ops___178 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___178 *notify_next;
};

struct kernfs_node___178 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___178 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___178 dir;
		struct kernfs_elem_symlink___178 symlink;
		struct kernfs_elem_attr___178 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___178;

struct kernfs_ops___178 {
	int (*open)(struct kernfs_open_file___178 *);
	void (*release)(struct kernfs_open_file___178 *);
	int (*seq_show)(struct seq_file___171 *, void *);
	void * (*seq_start)(struct seq_file___171 *, loff_t *);
	void * (*seq_next)(struct seq_file___171 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___171 *, void *);
	ssize_t (*read)(struct kernfs_open_file___178 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___178 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___178 *, struct vm_area_struct___182 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___178 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___178 {
	int (*remount_fs)(struct kernfs_root___178 *, int *, char *);
	int (*show_options)(struct seq_file___171 *, struct kernfs_root___178 *);
	int (*mkdir)(struct kernfs_node___178 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___178 *);
	int (*rename)(struct kernfs_node___178 *, struct kernfs_node___178 *, const char *);
	int (*show_path)(struct seq_file___171 *, struct kernfs_node___178 *, struct kernfs_root___178 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___178 {
	struct kernfs_node___178 *kn;
	struct file___182 *file;
	struct seq_file___171 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___179 *vm_ops;
};

struct bin_attribute___169;

struct attribute_group___170 {
	const char *name;
	umode_t (*is_visible)(struct kobject___176 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___176 *, struct bin_attribute___169 *, int);
	struct attribute **attrs;
	struct bin_attribute___169 **bin_attrs;
};

struct bin_attribute___169 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___182 *, struct kobject___176 *, struct bin_attribute___169 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___182 *, struct kobject___176 *, struct bin_attribute___169 *, char *, loff_t, size_t);
	int (*mmap)(struct file___182 *, struct kobject___176 *, struct bin_attribute___169 *, struct vm_area_struct___182 *);
};

struct sysfs_ops___175 {
	ssize_t (*show)(struct kobject___176 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___176 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___175;

struct kset___175 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___176 kobj;
	const struct kset_uevent_ops___175 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___175 {
	void (*release)(struct kobject___176 *);
	const struct sysfs_ops___175 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___11 * (*child_ns_type)(struct kobject___176 *);
	const void * (*namespace)(struct kobject___176 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___175 {
	int (* const filter)(struct kset___175 *, struct kobject___176 *);
	const char * (* const name)(struct kset___175 *, struct kobject___176 *);
	int (* const uevent)(struct kset___175 *, struct kobject___176 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___169 {
	int (*prepare)(struct device___169 *);
	void (*complete)(struct device___169 *);
	int (*suspend)(struct device___169 *);
	int (*resume)(struct device___169 *);
	int (*freeze)(struct device___169 *);
	int (*thaw)(struct device___169 *);
	int (*poweroff)(struct device___169 *);
	int (*restore)(struct device___169 *);
	int (*suspend_late)(struct device___169 *);
	int (*resume_early)(struct device___169 *);
	int (*freeze_late)(struct device___169 *);
	int (*thaw_early)(struct device___169 *);
	int (*poweroff_late)(struct device___169 *);
	int (*restore_early)(struct device___169 *);
	int (*suspend_noirq)(struct device___169 *);
	int (*resume_noirq)(struct device___169 *);
	int (*freeze_noirq)(struct device___169 *);
	int (*thaw_noirq)(struct device___169 *);
	int (*poweroff_noirq)(struct device___169 *);
	int (*restore_noirq)(struct device___169 *);
	int (*runtime_suspend)(struct device___169 *);
	int (*runtime_resume)(struct device___169 *);
	int (*runtime_idle)(struct device___169 *);
};

struct dev_pm_domain___169 {
	struct dev_pm_ops___169 ops;
	void (*detach)(struct device___169 *, bool);
	int (*activate)(struct device___169 *);
	void (*sync)(struct device___169 *);
	void (*dismiss)(struct device___169 *);
};

struct bus_type___169 {
	const char *name;
	const char *dev_name;
	struct device___169 *dev_root;
	const struct attribute_group___170 **bus_groups;
	const struct attribute_group___170 **dev_groups;
	const struct attribute_group___170 **drv_groups;
	int (*match)(struct device___169 *, struct device_driver___169 *);
	int (*uevent)(struct device___169 *, struct kobj_uevent_env *);
	int (*probe)(struct device___169 *);
	int (*remove)(struct device___169 *);
	void (*shutdown)(struct device___169 *);
	int (*online)(struct device___169 *);
	int (*offline)(struct device___169 *);
	int (*suspend)(struct device___169 *, pm_message_t);
	int (*resume)(struct device___169 *);
	int (*num_vf)(struct device___169 *);
	int (*dma_configure)(struct device___169 *);
	const struct dev_pm_ops___169 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___169 {
	const char *name;
	struct bus_type___169 *bus;
	struct module___155 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___169 *);
	int (*remove)(struct device___169 *);
	void (*shutdown)(struct device___169 *);
	int (*suspend)(struct device___169 *, pm_message_t);
	int (*resume)(struct device___169 *);
	const struct attribute_group___170 **groups;
	const struct dev_pm_ops___169 *pm;
	void (*coredump)(struct device___169 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct fwnode_operations___118;

struct fwnode_handle___118 {
	struct fwnode_handle___118 *secondary;
	const struct fwnode_operations___118 *ops;
};

enum {
	DISK_EVENT_MEDIA_CHANGE = 1,
	DISK_EVENT_EJECT_REQUEST = 2,
};

struct disk_part_tbl___44 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___44 *last_lookup;
	struct hd_struct___44 *part[0];
};

struct block_device_operations___44 {
	int (*open)(struct block_device___182 *, fmode_t);
	void (*release)(struct gendisk___44 *, fmode_t);
	int (*rw_page)(struct block_device___182 *, sector_t, struct page___182 *, unsigned int);
	int (*ioctl)(struct block_device___182 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___182 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___44 *, unsigned int);
	int (*media_changed)(struct gendisk___44 *);
	void (*unlock_native_capacity)(struct gendisk___44 *);
	int (*revalidate_disk)(struct gendisk___44 *);
	int (*getgeo)(struct block_device___182 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___182 *, long unsigned int);
	int (*report_zones)(struct gendisk___44 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___155 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct badblocks___2 {
	struct device___169 *dev;
	int count;
	int unacked_exist;
	int shift;
	u64 *page;
	int changed;
	seqlock_t lock;
	sector_t sector;
	sector_t size;
};

struct bdi_writeback_congested___91 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___91 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

enum {
	BIOSET_NEED_BVECS = 1,
	BIOSET_NEED_RESCUER = 2,
};

struct bsg_ops___43 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___44 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___44 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___44 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___43(struct request___44 *, blk_status_t);

struct request___44 {
	struct request_queue___44 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___91 *bio;
	struct bio___91 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___91 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___47 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___43 *saved_end_io;
		} flush;
	};
	struct gendisk___44 *rq_disk;
	struct hd_struct___44 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___43 *end_io;
	void *end_io_data;
	struct request___44 *next_rq;
};

struct fwnode_reference_args___118;

struct fwnode_endpoint___118;

struct fwnode_operations___118 {
	struct fwnode_handle___118 * (*get)(struct fwnode_handle___118 *);
	void (*put)(struct fwnode_handle___118 *);
	bool (*device_is_available)(const struct fwnode_handle___118 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___118 *, const struct device___169 *);
	bool (*property_present)(const struct fwnode_handle___118 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___118 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___118 *, const char *, const char **, size_t);
	struct fwnode_handle___118 * (*get_parent)(const struct fwnode_handle___118 *);
	struct fwnode_handle___118 * (*get_next_child_node)(const struct fwnode_handle___118 *, struct fwnode_handle___118 *);
	struct fwnode_handle___118 * (*get_named_child_node)(const struct fwnode_handle___118 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___118 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___118 *);
	struct fwnode_handle___118 * (*graph_get_next_endpoint)(const struct fwnode_handle___118 *, struct fwnode_handle___118 *);
	struct fwnode_handle___118 * (*graph_get_remote_endpoint)(const struct fwnode_handle___118 *);
	struct fwnode_handle___118 * (*graph_get_port_parent)(struct fwnode_handle___118 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___118 *, struct fwnode_endpoint___118 *);
};

struct fwnode_endpoint___118 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___118 *local_fwnode;
};

struct fwnode_reference_args___118 {
	struct fwnode_handle___118 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct elevator_type___43;

struct elevator_mq_ops___43 {
	int (*init_sched)(struct request_queue___44 *, struct elevator_type___43 *);
	void (*exit_sched)(struct elevator_queue___43 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	bool (*allow_merge)(struct request_queue___44 *, struct request___44 *, struct bio___91 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx *, struct bio___91 *);
	int (*request_merge)(struct request_queue___44 *, struct request___44 **, struct bio___91 *);
	void (*request_merged)(struct request_queue___44 *, struct request___44 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___44 *, struct request___44 *, struct request___44 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___44 *, struct bio___91 *);
	void (*finish_request)(struct request___44 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___44 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___44 *, u64);
	void (*started_request)(struct request___44 *);
	void (*requeue_request)(struct request___44 *);
	struct request___44 * (*former_request)(struct request_queue___44 *, struct request___44 *);
	struct request___44 * (*next_request)(struct request_queue___44 *, struct request___44 *);
	void (*init_icq)(struct io_cq___47 *);
	void (*exit_icq)(struct io_cq___47 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___43;

struct elevator_type___43 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___43 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___43 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___155 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___43 {
	struct elevator_type___43 *type;
	void *elevator_data;
	struct kobject___176 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___43 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___43 *, char *);
	ssize_t (*store)(struct elevator_queue___43 *, const char *, size_t);
};

typedef int (*key_restrict_link_func_t___177)(struct key___177 *, const struct key_type *, const union key_payload *, struct key___177 *);

struct key_restriction___177;

struct key___177 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___182 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___177 *restrict_link;
};

struct key_restriction___177 {
	key_restrict_link_func_t___177 check;
	struct key___177 *key;
	struct key_type *keytype;
};

struct seq_operations___169 {
	void * (*start)(struct seq_file___171 *, loff_t *);
	void (*stop)(struct seq_file___171 *, void *);
	void * (*next)(struct seq_file___171 *, void *, loff_t *);
	int (*show)(struct seq_file___171 *, void *);
};

struct cgroup_namespace___156 {
	refcount_t count;
	struct ns_common___10 ns;
	struct user_namespace___161 *user_ns;
	struct ucounts___161 *ucounts;
	struct css_set___156 *root_cset;
};

struct ucounts___161 {
	struct hlist_node node;
	struct user_namespace___161 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct kthread_work___156;

typedef void (*kthread_work_func_t___156)(struct kthread_work___156 *);

struct kthread_worker___156;

struct kthread_work___156 {
	struct list_head node;
	kthread_work_func_t___156 func;
	struct kthread_worker___156 *worker;
	int canceling;
};

struct kthread_worker___156 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___182 *task;
	struct kthread_work___156 *current_work;
};

struct kthread_delayed_work___156 {
	struct kthread_work___156 work;
	struct timer_list timer;
};

struct psi_group___156 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___156 *poll_kworker;
	struct kthread_delayed_work___156 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___156;

struct cgroup_rstat_cpu___156;

struct cgroup___156 {
	struct cgroup_subsys_state___156 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___178 *kn;
	struct cgroup_file___156 procs_file;
	struct cgroup_file___156 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___156 *subsys[13];
	struct cgroup_root___156 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___156 *dom_cgrp;
	struct cgroup_rstat_cpu___156 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___21 bpf;
	atomic_t congestion_count;
	struct cgroup___156 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___156 psi;
	int ancestor_ids[0];
};

struct cftype___156;

struct cgroup_subsys___156 {
	struct cgroup_subsys_state___156 * (*css_alloc)(struct cgroup_subsys_state___156 *);
	int (*css_online)(struct cgroup_subsys_state___156 *);
	void (*css_offline)(struct cgroup_subsys_state___156 *);
	void (*css_released)(struct cgroup_subsys_state___156 *);
	void (*css_free)(struct cgroup_subsys_state___156 *);
	void (*css_reset)(struct cgroup_subsys_state___156 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___156 *, int);
	int (*css_extra_stat_show)(struct seq_file___171 *, struct cgroup_subsys_state___156 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___182 *);
	void (*cancel_fork)(struct task_struct___182 *);
	void (*fork)(struct task_struct___182 *);
	void (*exit)(struct task_struct___182 *);
	void (*free)(struct task_struct___182 *);
	void (*bind)(struct cgroup_subsys_state___156 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___156 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___156 *dfl_cftypes;
	struct cftype___156 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___156 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___156 *updated_children;
	struct cgroup___156 *updated_next;
};

struct cgroup_root___156 {
	struct kernfs_root___178 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___156 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___156 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___156 *ss;
	struct list_head node;
	struct kernfs_ops___178 *kf_ops;
	int (*open)(struct kernfs_open_file___178 *);
	void (*release)(struct kernfs_open_file___178 *);
	u64 (*read_u64)(struct cgroup_subsys_state___156 *, struct cftype___156 *);
	s64 (*read_s64)(struct cgroup_subsys_state___156 *, struct cftype___156 *);
	int (*seq_show)(struct seq_file___171 *, void *);
	void * (*seq_start)(struct seq_file___171 *, loff_t *);
	void * (*seq_next)(struct seq_file___171 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___171 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___156 *, struct cftype___156 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___156 *, struct cftype___156 *, s64);
	ssize_t (*write)(struct kernfs_open_file___178 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___178 *, struct poll_table_struct___6 *);
};

struct blkcg_policy_data___34;

struct blkcg___34 {
	struct cgroup_subsys_state___156 css;
	spinlock_t lock;
	struct xarray blkg_tree;
	struct blkcg_gq___34 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___34 *cpd[5];
	struct list_head all_blkcgs_node;
	struct list_head cgwb_list;
	refcount_t cgwb_refcnt;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct blkcg_policy_data___34 {
	struct blkcg___34 *blkcg;
	int plid;
};

struct blkg_policy_data___34 {
	struct blkcg_gq___34 *blkg;
	int plid;
};

struct kernel_param_ops___152 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___152 *);
	int (*get)(char *, const struct kernel_param___152 *);
	void (*free)(void *);
};

struct kparam_array___152;

struct kernel_param___152 {
	const char *name;
	struct module___155 *mod;
	const struct kernel_param_ops___152 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___152 *arr;
	};
};

struct kparam_array___152 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___152 *ops;
	void *elem;
};

struct module_attribute___152 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___152 *, struct module_kobject___152 *, char *);
	ssize_t (*store)(struct module_attribute___152 *, struct module_kobject___152 *, const char *, size_t);
	void (*setup)(struct module___155 *, const char *);
	int (*test)(struct module___155 *);
	void (*free)(struct module___155 *);
};

struct mem_cgroup_reclaim_iter___82 {
	struct mem_cgroup___82 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___82 {
	struct lruvec___181 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___82 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___82 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct node___145 {
	struct device___169 dev;
};

struct bdev_inode {
	struct block_device___182 bdev;
	struct inode___182 vfs_inode;
};

struct blkdev_dio {
	union {
		struct kiocb___182 *iocb;
		struct task_struct___182 *waiter;
	};
	size_t size;
	atomic_t ref;
	bool multi_bio: 1;
	bool should_dirty: 1;
	bool is_sync: 1;
	struct bio___91 bio;
};

struct bd_holder_disk {
	struct list_head list;
	struct gendisk___44 *disk;
	int refcnt;
};

struct module___156;

struct file___183;

struct kiocb___183;

struct iov_iter___89;

struct vm_area_struct___183;

struct inode___183;

struct file_lock___183;

struct page___183;

struct file_operations___183 {
	struct module___156 *owner;
	loff_t (*llseek)(struct file___183 *, loff_t, int);
	ssize_t (*read)(struct file___183 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___183 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___183 *, struct iov_iter___89 *);
	ssize_t (*write_iter)(struct kiocb___183 *, struct iov_iter___89 *);
	int (*iopoll)(struct kiocb___183 *, bool);
	int (*iterate)(struct file___183 *, struct dir_context *);
	int (*iterate_shared)(struct file___183 *, struct dir_context *);
	__poll_t (*poll)(struct file___183 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___183 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___183 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___183 *, struct vm_area_struct___183 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___183 *, struct file___183 *);
	int (*flush)(struct file___183 *, fl_owner_t);
	int (*release)(struct inode___183 *, struct file___183 *);
	int (*fsync)(struct file___183 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___183 *, int);
	int (*lock)(struct file___183 *, int, struct file_lock___183 *);
	ssize_t (*sendpage)(struct file___183 *, struct page___183 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___183 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___183 *, int, struct file_lock___183 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___183 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___183 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___183 *, long int, struct file_lock___183 **, void **);
	long int (*fallocate)(struct file___183 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___183 *);
	ssize_t (*copy_file_range)(struct file___183 *, loff_t, struct file___183 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___183 *, loff_t, struct file___183 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___183 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___182 {
	u64 seqnum;
	struct vm_area_struct___183 *vmas[4];
};

struct page_frag___182 {
	struct page___183 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___182;

struct bio_list___92;

struct backing_dev_info___92;

struct io_context___48;

struct request_queue___45;

struct vm_struct___132;

struct task_struct___183 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___183 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___182 *mm;
	struct mm_struct___182 *active_mm;
	struct vmacache___182 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___183 *real_parent;
	struct task_struct___183 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___183 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___145 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___145 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___145 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___2 *ptracer_cred;
	const struct cred___2 *real_cred;
	const struct cred___2 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___183 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___92 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___92 *backing_dev_info;
	struct io_context___48 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___182 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___45 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___183 *oom_reaper_list;
	struct vm_struct___132 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___113 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___183 *pgtable_t___182;

struct address_space___182;

struct dev_pagemap___180;

struct page___183 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___182 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___183 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___182 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___182 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___180 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___182;

struct lruvec___182 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___182 *pgdat;
};

struct zone___182 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___182 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___182 {
	struct zone___182 *zone;
	int zone_idx;
};

struct zonelist___182 {
	struct zoneref___182 _zonerefs[25];
};

struct pglist_data___182 {
	struct zone___182 node_zones[3];
	struct zonelist___182 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___183 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___183 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___182 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___183 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___183 *owner;
};

struct secondary_data___183 {
	void *stack;
	struct task_struct___183 *task;
	long int status;
};

struct blocking_notifier_head___182 {
	struct rw_semaphore___183 rwsem;
	struct notifier_block *head;
};

struct dentry___182;

struct path___182 {
	struct vfsmount *mnt;
	struct dentry___182 *dentry;
};

struct file___183 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___182 f_path;
	struct inode___183 *f_inode;
	const struct file_operations___183 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___145 f_owner;
	const struct cred___2 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___182 *f_mapping;
	errseq_t f_wb_err;
};

struct kernfs_root___179;

struct kernfs_elem_dir___179 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___179 *root;
};

struct kernfs_node___179;

struct kernfs_syscall_ops___179;

struct kernfs_root___179 {
	struct kernfs_node___179 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___179 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___179 {
	struct kernfs_node___179 *target_kn;
};

struct kernfs_ops___179;

struct kernfs_elem_attr___179 {
	const struct kernfs_ops___179 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___179 *notify_next;
};

struct kernfs_node___179 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___179 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___179 dir;
		struct kernfs_elem_symlink___179 symlink;
		struct kernfs_elem_attr___179 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___179;

struct kernfs_ops___179 {
	int (*open)(struct kernfs_open_file___179 *);
	void (*release)(struct kernfs_open_file___179 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___179 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___179 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___179 *, struct vm_area_struct___183 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___179 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___179 {
	int (*remount_fs)(struct kernfs_root___179 *, int *, char *);
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___179 *);
	int (*mkdir)(struct kernfs_node___179 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___179 *);
	int (*rename)(struct kernfs_node___179 *, struct kernfs_node___179 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___179 *, struct kernfs_root___179 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_operations_struct___180;

struct kernfs_open_file___179 {
	struct kernfs_node___179 *kn;
	struct file___183 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___180 *vm_ops;
};

struct vm_fault___180;

struct vm_operations_struct___180 {
	void (*open)(struct vm_area_struct___183 *);
	void (*close)(struct vm_area_struct___183 *);
	int (*split)(struct vm_area_struct___183 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___183 *);
	vm_fault_t (*fault)(struct vm_fault___180 *);
	vm_fault_t (*huge_fault)(struct vm_fault___180 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___180 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___183 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___180 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___180 *);
	int (*access)(struct vm_area_struct___183 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___183 *);
	int (*set_policy)(struct vm_area_struct___183 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___183 *, long unsigned int);
	struct page___183 * (*find_special_page)(struct vm_area_struct___183 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_area_struct___183 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___183 *vm_next;
	struct vm_area_struct___183 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___182 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___180 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___183 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___177;

struct bin_attribute___170;

struct attribute_group___171 {
	const char *name;
	umode_t (*is_visible)(struct kobject___177 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___177 *, struct bin_attribute___170 *, int);
	struct attribute **attrs;
	struct bin_attribute___170 **bin_attrs;
};

struct kset___176;

struct kobj_type___176;

struct kobject___177 {
	const char *name;
	struct list_head entry;
	struct kobject___177 *parent;
	struct kset___176 *kset;
	struct kobj_type___176 *ktype;
	struct kernfs_node___179 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___170 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___183 *, struct kobject___177 *, struct bin_attribute___170 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___183 *, struct kobject___177 *, struct bin_attribute___170 *, char *, loff_t, size_t);
	int (*mmap)(struct file___183 *, struct kobject___177 *, struct bin_attribute___170 *, struct vm_area_struct___183 *);
};

struct sysfs_ops___176 {
	ssize_t (*show)(struct kobject___177 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___177 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___176;

struct kset___176 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___177 kobj;
	const struct kset_uevent_ops___176 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___176 {
	void (*release)(struct kobject___177 *);
	const struct sysfs_ops___176 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___11 * (*child_ns_type)(struct kobject___177 *);
	const void * (*namespace)(struct kobject___177 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___176 {
	int (* const filter)(struct kset___176 *, struct kobject___177 *);
	const char * (* const name)(struct kset___176 *, struct kobject___177 *);
	int (* const uevent)(struct kset___176 *, struct kobject___177 *, struct kobj_uevent_env *);
};

struct kobj_attribute___177 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___177 *, struct kobj_attribute___177 *, char *);
	ssize_t (*store)(struct kobject___177 *, struct kobj_attribute___177 *, const char *, size_t);
};

struct kernel_param___153;

struct kernel_param_ops___153 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___153 *);
	int (*get)(char *, const struct kernel_param___153 *);
	void (*free)(void *);
};

struct kparam_array___153;

struct kernel_param___153 {
	const char *name;
	struct module___156 *mod;
	const struct kernel_param_ops___153 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___153 *arr;
	};
};

struct kparam_array___153 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___153 *ops;
	void *elem;
};

struct module_kobject___153 {
	struct kobject___177 kobj;
	struct module___156 *mod;
	struct kobject___177 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___153 {
	struct module___156 *mod;
	struct latch_tree_node node;
};

struct module_layout___153 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___153 mtn;
};

struct module_attribute___153;

struct module___156 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___153 mkobj;
	struct module_attribute___153 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___177 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___153 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___153 core_layout;
	struct module_layout___153 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___153 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___153 *, struct module_kobject___153 *, char *);
	ssize_t (*store)(struct module_attribute___153 *, struct module_kobject___153 *, const char *, size_t);
	void (*setup)(struct module___156 *, const char *);
	int (*test)(struct module___156 *);
	void (*free)(struct module___156 *);
};

struct dentry_operations___182;

struct super_block___182;

struct dentry___182 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___182 *d_parent;
	struct qstr d_name;
	struct inode___183 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___182 *d_op;
	struct super_block___182 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___182;

struct address_space___182 {
	struct inode___183 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___183 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___182 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___182;

struct bdi_writeback___92;

struct block_device___183;

struct inode___183 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___182 *i_op;
	struct super_block___182 *i_sb;
	struct address_space___182 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___183 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___92 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___183 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___182 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___183 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___182 {
	int (*d_revalidate)(struct dentry___182 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___182 *, unsigned int);
	int (*d_hash)(const struct dentry___182 *, struct qstr *);
	int (*d_compare)(const struct dentry___182 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___182 *);
	int (*d_init)(struct dentry___182 *);
	void (*d_release)(struct dentry___182 *);
	void (*d_prune)(struct dentry___182 *);
	void (*d_iput)(struct dentry___182 *, struct inode___183 *);
	char * (*d_dname)(struct dentry___182 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___182 *);
	int (*d_manage)(const struct path___182 *, bool);
	struct dentry___182 * (*d_real)(struct dentry___182 *, const struct inode___183 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___182;

struct mem_dqinfo___182 {
	struct quota_format_type___182 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___182;

struct quota_info___182 {
	unsigned int flags;
	struct rw_semaphore___183 dqio_sem;
	struct inode___183 *files[3];
	struct mem_dqinfo___182 info[3];
	const struct quota_format_ops___182 *ops[3];
};

struct rcuwait___182 {
	struct task_struct___183 *task;
};

struct percpu_rw_semaphore___182 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___183 rw_sem;
	struct rcuwait___182 writer;
	int readers_block;
};

struct sb_writers___182 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___182 rw_sem[3];
};

struct file_system_type___182;

struct super_operations___182;

struct dquot_operations___182;

struct quotactl_ops___182;

struct super_block___182 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___182 *s_type;
	const struct super_operations___182 *s_op;
	const struct dquot_operations___182 *dq_op;
	const struct quotactl_ops___182 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___182 *s_root;
	struct rw_semaphore___183 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___183 *s_bdev;
	struct backing_dev_info___92 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___182 s_dquot;
	struct sb_writers___182 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___182 *s_d_op;
	int cleancache_poolid;
	struct shrinker___82 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct core_state___182;

struct mm_struct___182 {
	struct {
		struct vm_area_struct___183 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___183 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___183 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___182 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___183 *owner;
		struct user_namespace___3 *user_ns;
		struct file___183 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___182 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___180)(struct vm_area_struct___183 *, long unsigned int, const struct page___183 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___180)(struct page___183 *, void *);

struct device___170;

struct dev_pagemap___180 {
	dev_page_fault_t___180 page_fault;
	dev_page_free_t___180 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___170 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___182 {
	struct task_struct___183 *task;
	struct core_thread___182 *next;
};

struct core_state___182 {
	atomic_t nr_threads;
	struct core_thread___182 dumper;
	struct completion startup;
};

struct vm_fault___180 {
	struct vm_area_struct___183 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___183 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___183 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___182 prealloc_pte;
};

struct bio___92;

struct bio_list___92 {
	struct bio___92 *head;
	struct bio___92 *tail;
};

struct bdi_writeback_congested___92;

struct cgroup_subsys_state___157;

struct bdi_writeback___92 {
	struct backing_dev_info___92 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___92 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___157 *memcg_css;
	struct cgroup_subsys_state___157 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___92 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___92 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___170 *dev;
	struct device___170 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___182 *debug_dir;
	struct dentry___182 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___48;

struct io_context___48 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___48 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

typedef blk_qc_t make_request_fn___44(struct request_queue___45 *, struct bio___92 *);

struct request___45;

typedef int dma_drain_needed_fn___44(struct request___45 *);

struct bsg_ops___44;

struct bsg_class_device___44 {
	struct device___170 *class_dev;
	int minor;
	struct request_queue___45 *queue;
	const struct bsg_ops___44 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___92 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___92 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___44;

struct request_queue___45 {
	struct list_head queue_head;
	struct request___45 *last_merge;
	struct elevator_queue___44 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___44 *make_request_fn;
	dma_drain_needed_fn___44 *dma_drain_needed;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___92 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___177 kobj;
	struct kobject___177 *mq_kobj;
	struct blk_integrity integrity;
	struct device___170 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	struct bsg_class_device___44 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___92 bio_split;
	struct dentry___182 *debugfs_dir;
	struct dentry___182 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___132 {
	struct vm_struct___132 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___183 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct io_cq___48 {
	struct request_queue___45 *q;
	struct io_context___48 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___6 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct buffer_head___5;

typedef int get_block_t___3(struct inode___183 *, sector_t, struct buffer_head___5 *, int);

typedef void bh_end_io_t___5(struct buffer_head___5 *, int);

struct buffer_head___5 {
	long unsigned int b_state;
	struct buffer_head___5 *b_this_page;
	struct page___183 *b_page;
	sector_t b_blocknr;
	size_t b_size;
	char *b_data;
	struct block_device___183 *b_bdev;
	bh_end_io_t___5 *b_end_io;
	void *b_private;
	struct list_head b_assoc_buffers;
	struct address_space___182 *b_assoc_map;
	atomic_t b_count;
};

typedef int dio_iodone_t(struct kiocb___183 *, loff_t, ssize_t, void *);

struct kiocb___183 {
	struct file___183 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___183 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___182 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___183 *ia_file;
};

struct dquot___182 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___182 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___182 {
	int qf_fmt_id;
	const struct quota_format_ops___182 *qf_ops;
	struct module___156 *qf_owner;
	struct quota_format_type___182 *qf_next;
};

struct quota_format_ops___182 {
	int (*check_quota_file)(struct super_block___182 *, int);
	int (*read_file_info)(struct super_block___182 *, int);
	int (*write_file_info)(struct super_block___182 *, int);
	int (*free_file_info)(struct super_block___182 *, int);
	int (*read_dqblk)(struct dquot___182 *);
	int (*commit_dqblk)(struct dquot___182 *);
	int (*release_dqblk)(struct dquot___182 *);
	int (*get_next_id)(struct super_block___182 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___182 {
	int (*write_dquot)(struct dquot___182 *);
	struct dquot___182 * (*alloc_dquot)(struct super_block___182 *, int);
	void (*destroy_dquot)(struct dquot___182 *);
	int (*acquire_dquot)(struct dquot___182 *);
	int (*release_dquot)(struct dquot___182 *);
	int (*mark_dirty)(struct dquot___182 *);
	int (*write_info)(struct super_block___182 *, int);
	qsize_t * (*get_reserved_space)(struct inode___183 *);
	int (*get_projid)(struct inode___183 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___183 *, qsize_t *);
	int (*get_next_id)(struct super_block___182 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___182 {
	int (*quota_on)(struct super_block___182 *, int, int, const struct path___182 *);
	int (*quota_off)(struct super_block___182 *, int);
	int (*quota_enable)(struct super_block___182 *, unsigned int);
	int (*quota_disable)(struct super_block___182 *, unsigned int);
	int (*quota_sync)(struct super_block___182 *, int);
	int (*set_info)(struct super_block___182 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___182 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___182 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___182 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___182 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___182 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___182 {
	int (*writepage)(struct page___183 *, struct writeback_control___3 *);
	int (*readpage)(struct file___183 *, struct page___183 *);
	int (*writepages)(struct address_space___182 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___183 *);
	int (*readpages)(struct file___183 *, struct address_space___182 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___183 *, struct address_space___182 *, loff_t, unsigned int, unsigned int, struct page___183 **, void **);
	int (*write_end)(struct file___183 *, struct address_space___182 *, loff_t, unsigned int, unsigned int, struct page___183 *, void *);
	sector_t (*bmap)(struct address_space___182 *, sector_t);
	void (*invalidatepage)(struct page___183 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___183 *, gfp_t);
	void (*freepage)(struct page___183 *);
	ssize_t (*direct_IO)(struct kiocb___183 *, struct iov_iter___89 *);
	int (*migratepage)(struct address_space___182 *, struct page___183 *, struct page___183 *, enum migrate_mode);
	bool (*isolate_page)(struct page___183 *, isolate_mode_t);
	void (*putback_page)(struct page___183 *);
	int (*launder_page)(struct page___183 *);
	int (*is_partially_uptodate)(struct page___183 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___183 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___182 *, struct page___183 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___183 *, sector_t *);
	void (*swap_deactivate)(struct file___183 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio_vec___92;

struct iov_iter___89 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___92 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct hd_struct___45;

struct gendisk___45;

struct block_device___183 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___183 *bd_inode;
	struct super_block___182 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___183 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___45 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___45 *bd_disk;
	struct request_queue___45 *bd_queue;
	struct backing_dev_info___92 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___170 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___170 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___170;

struct bus_type___170;

struct device_driver___170;

struct dev_pm_domain___170;

struct fwnode_handle___119;

struct class___170;

struct device___170 {
	struct device___170 *parent;
	struct device_private *p;
	struct kobject___177 kobj;
	const char *init_name;
	const struct device_type___170 *type;
	struct mutex mutex;
	struct bus_type___170 *bus;
	struct device_driver___170 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___170 power;
	struct dev_pm_domain___170 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___119 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___170 *class;
	const struct attribute_group___171 **groups;
	void (*release)(struct device___170 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___45 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___170 __dev;
	struct kobject___177 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___45;

struct block_device_operations___45;

struct gendisk___45 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___45 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___45 *part_tbl;
	struct hd_struct___45 part0;
	const struct block_device_operations___45 *fops;
	struct request_queue___45 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___183 lookup_sem;
	struct kobject___177 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___177 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___182 {
	struct dentry___182 * (*lookup)(struct inode___183 *, struct dentry___182 *, unsigned int);
	const char * (*get_link)(struct dentry___182 *, struct inode___183 *, struct delayed_call *);
	int (*permission)(struct inode___183 *, int);
	struct posix_acl * (*get_acl)(struct inode___183 *, int);
	int (*readlink)(struct dentry___182 *, char *, int);
	int (*create)(struct inode___183 *, struct dentry___182 *, umode_t, bool);
	int (*link)(struct dentry___182 *, struct inode___183 *, struct dentry___182 *);
	int (*unlink)(struct inode___183 *, struct dentry___182 *);
	int (*symlink)(struct inode___183 *, struct dentry___182 *, const char *);
	int (*mkdir)(struct inode___183 *, struct dentry___182 *, umode_t);
	int (*rmdir)(struct inode___183 *, struct dentry___182 *);
	int (*mknod)(struct inode___183 *, struct dentry___182 *, umode_t, dev_t);
	int (*rename)(struct inode___183 *, struct dentry___182 *, struct inode___183 *, struct dentry___182 *, unsigned int);
	int (*setattr)(struct dentry___182 *, struct iattr___182 *);
	int (*getattr)(const struct path___182 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___182 *, char *, size_t);
	int (*fiemap)(struct inode___183 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___183 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___183 *, struct dentry___182 *, struct file___183 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___183 *, struct dentry___182 *, umode_t);
	int (*set_acl)(struct inode___183 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___182 {
	void (*fl_copy_lock)(struct file_lock___183 *, struct file_lock___183 *);
	void (*fl_release_private)(struct file_lock___183 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___182;

struct lock_manager_operations___182;

struct file_lock___183 {
	struct file_lock___183 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___183 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___182 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___182 *fl_ops;
	const struct lock_manager_operations___182 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___182 {
	int (*lm_compare_owner)(struct file_lock___183 *, struct file_lock___183 *);
	long unsigned int (*lm_owner_key)(struct file_lock___183 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___183 *);
	int (*lm_grant)(struct file_lock___183 *, int);
	bool (*lm_break)(struct file_lock___183 *);
	int (*lm_change)(struct file_lock___183 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___183 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___182 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___182 *fa_next;
	struct file___183 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___182 {
	const char *name;
	int fs_flags;
	struct dentry___182 * (*mount)(struct file_system_type___182 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___182 *);
	struct module___156 *owner;
	struct file_system_type___182 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___182 {
	struct inode___183 * (*alloc_inode)(struct super_block___182 *);
	void (*destroy_inode)(struct inode___183 *);
	void (*dirty_inode)(struct inode___183 *, int);
	int (*write_inode)(struct inode___183 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___183 *);
	void (*evict_inode)(struct inode___183 *);
	void (*put_super)(struct super_block___182 *);
	int (*sync_fs)(struct super_block___182 *, int);
	int (*freeze_super)(struct super_block___182 *);
	int (*freeze_fs)(struct super_block___182 *);
	int (*thaw_super)(struct super_block___182 *);
	int (*unfreeze_fs)(struct super_block___182 *);
	int (*statfs)(struct dentry___182 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___182 *, int *, char *);
	void (*umount_begin)(struct super_block___182 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___182 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___182 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___182 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___182 *);
	ssize_t (*quota_read)(struct super_block___182 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___182 *, int, const char *, size_t, loff_t);
	struct dquot___182 ** (*get_dquots)(struct inode___183 *);
	int (*bdev_try_to_free_page)(struct super_block___182 *, struct page___183 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___182 *, struct shrink_control___82 *);
	long int (*free_cached_objects)(struct super_block___182 *, struct shrink_control___82 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void dio_submit_t(struct bio___92 *, struct inode___183 *, loff_t);

typedef void bio_end_io_t___92(struct bio___92 *);

struct bio_vec___92 {
	struct page___183 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___92;

struct bio___92 {
	struct bio___92 *bi_next;
	struct gendisk___45 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___92 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___92 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___92 *bi_io_vec;
	struct bio_set___92 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___92 bi_inline_vecs[0];
};

enum {
	DIO_LOCKING = 1,
	DIO_SKIP_HOLES = 2,
};

typedef void compound_page_dtor___180(struct page___183 *);

struct bio_integrity_payload___92 {
	struct bio___92 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___92 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___92 bip_inline_vecs[0];
};

struct dev_pm_ops___170;

struct device_type___170 {
	const char *name;
	const struct attribute_group___171 **groups;
	int (*uevent)(struct device___170 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___170 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___170 *);
	const struct dev_pm_ops___170 *pm;
};

struct class___170 {
	const char *name;
	struct module___156 *owner;
	const struct attribute_group___171 **class_groups;
	const struct attribute_group___171 **dev_groups;
	struct kobject___177 *dev_kobj;
	int (*dev_uevent)(struct device___170 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___170 *, umode_t *);
	void (*class_release)(struct class___170 *);
	void (*dev_release)(struct device___170 *);
	int (*shutdown_pre)(struct device___170 *);
	const struct kobj_ns_type_operations___11 *ns_type;
	const void * (*namespace)(struct device___170 *);
	const struct dev_pm_ops___170 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dev_pm_ops___170 {
	int (*prepare)(struct device___170 *);
	void (*complete)(struct device___170 *);
	int (*suspend)(struct device___170 *);
	int (*resume)(struct device___170 *);
	int (*freeze)(struct device___170 *);
	int (*thaw)(struct device___170 *);
	int (*poweroff)(struct device___170 *);
	int (*restore)(struct device___170 *);
	int (*suspend_late)(struct device___170 *);
	int (*resume_early)(struct device___170 *);
	int (*freeze_late)(struct device___170 *);
	int (*thaw_early)(struct device___170 *);
	int (*poweroff_late)(struct device___170 *);
	int (*restore_early)(struct device___170 *);
	int (*suspend_noirq)(struct device___170 *);
	int (*resume_noirq)(struct device___170 *);
	int (*freeze_noirq)(struct device___170 *);
	int (*thaw_noirq)(struct device___170 *);
	int (*poweroff_noirq)(struct device___170 *);
	int (*restore_noirq)(struct device___170 *);
	int (*runtime_suspend)(struct device___170 *);
	int (*runtime_resume)(struct device___170 *);
	int (*runtime_idle)(struct device___170 *);
};

struct dev_pm_domain___170 {
	struct dev_pm_ops___170 ops;
	void (*detach)(struct device___170 *, bool);
	int (*activate)(struct device___170 *);
	void (*sync)(struct device___170 *);
	void (*dismiss)(struct device___170 *);
};

struct bus_type___170 {
	const char *name;
	const char *dev_name;
	struct device___170 *dev_root;
	const struct attribute_group___171 **bus_groups;
	const struct attribute_group___171 **dev_groups;
	const struct attribute_group___171 **drv_groups;
	int (*match)(struct device___170 *, struct device_driver___170 *);
	int (*uevent)(struct device___170 *, struct kobj_uevent_env *);
	int (*probe)(struct device___170 *);
	int (*remove)(struct device___170 *);
	void (*shutdown)(struct device___170 *);
	int (*online)(struct device___170 *);
	int (*offline)(struct device___170 *);
	int (*suspend)(struct device___170 *, pm_message_t);
	int (*resume)(struct device___170 *);
	int (*num_vf)(struct device___170 *);
	int (*dma_configure)(struct device___170 *);
	const struct dev_pm_ops___170 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___170 {
	const char *name;
	struct bus_type___170 *bus;
	struct module___156 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___170 *);
	int (*remove)(struct device___170 *);
	void (*shutdown)(struct device___170 *);
	int (*suspend)(struct device___170 *, pm_message_t);
	int (*resume)(struct device___170 *);
	const struct attribute_group___171 **groups;
	const struct dev_pm_ops___170 *pm;
	void (*coredump)(struct device___170 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct fwnode_operations___119;

struct fwnode_handle___119 {
	struct fwnode_handle___119 *secondary;
	const struct fwnode_operations___119 *ops;
};

struct disk_part_tbl___45 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___45 *last_lookup;
	struct hd_struct___45 *part[0];
};

struct block_device_operations___45 {
	int (*open)(struct block_device___183 *, fmode_t);
	void (*release)(struct gendisk___45 *, fmode_t);
	int (*rw_page)(struct block_device___183 *, sector_t, struct page___183 *, unsigned int);
	int (*ioctl)(struct block_device___183 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___183 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___45 *, unsigned int);
	int (*media_changed)(struct gendisk___45 *);
	void (*unlock_native_capacity)(struct gendisk___45 *);
	int (*revalidate_disk)(struct gendisk___45 *);
	int (*getgeo)(struct block_device___183 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___183 *, long unsigned int);
	int (*report_zones)(struct gendisk___45 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___156 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bdi_writeback_congested___92 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___92 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bsg_ops___44 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___45 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___45 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___45 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___44(struct request___45 *, blk_status_t);

struct request___45 {
	struct request_queue___45 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___92 *bio;
	struct bio___92 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___92 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___48 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___44 *saved_end_io;
		} flush;
	};
	struct gendisk___45 *rq_disk;
	struct hd_struct___45 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___44 *end_io;
	void *end_io_data;
	struct request___45 *next_rq;
};

struct fwnode_reference_args___119;

struct fwnode_endpoint___119;

struct fwnode_operations___119 {
	struct fwnode_handle___119 * (*get)(struct fwnode_handle___119 *);
	void (*put)(struct fwnode_handle___119 *);
	bool (*device_is_available)(const struct fwnode_handle___119 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___119 *, const struct device___170 *);
	bool (*property_present)(const struct fwnode_handle___119 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___119 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___119 *, const char *, const char **, size_t);
	struct fwnode_handle___119 * (*get_parent)(const struct fwnode_handle___119 *);
	struct fwnode_handle___119 * (*get_next_child_node)(const struct fwnode_handle___119 *, struct fwnode_handle___119 *);
	struct fwnode_handle___119 * (*get_named_child_node)(const struct fwnode_handle___119 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___119 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___119 *);
	struct fwnode_handle___119 * (*graph_get_next_endpoint)(const struct fwnode_handle___119 *, struct fwnode_handle___119 *);
	struct fwnode_handle___119 * (*graph_get_remote_endpoint)(const struct fwnode_handle___119 *);
	struct fwnode_handle___119 * (*graph_get_port_parent)(struct fwnode_handle___119 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___119 *, struct fwnode_endpoint___119 *);
};

struct fwnode_endpoint___119 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___119 *local_fwnode;
};

struct fwnode_reference_args___119 {
	struct fwnode_handle___119 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct elevator_type___44;

struct elevator_mq_ops___44 {
	int (*init_sched)(struct request_queue___45 *, struct elevator_type___44 *);
	void (*exit_sched)(struct elevator_queue___44 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	bool (*allow_merge)(struct request_queue___45 *, struct request___45 *, struct bio___92 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx *, struct bio___92 *);
	int (*request_merge)(struct request_queue___45 *, struct request___45 **, struct bio___92 *);
	void (*request_merged)(struct request_queue___45 *, struct request___45 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___45 *, struct request___45 *, struct request___45 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___45 *, struct bio___92 *);
	void (*finish_request)(struct request___45 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___45 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___45 *, u64);
	void (*started_request)(struct request___45 *);
	void (*requeue_request)(struct request___45 *);
	struct request___45 * (*former_request)(struct request_queue___45 *, struct request___45 *);
	struct request___45 * (*next_request)(struct request_queue___45 *, struct request___45 *);
	void (*init_icq)(struct io_cq___48 *);
	void (*exit_icq)(struct io_cq___48 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___44;

struct elevator_type___44 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___44 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___44 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___156 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___44 {
	struct elevator_type___44 *type;
	void *elevator_data;
	struct kobject___177 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___44 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___44 *, char *);
	ssize_t (*store)(struct elevator_queue___44 *, const char *, size_t);
};

struct dio_submit {
	struct bio___92 *bio;
	unsigned int blkbits;
	unsigned int blkfactor;
	unsigned int start_zero_done;
	int pages_in_io;
	sector_t block_in_file;
	unsigned int blocks_available;
	int reap_counter;
	sector_t final_block_in_request;
	int boundary;
	get_block_t___3 *get_block;
	dio_submit_t *submit_io;
	loff_t logical_offset_in_bio;
	sector_t final_block_in_bio;
	sector_t next_block_for_io;
	struct page___183 *cur_page;
	unsigned int cur_page_offset;
	unsigned int cur_page_len;
	sector_t cur_page_block;
	loff_t cur_page_fs_offset;
	struct iov_iter___89 *iter;
	unsigned int head;
	unsigned int tail;
	size_t from;
	size_t to;
};

struct dio {
	int flags;
	int op;
	int op_flags;
	blk_qc_t bio_cookie;
	struct gendisk___45 *bio_disk;
	struct inode___183 *inode;
	loff_t i_size;
	dio_iodone_t *end_io;
	void *private;
	spinlock_t bio_lock;
	int page_errors;
	int is_async;
	bool defer_completion;
	bool should_dirty;
	int io_error;
	long unsigned int refcount;
	struct bio___92 *bio_list;
	struct task_struct___183 *waiter;
	struct kiocb___183 *iocb;
	ssize_t result;
	union {
		struct page___183 *pages[64];
		struct work_struct complete_work;
	};
	long: 64;
};

struct file___184;

struct kiocb___184;

struct vm_area_struct___184;

struct inode___184;

struct file_lock___184;

struct page___184;

struct seq_file___172;

struct file_operations___184 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___184 *, loff_t, int);
	ssize_t (*read)(struct file___184 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___184 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___184 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___184 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___184 *, bool);
	int (*iterate)(struct file___184 *, struct dir_context *);
	int (*iterate_shared)(struct file___184 *, struct dir_context *);
	__poll_t (*poll)(struct file___184 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___184 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___184 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___184 *, struct vm_area_struct___184 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___184 *, struct file___184 *);
	int (*flush)(struct file___184 *, fl_owner_t);
	int (*release)(struct inode___184 *, struct file___184 *);
	int (*fsync)(struct file___184 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___184 *, int);
	int (*lock)(struct file___184 *, int, struct file_lock___184 *);
	ssize_t (*sendpage)(struct file___184 *, struct page___184 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___184 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___184 *, int, struct file_lock___184 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___184 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___184 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___184 *, long int, struct file_lock___184 **, void **);
	long int (*fallocate)(struct file___184 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___172 *, struct file___184 *);
	ssize_t (*copy_file_range)(struct file___184 *, loff_t, struct file___184 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___184 *, loff_t, struct file___184 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___184 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___183 {
	u64 seqnum;
	struct vm_area_struct___184 *vmas[4];
};

struct page_frag___183 {
	struct page___184 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___183;

struct mem_cgroup___83;

struct cred___178;

struct nsproxy___174;

struct bio_list___93;

struct backing_dev_info___93;

struct io_context___49;

struct css_set___157;

struct request_queue___46;

struct vm_struct___133;

struct task_struct___184 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___184 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___183 *mm;
	struct mm_struct___183 *active_mm;
	struct vmacache___183 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___184 *real_parent;
	struct task_struct___184 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___184 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___83 *active_memcg;
	long int rh_reserved2;
	struct pid___145 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___145 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___145 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___178 *ptracer_cred;
	const struct cred___178 *real_cred;
	const struct cred___178 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___174 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___184 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___93 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___93 *backing_dev_info;
	struct io_context___49 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___157 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___183 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___83 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___46 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___184 *oom_reaper_list;
	struct vm_struct___133 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___113 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___184 *pgtable_t___183;

struct address_space___183;

struct dev_pagemap___181;

struct page___184 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___183 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___184 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___183 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___183 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___181 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___83 *mem_cgroup;
};

struct pglist_data___183;

struct lruvec___183 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___183 *pgdat;
};

struct zone___183 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___183 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___183 {
	struct zone___183 *zone;
	int zone_idx;
};

struct zonelist___183 {
	struct zoneref___183 _zonerefs[25];
};

struct pglist_data___183 {
	struct zone___183 node_zones[3];
	struct zonelist___183 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___184 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___184 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___183 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___184 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___184 *owner;
};

struct secondary_data___184 {
	void *stack;
	struct task_struct___184 *task;
	long int status;
};

struct blocking_notifier_head___183 {
	struct rw_semaphore___184 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___181;

struct vm_area_struct___184 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___184 *vm_next;
	struct vm_area_struct___184 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___183 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___181 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___184 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___183;

struct user_namespace___162;

struct mm_struct___183 {
	struct {
		struct vm_area_struct___184 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___184 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___184 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___183 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___184 *owner;
		struct user_namespace___162 *user_ns;
		struct file___184 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___183 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___183;

struct address_space___183 {
	struct inode___184 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___184 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___183 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___181)(struct vm_area_struct___184 *, long unsigned int, const struct page___184 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___181)(struct page___184 *, void *);

struct device___171;

struct dev_pagemap___181 {
	dev_page_fault_t___181 page_fault;
	dev_page_free_t___181 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___171 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct cgroup___157;

struct cgroup_subsys___157;

struct cgroup_subsys_state___158 {
	struct cgroup___157 *cgroup;
	struct cgroup_subsys___157 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___158 *parent;
};

struct kernfs_node___180;

struct cgroup_file___157 {
	struct kernfs_node___180 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___83;

struct mem_cgroup___83 {
	struct cgroup_subsys_state___158 css;
	struct mem_cgroup_id___17 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___157 events_file;
	struct cgroup_file___157 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___184 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___83 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry___183;

struct path___183 {
	struct vfsmount *mnt;
	struct dentry___183 *dentry;
};

struct file___184 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___183 f_path;
	struct inode___184 *f_inode;
	const struct file_operations___184 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___145 f_owner;
	const struct cred___178 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___183 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___181;

struct vm_operations_struct___181 {
	void (*open)(struct vm_area_struct___184 *);
	void (*close)(struct vm_area_struct___184 *);
	int (*split)(struct vm_area_struct___184 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___184 *);
	vm_fault_t (*fault)(struct vm_fault___181 *);
	vm_fault_t (*huge_fault)(struct vm_fault___181 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___181 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___184 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___181 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___181 *);
	int (*access)(struct vm_area_struct___184 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___184 *);
	int (*set_policy)(struct vm_area_struct___184 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___184 *, long unsigned int);
	struct page___184 * (*find_special_page)(struct vm_area_struct___184 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___183 {
	struct task_struct___184 *task;
	struct core_thread___183 *next;
};

struct core_state___183 {
	atomic_t nr_threads;
	struct core_thread___183 dumper;
	struct completion startup;
};

struct key___178;

struct ucounts___162;

struct user_namespace___162 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___162 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___10 ns;
	long unsigned int flags;
	struct key___178 *persistent_keyring_register;
	struct rw_semaphore___184 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___162 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___181 {
	struct vm_area_struct___184 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___184 *cow_page;
	struct mem_cgroup___83 *memcg;
	struct page___184 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___183 prealloc_pte;
};

struct shrink_control___83 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___83 *memcg;
};

struct shrinker___83 {
	long unsigned int (*count_objects)(struct shrinker___83 *, struct shrink_control___83 *);
	long unsigned int (*scan_objects)(struct shrinker___83 *, struct shrink_control___83 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct user_struct___178 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___178 *uid_keyring;
	struct key___178 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___178 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___178 *session_keyring;
	struct key___178 *process_keyring;
	struct key___178 *thread_keyring;
	struct key___178 *request_key_auth;
	void *security;
	struct user_struct___178 *user;
	struct user_namespace___162 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___157;

struct nsproxy___174 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___157 *cgroup_ns;
};

struct bio___93;

struct bio_list___93 {
	struct bio___93 *head;
	struct bio___93 *tail;
};

struct bdi_writeback_congested___93;

struct bdi_writeback___93 {
	struct backing_dev_info___93 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___93 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___158 *memcg_css;
	struct cgroup_subsys_state___158 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___93 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___93 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___171 *dev;
	struct device___171 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___183 *debug_dir;
	struct dentry___183 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___49;

struct io_context___49 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___49 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___157 {
	struct cgroup_subsys_state___158 *subsys[13];
	refcount_t refcount;
	struct css_set___157 *dom_cset;
	struct cgroup___157 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___157 *mg_src_cgrp;
	struct cgroup___157 *mg_dst_cgrp;
	struct css_set___157 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

typedef blk_qc_t make_request_fn___45(struct request_queue___46 *, struct bio___93 *);

struct request___46;

typedef int dma_drain_needed_fn___45(struct request___46 *);

struct kset___177;

struct kobj_type___177;

struct kobject___178 {
	const char *name;
	struct list_head entry;
	struct kobject___178 *parent;
	struct kset___177 *kset;
	struct kobj_type___177 *ktype;
	struct kernfs_node___180 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___45;

struct bsg_class_device___45 {
	struct device___171 *class_dev;
	int minor;
	struct request_queue___46 *queue;
	const struct bsg_ops___45 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___93 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___93 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___45;

struct blkcg_gq___35;

struct request_queue___46 {
	struct list_head queue_head;
	struct request___46 *last_merge;
	struct elevator_queue___45 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___45 *make_request_fn;
	dma_drain_needed_fn___45 *dma_drain_needed;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___93 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___178 kobj;
	struct kobject___178 *mq_kobj;
	struct blk_integrity integrity;
	struct device___171 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___35 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	struct bsg_class_device___45 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___93 bio_split;
	struct dentry___183 *debugfs_dir;
	struct dentry___183 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___133 {
	struct vm_struct___133 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___184 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dev_pm_info___171 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___171 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___171;

struct bus_type___171;

struct device_driver___171;

struct dev_pm_domain___171;

struct fwnode_handle___120;

struct class___171;

struct attribute_group___172;

struct device___171 {
	struct device___171 *parent;
	struct device_private *p;
	struct kobject___178 kobj;
	const char *init_name;
	const struct device_type___171 *type;
	struct mutex mutex;
	struct bus_type___171 *bus;
	struct device_driver___171 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___171 power;
	struct dev_pm_domain___171 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___120 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___171 *class;
	const struct attribute_group___172 **groups;
	void (*release)(struct device___171 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___183;

struct super_block___183;

struct dentry___183 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___183 *d_parent;
	struct qstr d_name;
	struct inode___184 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___183 *d_op;
	struct super_block___183 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___183;

struct block_device___184;

struct inode___184 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___183 *i_op;
	struct super_block___183 *i_sb;
	struct address_space___183 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___184 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___93 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___184 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___183 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___184 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___183 {
	int (*d_revalidate)(struct dentry___183 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___183 *, unsigned int);
	int (*d_hash)(const struct dentry___183 *, struct qstr *);
	int (*d_compare)(const struct dentry___183 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___183 *);
	int (*d_init)(struct dentry___183 *);
	void (*d_release)(struct dentry___183 *);
	void (*d_prune)(struct dentry___183 *);
	void (*d_iput)(struct dentry___183 *, struct inode___184 *);
	char * (*d_dname)(struct dentry___183 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___183 *);
	int (*d_manage)(const struct path___183 *, bool);
	struct dentry___183 * (*d_real)(struct dentry___183 *, const struct inode___184 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___183;

struct mem_dqinfo___183 {
	struct quota_format_type___183 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___183;

struct quota_info___183 {
	unsigned int flags;
	struct rw_semaphore___184 dqio_sem;
	struct inode___184 *files[3];
	struct mem_dqinfo___183 info[3];
	const struct quota_format_ops___183 *ops[3];
};

struct rcuwait___183 {
	struct task_struct___184 *task;
};

struct percpu_rw_semaphore___183 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___184 rw_sem;
	struct rcuwait___183 writer;
	int readers_block;
};

struct sb_writers___183 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___183 rw_sem[3];
};

struct file_system_type___183;

struct super_operations___183;

struct dquot_operations___183;

struct quotactl_ops___183;

struct export_operations___7;

struct super_block___183 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___183 *s_type;
	const struct super_operations___183 *s_op;
	const struct dquot_operations___183 *dq_op;
	const struct quotactl_ops___183 *s_qcop;
	const struct export_operations___7 *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___183 *s_root;
	struct rw_semaphore___184 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___184 *s_bdev;
	struct backing_dev_info___93 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___183 s_dquot;
	struct sb_writers___183 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___183 *s_d_op;
	int cleancache_poolid;
	struct shrinker___83 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___162 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct io_cq___49 {
	struct request_queue___46 *q;
	struct io_context___49 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___6 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct buffer_head___6;

typedef int get_block_t___4(struct inode___184 *, sector_t, struct buffer_head___6 *, int);

typedef void bh_end_io_t___6(struct buffer_head___6 *, int);

struct buffer_head___6 {
	long unsigned int b_state;
	struct buffer_head___6 *b_this_page;
	struct page___184 *b_page;
	sector_t b_blocknr;
	size_t b_size;
	char *b_data;
	struct block_device___184 *b_bdev;
	bh_end_io_t___6 *b_end_io;
	void *b_private;
	struct list_head b_assoc_buffers;
	struct address_space___183 *b_assoc_map;
	atomic_t b_count;
};

struct kiocb___184 {
	struct file___184 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___184 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___183 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___184 *ia_file;
};

struct dquot___183 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___183 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___183 {
	int qf_fmt_id;
	const struct quota_format_ops___183 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___183 *qf_next;
};

struct quota_format_ops___183 {
	int (*check_quota_file)(struct super_block___183 *, int);
	int (*read_file_info)(struct super_block___183 *, int);
	int (*write_file_info)(struct super_block___183 *, int);
	int (*free_file_info)(struct super_block___183 *, int);
	int (*read_dqblk)(struct dquot___183 *);
	int (*commit_dqblk)(struct dquot___183 *);
	int (*release_dqblk)(struct dquot___183 *);
	int (*get_next_id)(struct super_block___183 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___183 {
	int (*write_dquot)(struct dquot___183 *);
	struct dquot___183 * (*alloc_dquot)(struct super_block___183 *, int);
	void (*destroy_dquot)(struct dquot___183 *);
	int (*acquire_dquot)(struct dquot___183 *);
	int (*release_dquot)(struct dquot___183 *);
	int (*mark_dirty)(struct dquot___183 *);
	int (*write_info)(struct super_block___183 *, int);
	qsize_t * (*get_reserved_space)(struct inode___184 *);
	int (*get_projid)(struct inode___184 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___184 *, qsize_t *);
	int (*get_next_id)(struct super_block___183 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___183 {
	int (*quota_on)(struct super_block___183 *, int, int, const struct path___183 *);
	int (*quota_off)(struct super_block___183 *, int);
	int (*quota_enable)(struct super_block___183 *, unsigned int);
	int (*quota_disable)(struct super_block___183 *, unsigned int);
	int (*quota_sync)(struct super_block___183 *, int);
	int (*set_info)(struct super_block___183 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___183 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___183 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___183 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___183 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___183 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___89;

struct swap_info_struct___61;

struct address_space_operations___183 {
	int (*writepage)(struct page___184 *, struct writeback_control___89 *);
	int (*readpage)(struct file___184 *, struct page___184 *);
	int (*writepages)(struct address_space___183 *, struct writeback_control___89 *);
	int (*set_page_dirty)(struct page___184 *);
	int (*readpages)(struct file___184 *, struct address_space___183 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___184 *, struct address_space___183 *, loff_t, unsigned int, unsigned int, struct page___184 **, void **);
	int (*write_end)(struct file___184 *, struct address_space___183 *, loff_t, unsigned int, unsigned int, struct page___184 *, void *);
	sector_t (*bmap)(struct address_space___183 *, sector_t);
	void (*invalidatepage)(struct page___184 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___184 *, gfp_t);
	void (*freepage)(struct page___184 *);
	ssize_t (*direct_IO)(struct kiocb___184 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___183 *, struct page___184 *, struct page___184 *, enum migrate_mode);
	bool (*isolate_page)(struct page___184 *, isolate_mode_t);
	void (*putback_page)(struct page___184 *);
	int (*launder_page)(struct page___184 *);
	int (*is_partially_uptodate)(struct page___184 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___184 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___183 *, struct page___184 *);
	int (*swap_activate)(struct swap_info_struct___61 *, struct file___184 *, sector_t *);
	void (*swap_deactivate)(struct file___184 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___89 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___93 *wb;
	struct inode___184 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct swap_info_struct___61 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___184 *bdev;
	struct file___184 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct hd_struct___46;

struct gendisk___46;

struct block_device___184 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___184 *bd_inode;
	struct super_block___183 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___184 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___46 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___46 *bd_disk;
	struct request_queue___46 *bd_queue;
	struct backing_dev_info___93 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct hd_struct___46 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___171 __dev;
	struct kobject___178 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___46;

struct block_device_operations___46;

struct gendisk___46 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___46 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___46 *part_tbl;
	struct hd_struct___46 part0;
	const struct block_device_operations___46 *fops;
	struct request_queue___46 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___184 lookup_sem;
	struct kobject___178 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___178 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___183 {
	struct dentry___183 * (*lookup)(struct inode___184 *, struct dentry___183 *, unsigned int);
	const char * (*get_link)(struct dentry___183 *, struct inode___184 *, struct delayed_call *);
	int (*permission)(struct inode___184 *, int);
	struct posix_acl * (*get_acl)(struct inode___184 *, int);
	int (*readlink)(struct dentry___183 *, char *, int);
	int (*create)(struct inode___184 *, struct dentry___183 *, umode_t, bool);
	int (*link)(struct dentry___183 *, struct inode___184 *, struct dentry___183 *);
	int (*unlink)(struct inode___184 *, struct dentry___183 *);
	int (*symlink)(struct inode___184 *, struct dentry___183 *, const char *);
	int (*mkdir)(struct inode___184 *, struct dentry___183 *, umode_t);
	int (*rmdir)(struct inode___184 *, struct dentry___183 *);
	int (*mknod)(struct inode___184 *, struct dentry___183 *, umode_t, dev_t);
	int (*rename)(struct inode___184 *, struct dentry___183 *, struct inode___184 *, struct dentry___183 *, unsigned int);
	int (*setattr)(struct dentry___183 *, struct iattr___183 *);
	int (*getattr)(const struct path___183 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___183 *, char *, size_t);
	int (*fiemap)(struct inode___184 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___184 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___184 *, struct dentry___183 *, struct file___184 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___184 *, struct dentry___183 *, umode_t);
	int (*set_acl)(struct inode___184 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___183 {
	void (*fl_copy_lock)(struct file_lock___184 *, struct file_lock___184 *);
	void (*fl_release_private)(struct file_lock___184 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___183;

struct lock_manager_operations___183;

struct file_lock___184 {
	struct file_lock___184 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___184 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___183 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___183 *fl_ops;
	const struct lock_manager_operations___183 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___183 {
	int (*lm_compare_owner)(struct file_lock___184 *, struct file_lock___184 *);
	long unsigned int (*lm_owner_key)(struct file_lock___184 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___184 *);
	int (*lm_grant)(struct file_lock___184 *, int);
	bool (*lm_break)(struct file_lock___184 *);
	int (*lm_change)(struct file_lock___184 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___184 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___183 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___183 *fa_next;
	struct file___184 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___183 {
	const char *name;
	int fs_flags;
	struct dentry___183 * (*mount)(struct file_system_type___183 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___183 *);
	struct module___11 *owner;
	struct file_system_type___183 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___183 {
	struct inode___184 * (*alloc_inode)(struct super_block___183 *);
	void (*destroy_inode)(struct inode___184 *);
	void (*dirty_inode)(struct inode___184 *, int);
	int (*write_inode)(struct inode___184 *, struct writeback_control___89 *);
	int (*drop_inode)(struct inode___184 *);
	void (*evict_inode)(struct inode___184 *);
	void (*put_super)(struct super_block___183 *);
	int (*sync_fs)(struct super_block___183 *, int);
	int (*freeze_super)(struct super_block___183 *);
	int (*freeze_fs)(struct super_block___183 *);
	int (*thaw_super)(struct super_block___183 *);
	int (*unfreeze_fs)(struct super_block___183 *);
	int (*statfs)(struct dentry___183 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___183 *, int *, char *);
	void (*umount_begin)(struct super_block___183 *);
	int (*show_options)(struct seq_file___172 *, struct dentry___183 *);
	int (*show_devname)(struct seq_file___172 *, struct dentry___183 *);
	int (*show_path)(struct seq_file___172 *, struct dentry___183 *);
	int (*show_stats)(struct seq_file___172 *, struct dentry___183 *);
	ssize_t (*quota_read)(struct super_block___183 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___183 *, int, const char *, size_t, loff_t);
	struct dquot___183 ** (*get_dquots)(struct inode___184 *);
	int (*bdev_try_to_free_page)(struct super_block___183 *, struct page___184 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___183 *, struct shrink_control___83 *);
	long int (*free_cached_objects)(struct super_block___183 *, struct shrink_control___83 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct export_operations___7 {
	int (*encode_fh)(struct inode___184 *, __u32 *, int *, struct inode___184 *);
	struct dentry___183 * (*fh_to_dentry)(struct super_block___183 *, struct fid *, int, int);
	struct dentry___183 * (*fh_to_parent)(struct super_block___183 *, struct fid *, int, int);
	int (*get_name)(struct dentry___183 *, char *, struct dentry___183 *);
	struct dentry___183 * (*get_parent)(struct dentry___183 *);
	int (*commit_metadata)(struct inode___184 *);
	int (*get_uuid)(struct super_block___183 *, u8 *, u32 *, u64 *);
	int (*map_blocks)(struct inode___184 *, loff_t, u64, struct iomap *, bool, u32 *);
	int (*commit_blocks)(struct inode___184 *, struct iomap *, int, struct iattr___183 *);
};

struct seq_operations___170;

struct seq_file___172 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___170 *op;
	int poll_event;
	const struct file___184 *file;
	void *private;
};

typedef void bio_end_io_t___93(struct bio___93 *);

struct bio_vec___93 {
	struct page___184 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___93;

struct bio___93 {
	struct bio___93 *bi_next;
	struct gendisk___46 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___93 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___35 *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___93 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___93 *bi_io_vec;
	struct bio_set___93 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___93 bi_inline_vecs[0];
};

struct kobj_attribute___178 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___178 *, struct kobj_attribute___178 *, char *);
	ssize_t (*store)(struct kobject___178 *, struct kobj_attribute___178 *, const char *, size_t);
};

typedef void compound_page_dtor___181(struct page___184 *);

struct bio_integrity_payload___93 {
	struct bio___93 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___93 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___93 bip_inline_vecs[0];
};

struct blkcg___35;

struct blkg_policy_data___35;

struct blkcg_gq___35 {
	struct request_queue___46 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___35 *blkcg;
	struct bdi_writeback_congested___93 *wb_congested;
	struct blkcg_gq___35 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_rwstat stat_bytes;
	struct blkg_rwstat stat_ios;
	struct blkg_policy_data___35 *pd[5];
	struct callback_head callback_head;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
};

struct dev_pm_ops___171;

struct device_type___171 {
	const char *name;
	const struct attribute_group___172 **groups;
	int (*uevent)(struct device___171 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___171 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___171 *);
	const struct dev_pm_ops___171 *pm;
};

struct class___171 {
	const char *name;
	struct module___11 *owner;
	const struct attribute_group___172 **class_groups;
	const struct attribute_group___172 **dev_groups;
	struct kobject___178 *dev_kobj;
	int (*dev_uevent)(struct device___171 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___171 *, umode_t *);
	void (*class_release)(struct class___171 *);
	void (*dev_release)(struct device___171 *);
	int (*shutdown_pre)(struct device___171 *);
	const struct kobj_ns_type_operations___11 *ns_type;
	const void * (*namespace)(struct device___171 *);
	const struct dev_pm_ops___171 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct kernfs_root___180;

struct kernfs_elem_dir___180 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___180 *root;
};

struct kernfs_syscall_ops___180;

struct kernfs_root___180 {
	struct kernfs_node___180 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___180 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___180 {
	struct kernfs_node___180 *target_kn;
};

struct kernfs_ops___180;

struct kernfs_elem_attr___180 {
	const struct kernfs_ops___180 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___180 *notify_next;
};

struct kernfs_node___180 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___180 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___180 dir;
		struct kernfs_elem_symlink___180 symlink;
		struct kernfs_elem_attr___180 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___180;

struct kernfs_ops___180 {
	int (*open)(struct kernfs_open_file___180 *);
	void (*release)(struct kernfs_open_file___180 *);
	int (*seq_show)(struct seq_file___172 *, void *);
	void * (*seq_start)(struct seq_file___172 *, loff_t *);
	void * (*seq_next)(struct seq_file___172 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___172 *, void *);
	ssize_t (*read)(struct kernfs_open_file___180 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___180 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___180 *, struct vm_area_struct___184 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___180 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___180 {
	int (*remount_fs)(struct kernfs_root___180 *, int *, char *);
	int (*show_options)(struct seq_file___172 *, struct kernfs_root___180 *);
	int (*mkdir)(struct kernfs_node___180 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___180 *);
	int (*rename)(struct kernfs_node___180 *, struct kernfs_node___180 *, const char *);
	int (*show_path)(struct seq_file___172 *, struct kernfs_node___180 *, struct kernfs_root___180 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___180 {
	struct kernfs_node___180 *kn;
	struct file___184 *file;
	struct seq_file___172 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___181 *vm_ops;
};

struct bin_attribute___171;

struct attribute_group___172 {
	const char *name;
	umode_t (*is_visible)(struct kobject___178 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___178 *, struct bin_attribute___171 *, int);
	struct attribute **attrs;
	struct bin_attribute___171 **bin_attrs;
};

struct bin_attribute___171 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___184 *, struct kobject___178 *, struct bin_attribute___171 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___184 *, struct kobject___178 *, struct bin_attribute___171 *, char *, loff_t, size_t);
	int (*mmap)(struct file___184 *, struct kobject___178 *, struct bin_attribute___171 *, struct vm_area_struct___184 *);
};

struct sysfs_ops___177 {
	ssize_t (*show)(struct kobject___178 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___178 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___177;

struct kset___177 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___178 kobj;
	const struct kset_uevent_ops___177 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___177 {
	void (*release)(struct kobject___178 *);
	const struct sysfs_ops___177 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___11 * (*child_ns_type)(struct kobject___178 *);
	const void * (*namespace)(struct kobject___178 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___177 {
	int (* const filter)(struct kset___177 *, struct kobject___178 *);
	const char * (* const name)(struct kset___177 *, struct kobject___178 *);
	int (* const uevent)(struct kset___177 *, struct kobject___178 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___171 {
	int (*prepare)(struct device___171 *);
	void (*complete)(struct device___171 *);
	int (*suspend)(struct device___171 *);
	int (*resume)(struct device___171 *);
	int (*freeze)(struct device___171 *);
	int (*thaw)(struct device___171 *);
	int (*poweroff)(struct device___171 *);
	int (*restore)(struct device___171 *);
	int (*suspend_late)(struct device___171 *);
	int (*resume_early)(struct device___171 *);
	int (*freeze_late)(struct device___171 *);
	int (*thaw_early)(struct device___171 *);
	int (*poweroff_late)(struct device___171 *);
	int (*restore_early)(struct device___171 *);
	int (*suspend_noirq)(struct device___171 *);
	int (*resume_noirq)(struct device___171 *);
	int (*freeze_noirq)(struct device___171 *);
	int (*thaw_noirq)(struct device___171 *);
	int (*poweroff_noirq)(struct device___171 *);
	int (*restore_noirq)(struct device___171 *);
	int (*runtime_suspend)(struct device___171 *);
	int (*runtime_resume)(struct device___171 *);
	int (*runtime_idle)(struct device___171 *);
};

struct dev_pm_domain___171 {
	struct dev_pm_ops___171 ops;
	void (*detach)(struct device___171 *, bool);
	int (*activate)(struct device___171 *);
	void (*sync)(struct device___171 *);
	void (*dismiss)(struct device___171 *);
};

struct bus_type___171 {
	const char *name;
	const char *dev_name;
	struct device___171 *dev_root;
	const struct attribute_group___172 **bus_groups;
	const struct attribute_group___172 **dev_groups;
	const struct attribute_group___172 **drv_groups;
	int (*match)(struct device___171 *, struct device_driver___171 *);
	int (*uevent)(struct device___171 *, struct kobj_uevent_env *);
	int (*probe)(struct device___171 *);
	int (*remove)(struct device___171 *);
	void (*shutdown)(struct device___171 *);
	int (*online)(struct device___171 *);
	int (*offline)(struct device___171 *);
	int (*suspend)(struct device___171 *, pm_message_t);
	int (*resume)(struct device___171 *);
	int (*num_vf)(struct device___171 *);
	int (*dma_configure)(struct device___171 *);
	const struct dev_pm_ops___171 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___171 {
	const char *name;
	struct bus_type___171 *bus;
	struct module___11 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___171 *);
	int (*remove)(struct device___171 *);
	void (*shutdown)(struct device___171 *);
	int (*suspend)(struct device___171 *, pm_message_t);
	int (*resume)(struct device___171 *);
	const struct attribute_group___172 **groups;
	const struct dev_pm_ops___171 *pm;
	void (*coredump)(struct device___171 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct fwnode_operations___120;

struct fwnode_handle___120 {
	struct fwnode_handle___120 *secondary;
	const struct fwnode_operations___120 *ops;
};

struct disk_part_tbl___46 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___46 *last_lookup;
	struct hd_struct___46 *part[0];
};

struct block_device_operations___46 {
	int (*open)(struct block_device___184 *, fmode_t);
	void (*release)(struct gendisk___46 *, fmode_t);
	int (*rw_page)(struct block_device___184 *, sector_t, struct page___184 *, unsigned int);
	int (*ioctl)(struct block_device___184 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___184 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___46 *, unsigned int);
	int (*media_changed)(struct gendisk___46 *);
	void (*unlock_native_capacity)(struct gendisk___46 *);
	int (*revalidate_disk)(struct gendisk___46 *);
	int (*getgeo)(struct block_device___184 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___184 *, long unsigned int);
	int (*report_zones)(struct gendisk___46 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___11 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bdi_writeback_congested___93 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___93 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bsg_ops___45 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___46 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___46 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___46 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___45(struct request___46 *, blk_status_t);

struct request___46 {
	struct request_queue___46 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___93 *bio;
	struct bio___93 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___93 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___49 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___45 *saved_end_io;
		} flush;
	};
	struct gendisk___46 *rq_disk;
	struct hd_struct___46 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___45 *end_io;
	void *end_io_data;
	struct request___46 *next_rq;
};

struct fwnode_reference_args___120;

struct fwnode_endpoint___120;

struct fwnode_operations___120 {
	struct fwnode_handle___120 * (*get)(struct fwnode_handle___120 *);
	void (*put)(struct fwnode_handle___120 *);
	bool (*device_is_available)(const struct fwnode_handle___120 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___120 *, const struct device___171 *);
	bool (*property_present)(const struct fwnode_handle___120 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___120 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___120 *, const char *, const char **, size_t);
	struct fwnode_handle___120 * (*get_parent)(const struct fwnode_handle___120 *);
	struct fwnode_handle___120 * (*get_next_child_node)(const struct fwnode_handle___120 *, struct fwnode_handle___120 *);
	struct fwnode_handle___120 * (*get_named_child_node)(const struct fwnode_handle___120 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___120 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___120 *);
	struct fwnode_handle___120 * (*graph_get_next_endpoint)(const struct fwnode_handle___120 *, struct fwnode_handle___120 *);
	struct fwnode_handle___120 * (*graph_get_remote_endpoint)(const struct fwnode_handle___120 *);
	struct fwnode_handle___120 * (*graph_get_port_parent)(struct fwnode_handle___120 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___120 *, struct fwnode_endpoint___120 *);
};

struct fwnode_endpoint___120 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___120 *local_fwnode;
};

struct fwnode_reference_args___120 {
	struct fwnode_handle___120 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct elevator_type___45;

struct elevator_mq_ops___45 {
	int (*init_sched)(struct request_queue___46 *, struct elevator_type___45 *);
	void (*exit_sched)(struct elevator_queue___45 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	bool (*allow_merge)(struct request_queue___46 *, struct request___46 *, struct bio___93 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx *, struct bio___93 *);
	int (*request_merge)(struct request_queue___46 *, struct request___46 **, struct bio___93 *);
	void (*request_merged)(struct request_queue___46 *, struct request___46 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___46 *, struct request___46 *, struct request___46 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___46 *, struct bio___93 *);
	void (*finish_request)(struct request___46 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___46 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___46 *, u64);
	void (*started_request)(struct request___46 *);
	void (*requeue_request)(struct request___46 *);
	struct request___46 * (*former_request)(struct request_queue___46 *, struct request___46 *);
	struct request___46 * (*next_request)(struct request_queue___46 *, struct request___46 *);
	void (*init_icq)(struct io_cq___49 *);
	void (*exit_icq)(struct io_cq___49 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___45;

struct elevator_type___45 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___45 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___45 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___11 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___45 {
	struct elevator_type___45 *type;
	void *elevator_data;
	struct kobject___178 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___45 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___45 *, char *);
	ssize_t (*store)(struct elevator_queue___45 *, const char *, size_t);
};

typedef int (*key_restrict_link_func_t___178)(struct key___178 *, const struct key_type *, const union key_payload *, struct key___178 *);

struct key_restriction___178;

struct key___178 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___184 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___178 *restrict_link;
};

struct key_restriction___178 {
	key_restrict_link_func_t___178 check;
	struct key___178 *key;
	struct key_type *keytype;
};

struct seq_operations___170 {
	void * (*start)(struct seq_file___172 *, loff_t *);
	void (*stop)(struct seq_file___172 *, void *);
	void * (*next)(struct seq_file___172 *, void *, loff_t *);
	int (*show)(struct seq_file___172 *, void *);
};

struct cgroup_namespace___157 {
	refcount_t count;
	struct ns_common___10 ns;
	struct user_namespace___162 *user_ns;
	struct ucounts___162 *ucounts;
	struct css_set___157 *root_cset;
};

struct ucounts___162 {
	struct hlist_node node;
	struct user_namespace___162 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___157;

struct bpf_map_ops___157 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___157 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___157 *, struct file___184 *);
	void (*map_free)(struct bpf_map___157 *);
	int (*map_get_next_key)(struct bpf_map___157 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___157 *);
	void * (*map_lookup_elem)(struct bpf_map___157 *, void *);
	int (*map_update_elem)(struct bpf_map___157 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___157 *, void *);
	int (*map_push_elem)(struct bpf_map___157 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___157 *, void *);
	int (*map_peek_elem)(struct bpf_map___157 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___157 *, struct file___184 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___157 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___157 *, void *, struct seq_file___172 *);
	int (*map_check_btf)(const struct bpf_map___157 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___157 {
	const struct bpf_map_ops___157 *ops;
	struct bpf_map___157 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___178 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___157;

typedef void (*kthread_work_func_t___157)(struct kthread_work___157 *);

struct kthread_worker___157;

struct kthread_work___157 {
	struct list_head node;
	kthread_work_func_t___157 func;
	struct kthread_worker___157 *worker;
	int canceling;
};

struct kthread_worker___157 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___184 *task;
	struct kthread_work___157 *current_work;
};

struct kthread_delayed_work___157 {
	struct kthread_work___157 work;
	struct timer_list timer;
};

struct psi_group___157 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___157 *poll_kworker;
	struct kthread_delayed_work___157 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___157;

struct cgroup_rstat_cpu___157;

struct cgroup___157 {
	struct cgroup_subsys_state___158 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___180 *kn;
	struct cgroup_file___157 procs_file;
	struct cgroup_file___157 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___158 *subsys[13];
	struct cgroup_root___157 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___157 *dom_cgrp;
	struct cgroup_rstat_cpu___157 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___21 bpf;
	atomic_t congestion_count;
	struct cgroup___157 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___157 psi;
	int ancestor_ids[0];
};

struct cftype___157;

struct cgroup_subsys___157 {
	struct cgroup_subsys_state___158 * (*css_alloc)(struct cgroup_subsys_state___158 *);
	int (*css_online)(struct cgroup_subsys_state___158 *);
	void (*css_offline)(struct cgroup_subsys_state___158 *);
	void (*css_released)(struct cgroup_subsys_state___158 *);
	void (*css_free)(struct cgroup_subsys_state___158 *);
	void (*css_reset)(struct cgroup_subsys_state___158 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___158 *, int);
	int (*css_extra_stat_show)(struct seq_file___172 *, struct cgroup_subsys_state___158 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___184 *);
	void (*cancel_fork)(struct task_struct___184 *);
	void (*fork)(struct task_struct___184 *);
	void (*exit)(struct task_struct___184 *);
	void (*free)(struct task_struct___184 *);
	void (*bind)(struct cgroup_subsys_state___158 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___157 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___157 *dfl_cftypes;
	struct cftype___157 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___157 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___157 *updated_children;
	struct cgroup___157 *updated_next;
};

struct cgroup_root___157 {
	struct kernfs_root___180 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___157 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___157 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___157 *ss;
	struct list_head node;
	struct kernfs_ops___180 *kf_ops;
	int (*open)(struct kernfs_open_file___180 *);
	void (*release)(struct kernfs_open_file___180 *);
	u64 (*read_u64)(struct cgroup_subsys_state___158 *, struct cftype___157 *);
	s64 (*read_s64)(struct cgroup_subsys_state___158 *, struct cftype___157 *);
	int (*seq_show)(struct seq_file___172 *, void *);
	void * (*seq_start)(struct seq_file___172 *, loff_t *);
	void * (*seq_next)(struct seq_file___172 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___172 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___158 *, struct cftype___157 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___158 *, struct cftype___157 *, s64);
	ssize_t (*write)(struct kernfs_open_file___180 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___180 *, struct poll_table_struct___6 *);
};

struct mem_cgroup_reclaim_iter___83 {
	struct mem_cgroup___83 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___83 {
	struct lruvec___183 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___83 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___83 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct node___146 {
	struct device___171 dev;
};

struct blkcg_policy_data___35;

struct blkcg___35 {
	struct cgroup_subsys_state___158 css;
	spinlock_t lock;
	struct xarray blkg_tree;
	struct blkcg_gq___35 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___35 *cpd[5];
	struct list_head all_blkcgs_node;
	struct list_head cgwb_list;
	refcount_t cgwb_refcnt;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct blkcg_policy_data___35 {
	struct blkcg___35 *blkcg;
	int plid;
};

struct blkg_policy_data___35 {
	struct blkcg_gq___35 *blkg;
	int plid;
};

struct mpage_data {
	struct bio___93 *bio;
	sector_t last_block_in_bio;
	get_block_t___4 *get_block;
	unsigned int use_writepage;
};

struct file___185;

struct kiocb___185;

struct poll_table_struct___124;

struct vm_area_struct___185;

struct inode___185;

struct file_lock___185;

struct page___185;

struct seq_file___173;

struct file_operations___185 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___185 *, loff_t, int);
	ssize_t (*read)(struct file___185 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___185 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___185 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___185 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___185 *, bool);
	int (*iterate)(struct file___185 *, struct dir_context *);
	int (*iterate_shared)(struct file___185 *, struct dir_context *);
	__poll_t (*poll)(struct file___185 *, struct poll_table_struct___124 *);
	long int (*unlocked_ioctl)(struct file___185 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___185 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___185 *, struct vm_area_struct___185 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___185 *, struct file___185 *);
	int (*flush)(struct file___185 *, fl_owner_t);
	int (*release)(struct inode___185 *, struct file___185 *);
	int (*fsync)(struct file___185 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___185 *, int);
	int (*lock)(struct file___185 *, int, struct file_lock___185 *);
	ssize_t (*sendpage)(struct file___185 *, struct page___185 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___185 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___185 *, int, struct file_lock___185 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___185 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___185 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___185 *, long int, struct file_lock___185 **, void **);
	long int (*fallocate)(struct file___185 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___173 *, struct file___185 *);
	ssize_t (*copy_file_range)(struct file___185 *, loff_t, struct file___185 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___185 *, loff_t, struct file___185 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___185 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef u32 nlink_t;

struct vmacache___184 {
	u64 seqnum;
	struct vm_area_struct___185 *vmas[4];
};

struct page_frag___184 {
	struct page___185 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___184;

struct cred___179;

struct fs_struct___11;

struct nsproxy___175;

struct task_struct___185 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___185 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___184 *mm;
	struct mm_struct___184 *active_mm;
	struct vmacache___184 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___185 *real_parent;
	struct task_struct___185 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___185 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___145 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___145 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___145 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___179 *ptracer_cred;
	const struct cred___179 *real_cred;
	const struct cred___179 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct___11 *fs;
	struct files_struct *files;
	struct nsproxy___175 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___185 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___49 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___184 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___185 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___113 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct secondary_data___185 {
	void *stack;
	struct task_struct___185 *task;
	long int status;
};

typedef struct page___185 *pgtable_t___184;

struct address_space___184;

struct dev_pagemap___182;

struct page___185 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___184 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___185 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___184 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___184 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___182 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct key___179;

struct user_struct___179 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___179 *uid_keyring;
	struct key___179 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___182;

struct vm_area_struct___185 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___185 *vm_next;
	struct vm_area_struct___185 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___184 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___182 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___185 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct rw_semaphore___185 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___185 *owner;
};

struct linux_binfmt___18;

struct core_state___184;

struct mm_struct___184 {
	struct {
		struct vm_area_struct___185 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___185 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___185 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___18 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___184 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___185 *owner;
		struct user_namespace___3 *user_ns;
		struct file___185 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___184 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___179 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___179 *session_keyring;
	struct key___179 *process_keyring;
	struct key___179 *thread_keyring;
	struct key___179 *request_key_auth;
	void *security;
	struct user_struct___179 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct vfsmount___33;

struct dentry___184;

struct path___184 {
	struct vfsmount___33 *mnt;
	struct dentry___184 *dentry;
};

struct fs_struct___11 {
	int users;
	spinlock_t lock;
	seqcount_t seq;
	int umask;
	int in_exec;
	struct path___184 root;
	struct path___184 pwd;
};

struct mnt_namespace___4;

struct nsproxy___175 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace___4 *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___2 *cgroup_ns;
};

union thread_union___163 {
	struct task_struct___185 task;
	long unsigned int stack[8192];
};

struct proc_ns_operations___11;

struct ns_common___11 {
	atomic_long_t stashed;
	const struct proc_ns_operations___11 *ops;
	unsigned int inum;
};

struct mount___4;

struct mnt_namespace___4 {
	atomic_t count;
	struct ns_common___11 ns;
	struct mount___4 *root;
	struct list_head list;
	struct user_namespace___3 *user_ns;
	struct ucounts___2 *ucounts;
	u64 seq;
	wait_queue_head_t poll;
	u64 event;
	unsigned int mounts;
	unsigned int pending_mounts;
};

typedef int (*key_restrict_link_func_t___179)(struct key___179 *, const struct key_type *, const union key_payload *, struct key___179 *);

struct key_restriction___179;

struct key___179 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___185 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___179 *restrict_link;
};

struct key_restriction___179 {
	key_restrict_link_func_t___179 check;
	struct key___179 *key;
	struct key_type *keytype;
};

struct dentry_operations___184;

struct super_block___184;

struct dentry___184 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___184 *d_parent;
	struct qstr d_name;
	struct inode___185 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___184 *d_op;
	struct super_block___184 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___184;

struct address_space___184 {
	struct inode___185 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___185 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___184 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___184;

struct block_device___185;

struct inode___185 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___184 *i_op;
	struct super_block___184 *i_sb;
	struct address_space___184 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___185 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___185 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___184 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___185 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___184 {
	int (*d_revalidate)(struct dentry___184 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___184 *, unsigned int);
	int (*d_hash)(const struct dentry___184 *, struct qstr *);
	int (*d_compare)(const struct dentry___184 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___184 *);
	int (*d_init)(struct dentry___184 *);
	void (*d_release)(struct dentry___184 *);
	void (*d_prune)(struct dentry___184 *);
	void (*d_iput)(struct dentry___184 *, struct inode___185 *);
	char * (*d_dname)(struct dentry___184 *, char *, int);
	struct vfsmount___33 * (*d_automount)(struct path___184 *);
	int (*d_manage)(const struct path___184 *, bool);
	struct dentry___184 * (*d_real)(struct dentry___184 *, const struct inode___185 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___184;

struct mem_dqinfo___184 {
	struct quota_format_type___184 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___184;

struct quota_info___184 {
	unsigned int flags;
	struct rw_semaphore___185 dqio_sem;
	struct inode___185 *files[3];
	struct mem_dqinfo___184 info[3];
	const struct quota_format_ops___184 *ops[3];
};

struct rcuwait___184 {
	struct task_struct___185 *task;
};

struct percpu_rw_semaphore___184 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___185 rw_sem;
	struct rcuwait___184 writer;
	int readers_block;
};

struct sb_writers___184 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___184 rw_sem[3];
};

struct file_system_type___184;

struct super_operations___184;

struct dquot_operations___184;

struct quotactl_ops___184;

struct super_block___184 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___184 *s_type;
	const struct super_operations___184 *s_op;
	const struct dquot_operations___184 *dq_op;
	const struct quotactl_ops___184 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___184 *s_root;
	struct rw_semaphore___185 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___185 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___184 s_dquot;
	struct sb_writers___184 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___184 *s_d_op;
	int cleancache_poolid;
	struct shrinker___83 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___33 {
	struct dentry___184 *mnt_root;
	struct super_block___184 *mnt_sb;
	int mnt_flags;
};

struct pglist_data___184;

struct lruvec___184 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___184 *pgdat;
};

struct zone___184 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___184 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___184 {
	struct zone___184 *zone;
	int zone_idx;
};

struct zonelist___184 {
	struct zoneref___184 _zonerefs[25];
};

struct pglist_data___184 {
	struct zone___184 node_zones[3];
	struct zonelist___184 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___185 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___185 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___184 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___184 {
	struct rw_semaphore___185 rwsem;
	struct notifier_block *head;
};

typedef int (*dev_page_fault_t___182)(struct vm_area_struct___185 *, long unsigned int, const struct page___185 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___182)(struct page___185 *, void *);

struct dev_pagemap___182 {
	dev_page_fault_t___182 page_fault;
	dev_page_free_t___182 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___6 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct file___185 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___184 f_path;
	struct inode___185 *f_inode;
	const struct file_operations___185 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___145 f_owner;
	const struct cred___179 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___184 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___182;

struct vm_operations_struct___182 {
	void (*open)(struct vm_area_struct___185 *);
	void (*close)(struct vm_area_struct___185 *);
	int (*split)(struct vm_area_struct___185 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___185 *);
	vm_fault_t (*fault)(struct vm_fault___182 *);
	vm_fault_t (*huge_fault)(struct vm_fault___182 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___182 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___185 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___182 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___182 *);
	int (*access)(struct vm_area_struct___185 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___185 *);
	int (*set_policy)(struct vm_area_struct___185 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___185 *, long unsigned int);
	struct page___185 * (*find_special_page)(struct vm_area_struct___185 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___184 {
	struct task_struct___185 *task;
	struct core_thread___184 *next;
};

struct core_state___184 {
	atomic_t nr_threads;
	struct core_thread___184 dumper;
	struct completion startup;
};

struct linux_binprm___19;

struct coredump_params___18;

struct linux_binfmt___18 {
	struct list_head lh;
	struct module___11 *module;
	int (*load_binary)(struct linux_binprm___19 *);
	int (*load_shlib)(struct file___185 *);
	int (*core_dump)(struct coredump_params___18 *);
	long unsigned int min_coredump;
};

struct vm_fault___182 {
	struct vm_area_struct___185 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___185 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___185 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___184 prealloc_pte;
};

struct kiocb___185 {
	struct file___185 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___185 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___184 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___185 *ia_file;
};

struct dquot___184 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___184 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___184 {
	int qf_fmt_id;
	const struct quota_format_ops___184 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___184 *qf_next;
};

struct quota_format_ops___184 {
	int (*check_quota_file)(struct super_block___184 *, int);
	int (*read_file_info)(struct super_block___184 *, int);
	int (*write_file_info)(struct super_block___184 *, int);
	int (*free_file_info)(struct super_block___184 *, int);
	int (*read_dqblk)(struct dquot___184 *);
	int (*commit_dqblk)(struct dquot___184 *);
	int (*release_dqblk)(struct dquot___184 *);
	int (*get_next_id)(struct super_block___184 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___184 {
	int (*write_dquot)(struct dquot___184 *);
	struct dquot___184 * (*alloc_dquot)(struct super_block___184 *, int);
	void (*destroy_dquot)(struct dquot___184 *);
	int (*acquire_dquot)(struct dquot___184 *);
	int (*release_dquot)(struct dquot___184 *);
	int (*mark_dirty)(struct dquot___184 *);
	int (*write_info)(struct super_block___184 *, int);
	qsize_t * (*get_reserved_space)(struct inode___185 *);
	int (*get_projid)(struct inode___185 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___185 *, qsize_t *);
	int (*get_next_id)(struct super_block___184 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___184 {
	int (*quota_on)(struct super_block___184 *, int, int, const struct path___184 *);
	int (*quota_off)(struct super_block___184 *, int);
	int (*quota_enable)(struct super_block___184 *, unsigned int);
	int (*quota_disable)(struct super_block___184 *, unsigned int);
	int (*quota_sync)(struct super_block___184 *, int);
	int (*set_info)(struct super_block___184 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___184 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___184 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___184 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___184 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___184 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___184 {
	int (*writepage)(struct page___185 *, struct writeback_control___3 *);
	int (*readpage)(struct file___185 *, struct page___185 *);
	int (*writepages)(struct address_space___184 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___185 *);
	int (*readpages)(struct file___185 *, struct address_space___184 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___185 *, struct address_space___184 *, loff_t, unsigned int, unsigned int, struct page___185 **, void **);
	int (*write_end)(struct file___185 *, struct address_space___184 *, loff_t, unsigned int, unsigned int, struct page___185 *, void *);
	sector_t (*bmap)(struct address_space___184 *, sector_t);
	void (*invalidatepage)(struct page___185 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___185 *, gfp_t);
	void (*freepage)(struct page___185 *);
	ssize_t (*direct_IO)(struct kiocb___185 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___184 *, struct page___185 *, struct page___185 *, enum migrate_mode);
	bool (*isolate_page)(struct page___185 *, isolate_mode_t);
	void (*putback_page)(struct page___185 *);
	int (*launder_page)(struct page___185 *);
	int (*is_partially_uptodate)(struct page___185 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___185 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___184 *, struct page___185 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___185 *, sector_t *);
	void (*swap_deactivate)(struct file___185 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___185 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___185 *bd_inode;
	struct super_block___184 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___185 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___184 {
	struct dentry___184 * (*lookup)(struct inode___185 *, struct dentry___184 *, unsigned int);
	const char * (*get_link)(struct dentry___184 *, struct inode___185 *, struct delayed_call *);
	int (*permission)(struct inode___185 *, int);
	struct posix_acl * (*get_acl)(struct inode___185 *, int);
	int (*readlink)(struct dentry___184 *, char *, int);
	int (*create)(struct inode___185 *, struct dentry___184 *, umode_t, bool);
	int (*link)(struct dentry___184 *, struct inode___185 *, struct dentry___184 *);
	int (*unlink)(struct inode___185 *, struct dentry___184 *);
	int (*symlink)(struct inode___185 *, struct dentry___184 *, const char *);
	int (*mkdir)(struct inode___185 *, struct dentry___184 *, umode_t);
	int (*rmdir)(struct inode___185 *, struct dentry___184 *);
	int (*mknod)(struct inode___185 *, struct dentry___184 *, umode_t, dev_t);
	int (*rename)(struct inode___185 *, struct dentry___184 *, struct inode___185 *, struct dentry___184 *, unsigned int);
	int (*setattr)(struct dentry___184 *, struct iattr___184 *);
	int (*getattr)(const struct path___184 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___184 *, char *, size_t);
	int (*fiemap)(struct inode___185 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___185 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___185 *, struct dentry___184 *, struct file___185 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___185 *, struct dentry___184 *, umode_t);
	int (*set_acl)(struct inode___185 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___184 {
	void (*fl_copy_lock)(struct file_lock___185 *, struct file_lock___185 *);
	void (*fl_release_private)(struct file_lock___185 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___184;

struct lock_manager_operations___184;

struct file_lock___185 {
	struct file_lock___185 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___185 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___184 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___184 *fl_ops;
	const struct lock_manager_operations___184 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___184 {
	int (*lm_compare_owner)(struct file_lock___185 *, struct file_lock___185 *);
	long unsigned int (*lm_owner_key)(struct file_lock___185 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___185 *);
	int (*lm_grant)(struct file_lock___185 *, int);
	bool (*lm_break)(struct file_lock___185 *);
	int (*lm_change)(struct file_lock___185 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___185 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___184 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___184 *fa_next;
	struct file___185 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___184 {
	const char *name;
	int fs_flags;
	struct dentry___184 * (*mount)(struct file_system_type___184 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___184 *);
	struct module___11 *owner;
	struct file_system_type___184 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___184 {
	struct inode___185 * (*alloc_inode)(struct super_block___184 *);
	void (*destroy_inode)(struct inode___185 *);
	void (*dirty_inode)(struct inode___185 *, int);
	int (*write_inode)(struct inode___185 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___185 *);
	void (*evict_inode)(struct inode___185 *);
	void (*put_super)(struct super_block___184 *);
	int (*sync_fs)(struct super_block___184 *, int);
	int (*freeze_super)(struct super_block___184 *);
	int (*freeze_fs)(struct super_block___184 *);
	int (*thaw_super)(struct super_block___184 *);
	int (*unfreeze_fs)(struct super_block___184 *);
	int (*statfs)(struct dentry___184 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___184 *, int *, char *);
	void (*umount_begin)(struct super_block___184 *);
	int (*show_options)(struct seq_file___173 *, struct dentry___184 *);
	int (*show_devname)(struct seq_file___173 *, struct dentry___184 *);
	int (*show_path)(struct seq_file___173 *, struct dentry___184 *);
	int (*show_stats)(struct seq_file___173 *, struct dentry___184 *);
	ssize_t (*quota_read)(struct super_block___184 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___184 *, int, const char *, size_t, loff_t);
	struct dquot___184 ** (*get_dquots)(struct inode___185 *);
	int (*bdev_try_to_free_page)(struct super_block___184 *, struct page___185 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___184 *, struct shrink_control___83 *);
	long int (*free_cached_objects)(struct super_block___184 *, struct shrink_control___83 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___125)(struct file___185 *, wait_queue_head_t *, struct poll_table_struct___124 *);

struct poll_table_struct___124 {
	poll_queue_proc___125 _qproc;
	__poll_t _key;
};

struct seq_operations___171;

struct seq_file___173 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___171 *op;
	int poll_event;
	const struct file___185 *file;
	void *private;
};

typedef void compound_page_dtor___182(struct page___185 *);

typedef int (*proc_write_t)(struct file___185 *, char *, size_t);

struct proc_ns_operations___11 {
	const char *name;
	const char *real_ns_name;
	int type;
	struct ns_common___11 * (*get)(struct task_struct___185 *);
	void (*put)(struct ns_common___11 *);
	int (*install)(struct nsproxy___175 *, struct ns_common___11 *);
	struct user_namespace___3 * (*owner)(struct ns_common___11 *);
	struct ns_common___11 * (*get_parent)(struct ns_common___11 *);
};

struct linux_binprm___19 {
	char buf[256];
	struct vm_area_struct___185 *vma;
	long unsigned int vma_pages;
	struct mm_struct___184 *mm;
	long unsigned int p;
	unsigned int called_set_creds: 1;
	unsigned int cap_elevated: 1;
	unsigned int secureexec: 1;
	unsigned int recursion_depth;
	struct file___185 *file;
	struct cred___179 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
};

struct coredump_params___18 {
	union {
		const kernel_siginfo_t *siginfo;
		struct {
			const siginfo_t *siginfo;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	struct pt_regs *regs;
	struct file___185 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
};

struct seq_operations___171 {
	void * (*start)(struct seq_file___173 *, loff_t *);
	void (*stop)(struct seq_file___173 *, void *);
	void * (*next)(struct seq_file___173 *, void *, loff_t *);
	int (*show)(struct seq_file___173 *, void *);
};

struct proc_dir_entry___2 {
	atomic_t in_use;
	refcount_t refcnt;
	struct list_head pde_openers;
	spinlock_t pde_unload_lock;
	struct completion *pde_unload_completion;
	const struct inode_operations___184 *proc_iops;
	const struct file_operations___185 *proc_fops;
	union {
		const struct seq_operations___171 *seq_ops;
		int (*single_show)(struct seq_file___173 *, void *);
	};
	proc_write_t write;
	void *data;
	unsigned int state_size;
	unsigned int low_ino;
	nlink_t nlink;
	kuid_t uid;
	kgid_t gid;
	loff_t size;
	struct proc_dir_entry___2 *parent;
	struct rb_root subdir;
	struct rb_node subdir_node;
	char *name;
	umode_t mode;
	u8 namelen;
	char inline_name[0];
};

union proc_op {
	int (*proc_get_link)(struct dentry___184 *, struct path___184 *);
	int (*proc_show)(struct seq_file___173 *, struct pid_namespace *, struct pid___145 *, struct task_struct___185 *);
};

struct proc_inode {
	struct pid___145 *pid;
	unsigned int fd;
	union proc_op op;
	struct proc_dir_entry___2 *pde;
	struct ctl_table_header *sysctl;
	struct ctl_table *sysctl_entry;
	struct hlist_node sysctl_inodes;
	const struct proc_ns_operations___11 *ns_ops;
	struct inode___185 vfs_inode;
};

typedef struct poll_table_struct___124 poll_table___14;

struct mountpoint___4;

struct mount___4 {
	struct hlist_node mnt_hash;
	struct mount___4 *mnt_parent;
	struct dentry___184 *mnt_mountpoint;
	struct vfsmount___33 mnt;
	union {
		struct callback_head mnt_rcu;
		struct llist_node mnt_llist;
	};
	struct mnt_pcp *mnt_pcp;
	struct list_head mnt_mounts;
	struct list_head mnt_child;
	struct list_head mnt_instance;
	const char *mnt_devname;
	struct list_head mnt_list;
	struct list_head mnt_expire;
	struct list_head mnt_share;
	struct list_head mnt_slave_list;
	struct list_head mnt_slave;
	struct mount___4 *mnt_master;
	struct mnt_namespace___4 *mnt_ns;
	struct mountpoint___4 *mnt_mp;
	struct hlist_node mnt_mp_list;
	struct list_head mnt_umounting;
	struct fsnotify_mark_connector *mnt_fsnotify_marks;
	__u32 mnt_fsnotify_mask;
	int mnt_id;
	int mnt_group_id;
	int mnt_expiry_mark;
	struct hlist_head mnt_pins;
	struct fs_pin mnt_umount;
	struct dentry___184 *mnt_ex_mountpoint;
};

struct mountpoint___4 {
	struct hlist_node m_hash;
	struct dentry___184 *m_dentry;
	struct hlist_head m_list;
	int m_count;
};

struct proc_mounts___2 {
	struct mnt_namespace___4 *ns;
	struct path___184 root;
	int (*show)(struct seq_file___173 *, struct vfsmount___33 *);
	void *cached_mount;
	u64 cached_event;
	loff_t cached_index;
};

struct proc_fs_info {
	int flag;
	const char *str;
};

struct module___157;

struct file___186;

struct kiocb___186;

struct poll_table_struct___125;

struct vm_area_struct___186;

struct inode___186;

struct file_lock___186;

struct page___186;

struct seq_file___174;

struct file_operations___186 {
	struct module___157 *owner;
	loff_t (*llseek)(struct file___186 *, loff_t, int);
	ssize_t (*read)(struct file___186 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___186 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___186 *, struct iov_iter___89 *);
	ssize_t (*write_iter)(struct kiocb___186 *, struct iov_iter___89 *);
	int (*iopoll)(struct kiocb___186 *, bool);
	int (*iterate)(struct file___186 *, struct dir_context *);
	int (*iterate_shared)(struct file___186 *, struct dir_context *);
	__poll_t (*poll)(struct file___186 *, struct poll_table_struct___125 *);
	long int (*unlocked_ioctl)(struct file___186 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___186 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___186 *, struct vm_area_struct___186 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___186 *, struct file___186 *);
	int (*flush)(struct file___186 *, fl_owner_t);
	int (*release)(struct inode___186 *, struct file___186 *);
	int (*fsync)(struct file___186 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___186 *, int);
	int (*lock)(struct file___186 *, int, struct file_lock___186 *);
	ssize_t (*sendpage)(struct file___186 *, struct page___186 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___186 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___186 *, int, struct file_lock___186 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___186 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___186 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___186 *, long int, struct file_lock___186 **, void **);
	long int (*fallocate)(struct file___186 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___174 *, struct file___186 *);
	ssize_t (*copy_file_range)(struct file___186 *, loff_t, struct file___186 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___186 *, loff_t, struct file___186 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___186 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___185 {
	u64 seqnum;
	struct vm_area_struct___186 *vmas[4];
};

struct page_frag___185 {
	struct page___186 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___185;

struct pid___146;

struct cred___180;

struct nsproxy___176;

struct signal_struct___162;

struct task_struct___186 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___186 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___185 *mm;
	struct mm_struct___185 *active_mm;
	struct vmacache___185 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___186 *real_parent;
	struct task_struct___186 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___186 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___146 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___146 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___146 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___180 *ptracer_cred;
	const struct cred___180 *real_cred;
	const struct cred___180 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___176 *nsproxy;
	struct signal_struct___162 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___186 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___49 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___185 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___186 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___113 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___185;

struct super_block___185;

struct dentry___185 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___185 *d_parent;
	struct qstr d_name;
	struct inode___186 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___185 *d_op;
	struct super_block___185 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct rw_semaphore___186 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___186 *owner;
};

struct address_space_operations___185;

struct address_space___185 {
	struct inode___186 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___186 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___185 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___185;

struct block_device___186;

struct inode___186 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___185 *i_op;
	struct super_block___185 *i_sb;
	struct address_space___185 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___186 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___186 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___185 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___186 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vfsmount___34;

struct path___185;

struct dentry_operations___185 {
	int (*d_revalidate)(struct dentry___185 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___185 *, unsigned int);
	int (*d_hash)(const struct dentry___185 *, struct qstr *);
	int (*d_compare)(const struct dentry___185 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___185 *);
	int (*d_init)(struct dentry___185 *);
	void (*d_release)(struct dentry___185 *);
	void (*d_prune)(struct dentry___185 *);
	void (*d_iput)(struct dentry___185 *, struct inode___186 *);
	char * (*d_dname)(struct dentry___185 *, char *, int);
	struct vfsmount___34 * (*d_automount)(struct path___185 *);
	int (*d_manage)(const struct path___185 *, bool);
	struct dentry___185 * (*d_real)(struct dentry___185 *, const struct inode___186 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___185;

struct mem_dqinfo___185 {
	struct quota_format_type___185 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___185;

struct quota_info___185 {
	unsigned int flags;
	struct rw_semaphore___186 dqio_sem;
	struct inode___186 *files[3];
	struct mem_dqinfo___185 info[3];
	const struct quota_format_ops___185 *ops[3];
};

struct rcuwait___185 {
	struct task_struct___186 *task;
};

struct percpu_rw_semaphore___185 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___186 rw_sem;
	struct rcuwait___185 writer;
	int readers_block;
};

struct sb_writers___185 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___185 rw_sem[3];
};

struct file_system_type___185;

struct super_operations___185;

struct dquot_operations___185;

struct quotactl_ops___185;

struct user_namespace___163;

struct super_block___185 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___185 *s_type;
	const struct super_operations___185 *s_op;
	const struct dquot_operations___185 *dq_op;
	const struct quotactl_ops___185 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___185 *s_root;
	struct rw_semaphore___186 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___186 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___185 s_dquot;
	struct sb_writers___185 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___185 *s_d_op;
	int cleancache_poolid;
	struct shrinker___83 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___163 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___34 {
	struct dentry___185 *mnt_root;
	struct super_block___185 *mnt_sb;
	int mnt_flags;
};

struct path___185 {
	struct vfsmount___34 *mnt;
	struct dentry___185 *dentry;
};

struct key___180;

struct ucounts___163;

struct user_namespace___163 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___163 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___11 ns;
	long unsigned int flags;
	struct key___180 *persistent_keyring_register;
	struct rw_semaphore___186 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___163 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___186 *pgtable_t___185;

struct dev_pagemap___183;

struct page___186 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___185 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___186 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___185 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___185 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___183 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___185;

struct lruvec___185 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___185 *pgdat;
};

struct zone___185 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___185 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___185 {
	struct zone___185 *zone;
	int zone_idx;
};

struct zonelist___185 {
	struct zoneref___185 _zonerefs[25];
};

struct pglist_data___185 {
	struct zone___185 node_zones[3];
	struct zonelist___185 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___186 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___186 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___185 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___186 {
	void *stack;
	struct task_struct___186 *task;
	long int status;
};

struct blocking_notifier_head___185 {
	struct rw_semaphore___186 rwsem;
	struct notifier_block *head;
};

struct pid_namespace___146;

struct upid___146 {
	int nr;
	struct pid_namespace___146 *ns;
};

struct pid_namespace___146 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___186 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___146 *parent;
	struct vfsmount___34 *proc_mnt;
	struct dentry___185 *proc_self;
	struct dentry___185 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___163 *user_ns;
	struct ucounts___163 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___11 ns;
};

struct pid___146 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___146 numbers[1];
};

struct vm_operations_struct___183;

struct vm_area_struct___186 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___186 *vm_next;
	struct vm_area_struct___186 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___185 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___183 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___186 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___185;

struct mm_struct___185 {
	struct {
		struct vm_area_struct___186 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___186 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___186 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___185 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___186 *owner;
		struct user_namespace___163 *user_ns;
		struct file___186 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___185 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___183)(struct vm_area_struct___186 *, long unsigned int, const struct page___186 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___183)(struct page___186 *, void *);

struct dev_pagemap___183 {
	dev_page_fault_t___183 page_fault;
	dev_page_free_t___183 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___6 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct fown_struct___146 {
	rwlock_t lock;
	struct pid___146 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___186 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___185 f_path;
	struct inode___186 *f_inode;
	const struct file_operations___186 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___146 f_owner;
	const struct cred___180 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___185 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___183;

struct vm_operations_struct___183 {
	void (*open)(struct vm_area_struct___186 *);
	void (*close)(struct vm_area_struct___186 *);
	int (*split)(struct vm_area_struct___186 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___186 *);
	vm_fault_t (*fault)(struct vm_fault___183 *);
	vm_fault_t (*huge_fault)(struct vm_fault___183 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___183 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___186 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___183 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___183 *);
	int (*access)(struct vm_area_struct___186 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___186 *);
	int (*set_policy)(struct vm_area_struct___186 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___186 *, long unsigned int);
	struct page___186 * (*find_special_page)(struct vm_area_struct___186 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___185 {
	struct task_struct___186 *task;
	struct core_thread___185 *next;
};

struct core_state___185 {
	atomic_t nr_threads;
	struct core_thread___185 dumper;
	struct completion startup;
};

struct vm_fault___183 {
	struct vm_area_struct___186 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___186 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___186 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___185 prealloc_pte;
};

struct user_struct___180 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___180 *uid_keyring;
	struct key___180 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___180 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___180 *session_keyring;
	struct key___180 *process_keyring;
	struct key___180 *thread_keyring;
	struct key___180 *request_key_auth;
	void *security;
	struct user_struct___180 *user;
	struct user_namespace___163 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct mnt_namespace___5;

struct nsproxy___176 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace___5 *mnt_ns;
	struct pid_namespace___146 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct signal_struct___162 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___186 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___186 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___146 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___146 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___185 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___146 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

union thread_union___164 {
	struct task_struct___186 task;
	long unsigned int stack[8192];
};

struct kiocb___186 {
	struct file___186 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___186 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___185 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___186 *ia_file;
};

struct dquot___185 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___185 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___185 {
	int qf_fmt_id;
	const struct quota_format_ops___185 *qf_ops;
	struct module___157 *qf_owner;
	struct quota_format_type___185 *qf_next;
};

struct quota_format_ops___185 {
	int (*check_quota_file)(struct super_block___185 *, int);
	int (*read_file_info)(struct super_block___185 *, int);
	int (*write_file_info)(struct super_block___185 *, int);
	int (*free_file_info)(struct super_block___185 *, int);
	int (*read_dqblk)(struct dquot___185 *);
	int (*commit_dqblk)(struct dquot___185 *);
	int (*release_dqblk)(struct dquot___185 *);
	int (*get_next_id)(struct super_block___185 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___185 {
	int (*write_dquot)(struct dquot___185 *);
	struct dquot___185 * (*alloc_dquot)(struct super_block___185 *, int);
	void (*destroy_dquot)(struct dquot___185 *);
	int (*acquire_dquot)(struct dquot___185 *);
	int (*release_dquot)(struct dquot___185 *);
	int (*mark_dirty)(struct dquot___185 *);
	int (*write_info)(struct super_block___185 *, int);
	qsize_t * (*get_reserved_space)(struct inode___186 *);
	int (*get_projid)(struct inode___186 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___186 *, qsize_t *);
	int (*get_next_id)(struct super_block___185 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___185 {
	int (*quota_on)(struct super_block___185 *, int, int, const struct path___185 *);
	int (*quota_off)(struct super_block___185 *, int);
	int (*quota_enable)(struct super_block___185 *, unsigned int);
	int (*quota_disable)(struct super_block___185 *, unsigned int);
	int (*quota_sync)(struct super_block___185 *, int);
	int (*set_info)(struct super_block___185 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___185 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___185 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___185 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___185 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___185 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___178;

struct kobj_type___178;

struct kernfs_node___181;

struct kobject___179 {
	const char *name;
	struct list_head entry;
	struct kobject___179 *parent;
	struct kset___178 *kset;
	struct kobj_type___178 *ktype;
	struct kernfs_node___181 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___154 {
	struct kobject___179 kobj;
	struct module___157 *mod;
	struct kobject___179 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___154 {
	struct module___157 *mod;
	struct latch_tree_node node;
};

struct module_layout___154 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___154 mtn;
};

struct module_attribute___154;

struct kernel_param___154;

struct module___157 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___154 mkobj;
	struct module_attribute___154 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___179 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___154 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___154 core_layout;
	struct module_layout___154 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___185 {
	int (*writepage)(struct page___186 *, struct writeback_control___3 *);
	int (*readpage)(struct file___186 *, struct page___186 *);
	int (*writepages)(struct address_space___185 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___186 *);
	int (*readpages)(struct file___186 *, struct address_space___185 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___186 *, struct address_space___185 *, loff_t, unsigned int, unsigned int, struct page___186 **, void **);
	int (*write_end)(struct file___186 *, struct address_space___185 *, loff_t, unsigned int, unsigned int, struct page___186 *, void *);
	sector_t (*bmap)(struct address_space___185 *, sector_t);
	void (*invalidatepage)(struct page___186 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___186 *, gfp_t);
	void (*freepage)(struct page___186 *);
	ssize_t (*direct_IO)(struct kiocb___186 *, struct iov_iter___89 *);
	int (*migratepage)(struct address_space___185 *, struct page___186 *, struct page___186 *, enum migrate_mode);
	bool (*isolate_page)(struct page___186 *, isolate_mode_t);
	void (*putback_page)(struct page___186 *);
	int (*launder_page)(struct page___186 *);
	int (*is_partially_uptodate)(struct page___186 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___186 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___185 *, struct page___186 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___186 *, sector_t *);
	void (*swap_deactivate)(struct file___186 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___186 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___186 *bd_inode;
	struct super_block___185 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___186 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___185 {
	struct dentry___185 * (*lookup)(struct inode___186 *, struct dentry___185 *, unsigned int);
	const char * (*get_link)(struct dentry___185 *, struct inode___186 *, struct delayed_call *);
	int (*permission)(struct inode___186 *, int);
	struct posix_acl * (*get_acl)(struct inode___186 *, int);
	int (*readlink)(struct dentry___185 *, char *, int);
	int (*create)(struct inode___186 *, struct dentry___185 *, umode_t, bool);
	int (*link)(struct dentry___185 *, struct inode___186 *, struct dentry___185 *);
	int (*unlink)(struct inode___186 *, struct dentry___185 *);
	int (*symlink)(struct inode___186 *, struct dentry___185 *, const char *);
	int (*mkdir)(struct inode___186 *, struct dentry___185 *, umode_t);
	int (*rmdir)(struct inode___186 *, struct dentry___185 *);
	int (*mknod)(struct inode___186 *, struct dentry___185 *, umode_t, dev_t);
	int (*rename)(struct inode___186 *, struct dentry___185 *, struct inode___186 *, struct dentry___185 *, unsigned int);
	int (*setattr)(struct dentry___185 *, struct iattr___185 *);
	int (*getattr)(const struct path___185 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___185 *, char *, size_t);
	int (*fiemap)(struct inode___186 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___186 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___186 *, struct dentry___185 *, struct file___186 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___186 *, struct dentry___185 *, umode_t);
	int (*set_acl)(struct inode___186 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___185 {
	void (*fl_copy_lock)(struct file_lock___186 *, struct file_lock___186 *);
	void (*fl_release_private)(struct file_lock___186 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___185;

struct lock_manager_operations___185;

struct file_lock___186 {
	struct file_lock___186 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___186 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___185 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___185 *fl_ops;
	const struct lock_manager_operations___185 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___185 {
	int (*lm_compare_owner)(struct file_lock___186 *, struct file_lock___186 *);
	long unsigned int (*lm_owner_key)(struct file_lock___186 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___186 *);
	int (*lm_grant)(struct file_lock___186 *, int);
	bool (*lm_break)(struct file_lock___186 *);
	int (*lm_change)(struct file_lock___186 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___186 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___185 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___185 *fa_next;
	struct file___186 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___185 {
	const char *name;
	int fs_flags;
	struct dentry___185 * (*mount)(struct file_system_type___185 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___185 *);
	struct module___157 *owner;
	struct file_system_type___185 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___185 {
	struct inode___186 * (*alloc_inode)(struct super_block___185 *);
	void (*destroy_inode)(struct inode___186 *);
	void (*dirty_inode)(struct inode___186 *, int);
	int (*write_inode)(struct inode___186 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___186 *);
	void (*evict_inode)(struct inode___186 *);
	void (*put_super)(struct super_block___185 *);
	int (*sync_fs)(struct super_block___185 *, int);
	int (*freeze_super)(struct super_block___185 *);
	int (*freeze_fs)(struct super_block___185 *);
	int (*thaw_super)(struct super_block___185 *);
	int (*unfreeze_fs)(struct super_block___185 *);
	int (*statfs)(struct dentry___185 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___185 *, int *, char *);
	void (*umount_begin)(struct super_block___185 *);
	int (*show_options)(struct seq_file___174 *, struct dentry___185 *);
	int (*show_devname)(struct seq_file___174 *, struct dentry___185 *);
	int (*show_path)(struct seq_file___174 *, struct dentry___185 *);
	int (*show_stats)(struct seq_file___174 *, struct dentry___185 *);
	ssize_t (*quota_read)(struct super_block___185 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___185 *, int, const char *, size_t, loff_t);
	struct dquot___185 ** (*get_dquots)(struct inode___186 *);
	int (*bdev_try_to_free_page)(struct super_block___185 *, struct page___186 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___185 *, struct shrink_control___83 *);
	long int (*free_cached_objects)(struct super_block___185 *, struct shrink_control___83 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___126)(struct file___186 *, wait_queue_head_t *, struct poll_table_struct___125 *);

struct poll_table_struct___125 {
	poll_queue_proc___126 _qproc;
	__poll_t _key;
};

struct seq_operations___172;

struct seq_file___174 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___172 *op;
	int poll_event;
	const struct file___186 *file;
	void *private;
};

struct kernfs_root___181;

struct kernfs_elem_dir___181 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___181 *root;
};

struct kernfs_syscall_ops___181;

struct kernfs_root___181 {
	struct kernfs_node___181 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___181 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___181 {
	struct kernfs_node___181 *target_kn;
};

struct kernfs_ops___181;

struct kernfs_elem_attr___181 {
	const struct kernfs_ops___181 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___181 *notify_next;
};

struct kernfs_node___181 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___181 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___181 dir;
		struct kernfs_elem_symlink___181 symlink;
		struct kernfs_elem_attr___181 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___181;

struct kernfs_ops___181 {
	int (*open)(struct kernfs_open_file___181 *);
	void (*release)(struct kernfs_open_file___181 *);
	int (*seq_show)(struct seq_file___174 *, void *);
	void * (*seq_start)(struct seq_file___174 *, loff_t *);
	void * (*seq_next)(struct seq_file___174 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___174 *, void *);
	ssize_t (*read)(struct kernfs_open_file___181 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___181 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___181 *, struct vm_area_struct___186 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___181 *, struct poll_table_struct___125 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___181 {
	int (*remount_fs)(struct kernfs_root___181 *, int *, char *);
	int (*show_options)(struct seq_file___174 *, struct kernfs_root___181 *);
	int (*mkdir)(struct kernfs_node___181 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___181 *);
	int (*rename)(struct kernfs_node___181 *, struct kernfs_node___181 *, const char *);
	int (*show_path)(struct seq_file___174 *, struct kernfs_node___181 *, struct kernfs_root___181 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___181 {
	struct kernfs_node___181 *kn;
	struct file___186 *file;
	struct seq_file___174 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___183 *vm_ops;
};

struct sysfs_ops___178 {
	ssize_t (*show)(struct kobject___179 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___179 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___178;

struct kset___178 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___179 kobj;
	const struct kset_uevent_ops___178 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___178 {
	void (*release)(struct kobject___179 *);
	const struct sysfs_ops___178 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___11 * (*child_ns_type)(struct kobject___179 *);
	const void * (*namespace)(struct kobject___179 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___178 {
	int (* const filter)(struct kset___178 *, struct kobject___179 *);
	const char * (* const name)(struct kset___178 *, struct kobject___179 *);
	int (* const uevent)(struct kset___178 *, struct kobject___179 *, struct kobj_uevent_env *);
};

struct kobj_attribute___179 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___179 *, struct kobj_attribute___179 *, char *);
	ssize_t (*store)(struct kobject___179 *, struct kobj_attribute___179 *, const char *, size_t);
};

struct kernel_param_ops___154 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___154 *);
	int (*get)(char *, const struct kernel_param___154 *);
	void (*free)(void *);
};

struct kparam_array___154;

struct kernel_param___154 {
	const char *name;
	struct module___157 *mod;
	const struct kernel_param_ops___154 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___154 *arr;
	};
};

struct kparam_array___154 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___154 *ops;
	void *elem;
};

struct module_attribute___154 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___154 *, struct module_kobject___154 *, char *);
	ssize_t (*store)(struct module_attribute___154 *, struct module_kobject___154 *, const char *, size_t);
	void (*setup)(struct module___157 *, const char *);
	int (*test)(struct module___157 *);
	void (*free)(struct module___157 *);
};

struct mount___5;

struct mnt_namespace___5 {
	atomic_t count;
	struct ns_common___11 ns;
	struct mount___5 *root;
	struct list_head list;
	struct user_namespace___163 *user_ns;
	struct ucounts___163 *ucounts;
	u64 seq;
	wait_queue_head_t poll;
	u64 event;
	unsigned int mounts;
	unsigned int pending_mounts;
};

struct key_restriction___180;

struct key___180 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___186 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___180 *restrict_link;
};

struct ucounts___163 {
	struct hlist_node node;
	struct user_namespace___163 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct seq_operations___172 {
	void * (*start)(struct seq_file___174 *, loff_t *);
	void (*stop)(struct seq_file___174 *, void *);
	void * (*next)(struct seq_file___174 *, void *, loff_t *);
	int (*show)(struct seq_file___174 *, void *);
};

struct fsnotify_group___3;

struct fsnotify_iter_info___3;

struct fsnotify_mark___3;

struct fsnotify_event___3;

struct fsnotify_ops___3 {
	int (*handle_event)(struct fsnotify_group___3 *, struct inode___186 *, u32, const void *, int, const unsigned char *, u32, struct fsnotify_iter_info___3 *);
	void (*free_group_priv)(struct fsnotify_group___3 *);
	void (*freeing_mark)(struct fsnotify_mark___3 *, struct fsnotify_group___3 *);
	void (*free_event)(struct fsnotify_event___3 *);
	void (*free_mark)(struct fsnotify_mark___3 *);
};

struct inotify_group_private_data___3 {
	spinlock_t idr_lock;
	struct idr idr;
	struct ucounts___163 *ucounts;
};

struct fanotify_group_private_data___3 {
	struct list_head access_list;
	wait_queue_head_t access_waitq;
	int flags;
	int f_flags;
	unsigned int max_marks;
	struct user_struct___180 *user;
};

struct fsnotify_group___3 {
	const struct fsnotify_ops___3 *ops;
	refcount_t refcnt;
	spinlock_t notification_lock;
	struct list_head notification_list;
	wait_queue_head_t notification_waitq;
	unsigned int q_len;
	unsigned int max_events;
	unsigned int priority;
	bool shutdown;
	struct mutex mark_mutex;
	atomic_t num_marks;
	atomic_t user_waits;
	struct list_head marks_list;
	struct fasync_struct___185 *fsn_fa;
	struct fsnotify_event___3 *overflow_event;
	struct mem_cgroup___2 *memcg;
	union {
		void *private;
		struct inotify_group_private_data___3 inotify_data;
		struct fanotify_group_private_data___3 fanotify_data;
	};
};

struct fsnotify_iter_info___3 {
	struct fsnotify_mark___3 *marks[2];
	unsigned int report_mask;
	int srcu_idx;
};

struct fsnotify_mark___3 {
	__u32 mask;
	refcount_t refcnt;
	struct fsnotify_group___3 *group;
	struct list_head g_list;
	spinlock_t lock;
	struct hlist_node obj_list;
	struct fsnotify_mark_connector *connector;
	__u32 ignored_mask;
	unsigned int flags;
};

struct fsnotify_event___3 {
	struct list_head list;
	struct inode___186 *inode;
	u32 mask;
};

typedef int (*key_restrict_link_func_t___180)(struct key___180 *, const struct key_type *, const union key_payload *, struct key___180 *);

struct key_restriction___180 {
	key_restrict_link_func_t___180 check;
	struct key___180 *key;
	struct key_type *keytype;
};

typedef void compound_page_dtor___183(struct page___186 *);

struct mountpoint___5;

struct mount___5 {
	struct hlist_node mnt_hash;
	struct mount___5 *mnt_parent;
	struct dentry___185 *mnt_mountpoint;
	struct vfsmount___34 mnt;
	union {
		struct callback_head mnt_rcu;
		struct llist_node mnt_llist;
	};
	struct mnt_pcp *mnt_pcp;
	struct list_head mnt_mounts;
	struct list_head mnt_child;
	struct list_head mnt_instance;
	const char *mnt_devname;
	struct list_head mnt_list;
	struct list_head mnt_expire;
	struct list_head mnt_share;
	struct list_head mnt_slave_list;
	struct list_head mnt_slave;
	struct mount___5 *mnt_master;
	struct mnt_namespace___5 *mnt_ns;
	struct mountpoint___5 *mnt_mp;
	struct hlist_node mnt_mp_list;
	struct list_head mnt_umounting;
	struct fsnotify_mark_connector *mnt_fsnotify_marks;
	__u32 mnt_fsnotify_mask;
	int mnt_id;
	int mnt_group_id;
	int mnt_expiry_mark;
	struct hlist_head mnt_pins;
	struct fs_pin mnt_umount;
	struct dentry___185 *mnt_ex_mountpoint;
};

struct mountpoint___5 {
	struct hlist_node m_hash;
	struct dentry___185 *m_dentry;
	struct hlist_head m_list;
	int m_count;
};

struct module___158;

struct file___187;

struct kiocb___187;

struct poll_table_struct___126;

struct vm_area_struct___187;

struct inode___187;

struct file_lock___187;

struct page___187;

struct seq_file___175;

struct file_operations___187 {
	struct module___158 *owner;
	loff_t (*llseek)(struct file___187 *, loff_t, int);
	ssize_t (*read)(struct file___187 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___187 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___187 *, struct iov_iter___89 *);
	ssize_t (*write_iter)(struct kiocb___187 *, struct iov_iter___89 *);
	int (*iopoll)(struct kiocb___187 *, bool);
	int (*iterate)(struct file___187 *, struct dir_context *);
	int (*iterate_shared)(struct file___187 *, struct dir_context *);
	__poll_t (*poll)(struct file___187 *, struct poll_table_struct___126 *);
	long int (*unlocked_ioctl)(struct file___187 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___187 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___187 *, struct vm_area_struct___187 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___187 *, struct file___187 *);
	int (*flush)(struct file___187 *, fl_owner_t);
	int (*release)(struct inode___187 *, struct file___187 *);
	int (*fsync)(struct file___187 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___187 *, int);
	int (*lock)(struct file___187 *, int, struct file_lock___187 *);
	ssize_t (*sendpage)(struct file___187 *, struct page___187 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___187 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___187 *, int, struct file_lock___187 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___187 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___187 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___187 *, long int, struct file_lock___187 **, void **);
	long int (*fallocate)(struct file___187 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___175 *, struct file___187 *);
	ssize_t (*copy_file_range)(struct file___187 *, loff_t, struct file___187 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___187 *, loff_t, struct file___187 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___187 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___186 {
	u64 seqnum;
	struct vm_area_struct___187 *vmas[4];
};

struct page_frag___186 {
	struct page___187 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___186;

struct pid___147;

struct cred___181;

struct nsproxy___177;

struct signal_struct___163;

struct task_struct___187 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___187 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___186 *mm;
	struct mm_struct___186 *active_mm;
	struct vmacache___186 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___187 *real_parent;
	struct task_struct___187 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___187 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___147 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___147 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___147 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___181 *ptracer_cred;
	const struct cred___181 *real_cred;
	const struct cred___181 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___177 *nsproxy;
	struct signal_struct___163 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___187 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___49 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___186 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___187 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___113 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___186;

struct super_block___186;

struct dentry___186 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___186 *d_parent;
	struct qstr d_name;
	struct inode___187 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___186 *d_op;
	struct super_block___186 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct rw_semaphore___187 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___187 *owner;
};

struct address_space_operations___186;

struct address_space___186 {
	struct inode___187 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___187 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___186 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___186;

struct block_device___187;

struct inode___187 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___186 *i_op;
	struct super_block___186 *i_sb;
	struct address_space___186 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___187 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___187 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___186 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___187 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vfsmount___35;

struct path___186;

struct dentry_operations___186 {
	int (*d_revalidate)(struct dentry___186 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___186 *, unsigned int);
	int (*d_hash)(const struct dentry___186 *, struct qstr *);
	int (*d_compare)(const struct dentry___186 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___186 *);
	int (*d_init)(struct dentry___186 *);
	void (*d_release)(struct dentry___186 *);
	void (*d_prune)(struct dentry___186 *);
	void (*d_iput)(struct dentry___186 *, struct inode___187 *);
	char * (*d_dname)(struct dentry___186 *, char *, int);
	struct vfsmount___35 * (*d_automount)(struct path___186 *);
	int (*d_manage)(const struct path___186 *, bool);
	struct dentry___186 * (*d_real)(struct dentry___186 *, const struct inode___187 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___186;

struct mem_dqinfo___186 {
	struct quota_format_type___186 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___186;

struct quota_info___186 {
	unsigned int flags;
	struct rw_semaphore___187 dqio_sem;
	struct inode___187 *files[3];
	struct mem_dqinfo___186 info[3];
	const struct quota_format_ops___186 *ops[3];
};

struct rcuwait___186 {
	struct task_struct___187 *task;
};

struct percpu_rw_semaphore___186 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___187 rw_sem;
	struct rcuwait___186 writer;
	int readers_block;
};

struct sb_writers___186 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___186 rw_sem[3];
};

struct file_system_type___186;

struct super_operations___186;

struct dquot_operations___186;

struct quotactl_ops___186;

struct user_namespace___164;

struct super_block___186 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___186 *s_type;
	const struct super_operations___186 *s_op;
	const struct dquot_operations___186 *dq_op;
	const struct quotactl_ops___186 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___186 *s_root;
	struct rw_semaphore___187 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___187 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___186 s_dquot;
	struct sb_writers___186 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___186 *s_d_op;
	int cleancache_poolid;
	struct shrinker___83 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___164 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___35 {
	struct dentry___186 *mnt_root;
	struct super_block___186 *mnt_sb;
	int mnt_flags;
};

struct path___186 {
	struct vfsmount___35 *mnt;
	struct dentry___186 *dentry;
};

struct key___181;

struct ucounts___164;

struct user_namespace___164 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___164 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___11 ns;
	long unsigned int flags;
	struct key___181 *persistent_keyring_register;
	struct rw_semaphore___187 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___164 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___187 *pgtable_t___186;

struct dev_pagemap___184;

struct page___187 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___186 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___187 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___186 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___186 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___184 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___186;

struct lruvec___186 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___186 *pgdat;
};

struct zone___186 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___186 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___186 {
	struct zone___186 *zone;
	int zone_idx;
};

struct zonelist___186 {
	struct zoneref___186 _zonerefs[25];
};

struct pglist_data___186 {
	struct zone___186 node_zones[3];
	struct zonelist___186 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___187 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___187 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___186 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___187 {
	void *stack;
	struct task_struct___187 *task;
	long int status;
};

struct blocking_notifier_head___186 {
	struct rw_semaphore___187 rwsem;
	struct notifier_block *head;
};

struct pid_namespace___147;

struct upid___147 {
	int nr;
	struct pid_namespace___147 *ns;
};

struct pid_namespace___147 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___187 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___147 *parent;
	struct vfsmount___35 *proc_mnt;
	struct dentry___186 *proc_self;
	struct dentry___186 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___164 *user_ns;
	struct ucounts___164 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___11 ns;
};

struct pid___147 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___147 numbers[1];
};

struct vm_operations_struct___184;

struct vm_area_struct___187 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___187 *vm_next;
	struct vm_area_struct___187 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___186 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___184 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___187 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___186;

struct mm_struct___186 {
	struct {
		struct vm_area_struct___187 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___187 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___187 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___186 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___187 *owner;
		struct user_namespace___164 *user_ns;
		struct file___187 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___186 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___184)(struct vm_area_struct___187 *, long unsigned int, const struct page___187 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___184)(struct page___187 *, void *);

struct dev_pagemap___184 {
	dev_page_fault_t___184 page_fault;
	dev_page_free_t___184 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___6 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct fown_struct___147 {
	rwlock_t lock;
	struct pid___147 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___187 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___186 f_path;
	struct inode___187 *f_inode;
	const struct file_operations___187 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___147 f_owner;
	const struct cred___181 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___186 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___184;

struct vm_operations_struct___184 {
	void (*open)(struct vm_area_struct___187 *);
	void (*close)(struct vm_area_struct___187 *);
	int (*split)(struct vm_area_struct___187 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___187 *);
	vm_fault_t (*fault)(struct vm_fault___184 *);
	vm_fault_t (*huge_fault)(struct vm_fault___184 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___184 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___187 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___184 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___184 *);
	int (*access)(struct vm_area_struct___187 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___187 *);
	int (*set_policy)(struct vm_area_struct___187 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___187 *, long unsigned int);
	struct page___187 * (*find_special_page)(struct vm_area_struct___187 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___186 {
	struct task_struct___187 *task;
	struct core_thread___186 *next;
};

struct core_state___186 {
	atomic_t nr_threads;
	struct core_thread___186 dumper;
	struct completion startup;
};

struct vm_fault___184 {
	struct vm_area_struct___187 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___187 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___187 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___186 prealloc_pte;
};

struct user_struct___181 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___181 *uid_keyring;
	struct key___181 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___181 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___181 *session_keyring;
	struct key___181 *process_keyring;
	struct key___181 *thread_keyring;
	struct key___181 *request_key_auth;
	void *security;
	struct user_struct___181 *user;
	struct user_namespace___164 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct mnt_namespace___6;

struct nsproxy___177 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace___6 *mnt_ns;
	struct pid_namespace___147 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct signal_struct___163 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___187 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___187 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___147 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___147 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___186 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___147 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

union thread_union___165 {
	struct task_struct___187 task;
	long unsigned int stack[8192];
};

struct kiocb___187 {
	struct file___187 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___187 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___186 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___187 *ia_file;
};

struct dquot___186 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___186 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___186 {
	int qf_fmt_id;
	const struct quota_format_ops___186 *qf_ops;
	struct module___158 *qf_owner;
	struct quota_format_type___186 *qf_next;
};

struct quota_format_ops___186 {
	int (*check_quota_file)(struct super_block___186 *, int);
	int (*read_file_info)(struct super_block___186 *, int);
	int (*write_file_info)(struct super_block___186 *, int);
	int (*free_file_info)(struct super_block___186 *, int);
	int (*read_dqblk)(struct dquot___186 *);
	int (*commit_dqblk)(struct dquot___186 *);
	int (*release_dqblk)(struct dquot___186 *);
	int (*get_next_id)(struct super_block___186 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___186 {
	int (*write_dquot)(struct dquot___186 *);
	struct dquot___186 * (*alloc_dquot)(struct super_block___186 *, int);
	void (*destroy_dquot)(struct dquot___186 *);
	int (*acquire_dquot)(struct dquot___186 *);
	int (*release_dquot)(struct dquot___186 *);
	int (*mark_dirty)(struct dquot___186 *);
	int (*write_info)(struct super_block___186 *, int);
	qsize_t * (*get_reserved_space)(struct inode___187 *);
	int (*get_projid)(struct inode___187 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___187 *, qsize_t *);
	int (*get_next_id)(struct super_block___186 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___186 {
	int (*quota_on)(struct super_block___186 *, int, int, const struct path___186 *);
	int (*quota_off)(struct super_block___186 *, int);
	int (*quota_enable)(struct super_block___186 *, unsigned int);
	int (*quota_disable)(struct super_block___186 *, unsigned int);
	int (*quota_sync)(struct super_block___186 *, int);
	int (*set_info)(struct super_block___186 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___186 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___186 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___186 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___186 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___186 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___179;

struct kobj_type___179;

struct kernfs_node___182;

struct kobject___180 {
	const char *name;
	struct list_head entry;
	struct kobject___180 *parent;
	struct kset___179 *kset;
	struct kobj_type___179 *ktype;
	struct kernfs_node___182 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___155 {
	struct kobject___180 kobj;
	struct module___158 *mod;
	struct kobject___180 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___155 {
	struct module___158 *mod;
	struct latch_tree_node node;
};

struct module_layout___155 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___155 mtn;
};

struct module_attribute___155;

struct kernel_param___155;

struct module___158 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___155 mkobj;
	struct module_attribute___155 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___180 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___155 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___155 core_layout;
	struct module_layout___155 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___186 {
	int (*writepage)(struct page___187 *, struct writeback_control___3 *);
	int (*readpage)(struct file___187 *, struct page___187 *);
	int (*writepages)(struct address_space___186 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___187 *);
	int (*readpages)(struct file___187 *, struct address_space___186 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___187 *, struct address_space___186 *, loff_t, unsigned int, unsigned int, struct page___187 **, void **);
	int (*write_end)(struct file___187 *, struct address_space___186 *, loff_t, unsigned int, unsigned int, struct page___187 *, void *);
	sector_t (*bmap)(struct address_space___186 *, sector_t);
	void (*invalidatepage)(struct page___187 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___187 *, gfp_t);
	void (*freepage)(struct page___187 *);
	ssize_t (*direct_IO)(struct kiocb___187 *, struct iov_iter___89 *);
	int (*migratepage)(struct address_space___186 *, struct page___187 *, struct page___187 *, enum migrate_mode);
	bool (*isolate_page)(struct page___187 *, isolate_mode_t);
	void (*putback_page)(struct page___187 *);
	int (*launder_page)(struct page___187 *);
	int (*is_partially_uptodate)(struct page___187 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___187 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___186 *, struct page___187 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___187 *, sector_t *);
	void (*swap_deactivate)(struct file___187 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___187 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___187 *bd_inode;
	struct super_block___186 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___187 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___186 {
	struct dentry___186 * (*lookup)(struct inode___187 *, struct dentry___186 *, unsigned int);
	const char * (*get_link)(struct dentry___186 *, struct inode___187 *, struct delayed_call *);
	int (*permission)(struct inode___187 *, int);
	struct posix_acl * (*get_acl)(struct inode___187 *, int);
	int (*readlink)(struct dentry___186 *, char *, int);
	int (*create)(struct inode___187 *, struct dentry___186 *, umode_t, bool);
	int (*link)(struct dentry___186 *, struct inode___187 *, struct dentry___186 *);
	int (*unlink)(struct inode___187 *, struct dentry___186 *);
	int (*symlink)(struct inode___187 *, struct dentry___186 *, const char *);
	int (*mkdir)(struct inode___187 *, struct dentry___186 *, umode_t);
	int (*rmdir)(struct inode___187 *, struct dentry___186 *);
	int (*mknod)(struct inode___187 *, struct dentry___186 *, umode_t, dev_t);
	int (*rename)(struct inode___187 *, struct dentry___186 *, struct inode___187 *, struct dentry___186 *, unsigned int);
	int (*setattr)(struct dentry___186 *, struct iattr___186 *);
	int (*getattr)(const struct path___186 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___186 *, char *, size_t);
	int (*fiemap)(struct inode___187 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___187 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___187 *, struct dentry___186 *, struct file___187 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___187 *, struct dentry___186 *, umode_t);
	int (*set_acl)(struct inode___187 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___186 {
	void (*fl_copy_lock)(struct file_lock___187 *, struct file_lock___187 *);
	void (*fl_release_private)(struct file_lock___187 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___186;

struct lock_manager_operations___186;

struct file_lock___187 {
	struct file_lock___187 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___187 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___186 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___186 *fl_ops;
	const struct lock_manager_operations___186 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___186 {
	int (*lm_compare_owner)(struct file_lock___187 *, struct file_lock___187 *);
	long unsigned int (*lm_owner_key)(struct file_lock___187 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___187 *);
	int (*lm_grant)(struct file_lock___187 *, int);
	bool (*lm_break)(struct file_lock___187 *);
	int (*lm_change)(struct file_lock___187 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___187 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___186 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___186 *fa_next;
	struct file___187 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___186 {
	const char *name;
	int fs_flags;
	struct dentry___186 * (*mount)(struct file_system_type___186 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___186 *);
	struct module___158 *owner;
	struct file_system_type___186 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___186 {
	struct inode___187 * (*alloc_inode)(struct super_block___186 *);
	void (*destroy_inode)(struct inode___187 *);
	void (*dirty_inode)(struct inode___187 *, int);
	int (*write_inode)(struct inode___187 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___187 *);
	void (*evict_inode)(struct inode___187 *);
	void (*put_super)(struct super_block___186 *);
	int (*sync_fs)(struct super_block___186 *, int);
	int (*freeze_super)(struct super_block___186 *);
	int (*freeze_fs)(struct super_block___186 *);
	int (*thaw_super)(struct super_block___186 *);
	int (*unfreeze_fs)(struct super_block___186 *);
	int (*statfs)(struct dentry___186 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___186 *, int *, char *);
	void (*umount_begin)(struct super_block___186 *);
	int (*show_options)(struct seq_file___175 *, struct dentry___186 *);
	int (*show_devname)(struct seq_file___175 *, struct dentry___186 *);
	int (*show_path)(struct seq_file___175 *, struct dentry___186 *);
	int (*show_stats)(struct seq_file___175 *, struct dentry___186 *);
	ssize_t (*quota_read)(struct super_block___186 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___186 *, int, const char *, size_t, loff_t);
	struct dquot___186 ** (*get_dquots)(struct inode___187 *);
	int (*bdev_try_to_free_page)(struct super_block___186 *, struct page___187 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___186 *, struct shrink_control___83 *);
	long int (*free_cached_objects)(struct super_block___186 *, struct shrink_control___83 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___127)(struct file___187 *, wait_queue_head_t *, struct poll_table_struct___126 *);

struct poll_table_struct___126 {
	poll_queue_proc___127 _qproc;
	__poll_t _key;
};

struct seq_operations___173;

struct seq_file___175 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___173 *op;
	int poll_event;
	const struct file___187 *file;
	void *private;
};

struct kernfs_root___182;

struct kernfs_elem_dir___182 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___182 *root;
};

struct kernfs_syscall_ops___182;

struct kernfs_root___182 {
	struct kernfs_node___182 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___182 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___182 {
	struct kernfs_node___182 *target_kn;
};

struct kernfs_ops___182;

struct kernfs_elem_attr___182 {
	const struct kernfs_ops___182 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___182 *notify_next;
};

struct kernfs_node___182 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___182 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___182 dir;
		struct kernfs_elem_symlink___182 symlink;
		struct kernfs_elem_attr___182 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___182;

struct kernfs_ops___182 {
	int (*open)(struct kernfs_open_file___182 *);
	void (*release)(struct kernfs_open_file___182 *);
	int (*seq_show)(struct seq_file___175 *, void *);
	void * (*seq_start)(struct seq_file___175 *, loff_t *);
	void * (*seq_next)(struct seq_file___175 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___175 *, void *);
	ssize_t (*read)(struct kernfs_open_file___182 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___182 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___182 *, struct vm_area_struct___187 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___182 *, struct poll_table_struct___126 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___182 {
	int (*remount_fs)(struct kernfs_root___182 *, int *, char *);
	int (*show_options)(struct seq_file___175 *, struct kernfs_root___182 *);
	int (*mkdir)(struct kernfs_node___182 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___182 *);
	int (*rename)(struct kernfs_node___182 *, struct kernfs_node___182 *, const char *);
	int (*show_path)(struct seq_file___175 *, struct kernfs_node___182 *, struct kernfs_root___182 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___182 {
	struct kernfs_node___182 *kn;
	struct file___187 *file;
	struct seq_file___175 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___184 *vm_ops;
};

struct sysfs_ops___179 {
	ssize_t (*show)(struct kobject___180 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___180 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___179;

struct kset___179 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___180 kobj;
	const struct kset_uevent_ops___179 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___179 {
	void (*release)(struct kobject___180 *);
	const struct sysfs_ops___179 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___11 * (*child_ns_type)(struct kobject___180 *);
	const void * (*namespace)(struct kobject___180 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___179 {
	int (* const filter)(struct kset___179 *, struct kobject___180 *);
	const char * (* const name)(struct kset___179 *, struct kobject___180 *);
	int (* const uevent)(struct kset___179 *, struct kobject___180 *, struct kobj_uevent_env *);
};

struct kobj_attribute___180 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___180 *, struct kobj_attribute___180 *, char *);
	ssize_t (*store)(struct kobject___180 *, struct kobj_attribute___180 *, const char *, size_t);
};

struct kernel_param_ops___155 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___155 *);
	int (*get)(char *, const struct kernel_param___155 *);
	void (*free)(void *);
};

struct kparam_array___155;

struct kernel_param___155 {
	const char *name;
	struct module___158 *mod;
	const struct kernel_param_ops___155 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___155 *arr;
	};
};

struct kparam_array___155 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___155 *ops;
	void *elem;
};

struct module_attribute___155 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___155 *, struct module_kobject___155 *, char *);
	ssize_t (*store)(struct module_attribute___155 *, struct module_kobject___155 *, const char *, size_t);
	void (*setup)(struct module___158 *, const char *);
	int (*test)(struct module___158 *);
	void (*free)(struct module___158 *);
};

struct mount___6;

struct mnt_namespace___6 {
	atomic_t count;
	struct ns_common___11 ns;
	struct mount___6 *root;
	struct list_head list;
	struct user_namespace___164 *user_ns;
	struct ucounts___164 *ucounts;
	u64 seq;
	wait_queue_head_t poll;
	u64 event;
	unsigned int mounts;
	unsigned int pending_mounts;
};

struct key_restriction___181;

struct key___181 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___187 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___181 *restrict_link;
};

struct ucounts___164 {
	struct hlist_node node;
	struct user_namespace___164 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct seq_operations___173 {
	void * (*start)(struct seq_file___175 *, loff_t *);
	void (*stop)(struct seq_file___175 *, void *);
	void * (*next)(struct seq_file___175 *, void *, loff_t *);
	int (*show)(struct seq_file___175 *, void *);
};

struct fsnotify_group___4;

struct fsnotify_iter_info___4;

struct fsnotify_mark___4;

struct fsnotify_event___4;

struct fsnotify_ops___4 {
	int (*handle_event)(struct fsnotify_group___4 *, struct inode___187 *, u32, const void *, int, const unsigned char *, u32, struct fsnotify_iter_info___4 *);
	void (*free_group_priv)(struct fsnotify_group___4 *);
	void (*freeing_mark)(struct fsnotify_mark___4 *, struct fsnotify_group___4 *);
	void (*free_event)(struct fsnotify_event___4 *);
	void (*free_mark)(struct fsnotify_mark___4 *);
};

struct inotify_group_private_data___4 {
	spinlock_t idr_lock;
	struct idr idr;
	struct ucounts___164 *ucounts;
};

struct fanotify_group_private_data___4 {
	struct list_head access_list;
	wait_queue_head_t access_waitq;
	int flags;
	int f_flags;
	unsigned int max_marks;
	struct user_struct___181 *user;
};

struct fsnotify_group___4 {
	const struct fsnotify_ops___4 *ops;
	refcount_t refcnt;
	spinlock_t notification_lock;
	struct list_head notification_list;
	wait_queue_head_t notification_waitq;
	unsigned int q_len;
	unsigned int max_events;
	unsigned int priority;
	bool shutdown;
	struct mutex mark_mutex;
	atomic_t num_marks;
	atomic_t user_waits;
	struct list_head marks_list;
	struct fasync_struct___186 *fsn_fa;
	struct fsnotify_event___4 *overflow_event;
	struct mem_cgroup___2 *memcg;
	union {
		void *private;
		struct inotify_group_private_data___4 inotify_data;
		struct fanotify_group_private_data___4 fanotify_data;
	};
};

struct fsnotify_iter_info___4 {
	struct fsnotify_mark___4 *marks[2];
	unsigned int report_mask;
	int srcu_idx;
};

struct fsnotify_mark___4 {
	__u32 mask;
	refcount_t refcnt;
	struct fsnotify_group___4 *group;
	struct list_head g_list;
	spinlock_t lock;
	struct hlist_node obj_list;
	struct fsnotify_mark_connector *connector;
	__u32 ignored_mask;
	unsigned int flags;
};

struct fsnotify_event___4 {
	struct list_head list;
	struct inode___187 *inode;
	u32 mask;
};

typedef int (*key_restrict_link_func_t___181)(struct key___181 *, const struct key_type *, const union key_payload *, struct key___181 *);

struct key_restriction___181 {
	key_restrict_link_func_t___181 check;
	struct key___181 *key;
	struct key_type *keytype;
};

typedef void compound_page_dtor___184(struct page___187 *);

struct mountpoint___6;

struct mount___6 {
	struct hlist_node mnt_hash;
	struct mount___6 *mnt_parent;
	struct dentry___186 *mnt_mountpoint;
	struct vfsmount___35 mnt;
	union {
		struct callback_head mnt_rcu;
		struct llist_node mnt_llist;
	};
	struct mnt_pcp *mnt_pcp;
	struct list_head mnt_mounts;
	struct list_head mnt_child;
	struct list_head mnt_instance;
	const char *mnt_devname;
	struct list_head mnt_list;
	struct list_head mnt_expire;
	struct list_head mnt_share;
	struct list_head mnt_slave_list;
	struct list_head mnt_slave;
	struct mount___6 *mnt_master;
	struct mnt_namespace___6 *mnt_ns;
	struct mountpoint___6 *mnt_mp;
	struct hlist_node mnt_mp_list;
	struct list_head mnt_umounting;
	struct fsnotify_mark_connector *mnt_fsnotify_marks;
	__u32 mnt_fsnotify_mask;
	int mnt_id;
	int mnt_group_id;
	int mnt_expiry_mark;
	struct hlist_head mnt_pins;
	struct fs_pin mnt_umount;
	struct dentry___186 *mnt_ex_mountpoint;
};

struct mountpoint___6 {
	struct hlist_node m_hash;
	struct dentry___186 *m_dentry;
	struct hlist_head m_list;
	int m_count;
};

struct file___188;

struct kiocb___188;

struct iov_iter___90;

struct poll_table_struct___127;

struct vm_area_struct___188;

struct inode___188;

struct file_lock___188;

struct page___188;

struct seq_file___176;

struct file_operations___188 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___188 *, loff_t, int);
	ssize_t (*read)(struct file___188 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___188 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___188 *, struct iov_iter___90 *);
	ssize_t (*write_iter)(struct kiocb___188 *, struct iov_iter___90 *);
	int (*iopoll)(struct kiocb___188 *, bool);
	int (*iterate)(struct file___188 *, struct dir_context *);
	int (*iterate_shared)(struct file___188 *, struct dir_context *);
	__poll_t (*poll)(struct file___188 *, struct poll_table_struct___127 *);
	long int (*unlocked_ioctl)(struct file___188 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___188 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___188 *, struct vm_area_struct___188 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___188 *, struct file___188 *);
	int (*flush)(struct file___188 *, fl_owner_t);
	int (*release)(struct inode___188 *, struct file___188 *);
	int (*fsync)(struct file___188 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___188 *, int);
	int (*lock)(struct file___188 *, int, struct file_lock___188 *);
	ssize_t (*sendpage)(struct file___188 *, struct page___188 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___188 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___188 *, int, struct file_lock___188 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___188 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___188 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___188 *, long int, struct file_lock___188 **, void **);
	long int (*fallocate)(struct file___188 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___176 *, struct file___188 *);
	ssize_t (*copy_file_range)(struct file___188 *, loff_t, struct file___188 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___188 *, loff_t, struct file___188 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___188 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___187 {
	u64 seqnum;
	struct vm_area_struct___188 *vmas[4];
};

struct page_frag___187 {
	struct page___188 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___187;

struct mem_cgroup___84;

struct pid___148;

struct cred___182;

struct nsproxy___178;

struct signal_struct___164;

struct bio_list___94;

struct backing_dev_info___94;

struct css_set___158;

struct task_struct___188 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___188 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___187 *mm;
	struct mm_struct___187 *active_mm;
	struct vmacache___187 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___188 *real_parent;
	struct task_struct___188 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___188 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___84 *active_memcg;
	long int rh_reserved2;
	struct pid___148 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___148 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___148 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___182 *ptracer_cred;
	const struct cred___182 *real_cred;
	const struct cred___182 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___178 *nsproxy;
	struct signal_struct___164 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___188 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___94 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___94 *backing_dev_info;
	struct io_context___49 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___158 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___187 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___84 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___188 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___113 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___188 *pgtable_t___187;

struct address_space___187;

struct dev_pagemap___185;

struct page___188 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___187 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___188 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___187 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___187 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___185 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___84 *mem_cgroup;
};

struct pglist_data___187;

struct lruvec___187 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___187 *pgdat;
};

struct zone___187 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___187 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___187 {
	struct zone___187 *zone;
	int zone_idx;
};

struct zonelist___187 {
	struct zoneref___187 _zonerefs[25];
};

struct pglist_data___187 {
	struct zone___187 node_zones[3];
	struct zonelist___187 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___188 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___188 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___187 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___188 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___188 *owner;
};

struct secondary_data___188 {
	void *stack;
	struct task_struct___188 *task;
	long int status;
};

struct blocking_notifier_head___187 {
	struct rw_semaphore___188 rwsem;
	struct notifier_block *head;
};

struct cgroup___158;

struct cgroup_subsys___158;

struct cgroup_subsys_state___159 {
	struct cgroup___158 *cgroup;
	struct cgroup_subsys___158 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___159 *parent;
};

struct kernfs_node___183;

struct cgroup_file___158 {
	struct kernfs_node___183 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___84;

struct mem_cgroup___84 {
	struct cgroup_subsys_state___159 css;
	struct mem_cgroup_id___6 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___158 events_file;
	struct cgroup_file___158 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___188 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___84 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___148;

struct upid___148 {
	int nr;
	struct pid_namespace___148 *ns;
};

struct vfsmount___36;

struct dentry___187;

struct user_namespace___165;

struct ucounts___165;

struct pid_namespace___148 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___188 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___148 *parent;
	struct vfsmount___36 *proc_mnt;
	struct dentry___187 *proc_self;
	struct dentry___187 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___165 *user_ns;
	struct ucounts___165 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___11 ns;
};

struct pid___148 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___148 numbers[1];
};

struct key___182;

struct user_namespace___165 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___165 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___11 ns;
	long unsigned int flags;
	struct key___182 *persistent_keyring_register;
	struct rw_semaphore___188 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___165 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct user_struct___182 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___182 *uid_keyring;
	struct key___182 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___185;

struct vm_area_struct___188 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___188 *vm_next;
	struct vm_area_struct___188 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___187 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___185 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___188 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___187;

struct mm_struct___187 {
	struct {
		struct vm_area_struct___188 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___188 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___188 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___187 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___188 *owner;
		struct user_namespace___165 *user_ns;
		struct file___188 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___187 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___182 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___182 *session_keyring;
	struct key___182 *process_keyring;
	struct key___182 *thread_keyring;
	struct key___182 *request_key_auth;
	void *security;
	struct user_struct___182 *user;
	struct user_namespace___165 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct mnt_namespace___7;

struct cgroup_namespace___158;

struct nsproxy___178 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace___7 *mnt_ns;
	struct pid_namespace___148 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___158 *cgroup_ns;
};

struct signal_struct___164 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___188 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___188 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___148 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___148 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___187 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___148 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___94;

struct bio_list___94 {
	struct bio___94 *head;
	struct bio___94 *tail;
};

struct bdi_writeback_congested___94;

struct bdi_writeback___94 {
	struct backing_dev_info___94 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___94 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___159 *memcg_css;
	struct cgroup_subsys_state___159 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___94 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___94 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___6 *dev;
	struct device___6 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___187 *debug_dir;
	struct dentry___187 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___158 {
	struct cgroup_subsys_state___159 *subsys[13];
	refcount_t refcount;
	struct css_set___158 *dom_cset;
	struct cgroup___158 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___158 *mg_src_cgrp;
	struct cgroup___158 *mg_dst_cgrp;
	struct css_set___158 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

union thread_union___166 {
	struct task_struct___188 task;
	long unsigned int stack[8192];
};

struct dentry_operations___187;

struct super_block___187;

struct dentry___187 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___187 *d_parent;
	struct qstr d_name;
	struct inode___188 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___187 *d_op;
	struct super_block___187 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___187;

struct address_space___187 {
	struct inode___188 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___188 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___187 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___187;

struct block_device___188;

struct inode___188 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___187 *i_op;
	struct super_block___187 *i_sb;
	struct address_space___187 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___188 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___94 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___188 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___187 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___188 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___187;

struct dentry_operations___187 {
	int (*d_revalidate)(struct dentry___187 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___187 *, unsigned int);
	int (*d_hash)(const struct dentry___187 *, struct qstr *);
	int (*d_compare)(const struct dentry___187 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___187 *);
	int (*d_init)(struct dentry___187 *);
	void (*d_release)(struct dentry___187 *);
	void (*d_prune)(struct dentry___187 *);
	void (*d_iput)(struct dentry___187 *, struct inode___188 *);
	char * (*d_dname)(struct dentry___187 *, char *, int);
	struct vfsmount___36 * (*d_automount)(struct path___187 *);
	int (*d_manage)(const struct path___187 *, bool);
	struct dentry___187 * (*d_real)(struct dentry___187 *, const struct inode___188 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___187;

struct mem_dqinfo___187 {
	struct quota_format_type___187 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___187;

struct quota_info___187 {
	unsigned int flags;
	struct rw_semaphore___188 dqio_sem;
	struct inode___188 *files[3];
	struct mem_dqinfo___187 info[3];
	const struct quota_format_ops___187 *ops[3];
};

struct rcuwait___187 {
	struct task_struct___188 *task;
};

struct percpu_rw_semaphore___187 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___188 rw_sem;
	struct rcuwait___187 writer;
	int readers_block;
};

struct sb_writers___187 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___187 rw_sem[3];
};

struct shrink_control___84;

struct shrinker___84 {
	long unsigned int (*count_objects)(struct shrinker___84 *, struct shrink_control___84 *);
	long unsigned int (*scan_objects)(struct shrinker___84 *, struct shrink_control___84 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___187;

struct super_operations___187;

struct dquot_operations___187;

struct quotactl_ops___187;

struct super_block___187 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___187 *s_type;
	const struct super_operations___187 *s_op;
	const struct dquot_operations___187 *dq_op;
	const struct quotactl_ops___187 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___187 *s_root;
	struct rw_semaphore___188 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___188 *s_bdev;
	struct backing_dev_info___94 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___187 s_dquot;
	struct sb_writers___187 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___187 *s_d_op;
	int cleancache_poolid;
	struct shrinker___84 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___165 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___36 {
	struct dentry___187 *mnt_root;
	struct super_block___187 *mnt_sb;
	int mnt_flags;
};

struct path___187 {
	struct vfsmount___36 *mnt;
	struct dentry___187 *dentry;
};

struct shrink_control___84 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___84 *memcg;
};

typedef int (*dev_page_fault_t___185)(struct vm_area_struct___188 *, long unsigned int, const struct page___188 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___185)(struct page___188 *, void *);

struct dev_pagemap___185 {
	dev_page_fault_t___185 page_fault;
	dev_page_free_t___185 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___6 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct fown_struct___148 {
	rwlock_t lock;
	struct pid___148 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___188 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___187 f_path;
	struct inode___188 *f_inode;
	const struct file_operations___188 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___148 f_owner;
	const struct cred___182 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___187 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___185;

struct vm_operations_struct___185 {
	void (*open)(struct vm_area_struct___188 *);
	void (*close)(struct vm_area_struct___188 *);
	int (*split)(struct vm_area_struct___188 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___188 *);
	vm_fault_t (*fault)(struct vm_fault___185 *);
	vm_fault_t (*huge_fault)(struct vm_fault___185 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___185 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___188 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___185 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___185 *);
	int (*access)(struct vm_area_struct___188 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___188 *);
	int (*set_policy)(struct vm_area_struct___188 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___188 *, long unsigned int);
	struct page___188 * (*find_special_page)(struct vm_area_struct___188 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___187 {
	struct task_struct___188 *task;
	struct core_thread___187 *next;
};

struct core_state___187 {
	atomic_t nr_threads;
	struct core_thread___187 dumper;
	struct completion startup;
};

struct vm_fault___185 {
	struct vm_area_struct___188 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___188 *cow_page;
	struct mem_cgroup___84 *memcg;
	struct page___188 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___187 prealloc_pte;
};

struct kiocb___188 {
	struct file___188 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___188 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___187 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___188 *ia_file;
};

struct dquot___187 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___187 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___187 {
	int qf_fmt_id;
	const struct quota_format_ops___187 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___187 *qf_next;
};

struct quota_format_ops___187 {
	int (*check_quota_file)(struct super_block___187 *, int);
	int (*read_file_info)(struct super_block___187 *, int);
	int (*write_file_info)(struct super_block___187 *, int);
	int (*free_file_info)(struct super_block___187 *, int);
	int (*read_dqblk)(struct dquot___187 *);
	int (*commit_dqblk)(struct dquot___187 *);
	int (*release_dqblk)(struct dquot___187 *);
	int (*get_next_id)(struct super_block___187 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___187 {
	int (*write_dquot)(struct dquot___187 *);
	struct dquot___187 * (*alloc_dquot)(struct super_block___187 *, int);
	void (*destroy_dquot)(struct dquot___187 *);
	int (*acquire_dquot)(struct dquot___187 *);
	int (*release_dquot)(struct dquot___187 *);
	int (*mark_dirty)(struct dquot___187 *);
	int (*write_info)(struct super_block___187 *, int);
	qsize_t * (*get_reserved_space)(struct inode___188 *);
	int (*get_projid)(struct inode___188 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___188 *, qsize_t *);
	int (*get_next_id)(struct super_block___187 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___187 {
	int (*quota_on)(struct super_block___187 *, int, int, const struct path___187 *);
	int (*quota_off)(struct super_block___187 *, int);
	int (*quota_enable)(struct super_block___187 *, unsigned int);
	int (*quota_disable)(struct super_block___187 *, unsigned int);
	int (*quota_sync)(struct super_block___187 *, int);
	int (*set_info)(struct super_block___187 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___187 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___187 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___187 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___187 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___187 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___90;

struct address_space_operations___187 {
	int (*writepage)(struct page___188 *, struct writeback_control___90 *);
	int (*readpage)(struct file___188 *, struct page___188 *);
	int (*writepages)(struct address_space___187 *, struct writeback_control___90 *);
	int (*set_page_dirty)(struct page___188 *);
	int (*readpages)(struct file___188 *, struct address_space___187 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___188 *, struct address_space___187 *, loff_t, unsigned int, unsigned int, struct page___188 **, void **);
	int (*write_end)(struct file___188 *, struct address_space___187 *, loff_t, unsigned int, unsigned int, struct page___188 *, void *);
	sector_t (*bmap)(struct address_space___187 *, sector_t);
	void (*invalidatepage)(struct page___188 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___188 *, gfp_t);
	void (*freepage)(struct page___188 *);
	ssize_t (*direct_IO)(struct kiocb___188 *, struct iov_iter___90 *);
	int (*migratepage)(struct address_space___187 *, struct page___188 *, struct page___188 *, enum migrate_mode);
	bool (*isolate_page)(struct page___188 *, isolate_mode_t);
	void (*putback_page)(struct page___188 *);
	int (*launder_page)(struct page___188 *);
	int (*is_partially_uptodate)(struct page___188 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___188 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___187 *, struct page___188 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___188 *, sector_t *);
	void (*swap_deactivate)(struct file___188 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___90 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___94 *wb;
	struct inode___188 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___94;

struct iov_iter___90 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___94 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___188 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___188 *bd_inode;
	struct super_block___187 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___188 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___94 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___187 {
	struct dentry___187 * (*lookup)(struct inode___188 *, struct dentry___187 *, unsigned int);
	const char * (*get_link)(struct dentry___187 *, struct inode___188 *, struct delayed_call *);
	int (*permission)(struct inode___188 *, int);
	struct posix_acl * (*get_acl)(struct inode___188 *, int);
	int (*readlink)(struct dentry___187 *, char *, int);
	int (*create)(struct inode___188 *, struct dentry___187 *, umode_t, bool);
	int (*link)(struct dentry___187 *, struct inode___188 *, struct dentry___187 *);
	int (*unlink)(struct inode___188 *, struct dentry___187 *);
	int (*symlink)(struct inode___188 *, struct dentry___187 *, const char *);
	int (*mkdir)(struct inode___188 *, struct dentry___187 *, umode_t);
	int (*rmdir)(struct inode___188 *, struct dentry___187 *);
	int (*mknod)(struct inode___188 *, struct dentry___187 *, umode_t, dev_t);
	int (*rename)(struct inode___188 *, struct dentry___187 *, struct inode___188 *, struct dentry___187 *, unsigned int);
	int (*setattr)(struct dentry___187 *, struct iattr___187 *);
	int (*getattr)(const struct path___187 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___187 *, char *, size_t);
	int (*fiemap)(struct inode___188 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___188 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___188 *, struct dentry___187 *, struct file___188 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___188 *, struct dentry___187 *, umode_t);
	int (*set_acl)(struct inode___188 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___187 {
	void (*fl_copy_lock)(struct file_lock___188 *, struct file_lock___188 *);
	void (*fl_release_private)(struct file_lock___188 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___187;

struct lock_manager_operations___187;

struct file_lock___188 {
	struct file_lock___188 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___188 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___187 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___187 *fl_ops;
	const struct lock_manager_operations___187 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___187 {
	int (*lm_compare_owner)(struct file_lock___188 *, struct file_lock___188 *);
	long unsigned int (*lm_owner_key)(struct file_lock___188 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___188 *);
	int (*lm_grant)(struct file_lock___188 *, int);
	bool (*lm_break)(struct file_lock___188 *);
	int (*lm_change)(struct file_lock___188 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___188 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___187 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___187 *fa_next;
	struct file___188 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___187 {
	const char *name;
	int fs_flags;
	struct dentry___187 * (*mount)(struct file_system_type___187 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___187 *);
	struct module___11 *owner;
	struct file_system_type___187 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___187 {
	struct inode___188 * (*alloc_inode)(struct super_block___187 *);
	void (*destroy_inode)(struct inode___188 *);
	void (*dirty_inode)(struct inode___188 *, int);
	int (*write_inode)(struct inode___188 *, struct writeback_control___90 *);
	int (*drop_inode)(struct inode___188 *);
	void (*evict_inode)(struct inode___188 *);
	void (*put_super)(struct super_block___187 *);
	int (*sync_fs)(struct super_block___187 *, int);
	int (*freeze_super)(struct super_block___187 *);
	int (*freeze_fs)(struct super_block___187 *);
	int (*thaw_super)(struct super_block___187 *);
	int (*unfreeze_fs)(struct super_block___187 *);
	int (*statfs)(struct dentry___187 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___187 *, int *, char *);
	void (*umount_begin)(struct super_block___187 *);
	int (*show_options)(struct seq_file___176 *, struct dentry___187 *);
	int (*show_devname)(struct seq_file___176 *, struct dentry___187 *);
	int (*show_path)(struct seq_file___176 *, struct dentry___187 *);
	int (*show_stats)(struct seq_file___176 *, struct dentry___187 *);
	ssize_t (*quota_read)(struct super_block___187 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___187 *, int, const char *, size_t, loff_t);
	struct dquot___187 ** (*get_dquots)(struct inode___188 *);
	int (*bdev_try_to_free_page)(struct super_block___187 *, struct page___188 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___187 *, struct shrink_control___84 *);
	long int (*free_cached_objects)(struct super_block___187 *, struct shrink_control___84 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___128)(struct file___188 *, wait_queue_head_t *, struct poll_table_struct___127 *);

struct poll_table_struct___127 {
	poll_queue_proc___128 _qproc;
	__poll_t _key;
};

struct seq_operations___174;

struct seq_file___176 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___174 *op;
	int poll_event;
	const struct file___188 *file;
	void *private;
};

typedef void bio_end_io_t___94(struct bio___94 *);

struct bio_vec___94 {
	struct page___188 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___94;

struct bio_set___94;

struct bio___94 {
	struct bio___94 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___94 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___94 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___94 *bi_io_vec;
	struct bio_set___94 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___94 bi_inline_vecs[0];
};

typedef int (*key_restrict_link_func_t___182)(struct key___182 *, const struct key_type *, const union key_payload *, struct key___182 *);

struct key_restriction___182;

struct key___182 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___188 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___182 *restrict_link;
};

struct key_restriction___182 {
	key_restrict_link_func_t___182 check;
	struct key___182 *key;
	struct key_type *keytype;
};

struct seq_operations___174 {
	void * (*start)(struct seq_file___176 *, loff_t *);
	void (*stop)(struct seq_file___176 *, void *);
	void * (*next)(struct seq_file___176 *, void *, loff_t *);
	int (*show)(struct seq_file___176 *, void *);
};

struct kernfs_root___183;

struct kernfs_elem_dir___183 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___183 *root;
};

struct kernfs_syscall_ops___183;

struct kernfs_root___183 {
	struct kernfs_node___183 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___183 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___183 {
	struct kernfs_node___183 *target_kn;
};

struct kernfs_ops___183;

struct kernfs_elem_attr___183 {
	const struct kernfs_ops___183 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___183 *notify_next;
};

struct kernfs_node___183 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___183 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___183 dir;
		struct kernfs_elem_symlink___183 symlink;
		struct kernfs_elem_attr___183 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___183;

struct kernfs_ops___183 {
	int (*open)(struct kernfs_open_file___183 *);
	void (*release)(struct kernfs_open_file___183 *);
	int (*seq_show)(struct seq_file___176 *, void *);
	void * (*seq_start)(struct seq_file___176 *, loff_t *);
	void * (*seq_next)(struct seq_file___176 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___176 *, void *);
	ssize_t (*read)(struct kernfs_open_file___183 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___183 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___183 *, struct vm_area_struct___188 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___183 *, struct poll_table_struct___127 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___183 {
	int (*remount_fs)(struct kernfs_root___183 *, int *, char *);
	int (*show_options)(struct seq_file___176 *, struct kernfs_root___183 *);
	int (*mkdir)(struct kernfs_node___183 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___183 *);
	int (*rename)(struct kernfs_node___183 *, struct kernfs_node___183 *, const char *);
	int (*show_path)(struct seq_file___176 *, struct kernfs_node___183 *, struct kernfs_root___183 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___183 {
	struct kernfs_node___183 *kn;
	struct file___188 *file;
	struct seq_file___176 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___185 *vm_ops;
};

struct mount___7;

struct mnt_namespace___7 {
	atomic_t count;
	struct ns_common___11 ns;
	struct mount___7 *root;
	struct list_head list;
	struct user_namespace___165 *user_ns;
	struct ucounts___165 *ucounts;
	u64 seq;
	wait_queue_head_t poll;
	u64 event;
	unsigned int mounts;
	unsigned int pending_mounts;
};

struct cgroup_namespace___158 {
	refcount_t count;
	struct ns_common___11 ns;
	struct user_namespace___165 *user_ns;
	struct ucounts___165 *ucounts;
	struct css_set___158 *root_cset;
};

struct ucounts___165 {
	struct hlist_node node;
	struct user_namespace___165 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___158;

struct bpf_map_ops___158 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___158 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___158 *, struct file___188 *);
	void (*map_free)(struct bpf_map___158 *);
	int (*map_get_next_key)(struct bpf_map___158 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___158 *);
	void * (*map_lookup_elem)(struct bpf_map___158 *, void *);
	int (*map_update_elem)(struct bpf_map___158 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___158 *, void *);
	int (*map_push_elem)(struct bpf_map___158 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___158 *, void *);
	int (*map_peek_elem)(struct bpf_map___158 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___158 *, struct file___188 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___158 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___158 *, void *, struct seq_file___176 *);
	int (*map_check_btf)(const struct bpf_map___158 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___158 {
	const struct bpf_map_ops___158 *ops;
	struct bpf_map___158 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___182 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___158;

typedef void (*kthread_work_func_t___158)(struct kthread_work___158 *);

struct kthread_worker___158;

struct kthread_work___158 {
	struct list_head node;
	kthread_work_func_t___158 func;
	struct kthread_worker___158 *worker;
	int canceling;
};

struct kthread_worker___158 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___188 *task;
	struct kthread_work___158 *current_work;
};

struct kthread_delayed_work___158 {
	struct kthread_work___158 work;
	struct timer_list timer;
};

struct psi_group___158 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___158 *poll_kworker;
	struct kthread_delayed_work___158 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___158;

struct cgroup_rstat_cpu___158;

struct cgroup___158 {
	struct cgroup_subsys_state___159 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___183 *kn;
	struct cgroup_file___158 procs_file;
	struct cgroup_file___158 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___159 *subsys[13];
	struct cgroup_root___158 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___158 *dom_cgrp;
	struct cgroup_rstat_cpu___158 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___21 bpf;
	atomic_t congestion_count;
	struct cgroup___158 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___158 psi;
	int ancestor_ids[0];
};

struct cftype___158;

struct cgroup_subsys___158 {
	struct cgroup_subsys_state___159 * (*css_alloc)(struct cgroup_subsys_state___159 *);
	int (*css_online)(struct cgroup_subsys_state___159 *);
	void (*css_offline)(struct cgroup_subsys_state___159 *);
	void (*css_released)(struct cgroup_subsys_state___159 *);
	void (*css_free)(struct cgroup_subsys_state___159 *);
	void (*css_reset)(struct cgroup_subsys_state___159 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___159 *, int);
	int (*css_extra_stat_show)(struct seq_file___176 *, struct cgroup_subsys_state___159 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___188 *);
	void (*cancel_fork)(struct task_struct___188 *);
	void (*fork)(struct task_struct___188 *);
	void (*exit)(struct task_struct___188 *);
	void (*free)(struct task_struct___188 *);
	void (*bind)(struct cgroup_subsys_state___159 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___158 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___158 *dfl_cftypes;
	struct cftype___158 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___158 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___158 *updated_children;
	struct cgroup___158 *updated_next;
};

struct cgroup_root___158 {
	struct kernfs_root___183 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___158 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___158 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___158 *ss;
	struct list_head node;
	struct kernfs_ops___183 *kf_ops;
	int (*open)(struct kernfs_open_file___183 *);
	void (*release)(struct kernfs_open_file___183 *);
	u64 (*read_u64)(struct cgroup_subsys_state___159 *, struct cftype___158 *);
	s64 (*read_s64)(struct cgroup_subsys_state___159 *, struct cftype___158 *);
	int (*seq_show)(struct seq_file___176 *, void *);
	void * (*seq_start)(struct seq_file___176 *, loff_t *);
	void * (*seq_next)(struct seq_file___176 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___176 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___159 *, struct cftype___158 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___159 *, struct cftype___158 *, s64);
	ssize_t (*write)(struct kernfs_open_file___183 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___183 *, struct poll_table_struct___127 *);
};

typedef void compound_page_dtor___185(struct page___188 *);

struct bdi_writeback_congested___94 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___94 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___94 {
	struct bio___94 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___94 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___94 bip_inline_vecs[0];
};

struct bio_set___94 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___94 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___84 {
	struct mem_cgroup___84 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___84 {
	struct lruvec___187 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___84 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___84 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct fsnotify_group___5;

struct fsnotify_iter_info___5;

struct fsnotify_mark___5;

struct fsnotify_event___5;

struct fsnotify_ops___5 {
	int (*handle_event)(struct fsnotify_group___5 *, struct inode___188 *, u32, const void *, int, const unsigned char *, u32, struct fsnotify_iter_info___5 *);
	void (*free_group_priv)(struct fsnotify_group___5 *);
	void (*freeing_mark)(struct fsnotify_mark___5 *, struct fsnotify_group___5 *);
	void (*free_event)(struct fsnotify_event___5 *);
	void (*free_mark)(struct fsnotify_mark___5 *);
};

struct inotify_group_private_data___5 {
	spinlock_t idr_lock;
	struct idr idr;
	struct ucounts___165 *ucounts;
};

struct fanotify_group_private_data___5 {
	struct list_head access_list;
	wait_queue_head_t access_waitq;
	int flags;
	int f_flags;
	unsigned int max_marks;
	struct user_struct___182 *user;
};

struct fsnotify_group___5 {
	const struct fsnotify_ops___5 *ops;
	refcount_t refcnt;
	spinlock_t notification_lock;
	struct list_head notification_list;
	wait_queue_head_t notification_waitq;
	unsigned int q_len;
	unsigned int max_events;
	unsigned int priority;
	bool shutdown;
	struct mutex mark_mutex;
	atomic_t num_marks;
	atomic_t user_waits;
	struct list_head marks_list;
	struct fasync_struct___187 *fsn_fa;
	struct fsnotify_event___5 *overflow_event;
	struct mem_cgroup___84 *memcg;
	union {
		void *private;
		struct inotify_group_private_data___5 inotify_data;
		struct fanotify_group_private_data___5 fanotify_data;
	};
};

struct fsnotify_iter_info___5 {
	struct fsnotify_mark___5 *marks[2];
	unsigned int report_mask;
	int srcu_idx;
};

struct fsnotify_mark___5 {
	__u32 mask;
	refcount_t refcnt;
	struct fsnotify_group___5 *group;
	struct list_head g_list;
	spinlock_t lock;
	struct hlist_node obj_list;
	struct fsnotify_mark_connector *connector;
	__u32 ignored_mask;
	unsigned int flags;
};

struct fsnotify_event___5 {
	struct list_head list;
	struct inode___188 *inode;
	u32 mask;
};

struct mountpoint___7;

struct mount___7 {
	struct hlist_node mnt_hash;
	struct mount___7 *mnt_parent;
	struct dentry___187 *mnt_mountpoint;
	struct vfsmount___36 mnt;
	union {
		struct callback_head mnt_rcu;
		struct llist_node mnt_llist;
	};
	struct mnt_pcp *mnt_pcp;
	struct list_head mnt_mounts;
	struct list_head mnt_child;
	struct list_head mnt_instance;
	const char *mnt_devname;
	struct list_head mnt_list;
	struct list_head mnt_expire;
	struct list_head mnt_share;
	struct list_head mnt_slave_list;
	struct list_head mnt_slave;
	struct mount___7 *mnt_master;
	struct mnt_namespace___7 *mnt_ns;
	struct mountpoint___7 *mnt_mp;
	struct hlist_node mnt_mp_list;
	struct list_head mnt_umounting;
	struct fsnotify_mark_connector *mnt_fsnotify_marks;
	__u32 mnt_fsnotify_mask;
	int mnt_id;
	int mnt_group_id;
	int mnt_expiry_mark;
	struct hlist_head mnt_pins;
	struct fs_pin mnt_umount;
	struct dentry___187 *mnt_ex_mountpoint;
};

struct mountpoint___7 {
	struct hlist_node m_hash;
	struct dentry___187 *m_dentry;
	struct hlist_head m_list;
	int m_count;
};

struct vfsmount___37;

struct dentry___188;

struct path___188 {
	struct vfsmount___37 *mnt;
	struct dentry___188 *dentry;
};

struct pid___149;

struct fown_struct___149 {
	rwlock_t lock;
	struct pid___149 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct inode___189;

struct file_operations___189;

struct cred___183;

struct address_space___188;

struct file___189 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___188 f_path;
	struct inode___189 *f_inode;
	const struct file_operations___189 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___149 f_owner;
	const struct cred___183 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___188 *f_mapping;
	errseq_t f_wb_err;
};

struct kiocb___189;

struct poll_table_struct___128;

struct vm_area_struct___189;

struct file_lock___189;

struct page___189;

struct seq_file___177;

struct file_operations___189 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___189 *, loff_t, int);
	ssize_t (*read)(struct file___189 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___189 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___189 *, struct iov_iter___90 *);
	ssize_t (*write_iter)(struct kiocb___189 *, struct iov_iter___90 *);
	int (*iopoll)(struct kiocb___189 *, bool);
	int (*iterate)(struct file___189 *, struct dir_context *);
	int (*iterate_shared)(struct file___189 *, struct dir_context *);
	__poll_t (*poll)(struct file___189 *, struct poll_table_struct___128 *);
	long int (*unlocked_ioctl)(struct file___189 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___189 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___189 *, struct vm_area_struct___189 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___189 *, struct file___189 *);
	int (*flush)(struct file___189 *, fl_owner_t);
	int (*release)(struct inode___189 *, struct file___189 *);
	int (*fsync)(struct file___189 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___189 *, int);
	int (*lock)(struct file___189 *, int, struct file_lock___189 *);
	ssize_t (*sendpage)(struct file___189 *, struct page___189 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___189 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___189 *, int, struct file_lock___189 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___189 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___189 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___189 *, long int, struct file_lock___189 **, void **);
	long int (*fallocate)(struct file___189 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___177 *, struct file___189 *);
	ssize_t (*copy_file_range)(struct file___189 *, loff_t, struct file___189 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___189 *, loff_t, struct file___189 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___189 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___188 {
	u64 seqnum;
	struct vm_area_struct___189 *vmas[4];
};

struct page_frag___188 {
	struct page___189 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___188;

struct nsproxy___179;

struct signal_struct___165;

struct task_struct___189 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___189 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___188 *mm;
	struct mm_struct___188 *active_mm;
	struct vmacache___188 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___189 *real_parent;
	struct task_struct___189 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___189 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___149 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___149 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___149 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___183 *ptracer_cred;
	const struct cred___183 *real_cred;
	const struct cred___183 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___179 *nsproxy;
	struct signal_struct___165 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___189 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___49 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___188 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___189 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___113 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___188;

struct super_block___188;

struct dentry___188 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___188 *d_parent;
	struct qstr d_name;
	struct inode___189 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___188 *d_op;
	struct super_block___188 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct rw_semaphore___189 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___189 *owner;
};

struct address_space_operations___188;

struct address_space___188 {
	struct inode___189 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___189 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___188 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___188;

struct block_device___189;

struct inode___189 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___188 *i_op;
	struct super_block___188 *i_sb;
	struct address_space___188 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___189 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___189 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___188 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___189 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___188 {
	int (*d_revalidate)(struct dentry___188 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___188 *, unsigned int);
	int (*d_hash)(const struct dentry___188 *, struct qstr *);
	int (*d_compare)(const struct dentry___188 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___188 *);
	int (*d_init)(struct dentry___188 *);
	void (*d_release)(struct dentry___188 *);
	void (*d_prune)(struct dentry___188 *);
	void (*d_iput)(struct dentry___188 *, struct inode___189 *);
	char * (*d_dname)(struct dentry___188 *, char *, int);
	struct vfsmount___37 * (*d_automount)(struct path___188 *);
	int (*d_manage)(const struct path___188 *, bool);
	struct dentry___188 * (*d_real)(struct dentry___188 *, const struct inode___189 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___188;

struct mem_dqinfo___188 {
	struct quota_format_type___188 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___188;

struct quota_info___188 {
	unsigned int flags;
	struct rw_semaphore___189 dqio_sem;
	struct inode___189 *files[3];
	struct mem_dqinfo___188 info[3];
	const struct quota_format_ops___188 *ops[3];
};

struct rcuwait___188 {
	struct task_struct___189 *task;
};

struct percpu_rw_semaphore___188 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___189 rw_sem;
	struct rcuwait___188 writer;
	int readers_block;
};

struct sb_writers___188 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___188 rw_sem[3];
};

struct file_system_type___188;

struct super_operations___188;

struct dquot_operations___188;

struct quotactl_ops___188;

struct export_operations___8;

struct user_namespace___166;

struct super_block___188 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___188 *s_type;
	const struct super_operations___188 *s_op;
	const struct dquot_operations___188 *dq_op;
	const struct quotactl_ops___188 *s_qcop;
	const struct export_operations___8 *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___188 *s_root;
	struct rw_semaphore___189 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___189 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___188 s_dquot;
	struct sb_writers___188 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___188 *s_d_op;
	int cleancache_poolid;
	struct shrinker___84 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___166 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___37 {
	struct dentry___188 *mnt_root;
	struct super_block___188 *mnt_sb;
	int mnt_flags;
};

struct key___183;

struct ucounts___166;

struct user_namespace___166 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___166 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___11 ns;
	long unsigned int flags;
	struct key___183 *persistent_keyring_register;
	struct rw_semaphore___189 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___166 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___189 *pgtable_t___188;

struct dev_pagemap___186;

struct page___189 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___188 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___189 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___188 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___188 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___186 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___188;

struct lruvec___188 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___188 *pgdat;
};

struct zone___188 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___188 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___188 {
	struct zone___188 *zone;
	int zone_idx;
};

struct zonelist___188 {
	struct zoneref___188 _zonerefs[25];
};

struct pglist_data___188 {
	struct zone___188 node_zones[3];
	struct zonelist___188 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___189 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___189 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___188 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___189 {
	void *stack;
	struct task_struct___189 *task;
	long int status;
};

struct blocking_notifier_head___188 {
	struct rw_semaphore___189 rwsem;
	struct notifier_block *head;
};

struct pid_namespace___149;

struct upid___149 {
	int nr;
	struct pid_namespace___149 *ns;
};

struct pid_namespace___149 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___189 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___149 *parent;
	struct vfsmount___37 *proc_mnt;
	struct dentry___188 *proc_self;
	struct dentry___188 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___166 *user_ns;
	struct ucounts___166 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___11 ns;
};

struct pid___149 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___149 numbers[1];
};

struct vm_operations_struct___186;

struct vm_area_struct___189 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___189 *vm_next;
	struct vm_area_struct___189 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___188 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___186 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___189 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___188;

struct mm_struct___188 {
	struct {
		struct vm_area_struct___189 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___189 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___189 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___188 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___189 *owner;
		struct user_namespace___166 *user_ns;
		struct file___189 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___188 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___186)(struct vm_area_struct___189 *, long unsigned int, const struct page___189 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___186)(struct page___189 *, void *);

struct dev_pagemap___186 {
	dev_page_fault_t___186 page_fault;
	dev_page_free_t___186 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___6 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct vm_fault___186;

struct vm_operations_struct___186 {
	void (*open)(struct vm_area_struct___189 *);
	void (*close)(struct vm_area_struct___189 *);
	int (*split)(struct vm_area_struct___189 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___189 *);
	vm_fault_t (*fault)(struct vm_fault___186 *);
	vm_fault_t (*huge_fault)(struct vm_fault___186 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___186 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___189 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___186 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___186 *);
	int (*access)(struct vm_area_struct___189 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___189 *);
	int (*set_policy)(struct vm_area_struct___189 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___189 *, long unsigned int);
	struct page___189 * (*find_special_page)(struct vm_area_struct___189 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___188 {
	struct task_struct___189 *task;
	struct core_thread___188 *next;
};

struct core_state___188 {
	atomic_t nr_threads;
	struct core_thread___188 dumper;
	struct completion startup;
};

struct vm_fault___186 {
	struct vm_area_struct___189 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___189 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___189 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___188 prealloc_pte;
};

struct user_struct___183 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___183 *uid_keyring;
	struct key___183 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___183 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___183 *session_keyring;
	struct key___183 *process_keyring;
	struct key___183 *thread_keyring;
	struct key___183 *request_key_auth;
	void *security;
	struct user_struct___183 *user;
	struct user_namespace___166 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct mnt_namespace___8;

struct nsproxy___179 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace___8 *mnt_ns;
	struct pid_namespace___149 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct signal_struct___165 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___189 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___189 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___149 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___149 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___188 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___149 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

union thread_union___167 {
	struct task_struct___189 task;
	long unsigned int stack[8192];
};

struct kiocb___189 {
	struct file___189 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___189 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___188 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___189 *ia_file;
};

struct dquot___188 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___188 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___188 {
	int qf_fmt_id;
	const struct quota_format_ops___188 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___188 *qf_next;
};

struct quota_format_ops___188 {
	int (*check_quota_file)(struct super_block___188 *, int);
	int (*read_file_info)(struct super_block___188 *, int);
	int (*write_file_info)(struct super_block___188 *, int);
	int (*free_file_info)(struct super_block___188 *, int);
	int (*read_dqblk)(struct dquot___188 *);
	int (*commit_dqblk)(struct dquot___188 *);
	int (*release_dqblk)(struct dquot___188 *);
	int (*get_next_id)(struct super_block___188 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___188 {
	int (*write_dquot)(struct dquot___188 *);
	struct dquot___188 * (*alloc_dquot)(struct super_block___188 *, int);
	void (*destroy_dquot)(struct dquot___188 *);
	int (*acquire_dquot)(struct dquot___188 *);
	int (*release_dquot)(struct dquot___188 *);
	int (*mark_dirty)(struct dquot___188 *);
	int (*write_info)(struct super_block___188 *, int);
	qsize_t * (*get_reserved_space)(struct inode___189 *);
	int (*get_projid)(struct inode___189 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___189 *, qsize_t *);
	int (*get_next_id)(struct super_block___188 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___188 {
	int (*quota_on)(struct super_block___188 *, int, int, const struct path___188 *);
	int (*quota_off)(struct super_block___188 *, int);
	int (*quota_enable)(struct super_block___188 *, unsigned int);
	int (*quota_disable)(struct super_block___188 *, unsigned int);
	int (*quota_sync)(struct super_block___188 *, int);
	int (*set_info)(struct super_block___188 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___188 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___188 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___188 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___188 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___188 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___188 {
	int (*writepage)(struct page___189 *, struct writeback_control___3 *);
	int (*readpage)(struct file___189 *, struct page___189 *);
	int (*writepages)(struct address_space___188 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___189 *);
	int (*readpages)(struct file___189 *, struct address_space___188 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___189 *, struct address_space___188 *, loff_t, unsigned int, unsigned int, struct page___189 **, void **);
	int (*write_end)(struct file___189 *, struct address_space___188 *, loff_t, unsigned int, unsigned int, struct page___189 *, void *);
	sector_t (*bmap)(struct address_space___188 *, sector_t);
	void (*invalidatepage)(struct page___189 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___189 *, gfp_t);
	void (*freepage)(struct page___189 *);
	ssize_t (*direct_IO)(struct kiocb___189 *, struct iov_iter___90 *);
	int (*migratepage)(struct address_space___188 *, struct page___189 *, struct page___189 *, enum migrate_mode);
	bool (*isolate_page)(struct page___189 *, isolate_mode_t);
	void (*putback_page)(struct page___189 *);
	int (*launder_page)(struct page___189 *);
	int (*is_partially_uptodate)(struct page___189 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___189 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___188 *, struct page___189 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___189 *, sector_t *);
	void (*swap_deactivate)(struct file___189 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___189 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___189 *bd_inode;
	struct super_block___188 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___189 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___188 {
	struct dentry___188 * (*lookup)(struct inode___189 *, struct dentry___188 *, unsigned int);
	const char * (*get_link)(struct dentry___188 *, struct inode___189 *, struct delayed_call *);
	int (*permission)(struct inode___189 *, int);
	struct posix_acl * (*get_acl)(struct inode___189 *, int);
	int (*readlink)(struct dentry___188 *, char *, int);
	int (*create)(struct inode___189 *, struct dentry___188 *, umode_t, bool);
	int (*link)(struct dentry___188 *, struct inode___189 *, struct dentry___188 *);
	int (*unlink)(struct inode___189 *, struct dentry___188 *);
	int (*symlink)(struct inode___189 *, struct dentry___188 *, const char *);
	int (*mkdir)(struct inode___189 *, struct dentry___188 *, umode_t);
	int (*rmdir)(struct inode___189 *, struct dentry___188 *);
	int (*mknod)(struct inode___189 *, struct dentry___188 *, umode_t, dev_t);
	int (*rename)(struct inode___189 *, struct dentry___188 *, struct inode___189 *, struct dentry___188 *, unsigned int);
	int (*setattr)(struct dentry___188 *, struct iattr___188 *);
	int (*getattr)(const struct path___188 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___188 *, char *, size_t);
	int (*fiemap)(struct inode___189 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___189 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___189 *, struct dentry___188 *, struct file___189 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___189 *, struct dentry___188 *, umode_t);
	int (*set_acl)(struct inode___189 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_handle {
	__u32 handle_bytes;
	int handle_type;
	unsigned char f_handle[0];
};

struct file_lock_operations___188 {
	void (*fl_copy_lock)(struct file_lock___189 *, struct file_lock___189 *);
	void (*fl_release_private)(struct file_lock___189 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___188;

struct lock_manager_operations___188;

struct file_lock___189 {
	struct file_lock___189 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___189 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___188 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___188 *fl_ops;
	const struct lock_manager_operations___188 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___188 {
	int (*lm_compare_owner)(struct file_lock___189 *, struct file_lock___189 *);
	long unsigned int (*lm_owner_key)(struct file_lock___189 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___189 *);
	int (*lm_grant)(struct file_lock___189 *, int);
	bool (*lm_break)(struct file_lock___189 *);
	int (*lm_change)(struct file_lock___189 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___189 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___188 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___188 *fa_next;
	struct file___189 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___188 {
	const char *name;
	int fs_flags;
	struct dentry___188 * (*mount)(struct file_system_type___188 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___188 *);
	struct module___11 *owner;
	struct file_system_type___188 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___188 {
	struct inode___189 * (*alloc_inode)(struct super_block___188 *);
	void (*destroy_inode)(struct inode___189 *);
	void (*dirty_inode)(struct inode___189 *, int);
	int (*write_inode)(struct inode___189 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___189 *);
	void (*evict_inode)(struct inode___189 *);
	void (*put_super)(struct super_block___188 *);
	int (*sync_fs)(struct super_block___188 *, int);
	int (*freeze_super)(struct super_block___188 *);
	int (*freeze_fs)(struct super_block___188 *);
	int (*thaw_super)(struct super_block___188 *);
	int (*unfreeze_fs)(struct super_block___188 *);
	int (*statfs)(struct dentry___188 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___188 *, int *, char *);
	void (*umount_begin)(struct super_block___188 *);
	int (*show_options)(struct seq_file___177 *, struct dentry___188 *);
	int (*show_devname)(struct seq_file___177 *, struct dentry___188 *);
	int (*show_path)(struct seq_file___177 *, struct dentry___188 *);
	int (*show_stats)(struct seq_file___177 *, struct dentry___188 *);
	ssize_t (*quota_read)(struct super_block___188 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___188 *, int, const char *, size_t, loff_t);
	struct dquot___188 ** (*get_dquots)(struct inode___189 *);
	int (*bdev_try_to_free_page)(struct super_block___188 *, struct page___189 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___188 *, struct shrink_control___84 *);
	long int (*free_cached_objects)(struct super_block___188 *, struct shrink_control___84 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct export_operations___8 {
	int (*encode_fh)(struct inode___189 *, __u32 *, int *, struct inode___189 *);
	struct dentry___188 * (*fh_to_dentry)(struct super_block___188 *, struct fid *, int, int);
	struct dentry___188 * (*fh_to_parent)(struct super_block___188 *, struct fid *, int, int);
	int (*get_name)(struct dentry___188 *, char *, struct dentry___188 *);
	struct dentry___188 * (*get_parent)(struct dentry___188 *);
	int (*commit_metadata)(struct inode___189 *);
	int (*get_uuid)(struct super_block___188 *, u8 *, u32 *, u64 *);
	int (*map_blocks)(struct inode___189 *, loff_t, u64, struct iomap *, bool, u32 *);
	int (*commit_blocks)(struct inode___189 *, struct iomap *, int, struct iattr___188 *);
};

typedef void (*poll_queue_proc___129)(struct file___189 *, wait_queue_head_t *, struct poll_table_struct___128 *);

struct poll_table_struct___128 {
	poll_queue_proc___129 _qproc;
	__poll_t _key;
};

struct seq_operations___175;

struct seq_file___177 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___175 *op;
	int poll_event;
	const struct file___189 *file;
	void *private;
};

struct mount___8;

struct mnt_namespace___8 {
	atomic_t count;
	struct ns_common___11 ns;
	struct mount___8 *root;
	struct list_head list;
	struct user_namespace___166 *user_ns;
	struct ucounts___166 *ucounts;
	u64 seq;
	wait_queue_head_t poll;
	u64 event;
	unsigned int mounts;
	unsigned int pending_mounts;
};

struct key_restriction___183;

struct key___183 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___189 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___183 *restrict_link;
};

struct ucounts___166 {
	struct hlist_node node;
	struct user_namespace___166 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct seq_operations___175 {
	void * (*start)(struct seq_file___177 *, loff_t *);
	void (*stop)(struct seq_file___177 *, void *);
	void * (*next)(struct seq_file___177 *, void *, loff_t *);
	int (*show)(struct seq_file___177 *, void *);
};

struct fsnotify_group___6;

struct fsnotify_iter_info___6;

struct fsnotify_mark___6;

struct fsnotify_event___6;

struct fsnotify_ops___6 {
	int (*handle_event)(struct fsnotify_group___6 *, struct inode___189 *, u32, const void *, int, const unsigned char *, u32, struct fsnotify_iter_info___6 *);
	void (*free_group_priv)(struct fsnotify_group___6 *);
	void (*freeing_mark)(struct fsnotify_mark___6 *, struct fsnotify_group___6 *);
	void (*free_event)(struct fsnotify_event___6 *);
	void (*free_mark)(struct fsnotify_mark___6 *);
};

struct inotify_group_private_data___6 {
	spinlock_t idr_lock;
	struct idr idr;
	struct ucounts___166 *ucounts;
};

struct fanotify_group_private_data___6 {
	struct list_head access_list;
	wait_queue_head_t access_waitq;
	int flags;
	int f_flags;
	unsigned int max_marks;
	struct user_struct___183 *user;
};

struct fsnotify_group___6 {
	const struct fsnotify_ops___6 *ops;
	refcount_t refcnt;
	spinlock_t notification_lock;
	struct list_head notification_list;
	wait_queue_head_t notification_waitq;
	unsigned int q_len;
	unsigned int max_events;
	unsigned int priority;
	bool shutdown;
	struct mutex mark_mutex;
	atomic_t num_marks;
	atomic_t user_waits;
	struct list_head marks_list;
	struct fasync_struct___188 *fsn_fa;
	struct fsnotify_event___6 *overflow_event;
	struct mem_cgroup___2 *memcg;
	union {
		void *private;
		struct inotify_group_private_data___6 inotify_data;
		struct fanotify_group_private_data___6 fanotify_data;
	};
};

struct fsnotify_iter_info___6 {
	struct fsnotify_mark___6 *marks[2];
	unsigned int report_mask;
	int srcu_idx;
};

struct fsnotify_mark___6 {
	__u32 mask;
	refcount_t refcnt;
	struct fsnotify_group___6 *group;
	struct list_head g_list;
	spinlock_t lock;
	struct hlist_node obj_list;
	struct fsnotify_mark_connector *connector;
	__u32 ignored_mask;
	unsigned int flags;
};

struct fsnotify_event___6 {
	struct list_head list;
	struct inode___189 *inode;
	u32 mask;
};

typedef int (*key_restrict_link_func_t___183)(struct key___183 *, const struct key_type *, const union key_payload *, struct key___183 *);

struct key_restriction___183 {
	key_restrict_link_func_t___183 check;
	struct key___183 *key;
	struct key_type *keytype;
};

struct inotify_inode_mark {
	struct fsnotify_mark___6 fsn_mark;
	int wd;
};

typedef void compound_page_dtor___186(struct page___189 *);

struct mountpoint___8;

struct mount___8 {
	struct hlist_node mnt_hash;
	struct mount___8 *mnt_parent;
	struct dentry___188 *mnt_mountpoint;
	struct vfsmount___37 mnt;
	union {
		struct callback_head mnt_rcu;
		struct llist_node mnt_llist;
	};
	struct mnt_pcp *mnt_pcp;
	struct list_head mnt_mounts;
	struct list_head mnt_child;
	struct list_head mnt_instance;
	const char *mnt_devname;
	struct list_head mnt_list;
	struct list_head mnt_expire;
	struct list_head mnt_share;
	struct list_head mnt_slave_list;
	struct list_head mnt_slave;
	struct mount___8 *mnt_master;
	struct mnt_namespace___8 *mnt_ns;
	struct mountpoint___8 *mnt_mp;
	struct hlist_node mnt_mp_list;
	struct list_head mnt_umounting;
	struct fsnotify_mark_connector *mnt_fsnotify_marks;
	__u32 mnt_fsnotify_mask;
	int mnt_id;
	int mnt_group_id;
	int mnt_expiry_mark;
	struct hlist_head mnt_pins;
	struct fs_pin mnt_umount;
	struct dentry___188 *mnt_ex_mountpoint;
};

struct mountpoint___8 {
	struct hlist_node m_hash;
	struct dentry___188 *m_dentry;
	struct hlist_head m_list;
	int m_count;
};

struct module___159;

struct file___190;

struct kiocb___190;

struct vm_area_struct___190;

struct inode___190;

struct file_lock___190;

struct page___190;

struct file_operations___190 {
	struct module___159 *owner;
	loff_t (*llseek)(struct file___190 *, loff_t, int);
	ssize_t (*read)(struct file___190 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___190 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___190 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___190 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___190 *, bool);
	int (*iterate)(struct file___190 *, struct dir_context *);
	int (*iterate_shared)(struct file___190 *, struct dir_context *);
	__poll_t (*poll)(struct file___190 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___190 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___190 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___190 *, struct vm_area_struct___190 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___190 *, struct file___190 *);
	int (*flush)(struct file___190 *, fl_owner_t);
	int (*release)(struct inode___190 *, struct file___190 *);
	int (*fsync)(struct file___190 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___190 *, int);
	int (*lock)(struct file___190 *, int, struct file_lock___190 *);
	ssize_t (*sendpage)(struct file___190 *, struct page___190 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___190 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___190 *, int, struct file_lock___190 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___190 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___190 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___190 *, long int, struct file_lock___190 **, void **);
	long int (*fallocate)(struct file___190 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___190 *);
	ssize_t (*copy_file_range)(struct file___190 *, loff_t, struct file___190 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___190 *, loff_t, struct file___190 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___190 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___189 {
	u64 seqnum;
	struct vm_area_struct___190 *vmas[4];
};

struct page_frag___189 {
	struct page___190 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___189;

struct cred___184;

struct files_struct___11;

struct signal_struct___166;

struct task_struct___190 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___190 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___189 *mm;
	struct mm_struct___189 *active_mm;
	struct vmacache___189 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___190 *real_parent;
	struct task_struct___190 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___190 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___149 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___149 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___149 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___184 *ptracer_cred;
	const struct cred___184 *real_cred;
	const struct cred___184 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct___11 *files;
	struct nsproxy___179 *nsproxy;
	struct signal_struct___166 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___190 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___49 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___189 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___190 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___113 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___189;

struct super_block___189;

struct dentry___189 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___189 *d_parent;
	struct qstr d_name;
	struct inode___190 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___189 *d_op;
	struct super_block___189 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct rw_semaphore___190 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___190 *owner;
};

struct address_space_operations___189;

struct address_space___189 {
	struct inode___190 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___190 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___189 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___189;

struct block_device___190;

struct inode___190 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___189 *i_op;
	struct super_block___189 *i_sb;
	struct address_space___189 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___190 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___190 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___189 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___190 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___189;

struct dentry_operations___189 {
	int (*d_revalidate)(struct dentry___189 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___189 *, unsigned int);
	int (*d_hash)(const struct dentry___189 *, struct qstr *);
	int (*d_compare)(const struct dentry___189 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___189 *);
	int (*d_init)(struct dentry___189 *);
	void (*d_release)(struct dentry___189 *);
	void (*d_prune)(struct dentry___189 *);
	void (*d_iput)(struct dentry___189 *, struct inode___190 *);
	char * (*d_dname)(struct dentry___189 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___189 *);
	int (*d_manage)(const struct path___189 *, bool);
	struct dentry___189 * (*d_real)(struct dentry___189 *, const struct inode___190 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___189;

struct mem_dqinfo___189 {
	struct quota_format_type___189 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___189;

struct quota_info___189 {
	unsigned int flags;
	struct rw_semaphore___190 dqio_sem;
	struct inode___190 *files[3];
	struct mem_dqinfo___189 info[3];
	const struct quota_format_ops___189 *ops[3];
};

struct rcuwait___189 {
	struct task_struct___190 *task;
};

struct percpu_rw_semaphore___189 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___190 rw_sem;
	struct rcuwait___189 writer;
	int readers_block;
};

struct sb_writers___189 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___189 rw_sem[3];
};

struct file_system_type___189;

struct super_operations___189;

struct dquot_operations___189;

struct quotactl_ops___189;

struct user_namespace___167;

struct super_block___189 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___189 *s_type;
	const struct super_operations___189 *s_op;
	const struct dquot_operations___189 *dq_op;
	const struct quotactl_ops___189 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___189 *s_root;
	struct rw_semaphore___190 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___190 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___189 s_dquot;
	struct sb_writers___189 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___189 *s_d_op;
	int cleancache_poolid;
	struct shrinker___84 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___167 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct path___189 {
	struct vfsmount *mnt;
	struct dentry___189 *dentry;
};

struct key___184;

struct ucounts___167;

struct user_namespace___167 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___167 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___11 ns;
	long unsigned int flags;
	struct key___184 *persistent_keyring_register;
	struct rw_semaphore___190 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___167 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___190 *pgtable_t___189;

struct page___190 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___189 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___190 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___189 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___189 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___186 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___189;

struct lruvec___189 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___189 *pgdat;
};

struct zone___189 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___189 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___189 {
	struct zone___189 *zone;
	int zone_idx;
};

struct zonelist___189 {
	struct zoneref___189 _zonerefs[25];
};

struct pglist_data___189 {
	struct zone___189 node_zones[3];
	struct zonelist___189 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___190 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___190 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___189 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___190 {
	void *stack;
	struct task_struct___190 *task;
	long int status;
};

struct blocking_notifier_head___189 {
	struct rw_semaphore___190 rwsem;
	struct notifier_block *head;
};

struct vm_area_struct___190 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___190 *vm_next;
	struct vm_area_struct___190 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___189 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___13 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___190 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___189;

struct mm_struct___189 {
	struct {
		struct vm_area_struct___190 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___190 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___190 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___189 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___190 *owner;
		struct user_namespace___167 *user_ns;
		struct file___190 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___189 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct file___190 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___189 f_path;
	struct inode___190 *f_inode;
	const struct file_operations___190 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___149 f_owner;
	const struct cred___184 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___189 *f_mapping;
	errseq_t f_wb_err;
};

struct core_thread___189 {
	struct task_struct___190 *task;
	struct core_thread___189 *next;
};

struct core_state___189 {
	atomic_t nr_threads;
	struct core_thread___189 dumper;
	struct completion startup;
};

struct user_struct___184 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___184 *uid_keyring;
	struct key___184 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___184 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___184 *session_keyring;
	struct key___184 *process_keyring;
	struct key___184 *thread_keyring;
	struct key___184 *request_key_auth;
	void *security;
	struct user_struct___184 *user;
	struct user_namespace___167 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct fdtable___11 {
	unsigned int max_fds;
	struct file___190 **fd;
	long unsigned int *close_on_exec;
	long unsigned int *open_fds;
	long unsigned int *full_fds_bits;
	struct callback_head rcu;
};

struct files_struct___11 {
	atomic_t count;
	bool resize_in_progress;
	wait_queue_head_t resize_wait;
	struct fdtable___11 *fdt;
	struct fdtable___11 fdtab;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t file_lock;
	unsigned int next_fd;
	long unsigned int close_on_exec_init[1];
	long unsigned int open_fds_init[1];
	long unsigned int full_fds_bits_init[1];
	struct file___190 *fd_array[64];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct signal_struct___166 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___190 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___190 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___149 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___149 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___189 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___149 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

union thread_union___168 {
	struct task_struct___190 task;
	long unsigned int stack[8192];
};

struct kiocb___190 {
	struct file___190 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___190 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___189 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___190 *ia_file;
};

struct dquot___189 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___189 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___189 {
	int qf_fmt_id;
	const struct quota_format_ops___189 *qf_ops;
	struct module___159 *qf_owner;
	struct quota_format_type___189 *qf_next;
};

struct quota_format_ops___189 {
	int (*check_quota_file)(struct super_block___189 *, int);
	int (*read_file_info)(struct super_block___189 *, int);
	int (*write_file_info)(struct super_block___189 *, int);
	int (*free_file_info)(struct super_block___189 *, int);
	int (*read_dqblk)(struct dquot___189 *);
	int (*commit_dqblk)(struct dquot___189 *);
	int (*release_dqblk)(struct dquot___189 *);
	int (*get_next_id)(struct super_block___189 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___189 {
	int (*write_dquot)(struct dquot___189 *);
	struct dquot___189 * (*alloc_dquot)(struct super_block___189 *, int);
	void (*destroy_dquot)(struct dquot___189 *);
	int (*acquire_dquot)(struct dquot___189 *);
	int (*release_dquot)(struct dquot___189 *);
	int (*mark_dirty)(struct dquot___189 *);
	int (*write_info)(struct super_block___189 *, int);
	qsize_t * (*get_reserved_space)(struct inode___190 *);
	int (*get_projid)(struct inode___190 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___190 *, qsize_t *);
	int (*get_next_id)(struct super_block___189 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___189 {
	int (*quota_on)(struct super_block___189 *, int, int, const struct path___189 *);
	int (*quota_off)(struct super_block___189 *, int);
	int (*quota_enable)(struct super_block___189 *, unsigned int);
	int (*quota_disable)(struct super_block___189 *, unsigned int);
	int (*quota_sync)(struct super_block___189 *, int);
	int (*set_info)(struct super_block___189 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___189 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___189 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___189 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___189 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___189 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___180;

struct kobj_type___180;

struct kernfs_node___184;

struct kobject___181 {
	const char *name;
	struct list_head entry;
	struct kobject___181 *parent;
	struct kset___180 *kset;
	struct kobj_type___180 *ktype;
	struct kernfs_node___184 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___156 {
	struct kobject___181 kobj;
	struct module___159 *mod;
	struct kobject___181 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___156 {
	struct module___159 *mod;
	struct latch_tree_node node;
};

struct module_layout___156 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___156 mtn;
};

struct module_attribute___156;

struct kernel_param___156;

struct module___159 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___156 mkobj;
	struct module_attribute___156 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___181 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___156 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___156 core_layout;
	struct module_layout___156 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___189 {
	int (*writepage)(struct page___190 *, struct writeback_control___3 *);
	int (*readpage)(struct file___190 *, struct page___190 *);
	int (*writepages)(struct address_space___189 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___190 *);
	int (*readpages)(struct file___190 *, struct address_space___189 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___190 *, struct address_space___189 *, loff_t, unsigned int, unsigned int, struct page___190 **, void **);
	int (*write_end)(struct file___190 *, struct address_space___189 *, loff_t, unsigned int, unsigned int, struct page___190 *, void *);
	sector_t (*bmap)(struct address_space___189 *, sector_t);
	void (*invalidatepage)(struct page___190 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___190 *, gfp_t);
	void (*freepage)(struct page___190 *);
	ssize_t (*direct_IO)(struct kiocb___190 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___189 *, struct page___190 *, struct page___190 *, enum migrate_mode);
	bool (*isolate_page)(struct page___190 *, isolate_mode_t);
	void (*putback_page)(struct page___190 *);
	int (*launder_page)(struct page___190 *);
	int (*is_partially_uptodate)(struct page___190 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___190 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___189 *, struct page___190 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___190 *, sector_t *);
	void (*swap_deactivate)(struct file___190 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___190 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___190 *bd_inode;
	struct super_block___189 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___190 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___189 {
	struct dentry___189 * (*lookup)(struct inode___190 *, struct dentry___189 *, unsigned int);
	const char * (*get_link)(struct dentry___189 *, struct inode___190 *, struct delayed_call *);
	int (*permission)(struct inode___190 *, int);
	struct posix_acl * (*get_acl)(struct inode___190 *, int);
	int (*readlink)(struct dentry___189 *, char *, int);
	int (*create)(struct inode___190 *, struct dentry___189 *, umode_t, bool);
	int (*link)(struct dentry___189 *, struct inode___190 *, struct dentry___189 *);
	int (*unlink)(struct inode___190 *, struct dentry___189 *);
	int (*symlink)(struct inode___190 *, struct dentry___189 *, const char *);
	int (*mkdir)(struct inode___190 *, struct dentry___189 *, umode_t);
	int (*rmdir)(struct inode___190 *, struct dentry___189 *);
	int (*mknod)(struct inode___190 *, struct dentry___189 *, umode_t, dev_t);
	int (*rename)(struct inode___190 *, struct dentry___189 *, struct inode___190 *, struct dentry___189 *, unsigned int);
	int (*setattr)(struct dentry___189 *, struct iattr___189 *);
	int (*getattr)(const struct path___189 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___189 *, char *, size_t);
	int (*fiemap)(struct inode___190 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___190 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___190 *, struct dentry___189 *, struct file___190 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___190 *, struct dentry___189 *, umode_t);
	int (*set_acl)(struct inode___190 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___189 {
	void (*fl_copy_lock)(struct file_lock___190 *, struct file_lock___190 *);
	void (*fl_release_private)(struct file_lock___190 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___189;

struct lock_manager_operations___189;

struct file_lock___190 {
	struct file_lock___190 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___190 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___189 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___189 *fl_ops;
	const struct lock_manager_operations___189 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___189 {
	int (*lm_compare_owner)(struct file_lock___190 *, struct file_lock___190 *);
	long unsigned int (*lm_owner_key)(struct file_lock___190 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___190 *);
	int (*lm_grant)(struct file_lock___190 *, int);
	bool (*lm_break)(struct file_lock___190 *);
	int (*lm_change)(struct file_lock___190 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___190 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___189 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___189 *fa_next;
	struct file___190 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___189 {
	const char *name;
	int fs_flags;
	struct dentry___189 * (*mount)(struct file_system_type___189 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___189 *);
	struct module___159 *owner;
	struct file_system_type___189 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___189 {
	struct inode___190 * (*alloc_inode)(struct super_block___189 *);
	void (*destroy_inode)(struct inode___190 *);
	void (*dirty_inode)(struct inode___190 *, int);
	int (*write_inode)(struct inode___190 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___190 *);
	void (*evict_inode)(struct inode___190 *);
	void (*put_super)(struct super_block___189 *);
	int (*sync_fs)(struct super_block___189 *, int);
	int (*freeze_super)(struct super_block___189 *);
	int (*freeze_fs)(struct super_block___189 *);
	int (*thaw_super)(struct super_block___189 *);
	int (*unfreeze_fs)(struct super_block___189 *);
	int (*statfs)(struct dentry___189 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___189 *, int *, char *);
	void (*umount_begin)(struct super_block___189 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___189 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___189 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___189 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___189 *);
	ssize_t (*quota_read)(struct super_block___189 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___189 *, int, const char *, size_t, loff_t);
	struct dquot___189 ** (*get_dquots)(struct inode___190 *);
	int (*bdev_try_to_free_page)(struct super_block___189 *, struct page___190 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___189 *, struct shrink_control___84 *);
	long int (*free_cached_objects)(struct super_block___189 *, struct shrink_control___84 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_root___184;

struct kernfs_elem_dir___184 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___184 *root;
};

struct kernfs_syscall_ops___184;

struct kernfs_root___184 {
	struct kernfs_node___184 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___184 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___184 {
	struct kernfs_node___184 *target_kn;
};

struct kernfs_ops___184;

struct kernfs_elem_attr___184 {
	const struct kernfs_ops___184 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___184 *notify_next;
};

struct kernfs_node___184 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___184 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___184 dir;
		struct kernfs_elem_symlink___184 symlink;
		struct kernfs_elem_attr___184 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___184;

struct kernfs_ops___184 {
	int (*open)(struct kernfs_open_file___184 *);
	void (*release)(struct kernfs_open_file___184 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___184 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___184 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___184 *, struct vm_area_struct___190 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___184 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___184 {
	int (*remount_fs)(struct kernfs_root___184 *, int *, char *);
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___184 *);
	int (*mkdir)(struct kernfs_node___184 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___184 *);
	int (*rename)(struct kernfs_node___184 *, struct kernfs_node___184 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___184 *, struct kernfs_root___184 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___184 {
	struct kernfs_node___184 *kn;
	struct file___190 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___13 *vm_ops;
};

struct sysfs_ops___180 {
	ssize_t (*show)(struct kobject___181 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___181 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___180;

struct kset___180 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___181 kobj;
	const struct kset_uevent_ops___180 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___180 {
	void (*release)(struct kobject___181 *);
	const struct sysfs_ops___180 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___11 * (*child_ns_type)(struct kobject___181 *);
	const void * (*namespace)(struct kobject___181 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___180 {
	int (* const filter)(struct kset___180 *, struct kobject___181 *);
	const char * (* const name)(struct kset___180 *, struct kobject___181 *);
	int (* const uevent)(struct kset___180 *, struct kobject___181 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___156 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___156 *);
	int (*get)(char *, const struct kernel_param___156 *);
	void (*free)(void *);
};

struct kparam_array___156;

struct kernel_param___156 {
	const char *name;
	struct module___159 *mod;
	const struct kernel_param_ops___156 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___156 *arr;
	};
};

struct kparam_array___156 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___156 *ops;
	void *elem;
};

struct module_attribute___156 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___156 *, struct module_kobject___156 *, char *);
	ssize_t (*store)(struct module_attribute___156 *, struct module_kobject___156 *, const char *, size_t);
	void (*setup)(struct module___159 *, const char *);
	int (*test)(struct module___159 *);
	void (*free)(struct module___159 *);
};

typedef int (*key_restrict_link_func_t___184)(struct key___184 *, const struct key_type *, const union key_payload *, struct key___184 *);

struct key_restriction___184;

struct key___184 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___190 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___184 *restrict_link;
};

struct key_restriction___184 {
	key_restrict_link_func_t___184 check;
	struct key___184 *key;
	struct key_type *keytype;
};

struct dnotify_struct {
	struct dnotify_struct *dn_next;
	__u32 dn_mask;
	int dn_fd;
	struct file___190 *dn_filp;
	fl_owner_t dn_owner;
};

struct ucounts___167 {
	struct hlist_node node;
	struct user_namespace___167 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct fsnotify_group___7;

struct fsnotify_iter_info___7;

struct fsnotify_mark___7;

struct fsnotify_event___7;

struct fsnotify_ops___7 {
	int (*handle_event)(struct fsnotify_group___7 *, struct inode___190 *, u32, const void *, int, const unsigned char *, u32, struct fsnotify_iter_info___7 *);
	void (*free_group_priv)(struct fsnotify_group___7 *);
	void (*freeing_mark)(struct fsnotify_mark___7 *, struct fsnotify_group___7 *);
	void (*free_event)(struct fsnotify_event___7 *);
	void (*free_mark)(struct fsnotify_mark___7 *);
};

struct inotify_group_private_data___7 {
	spinlock_t idr_lock;
	struct idr idr;
	struct ucounts___167 *ucounts;
};

struct fanotify_group_private_data___7 {
	struct list_head access_list;
	wait_queue_head_t access_waitq;
	int flags;
	int f_flags;
	unsigned int max_marks;
	struct user_struct___184 *user;
};

struct fsnotify_group___7 {
	const struct fsnotify_ops___7 *ops;
	refcount_t refcnt;
	spinlock_t notification_lock;
	struct list_head notification_list;
	wait_queue_head_t notification_waitq;
	unsigned int q_len;
	unsigned int max_events;
	unsigned int priority;
	bool shutdown;
	struct mutex mark_mutex;
	atomic_t num_marks;
	atomic_t user_waits;
	struct list_head marks_list;
	struct fasync_struct___189 *fsn_fa;
	struct fsnotify_event___7 *overflow_event;
	struct mem_cgroup___2 *memcg;
	union {
		void *private;
		struct inotify_group_private_data___7 inotify_data;
		struct fanotify_group_private_data___7 fanotify_data;
	};
};

struct fsnotify_iter_info___7 {
	struct fsnotify_mark___7 *marks[2];
	unsigned int report_mask;
	int srcu_idx;
};

struct fsnotify_mark___7 {
	__u32 mask;
	refcount_t refcnt;
	struct fsnotify_group___7 *group;
	struct list_head g_list;
	spinlock_t lock;
	struct hlist_node obj_list;
	struct fsnotify_mark_connector *connector;
	__u32 ignored_mask;
	unsigned int flags;
};

struct fsnotify_event___7 {
	struct list_head list;
	struct inode___190 *inode;
	u32 mask;
};

struct dnotify_mark {
	struct fsnotify_mark___7 fsn_mark;
	struct dnotify_struct *dn;
};

struct inotify_event_info {
	struct fsnotify_event___7 fse;
	int wd;
	u32 sync_cookie;
	int name_len;
	char name[0];
};

struct file___191;

struct fd___23 {
	struct file___191 *file;
	unsigned int flags;
};

struct dentry___190;

struct path___190 {
	struct vfsmount *mnt;
	struct dentry___190 *dentry;
};

struct pid___150;

struct fown_struct___150 {
	rwlock_t lock;
	struct pid___150 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct inode___191;

struct file_operations___191;

struct cred___185;

struct address_space___190;

struct file___191 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___190 f_path;
	struct inode___191 *f_inode;
	const struct file_operations___191 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___150 f_owner;
	const struct cred___185 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___190 *f_mapping;
	errseq_t f_wb_err;
};

struct module___160;

struct kiocb___191;

struct iov_iter___91;

struct poll_table_struct___129;

struct vm_area_struct___191;

struct file_lock___191;

struct page___191;

struct seq_file___178;

struct file_operations___191 {
	struct module___160 *owner;
	loff_t (*llseek)(struct file___191 *, loff_t, int);
	ssize_t (*read)(struct file___191 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___191 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___191 *, struct iov_iter___91 *);
	ssize_t (*write_iter)(struct kiocb___191 *, struct iov_iter___91 *);
	int (*iopoll)(struct kiocb___191 *, bool);
	int (*iterate)(struct file___191 *, struct dir_context *);
	int (*iterate_shared)(struct file___191 *, struct dir_context *);
	__poll_t (*poll)(struct file___191 *, struct poll_table_struct___129 *);
	long int (*unlocked_ioctl)(struct file___191 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___191 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___191 *, struct vm_area_struct___191 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___191 *, struct file___191 *);
	int (*flush)(struct file___191 *, fl_owner_t);
	int (*release)(struct inode___191 *, struct file___191 *);
	int (*fsync)(struct file___191 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___191 *, int);
	int (*lock)(struct file___191 *, int, struct file_lock___191 *);
	ssize_t (*sendpage)(struct file___191 *, struct page___191 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___191 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___191 *, int, struct file_lock___191 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___191 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___191 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___191 *, long int, struct file_lock___191 **, void **);
	long int (*fallocate)(struct file___191 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___178 *, struct file___191 *);
	ssize_t (*copy_file_range)(struct file___191 *, loff_t, struct file___191 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___191 *, loff_t, struct file___191 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___191 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___190 {
	u64 seqnum;
	struct vm_area_struct___191 *vmas[4];
};

struct page_frag___190 {
	struct page___191 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___114;

struct debug_info___114 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___114 *hbp_break[16];
	struct perf_event___114 *hbp_watch[16];
};

struct thread_struct___114 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___114 debug;
	long: 64;
};

struct mm_struct___190;

struct mem_cgroup___85;

struct nsproxy___180;

struct signal_struct___167;

struct bio_list___95;

struct backing_dev_info___95;

struct css_set___159;

struct perf_event_context___114;

struct task_struct___191 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___191 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___190 *mm;
	struct mm_struct___190 *active_mm;
	struct vmacache___190 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___191 *real_parent;
	struct task_struct___191 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___191 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___85 *active_memcg;
	long int rh_reserved2;
	struct pid___150 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___150 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___150 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___185 *ptracer_cred;
	const struct cred___185 *real_cred;
	const struct cred___185 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___180 *nsproxy;
	struct signal_struct___167 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___191 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___95 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___95 *backing_dev_info;
	struct io_context___49 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___159 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___114 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___190 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___85 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___191 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___114 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___114 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___191 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___114)(struct perf_event___114 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___114;

struct fasync_struct___190;

struct pid_namespace___150;

struct trace_event_call___107;

struct perf_cgroup___114;

struct perf_event___114 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___114 *group_leader;
	struct pmu___114 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___114 hw;
	struct perf_event_context___114 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___114 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___191 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___190 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___114 *);
	struct callback_head callback_head;
	struct pid_namespace___150 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___114 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___114 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___107 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___114 *cgrp;
	struct list_head sb_list;
};

struct dentry_operations___190;

struct super_block___190;

struct dentry___190 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___190 *d_parent;
	struct qstr d_name;
	struct inode___191 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___190 *d_op;
	struct super_block___190 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct rw_semaphore___191 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___191 *owner;
};

struct address_space_operations___190;

struct address_space___190 {
	struct inode___191 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___191 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___190 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___190;

struct bdi_writeback___95;

struct block_device___191;

struct inode___191 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___190 *i_op;
	struct super_block___190 *i_sb;
	struct address_space___190 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___191 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___95 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___191 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___190 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___191 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___190 {
	int (*d_revalidate)(struct dentry___190 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___190 *, unsigned int);
	int (*d_hash)(const struct dentry___190 *, struct qstr *);
	int (*d_compare)(const struct dentry___190 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___190 *);
	int (*d_init)(struct dentry___190 *);
	void (*d_release)(struct dentry___190 *);
	void (*d_prune)(struct dentry___190 *);
	void (*d_iput)(struct dentry___190 *, struct inode___191 *);
	char * (*d_dname)(struct dentry___190 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___190 *);
	int (*d_manage)(const struct path___190 *, bool);
	struct dentry___190 * (*d_real)(struct dentry___190 *, const struct inode___191 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___190;

struct mem_dqinfo___190 {
	struct quota_format_type___190 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___190;

struct quota_info___190 {
	unsigned int flags;
	struct rw_semaphore___191 dqio_sem;
	struct inode___191 *files[3];
	struct mem_dqinfo___190 info[3];
	const struct quota_format_ops___190 *ops[3];
};

struct rcuwait___190 {
	struct task_struct___191 *task;
};

struct percpu_rw_semaphore___190 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___191 rw_sem;
	struct rcuwait___190 writer;
	int readers_block;
};

struct sb_writers___190 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___190 rw_sem[3];
};

struct shrink_control___85;

struct shrinker___85 {
	long unsigned int (*count_objects)(struct shrinker___85 *, struct shrink_control___85 *);
	long unsigned int (*scan_objects)(struct shrinker___85 *, struct shrink_control___85 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___190;

struct super_operations___190;

struct dquot_operations___190;

struct quotactl_ops___190;

struct user_namespace___168;

struct super_block___190 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___190 *s_type;
	const struct super_operations___190 *s_op;
	const struct dquot_operations___190 *dq_op;
	const struct quotactl_ops___190 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___190 *s_root;
	struct rw_semaphore___191 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___191 *s_bdev;
	struct backing_dev_info___95 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___190 s_dquot;
	struct sb_writers___190 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___190 *s_d_op;
	int cleancache_poolid;
	struct shrinker___85 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___168 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct key___185;

struct ucounts___168;

struct user_namespace___168 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___168 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___11 ns;
	long unsigned int flags;
	struct key___185 *persistent_keyring_register;
	struct rw_semaphore___191 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___168 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct shrink_control___85 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___85 *memcg;
};

struct cgroup___159;

struct cgroup_subsys___159;

struct cgroup_subsys_state___160 {
	struct cgroup___159 *cgroup;
	struct cgroup_subsys___159 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___160 *parent;
};

struct mem_cgroup_id___20 {
	int id;
	union {
		refcount_t ref;
		struct {
			atomic_t ref;
		} __UNIQUE_ID_rh_kabi_hide37;
		union {		};
	};
};

struct kernfs_node___185;

struct cgroup_file___159 {
	struct kernfs_node___185 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___85;

struct mem_cgroup___85 {
	struct cgroup_subsys_state___160 css;
	struct mem_cgroup_id___20 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___159 events_file;
	struct cgroup_file___159 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___191 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___85 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___191 *pgtable_t___190;

struct dev_pagemap___187;

struct page___191 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___190 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___191 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___190 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___190 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___187 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___85 *mem_cgroup;
};

struct pglist_data___190;

struct lruvec___190 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___190 *pgdat;
};

struct zone___190 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___190 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___190 {
	struct zone___190 *zone;
	int zone_idx;
};

struct zonelist___190 {
	struct zoneref___190 _zonerefs[25];
};

struct pglist_data___190 {
	struct zone___190 node_zones[3];
	struct zonelist___190 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___191 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___191 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___190 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___191 {
	void *stack;
	struct task_struct___191 *task;
	long int status;
};

struct blocking_notifier_head___190 {
	struct rw_semaphore___191 rwsem;
	struct notifier_block *head;
};

struct upid___150 {
	int nr;
	struct pid_namespace___150 *ns;
};

struct pid_namespace___150 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___191 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___150 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___190 *proc_self;
	struct dentry___190 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___168 *user_ns;
	struct ucounts___168 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___11 ns;
};

struct pid___150 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___150 numbers[1];
};

struct vm_operations_struct___187;

struct vm_area_struct___191 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___191 *vm_next;
	struct vm_area_struct___191 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___190 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___187 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___191 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___190;

struct mm_struct___190 {
	struct {
		struct vm_area_struct___191 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___191 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___191 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___190 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___191 *owner;
		struct user_namespace___168 *user_ns;
		struct file___191 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___190 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___187)(struct vm_area_struct___191 *, long unsigned int, const struct page___191 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___187)(struct page___191 *, void *);

struct device___172;

struct dev_pagemap___187 {
	dev_page_fault_t___187 page_fault;
	dev_page_free_t___187 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___172 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct vm_fault___187;

struct vm_operations_struct___187 {
	void (*open)(struct vm_area_struct___191 *);
	void (*close)(struct vm_area_struct___191 *);
	int (*split)(struct vm_area_struct___191 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___191 *);
	vm_fault_t (*fault)(struct vm_fault___187 *);
	vm_fault_t (*huge_fault)(struct vm_fault___187 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___187 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___191 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___187 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___187 *);
	int (*access)(struct vm_area_struct___191 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___191 *);
	int (*set_policy)(struct vm_area_struct___191 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___191 *, long unsigned int);
	struct page___191 * (*find_special_page)(struct vm_area_struct___191 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___190 {
	struct task_struct___191 *task;
	struct core_thread___190 *next;
};

struct core_state___190 {
	atomic_t nr_threads;
	struct core_thread___190 dumper;
	struct completion startup;
};

struct vm_fault___187 {
	struct vm_area_struct___191 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___191 *cow_page;
	struct mem_cgroup___85 *memcg;
	struct page___191 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___190 prealloc_pte;
};

struct user_struct___185 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___185 *uid_keyring;
	struct key___185 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___185 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___185 *session_keyring;
	struct key___185 *process_keyring;
	struct key___185 *thread_keyring;
	struct key___185 *request_key_auth;
	void *security;
	struct user_struct___185 *user;
	struct user_namespace___168 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___159;

struct nsproxy___180 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___150 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___159 *cgroup_ns;
};

struct signal_struct___167 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___191 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___191 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___150 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___150 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___190 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___150 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___95;

struct bio_list___95 {
	struct bio___95 *head;
	struct bio___95 *tail;
};

struct bdi_writeback_congested___95;

struct bdi_writeback___95 {
	struct backing_dev_info___95 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___95 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___160 *memcg_css;
	struct cgroup_subsys_state___160 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___95 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___95 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___172 *dev;
	struct device___172 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___190 *debug_dir;
	struct dentry___190 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___159 {
	struct cgroup_subsys_state___160 *subsys[13];
	refcount_t refcount;
	struct css_set___159 *dom_cset;
	struct cgroup___159 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___159 *mg_src_cgrp;
	struct cgroup___159 *mg_dst_cgrp;
	struct css_set___159 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___114 {
	struct pmu___114 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___191 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___114 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

union thread_union___169 {
	struct task_struct___191 task;
	long unsigned int stack[8192];
};

struct kiocb___191 {
	struct file___191 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___191 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___190 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___191 *ia_file;
};

struct dquot___190 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___190 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___190 {
	int qf_fmt_id;
	const struct quota_format_ops___190 *qf_ops;
	struct module___160 *qf_owner;
	struct quota_format_type___190 *qf_next;
};

struct quota_format_ops___190 {
	int (*check_quota_file)(struct super_block___190 *, int);
	int (*read_file_info)(struct super_block___190 *, int);
	int (*write_file_info)(struct super_block___190 *, int);
	int (*free_file_info)(struct super_block___190 *, int);
	int (*read_dqblk)(struct dquot___190 *);
	int (*commit_dqblk)(struct dquot___190 *);
	int (*release_dqblk)(struct dquot___190 *);
	int (*get_next_id)(struct super_block___190 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___190 {
	int (*write_dquot)(struct dquot___190 *);
	struct dquot___190 * (*alloc_dquot)(struct super_block___190 *, int);
	void (*destroy_dquot)(struct dquot___190 *);
	int (*acquire_dquot)(struct dquot___190 *);
	int (*release_dquot)(struct dquot___190 *);
	int (*mark_dirty)(struct dquot___190 *);
	int (*write_info)(struct super_block___190 *, int);
	qsize_t * (*get_reserved_space)(struct inode___191 *);
	int (*get_projid)(struct inode___191 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___191 *, qsize_t *);
	int (*get_next_id)(struct super_block___190 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___190 {
	int (*quota_on)(struct super_block___190 *, int, int, const struct path___190 *);
	int (*quota_off)(struct super_block___190 *, int);
	int (*quota_enable)(struct super_block___190 *, unsigned int);
	int (*quota_disable)(struct super_block___190 *, unsigned int);
	int (*quota_sync)(struct super_block___190 *, int);
	int (*set_info)(struct super_block___190 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___190 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___190 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___190 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___190 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___190 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___181;

struct kobj_type___181;

struct kobject___182 {
	const char *name;
	struct list_head entry;
	struct kobject___182 *parent;
	struct kset___181 *kset;
	struct kobj_type___181 *ktype;
	struct kernfs_node___185 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___157 {
	struct kobject___182 kobj;
	struct module___160 *mod;
	struct kobject___182 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___157 {
	struct module___160 *mod;
	struct latch_tree_node node;
};

struct module_layout___157 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___157 mtn;
};

struct module_attribute___157;

struct kernel_param___157;

struct module___160 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___157 mkobj;
	struct module_attribute___157 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___182 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___157 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___157 core_layout;
	struct module_layout___157 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___107 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___91;

struct address_space_operations___190 {
	int (*writepage)(struct page___191 *, struct writeback_control___91 *);
	int (*readpage)(struct file___191 *, struct page___191 *);
	int (*writepages)(struct address_space___190 *, struct writeback_control___91 *);
	int (*set_page_dirty)(struct page___191 *);
	int (*readpages)(struct file___191 *, struct address_space___190 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___191 *, struct address_space___190 *, loff_t, unsigned int, unsigned int, struct page___191 **, void **);
	int (*write_end)(struct file___191 *, struct address_space___190 *, loff_t, unsigned int, unsigned int, struct page___191 *, void *);
	sector_t (*bmap)(struct address_space___190 *, sector_t);
	void (*invalidatepage)(struct page___191 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___191 *, gfp_t);
	void (*freepage)(struct page___191 *);
	ssize_t (*direct_IO)(struct kiocb___191 *, struct iov_iter___91 *);
	int (*migratepage)(struct address_space___190 *, struct page___191 *, struct page___191 *, enum migrate_mode);
	bool (*isolate_page)(struct page___191 *, isolate_mode_t);
	void (*putback_page)(struct page___191 *);
	int (*launder_page)(struct page___191 *);
	int (*is_partially_uptodate)(struct page___191 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___191 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___190 *, struct page___191 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___191 *, sector_t *);
	void (*swap_deactivate)(struct file___191 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___91 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___95 *wb;
	struct inode___191 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___95;

struct iov_iter___91 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___95 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___191 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___191 *bd_inode;
	struct super_block___190 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___191 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___95 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___190 {
	struct dentry___190 * (*lookup)(struct inode___191 *, struct dentry___190 *, unsigned int);
	const char * (*get_link)(struct dentry___190 *, struct inode___191 *, struct delayed_call *);
	int (*permission)(struct inode___191 *, int);
	struct posix_acl * (*get_acl)(struct inode___191 *, int);
	int (*readlink)(struct dentry___190 *, char *, int);
	int (*create)(struct inode___191 *, struct dentry___190 *, umode_t, bool);
	int (*link)(struct dentry___190 *, struct inode___191 *, struct dentry___190 *);
	int (*unlink)(struct inode___191 *, struct dentry___190 *);
	int (*symlink)(struct inode___191 *, struct dentry___190 *, const char *);
	int (*mkdir)(struct inode___191 *, struct dentry___190 *, umode_t);
	int (*rmdir)(struct inode___191 *, struct dentry___190 *);
	int (*mknod)(struct inode___191 *, struct dentry___190 *, umode_t, dev_t);
	int (*rename)(struct inode___191 *, struct dentry___190 *, struct inode___191 *, struct dentry___190 *, unsigned int);
	int (*setattr)(struct dentry___190 *, struct iattr___190 *);
	int (*getattr)(const struct path___190 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___190 *, char *, size_t);
	int (*fiemap)(struct inode___191 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___191 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___191 *, struct dentry___190 *, struct file___191 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___191 *, struct dentry___190 *, umode_t);
	int (*set_acl)(struct inode___191 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___190 {
	void (*fl_copy_lock)(struct file_lock___191 *, struct file_lock___191 *);
	void (*fl_release_private)(struct file_lock___191 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___190;

struct file_lock___191 {
	struct file_lock___191 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___191 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___190 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___190 *fl_ops;
	const struct lock_manager_operations___190 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___190 {
	int (*lm_compare_owner)(struct file_lock___191 *, struct file_lock___191 *);
	long unsigned int (*lm_owner_key)(struct file_lock___191 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___191 *);
	int (*lm_grant)(struct file_lock___191 *, int);
	bool (*lm_break)(struct file_lock___191 *);
	int (*lm_change)(struct file_lock___191 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___191 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___190 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___190 *fa_next;
	struct file___191 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___190 {
	const char *name;
	int fs_flags;
	struct dentry___190 * (*mount)(struct file_system_type___190 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___190 *);
	struct module___160 *owner;
	struct file_system_type___190 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___190 {
	struct inode___191 * (*alloc_inode)(struct super_block___190 *);
	void (*destroy_inode)(struct inode___191 *);
	void (*dirty_inode)(struct inode___191 *, int);
	int (*write_inode)(struct inode___191 *, struct writeback_control___91 *);
	int (*drop_inode)(struct inode___191 *);
	void (*evict_inode)(struct inode___191 *);
	void (*put_super)(struct super_block___190 *);
	int (*sync_fs)(struct super_block___190 *, int);
	int (*freeze_super)(struct super_block___190 *);
	int (*freeze_fs)(struct super_block___190 *);
	int (*thaw_super)(struct super_block___190 *);
	int (*unfreeze_fs)(struct super_block___190 *);
	int (*statfs)(struct dentry___190 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___190 *, int *, char *);
	void (*umount_begin)(struct super_block___190 *);
	int (*show_options)(struct seq_file___178 *, struct dentry___190 *);
	int (*show_devname)(struct seq_file___178 *, struct dentry___190 *);
	int (*show_path)(struct seq_file___178 *, struct dentry___190 *);
	int (*show_stats)(struct seq_file___178 *, struct dentry___190 *);
	ssize_t (*quota_read)(struct super_block___190 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___190 *, int, const char *, size_t, loff_t);
	struct dquot___190 ** (*get_dquots)(struct inode___191 *);
	int (*bdev_try_to_free_page)(struct super_block___190 *, struct page___191 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___190 *, struct shrink_control___85 *);
	long int (*free_cached_objects)(struct super_block___190 *, struct shrink_control___85 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___130)(struct file___191 *, wait_queue_head_t *, struct poll_table_struct___129 *);

struct poll_table_struct___129 {
	poll_queue_proc___130 _qproc;
	__poll_t _key;
};

struct seq_operations___176;

struct seq_file___178 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___176 *op;
	int poll_event;
	const struct file___191 *file;
	void *private;
};

typedef void bio_end_io_t___95(struct bio___95 *);

struct bio_vec___95 {
	struct page___191 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___95;

struct bio_set___95;

struct bio___95 {
	struct bio___95 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___95 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___95 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___95 *bi_io_vec;
	struct bio_set___95 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___95 bi_inline_vecs[0];
};

struct cgroup_namespace___159 {
	refcount_t count;
	struct ns_common___11 ns;
	struct user_namespace___168 *user_ns;
	struct ucounts___168 *ucounts;
	struct css_set___159 *root_cset;
};

struct key_restriction___185;

struct key___185 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___191 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___185 *restrict_link;
};

struct ucounts___168 {
	struct hlist_node node;
	struct user_namespace___168 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct seq_operations___176 {
	void * (*start)(struct seq_file___178 *, loff_t *);
	void (*stop)(struct seq_file___178 *, void *);
	void * (*next)(struct seq_file___178 *, void *, loff_t *);
	int (*show)(struct seq_file___178 *, void *);
};

struct fsnotify_group___8;

struct fsnotify_iter_info___8;

struct fsnotify_mark___8;

struct fsnotify_event___8;

struct fsnotify_ops___8 {
	int (*handle_event)(struct fsnotify_group___8 *, struct inode___191 *, u32, const void *, int, const unsigned char *, u32, struct fsnotify_iter_info___8 *);
	void (*free_group_priv)(struct fsnotify_group___8 *);
	void (*freeing_mark)(struct fsnotify_mark___8 *, struct fsnotify_group___8 *);
	void (*free_event)(struct fsnotify_event___8 *);
	void (*free_mark)(struct fsnotify_mark___8 *);
};

struct inotify_group_private_data___8 {
	spinlock_t idr_lock;
	struct idr idr;
	struct ucounts___168 *ucounts;
};

struct fanotify_group_private_data___8 {
	struct list_head access_list;
	wait_queue_head_t access_waitq;
	int flags;
	int f_flags;
	unsigned int max_marks;
	struct user_struct___185 *user;
};

struct fsnotify_group___8 {
	const struct fsnotify_ops___8 *ops;
	refcount_t refcnt;
	spinlock_t notification_lock;
	struct list_head notification_list;
	wait_queue_head_t notification_waitq;
	unsigned int q_len;
	unsigned int max_events;
	unsigned int priority;
	bool shutdown;
	struct mutex mark_mutex;
	atomic_t num_marks;
	atomic_t user_waits;
	struct list_head marks_list;
	struct fasync_struct___190 *fsn_fa;
	struct fsnotify_event___8 *overflow_event;
	struct mem_cgroup___85 *memcg;
	union {
		void *private;
		struct inotify_group_private_data___8 inotify_data;
		struct fanotify_group_private_data___8 fanotify_data;
	};
};

struct fsnotify_iter_info___8 {
	struct fsnotify_mark___8 *marks[2];
	unsigned int report_mask;
	int srcu_idx;
};

struct fsnotify_mark___8 {
	__u32 mask;
	refcount_t refcnt;
	struct fsnotify_group___8 *group;
	struct list_head g_list;
	spinlock_t lock;
	struct hlist_node obj_list;
	struct fsnotify_mark_connector *connector;
	__u32 ignored_mask;
	unsigned int flags;
};

struct fsnotify_event___8 {
	struct list_head list;
	struct inode___191 *inode;
	u32 mask;
};

struct inotify_event {
	__s32 wd;
	__u32 mask;
	__u32 cookie;
	__u32 len;
	char name[0];
};

typedef int (*key_restrict_link_func_t___185)(struct key___185 *, const struct key_type *, const union key_payload *, struct key___185 *);

struct key_restriction___185 {
	key_restrict_link_func_t___185 check;
	struct key___185 *key;
	struct key_type *keytype;
};

struct dev_pm_info___172 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___172 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___172;

struct bus_type___172;

struct device_driver___172;

struct dev_pm_domain___172;

struct class___172;

struct attribute_group___173;

struct device___172 {
	struct device___172 *parent;
	struct device_private *p;
	struct kobject___182 kobj;
	const char *init_name;
	const struct device_type___172 *type;
	struct mutex mutex;
	struct bus_type___172 *bus;
	struct device_driver___172 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___172 power;
	struct dev_pm_domain___172 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___172 *class;
	const struct attribute_group___173 **groups;
	void (*release)(struct device___172 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct kobj_attribute___181 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___182 *, struct kobj_attribute___181 *, char *);
	ssize_t (*store)(struct kobject___182 *, struct kobj_attribute___181 *, const char *, size_t);
};

typedef void compound_page_dtor___187(struct page___191 *);

typedef struct poll_table_struct___129 poll_table___15;

struct kernfs_root___185;

struct kernfs_elem_dir___185 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___185 *root;
};

struct kernfs_syscall_ops___185;

struct kernfs_root___185 {
	struct kernfs_node___185 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___185 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___185 {
	struct kernfs_node___185 *target_kn;
};

struct kernfs_ops___185;

struct kernfs_elem_attr___185 {
	const struct kernfs_ops___185 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___185 *notify_next;
};

struct kernfs_node___185 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___185 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___185 dir;
		struct kernfs_elem_symlink___185 symlink;
		struct kernfs_elem_attr___185 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___185;

struct kernfs_ops___185 {
	int (*open)(struct kernfs_open_file___185 *);
	void (*release)(struct kernfs_open_file___185 *);
	int (*seq_show)(struct seq_file___178 *, void *);
	void * (*seq_start)(struct seq_file___178 *, loff_t *);
	void * (*seq_next)(struct seq_file___178 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___178 *, void *);
	ssize_t (*read)(struct kernfs_open_file___185 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___185 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___185 *, struct vm_area_struct___191 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___185 *, struct poll_table_struct___129 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___185 {
	int (*remount_fs)(struct kernfs_root___185 *, int *, char *);
	int (*show_options)(struct seq_file___178 *, struct kernfs_root___185 *);
	int (*mkdir)(struct kernfs_node___185 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___185 *);
	int (*rename)(struct kernfs_node___185 *, struct kernfs_node___185 *, const char *);
	int (*show_path)(struct seq_file___178 *, struct kernfs_node___185 *, struct kernfs_root___185 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___185 {
	struct kernfs_node___185 *kn;
	struct file___191 *file;
	struct seq_file___178 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___187 *vm_ops;
};

struct bin_attribute___172;

struct attribute_group___173 {
	const char *name;
	umode_t (*is_visible)(struct kobject___182 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___182 *, struct bin_attribute___172 *, int);
	struct attribute **attrs;
	struct bin_attribute___172 **bin_attrs;
};

struct bin_attribute___172 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___191 *, struct kobject___182 *, struct bin_attribute___172 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___191 *, struct kobject___182 *, struct bin_attribute___172 *, char *, loff_t, size_t);
	int (*mmap)(struct file___191 *, struct kobject___182 *, struct bin_attribute___172 *, struct vm_area_struct___191 *);
};

struct sysfs_ops___181 {
	ssize_t (*show)(struct kobject___182 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___182 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___181;

struct kset___181 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___182 kobj;
	const struct kset_uevent_ops___181 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___181 {
	void (*release)(struct kobject___182 *);
	const struct sysfs_ops___181 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___11 * (*child_ns_type)(struct kobject___182 *);
	const void * (*namespace)(struct kobject___182 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___181 {
	int (* const filter)(struct kset___181 *, struct kobject___182 *);
	const char * (* const name)(struct kset___181 *, struct kobject___182 *);
	int (* const uevent)(struct kset___181 *, struct kobject___182 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___157 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___157 *);
	int (*get)(char *, const struct kernel_param___157 *);
	void (*free)(void *);
};

struct kparam_array___157;

struct kernel_param___157 {
	const char *name;
	struct module___160 *mod;
	const struct kernel_param_ops___157 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___157 *arr;
	};
};

struct kparam_array___157 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___157 *ops;
	void *elem;
};

struct module_attribute___157 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___157 *, struct module_kobject___157 *, char *);
	ssize_t (*store)(struct module_attribute___157 *, struct module_kobject___157 *, const char *, size_t);
	void (*setup)(struct module___160 *, const char *);
	int (*test)(struct module___160 *);
	void (*free)(struct module___160 *);
};

struct trace_event_class___107;

struct trace_event_call___107 {
	struct list_head list;
	struct trace_event_class___107 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___21 *prog_array;
	int (*perf_perm)(struct trace_event_call___107 *, struct perf_event___114 *);
};

struct dev_pm_ops___172 {
	int (*prepare)(struct device___172 *);
	void (*complete)(struct device___172 *);
	int (*suspend)(struct device___172 *);
	int (*resume)(struct device___172 *);
	int (*freeze)(struct device___172 *);
	int (*thaw)(struct device___172 *);
	int (*poweroff)(struct device___172 *);
	int (*restore)(struct device___172 *);
	int (*suspend_late)(struct device___172 *);
	int (*resume_early)(struct device___172 *);
	int (*freeze_late)(struct device___172 *);
	int (*thaw_early)(struct device___172 *);
	int (*poweroff_late)(struct device___172 *);
	int (*restore_early)(struct device___172 *);
	int (*suspend_noirq)(struct device___172 *);
	int (*resume_noirq)(struct device___172 *);
	int (*freeze_noirq)(struct device___172 *);
	int (*thaw_noirq)(struct device___172 *);
	int (*poweroff_noirq)(struct device___172 *);
	int (*restore_noirq)(struct device___172 *);
	int (*runtime_suspend)(struct device___172 *);
	int (*runtime_resume)(struct device___172 *);
	int (*runtime_idle)(struct device___172 *);
};

struct dev_pm_domain___172 {
	struct dev_pm_ops___172 ops;
	void (*detach)(struct device___172 *, bool);
	int (*activate)(struct device___172 *);
	void (*sync)(struct device___172 *);
	void (*dismiss)(struct device___172 *);
};

struct bus_type___172 {
	const char *name;
	const char *dev_name;
	struct device___172 *dev_root;
	const struct attribute_group___173 **bus_groups;
	const struct attribute_group___173 **dev_groups;
	const struct attribute_group___173 **drv_groups;
	int (*match)(struct device___172 *, struct device_driver___172 *);
	int (*uevent)(struct device___172 *, struct kobj_uevent_env *);
	int (*probe)(struct device___172 *);
	int (*remove)(struct device___172 *);
	void (*shutdown)(struct device___172 *);
	int (*online)(struct device___172 *);
	int (*offline)(struct device___172 *);
	int (*suspend)(struct device___172 *, pm_message_t);
	int (*resume)(struct device___172 *);
	int (*num_vf)(struct device___172 *);
	int (*dma_configure)(struct device___172 *);
	const struct dev_pm_ops___172 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___172 {
	const char *name;
	struct bus_type___172 *bus;
	struct module___160 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___172 *);
	int (*remove)(struct device___172 *);
	void (*shutdown)(struct device___172 *);
	int (*suspend)(struct device___172 *, pm_message_t);
	int (*resume)(struct device___172 *);
	const struct attribute_group___173 **groups;
	const struct dev_pm_ops___172 *pm;
	void (*coredump)(struct device___172 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___172 {
	const char *name;
	const struct attribute_group___173 **groups;
	int (*uevent)(struct device___172 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___172 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___172 *);
	const struct dev_pm_ops___172 *pm;
};

struct class___172 {
	const char *name;
	struct module___160 *owner;
	const struct attribute_group___173 **class_groups;
	const struct attribute_group___173 **dev_groups;
	struct kobject___182 *dev_kobj;
	int (*dev_uevent)(struct device___172 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___172 *, umode_t *);
	void (*class_release)(struct class___172 *);
	void (*dev_release)(struct device___172 *);
	int (*shutdown_pre)(struct device___172 *);
	const struct kobj_ns_type_operations___11 *ns_type;
	const void * (*namespace)(struct device___172 *);
	const struct dev_pm_ops___172 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___147 {
	struct device___172 dev;
};

struct bpf_map___159;

struct bpf_map_ops___159 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___159 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___159 *, struct file___191 *);
	void (*map_free)(struct bpf_map___159 *);
	int (*map_get_next_key)(struct bpf_map___159 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___159 *);
	void * (*map_lookup_elem)(struct bpf_map___159 *, void *);
	int (*map_update_elem)(struct bpf_map___159 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___159 *, void *);
	int (*map_push_elem)(struct bpf_map___159 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___159 *, void *);
	int (*map_peek_elem)(struct bpf_map___159 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___159 *, struct file___191 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___159 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___159 *, void *, struct seq_file___178 *);
	int (*map_check_btf)(const struct bpf_map___159 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___159 {
	const struct bpf_map_ops___159 *ops;
	struct bpf_map___159 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___185 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___159;

typedef void (*kthread_work_func_t___159)(struct kthread_work___159 *);

struct kthread_worker___159;

struct kthread_work___159 {
	struct list_head node;
	kthread_work_func_t___159 func;
	struct kthread_worker___159 *worker;
	int canceling;
};

struct kthread_worker___159 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___191 *task;
	struct kthread_work___159 *current_work;
};

struct kthread_delayed_work___159 {
	struct kthread_work___159 work;
	struct timer_list timer;
};

struct psi_group___159 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___159 *poll_kworker;
	struct kthread_delayed_work___159 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___159;

struct cgroup_rstat_cpu___159;

struct cgroup___159 {
	struct cgroup_subsys_state___160 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___185 *kn;
	struct cgroup_file___159 procs_file;
	struct cgroup_file___159 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___160 *subsys[13];
	struct cgroup_root___159 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___159 *dom_cgrp;
	struct cgroup_rstat_cpu___159 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___21 bpf;
	atomic_t congestion_count;
	struct cgroup___159 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___159 psi;
	int ancestor_ids[0];
};

struct cftype___159;

struct cgroup_subsys___159 {
	struct cgroup_subsys_state___160 * (*css_alloc)(struct cgroup_subsys_state___160 *);
	int (*css_online)(struct cgroup_subsys_state___160 *);
	void (*css_offline)(struct cgroup_subsys_state___160 *);
	void (*css_released)(struct cgroup_subsys_state___160 *);
	void (*css_free)(struct cgroup_subsys_state___160 *);
	void (*css_reset)(struct cgroup_subsys_state___160 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___160 *, int);
	int (*css_extra_stat_show)(struct seq_file___178 *, struct cgroup_subsys_state___160 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___191 *);
	void (*cancel_fork)(struct task_struct___191 *);
	void (*fork)(struct task_struct___191 *);
	void (*exit)(struct task_struct___191 *);
	void (*free)(struct task_struct___191 *);
	void (*bind)(struct cgroup_subsys_state___160 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___159 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___159 *dfl_cftypes;
	struct cftype___159 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___159 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___159 *updated_children;
	struct cgroup___159 *updated_next;
};

struct cgroup_root___159 {
	struct kernfs_root___185 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___159 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___159 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___159 *ss;
	struct list_head node;
	struct kernfs_ops___185 *kf_ops;
	int (*open)(struct kernfs_open_file___185 *);
	void (*release)(struct kernfs_open_file___185 *);
	u64 (*read_u64)(struct cgroup_subsys_state___160 *, struct cftype___159 *);
	s64 (*read_s64)(struct cgroup_subsys_state___160 *, struct cftype___159 *);
	int (*seq_show)(struct seq_file___178 *, void *);
	void * (*seq_start)(struct seq_file___178 *, loff_t *);
	void * (*seq_next)(struct seq_file___178 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___178 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___160 *, struct cftype___159 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___160 *, struct cftype___159 *, s64);
	ssize_t (*write)(struct kernfs_open_file___185 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___185 *, struct poll_table_struct___129 *);
};

struct perf_cpu_context___114;

struct pmu___114 {
	struct list_head entry;
	struct module___160 *module;
	struct device___172 *dev;
	const struct attribute_group___173 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___114 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___114 *);
	void (*pmu_disable)(struct pmu___114 *);
	int (*event_init)(struct perf_event___114 *);
	void (*event_mapped)(struct perf_event___114 *, struct mm_struct___190 *);
	void (*event_unmapped)(struct perf_event___114 *, struct mm_struct___190 *);
	int (*add)(struct perf_event___114 *, int);
	void (*del)(struct perf_event___114 *, int);
	void (*start)(struct perf_event___114 *, int);
	void (*stop)(struct perf_event___114 *, int);
	void (*read)(struct perf_event___114 *);
	void (*start_txn)(struct pmu___114 *, unsigned int);
	int (*commit_txn)(struct pmu___114 *);
	void (*cancel_txn)(struct pmu___114 *);
	int (*event_idx)(struct perf_event___114 *);
	void (*sched_task)(struct perf_event_context___114 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___114 *);
	int (*filter_match)(struct perf_event___114 *);
	int (*check_period)(struct perf_event___114 *, u64);
};

struct perf_cpu_context___114 {
	struct perf_event_context___114 ctx;
	struct perf_event_context___114 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___114 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___114 {
	struct cgroup_subsys_state___160 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___107 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___107 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___107 *);
	struct list_head * (*get_fields)(struct trace_event_call___107 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___107 *);
};

struct syscall_metadata___52 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___107 *enter_event;
	struct trace_event_call___107 *exit_event;
};

struct bdi_writeback_congested___95 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___95 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___95 {
	struct bio___95 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___95 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___95 bip_inline_vecs[0];
};

struct bio_set___95 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___95 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___85 {
	struct mem_cgroup___85 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___85 {
	struct lruvec___190 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___85 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___85 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct inotify_event_info___2 {
	struct fsnotify_event___8 fse;
	int wd;
	u32 sync_cookie;
	int name_len;
	char name[0];
};

struct inotify_inode_mark___2 {
	struct fsnotify_mark___8 fsn_mark;
	int wd;
};

struct fsnotify_group___9;

struct fsnotify_iter_info___9;

struct fsnotify_mark___9;

struct fsnotify_event___9;

struct fsnotify_ops___9 {
	int (*handle_event)(struct fsnotify_group___9 *, struct inode___34 *, u32, const void *, int, const unsigned char *, u32, struct fsnotify_iter_info___9 *);
	void (*free_group_priv)(struct fsnotify_group___9 *);
	void (*freeing_mark)(struct fsnotify_mark___9 *, struct fsnotify_group___9 *);
	void (*free_event)(struct fsnotify_event___9 *);
	void (*free_mark)(struct fsnotify_mark___9 *);
};

struct inotify_group_private_data___9 {
	spinlock_t idr_lock;
	struct idr idr;
	struct ucounts___22 *ucounts;
};

struct fanotify_group_private_data___9 {
	struct list_head access_list;
	wait_queue_head_t access_waitq;
	int flags;
	int f_flags;
	unsigned int max_marks;
	struct user_struct___31 *user;
};

struct fsnotify_group___9 {
	const struct fsnotify_ops___9 *ops;
	refcount_t refcnt;
	spinlock_t notification_lock;
	struct list_head notification_list;
	wait_queue_head_t notification_waitq;
	unsigned int q_len;
	unsigned int max_events;
	unsigned int priority;
	bool shutdown;
	struct mutex mark_mutex;
	atomic_t num_marks;
	atomic_t user_waits;
	struct list_head marks_list;
	struct fasync_struct___31 *fsn_fa;
	struct fsnotify_event___9 *overflow_event;
	struct mem_cgroup___2 *memcg;
	union {
		void *private;
		struct inotify_group_private_data___9 inotify_data;
		struct fanotify_group_private_data___9 fanotify_data;
	};
};

struct fsnotify_iter_info___9 {
	struct fsnotify_mark___9 *marks[2];
	unsigned int report_mask;
	int srcu_idx;
};

struct fsnotify_mark___9 {
	__u32 mask;
	refcount_t refcnt;
	struct fsnotify_group___9 *group;
	struct list_head g_list;
	spinlock_t lock;
	struct hlist_node obj_list;
	struct fsnotify_mark_connector *connector;
	__u32 ignored_mask;
	unsigned int flags;
};

struct fsnotify_event___9 {
	struct list_head list;
	struct inode___34 *inode;
	u32 mask;
};

struct fanotify_event_info {
	struct fsnotify_event___9 fse;
	struct path___31 path;
	struct pid___27 *pid;
};

struct fanotify_perm_event_info {
	struct fanotify_event_info fae;
	int response;
	int fd;
};

struct fanotify_event_metadata {
	__u32 event_len;
	__u8 vers;
	__u8 reserved;
	__u16 metadata_len;
	__u64 mask;
	__s32 fd;
	__s32 pid;
};

struct fanotify_response {
	__s32 fd;
	__u32 response;
};

struct file___192;

struct fd___24 {
	struct file___192 *file;
	unsigned int flags;
};

struct vfsmount___38;

struct dentry___191;

struct path___191 {
	struct vfsmount___38 *mnt;
	struct dentry___191 *dentry;
};

struct pid___151;

struct fown_struct___151 {
	rwlock_t lock;
	struct pid___151 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct inode___192;

struct file_operations___192;

struct cred___186;

struct address_space___191;

struct file___192 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___191 f_path;
	struct inode___192 *f_inode;
	const struct file_operations___192 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___151 f_owner;
	const struct cred___186 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___191 *f_mapping;
	errseq_t f_wb_err;
};

struct module___161;

struct kiocb___192;

struct iov_iter___92;

struct poll_table_struct___130;

struct vm_area_struct___192;

struct file_lock___192;

struct page___192;

struct seq_file___179;

struct file_operations___192 {
	struct module___161 *owner;
	loff_t (*llseek)(struct file___192 *, loff_t, int);
	ssize_t (*read)(struct file___192 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___192 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___192 *, struct iov_iter___92 *);
	ssize_t (*write_iter)(struct kiocb___192 *, struct iov_iter___92 *);
	int (*iopoll)(struct kiocb___192 *, bool);
	int (*iterate)(struct file___192 *, struct dir_context *);
	int (*iterate_shared)(struct file___192 *, struct dir_context *);
	__poll_t (*poll)(struct file___192 *, struct poll_table_struct___130 *);
	long int (*unlocked_ioctl)(struct file___192 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___192 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___192 *, struct vm_area_struct___192 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___192 *, struct file___192 *);
	int (*flush)(struct file___192 *, fl_owner_t);
	int (*release)(struct inode___192 *, struct file___192 *);
	int (*fsync)(struct file___192 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___192 *, int);
	int (*lock)(struct file___192 *, int, struct file_lock___192 *);
	ssize_t (*sendpage)(struct file___192 *, struct page___192 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___192 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___192 *, int, struct file_lock___192 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___192 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___192 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___192 *, long int, struct file_lock___192 **, void **);
	long int (*fallocate)(struct file___192 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___179 *, struct file___192 *);
	ssize_t (*copy_file_range)(struct file___192 *, loff_t, struct file___192 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___192 *, loff_t, struct file___192 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___192 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___191 {
	u64 seqnum;
	struct vm_area_struct___192 *vmas[4];
};

struct page_frag___191 {
	struct page___192 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___115;

struct debug_info___115 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___115 *hbp_break[16];
	struct perf_event___115 *hbp_watch[16];
};

struct thread_struct___115 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___115 debug;
	long: 64;
};

struct mm_struct___191;

struct mem_cgroup___86;

struct nsproxy___181;

struct signal_struct___168;

struct bio_list___96;

struct backing_dev_info___96;

struct css_set___160;

struct perf_event_context___115;

struct task_struct___192 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___192 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___191 *mm;
	struct mm_struct___191 *active_mm;
	struct vmacache___191 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___192 *real_parent;
	struct task_struct___192 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___192 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___86 *active_memcg;
	long int rh_reserved2;
	struct pid___151 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___151 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___151 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___186 *ptracer_cred;
	const struct cred___186 *real_cred;
	const struct cred___186 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___181 *nsproxy;
	struct signal_struct___168 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___192 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___96 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___96 *backing_dev_info;
	struct io_context___49 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___160 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___115 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___191 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___86 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___192 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___115 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___115 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___192 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___115)(struct perf_event___115 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___115;

struct fasync_struct___191;

struct pid_namespace___151;

struct trace_event_call___108;

struct perf_cgroup___115;

struct perf_event___115 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___115 *group_leader;
	struct pmu___115 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___115 hw;
	struct perf_event_context___115 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___115 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___192 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___191 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___115 *);
	struct callback_head callback_head;
	struct pid_namespace___151 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___115 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___115 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___108 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___115 *cgrp;
	struct list_head sb_list;
};

struct dentry_operations___191;

struct super_block___191;

struct dentry___191 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___191 *d_parent;
	struct qstr d_name;
	struct inode___192 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___191 *d_op;
	struct super_block___191 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct rw_semaphore___192 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___192 *owner;
};

struct address_space_operations___191;

struct address_space___191 {
	struct inode___192 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___192 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___191 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___191;

struct bdi_writeback___96;

struct block_device___192;

struct inode___192 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___191 *i_op;
	struct super_block___191 *i_sb;
	struct address_space___191 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___192 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___96 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___192 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___191 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___192 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___191 {
	int (*d_revalidate)(struct dentry___191 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___191 *, unsigned int);
	int (*d_hash)(const struct dentry___191 *, struct qstr *);
	int (*d_compare)(const struct dentry___191 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___191 *);
	int (*d_init)(struct dentry___191 *);
	void (*d_release)(struct dentry___191 *);
	void (*d_prune)(struct dentry___191 *);
	void (*d_iput)(struct dentry___191 *, struct inode___192 *);
	char * (*d_dname)(struct dentry___191 *, char *, int);
	struct vfsmount___38 * (*d_automount)(struct path___191 *);
	int (*d_manage)(const struct path___191 *, bool);
	struct dentry___191 * (*d_real)(struct dentry___191 *, const struct inode___192 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___191;

struct mem_dqinfo___191 {
	struct quota_format_type___191 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___191;

struct quota_info___191 {
	unsigned int flags;
	struct rw_semaphore___192 dqio_sem;
	struct inode___192 *files[3];
	struct mem_dqinfo___191 info[3];
	const struct quota_format_ops___191 *ops[3];
};

struct rcuwait___191 {
	struct task_struct___192 *task;
};

struct percpu_rw_semaphore___191 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___192 rw_sem;
	struct rcuwait___191 writer;
	int readers_block;
};

struct sb_writers___191 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___191 rw_sem[3];
};

struct shrink_control___86;

struct shrinker___86 {
	long unsigned int (*count_objects)(struct shrinker___86 *, struct shrink_control___86 *);
	long unsigned int (*scan_objects)(struct shrinker___86 *, struct shrink_control___86 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___191;

struct super_operations___191;

struct dquot_operations___191;

struct quotactl_ops___191;

struct user_namespace___169;

struct super_block___191 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___191 *s_type;
	const struct super_operations___191 *s_op;
	const struct dquot_operations___191 *dq_op;
	const struct quotactl_ops___191 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___191 *s_root;
	struct rw_semaphore___192 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___192 *s_bdev;
	struct backing_dev_info___96 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___191 s_dquot;
	struct sb_writers___191 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___191 *s_d_op;
	int cleancache_poolid;
	struct shrinker___86 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___169 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___38 {
	struct dentry___191 *mnt_root;
	struct super_block___191 *mnt_sb;
	int mnt_flags;
};

struct key___186;

struct ucounts___169;

struct user_namespace___169 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___169 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___11 ns;
	long unsigned int flags;
	struct key___186 *persistent_keyring_register;
	struct rw_semaphore___192 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___169 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct shrink_control___86 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___86 *memcg;
};

struct cgroup___160;

struct cgroup_subsys___160;

struct cgroup_subsys_state___161 {
	struct cgroup___160 *cgroup;
	struct cgroup_subsys___160 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___161 *parent;
};

struct kernfs_node___186;

struct cgroup_file___160 {
	struct kernfs_node___186 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___86;

struct mem_cgroup___86 {
	struct cgroup_subsys_state___161 css;
	struct mem_cgroup_id___20 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___160 events_file;
	struct cgroup_file___160 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___192 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___86 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___192 *pgtable_t___191;

struct dev_pagemap___188;

struct page___192 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___191 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___192 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___191 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___191 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___188 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___86 *mem_cgroup;
};

struct pglist_data___191;

struct lruvec___191 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___191 *pgdat;
};

struct zone___191 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___191 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___191 {
	struct zone___191 *zone;
	int zone_idx;
};

struct zonelist___191 {
	struct zoneref___191 _zonerefs[25];
};

struct pglist_data___191 {
	struct zone___191 node_zones[3];
	struct zonelist___191 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___192 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___192 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___191 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___192 {
	void *stack;
	struct task_struct___192 *task;
	long int status;
};

struct blocking_notifier_head___191 {
	struct rw_semaphore___192 rwsem;
	struct notifier_block *head;
};

struct upid___151 {
	int nr;
	struct pid_namespace___151 *ns;
};

struct pid_namespace___151 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___192 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___151 *parent;
	struct vfsmount___38 *proc_mnt;
	struct dentry___191 *proc_self;
	struct dentry___191 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___169 *user_ns;
	struct ucounts___169 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___11 ns;
};

struct pid___151 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___151 numbers[1];
};

struct vm_operations_struct___188;

struct vm_area_struct___192 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___192 *vm_next;
	struct vm_area_struct___192 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___191 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___188 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___192 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___191;

struct mm_struct___191 {
	struct {
		struct vm_area_struct___192 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___192 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___192 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___191 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___192 *owner;
		struct user_namespace___169 *user_ns;
		struct file___192 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___191 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___188)(struct vm_area_struct___192 *, long unsigned int, const struct page___192 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___188)(struct page___192 *, void *);

struct device___173;

struct dev_pagemap___188 {
	dev_page_fault_t___188 page_fault;
	dev_page_free_t___188 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___173 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct vm_fault___188;

struct vm_operations_struct___188 {
	void (*open)(struct vm_area_struct___192 *);
	void (*close)(struct vm_area_struct___192 *);
	int (*split)(struct vm_area_struct___192 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___192 *);
	vm_fault_t (*fault)(struct vm_fault___188 *);
	vm_fault_t (*huge_fault)(struct vm_fault___188 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___188 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___192 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___188 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___188 *);
	int (*access)(struct vm_area_struct___192 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___192 *);
	int (*set_policy)(struct vm_area_struct___192 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___192 *, long unsigned int);
	struct page___192 * (*find_special_page)(struct vm_area_struct___192 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___191 {
	struct task_struct___192 *task;
	struct core_thread___191 *next;
};

struct core_state___191 {
	atomic_t nr_threads;
	struct core_thread___191 dumper;
	struct completion startup;
};

struct vm_fault___188 {
	struct vm_area_struct___192 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___192 *cow_page;
	struct mem_cgroup___86 *memcg;
	struct page___192 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___191 prealloc_pte;
};

struct user_struct___186 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___186 *uid_keyring;
	struct key___186 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___186 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___186 *session_keyring;
	struct key___186 *process_keyring;
	struct key___186 *thread_keyring;
	struct key___186 *request_key_auth;
	void *security;
	struct user_struct___186 *user;
	struct user_namespace___169 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct mnt_namespace___9;

struct cgroup_namespace___160;

struct nsproxy___181 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace___9 *mnt_ns;
	struct pid_namespace___151 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___160 *cgroup_ns;
};

struct signal_struct___168 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___192 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___192 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___151 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___151 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___191 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___151 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___96;

struct bio_list___96 {
	struct bio___96 *head;
	struct bio___96 *tail;
};

struct bdi_writeback_congested___96;

struct bdi_writeback___96 {
	struct backing_dev_info___96 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___96 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___161 *memcg_css;
	struct cgroup_subsys_state___161 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___96 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___96 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___173 *dev;
	struct device___173 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___191 *debug_dir;
	struct dentry___191 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___160 {
	struct cgroup_subsys_state___161 *subsys[13];
	refcount_t refcount;
	struct css_set___160 *dom_cset;
	struct cgroup___160 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___160 *mg_src_cgrp;
	struct cgroup___160 *mg_dst_cgrp;
	struct css_set___160 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___115 {
	struct pmu___115 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___192 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___115 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

union thread_union___170 {
	struct task_struct___192 task;
	long unsigned int stack[8192];
};

struct kiocb___192 {
	struct file___192 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___192 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___191 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___192 *ia_file;
};

struct dquot___191 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___191 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___191 {
	int qf_fmt_id;
	const struct quota_format_ops___191 *qf_ops;
	struct module___161 *qf_owner;
	struct quota_format_type___191 *qf_next;
};

struct quota_format_ops___191 {
	int (*check_quota_file)(struct super_block___191 *, int);
	int (*read_file_info)(struct super_block___191 *, int);
	int (*write_file_info)(struct super_block___191 *, int);
	int (*free_file_info)(struct super_block___191 *, int);
	int (*read_dqblk)(struct dquot___191 *);
	int (*commit_dqblk)(struct dquot___191 *);
	int (*release_dqblk)(struct dquot___191 *);
	int (*get_next_id)(struct super_block___191 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___191 {
	int (*write_dquot)(struct dquot___191 *);
	struct dquot___191 * (*alloc_dquot)(struct super_block___191 *, int);
	void (*destroy_dquot)(struct dquot___191 *);
	int (*acquire_dquot)(struct dquot___191 *);
	int (*release_dquot)(struct dquot___191 *);
	int (*mark_dirty)(struct dquot___191 *);
	int (*write_info)(struct super_block___191 *, int);
	qsize_t * (*get_reserved_space)(struct inode___192 *);
	int (*get_projid)(struct inode___192 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___192 *, qsize_t *);
	int (*get_next_id)(struct super_block___191 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___191 {
	int (*quota_on)(struct super_block___191 *, int, int, const struct path___191 *);
	int (*quota_off)(struct super_block___191 *, int);
	int (*quota_enable)(struct super_block___191 *, unsigned int);
	int (*quota_disable)(struct super_block___191 *, unsigned int);
	int (*quota_sync)(struct super_block___191 *, int);
	int (*set_info)(struct super_block___191 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___191 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___191 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___191 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___191 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___191 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___182;

struct kobj_type___182;

struct kobject___183 {
	const char *name;
	struct list_head entry;
	struct kobject___183 *parent;
	struct kset___182 *kset;
	struct kobj_type___182 *ktype;
	struct kernfs_node___186 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___158 {
	struct kobject___183 kobj;
	struct module___161 *mod;
	struct kobject___183 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___158 {
	struct module___161 *mod;
	struct latch_tree_node node;
};

struct module_layout___158 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___158 mtn;
};

struct module_attribute___158;

struct kernel_param___158;

struct module___161 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___158 mkobj;
	struct module_attribute___158 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___183 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___158 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___158 core_layout;
	struct module_layout___158 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___108 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___92;

struct address_space_operations___191 {
	int (*writepage)(struct page___192 *, struct writeback_control___92 *);
	int (*readpage)(struct file___192 *, struct page___192 *);
	int (*writepages)(struct address_space___191 *, struct writeback_control___92 *);
	int (*set_page_dirty)(struct page___192 *);
	int (*readpages)(struct file___192 *, struct address_space___191 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___192 *, struct address_space___191 *, loff_t, unsigned int, unsigned int, struct page___192 **, void **);
	int (*write_end)(struct file___192 *, struct address_space___191 *, loff_t, unsigned int, unsigned int, struct page___192 *, void *);
	sector_t (*bmap)(struct address_space___191 *, sector_t);
	void (*invalidatepage)(struct page___192 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___192 *, gfp_t);
	void (*freepage)(struct page___192 *);
	ssize_t (*direct_IO)(struct kiocb___192 *, struct iov_iter___92 *);
	int (*migratepage)(struct address_space___191 *, struct page___192 *, struct page___192 *, enum migrate_mode);
	bool (*isolate_page)(struct page___192 *, isolate_mode_t);
	void (*putback_page)(struct page___192 *);
	int (*launder_page)(struct page___192 *);
	int (*is_partially_uptodate)(struct page___192 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___192 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___191 *, struct page___192 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___192 *, sector_t *);
	void (*swap_deactivate)(struct file___192 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___92 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___96 *wb;
	struct inode___192 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___96;

struct iov_iter___92 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___96 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___192 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___192 *bd_inode;
	struct super_block___191 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___192 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___96 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___191 {
	struct dentry___191 * (*lookup)(struct inode___192 *, struct dentry___191 *, unsigned int);
	const char * (*get_link)(struct dentry___191 *, struct inode___192 *, struct delayed_call *);
	int (*permission)(struct inode___192 *, int);
	struct posix_acl * (*get_acl)(struct inode___192 *, int);
	int (*readlink)(struct dentry___191 *, char *, int);
	int (*create)(struct inode___192 *, struct dentry___191 *, umode_t, bool);
	int (*link)(struct dentry___191 *, struct inode___192 *, struct dentry___191 *);
	int (*unlink)(struct inode___192 *, struct dentry___191 *);
	int (*symlink)(struct inode___192 *, struct dentry___191 *, const char *);
	int (*mkdir)(struct inode___192 *, struct dentry___191 *, umode_t);
	int (*rmdir)(struct inode___192 *, struct dentry___191 *);
	int (*mknod)(struct inode___192 *, struct dentry___191 *, umode_t, dev_t);
	int (*rename)(struct inode___192 *, struct dentry___191 *, struct inode___192 *, struct dentry___191 *, unsigned int);
	int (*setattr)(struct dentry___191 *, struct iattr___191 *);
	int (*getattr)(const struct path___191 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___191 *, char *, size_t);
	int (*fiemap)(struct inode___192 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___192 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___192 *, struct dentry___191 *, struct file___192 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___192 *, struct dentry___191 *, umode_t);
	int (*set_acl)(struct inode___192 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___191 {
	void (*fl_copy_lock)(struct file_lock___192 *, struct file_lock___192 *);
	void (*fl_release_private)(struct file_lock___192 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___191;

struct file_lock___192 {
	struct file_lock___192 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___192 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___191 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___191 *fl_ops;
	const struct lock_manager_operations___191 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___191 {
	int (*lm_compare_owner)(struct file_lock___192 *, struct file_lock___192 *);
	long unsigned int (*lm_owner_key)(struct file_lock___192 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___192 *);
	int (*lm_grant)(struct file_lock___192 *, int);
	bool (*lm_break)(struct file_lock___192 *);
	int (*lm_change)(struct file_lock___192 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___192 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___191 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___191 *fa_next;
	struct file___192 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___191 {
	const char *name;
	int fs_flags;
	struct dentry___191 * (*mount)(struct file_system_type___191 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___191 *);
	struct module___161 *owner;
	struct file_system_type___191 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___191 {
	struct inode___192 * (*alloc_inode)(struct super_block___191 *);
	void (*destroy_inode)(struct inode___192 *);
	void (*dirty_inode)(struct inode___192 *, int);
	int (*write_inode)(struct inode___192 *, struct writeback_control___92 *);
	int (*drop_inode)(struct inode___192 *);
	void (*evict_inode)(struct inode___192 *);
	void (*put_super)(struct super_block___191 *);
	int (*sync_fs)(struct super_block___191 *, int);
	int (*freeze_super)(struct super_block___191 *);
	int (*freeze_fs)(struct super_block___191 *);
	int (*thaw_super)(struct super_block___191 *);
	int (*unfreeze_fs)(struct super_block___191 *);
	int (*statfs)(struct dentry___191 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___191 *, int *, char *);
	void (*umount_begin)(struct super_block___191 *);
	int (*show_options)(struct seq_file___179 *, struct dentry___191 *);
	int (*show_devname)(struct seq_file___179 *, struct dentry___191 *);
	int (*show_path)(struct seq_file___179 *, struct dentry___191 *);
	int (*show_stats)(struct seq_file___179 *, struct dentry___191 *);
	ssize_t (*quota_read)(struct super_block___191 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___191 *, int, const char *, size_t, loff_t);
	struct dquot___191 ** (*get_dquots)(struct inode___192 *);
	int (*bdev_try_to_free_page)(struct super_block___191 *, struct page___192 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___191 *, struct shrink_control___86 *);
	long int (*free_cached_objects)(struct super_block___191 *, struct shrink_control___86 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___131)(struct file___192 *, wait_queue_head_t *, struct poll_table_struct___130 *);

struct poll_table_struct___130 {
	poll_queue_proc___131 _qproc;
	__poll_t _key;
};

struct seq_operations___177;

struct seq_file___179 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___177 *op;
	int poll_event;
	const struct file___192 *file;
	void *private;
};

typedef void bio_end_io_t___96(struct bio___96 *);

struct bio_vec___96 {
	struct page___192 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___96;

struct bio_set___96;

struct bio___96 {
	struct bio___96 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___96 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___96 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___96 *bi_io_vec;
	struct bio_set___96 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___96 bi_inline_vecs[0];
};

struct mount___9;

struct mnt_namespace___9 {
	atomic_t count;
	struct ns_common___11 ns;
	struct mount___9 *root;
	struct list_head list;
	struct user_namespace___169 *user_ns;
	struct ucounts___169 *ucounts;
	u64 seq;
	wait_queue_head_t poll;
	u64 event;
	unsigned int mounts;
	unsigned int pending_mounts;
};

struct cgroup_namespace___160 {
	refcount_t count;
	struct ns_common___11 ns;
	struct user_namespace___169 *user_ns;
	struct ucounts___169 *ucounts;
	struct css_set___160 *root_cset;
};

struct key_restriction___186;

struct key___186 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___192 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___186 *restrict_link;
};

struct ucounts___169 {
	struct hlist_node node;
	struct user_namespace___169 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct seq_operations___177 {
	void * (*start)(struct seq_file___179 *, loff_t *);
	void (*stop)(struct seq_file___179 *, void *);
	void * (*next)(struct seq_file___179 *, void *, loff_t *);
	int (*show)(struct seq_file___179 *, void *);
};

struct fsnotify_group___10;

struct fsnotify_iter_info___10;

struct fsnotify_mark___10;

struct fsnotify_event___10;

struct fsnotify_ops___10 {
	int (*handle_event)(struct fsnotify_group___10 *, struct inode___192 *, u32, const void *, int, const unsigned char *, u32, struct fsnotify_iter_info___10 *);
	void (*free_group_priv)(struct fsnotify_group___10 *);
	void (*freeing_mark)(struct fsnotify_mark___10 *, struct fsnotify_group___10 *);
	void (*free_event)(struct fsnotify_event___10 *);
	void (*free_mark)(struct fsnotify_mark___10 *);
};

struct inotify_group_private_data___10 {
	spinlock_t idr_lock;
	struct idr idr;
	struct ucounts___169 *ucounts;
};

struct fanotify_group_private_data___10 {
	struct list_head access_list;
	wait_queue_head_t access_waitq;
	int flags;
	int f_flags;
	unsigned int max_marks;
	struct user_struct___186 *user;
};

struct fsnotify_group___10 {
	const struct fsnotify_ops___10 *ops;
	refcount_t refcnt;
	spinlock_t notification_lock;
	struct list_head notification_list;
	wait_queue_head_t notification_waitq;
	unsigned int q_len;
	unsigned int max_events;
	unsigned int priority;
	bool shutdown;
	struct mutex mark_mutex;
	atomic_t num_marks;
	atomic_t user_waits;
	struct list_head marks_list;
	struct fasync_struct___191 *fsn_fa;
	struct fsnotify_event___10 *overflow_event;
	struct mem_cgroup___86 *memcg;
	union {
		void *private;
		struct inotify_group_private_data___10 inotify_data;
		struct fanotify_group_private_data___10 fanotify_data;
	};
};

struct fsnotify_iter_info___10 {
	struct fsnotify_mark___10 *marks[2];
	unsigned int report_mask;
	int srcu_idx;
};

struct fsnotify_mark___10 {
	__u32 mask;
	refcount_t refcnt;
	struct fsnotify_group___10 *group;
	struct list_head g_list;
	spinlock_t lock;
	struct hlist_node obj_list;
	struct fsnotify_mark_connector *connector;
	__u32 ignored_mask;
	unsigned int flags;
};

struct fsnotify_event___10 {
	struct list_head list;
	struct inode___192 *inode;
	u32 mask;
};

typedef struct poll_table_struct___130 poll_table___16;

typedef int (*key_restrict_link_func_t___186)(struct key___186 *, const struct key_type *, const union key_payload *, struct key___186 *);

struct key_restriction___186 {
	key_restrict_link_func_t___186 check;
	struct key___186 *key;
	struct key_type *keytype;
};

struct dev_pm_info___173 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___173 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___173;

struct bus_type___173;

struct device_driver___173;

struct dev_pm_domain___173;

struct class___173;

struct attribute_group___174;

struct device___173 {
	struct device___173 *parent;
	struct device_private *p;
	struct kobject___183 kobj;
	const char *init_name;
	const struct device_type___173 *type;
	struct mutex mutex;
	struct bus_type___173 *bus;
	struct device_driver___173 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___173 power;
	struct dev_pm_domain___173 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___173 *class;
	const struct attribute_group___174 **groups;
	void (*release)(struct device___173 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct kobj_attribute___182 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___183 *, struct kobj_attribute___182 *, char *);
	ssize_t (*store)(struct kobject___183 *, struct kobj_attribute___182 *, const char *, size_t);
};

typedef void compound_page_dtor___188(struct page___192 *);

struct kernfs_root___186;

struct kernfs_elem_dir___186 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___186 *root;
};

struct kernfs_syscall_ops___186;

struct kernfs_root___186 {
	struct kernfs_node___186 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___186 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___186 {
	struct kernfs_node___186 *target_kn;
};

struct kernfs_ops___186;

struct kernfs_elem_attr___186 {
	const struct kernfs_ops___186 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___186 *notify_next;
};

struct kernfs_node___186 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___186 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___186 dir;
		struct kernfs_elem_symlink___186 symlink;
		struct kernfs_elem_attr___186 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___186;

struct kernfs_ops___186 {
	int (*open)(struct kernfs_open_file___186 *);
	void (*release)(struct kernfs_open_file___186 *);
	int (*seq_show)(struct seq_file___179 *, void *);
	void * (*seq_start)(struct seq_file___179 *, loff_t *);
	void * (*seq_next)(struct seq_file___179 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___179 *, void *);
	ssize_t (*read)(struct kernfs_open_file___186 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___186 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___186 *, struct vm_area_struct___192 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___186 *, struct poll_table_struct___130 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___186 {
	int (*remount_fs)(struct kernfs_root___186 *, int *, char *);
	int (*show_options)(struct seq_file___179 *, struct kernfs_root___186 *);
	int (*mkdir)(struct kernfs_node___186 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___186 *);
	int (*rename)(struct kernfs_node___186 *, struct kernfs_node___186 *, const char *);
	int (*show_path)(struct seq_file___179 *, struct kernfs_node___186 *, struct kernfs_root___186 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___186 {
	struct kernfs_node___186 *kn;
	struct file___192 *file;
	struct seq_file___179 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___188 *vm_ops;
};

struct bin_attribute___173;

struct attribute_group___174 {
	const char *name;
	umode_t (*is_visible)(struct kobject___183 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___183 *, struct bin_attribute___173 *, int);
	struct attribute **attrs;
	struct bin_attribute___173 **bin_attrs;
};

struct bin_attribute___173 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___192 *, struct kobject___183 *, struct bin_attribute___173 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___192 *, struct kobject___183 *, struct bin_attribute___173 *, char *, loff_t, size_t);
	int (*mmap)(struct file___192 *, struct kobject___183 *, struct bin_attribute___173 *, struct vm_area_struct___192 *);
};

struct sysfs_ops___182 {
	ssize_t (*show)(struct kobject___183 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___183 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___182;

struct kset___182 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___183 kobj;
	const struct kset_uevent_ops___182 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___182 {
	void (*release)(struct kobject___183 *);
	const struct sysfs_ops___182 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___11 * (*child_ns_type)(struct kobject___183 *);
	const void * (*namespace)(struct kobject___183 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___182 {
	int (* const filter)(struct kset___182 *, struct kobject___183 *);
	const char * (* const name)(struct kset___182 *, struct kobject___183 *);
	int (* const uevent)(struct kset___182 *, struct kobject___183 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___158 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___158 *);
	int (*get)(char *, const struct kernel_param___158 *);
	void (*free)(void *);
};

struct kparam_array___158;

struct kernel_param___158 {
	const char *name;
	struct module___161 *mod;
	const struct kernel_param_ops___158 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___158 *arr;
	};
};

struct kparam_array___158 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___158 *ops;
	void *elem;
};

struct module_attribute___158 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___158 *, struct module_kobject___158 *, char *);
	ssize_t (*store)(struct module_attribute___158 *, struct module_kobject___158 *, const char *, size_t);
	void (*setup)(struct module___161 *, const char *);
	int (*test)(struct module___161 *);
	void (*free)(struct module___161 *);
};

struct trace_event_class___108;

struct trace_event_call___108 {
	struct list_head list;
	struct trace_event_class___108 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___21 *prog_array;
	int (*perf_perm)(struct trace_event_call___108 *, struct perf_event___115 *);
};

struct dev_pm_ops___173 {
	int (*prepare)(struct device___173 *);
	void (*complete)(struct device___173 *);
	int (*suspend)(struct device___173 *);
	int (*resume)(struct device___173 *);
	int (*freeze)(struct device___173 *);
	int (*thaw)(struct device___173 *);
	int (*poweroff)(struct device___173 *);
	int (*restore)(struct device___173 *);
	int (*suspend_late)(struct device___173 *);
	int (*resume_early)(struct device___173 *);
	int (*freeze_late)(struct device___173 *);
	int (*thaw_early)(struct device___173 *);
	int (*poweroff_late)(struct device___173 *);
	int (*restore_early)(struct device___173 *);
	int (*suspend_noirq)(struct device___173 *);
	int (*resume_noirq)(struct device___173 *);
	int (*freeze_noirq)(struct device___173 *);
	int (*thaw_noirq)(struct device___173 *);
	int (*poweroff_noirq)(struct device___173 *);
	int (*restore_noirq)(struct device___173 *);
	int (*runtime_suspend)(struct device___173 *);
	int (*runtime_resume)(struct device___173 *);
	int (*runtime_idle)(struct device___173 *);
};

struct dev_pm_domain___173 {
	struct dev_pm_ops___173 ops;
	void (*detach)(struct device___173 *, bool);
	int (*activate)(struct device___173 *);
	void (*sync)(struct device___173 *);
	void (*dismiss)(struct device___173 *);
};

struct bus_type___173 {
	const char *name;
	const char *dev_name;
	struct device___173 *dev_root;
	const struct attribute_group___174 **bus_groups;
	const struct attribute_group___174 **dev_groups;
	const struct attribute_group___174 **drv_groups;
	int (*match)(struct device___173 *, struct device_driver___173 *);
	int (*uevent)(struct device___173 *, struct kobj_uevent_env *);
	int (*probe)(struct device___173 *);
	int (*remove)(struct device___173 *);
	void (*shutdown)(struct device___173 *);
	int (*online)(struct device___173 *);
	int (*offline)(struct device___173 *);
	int (*suspend)(struct device___173 *, pm_message_t);
	int (*resume)(struct device___173 *);
	int (*num_vf)(struct device___173 *);
	int (*dma_configure)(struct device___173 *);
	const struct dev_pm_ops___173 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___173 {
	const char *name;
	struct bus_type___173 *bus;
	struct module___161 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___173 *);
	int (*remove)(struct device___173 *);
	void (*shutdown)(struct device___173 *);
	int (*suspend)(struct device___173 *, pm_message_t);
	int (*resume)(struct device___173 *);
	const struct attribute_group___174 **groups;
	const struct dev_pm_ops___173 *pm;
	void (*coredump)(struct device___173 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___173 {
	const char *name;
	const struct attribute_group___174 **groups;
	int (*uevent)(struct device___173 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___173 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___173 *);
	const struct dev_pm_ops___173 *pm;
};

struct class___173 {
	const char *name;
	struct module___161 *owner;
	const struct attribute_group___174 **class_groups;
	const struct attribute_group___174 **dev_groups;
	struct kobject___183 *dev_kobj;
	int (*dev_uevent)(struct device___173 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___173 *, umode_t *);
	void (*class_release)(struct class___173 *);
	void (*dev_release)(struct device___173 *);
	int (*shutdown_pre)(struct device___173 *);
	const struct kobj_ns_type_operations___11 *ns_type;
	const void * (*namespace)(struct device___173 *);
	const struct dev_pm_ops___173 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___148 {
	struct device___173 dev;
};

struct bpf_map___160;

struct bpf_map_ops___160 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___160 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___160 *, struct file___192 *);
	void (*map_free)(struct bpf_map___160 *);
	int (*map_get_next_key)(struct bpf_map___160 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___160 *);
	void * (*map_lookup_elem)(struct bpf_map___160 *, void *);
	int (*map_update_elem)(struct bpf_map___160 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___160 *, void *);
	int (*map_push_elem)(struct bpf_map___160 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___160 *, void *);
	int (*map_peek_elem)(struct bpf_map___160 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___160 *, struct file___192 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___160 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___160 *, void *, struct seq_file___179 *);
	int (*map_check_btf)(const struct bpf_map___160 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___160 {
	const struct bpf_map_ops___160 *ops;
	struct bpf_map___160 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___186 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___160;

typedef void (*kthread_work_func_t___160)(struct kthread_work___160 *);

struct kthread_worker___160;

struct kthread_work___160 {
	struct list_head node;
	kthread_work_func_t___160 func;
	struct kthread_worker___160 *worker;
	int canceling;
};

struct kthread_worker___160 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___192 *task;
	struct kthread_work___160 *current_work;
};

struct kthread_delayed_work___160 {
	struct kthread_work___160 work;
	struct timer_list timer;
};

struct psi_group___160 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___160 *poll_kworker;
	struct kthread_delayed_work___160 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___160;

struct cgroup_rstat_cpu___160;

struct cgroup___160 {
	struct cgroup_subsys_state___161 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___186 *kn;
	struct cgroup_file___160 procs_file;
	struct cgroup_file___160 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___161 *subsys[13];
	struct cgroup_root___160 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___160 *dom_cgrp;
	struct cgroup_rstat_cpu___160 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___21 bpf;
	atomic_t congestion_count;
	struct cgroup___160 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___160 psi;
	int ancestor_ids[0];
};

struct cftype___160;

struct cgroup_subsys___160 {
	struct cgroup_subsys_state___161 * (*css_alloc)(struct cgroup_subsys_state___161 *);
	int (*css_online)(struct cgroup_subsys_state___161 *);
	void (*css_offline)(struct cgroup_subsys_state___161 *);
	void (*css_released)(struct cgroup_subsys_state___161 *);
	void (*css_free)(struct cgroup_subsys_state___161 *);
	void (*css_reset)(struct cgroup_subsys_state___161 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___161 *, int);
	int (*css_extra_stat_show)(struct seq_file___179 *, struct cgroup_subsys_state___161 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___192 *);
	void (*cancel_fork)(struct task_struct___192 *);
	void (*fork)(struct task_struct___192 *);
	void (*exit)(struct task_struct___192 *);
	void (*free)(struct task_struct___192 *);
	void (*bind)(struct cgroup_subsys_state___161 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___160 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___160 *dfl_cftypes;
	struct cftype___160 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___160 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___160 *updated_children;
	struct cgroup___160 *updated_next;
};

struct cgroup_root___160 {
	struct kernfs_root___186 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___160 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___160 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___160 *ss;
	struct list_head node;
	struct kernfs_ops___186 *kf_ops;
	int (*open)(struct kernfs_open_file___186 *);
	void (*release)(struct kernfs_open_file___186 *);
	u64 (*read_u64)(struct cgroup_subsys_state___161 *, struct cftype___160 *);
	s64 (*read_s64)(struct cgroup_subsys_state___161 *, struct cftype___160 *);
	int (*seq_show)(struct seq_file___179 *, void *);
	void * (*seq_start)(struct seq_file___179 *, loff_t *);
	void * (*seq_next)(struct seq_file___179 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___179 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___161 *, struct cftype___160 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___161 *, struct cftype___160 *, s64);
	ssize_t (*write)(struct kernfs_open_file___186 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___186 *, struct poll_table_struct___130 *);
};

struct perf_cpu_context___115;

struct pmu___115 {
	struct list_head entry;
	struct module___161 *module;
	struct device___173 *dev;
	const struct attribute_group___174 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___115 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___115 *);
	void (*pmu_disable)(struct pmu___115 *);
	int (*event_init)(struct perf_event___115 *);
	void (*event_mapped)(struct perf_event___115 *, struct mm_struct___191 *);
	void (*event_unmapped)(struct perf_event___115 *, struct mm_struct___191 *);
	int (*add)(struct perf_event___115 *, int);
	void (*del)(struct perf_event___115 *, int);
	void (*start)(struct perf_event___115 *, int);
	void (*stop)(struct perf_event___115 *, int);
	void (*read)(struct perf_event___115 *);
	void (*start_txn)(struct pmu___115 *, unsigned int);
	int (*commit_txn)(struct pmu___115 *);
	void (*cancel_txn)(struct pmu___115 *);
	int (*event_idx)(struct perf_event___115 *);
	void (*sched_task)(struct perf_event_context___115 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___115 *);
	int (*filter_match)(struct perf_event___115 *);
	int (*check_period)(struct perf_event___115 *, u64);
};

struct perf_cpu_context___115 {
	struct perf_event_context___115 ctx;
	struct perf_event_context___115 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___115 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___115 {
	struct cgroup_subsys_state___161 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___108 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___108 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___108 *);
	struct list_head * (*get_fields)(struct trace_event_call___108 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___108 *);
};

struct syscall_metadata___53 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___108 *enter_event;
	struct trace_event_call___108 *exit_event;
};

struct bdi_writeback_congested___96 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___96 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___96 {
	struct bio___96 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___96 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___96 bip_inline_vecs[0];
};

struct bio_set___96 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___96 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___86 {
	struct mem_cgroup___86 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___86 {
	struct lruvec___191 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___86 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___86 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct mountpoint___9;

struct mount___9 {
	struct hlist_node mnt_hash;
	struct mount___9 *mnt_parent;
	struct dentry___191 *mnt_mountpoint;
	struct vfsmount___38 mnt;
	union {
		struct callback_head mnt_rcu;
		struct llist_node mnt_llist;
	};
	struct mnt_pcp *mnt_pcp;
	struct list_head mnt_mounts;
	struct list_head mnt_child;
	struct list_head mnt_instance;
	const char *mnt_devname;
	struct list_head mnt_list;
	struct list_head mnt_expire;
	struct list_head mnt_share;
	struct list_head mnt_slave_list;
	struct list_head mnt_slave;
	struct mount___9 *mnt_master;
	struct mnt_namespace___9 *mnt_ns;
	struct mountpoint___9 *mnt_mp;
	struct hlist_node mnt_mp_list;
	struct list_head mnt_umounting;
	struct fsnotify_mark_connector *mnt_fsnotify_marks;
	__u32 mnt_fsnotify_mask;
	int mnt_id;
	int mnt_group_id;
	int mnt_expiry_mark;
	struct hlist_head mnt_pins;
	struct fs_pin mnt_umount;
	struct dentry___191 *mnt_ex_mountpoint;
};

struct mountpoint___9 {
	struct hlist_node m_hash;
	struct dentry___191 *m_dentry;
	struct hlist_head m_list;
	int m_count;
};

struct fanotify_event_info___2 {
	struct fsnotify_event___10 fse;
	struct path___191 path;
	struct pid___151 *pid;
};

struct fanotify_perm_event_info___2 {
	struct fanotify_event_info___2 fae;
	int response;
	int fd;
};

struct module___162;

struct file___193;

struct kiocb___193;

struct iov_iter___93;

struct poll_table_struct___131;

struct vm_area_struct___193;

struct inode___193;

struct file_lock___193;

struct page___193;

struct pipe_inode_info___43;

struct seq_file___180;

struct file_operations___193 {
	struct module___162 *owner;
	loff_t (*llseek)(struct file___193 *, loff_t, int);
	ssize_t (*read)(struct file___193 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___193 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___193 *, struct iov_iter___93 *);
	ssize_t (*write_iter)(struct kiocb___193 *, struct iov_iter___93 *);
	int (*iopoll)(struct kiocb___193 *, bool);
	int (*iterate)(struct file___193 *, struct dir_context *);
	int (*iterate_shared)(struct file___193 *, struct dir_context *);
	__poll_t (*poll)(struct file___193 *, struct poll_table_struct___131 *);
	long int (*unlocked_ioctl)(struct file___193 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___193 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___193 *, struct vm_area_struct___193 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___193 *, struct file___193 *);
	int (*flush)(struct file___193 *, fl_owner_t);
	int (*release)(struct inode___193 *, struct file___193 *);
	int (*fsync)(struct file___193 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___193 *, int);
	int (*lock)(struct file___193 *, int, struct file_lock___193 *);
	ssize_t (*sendpage)(struct file___193 *, struct page___193 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___193 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___193 *, int, struct file_lock___193 *);
	ssize_t (*splice_write)(struct pipe_inode_info___43 *, struct file___193 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___193 *, loff_t *, struct pipe_inode_info___43 *, size_t, unsigned int);
	int (*setlease)(struct file___193 *, long int, struct file_lock___193 **, void **);
	long int (*fallocate)(struct file___193 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___180 *, struct file___193 *);
	ssize_t (*copy_file_range)(struct file___193 *, loff_t, struct file___193 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___193 *, loff_t, struct file___193 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___193 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___192 {
	u64 seqnum;
	struct vm_area_struct___193 *vmas[4];
};

struct page_frag___192 {
	struct page___193 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___116;

struct debug_info___116 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___116 *hbp_break[16];
	struct perf_event___116 *hbp_watch[16];
};

struct thread_struct___116 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___116 debug;
	long: 64;
};

struct mm_struct___192;

struct mem_cgroup___87;

struct pid___152;

struct cred___187;

struct nsproxy___182;

struct signal_struct___169;

struct bio_list___97;

struct backing_dev_info___97;

struct css_set___161;

struct perf_event_context___116;

struct vm_struct___134;

struct task_struct___193 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___193 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___192 *mm;
	struct mm_struct___192 *active_mm;
	struct vmacache___192 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___193 *real_parent;
	struct task_struct___193 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___193 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___87 *active_memcg;
	long int rh_reserved2;
	struct pid___152 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___152 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___152 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___187 *ptracer_cred;
	const struct cred___187 *real_cred;
	const struct cred___187 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___182 *nsproxy;
	struct signal_struct___169 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___193 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___97 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___97 *backing_dev_info;
	struct io_context___49 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___161 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___116 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___43 *splice_pipe;
	struct page_frag___192 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___87 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___193 *oom_reaper_list;
	struct vm_struct___134 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___116 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___116 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___193 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___116)(struct perf_event___116 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___116;

struct fasync_struct___192;

struct pid_namespace___152;

struct bpf_prog___22;

struct trace_event_call___109;

struct perf_cgroup___116;

struct perf_event___116 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___116 *group_leader;
	struct pmu___116 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___116 hw;
	struct perf_event_context___116 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___116 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___193 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___192 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___116 *);
	struct callback_head callback_head;
	struct pid_namespace___152 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___116 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___116 orig_overflow_handler;
	struct bpf_prog___22 *prog;
	struct trace_event_call___109 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___116 *cgrp;
	struct list_head sb_list;
};

struct key___187;

struct user_struct___187 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___187 *uid_keyring;
	struct key___187 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct upid___152 {
	int nr;
	struct pid_namespace___152 *ns;
};

struct vfsmount___39;

struct dentry___192;

struct user_namespace___170;

struct ucounts___170;

struct pid_namespace___152 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___193 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___152 *parent;
	struct vfsmount___39 *proc_mnt;
	struct dentry___192 *proc_self;
	struct dentry___192 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___170 *user_ns;
	struct ucounts___170 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___11 ns;
};

struct pid___152 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___152 numbers[1];
};

struct rw_semaphore___193 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___193 *owner;
};

struct user_namespace___170 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___170 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___11 ns;
	long unsigned int flags;
	struct key___187 *persistent_keyring_register;
	struct rw_semaphore___193 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___170 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct secondary_data___193 {
	void *stack;
	struct task_struct___193 *task;
	long int status;
};

typedef struct page___193 *pgtable_t___192;

struct address_space___192;

struct dev_pagemap___189;

struct page___193 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___192 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___193 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___192 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___192 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___189 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___87 *mem_cgroup;
};

struct vm_operations_struct___189;

struct vm_area_struct___193 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___193 *vm_next;
	struct vm_area_struct___193 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___192 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___189 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___193 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___192;

struct mm_struct___192 {
	struct {
		struct vm_area_struct___193 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___193 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___193 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___192 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___193 *owner;
		struct user_namespace___170 *user_ns;
		struct file___193 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___192 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup___161;

struct cgroup_subsys___161;

struct cgroup_subsys_state___162 {
	struct cgroup___161 *cgroup;
	struct cgroup_subsys___161 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___162 *parent;
};

struct kernfs_node___187;

struct cgroup_file___161 {
	struct kernfs_node___187 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___87;

struct mem_cgroup___87 {
	struct cgroup_subsys_state___162 css;
	struct mem_cgroup_id___14 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___161 events_file;
	struct cgroup_file___161 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___193 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___87 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cred___187 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___187 *session_keyring;
	struct key___187 *process_keyring;
	struct key___187 *thread_keyring;
	struct key___187 *request_key_auth;
	void *security;
	struct user_struct___187 *user;
	struct user_namespace___170 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___33;

struct cgroup_namespace___161;

struct nsproxy___182 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___152 *pid_ns_for_children;
	struct net___33 *net_ns;
	struct cgroup_namespace___161 *cgroup_ns;
};

struct signal_struct___169 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___193 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___193 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___152 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___152 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___192 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___152 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___97;

struct bio_list___97 {
	struct bio___97 *head;
	struct bio___97 *tail;
};

struct bdi_writeback_congested___97;

struct bdi_writeback___97 {
	struct backing_dev_info___97 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___97 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___162 *memcg_css;
	struct cgroup_subsys_state___162 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___174;

struct backing_dev_info___97 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___97 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___174 *dev;
	struct device___174 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___192 *debug_dir;
	struct dentry___192 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___161 {
	struct cgroup_subsys_state___162 *subsys[13];
	refcount_t refcount;
	struct css_set___161 *dom_cset;
	struct cgroup___161 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___161 *mg_src_cgrp;
	struct cgroup___161 *mg_dst_cgrp;
	struct css_set___161 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___116 {
	struct pmu___116 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___193 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___116 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___43;

struct pipe_inode_info___43 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___193 *tmp_page;
	struct fasync_struct___192 *fasync_readers;
	struct fasync_struct___192 *fasync_writers;
	struct pipe_buffer___43 *bufs;
	struct user_struct___187 *user;
};

struct vm_struct___134 {
	struct vm_struct___134 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___193 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___171 {
	struct task_struct___193 task;
	long unsigned int stack[8192];
};

typedef int (*key_restrict_link_func_t___187)(struct key___187 *, const struct key_type *, const union key_payload *, struct key___187 *);

struct key_restriction___187;

struct key___187 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___193 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___187 *restrict_link;
};

struct key_restriction___187 {
	key_restrict_link_func_t___187 check;
	struct key___187 *key;
	struct key_type *keytype;
};

struct dentry_operations___192;

struct super_block___192;

struct dentry___192 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___192 *d_parent;
	struct qstr d_name;
	struct inode___193 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___192 *d_op;
	struct super_block___192 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___192;

struct address_space___192 {
	struct inode___193 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___193 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___192 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___192;

struct block_device___193;

struct inode___193 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___192 *i_op;
	struct super_block___192 *i_sb;
	struct address_space___192 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___193 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___97 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___193 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___192 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___43 *i_pipe;
		struct block_device___193 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___192;

struct dentry_operations___192 {
	int (*d_revalidate)(struct dentry___192 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___192 *, unsigned int);
	int (*d_hash)(const struct dentry___192 *, struct qstr *);
	int (*d_compare)(const struct dentry___192 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___192 *);
	int (*d_init)(struct dentry___192 *);
	void (*d_release)(struct dentry___192 *);
	void (*d_prune)(struct dentry___192 *);
	void (*d_iput)(struct dentry___192 *, struct inode___193 *);
	char * (*d_dname)(struct dentry___192 *, char *, int);
	struct vfsmount___39 * (*d_automount)(struct path___192 *);
	int (*d_manage)(const struct path___192 *, bool);
	struct dentry___192 * (*d_real)(struct dentry___192 *, const struct inode___193 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___192;

struct mem_dqinfo___192 {
	struct quota_format_type___192 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___192;

struct quota_info___192 {
	unsigned int flags;
	struct rw_semaphore___193 dqio_sem;
	struct inode___193 *files[3];
	struct mem_dqinfo___192 info[3];
	const struct quota_format_ops___192 *ops[3];
};

struct rcuwait___192 {
	struct task_struct___193 *task;
};

struct percpu_rw_semaphore___192 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___193 rw_sem;
	struct rcuwait___192 writer;
	int readers_block;
};

struct sb_writers___192 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___192 rw_sem[3];
};

struct shrink_control___87;

struct shrinker___87 {
	long unsigned int (*count_objects)(struct shrinker___87 *, struct shrink_control___87 *);
	long unsigned int (*scan_objects)(struct shrinker___87 *, struct shrink_control___87 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___192;

struct super_operations___192;

struct dquot_operations___192;

struct quotactl_ops___192;

struct super_block___192 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___192 *s_type;
	const struct super_operations___192 *s_op;
	const struct dquot_operations___192 *dq_op;
	const struct quotactl_ops___192 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___192 *s_root;
	struct rw_semaphore___193 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___193 *s_bdev;
	struct backing_dev_info___97 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___192 s_dquot;
	struct sb_writers___192 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___192 *s_d_op;
	int cleancache_poolid;
	struct shrinker___87 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___170 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___39 {
	struct dentry___192 *mnt_root;
	struct super_block___192 *mnt_sb;
	int mnt_flags;
};

struct path___192 {
	struct vfsmount___39 *mnt;
	struct dentry___192 *dentry;
};

struct shrink_control___87 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___87 *memcg;
};

struct pglist_data___192;

struct lruvec___192 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___192 *pgdat;
};

struct zone___192 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___192 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___192 {
	struct zone___192 *zone;
	int zone_idx;
};

struct zonelist___192 {
	struct zoneref___192 _zonerefs[25];
};

struct pglist_data___192 {
	struct zone___192 node_zones[3];
	struct zonelist___192 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___193 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___193 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___192 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___192 {
	struct rw_semaphore___193 rwsem;
	struct notifier_block *head;
};

typedef int (*dev_page_fault_t___189)(struct vm_area_struct___193 *, long unsigned int, const struct page___193 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___189)(struct page___193 *, void *);

struct dev_pagemap___189 {
	dev_page_fault_t___189 page_fault;
	dev_page_free_t___189 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___174 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct fown_struct___152 {
	rwlock_t lock;
	struct pid___152 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___193 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___192 f_path;
	struct inode___193 *f_inode;
	const struct file_operations___193 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___152 f_owner;
	const struct cred___187 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___192 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___189;

struct vm_operations_struct___189 {
	void (*open)(struct vm_area_struct___193 *);
	void (*close)(struct vm_area_struct___193 *);
	int (*split)(struct vm_area_struct___193 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___193 *);
	vm_fault_t (*fault)(struct vm_fault___189 *);
	vm_fault_t (*huge_fault)(struct vm_fault___189 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___189 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___193 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___189 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___189 *);
	int (*access)(struct vm_area_struct___193 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___193 *);
	int (*set_policy)(struct vm_area_struct___193 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___193 *, long unsigned int);
	struct page___193 * (*find_special_page)(struct vm_area_struct___193 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___192 {
	struct task_struct___193 *task;
	struct core_thread___192 *next;
};

struct core_state___192 {
	atomic_t nr_threads;
	struct core_thread___192 dumper;
	struct completion startup;
};

struct vm_fault___189 {
	struct vm_area_struct___193 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___193 *cow_page;
	struct mem_cgroup___87 *memcg;
	struct page___193 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___192 prealloc_pte;
};

struct kiocb___193 {
	struct file___193 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___193 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___192 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___193 *ia_file;
};

struct dquot___192 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___192 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___192 {
	int qf_fmt_id;
	const struct quota_format_ops___192 *qf_ops;
	struct module___162 *qf_owner;
	struct quota_format_type___192 *qf_next;
};

struct quota_format_ops___192 {
	int (*check_quota_file)(struct super_block___192 *, int);
	int (*read_file_info)(struct super_block___192 *, int);
	int (*write_file_info)(struct super_block___192 *, int);
	int (*free_file_info)(struct super_block___192 *, int);
	int (*read_dqblk)(struct dquot___192 *);
	int (*commit_dqblk)(struct dquot___192 *);
	int (*release_dqblk)(struct dquot___192 *);
	int (*get_next_id)(struct super_block___192 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___192 {
	int (*write_dquot)(struct dquot___192 *);
	struct dquot___192 * (*alloc_dquot)(struct super_block___192 *, int);
	void (*destroy_dquot)(struct dquot___192 *);
	int (*acquire_dquot)(struct dquot___192 *);
	int (*release_dquot)(struct dquot___192 *);
	int (*mark_dirty)(struct dquot___192 *);
	int (*write_info)(struct super_block___192 *, int);
	qsize_t * (*get_reserved_space)(struct inode___193 *);
	int (*get_projid)(struct inode___193 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___193 *, qsize_t *);
	int (*get_next_id)(struct super_block___192 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___192 {
	int (*quota_on)(struct super_block___192 *, int, int, const struct path___192 *);
	int (*quota_off)(struct super_block___192 *, int);
	int (*quota_enable)(struct super_block___192 *, unsigned int);
	int (*quota_disable)(struct super_block___192 *, unsigned int);
	int (*quota_sync)(struct super_block___192 *, int);
	int (*set_info)(struct super_block___192 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___192 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___192 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___192 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___192 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___192 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___183;

struct kobj_type___183;

struct kobject___184 {
	const char *name;
	struct list_head entry;
	struct kobject___184 *parent;
	struct kset___183 *kset;
	struct kobj_type___183 *ktype;
	struct kernfs_node___187 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___159 {
	struct kobject___184 kobj;
	struct module___162 *mod;
	struct kobject___184 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___159 {
	struct module___162 *mod;
	struct latch_tree_node node;
};

struct module_layout___159 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___159 mtn;
};

struct module_attribute___159;

struct kernel_param___159;

struct module___162 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___159 mkobj;
	struct module_attribute___159 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___184 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___159 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___159 core_layout;
	struct module_layout___159 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___109 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___93;

struct address_space_operations___192 {
	int (*writepage)(struct page___193 *, struct writeback_control___93 *);
	int (*readpage)(struct file___193 *, struct page___193 *);
	int (*writepages)(struct address_space___192 *, struct writeback_control___93 *);
	int (*set_page_dirty)(struct page___193 *);
	int (*readpages)(struct file___193 *, struct address_space___192 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___193 *, struct address_space___192 *, loff_t, unsigned int, unsigned int, struct page___193 **, void **);
	int (*write_end)(struct file___193 *, struct address_space___192 *, loff_t, unsigned int, unsigned int, struct page___193 *, void *);
	sector_t (*bmap)(struct address_space___192 *, sector_t);
	void (*invalidatepage)(struct page___193 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___193 *, gfp_t);
	void (*freepage)(struct page___193 *);
	ssize_t (*direct_IO)(struct kiocb___193 *, struct iov_iter___93 *);
	int (*migratepage)(struct address_space___192 *, struct page___193 *, struct page___193 *, enum migrate_mode);
	bool (*isolate_page)(struct page___193 *, isolate_mode_t);
	void (*putback_page)(struct page___193 *);
	int (*launder_page)(struct page___193 *);
	int (*is_partially_uptodate)(struct page___193 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___193 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___192 *, struct page___193 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___193 *, sector_t *);
	void (*swap_deactivate)(struct file___193 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___93 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___97 *wb;
	struct inode___193 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___97;

struct iov_iter___93 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___97 *bvec;
		struct pipe_inode_info___43 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___193 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___193 *bd_inode;
	struct super_block___192 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___193 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___97 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___192 {
	struct dentry___192 * (*lookup)(struct inode___193 *, struct dentry___192 *, unsigned int);
	const char * (*get_link)(struct dentry___192 *, struct inode___193 *, struct delayed_call *);
	int (*permission)(struct inode___193 *, int);
	struct posix_acl * (*get_acl)(struct inode___193 *, int);
	int (*readlink)(struct dentry___192 *, char *, int);
	int (*create)(struct inode___193 *, struct dentry___192 *, umode_t, bool);
	int (*link)(struct dentry___192 *, struct inode___193 *, struct dentry___192 *);
	int (*unlink)(struct inode___193 *, struct dentry___192 *);
	int (*symlink)(struct inode___193 *, struct dentry___192 *, const char *);
	int (*mkdir)(struct inode___193 *, struct dentry___192 *, umode_t);
	int (*rmdir)(struct inode___193 *, struct dentry___192 *);
	int (*mknod)(struct inode___193 *, struct dentry___192 *, umode_t, dev_t);
	int (*rename)(struct inode___193 *, struct dentry___192 *, struct inode___193 *, struct dentry___192 *, unsigned int);
	int (*setattr)(struct dentry___192 *, struct iattr___192 *);
	int (*getattr)(const struct path___192 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___192 *, char *, size_t);
	int (*fiemap)(struct inode___193 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___193 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___193 *, struct dentry___192 *, struct file___193 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___193 *, struct dentry___192 *, umode_t);
	int (*set_acl)(struct inode___193 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___192 {
	void (*fl_copy_lock)(struct file_lock___193 *, struct file_lock___193 *);
	void (*fl_release_private)(struct file_lock___193 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___192;

struct file_lock___193 {
	struct file_lock___193 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___193 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___192 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___192 *fl_ops;
	const struct lock_manager_operations___192 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___192 {
	int (*lm_compare_owner)(struct file_lock___193 *, struct file_lock___193 *);
	long unsigned int (*lm_owner_key)(struct file_lock___193 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___193 *);
	int (*lm_grant)(struct file_lock___193 *, int);
	bool (*lm_break)(struct file_lock___193 *);
	int (*lm_change)(struct file_lock___193 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___193 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___192 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___192 *fa_next;
	struct file___193 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___192 {
	const char *name;
	int fs_flags;
	struct dentry___192 * (*mount)(struct file_system_type___192 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___192 *);
	struct module___162 *owner;
	struct file_system_type___192 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___192 {
	struct inode___193 * (*alloc_inode)(struct super_block___192 *);
	void (*destroy_inode)(struct inode___193 *);
	void (*dirty_inode)(struct inode___193 *, int);
	int (*write_inode)(struct inode___193 *, struct writeback_control___93 *);
	int (*drop_inode)(struct inode___193 *);
	void (*evict_inode)(struct inode___193 *);
	void (*put_super)(struct super_block___192 *);
	int (*sync_fs)(struct super_block___192 *, int);
	int (*freeze_super)(struct super_block___192 *);
	int (*freeze_fs)(struct super_block___192 *);
	int (*thaw_super)(struct super_block___192 *);
	int (*unfreeze_fs)(struct super_block___192 *);
	int (*statfs)(struct dentry___192 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___192 *, int *, char *);
	void (*umount_begin)(struct super_block___192 *);
	int (*show_options)(struct seq_file___180 *, struct dentry___192 *);
	int (*show_devname)(struct seq_file___180 *, struct dentry___192 *);
	int (*show_path)(struct seq_file___180 *, struct dentry___192 *);
	int (*show_stats)(struct seq_file___180 *, struct dentry___192 *);
	ssize_t (*quota_read)(struct super_block___192 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___192 *, int, const char *, size_t, loff_t);
	struct dquot___192 ** (*get_dquots)(struct inode___193 *);
	int (*bdev_try_to_free_page)(struct super_block___192 *, struct page___193 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___192 *, struct shrink_control___87 *);
	long int (*free_cached_objects)(struct super_block___192 *, struct shrink_control___87 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___132)(struct file___193 *, wait_queue_head_t *, struct poll_table_struct___131 *);

struct poll_table_struct___131 {
	poll_queue_proc___132 _qproc;
	__poll_t _key;
};

struct seq_operations___178;

struct seq_file___180 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___178 *op;
	int poll_event;
	const struct file___193 *file;
	void *private;
};

typedef void bio_end_io_t___97(struct bio___97 *);

struct bio_vec___97 {
	struct page___193 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___97;

struct bio_set___97;

struct bio___97 {
	struct bio___97 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___97 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___97 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___97 *bi_io_vec;
	struct bio_set___97 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___97 bi_inline_vecs[0];
};

struct fd___25 {
	struct file___193 *file;
	unsigned int flags;
};

struct dev_pm_info___174 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___174 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___174;

struct bus_type___174;

struct device_driver___174;

struct dev_pm_domain___174;

struct dma_map_ops___41;

struct fwnode_handle___121;

struct class___174;

struct attribute_group___175;

struct device___174 {
	struct device___174 *parent;
	struct device_private *p;
	struct kobject___184 kobj;
	const char *init_name;
	const struct device_type___174 *type;
	struct mutex mutex;
	struct bus_type___174 *bus;
	struct device_driver___174 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___174 power;
	struct dev_pm_domain___174 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___41 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___121 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___174 *class;
	const struct attribute_group___175 **groups;
	void (*release)(struct device___174 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct kobj_attribute___183 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___184 *, struct kobj_attribute___183 *, char *);
	ssize_t (*store)(struct kobject___184 *, struct kobj_attribute___183 *, const char *, size_t);
};

typedef void compound_page_dtor___189(struct page___193 *);

struct epoll_event {
	__poll_t events;
	__u64 data;
};

typedef struct poll_table_struct___131 poll_table___17;

struct seq_operations___178 {
	void * (*start)(struct seq_file___180 *, loff_t *);
	void (*stop)(struct seq_file___180 *, void *);
	void * (*next)(struct seq_file___180 *, void *, loff_t *);
	int (*show)(struct seq_file___180 *, void *);
};

struct inet_frags___23;

struct netns_frags___23 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___23 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ip_ra_chain___3;

struct fib_rules_ops___12;

struct sock___14;

struct fib_notifier_ops___12;

struct netns_ipv4___23 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___3 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___12 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___14 *fibnl;
	struct sock___14 **icmp_sk;
	struct sock___14 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___14 **tcp_sk;
	struct netns_frags___23 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___12 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___12 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___12 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct dst_entry___13;

struct net_device___27;

struct sk_buff___26;

struct neighbour___13;

struct dst_ops___31 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___31 *);
	struct dst_entry___13 * (*check)(struct dst_entry___13 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___13 *);
	unsigned int (*mtu)(const struct dst_entry___13 *);
	u32 * (*cow_metrics)(struct dst_entry___13 *, long unsigned int);
	void (*destroy)(struct dst_entry___13 *);
	void (*ifdown)(struct dst_entry___13 *, struct net_device___27 *, int);
	struct dst_entry___13 * (*negative_advice)(struct dst_entry___13 *);
	void (*link_failure)(struct sk_buff___26 *);
	void (*update_pmtu)(struct dst_entry___13 *, struct sock___14 *, struct sk_buff___26 *, u32);
	void (*redirect)(struct dst_entry___13 *, struct sock___14 *, struct sk_buff___26 *);
	int (*local_out)(struct net___33 *, struct sock___14 *, struct sk_buff___26 *);
	struct neighbour___13 * (*neigh_lookup)(const struct dst_entry___13 *, struct sk_buff___26 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___13 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___31 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___23 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___31 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___12 *fib6_rules_ops;
	struct sock___14 **icmp_sk;
	struct sock___14 *ndisc_sk;
	struct sock___14 *tcp_sk;
	struct sock___14 *igmp_sk;
	struct sock___14 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___12 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___12 *notifier_ops;
	struct fib_notifier_ops___12 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___12 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___14 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___23 {
	struct netns_frags___23 frags;
};

struct netns_xfrm___31 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___14 *nlsk;
	struct sock___14 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___31 xfrm4_dst_ops;
	struct dst_ops___31 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct net___33 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___170 *user_ns;
	struct ucounts___170 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___11 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___14 *rtnl;
	struct sock___14 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___27 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___23 ipv4;
	struct netns_ipv6___31 ipv6;
	struct netns_sctp___12 sctp;
	struct netns_nf nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___23 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___14 *nfnl;
	struct sock___14 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___31 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___14 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___22 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cgroup_namespace___161 {
	refcount_t count;
	struct ns_common___11 ns;
	struct user_namespace___170 *user_ns;
	struct ucounts___170 *ucounts;
	struct css_set___161 *root_cset;
};

struct ucounts___170 {
	struct hlist_node node;
	struct user_namespace___170 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct kernfs_root___187;

struct kernfs_elem_dir___187 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___187 *root;
};

struct kernfs_syscall_ops___187;

struct kernfs_root___187 {
	struct kernfs_node___187 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___187 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___187 {
	struct kernfs_node___187 *target_kn;
};

struct kernfs_ops___187;

struct kernfs_elem_attr___187 {
	const struct kernfs_ops___187 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___187 *notify_next;
};

struct kernfs_node___187 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___187 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___187 dir;
		struct kernfs_elem_symlink___187 symlink;
		struct kernfs_elem_attr___187 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___187;

struct kernfs_ops___187 {
	int (*open)(struct kernfs_open_file___187 *);
	void (*release)(struct kernfs_open_file___187 *);
	int (*seq_show)(struct seq_file___180 *, void *);
	void * (*seq_start)(struct seq_file___180 *, loff_t *);
	void * (*seq_next)(struct seq_file___180 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___180 *, void *);
	ssize_t (*read)(struct kernfs_open_file___187 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___187 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___187 *, struct vm_area_struct___193 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___187 *, struct poll_table_struct___131 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___187 {
	int (*remount_fs)(struct kernfs_root___187 *, int *, char *);
	int (*show_options)(struct seq_file___180 *, struct kernfs_root___187 *);
	int (*mkdir)(struct kernfs_node___187 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___187 *);
	int (*rename)(struct kernfs_node___187 *, struct kernfs_node___187 *, const char *);
	int (*show_path)(struct seq_file___180 *, struct kernfs_node___187 *, struct kernfs_root___187 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___187 {
	struct kernfs_node___187 *kn;
	struct file___193 *file;
	struct seq_file___180 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___189 *vm_ops;
};

struct kobj_ns_type_operations___12 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___14 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___33 *net;
} possible_net_t___24;

struct proto___12;

struct sock_common___12 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___12 *skc_prot;
	possible_net_t___24 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___14 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff_head___23 {
	struct sk_buff___26 *next;
	struct sk_buff___26 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___12;

struct socket_wq___12;

struct socket___12;

struct sock___14 {
	struct sock_common___12 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___23 sk_error_queue;
	struct sk_buff_head___23 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___26 *head;
		struct sk_buff___26 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___12 *sk_filter;
	union {
		struct socket_wq___12 *sk_wq;
		struct socket_wq___12 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___13 *sk_rx_dst;
	struct dst_entry___13 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___26 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___23 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___192 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___12 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___152 *sk_peer_pid;
	const struct cred___187 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___12 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___87 *sk_memcg;
	void (*sk_state_change)(struct sock___14 *);
	void (*sk_data_ready)(struct sock___14 *);
	void (*sk_write_space)(struct sock___14 *);
	void (*sk_error_report)(struct sock___14 *);
	int (*sk_backlog_rcv)(struct sock___14 *, struct sk_buff___26 *);
	struct sk_buff___26 * (*sk_validate_xmit_skb)(struct sock___14 *, struct net_device___27 *, struct sk_buff___26 *);
	void (*sk_destruct)(struct sock___14 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct bin_attribute___174;

struct attribute_group___175 {
	const char *name;
	umode_t (*is_visible)(struct kobject___184 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___184 *, struct bin_attribute___174 *, int);
	struct attribute **attrs;
	struct bin_attribute___174 **bin_attrs;
};

struct bin_attribute___174 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___193 *, struct kobject___184 *, struct bin_attribute___174 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___193 *, struct kobject___184 *, struct bin_attribute___174 *, char *, loff_t, size_t);
	int (*mmap)(struct file___193 *, struct kobject___184 *, struct bin_attribute___174 *, struct vm_area_struct___193 *);
};

struct sysfs_ops___183 {
	ssize_t (*show)(struct kobject___184 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___184 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___183;

struct kset___183 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___184 kobj;
	const struct kset_uevent_ops___183 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___183 {
	void (*release)(struct kobject___184 *);
	const struct sysfs_ops___183 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___12 * (*child_ns_type)(struct kobject___184 *);
	const void * (*namespace)(struct kobject___184 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___183 {
	int (* const filter)(struct kset___183 *, struct kobject___184 *);
	const char * (* const name)(struct kset___183 *, struct kobject___184 *);
	int (* const uevent)(struct kset___183 *, struct kobject___184 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___159 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___159 *);
	int (*get)(char *, const struct kernel_param___159 *);
	void (*free)(void *);
};

struct kparam_array___159;

struct kernel_param___159 {
	const char *name;
	struct module___162 *mod;
	const struct kernel_param_ops___159 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___159 *arr;
	};
};

struct kparam_array___159 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___159 *ops;
	void *elem;
};

struct module_attribute___159 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___159 *, struct module_kobject___159 *, char *);
	ssize_t (*store)(struct module_attribute___159 *, struct module_kobject___159 *, const char *, size_t);
	void (*setup)(struct module___162 *, const char *);
	int (*test)(struct module___162 *);
	void (*free)(struct module___162 *);
};

struct trace_event_class___109;

struct bpf_prog_array___22;

struct trace_event_call___109 {
	struct list_head list;
	struct trace_event_class___109 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___22 *prog_array;
	int (*perf_perm)(struct trace_event_call___109 *, struct perf_event___116 *);
};

struct msghdr___12 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___93 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___193 *msg_iocb;
};

struct dev_pm_ops___174 {
	int (*prepare)(struct device___174 *);
	void (*complete)(struct device___174 *);
	int (*suspend)(struct device___174 *);
	int (*resume)(struct device___174 *);
	int (*freeze)(struct device___174 *);
	int (*thaw)(struct device___174 *);
	int (*poweroff)(struct device___174 *);
	int (*restore)(struct device___174 *);
	int (*suspend_late)(struct device___174 *);
	int (*resume_early)(struct device___174 *);
	int (*freeze_late)(struct device___174 *);
	int (*thaw_early)(struct device___174 *);
	int (*poweroff_late)(struct device___174 *);
	int (*restore_early)(struct device___174 *);
	int (*suspend_noirq)(struct device___174 *);
	int (*resume_noirq)(struct device___174 *);
	int (*freeze_noirq)(struct device___174 *);
	int (*thaw_noirq)(struct device___174 *);
	int (*poweroff_noirq)(struct device___174 *);
	int (*restore_noirq)(struct device___174 *);
	int (*runtime_suspend)(struct device___174 *);
	int (*runtime_resume)(struct device___174 *);
	int (*runtime_idle)(struct device___174 *);
};

struct dev_pm_domain___174 {
	struct dev_pm_ops___174 ops;
	void (*detach)(struct device___174 *, bool);
	int (*activate)(struct device___174 *);
	void (*sync)(struct device___174 *);
	void (*dismiss)(struct device___174 *);
};

struct bus_type___174 {
	const char *name;
	const char *dev_name;
	struct device___174 *dev_root;
	const struct attribute_group___175 **bus_groups;
	const struct attribute_group___175 **dev_groups;
	const struct attribute_group___175 **drv_groups;
	int (*match)(struct device___174 *, struct device_driver___174 *);
	int (*uevent)(struct device___174 *, struct kobj_uevent_env *);
	int (*probe)(struct device___174 *);
	int (*remove)(struct device___174 *);
	void (*shutdown)(struct device___174 *);
	int (*online)(struct device___174 *);
	int (*offline)(struct device___174 *);
	int (*suspend)(struct device___174 *, pm_message_t);
	int (*resume)(struct device___174 *);
	int (*num_vf)(struct device___174 *);
	int (*dma_configure)(struct device___174 *);
	const struct dev_pm_ops___174 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___174 {
	const char *name;
	struct bus_type___174 *bus;
	struct module___162 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___174 *);
	int (*remove)(struct device___174 *);
	void (*shutdown)(struct device___174 *);
	int (*suspend)(struct device___174 *, pm_message_t);
	int (*resume)(struct device___174 *);
	const struct attribute_group___175 **groups;
	const struct dev_pm_ops___174 *pm;
	void (*coredump)(struct device___174 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___174 {
	const char *name;
	const struct attribute_group___175 **groups;
	int (*uevent)(struct device___174 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___174 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___174 *);
	const struct dev_pm_ops___174 *pm;
};

struct class___174 {
	const char *name;
	struct module___162 *owner;
	const struct attribute_group___175 **class_groups;
	const struct attribute_group___175 **dev_groups;
	struct kobject___184 *dev_kobj;
	int (*dev_uevent)(struct device___174 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___174 *, umode_t *);
	void (*class_release)(struct class___174 *);
	void (*dev_release)(struct device___174 *);
	int (*shutdown_pre)(struct device___174 *);
	const struct kobj_ns_type_operations___12 *ns_type;
	const void * (*namespace)(struct device___174 *);
	const struct dev_pm_ops___174 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___41 {
	void * (*alloc)(struct device___174 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___174 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___174 *, struct vm_area_struct___193 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___174 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___174 *, struct page___193 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___174 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___174 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___174 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___174 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___174 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___174 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide21;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___174 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___174 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___174 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___174 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___174 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___174 *, u64);
	u64 (*get_required_mask)(struct device___174 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___121;

struct fwnode_handle___121 {
	struct fwnode_handle___121 *secondary;
	const struct fwnode_operations___121 *ops;
};

struct node___149 {
	struct device___174 dev;
};

struct bpf_map___161;

struct bpf_map_ops___161 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___161 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___161 *, struct file___193 *);
	void (*map_free)(struct bpf_map___161 *);
	int (*map_get_next_key)(struct bpf_map___161 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___161 *);
	void * (*map_lookup_elem)(struct bpf_map___161 *, void *);
	int (*map_update_elem)(struct bpf_map___161 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___161 *, void *);
	int (*map_push_elem)(struct bpf_map___161 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___161 *, void *);
	int (*map_peek_elem)(struct bpf_map___161 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___161 *, struct file___193 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___161 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___161 *, void *, struct seq_file___180 *);
	int (*map_check_btf)(const struct bpf_map___161 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___161 {
	const struct bpf_map_ops___161 *ops;
	struct bpf_map___161 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___187 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___23;

struct bpf_map_dev_ops___23 {
	int (*map_get_next_key)(struct bpf_offloaded_map___23 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___23 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___23 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___23 *, void *);
};

struct bpf_offloaded_map___23 {
	struct bpf_map___161 map;
	struct net_device___27 *netdev;
	const struct bpf_map_dev_ops___23 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

typedef rx_handler_result_t rx_handler_func_t___23(struct sk_buff___26 **);

struct net_device_ops___23;

struct ethtool_ops___23;

struct l3mdev_ops___13;

struct ndisc_ops___7;

struct xfrmdev_ops___23;

struct tlsdev_ops___23;

struct header_ops___23;

struct inet6_dev___7;

struct netdev_rx_queue___23;

struct mini_Qdisc___22;

struct netdev_queue___23;

struct Qdisc___22;

struct rtnl_link_ops___22;

struct dcbnl_rtnl_ops___23;

struct net_device___27 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___23 *netdev_ops;
	const struct ethtool_ops___23 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___13 *l3mdev_ops;
	const struct ndisc_ops___7 *ndisc_ops;
	const struct xfrmdev_ops___23 *xfrmdev_ops;
	const struct tlsdev_ops___23 *tlsdev_ops;
	const struct header_ops___23 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___183 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___7 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___23 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___22 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___23 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___22 *miniq_ingress;
	struct netdev_queue___23 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___23 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___22 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___22 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___23 = 0,
		NETREG_REGISTERED___23 = 1,
		NETREG_UNREGISTERING___23 = 2,
		NETREG_UNREGISTERED___23 = 3,
		NETREG_RELEASED___23 = 4,
		NETREG_DUMMY___23 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___23 = 0,
		RTNL_LINK_INITIALIZING___23 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___27 *);
	struct netpoll_info *npinfo;
	possible_net_t___24 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___174 dev;
	const struct attribute_group___175 *sysfs_groups[4];
	const struct attribute_group___175 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___22 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___23 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide37;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct bpf_prog_ops___22 {
	int (*test_run)(struct bpf_prog___22 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_aux___22;

struct bpf_prog___22 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___22 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

struct bpf_verifier_ops___22 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___22 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___22 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___22 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___22 *, u32 *);
};

struct bpf_prog_offload_ops___22 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___22 *);
	int (*translate)(struct bpf_prog___22 *);
	void (*destroy)(struct bpf_prog___22 *);
};

struct bpf_prog_offload___22 {
	struct bpf_prog___22 *prog;
	struct net_device___27 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___22 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___22 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___22 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___22 *ops;
	struct bpf_map___161 **used_maps;
	struct bpf_prog___22 *prog;
	struct user_struct___187 *user;
	u64 load_time;
	struct bpf_map___161 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___22 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___22 {
	struct bpf_prog___22 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___22 {
	struct callback_head rcu;
	struct bpf_prog_array_item___22 items[0];
};

struct cgroup_bpf___22 {
	struct bpf_prog_array___22 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___22 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___161;

typedef void (*kthread_work_func_t___161)(struct kthread_work___161 *);

struct kthread_worker___161;

struct kthread_work___161 {
	struct list_head node;
	kthread_work_func_t___161 func;
	struct kthread_worker___161 *worker;
	int canceling;
};

struct kthread_worker___161 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___193 *task;
	struct kthread_work___161 *current_work;
};

struct kthread_delayed_work___161 {
	struct kthread_work___161 work;
	struct timer_list timer;
};

struct psi_group___161 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___161 *poll_kworker;
	struct kthread_delayed_work___161 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___161;

struct cgroup_rstat_cpu___161;

struct cgroup___161 {
	struct cgroup_subsys_state___162 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___187 *kn;
	struct cgroup_file___161 procs_file;
	struct cgroup_file___161 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___162 *subsys[13];
	struct cgroup_root___161 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___161 *dom_cgrp;
	struct cgroup_rstat_cpu___161 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___22 bpf;
	atomic_t congestion_count;
	struct cgroup___161 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___161 psi;
	int ancestor_ids[0];
};

struct cftype___161;

struct cgroup_subsys___161 {
	struct cgroup_subsys_state___162 * (*css_alloc)(struct cgroup_subsys_state___162 *);
	int (*css_online)(struct cgroup_subsys_state___162 *);
	void (*css_offline)(struct cgroup_subsys_state___162 *);
	void (*css_released)(struct cgroup_subsys_state___162 *);
	void (*css_free)(struct cgroup_subsys_state___162 *);
	void (*css_reset)(struct cgroup_subsys_state___162 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___162 *, int);
	int (*css_extra_stat_show)(struct seq_file___180 *, struct cgroup_subsys_state___162 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___193 *);
	void (*cancel_fork)(struct task_struct___193 *);
	void (*fork)(struct task_struct___193 *);
	void (*exit)(struct task_struct___193 *);
	void (*free)(struct task_struct___193 *);
	void (*bind)(struct cgroup_subsys_state___162 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___161 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___161 *dfl_cftypes;
	struct cftype___161 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___161 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___161 *updated_children;
	struct cgroup___161 *updated_next;
};

struct cgroup_root___161 {
	struct kernfs_root___187 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___161 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___161 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___161 *ss;
	struct list_head node;
	struct kernfs_ops___187 *kf_ops;
	int (*open)(struct kernfs_open_file___187 *);
	void (*release)(struct kernfs_open_file___187 *);
	u64 (*read_u64)(struct cgroup_subsys_state___162 *, struct cftype___161 *);
	s64 (*read_s64)(struct cgroup_subsys_state___162 *, struct cftype___161 *);
	int (*seq_show)(struct seq_file___180 *, void *);
	void * (*seq_start)(struct seq_file___180 *, loff_t *);
	void * (*seq_next)(struct seq_file___180 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___180 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___162 *, struct cftype___161 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___162 *, struct cftype___161 *, s64);
	ssize_t (*write)(struct kernfs_open_file___187 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___187 *, struct poll_table_struct___131 *);
};

struct perf_cpu_context___116;

struct pmu___116 {
	struct list_head entry;
	struct module___162 *module;
	struct device___174 *dev;
	const struct attribute_group___175 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___116 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___116 *);
	void (*pmu_disable)(struct pmu___116 *);
	int (*event_init)(struct perf_event___116 *);
	void (*event_mapped)(struct perf_event___116 *, struct mm_struct___192 *);
	void (*event_unmapped)(struct perf_event___116 *, struct mm_struct___192 *);
	int (*add)(struct perf_event___116 *, int);
	void (*del)(struct perf_event___116 *, int);
	void (*start)(struct perf_event___116 *, int);
	void (*stop)(struct perf_event___116 *, int);
	void (*read)(struct perf_event___116 *);
	void (*start_txn)(struct pmu___116 *, unsigned int);
	int (*commit_txn)(struct pmu___116 *);
	void (*cancel_txn)(struct pmu___116 *);
	int (*event_idx)(struct perf_event___116 *);
	void (*sched_task)(struct perf_event_context___116 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___116 *);
	int (*filter_match)(struct perf_event___116 *);
	int (*check_period)(struct perf_event___116 *, u64);
};

struct perf_cpu_context___116 {
	struct perf_event_context___116 ctx;
	struct perf_event_context___116 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___116 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___116 {
	struct cgroup_subsys_state___162 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___109 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___109 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___109 *);
	struct list_head * (*get_fields)(struct trace_event_call___109 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___109 *);
};

struct syscall_metadata___54 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___109 *enter_event;
	struct trace_event_call___109 *exit_event;
};

struct fwnode_reference_args___121;

struct fwnode_endpoint___121;

struct fwnode_operations___121 {
	struct fwnode_handle___121 * (*get)(struct fwnode_handle___121 *);
	void (*put)(struct fwnode_handle___121 *);
	bool (*device_is_available)(const struct fwnode_handle___121 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___121 *, const struct device___174 *);
	bool (*property_present)(const struct fwnode_handle___121 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___121 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___121 *, const char *, const char **, size_t);
	struct fwnode_handle___121 * (*get_parent)(const struct fwnode_handle___121 *);
	struct fwnode_handle___121 * (*get_next_child_node)(const struct fwnode_handle___121 *, struct fwnode_handle___121 *);
	struct fwnode_handle___121 * (*get_named_child_node)(const struct fwnode_handle___121 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___121 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___121 *);
	struct fwnode_handle___121 * (*graph_get_next_endpoint)(const struct fwnode_handle___121 *, struct fwnode_handle___121 *);
	struct fwnode_handle___121 * (*graph_get_remote_endpoint)(const struct fwnode_handle___121 *);
	struct fwnode_handle___121 * (*graph_get_port_parent)(struct fwnode_handle___121 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___121 *, struct fwnode_endpoint___121 *);
};

struct fwnode_endpoint___121 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___121 *local_fwnode;
};

struct fwnode_reference_args___121 {
	struct fwnode_handle___121 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct socket_wq___12 {
	wait_queue_head_t wait;
	struct fasync_struct___192 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___12;

struct socket___12 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___12 *wq;
	struct file___193 *file;
	struct sock___14 *sk;
	const struct proto_ops___12 *ops;
};

typedef int (*sk_read_actor_t___12)(read_descriptor_t *, struct sk_buff___26 *, unsigned int, size_t);

struct proto_ops___12 {
	int family;
	struct module___162 *owner;
	int (*release)(struct socket___12 *);
	int (*bind)(struct socket___12 *, struct sockaddr *, int);
	int (*connect)(struct socket___12 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___12 *, struct socket___12 *);
	int (*accept)(struct socket___12 *, struct socket___12 *, int, bool);
	int (*getname)(struct socket___12 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___193 *, struct socket___12 *, struct poll_table_struct___131 *);
	int (*ioctl)(struct socket___12 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___12 *, int);
	int (*shutdown)(struct socket___12 *, int);
	int (*setsockopt)(struct socket___12 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___12 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___12 *, struct msghdr___12 *, size_t);
	int (*recvmsg)(struct socket___12 *, struct msghdr___12 *, size_t, int);
	int (*mmap)(struct file___193 *, struct socket___12 *, struct vm_area_struct___193 *);
	ssize_t (*sendpage)(struct socket___12 *, struct page___193 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___12 *, loff_t *, struct pipe_inode_info___43 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___14 *, int);
	int (*peek_len)(struct socket___12 *);
	int (*read_sock)(struct sock___14 *, read_descriptor_t *, sk_read_actor_t___12);
	int (*sendpage_locked)(struct sock___14 *, struct page___193 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___14 *, struct msghdr___12 *, size_t);
	int (*set_rcvlowat)(struct sock___14 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct nf_bridge_info___23;

struct sk_buff___26 {
	union {
		struct {
			struct sk_buff___26 *next;
			struct sk_buff___26 *prev;
			union {
				struct net_device___27 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___14 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___26 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___23 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct pipe_buf_operations___43;

struct pipe_buffer___43 {
	struct page___193 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___43 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___43 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___43 *, struct pipe_buffer___43 *);
	void (*release)(struct pipe_inode_info___43 *, struct pipe_buffer___43 *);
	int (*steal)(struct pipe_inode_info___43 *, struct pipe_buffer___43 *);
	union {
		bool (*get)(struct pipe_inode_info___43 *, struct pipe_buffer___43 *);
		struct {
			void (*get)(struct pipe_inode_info___43 *, struct pipe_buffer___43 *);
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
};

struct nf_bridge_info___23 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___23 = 0,
		BRNF_PROTO_8021Q___23 = 1,
		BRNF_PROTO_PPPOE___23 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___27 *physindev;
	struct net_device___27 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

struct ethtool_ops___23 {
	int (*get_settings)(struct net_device___27 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___27 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___27 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___27 *);
	void (*get_regs)(struct net_device___27 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___27 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___27 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___27 *);
	void (*set_msglevel)(struct net_device___27 *, u32);
	int (*nway_reset)(struct net_device___27 *);
	u32 (*get_link)(struct net_device___27 *);
	int (*get_eeprom_len)(struct net_device___27 *);
	int (*get_eeprom)(struct net_device___27 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___27 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___27 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___27 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___27 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___27 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___27 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___27 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___27 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___27 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___27 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___27 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___27 *);
	void (*complete)(struct net_device___27 *);
	u32 (*get_priv_flags)(struct net_device___27 *);
	int (*set_priv_flags)(struct net_device___27 *, u32);
	int (*get_sset_count)(struct net_device___27 *, int);
	int (*get_rxnfc)(struct net_device___27 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___27 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___27 *, struct ethtool_flash *);
	int (*reset)(struct net_device___27 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___27 *);
	u32 (*get_rxfh_indir_size)(struct net_device___27 *);
	int (*get_rxfh)(struct net_device___27 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___27 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___27 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___27 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___27 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___27 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___27 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___27 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___27 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___27 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___27 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___27 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___27 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___27 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___27 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___27 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___27 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___27 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___27 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___27 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___27 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___27 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	int (*get_fecparam)(struct net_device___27 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___27 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___27 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___27 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___27 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___23;

struct inet_frags___23 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___23 *, const void *);
	void (*destructor)(struct inet_frag_queue___23 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___23 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___26 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___26 *fragments_tail;
	struct sk_buff___26 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___23 *net;
	struct callback_head rcu;
};

struct ip_ra_chain___3 {
	struct ip_ra_chain___3 *next;
	struct sock___14 *sk;
	union {
		void (*destructor)(struct sock___14 *);
		struct sock___14 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___12;

struct fib_lookup_arg___12;

struct fib_rules_ops___12 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___12 *, struct flowi *, int, struct fib_lookup_arg___12 *);
	bool (*suppress)(struct fib_rule___12 *, struct fib_lookup_arg___12 *);
	int (*match)(struct fib_rule___12 *, struct flowi *, int);
	int (*configure)(struct fib_rule___12 *, struct sk_buff___26 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___12 *);
	int (*compare)(struct fib_rule___12 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___12 *, struct sk_buff___26 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___12 *);
	void (*flush_cache)(struct fib_rules_ops___12 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___162 *owner;
	struct net___33 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___12 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___33 *);
	int (*fib_dump)(struct net___33 *, struct notifier_block *);
	struct module___162 *owner;
	struct callback_head rcu;
};

struct dst_entry___13 {
	struct net_device___27 *dev;
	struct dst_ops___31 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___26 *);
	int (*output)(struct net___33 *, struct sock___14 *, struct sk_buff___26 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___12;

struct neigh_parms___13;

struct neigh_ops___12;

struct neighbour___13 {
	struct neighbour___13 *next;
	struct neigh_table___12 *tbl;
	struct neigh_parms___13 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___23 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___13 *, struct sk_buff___26 *);
	const struct neigh_ops___12 *ops;
	struct callback_head rcu;
	struct net_device___27 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct pernet_operations___23 {
	struct list_head list;
	int (*init)(struct net___33 *);
	void (*exit)(struct net___33 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___23 {
	int (*ieee_getets)(struct net_device___27 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___27 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___27 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___27 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___27 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___27 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___27 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___27 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___27 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___27 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___27 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___27 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___27 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___27 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___27 *);
	u8 (*setstate)(struct net_device___27 *, u8);
	void (*getpermhwaddr)(struct net_device___27 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___27 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___27 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___27 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___27 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___27 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___27 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___27 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___27 *, int, u8 *);
	void (*setpfccfg)(struct net_device___27 *, int, u8);
	void (*getpfccfg)(struct net_device___27 *, int, u8 *);
	u8 (*setall)(struct net_device___27 *);
	u8 (*getcap)(struct net_device___27 *, int, u8 *);
	int (*getnumtcs)(struct net_device___27 *, int, u8 *);
	int (*setnumtcs)(struct net_device___27 *, int, u8);
	u8 (*getpfcstate)(struct net_device___27 *);
	void (*setpfcstate)(struct net_device___27 *, u8);
	void (*getbcncfg)(struct net_device___27 *, int, u32 *);
	void (*setbcncfg)(struct net_device___27 *, int, u32);
	void (*getbcnrp)(struct net_device___27 *, int, u8 *);
	void (*setbcnrp)(struct net_device___27 *, int, u8);
	int (*setapp)(struct net_device___27 *, u8, u16, u8);
	int (*getapp)(struct net_device___27 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___27 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___27 *, int, u8);
	u8 (*getdcbx)(struct net_device___27 *);
	u8 (*setdcbx)(struct net_device___27 *, u8);
	int (*peer_getappinfo)(struct net_device___27 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___27 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___27 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___27 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___27 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___27 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct xdp_rxq_info___23 {
	struct net_device___27 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___23 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___27 *dev_rx;
};

struct netlink_callback___23 {
	struct sk_buff___26 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___23 *);
	int (*dump)(struct sk_buff___26 *, struct netlink_callback___23 *);
	int (*done)(struct netlink_callback___23 *);
	void *data;
	struct module___162 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___23 {
	int (*create)(struct sk_buff___26 *, struct net_device___27 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___26 *, unsigned char *);
	int (*cache)(const struct neighbour___13 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___27 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___23 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___23 *, int);
	int poll_owner;
	struct net_device___27 *dev;
	struct sk_buff___26 *gro_list;
	struct sk_buff___26 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___23 {
	struct net_device___27 *dev;
	struct Qdisc___22 *qdisc;
	struct Qdisc___22 *qdisc_sleeping;
	struct kobject___184 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___27 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___22 {
	struct sk_buff___26 *head;
	struct sk_buff___26 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___22;

struct Qdisc___22 {
	int (*enqueue)(struct sk_buff___26 *, struct Qdisc___22 *, struct sk_buff___26 **);
	struct sk_buff___26 * (*dequeue)(struct Qdisc___22 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___22 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___23 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___23 gso_skb;
	struct qdisc_skb_head___22 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___22 *next_sched;
	struct sk_buff_head___23 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___23 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___184 kobj;
	struct net_device___27 *dev;
	long: 64;
	struct xdp_rxq_info___23 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___23)(struct net_device___27 *, struct sk_buff___26 *, struct net_device___27 *);

struct netdev_bpf___23 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___22 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___22 *prog;
			const struct bpf_prog_offload_ops___22 *ops;
		} verifier;
		struct {
			struct bpf_prog___22 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___23 *offmap;
		};
		struct {
			struct xdp_umem *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___23 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___26 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___23 {
	int (*tls_dev_add)(struct net_device___27 *, struct sock___14 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___27 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___27 *, struct sock___14 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___23 {
	int (*ndo_init)(struct net_device___27 *);
	void (*ndo_uninit)(struct net_device___27 *);
	int (*ndo_open)(struct net_device___27 *);
	int (*ndo_stop)(struct net_device___27 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___26 *, struct net_device___27 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___26 *, struct net_device___27 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___27 *, struct sk_buff___26 *, struct net_device___27 *, select_queue_fallback_t___23);
	void (*ndo_change_rx_flags)(struct net_device___27 *, int);
	void (*ndo_set_rx_mode)(struct net_device___27 *);
	int (*ndo_set_mac_address)(struct net_device___27 *, void *);
	int (*ndo_validate_addr)(struct net_device___27 *);
	int (*ndo_do_ioctl)(struct net_device___27 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___27 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___27 *, int);
	int (*ndo_neigh_setup)(struct net_device___27 *, struct neigh_parms___13 *);
	void (*ndo_tx_timeout)(struct net_device___27 *);
	void (*ndo_get_stats64)(struct net_device___27 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___27 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___27 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___27 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___27 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___27 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___27 *);
	int (*ndo_netpoll_setup)(struct net_device___27 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___27 *);
	int (*ndo_set_vf_mac)(struct net_device___27 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___27 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___27 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___27 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___27 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___27 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___27 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___27 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___27 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___27 *, int, struct sk_buff___26 *);
	int (*ndo_set_vf_guid)(struct net_device___27 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___27 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___27 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___27 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___27 *, const struct sk_buff___26 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___27 *, struct net_device___27 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___27 *, struct net_device___27 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___27 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___27 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___27 *, struct neighbour___13 *);
	void (*ndo_neigh_destroy)(struct net_device___27 *, struct neighbour___13 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___27 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___27 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___27 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___26 *, struct netlink_callback___23 *, struct net_device___27 *, struct net_device___27 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___27 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___27 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide35;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___26 *, u32, u32, struct net_device___27 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___27 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___27 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___27 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___27 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___27 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___27 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___27 *, struct net_device___27 *);
	void (*ndo_dfwd_del_station)(struct net_device___27 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___27 *);
	int (*ndo_set_tx_maxrate)(struct net_device___27 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___27 *);
	int (*ndo_change_proto_down)(struct net_device___27 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___27 *, struct sk_buff___26 *);
	void (*ndo_set_rx_headroom)(struct net_device___27 *, int);
	int (*ndo_bpf)(struct net_device___27 *, struct netdev_bpf___23 *);
	int (*ndo_xdp_xmit)(struct net_device___27 *, int, struct xdp_frame___23 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___27 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___27 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide36;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___13 {
	possible_net_t___24 net;
	struct net_device___27 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___13 *);
	void (*neigh_cleanup)(struct neighbour___13 *);
	struct neigh_table___12 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___13 {
	u32 (*l3mdev_fib_table)(const struct net_device___27 *);
	struct sk_buff___26 * (*l3mdev_l3_rcv)(struct net_device___27 *, struct sk_buff___26 *, u16);
	struct sk_buff___26 * (*l3mdev_l3_out)(struct net_device___27 *, struct sock___14 *, struct sk_buff___26 *, u16);
	struct dst_entry___13 * (*l3mdev_link_scope_lookup)(const struct net_device___27 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct ndisc_ops___7 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___27 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___27 *, struct neighbour___13 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___27 *, u8, struct neighbour___13 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___27 *, struct sk_buff___26 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___33 *, struct net_device___27 *, const struct prefix_info *, struct inet6_dev___7 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___6;

struct inet6_dev___7 {
	struct net_device___27 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___6 *mc_list;
	struct ifmcaddr6___6 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	u8 rndid[8];
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___13 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
};

struct tcf_proto___22;

struct mini_Qdisc___22 {
	struct tcf_proto___22 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___22 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___27 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___33 *, struct net_device___27 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___27 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___27 *, struct list_head *);
	size_t (*get_size)(const struct net_device___27 *);
	int (*fill_info)(struct sk_buff___26 *, const struct net_device___27 *);
	size_t (*get_xstats_size)(const struct net_device___27 *);
	int (*fill_xstats)(struct sk_buff___26 *, const struct net_device___27 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___27 *, struct net_device___27 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___27 *, const struct net_device___27 *);
	int (*fill_slave_info)(struct sk_buff___26 *, const struct net_device___27 *, const struct net_device___27 *);
	struct net___33 * (*get_link_net)(const struct net_device___27 *);
	size_t (*get_linkxstats_size)(const struct net_device___27 *, int);
	int (*fill_linkxstats)(struct sk_buff___26 *, const struct net_device___27 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___23 {
	struct list_head poll_list;
	struct sk_buff_head___23 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___23 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___22 *output_queue;
	struct Qdisc___22 **output_queue_tailp;
	struct sk_buff___26 *completion_queue;
	struct sk_buff_head___23 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___23 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___23 input_pkt_queue;
	struct napi_struct___23 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bdi_writeback_congested___97 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___97 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___97 {
	struct bio___97 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___97 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___97 bip_inline_vecs[0];
};

struct bio_set___97 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___97 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___87 {
	struct mem_cgroup___87 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___87 {
	struct lruvec___192 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___87 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___87 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct gnet_dump___22 {
	spinlock_t *lock;
	struct sk_buff___26 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___22;

struct Qdisc_ops___22 {
	struct Qdisc_ops___22 *next;
	const struct Qdisc_class_ops___22 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___26 *, struct Qdisc___22 *, struct sk_buff___26 **);
	struct sk_buff___26 * (*dequeue)(struct Qdisc___22 *);
	struct sk_buff___26 * (*peek)(struct Qdisc___22 *);
	int (*init)(struct Qdisc___22 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___22 *);
	void (*destroy)(struct Qdisc___22 *);
	int (*change)(struct Qdisc___22 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___22 *);
	int (*change_tx_queue_len)(struct Qdisc___22 *, unsigned int);
	int (*dump)(struct Qdisc___22 *, struct sk_buff___26 *);
	int (*dump_stats)(struct Qdisc___22 *, struct gnet_dump___22 *);
	void (*ingress_block_set)(struct Qdisc___22 *, u32);
	void (*egress_block_set)(struct Qdisc___22 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___22 *);
	u32 (*egress_block_get)(struct Qdisc___22 *);
	struct module___162 *owner;
};

struct tcf_block___22;

struct Qdisc_class_ops___22 {
	unsigned int flags;
	struct netdev_queue___23 * (*select_queue)(struct Qdisc___22 *, struct tcmsg *);
	int (*graft)(struct Qdisc___22 *, long unsigned int, struct Qdisc___22 *, struct Qdisc___22 **, struct netlink_ext_ack *);
	struct Qdisc___22 * (*leaf)(struct Qdisc___22 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___22 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___22 *, u32);
	int (*change)(struct Qdisc___22 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___22 *, long unsigned int);
	void (*walk)(struct Qdisc___22 *, struct qdisc_walker *);
	struct tcf_block___22 * (*tcf_block)(struct Qdisc___22 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___22 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___22 *, long unsigned int);
	int (*dump)(struct Qdisc___22 *, long unsigned int, struct sk_buff___26 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___22 *, long unsigned int, struct gnet_dump___22 *);
};

struct tcf_chain___22;

struct tcf_block___22 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___33 *net;
	struct Qdisc___22 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___22 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___22;

struct tcf_proto_ops___22;

struct tcf_proto___22 {
	struct tcf_proto___22 *next;
	void *root;
	int (*classify)(struct sk_buff___26 *, const struct tcf_proto___22 *, struct tcf_result___22 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___22 *ops;
	struct tcf_chain___22 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___22 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___22 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___22 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___26 *, const struct tcf_proto___22 *, struct tcf_result___22 *);
	int (*init)(struct tcf_proto___22 *);
	void (*destroy)(struct tcf_proto___22 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___22 *, u32);
	void (*put)(struct tcf_proto___22 *, void *);
	int (*change)(struct net___33 *, struct sk_buff___26 *, struct tcf_proto___22 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___22 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___22 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___22 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___33 *, struct tcf_chain___22 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___33 *, struct tcf_proto___22 *, void *, struct sk_buff___26 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___26 *, struct net___33 *, void *);
	struct module___162 *owner;
	int flags;
};

struct tcf_chain___22 {
	struct mutex filter_chain_lock;
	struct tcf_proto___22 *filter_chain;
	struct list_head list;
	struct tcf_block___22 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___22 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___12 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___22 *prog;
};

struct bpf_redirect_info___22 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___161 *map;
	struct bpf_map___161 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___12;

struct neigh_hash_table___12;

struct neigh_table___12 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___27 *, __u32 *);
	bool (*key_eq)(const struct neighbour___13 *, const void *);
	int (*constructor)(struct neighbour___13 *);
	int (*pconstructor)(struct pneigh_entry___12 *);
	void (*pdestructor)(struct pneigh_entry___12 *);
	void (*proxy_redo)(struct sk_buff___26 *);
	char *id;
	struct neigh_parms___13 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___23 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___12 *nht;
	struct pneigh_entry___12 **phash_buckets;
};

struct neigh_ops___12 {
	int family;
	void (*solicit)(struct neighbour___13 *, struct sk_buff___26 *);
	void (*error_report)(struct neighbour___13 *, struct sk_buff___26 *);
	int (*output)(struct neighbour___13 *, struct sk_buff___26 *);
	int (*connected_output)(struct neighbour___13 *, struct sk_buff___26 *);
};

struct pneigh_entry___12 {
	struct pneigh_entry___12 *next;
	possible_net_t___24 net;
	struct net_device___27 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___12 {
	struct neighbour___13 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___12 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___12 *ctarget;
	struct net___33 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___12 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___12 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___7;

struct timewait_sock_ops___7;

struct proto___12 {
	void (*close)(struct sock___14 *, long int);
	int (*pre_connect)(struct sock___14 *, struct sockaddr *, int);
	int (*connect)(struct sock___14 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___14 *, int);
	struct sock___14 * (*accept)(struct sock___14 *, int, int *, bool);
	int (*ioctl)(struct sock___14 *, int, long unsigned int);
	int (*init)(struct sock___14 *);
	void (*destroy)(struct sock___14 *);
	void (*shutdown)(struct sock___14 *, int);
	int (*setsockopt)(struct sock___14 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___14 *, int, int, char *, int *);
	void (*keepalive)(struct sock___14 *, int);
	int (*sendmsg)(struct sock___14 *, struct msghdr___12 *, size_t);
	int (*recvmsg)(struct sock___14 *, struct msghdr___12 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___14 *, struct page___193 *, int, size_t, int);
	int (*bind)(struct sock___14 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___14 *, struct sk_buff___26 *);
	void (*release_cb)(struct sock___14 *);
	int (*hash)(struct sock___14 *);
	void (*unhash)(struct sock___14 *);
	void (*rehash)(struct sock___14 *);
	int (*get_port)(struct sock___14 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___14 *);
	bool (*stream_memory_read)(const struct sock___14 *);
	void (*enter_memory_pressure)(struct sock___14 *);
	void (*leave_memory_pressure)(struct sock___14 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___7 *rsk_prot;
	struct timewait_sock_ops___7 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___162 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___14 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct request_sock___6;

struct request_sock_ops___7 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___14 *, struct request_sock___6 *);
	void (*send_ack)(const struct sock___14 *, struct sk_buff___26 *, struct request_sock___6 *);
	void (*send_reset)(const struct sock___14 *, struct sk_buff___26 *);
	void (*destructor)(struct request_sock___6 *);
	void (*syn_ack_timeout)(const struct request_sock___6 *);
};

struct timewait_sock_ops___7 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___14 *, struct sock___14 *, void *);
	void (*twsk_destructor)(struct sock___14 *);
};

struct request_sock___6 {
	struct sock_common___12 __req_common;
	struct request_sock___6 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___7 *rsk_ops;
	struct sock___14 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___6 {
	struct in6_addr mca_addr;
	struct inet6_dev___7 *idev;
	struct ifmcaddr6___6 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ip6_ra_chain___6 {
	struct ip6_ra_chain___6 *next;
	struct sock___14 *sk;
	int sel;
	void (*destructor)(struct sock___14 *);
};

struct epoll_filefd {
	struct file___193 *file;
	int fd;
} __attribute__((packed));

struct nested_call_node {
	struct list_head llink;
	void *cookie;
	void *ctx;
};

struct nested_calls {
	struct list_head tasks_call_list;
	spinlock_t lock;
};

struct eventpoll;

struct epitem {
	union {
		struct rb_node rbn;
		struct callback_head rcu;
	};
	struct list_head rdllink;
	struct epitem *next;
	struct epoll_filefd ffd;
	int nwait;
	struct list_head pwqlist;
	struct eventpoll *ep;
	struct list_head fllink;
	struct wakeup_source *ws;
	struct epoll_event event;
};

struct eventpoll {
	spinlock_t lock;
	struct mutex mtx;
	wait_queue_head_t wq;
	wait_queue_head_t poll_wait;
	struct list_head rdllist;
	struct rb_root_cached rbr;
	struct epitem *ovflist;
	struct wakeup_source *ws;
	struct user_struct___187 *user;
	struct file___193 *file;
	int visited;
	struct list_head visited_list_link;
	unsigned int napi_id;
};

struct eppoll_entry {
	struct list_head llink;
	struct epitem *base;
	wait_queue_entry_t wait;
	wait_queue_head_t *whead;
};

struct ep_pqueue {
	poll_table___17 pt;
	struct epitem *epi;
};

struct ep_send_events_data {
	int maxevents;
	struct epoll_event *events;
	int res;
};

struct signalfd_siginfo {
	__u32 ssi_signo;
	__s32 ssi_errno;
	__s32 ssi_code;
	__u32 ssi_pid;
	__u32 ssi_uid;
	__s32 ssi_fd;
	__u32 ssi_tid;
	__u32 ssi_band;
	__u32 ssi_overrun;
	__u32 ssi_trapno;
	__s32 ssi_status;
	__s32 ssi_int;
	__u64 ssi_ptr;
	__u64 ssi_utime;
	__u64 ssi_stime;
	__u64 ssi_addr;
	__u16 ssi_addr_lsb;
	__u16 __pad2;
	__s32 ssi_syscall;
	__u64 ssi_call_addr;
	__u32 ssi_arch;
	__u8 __pad[28];
};

struct signalfd_ctx {
	sigset_t sigmask;
};

struct fd___26 {
	struct file___73 *file;
	unsigned int flags;
};

struct syscall_metadata___55 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___41 *enter_event;
	struct trace_event_call___41 *exit_event;
};

struct timerfd_ctx {
	union {
		struct hrtimer tmr;
		struct alarm alarm;
	} t;
	ktime_t tintv;
	ktime_t moffs;
	wait_queue_head_t wqh;
	u64 ticks;
	int clockid;
	short unsigned int expired;
	short unsigned int settime_flags;
	struct callback_head rcu;
	struct list_head clist;
	spinlock_t cancel_lock;
	bool might_cancel;
};

struct eventfd_ctx___2 {
	struct kref kref;
	wait_queue_head_t wqh;
	__u64 count;
	unsigned int flags;
};

enum userfaultfd_state {
	UFFD_STATE_WAIT_API = 0,
	UFFD_STATE_RUNNING = 1,
};

struct userfaultfd_ctx {
	wait_queue_head_t fault_pending_wqh;
	wait_queue_head_t fault_wqh;
	wait_queue_head_t fd_wqh;
	wait_queue_head_t event_wqh;
	struct seqcount refile_seq;
	atomic_t refcount;
	unsigned int flags;
	unsigned int features;
	enum userfaultfd_state state;
	bool released;
	bool mmap_changing;
	struct mm_struct___192 *mm;
};

struct uffd_msg {
	__u8 event;
	__u8 reserved1;
	__u16 reserved2;
	__u32 reserved3;
	union {
		struct {
			__u64 flags;
			__u64 address;
			union {
				__u32 ptid;
			} feat;
		} pagefault;
		struct {
			__u32 ufd;
		} fork;
		struct {
			__u64 from;
			__u64 to;
			__u64 len;
		} remap;
		struct {
			__u64 start;
			__u64 end;
		} remove;
		struct {
			__u64 reserved1;
			__u64 reserved2;
			__u64 reserved3;
		} reserved;
	} arg;
};

struct uffdio_api {
	__u64 api;
	__u64 features;
	__u64 ioctls;
};

struct uffdio_range {
	__u64 start;
	__u64 len;
};

struct uffdio_register {
	struct uffdio_range range;
	__u64 mode;
	__u64 ioctls;
};

struct uffdio_copy {
	__u64 dst;
	__u64 src;
	__u64 len;
	__u64 mode;
	__s64 copy;
};

struct uffdio_zeropage {
	struct uffdio_range range;
	__u64 mode;
	__s64 zeropage;
};

struct hstate___34 {
	int next_nid_to_alloc;
	int next_nid_to_free;
	unsigned int order;
	long unsigned int mask;
	long unsigned int max_huge_pages;
	long unsigned int nr_huge_pages;
	long unsigned int free_huge_pages;
	long unsigned int resv_huge_pages;
	long unsigned int surplus_huge_pages;
	long unsigned int nr_overcommit_huge_pages;
	struct list_head hugepage_activelist;
	struct list_head hugepage_freelists[8];
	unsigned int nr_huge_pages_node[8];
	unsigned int free_huge_pages_node[8];
	unsigned int surplus_huge_pages_node[8];
	struct cftype___161 cgroup_files[5];
	char name[32];
};

struct userfaultfd_fork_ctx {
	struct userfaultfd_ctx *orig;
	struct userfaultfd_ctx *new;
	struct list_head list;
};

struct userfaultfd_unmap_ctx {
	struct userfaultfd_ctx *ctx;
	long unsigned int start;
	long unsigned int end;
	struct list_head list;
};

struct userfaultfd_wait_queue {
	struct uffd_msg msg;
	wait_queue_entry_t wq;
	struct userfaultfd_ctx *ctx;
	bool waken;
};

struct userfaultfd_wake_range {
	long unsigned int start;
	long unsigned int len;
};

struct module___163;

struct file___194;

struct kiocb___194;

struct iov_iter___94;

struct poll_table_struct___132;

struct vm_area_struct___194;

struct inode___194;

struct file_lock___194;

struct page___194;

struct seq_file___181;

struct file_operations___194 {
	struct module___163 *owner;
	loff_t (*llseek)(struct file___194 *, loff_t, int);
	ssize_t (*read)(struct file___194 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___194 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___194 *, struct iov_iter___94 *);
	ssize_t (*write_iter)(struct kiocb___194 *, struct iov_iter___94 *);
	int (*iopoll)(struct kiocb___194 *, bool);
	int (*iterate)(struct file___194 *, struct dir_context *);
	int (*iterate_shared)(struct file___194 *, struct dir_context *);
	__poll_t (*poll)(struct file___194 *, struct poll_table_struct___132 *);
	long int (*unlocked_ioctl)(struct file___194 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___194 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___194 *, struct vm_area_struct___194 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___194 *, struct file___194 *);
	int (*flush)(struct file___194 *, fl_owner_t);
	int (*release)(struct inode___194 *, struct file___194 *);
	int (*fsync)(struct file___194 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___194 *, int);
	int (*lock)(struct file___194 *, int, struct file_lock___194 *);
	ssize_t (*sendpage)(struct file___194 *, struct page___194 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___194 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___194 *, int, struct file_lock___194 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___194 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___194 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___194 *, long int, struct file_lock___194 **, void **);
	long int (*fallocate)(struct file___194 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___181 *, struct file___194 *);
	ssize_t (*copy_file_range)(struct file___194 *, loff_t, struct file___194 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___194 *, loff_t, struct file___194 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___194 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___193 {
	u64 seqnum;
	struct vm_area_struct___194 *vmas[4];
};

struct page_frag___193 {
	struct page___194 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___117;

struct debug_info___117 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___117 *hbp_break[16];
	struct perf_event___117 *hbp_watch[16];
};

struct thread_struct___117 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___117 debug;
	long: 64;
};

struct mm_struct___193;

struct pid___153;

struct cred___188;

struct nsproxy___183;

struct signal_struct___170;

struct bio_list___98;

struct backing_dev_info___98;

struct io_context___50;

struct css_set___162;

struct perf_event_context___117;

struct request_queue___47;

struct vm_struct___135;

struct task_struct___194 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___194 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___193 *mm;
	struct mm_struct___193 *active_mm;
	struct vmacache___193 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___194 *real_parent;
	struct task_struct___194 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___194 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___153 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___153 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___153 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___188 *ptracer_cred;
	const struct cred___188 *real_cred;
	const struct cred___188 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___183 *nsproxy;
	struct signal_struct___170 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___194 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___98 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___98 *backing_dev_info;
	struct io_context___50 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___162 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___117 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___193 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___47 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___194 *oom_reaper_list;
	struct vm_struct___135 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___117 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___117 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___194 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___117)(struct perf_event___117 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___117;

struct fasync_struct___193;

struct pid_namespace___153;

struct trace_event_call___110;

struct perf_cgroup___117;

struct perf_event___117 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___117 *group_leader;
	struct pmu___117 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___117 hw;
	struct perf_event_context___117 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___117 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___194 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___193 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___117 *);
	struct callback_head callback_head;
	struct pid_namespace___153 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___117 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___117 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___110 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___117 *cgrp;
	struct list_head sb_list;
};

struct dentry_operations___193;

struct super_block___193;

struct dentry___193 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___193 *d_parent;
	struct qstr d_name;
	struct inode___194 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___193 *d_op;
	struct super_block___193 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct rw_semaphore___194 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___194 *owner;
};

struct address_space_operations___193;

struct address_space___193 {
	struct inode___194 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___194 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___193 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___193;

struct bdi_writeback___98;

struct block_device___194;

struct inode___194 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___193 *i_op;
	struct super_block___193 *i_sb;
	struct address_space___193 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___194 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___98 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___194 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___193 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___194 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vfsmount___40;

struct path___193;

struct dentry_operations___193 {
	int (*d_revalidate)(struct dentry___193 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___193 *, unsigned int);
	int (*d_hash)(const struct dentry___193 *, struct qstr *);
	int (*d_compare)(const struct dentry___193 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___193 *);
	int (*d_init)(struct dentry___193 *);
	void (*d_release)(struct dentry___193 *);
	void (*d_prune)(struct dentry___193 *);
	void (*d_iput)(struct dentry___193 *, struct inode___194 *);
	char * (*d_dname)(struct dentry___193 *, char *, int);
	struct vfsmount___40 * (*d_automount)(struct path___193 *);
	int (*d_manage)(const struct path___193 *, bool);
	struct dentry___193 * (*d_real)(struct dentry___193 *, const struct inode___194 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___193;

struct mem_dqinfo___193 {
	struct quota_format_type___193 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___193;

struct quota_info___193 {
	unsigned int flags;
	struct rw_semaphore___194 dqio_sem;
	struct inode___194 *files[3];
	struct mem_dqinfo___193 info[3];
	const struct quota_format_ops___193 *ops[3];
};

struct rcuwait___193 {
	struct task_struct___194 *task;
};

struct percpu_rw_semaphore___193 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___194 rw_sem;
	struct rcuwait___193 writer;
	int readers_block;
};

struct sb_writers___193 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___193 rw_sem[3];
};

struct file_system_type___193;

struct super_operations___193;

struct dquot_operations___193;

struct quotactl_ops___193;

struct user_namespace___171;

struct super_block___193 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___193 *s_type;
	const struct super_operations___193 *s_op;
	const struct dquot_operations___193 *dq_op;
	const struct quotactl_ops___193 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___193 *s_root;
	struct rw_semaphore___194 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___194 *s_bdev;
	struct backing_dev_info___98 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___193 s_dquot;
	struct sb_writers___193 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___193 *s_d_op;
	int cleancache_poolid;
	struct shrinker___87 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___171 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___40 {
	struct dentry___193 *mnt_root;
	struct super_block___193 *mnt_sb;
	int mnt_flags;
};

struct path___193 {
	struct vfsmount___40 *mnt;
	struct dentry___193 *dentry;
};

struct key___188;

struct ucounts___171;

struct user_namespace___171 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___171 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___11 ns;
	long unsigned int flags;
	struct key___188 *persistent_keyring_register;
	struct rw_semaphore___194 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___171 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___194 *pgtable_t___193;

struct dev_pagemap___190;

struct page___194 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___193 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___194 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___193 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___193 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___190 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___193;

struct lruvec___193 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___193 *pgdat;
};

struct zone___193 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___193 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___193 {
	struct zone___193 *zone;
	int zone_idx;
};

struct zonelist___193 {
	struct zoneref___193 _zonerefs[25];
};

struct pglist_data___193 {
	struct zone___193 node_zones[3];
	struct zonelist___193 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___194 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___194 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___193 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___194 {
	void *stack;
	struct task_struct___194 *task;
	long int status;
};

struct blocking_notifier_head___193 {
	struct rw_semaphore___194 rwsem;
	struct notifier_block *head;
};

struct upid___153 {
	int nr;
	struct pid_namespace___153 *ns;
};

struct pid_namespace___153 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___194 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___153 *parent;
	struct vfsmount___40 *proc_mnt;
	struct dentry___193 *proc_self;
	struct dentry___193 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___171 *user_ns;
	struct ucounts___171 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___11 ns;
};

struct pid___153 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___153 numbers[1];
};

struct vm_operations_struct___190;

struct vm_area_struct___194 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___194 *vm_next;
	struct vm_area_struct___194 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___193 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___190 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___194 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___193;

struct kioctx_table___2;

struct mm_struct___193 {
	struct {
		struct vm_area_struct___194 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___194 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___194 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___193 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table___2 *ioctx_table;
		struct task_struct___194 *owner;
		struct user_namespace___171 *user_ns;
		struct file___194 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___193 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___190)(struct vm_area_struct___194 *, long unsigned int, const struct page___194 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___190)(struct page___194 *, void *);

struct device___175;

struct dev_pagemap___190 {
	dev_page_fault_t___190 page_fault;
	dev_page_free_t___190 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___175 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct fown_struct___153 {
	rwlock_t lock;
	struct pid___153 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___194 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___193 f_path;
	struct inode___194 *f_inode;
	const struct file_operations___194 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___153 f_owner;
	const struct cred___188 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___193 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___190;

struct vm_operations_struct___190 {
	void (*open)(struct vm_area_struct___194 *);
	void (*close)(struct vm_area_struct___194 *);
	int (*split)(struct vm_area_struct___194 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___194 *);
	vm_fault_t (*fault)(struct vm_fault___190 *);
	vm_fault_t (*huge_fault)(struct vm_fault___190 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___190 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___194 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___190 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___190 *);
	int (*access)(struct vm_area_struct___194 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___194 *);
	int (*set_policy)(struct vm_area_struct___194 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___194 *, long unsigned int);
	struct page___194 * (*find_special_page)(struct vm_area_struct___194 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___193 {
	struct task_struct___194 *task;
	struct core_thread___193 *next;
};

struct core_state___193 {
	atomic_t nr_threads;
	struct core_thread___193 dumper;
	struct completion startup;
};

struct kioctx;

struct kioctx_table___2 {
	struct callback_head rcu;
	unsigned int nr;
	struct kioctx *table[0];
};

struct vm_fault___190 {
	struct vm_area_struct___194 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___194 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___194 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___193 prealloc_pte;
};

struct hrtimer_sleeper___4 {
	struct hrtimer timer;
	struct task_struct___194 *task;
};

struct user_struct___188 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___188 *uid_keyring;
	struct key___188 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___188 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___188 *session_keyring;
	struct key___188 *process_keyring;
	struct key___188 *thread_keyring;
	struct key___188 *request_key_auth;
	void *security;
	struct user_struct___188 *user;
	struct user_namespace___171 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___162;

struct nsproxy___183 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___153 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___162 *cgroup_ns;
};

struct signal_struct___170 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___194 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___194 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___153 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___153 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___193 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___153 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___98;

struct bio_list___98 {
	struct bio___98 *head;
	struct bio___98 *tail;
};

struct bdi_writeback_congested___98;

struct cgroup_subsys_state___163;

struct bdi_writeback___98 {
	struct backing_dev_info___98 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___98 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___163 *memcg_css;
	struct cgroup_subsys_state___163 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___98 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___98 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___175 *dev;
	struct device___175 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___193 *debug_dir;
	struct dentry___193 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___50;

struct io_context___50 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___50 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___162;

struct css_set___162 {
	struct cgroup_subsys_state___163 *subsys[13];
	refcount_t refcount;
	struct css_set___162 *dom_cset;
	struct cgroup___162 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___162 *mg_src_cgrp;
	struct cgroup___162 *mg_dst_cgrp;
	struct css_set___162 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___117 {
	struct pmu___117 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___194 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___117 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

typedef blk_qc_t make_request_fn___46(struct request_queue___47 *, struct bio___98 *);

struct request___47;

typedef int dma_drain_needed_fn___46(struct request___47 *);

struct kset___184;

struct kobj_type___184;

struct kernfs_node___188;

struct kobject___185 {
	const char *name;
	struct list_head entry;
	struct kobject___185 *parent;
	struct kset___184 *kset;
	struct kobj_type___184 *ktype;
	struct kernfs_node___188 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___46;

struct bsg_class_device___46 {
	struct device___175 *class_dev;
	int minor;
	struct request_queue___47 *queue;
	const struct bsg_ops___46 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___98 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___98 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___46;

struct blkcg_gq___36;

struct request_queue___47 {
	struct list_head queue_head;
	struct request___47 *last_merge;
	struct elevator_queue___46 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___46 *make_request_fn;
	dma_drain_needed_fn___46 *dma_drain_needed;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___98 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___185 kobj;
	struct kobject___185 *mq_kobj;
	struct blk_integrity integrity;
	struct device___175 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___36 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide36;
		union {		};
	};
	struct bsg_class_device___46 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___98 bio_split;
	struct dentry___193 *debugfs_dir;
	struct dentry___193 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___135 {
	struct vm_struct___135 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___194 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___172 {
	struct task_struct___194 task;
	long unsigned int stack[8192];
};

struct io_cq___50 {
	struct request_queue___47 *q;
	struct io_context___50 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___6 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___194 {
	struct file___194 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___194 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___193 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___194 *ia_file;
};

struct dquot___193 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___193 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___193 {
	int qf_fmt_id;
	const struct quota_format_ops___193 *qf_ops;
	struct module___163 *qf_owner;
	struct quota_format_type___193 *qf_next;
};

struct quota_format_ops___193 {
	int (*check_quota_file)(struct super_block___193 *, int);
	int (*read_file_info)(struct super_block___193 *, int);
	int (*write_file_info)(struct super_block___193 *, int);
	int (*free_file_info)(struct super_block___193 *, int);
	int (*read_dqblk)(struct dquot___193 *);
	int (*commit_dqblk)(struct dquot___193 *);
	int (*release_dqblk)(struct dquot___193 *);
	int (*get_next_id)(struct super_block___193 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___193 {
	int (*write_dquot)(struct dquot___193 *);
	struct dquot___193 * (*alloc_dquot)(struct super_block___193 *, int);
	void (*destroy_dquot)(struct dquot___193 *);
	int (*acquire_dquot)(struct dquot___193 *);
	int (*release_dquot)(struct dquot___193 *);
	int (*mark_dirty)(struct dquot___193 *);
	int (*write_info)(struct super_block___193 *, int);
	qsize_t * (*get_reserved_space)(struct inode___194 *);
	int (*get_projid)(struct inode___194 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___194 *, qsize_t *);
	int (*get_next_id)(struct super_block___193 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___193 {
	int (*quota_on)(struct super_block___193 *, int, int, const struct path___193 *);
	int (*quota_off)(struct super_block___193 *, int);
	int (*quota_enable)(struct super_block___193 *, unsigned int);
	int (*quota_disable)(struct super_block___193 *, unsigned int);
	int (*quota_sync)(struct super_block___193 *, int);
	int (*set_info)(struct super_block___193 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___193 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___193 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___193 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___193 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___193 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___160 {
	struct kobject___185 kobj;
	struct module___163 *mod;
	struct kobject___185 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___160 {
	struct module___163 *mod;
	struct latch_tree_node node;
};

struct module_layout___160 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___160 mtn;
};

struct module_attribute___160;

struct kernel_param___160;

struct module___163 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___160 mkobj;
	struct module_attribute___160 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___185 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___160 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___160 core_layout;
	struct module_layout___160 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___110 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___94;

struct address_space_operations___193 {
	int (*writepage)(struct page___194 *, struct writeback_control___94 *);
	int (*readpage)(struct file___194 *, struct page___194 *);
	int (*writepages)(struct address_space___193 *, struct writeback_control___94 *);
	int (*set_page_dirty)(struct page___194 *);
	int (*readpages)(struct file___194 *, struct address_space___193 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___194 *, struct address_space___193 *, loff_t, unsigned int, unsigned int, struct page___194 **, void **);
	int (*write_end)(struct file___194 *, struct address_space___193 *, loff_t, unsigned int, unsigned int, struct page___194 *, void *);
	sector_t (*bmap)(struct address_space___193 *, sector_t);
	void (*invalidatepage)(struct page___194 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___194 *, gfp_t);
	void (*freepage)(struct page___194 *);
	ssize_t (*direct_IO)(struct kiocb___194 *, struct iov_iter___94 *);
	int (*migratepage)(struct address_space___193 *, struct page___194 *, struct page___194 *, enum migrate_mode);
	bool (*isolate_page)(struct page___194 *, isolate_mode_t);
	void (*putback_page)(struct page___194 *);
	int (*launder_page)(struct page___194 *);
	int (*is_partially_uptodate)(struct page___194 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___194 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___193 *, struct page___194 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___194 *, sector_t *);
	void (*swap_deactivate)(struct file___194 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___94 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___98 *wb;
	struct inode___194 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___98;

struct iov_iter___94 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___98 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct hd_struct___47;

struct gendisk___47;

struct block_device___194 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___194 *bd_inode;
	struct super_block___193 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___194 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___47 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___47 *bd_disk;
	struct request_queue___47 *bd_queue;
	struct backing_dev_info___98 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___175 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___175 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___175;

struct bus_type___175;

struct device_driver___175;

struct dev_pm_domain___175;

struct fwnode_handle___122;

struct class___175;

struct attribute_group___176;

struct device___175 {
	struct device___175 *parent;
	struct device_private *p;
	struct kobject___185 kobj;
	const char *init_name;
	const struct device_type___175 *type;
	struct mutex mutex;
	struct bus_type___175 *bus;
	struct device_driver___175 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___175 power;
	struct dev_pm_domain___175 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___122 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___175 *class;
	const struct attribute_group___176 **groups;
	void (*release)(struct device___175 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___47 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___175 __dev;
	struct kobject___185 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___47;

struct block_device_operations___47;

struct gendisk___47 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___47 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___47 *part_tbl;
	struct hd_struct___47 part0;
	const struct block_device_operations___47 *fops;
	struct request_queue___47 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___194 lookup_sem;
	struct kobject___185 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___185 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___193 {
	struct dentry___193 * (*lookup)(struct inode___194 *, struct dentry___193 *, unsigned int);
	const char * (*get_link)(struct dentry___193 *, struct inode___194 *, struct delayed_call *);
	int (*permission)(struct inode___194 *, int);
	struct posix_acl * (*get_acl)(struct inode___194 *, int);
	int (*readlink)(struct dentry___193 *, char *, int);
	int (*create)(struct inode___194 *, struct dentry___193 *, umode_t, bool);
	int (*link)(struct dentry___193 *, struct inode___194 *, struct dentry___193 *);
	int (*unlink)(struct inode___194 *, struct dentry___193 *);
	int (*symlink)(struct inode___194 *, struct dentry___193 *, const char *);
	int (*mkdir)(struct inode___194 *, struct dentry___193 *, umode_t);
	int (*rmdir)(struct inode___194 *, struct dentry___193 *);
	int (*mknod)(struct inode___194 *, struct dentry___193 *, umode_t, dev_t);
	int (*rename)(struct inode___194 *, struct dentry___193 *, struct inode___194 *, struct dentry___193 *, unsigned int);
	int (*setattr)(struct dentry___193 *, struct iattr___193 *);
	int (*getattr)(const struct path___193 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___193 *, char *, size_t);
	int (*fiemap)(struct inode___194 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___194 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___194 *, struct dentry___193 *, struct file___194 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___194 *, struct dentry___193 *, umode_t);
	int (*set_acl)(struct inode___194 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___193 {
	void (*fl_copy_lock)(struct file_lock___194 *, struct file_lock___194 *);
	void (*fl_release_private)(struct file_lock___194 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___193;

struct file_lock___194 {
	struct file_lock___194 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___194 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___193 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___193 *fl_ops;
	const struct lock_manager_operations___193 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___193 {
	int (*lm_compare_owner)(struct file_lock___194 *, struct file_lock___194 *);
	long unsigned int (*lm_owner_key)(struct file_lock___194 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___194 *);
	int (*lm_grant)(struct file_lock___194 *, int);
	bool (*lm_break)(struct file_lock___194 *);
	int (*lm_change)(struct file_lock___194 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___194 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___193 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___193 *fa_next;
	struct file___194 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___193 {
	const char *name;
	int fs_flags;
	struct dentry___193 * (*mount)(struct file_system_type___193 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___193 *);
	struct module___163 *owner;
	struct file_system_type___193 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___193 {
	struct inode___194 * (*alloc_inode)(struct super_block___193 *);
	void (*destroy_inode)(struct inode___194 *);
	void (*dirty_inode)(struct inode___194 *, int);
	int (*write_inode)(struct inode___194 *, struct writeback_control___94 *);
	int (*drop_inode)(struct inode___194 *);
	void (*evict_inode)(struct inode___194 *);
	void (*put_super)(struct super_block___193 *);
	int (*sync_fs)(struct super_block___193 *, int);
	int (*freeze_super)(struct super_block___193 *);
	int (*freeze_fs)(struct super_block___193 *);
	int (*thaw_super)(struct super_block___193 *);
	int (*unfreeze_fs)(struct super_block___193 *);
	int (*statfs)(struct dentry___193 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___193 *, int *, char *);
	void (*umount_begin)(struct super_block___193 *);
	int (*show_options)(struct seq_file___181 *, struct dentry___193 *);
	int (*show_devname)(struct seq_file___181 *, struct dentry___193 *);
	int (*show_path)(struct seq_file___181 *, struct dentry___193 *);
	int (*show_stats)(struct seq_file___181 *, struct dentry___193 *);
	ssize_t (*quota_read)(struct super_block___193 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___193 *, int, const char *, size_t, loff_t);
	struct dquot___193 ** (*get_dquots)(struct inode___194 *);
	int (*bdev_try_to_free_page)(struct super_block___193 *, struct page___194 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___193 *, struct shrink_control___87 *);
	long int (*free_cached_objects)(struct super_block___193 *, struct shrink_control___87 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___133)(struct file___194 *, wait_queue_head_t *, struct poll_table_struct___132 *);

struct poll_table_struct___132 {
	poll_queue_proc___133 _qproc;
	__poll_t _key;
};

struct seq_operations___179;

struct seq_file___181 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___179 *op;
	int poll_event;
	const struct file___194 *file;
	void *private;
};

typedef void bio_end_io_t___98(struct bio___98 *);

struct bio_vec___98 {
	struct page___194 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___98;

struct bio___98 {
	struct bio___98 *bi_next;
	struct gendisk___47 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___98 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___36 *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___98 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___98 *bi_io_vec;
	struct bio_set___98 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___98 bi_inline_vecs[0];
};

typedef __kernel_ulong_t aio_context_t;

enum {
	IOCB_CMD_PREAD = 0,
	IOCB_CMD_PWRITE = 1,
	IOCB_CMD_FSYNC = 2,
	IOCB_CMD_FDSYNC = 3,
	IOCB_CMD_NOOP = 6,
	IOCB_CMD_PREADV = 7,
	IOCB_CMD_PWRITEV = 8,
};

struct io_event {
	__u64 data;
	__u64 obj;
	__s64 res;
	__s64 res2;
};

struct iocb {
	__u64 aio_data;
	__u32 aio_key;
	__kernel_rwf_t aio_rw_flags;
	__u16 aio_lio_opcode;
	__s16 aio_reqprio;
	__u32 aio_fildes;
	__u64 aio_buf;
	__u64 aio_nbytes;
	__s64 aio_offset;
	__u64 aio_reserved2;
	__u32 aio_flags;
	__u32 aio_resfd;
};

typedef int (*key_restrict_link_func_t___188)(struct key___188 *, const struct key_type *, const union key_payload *, struct key___188 *);

struct key_restriction___188;

struct key___188 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___194 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___188 *restrict_link;
};

struct key_restriction___188 {
	key_restrict_link_func_t___188 check;
	struct key___188 *key;
	struct key_type *keytype;
};

struct kobj_attribute___184 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___185 *, struct kobj_attribute___184 *, char *);
	ssize_t (*store)(struct kobject___185 *, struct kobj_attribute___184 *, const char *, size_t);
};

typedef void compound_page_dtor___190(struct page___194 *);

struct seq_operations___179 {
	void * (*start)(struct seq_file___181 *, loff_t *);
	void (*stop)(struct seq_file___181 *, void *);
	void * (*next)(struct seq_file___181 *, void *, loff_t *);
	int (*show)(struct seq_file___181 *, void *);
};

struct cgroup_namespace___162 {
	refcount_t count;
	struct ns_common___11 ns;
	struct user_namespace___171 *user_ns;
	struct ucounts___171 *ucounts;
	struct css_set___162 *root_cset;
};

struct ucounts___171 {
	struct hlist_node node;
	struct user_namespace___171 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct kernfs_root___188;

struct kernfs_elem_dir___188 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___188 *root;
};

struct kernfs_syscall_ops___188;

struct kernfs_root___188 {
	struct kernfs_node___188 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___188 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___188 {
	struct kernfs_node___188 *target_kn;
};

struct kernfs_ops___188;

struct kernfs_elem_attr___188 {
	const struct kernfs_ops___188 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___188 *notify_next;
};

struct kernfs_node___188 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___188 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___188 dir;
		struct kernfs_elem_symlink___188 symlink;
		struct kernfs_elem_attr___188 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___188;

struct kernfs_ops___188 {
	int (*open)(struct kernfs_open_file___188 *);
	void (*release)(struct kernfs_open_file___188 *);
	int (*seq_show)(struct seq_file___181 *, void *);
	void * (*seq_start)(struct seq_file___181 *, loff_t *);
	void * (*seq_next)(struct seq_file___181 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___181 *, void *);
	ssize_t (*read)(struct kernfs_open_file___188 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___188 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___188 *, struct vm_area_struct___194 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___188 *, struct poll_table_struct___132 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___188 {
	int (*remount_fs)(struct kernfs_root___188 *, int *, char *);
	int (*show_options)(struct seq_file___181 *, struct kernfs_root___188 *);
	int (*mkdir)(struct kernfs_node___188 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___188 *);
	int (*rename)(struct kernfs_node___188 *, struct kernfs_node___188 *, const char *);
	int (*show_path)(struct seq_file___181 *, struct kernfs_node___188 *, struct kernfs_root___188 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___188 {
	struct kernfs_node___188 *kn;
	struct file___194 *file;
	struct seq_file___181 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___190 *vm_ops;
};

struct bin_attribute___175;

struct attribute_group___176 {
	const char *name;
	umode_t (*is_visible)(struct kobject___185 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___185 *, struct bin_attribute___175 *, int);
	struct attribute **attrs;
	struct bin_attribute___175 **bin_attrs;
};

struct bin_attribute___175 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___194 *, struct kobject___185 *, struct bin_attribute___175 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___194 *, struct kobject___185 *, struct bin_attribute___175 *, char *, loff_t, size_t);
	int (*mmap)(struct file___194 *, struct kobject___185 *, struct bin_attribute___175 *, struct vm_area_struct___194 *);
};

struct sysfs_ops___184 {
	ssize_t (*show)(struct kobject___185 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___185 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___184;

struct kset___184 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___185 kobj;
	const struct kset_uevent_ops___184 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___184 {
	void (*release)(struct kobject___185 *);
	const struct sysfs_ops___184 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___12 * (*child_ns_type)(struct kobject___185 *);
	const void * (*namespace)(struct kobject___185 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___184 {
	int (* const filter)(struct kset___184 *, struct kobject___185 *);
	const char * (* const name)(struct kset___184 *, struct kobject___185 *);
	int (* const uevent)(struct kset___184 *, struct kobject___185 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___160 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___160 *);
	int (*get)(char *, const struct kernel_param___160 *);
	void (*free)(void *);
};

struct kparam_array___160;

struct kernel_param___160 {
	const char *name;
	struct module___163 *mod;
	const struct kernel_param_ops___160 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___160 *arr;
	};
};

struct kparam_array___160 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___160 *ops;
	void *elem;
};

struct module_attribute___160 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___160 *, struct module_kobject___160 *, char *);
	ssize_t (*store)(struct module_attribute___160 *, struct module_kobject___160 *, const char *, size_t);
	void (*setup)(struct module___163 *, const char *);
	int (*test)(struct module___163 *);
	void (*free)(struct module___163 *);
};

struct trace_event_class___110;

struct trace_event_call___110 {
	struct list_head list;
	struct trace_event_class___110 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___22 *prog_array;
	int (*perf_perm)(struct trace_event_call___110 *, struct perf_event___117 *);
};

struct dev_pm_ops___175 {
	int (*prepare)(struct device___175 *);
	void (*complete)(struct device___175 *);
	int (*suspend)(struct device___175 *);
	int (*resume)(struct device___175 *);
	int (*freeze)(struct device___175 *);
	int (*thaw)(struct device___175 *);
	int (*poweroff)(struct device___175 *);
	int (*restore)(struct device___175 *);
	int (*suspend_late)(struct device___175 *);
	int (*resume_early)(struct device___175 *);
	int (*freeze_late)(struct device___175 *);
	int (*thaw_early)(struct device___175 *);
	int (*poweroff_late)(struct device___175 *);
	int (*restore_early)(struct device___175 *);
	int (*suspend_noirq)(struct device___175 *);
	int (*resume_noirq)(struct device___175 *);
	int (*freeze_noirq)(struct device___175 *);
	int (*thaw_noirq)(struct device___175 *);
	int (*poweroff_noirq)(struct device___175 *);
	int (*restore_noirq)(struct device___175 *);
	int (*runtime_suspend)(struct device___175 *);
	int (*runtime_resume)(struct device___175 *);
	int (*runtime_idle)(struct device___175 *);
};

struct dev_pm_domain___175 {
	struct dev_pm_ops___175 ops;
	void (*detach)(struct device___175 *, bool);
	int (*activate)(struct device___175 *);
	void (*sync)(struct device___175 *);
	void (*dismiss)(struct device___175 *);
};

struct bus_type___175 {
	const char *name;
	const char *dev_name;
	struct device___175 *dev_root;
	const struct attribute_group___176 **bus_groups;
	const struct attribute_group___176 **dev_groups;
	const struct attribute_group___176 **drv_groups;
	int (*match)(struct device___175 *, struct device_driver___175 *);
	int (*uevent)(struct device___175 *, struct kobj_uevent_env *);
	int (*probe)(struct device___175 *);
	int (*remove)(struct device___175 *);
	void (*shutdown)(struct device___175 *);
	int (*online)(struct device___175 *);
	int (*offline)(struct device___175 *);
	int (*suspend)(struct device___175 *, pm_message_t);
	int (*resume)(struct device___175 *);
	int (*num_vf)(struct device___175 *);
	int (*dma_configure)(struct device___175 *);
	const struct dev_pm_ops___175 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___175 {
	const char *name;
	struct bus_type___175 *bus;
	struct module___163 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___175 *);
	int (*remove)(struct device___175 *);
	void (*shutdown)(struct device___175 *);
	int (*suspend)(struct device___175 *, pm_message_t);
	int (*resume)(struct device___175 *);
	const struct attribute_group___176 **groups;
	const struct dev_pm_ops___175 *pm;
	void (*coredump)(struct device___175 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___175 {
	const char *name;
	const struct attribute_group___176 **groups;
	int (*uevent)(struct device___175 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___175 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___175 *);
	const struct dev_pm_ops___175 *pm;
};

struct class___175 {
	const char *name;
	struct module___163 *owner;
	const struct attribute_group___176 **class_groups;
	const struct attribute_group___176 **dev_groups;
	struct kobject___185 *dev_kobj;
	int (*dev_uevent)(struct device___175 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___175 *, umode_t *);
	void (*class_release)(struct class___175 *);
	void (*dev_release)(struct device___175 *);
	int (*shutdown_pre)(struct device___175 *);
	const struct kobj_ns_type_operations___12 *ns_type;
	const void * (*namespace)(struct device___175 *);
	const struct dev_pm_ops___175 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct fwnode_operations___122;

struct fwnode_handle___122 {
	struct fwnode_handle___122 *secondary;
	const struct fwnode_operations___122 *ops;
};

struct node___150 {
	struct device___175 dev;
};

struct bpf_map___162;

struct bpf_map_ops___162 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___162 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___162 *, struct file___194 *);
	void (*map_free)(struct bpf_map___162 *);
	int (*map_get_next_key)(struct bpf_map___162 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___162 *);
	void * (*map_lookup_elem)(struct bpf_map___162 *, void *);
	int (*map_update_elem)(struct bpf_map___162 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___162 *, void *);
	int (*map_push_elem)(struct bpf_map___162 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___162 *, void *);
	int (*map_peek_elem)(struct bpf_map___162 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___162 *, struct file___194 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___162 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___162 *, void *, struct seq_file___181 *);
	int (*map_check_btf)(const struct bpf_map___162 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___162 {
	const struct bpf_map_ops___162 *ops;
	struct bpf_map___162 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___188 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___162;

typedef void (*kthread_work_func_t___162)(struct kthread_work___162 *);

struct kthread_worker___162;

struct kthread_work___162 {
	struct list_head node;
	kthread_work_func_t___162 func;
	struct kthread_worker___162 *worker;
	int canceling;
};

struct kthread_worker___162 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___194 *task;
	struct kthread_work___162 *current_work;
};

struct kthread_delayed_work___162 {
	struct kthread_work___162 work;
	struct timer_list timer;
};

struct psi_group___162 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___162 *poll_kworker;
	struct kthread_delayed_work___162 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___162 {
	struct kernfs_node___188 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___162;

struct cgroup_subsys_state___163 {
	struct cgroup___162 *cgroup;
	struct cgroup_subsys___162 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___163 *parent;
};

struct cgroup_root___162;

struct cgroup_rstat_cpu___162;

struct cgroup___162 {
	struct cgroup_subsys_state___163 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___188 *kn;
	struct cgroup_file___162 procs_file;
	struct cgroup_file___162 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___163 *subsys[13];
	struct cgroup_root___162 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___162 *dom_cgrp;
	struct cgroup_rstat_cpu___162 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___22 bpf;
	atomic_t congestion_count;
	struct cgroup___162 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___162 psi;
	int ancestor_ids[0];
};

struct cftype___162;

struct cgroup_subsys___162 {
	struct cgroup_subsys_state___163 * (*css_alloc)(struct cgroup_subsys_state___163 *);
	int (*css_online)(struct cgroup_subsys_state___163 *);
	void (*css_offline)(struct cgroup_subsys_state___163 *);
	void (*css_released)(struct cgroup_subsys_state___163 *);
	void (*css_free)(struct cgroup_subsys_state___163 *);
	void (*css_reset)(struct cgroup_subsys_state___163 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___163 *, int);
	int (*css_extra_stat_show)(struct seq_file___181 *, struct cgroup_subsys_state___163 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___194 *);
	void (*cancel_fork)(struct task_struct___194 *);
	void (*fork)(struct task_struct___194 *);
	void (*exit)(struct task_struct___194 *);
	void (*free)(struct task_struct___194 *);
	void (*bind)(struct cgroup_subsys_state___163 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___162 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___162 *dfl_cftypes;
	struct cftype___162 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___162 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___162 *updated_children;
	struct cgroup___162 *updated_next;
};

struct cgroup_root___162 {
	struct kernfs_root___188 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___162 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___162 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___162 *ss;
	struct list_head node;
	struct kernfs_ops___188 *kf_ops;
	int (*open)(struct kernfs_open_file___188 *);
	void (*release)(struct kernfs_open_file___188 *);
	u64 (*read_u64)(struct cgroup_subsys_state___163 *, struct cftype___162 *);
	s64 (*read_s64)(struct cgroup_subsys_state___163 *, struct cftype___162 *);
	int (*seq_show)(struct seq_file___181 *, void *);
	void * (*seq_start)(struct seq_file___181 *, loff_t *);
	void * (*seq_next)(struct seq_file___181 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___181 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___163 *, struct cftype___162 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___163 *, struct cftype___162 *, s64);
	ssize_t (*write)(struct kernfs_open_file___188 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___188 *, struct poll_table_struct___132 *);
};

struct perf_cpu_context___117;

struct pmu___117 {
	struct list_head entry;
	struct module___163 *module;
	struct device___175 *dev;
	const struct attribute_group___176 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___117 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___117 *);
	void (*pmu_disable)(struct pmu___117 *);
	int (*event_init)(struct perf_event___117 *);
	void (*event_mapped)(struct perf_event___117 *, struct mm_struct___193 *);
	void (*event_unmapped)(struct perf_event___117 *, struct mm_struct___193 *);
	int (*add)(struct perf_event___117 *, int);
	void (*del)(struct perf_event___117 *, int);
	void (*start)(struct perf_event___117 *, int);
	void (*stop)(struct perf_event___117 *, int);
	void (*read)(struct perf_event___117 *);
	void (*start_txn)(struct pmu___117 *, unsigned int);
	int (*commit_txn)(struct pmu___117 *);
	void (*cancel_txn)(struct pmu___117 *);
	int (*event_idx)(struct perf_event___117 *);
	void (*sched_task)(struct perf_event_context___117 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___117 *);
	int (*filter_match)(struct perf_event___117 *);
	int (*check_period)(struct perf_event___117 *, u64);
};

struct perf_cpu_context___117 {
	struct perf_event_context___117 ctx;
	struct perf_event_context___117 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___117 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___117 {
	struct cgroup_subsys_state___163 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___110 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___110 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___110 *);
	struct list_head * (*get_fields)(struct trace_event_call___110 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___110 *);
};

struct syscall_metadata___56 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___110 *enter_event;
	struct trace_event_call___110 *exit_event;
};

struct bio_integrity_payload___98 {
	struct bio___98 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___98 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___98 bip_inline_vecs[0];
};

struct blkcg___36;

struct blkg_policy_data___36;

struct blkcg_gq___36 {
	struct request_queue___47 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___36 *blkcg;
	struct bdi_writeback_congested___98 *wb_congested;
	struct blkcg_gq___36 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_rwstat stat_bytes;
	struct blkg_rwstat stat_ios;
	struct blkg_policy_data___36 *pd[5];
	struct callback_head callback_head;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
};

struct disk_part_tbl___47 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___47 *last_lookup;
	struct hd_struct___47 *part[0];
};

struct block_device_operations___47 {
	int (*open)(struct block_device___194 *, fmode_t);
	void (*release)(struct gendisk___47 *, fmode_t);
	int (*rw_page)(struct block_device___194 *, sector_t, struct page___194 *, unsigned int);
	int (*ioctl)(struct block_device___194 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___194 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___47 *, unsigned int);
	int (*media_changed)(struct gendisk___47 *);
	void (*unlock_native_capacity)(struct gendisk___47 *);
	int (*revalidate_disk)(struct gendisk___47 *);
	int (*getgeo)(struct block_device___194 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___194 *, long unsigned int);
	int (*report_zones)(struct gendisk___47 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___163 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bdi_writeback_congested___98 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___98 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bsg_ops___46 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___47 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___47 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___47 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___46(struct request___47 *, blk_status_t);

struct request___47 {
	struct request_queue___47 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___98 *bio;
	struct bio___98 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___98 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___50 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___46 *saved_end_io;
		} flush;
	};
	struct gendisk___47 *rq_disk;
	struct hd_struct___47 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___46 *end_io;
	void *end_io_data;
	struct request___47 *next_rq;
};

struct fwnode_reference_args___122;

struct fwnode_endpoint___122;

struct fwnode_operations___122 {
	struct fwnode_handle___122 * (*get)(struct fwnode_handle___122 *);
	void (*put)(struct fwnode_handle___122 *);
	bool (*device_is_available)(const struct fwnode_handle___122 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___122 *, const struct device___175 *);
	bool (*property_present)(const struct fwnode_handle___122 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___122 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___122 *, const char *, const char **, size_t);
	struct fwnode_handle___122 * (*get_parent)(const struct fwnode_handle___122 *);
	struct fwnode_handle___122 * (*get_next_child_node)(const struct fwnode_handle___122 *, struct fwnode_handle___122 *);
	struct fwnode_handle___122 * (*get_named_child_node)(const struct fwnode_handle___122 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___122 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___122 *);
	struct fwnode_handle___122 * (*graph_get_next_endpoint)(const struct fwnode_handle___122 *, struct fwnode_handle___122 *);
	struct fwnode_handle___122 * (*graph_get_remote_endpoint)(const struct fwnode_handle___122 *);
	struct fwnode_handle___122 * (*graph_get_port_parent)(struct fwnode_handle___122 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___122 *, struct fwnode_endpoint___122 *);
};

struct fwnode_endpoint___122 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___122 *local_fwnode;
};

struct fwnode_reference_args___122 {
	struct fwnode_handle___122 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct elevator_type___46;

struct elevator_mq_ops___46 {
	int (*init_sched)(struct request_queue___47 *, struct elevator_type___46 *);
	void (*exit_sched)(struct elevator_queue___46 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	bool (*allow_merge)(struct request_queue___47 *, struct request___47 *, struct bio___98 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx *, struct bio___98 *);
	int (*request_merge)(struct request_queue___47 *, struct request___47 **, struct bio___98 *);
	void (*request_merged)(struct request_queue___47 *, struct request___47 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___47 *, struct request___47 *, struct request___47 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___47 *, struct bio___98 *);
	void (*finish_request)(struct request___47 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___47 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___47 *, u64);
	void (*started_request)(struct request___47 *);
	void (*requeue_request)(struct request___47 *);
	struct request___47 * (*former_request)(struct request_queue___47 *, struct request___47 *);
	struct request___47 * (*next_request)(struct request_queue___47 *, struct request___47 *);
	void (*init_icq)(struct io_cq___50 *);
	void (*exit_icq)(struct io_cq___50 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide35;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___46;

struct elevator_type___46 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___46 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___46 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___163 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___46 {
	struct elevator_type___46 *type;
	void *elevator_data;
	struct kobject___185 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___46 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___46 *, char *);
	ssize_t (*store)(struct elevator_queue___46 *, const char *, size_t);
};

struct blkcg_policy_data___36;

struct blkcg___36 {
	struct cgroup_subsys_state___163 css;
	spinlock_t lock;
	struct xarray blkg_tree;
	struct blkcg_gq___36 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___36 *cpd[5];
	struct list_head all_blkcgs_node;
	struct list_head cgwb_list;
	refcount_t cgwb_refcnt;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct blkcg_policy_data___36 {
	struct blkcg___36 *blkcg;
	int plid;
};

struct blkg_policy_data___36 {
	struct blkcg_gq___36 *blkg;
	int plid;
};

typedef int kiocb_cancel_fn(struct kiocb___194 *);

struct hstate___35 {
	int next_nid_to_alloc;
	int next_nid_to_free;
	unsigned int order;
	long unsigned int mask;
	long unsigned int max_huge_pages;
	long unsigned int nr_huge_pages;
	long unsigned int free_huge_pages;
	long unsigned int resv_huge_pages;
	long unsigned int surplus_huge_pages;
	long unsigned int nr_overcommit_huge_pages;
	struct list_head hugepage_activelist;
	struct list_head hugepage_freelists[8];
	unsigned int nr_huge_pages_node[8];
	unsigned int free_huge_pages_node[8];
	unsigned int surplus_huge_pages_node[8];
	struct cftype___162 cgroup_files[5];
	char name[32];
};

struct aio_ring {
	unsigned int id;
	unsigned int nr;
	unsigned int head;
	unsigned int tail;
	unsigned int magic;
	unsigned int compat_features;
	unsigned int incompat_features;
	unsigned int header_length;
	struct io_event io_events[0];
};

struct kioctx_cpu;

struct ctx_rq_wait;

struct kioctx {
	struct percpu_ref users;
	atomic_t dead;
	struct percpu_ref reqs;
	long unsigned int user_id;
	struct kioctx_cpu *cpu;
	unsigned int req_batch;
	unsigned int max_reqs;
	unsigned int nr_events;
	long unsigned int mmap_base;
	long unsigned int mmap_size;
	struct page___194 **ring_pages;
	long int nr_pages;
	struct rcu_work free_rwork;
	struct ctx_rq_wait *rq_wait;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct {
		atomic_t reqs_available;
		long: 32;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct {
		spinlock_t ctx_lock;
		struct list_head active_reqs;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct {
		struct mutex ring_lock;
		wait_queue_head_t wait;
		long: 64;
	};
	struct {
		unsigned int tail;
		unsigned int completed_events;
		spinlock_t completion_lock;
		long: 32;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct page___194 *internal_pages[8];
	struct file___194 *aio_ring_file;
	unsigned int id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kioctx_cpu {
	unsigned int reqs_available;
};

struct ctx_rq_wait {
	struct completion comp;
	atomic_t count;
};

struct fsync_iocb {
	struct work_struct work;
	struct file___194 *file;
	bool datasync;
};

struct aio_kiocb {
	union {
		struct kiocb___194 rw;
		struct fsync_iocb fsync;
	};
	struct kioctx *ki_ctx;
	kiocb_cancel_fn *ki_cancel;
	struct iocb *ki_user_iocb;
	__u64 ki_user_data;
	struct list_head ki_list;
	struct eventfd_ctx *ki_eventfd;
};

struct __aio_sigset {
	const sigset_t *sigmask;
	size_t sigsetsize;
};

struct module___164;

struct file___195;

struct kiocb___195;

struct iov_iter___95;

struct poll_table_struct___133;

struct vm_area_struct___195;

struct inode___195;

struct file_lock___195;

struct page___195;

struct seq_file___182;

struct file_operations___195 {
	struct module___164 *owner;
	loff_t (*llseek)(struct file___195 *, loff_t, int);
	ssize_t (*read)(struct file___195 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___195 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___195 *, struct iov_iter___95 *);
	ssize_t (*write_iter)(struct kiocb___195 *, struct iov_iter___95 *);
	int (*iopoll)(struct kiocb___195 *, bool);
	int (*iterate)(struct file___195 *, struct dir_context *);
	int (*iterate_shared)(struct file___195 *, struct dir_context *);
	__poll_t (*poll)(struct file___195 *, struct poll_table_struct___133 *);
	long int (*unlocked_ioctl)(struct file___195 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___195 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___195 *, struct vm_area_struct___195 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___195 *, struct file___195 *);
	int (*flush)(struct file___195 *, fl_owner_t);
	int (*release)(struct inode___195 *, struct file___195 *);
	int (*fsync)(struct file___195 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___195 *, int);
	int (*lock)(struct file___195 *, int, struct file_lock___195 *);
	ssize_t (*sendpage)(struct file___195 *, struct page___195 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___195 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___195 *, int, struct file_lock___195 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___195 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___195 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___195 *, long int, struct file_lock___195 **, void **);
	long int (*fallocate)(struct file___195 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___182 *, struct file___195 *);
	ssize_t (*copy_file_range)(struct file___195 *, loff_t, struct file___195 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___195 *, loff_t, struct file___195 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___195 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___194 {
	u64 seqnum;
	struct vm_area_struct___195 *vmas[4];
};

struct page_frag___194 {
	struct page___195 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___118;

struct debug_info___118 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___118 *hbp_break[16];
	struct perf_event___118 *hbp_watch[16];
};

struct thread_struct___118 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___118 debug;
	long: 64;
};

struct mm_struct___194;

struct mem_cgroup___88;

struct pid___154;

struct cred___189;

struct nsproxy___184;

struct signal_struct___171;

struct bio_list___99;

struct backing_dev_info___99;

struct io_context___51;

struct css_set___163;

struct perf_event_context___118;

struct request_queue___48;

struct vm_struct___136;

struct task_struct___195 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___195 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___194 *mm;
	struct mm_struct___194 *active_mm;
	struct vmacache___194 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___195 *real_parent;
	struct task_struct___195 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___195 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___88 *active_memcg;
	long int rh_reserved2;
	struct pid___154 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___154 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___154 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___189 *ptracer_cred;
	const struct cred___189 *real_cred;
	const struct cred___189 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___184 *nsproxy;
	struct signal_struct___171 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___195 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___99 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___99 *backing_dev_info;
	struct io_context___51 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___163 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___118 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___194 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___88 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___48 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___195 *oom_reaper_list;
	struct vm_struct___136 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___118 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___118 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___195 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___118)(struct perf_event___118 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___118;

struct fasync_struct___194;

struct pid_namespace___154;

struct trace_event_call___111;

struct perf_cgroup___118;

struct perf_event___118 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___118 *group_leader;
	struct pmu___118 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___118 hw;
	struct perf_event_context___118 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___118 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___195 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___194 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___118 *);
	struct callback_head callback_head;
	struct pid_namespace___154 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___118 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___118 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___111 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___118 *cgrp;
	struct list_head sb_list;
};

struct upid___154 {
	int nr;
	struct pid_namespace___154 *ns;
};

struct dentry___194;

struct user_namespace___172;

struct ucounts___172;

struct pid_namespace___154 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___195 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___154 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___194 *proc_self;
	struct dentry___194 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___172 *user_ns;
	struct ucounts___172 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___11 ns;
};

struct pid___154 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___154 numbers[1];
};

struct rw_semaphore___195 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___195 *owner;
};

struct key___189;

struct user_namespace___172 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___172 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___11 ns;
	long unsigned int flags;
	struct key___189 *persistent_keyring_register;
	struct rw_semaphore___195 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___172 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct secondary_data___195 {
	void *stack;
	struct task_struct___195 *task;
	long int status;
};

typedef struct page___195 *pgtable_t___194;

struct address_space___194;

struct dev_pagemap___191;

struct page___195 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___194 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___195 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___194 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___194 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___191 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___88 *mem_cgroup;
};

struct user_struct___189 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___189 *uid_keyring;
	struct key___189 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___191;

struct vm_area_struct___195 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___195 *vm_next;
	struct vm_area_struct___195 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___194 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___191 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___195 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___194;

struct mm_struct___194 {
	struct {
		struct vm_area_struct___195 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___195 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___195 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___194 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___195 *owner;
		struct user_namespace___172 *user_ns;
		struct file___195 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___194 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup___163;

struct cgroup_subsys___163;

struct cgroup_subsys_state___164 {
	struct cgroup___163 *cgroup;
	struct cgroup_subsys___163 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___164 *parent;
};

struct kernfs_node___189;

struct cgroup_file___163 {
	struct kernfs_node___189 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___88;

struct mem_cgroup___88 {
	struct cgroup_subsys_state___164 css;
	struct mem_cgroup_id___17 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___163 events_file;
	struct cgroup_file___163 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___195 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___88 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cred___189 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___189 *session_keyring;
	struct key___189 *process_keyring;
	struct key___189 *thread_keyring;
	struct key___189 *request_key_auth;
	void *security;
	struct user_struct___189 *user;
	struct user_namespace___172 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___163;

struct nsproxy___184 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___154 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___163 *cgroup_ns;
};

struct signal_struct___171 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___195 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___195 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___154 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___154 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___194 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___154 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide41;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___99;

struct bio_list___99 {
	struct bio___99 *head;
	struct bio___99 *tail;
};

struct bdi_writeback_congested___99;

struct bdi_writeback___99 {
	struct backing_dev_info___99 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___99 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___164 *memcg_css;
	struct cgroup_subsys_state___164 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___176;

struct backing_dev_info___99 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___99 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___176 *dev;
	struct device___176 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___194 *debug_dir;
	struct dentry___194 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___51;

struct io_context___51 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___51 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___163 {
	struct cgroup_subsys_state___164 *subsys[13];
	refcount_t refcount;
	struct css_set___163 *dom_cset;
	struct cgroup___163 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___163 *mg_src_cgrp;
	struct cgroup___163 *mg_dst_cgrp;
	struct css_set___163 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___118 {
	struct pmu___118 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___195 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___118 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

typedef blk_qc_t make_request_fn___47(struct request_queue___48 *, struct bio___99 *);

struct request___48;

typedef int dma_drain_needed_fn___47(struct request___48 *);

struct kset___185;

struct kobj_type___185;

struct kobject___186 {
	const char *name;
	struct list_head entry;
	struct kobject___186 *parent;
	struct kset___185 *kset;
	struct kobj_type___185 *ktype;
	struct kernfs_node___189 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___47;

struct bsg_class_device___47 {
	struct device___176 *class_dev;
	int minor;
	struct request_queue___48 *queue;
	const struct bsg_ops___47 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___99 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___99 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___47;

struct request_queue___48 {
	struct list_head queue_head;
	struct request___48 *last_merge;
	struct elevator_queue___47 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___47 *make_request_fn;
	dma_drain_needed_fn___47 *dma_drain_needed;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___99 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___186 kobj;
	struct kobject___186 *mq_kobj;
	struct blk_integrity integrity;
	struct device___176 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	struct bsg_class_device___47 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___99 bio_split;
	struct dentry___194 *debugfs_dir;
	struct dentry___194 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___136 {
	struct vm_struct___136 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___195 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___173 {
	struct task_struct___195 task;
	long unsigned int stack[8192];
};

struct pglist_data___194;

struct lruvec___194 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___194 *pgdat;
};

struct zone___194 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___194 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___194 {
	struct zone___194 *zone;
	int zone_idx;
};

struct zonelist___194 {
	struct zoneref___194 _zonerefs[25];
};

struct pglist_data___194 {
	struct zone___194 node_zones[3];
	struct zonelist___194 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___195 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___195 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___194 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___194 {
	struct rw_semaphore___195 rwsem;
	struct notifier_block *head;
};

struct bio_vec___99 {
	struct page___195 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

typedef void bio_end_io_t___99(struct bio___99 *);

struct gendisk___48;

struct bio_integrity_payload___99;

struct bio___99 {
	struct bio___99 *bi_next;
	struct gendisk___48 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___99 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___99 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___99 *bi_io_vec;
	struct bio_set___99 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___99 bi_inline_vecs[0];
};

struct bio_integrity_payload___99 {
	struct bio___99 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___99 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___99 bip_inline_vecs[0];
};

struct dev_pm_info___176 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___176 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___176;

struct bus_type___176;

struct device_driver___176;

struct dev_pm_domain___176;

struct fwnode_handle___123;

struct class___176;

struct attribute_group___177;

struct device___176 {
	struct device___176 *parent;
	struct device_private *p;
	struct kobject___186 kobj;
	const char *init_name;
	const struct device_type___176 *type;
	struct mutex mutex;
	struct bus_type___176 *bus;
	struct device_driver___176 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___176 power;
	struct dev_pm_domain___176 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___123 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___176 *class;
	const struct attribute_group___177 **groups;
	void (*release)(struct device___176 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___48 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___176 __dev;
	struct kobject___186 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___48;

struct block_device_operations___48;

struct gendisk___48 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___48 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___48 *part_tbl;
	struct hd_struct___48 part0;
	const struct block_device_operations___48 *fops;
	struct request_queue___48 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___195 lookup_sem;
	struct kobject___186 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___186 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_ops___176;

struct device_type___176 {
	const char *name;
	const struct attribute_group___177 **groups;
	int (*uevent)(struct device___176 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___176 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___176 *);
	const struct dev_pm_ops___176 *pm;
};

struct class___176 {
	const char *name;
	struct module___164 *owner;
	const struct attribute_group___177 **class_groups;
	const struct attribute_group___177 **dev_groups;
	struct kobject___186 *dev_kobj;
	int (*dev_uevent)(struct device___176 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___176 *, umode_t *);
	void (*class_release)(struct class___176 *);
	void (*dev_release)(struct device___176 *);
	int (*shutdown_pre)(struct device___176 *);
	const struct kobj_ns_type_operations___12 *ns_type;
	const void * (*namespace)(struct device___176 *);
	const struct dev_pm_ops___176 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct kernfs_root___189;

struct kernfs_elem_dir___189 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___189 *root;
};

struct kernfs_syscall_ops___189;

struct kernfs_root___189 {
	struct kernfs_node___189 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___189 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___189 {
	struct kernfs_node___189 *target_kn;
};

struct kernfs_ops___189;

struct kernfs_elem_attr___189 {
	const struct kernfs_ops___189 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___189 *notify_next;
};

struct kernfs_node___189 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___189 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___189 dir;
		struct kernfs_elem_symlink___189 symlink;
		struct kernfs_elem_attr___189 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___189;

struct kernfs_ops___189 {
	int (*open)(struct kernfs_open_file___189 *);
	void (*release)(struct kernfs_open_file___189 *);
	int (*seq_show)(struct seq_file___182 *, void *);
	void * (*seq_start)(struct seq_file___182 *, loff_t *);
	void * (*seq_next)(struct seq_file___182 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___182 *, void *);
	ssize_t (*read)(struct kernfs_open_file___189 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___189 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___189 *, struct vm_area_struct___195 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___189 *, struct poll_table_struct___133 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___189 {
	int (*remount_fs)(struct kernfs_root___189 *, int *, char *);
	int (*show_options)(struct seq_file___182 *, struct kernfs_root___189 *);
	int (*mkdir)(struct kernfs_node___189 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___189 *);
	int (*rename)(struct kernfs_node___189 *, struct kernfs_node___189 *, const char *);
	int (*show_path)(struct seq_file___182 *, struct kernfs_node___189 *, struct kernfs_root___189 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___180;

struct seq_file___182 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___180 *op;
	int poll_event;
	const struct file___195 *file;
	void *private;
};

struct kernfs_open_file___189 {
	struct kernfs_node___189 *kn;
	struct file___195 *file;
	struct seq_file___182 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___191 *vm_ops;
};

struct path___194 {
	struct vfsmount *mnt;
	struct dentry___194 *dentry;
};

struct fown_struct___154 {
	rwlock_t lock;
	struct pid___154 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___195 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___194 f_path;
	struct inode___195 *f_inode;
	const struct file_operations___195 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___154 f_owner;
	const struct cred___189 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___194 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___191;

struct vm_operations_struct___191 {
	void (*open)(struct vm_area_struct___195 *);
	void (*close)(struct vm_area_struct___195 *);
	int (*split)(struct vm_area_struct___195 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___195 *);
	vm_fault_t (*fault)(struct vm_fault___191 *);
	vm_fault_t (*huge_fault)(struct vm_fault___191 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___191 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___195 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___191 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___191 *);
	int (*access)(struct vm_area_struct___195 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___195 *);
	int (*set_policy)(struct vm_area_struct___195 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___195 *, long unsigned int);
	struct page___195 * (*find_special_page)(struct vm_area_struct___195 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___134)(struct file___195 *, wait_queue_head_t *, struct poll_table_struct___133 *);

struct poll_table_struct___133 {
	poll_queue_proc___134 _qproc;
	__poll_t _key;
};

struct bin_attribute___176;

struct attribute_group___177 {
	const char *name;
	umode_t (*is_visible)(struct kobject___186 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___186 *, struct bin_attribute___176 *, int);
	struct attribute **attrs;
	struct bin_attribute___176 **bin_attrs;
};

struct bin_attribute___176 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___195 *, struct kobject___186 *, struct bin_attribute___176 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___195 *, struct kobject___186 *, struct bin_attribute___176 *, char *, loff_t, size_t);
	int (*mmap)(struct file___195 *, struct kobject___186 *, struct bin_attribute___176 *, struct vm_area_struct___195 *);
};

struct sysfs_ops___185 {
	ssize_t (*show)(struct kobject___186 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___186 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___185;

struct kset___185 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___186 kobj;
	const struct kset_uevent_ops___185 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___185 {
	void (*release)(struct kobject___186 *);
	const struct sysfs_ops___185 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___12 * (*child_ns_type)(struct kobject___186 *);
	const void * (*namespace)(struct kobject___186 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___185 {
	int (* const filter)(struct kset___185 *, struct kobject___186 *);
	const char * (* const name)(struct kset___185 *, struct kobject___186 *);
	int (* const uevent)(struct kset___185 *, struct kobject___186 *, struct kobj_uevent_env *);
};

struct kobj_attribute___185 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___186 *, struct kobj_attribute___185 *, char *);
	ssize_t (*store)(struct kobject___186 *, struct kobj_attribute___185 *, const char *, size_t);
};

struct dev_pm_ops___176 {
	int (*prepare)(struct device___176 *);
	void (*complete)(struct device___176 *);
	int (*suspend)(struct device___176 *);
	int (*resume)(struct device___176 *);
	int (*freeze)(struct device___176 *);
	int (*thaw)(struct device___176 *);
	int (*poweroff)(struct device___176 *);
	int (*restore)(struct device___176 *);
	int (*suspend_late)(struct device___176 *);
	int (*resume_early)(struct device___176 *);
	int (*freeze_late)(struct device___176 *);
	int (*thaw_early)(struct device___176 *);
	int (*poweroff_late)(struct device___176 *);
	int (*restore_early)(struct device___176 *);
	int (*suspend_noirq)(struct device___176 *);
	int (*resume_noirq)(struct device___176 *);
	int (*freeze_noirq)(struct device___176 *);
	int (*thaw_noirq)(struct device___176 *);
	int (*poweroff_noirq)(struct device___176 *);
	int (*restore_noirq)(struct device___176 *);
	int (*runtime_suspend)(struct device___176 *);
	int (*runtime_resume)(struct device___176 *);
	int (*runtime_idle)(struct device___176 *);
};

struct dev_pm_domain___176 {
	struct dev_pm_ops___176 ops;
	void (*detach)(struct device___176 *, bool);
	int (*activate)(struct device___176 *);
	void (*sync)(struct device___176 *);
	void (*dismiss)(struct device___176 *);
};

struct bus_type___176 {
	const char *name;
	const char *dev_name;
	struct device___176 *dev_root;
	const struct attribute_group___177 **bus_groups;
	const struct attribute_group___177 **dev_groups;
	const struct attribute_group___177 **drv_groups;
	int (*match)(struct device___176 *, struct device_driver___176 *);
	int (*uevent)(struct device___176 *, struct kobj_uevent_env *);
	int (*probe)(struct device___176 *);
	int (*remove)(struct device___176 *);
	void (*shutdown)(struct device___176 *);
	int (*online)(struct device___176 *);
	int (*offline)(struct device___176 *);
	int (*suspend)(struct device___176 *, pm_message_t);
	int (*resume)(struct device___176 *);
	int (*num_vf)(struct device___176 *);
	int (*dma_configure)(struct device___176 *);
	const struct dev_pm_ops___176 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___176 {
	const char *name;
	struct bus_type___176 *bus;
	struct module___164 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___176 *);
	int (*remove)(struct device___176 *);
	void (*shutdown)(struct device___176 *);
	int (*suspend)(struct device___176 *, pm_message_t);
	int (*resume)(struct device___176 *);
	const struct attribute_group___177 **groups;
	const struct dev_pm_ops___176 *pm;
	void (*coredump)(struct device___176 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct module_kobject___161 {
	struct kobject___186 kobj;
	struct module___164 *mod;
	struct kobject___186 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___161 {
	struct module___164 *mod;
	struct latch_tree_node node;
};

struct module_layout___161 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___161 mtn;
};

struct module_attribute___161;

struct kernel_param___161;

struct module___164 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___161 mkobj;
	struct module_attribute___161 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___186 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___161 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___161 core_layout;
	struct module_layout___161 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___111 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide46;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide47;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_operations___123;

struct fwnode_handle___123 {
	struct fwnode_handle___123 *secondary;
	const struct fwnode_operations___123 *ops;
};

struct dentry_operations___194;

struct super_block___194;

struct dentry___194 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___194 *d_parent;
	struct qstr d_name;
	struct inode___195 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___194 *d_op;
	struct super_block___194 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___194;

struct address_space___194 {
	struct inode___195 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___195 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___194 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___194;

struct block_device___195;

struct inode___195 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___194 *i_op;
	struct super_block___194 *i_sb;
	struct address_space___194 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___195 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___99 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___195 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___194 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___195 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___194 {
	int (*d_revalidate)(struct dentry___194 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___194 *, unsigned int);
	int (*d_hash)(const struct dentry___194 *, struct qstr *);
	int (*d_compare)(const struct dentry___194 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___194 *);
	int (*d_init)(struct dentry___194 *);
	void (*d_release)(struct dentry___194 *);
	void (*d_prune)(struct dentry___194 *);
	void (*d_iput)(struct dentry___194 *, struct inode___195 *);
	char * (*d_dname)(struct dentry___194 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___194 *);
	int (*d_manage)(const struct path___194 *, bool);
	struct dentry___194 * (*d_real)(struct dentry___194 *, const struct inode___195 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___194;

struct mem_dqinfo___194 {
	struct quota_format_type___194 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___194;

struct quota_info___194 {
	unsigned int flags;
	struct rw_semaphore___195 dqio_sem;
	struct inode___195 *files[3];
	struct mem_dqinfo___194 info[3];
	const struct quota_format_ops___194 *ops[3];
};

struct rcuwait___194 {
	struct task_struct___195 *task;
};

struct percpu_rw_semaphore___194 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___195 rw_sem;
	struct rcuwait___194 writer;
	int readers_block;
};

struct sb_writers___194 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___194 rw_sem[3];
};

struct shrink_control___88;

struct shrinker___88 {
	long unsigned int (*count_objects)(struct shrinker___88 *, struct shrink_control___88 *);
	long unsigned int (*scan_objects)(struct shrinker___88 *, struct shrink_control___88 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___194;

struct super_operations___194;

struct dquot_operations___194;

struct quotactl_ops___194;

struct super_block___194 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___194 *s_type;
	const struct super_operations___194 *s_op;
	const struct dquot_operations___194 *dq_op;
	const struct quotactl_ops___194 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___194 *s_root;
	struct rw_semaphore___195 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___195 *s_bdev;
	struct backing_dev_info___99 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___194 s_dquot;
	struct sb_writers___194 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___194 *s_d_op;
	int cleancache_poolid;
	struct shrinker___88 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___172 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___88 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___88 *memcg;
};

typedef int (*dev_page_fault_t___191)(struct vm_area_struct___195 *, long unsigned int, const struct page___195 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___191)(struct page___195 *, void *);

struct dev_pagemap___191 {
	dev_page_fault_t___191 page_fault;
	dev_page_free_t___191 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___176 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___194 {
	struct task_struct___195 *task;
	struct core_thread___194 *next;
};

struct core_state___194 {
	atomic_t nr_threads;
	struct core_thread___194 dumper;
	struct completion startup;
};

struct vm_fault___191 {
	struct vm_area_struct___195 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___195 *cow_page;
	struct mem_cgroup___88 *memcg;
	struct page___195 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___194 prealloc_pte;
};

struct io_cq___51 {
	struct request_queue___48 *q;
	struct io_context___51 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___6 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___195 {
	struct file___195 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___195 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___194 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___195 *ia_file;
};

struct dquot___194 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___194 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___194 {
	int qf_fmt_id;
	const struct quota_format_ops___194 *qf_ops;
	struct module___164 *qf_owner;
	struct quota_format_type___194 *qf_next;
};

struct quota_format_ops___194 {
	int (*check_quota_file)(struct super_block___194 *, int);
	int (*read_file_info)(struct super_block___194 *, int);
	int (*write_file_info)(struct super_block___194 *, int);
	int (*free_file_info)(struct super_block___194 *, int);
	int (*read_dqblk)(struct dquot___194 *);
	int (*commit_dqblk)(struct dquot___194 *);
	int (*release_dqblk)(struct dquot___194 *);
	int (*get_next_id)(struct super_block___194 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___194 {
	int (*write_dquot)(struct dquot___194 *);
	struct dquot___194 * (*alloc_dquot)(struct super_block___194 *, int);
	void (*destroy_dquot)(struct dquot___194 *);
	int (*acquire_dquot)(struct dquot___194 *);
	int (*release_dquot)(struct dquot___194 *);
	int (*mark_dirty)(struct dquot___194 *);
	int (*write_info)(struct super_block___194 *, int);
	qsize_t * (*get_reserved_space)(struct inode___195 *);
	int (*get_projid)(struct inode___195 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___195 *, qsize_t *);
	int (*get_next_id)(struct super_block___194 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___194 {
	int (*quota_on)(struct super_block___194 *, int, int, const struct path___194 *);
	int (*quota_off)(struct super_block___194 *, int);
	int (*quota_enable)(struct super_block___194 *, unsigned int);
	int (*quota_disable)(struct super_block___194 *, unsigned int);
	int (*quota_sync)(struct super_block___194 *, int);
	int (*set_info)(struct super_block___194 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___194 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___194 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___194 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___194 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___194 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___95;

struct address_space_operations___194 {
	int (*writepage)(struct page___195 *, struct writeback_control___95 *);
	int (*readpage)(struct file___195 *, struct page___195 *);
	int (*writepages)(struct address_space___194 *, struct writeback_control___95 *);
	int (*set_page_dirty)(struct page___195 *);
	int (*readpages)(struct file___195 *, struct address_space___194 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___195 *, struct address_space___194 *, loff_t, unsigned int, unsigned int, struct page___195 **, void **);
	int (*write_end)(struct file___195 *, struct address_space___194 *, loff_t, unsigned int, unsigned int, struct page___195 *, void *);
	sector_t (*bmap)(struct address_space___194 *, sector_t);
	void (*invalidatepage)(struct page___195 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___195 *, gfp_t);
	void (*freepage)(struct page___195 *);
	ssize_t (*direct_IO)(struct kiocb___195 *, struct iov_iter___95 *);
	int (*migratepage)(struct address_space___194 *, struct page___195 *, struct page___195 *, enum migrate_mode);
	bool (*isolate_page)(struct page___195 *, isolate_mode_t);
	void (*putback_page)(struct page___195 *);
	int (*launder_page)(struct page___195 *);
	int (*is_partially_uptodate)(struct page___195 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___195 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___194 *, struct page___195 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___195 *, sector_t *);
	void (*swap_deactivate)(struct file___195 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___95 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___99 *wb;
	struct inode___195 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct iov_iter___95 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___99 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___195 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___195 *bd_inode;
	struct super_block___194 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___195 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___48 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___48 *bd_disk;
	struct request_queue___48 *bd_queue;
	struct backing_dev_info___99 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___194 {
	struct dentry___194 * (*lookup)(struct inode___195 *, struct dentry___194 *, unsigned int);
	const char * (*get_link)(struct dentry___194 *, struct inode___195 *, struct delayed_call *);
	int (*permission)(struct inode___195 *, int);
	struct posix_acl * (*get_acl)(struct inode___195 *, int);
	int (*readlink)(struct dentry___194 *, char *, int);
	int (*create)(struct inode___195 *, struct dentry___194 *, umode_t, bool);
	int (*link)(struct dentry___194 *, struct inode___195 *, struct dentry___194 *);
	int (*unlink)(struct inode___195 *, struct dentry___194 *);
	int (*symlink)(struct inode___195 *, struct dentry___194 *, const char *);
	int (*mkdir)(struct inode___195 *, struct dentry___194 *, umode_t);
	int (*rmdir)(struct inode___195 *, struct dentry___194 *);
	int (*mknod)(struct inode___195 *, struct dentry___194 *, umode_t, dev_t);
	int (*rename)(struct inode___195 *, struct dentry___194 *, struct inode___195 *, struct dentry___194 *, unsigned int);
	int (*setattr)(struct dentry___194 *, struct iattr___194 *);
	int (*getattr)(const struct path___194 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___194 *, char *, size_t);
	int (*fiemap)(struct inode___195 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___195 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___195 *, struct dentry___194 *, struct file___195 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___195 *, struct dentry___194 *, umode_t);
	int (*set_acl)(struct inode___195 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___194 {
	void (*fl_copy_lock)(struct file_lock___195 *, struct file_lock___195 *);
	void (*fl_release_private)(struct file_lock___195 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___194;

struct file_lock___195 {
	struct file_lock___195 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___195 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___194 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___194 *fl_ops;
	const struct lock_manager_operations___194 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___194 {
	int (*lm_compare_owner)(struct file_lock___195 *, struct file_lock___195 *);
	long unsigned int (*lm_owner_key)(struct file_lock___195 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___195 *);
	int (*lm_grant)(struct file_lock___195 *, int);
	bool (*lm_break)(struct file_lock___195 *);
	int (*lm_change)(struct file_lock___195 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___195 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___194 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___194 *fa_next;
	struct file___195 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___194 {
	const char *name;
	int fs_flags;
	struct dentry___194 * (*mount)(struct file_system_type___194 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___194 *);
	struct module___164 *owner;
	struct file_system_type___194 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___194 {
	struct inode___195 * (*alloc_inode)(struct super_block___194 *);
	void (*destroy_inode)(struct inode___195 *);
	void (*dirty_inode)(struct inode___195 *, int);
	int (*write_inode)(struct inode___195 *, struct writeback_control___95 *);
	int (*drop_inode)(struct inode___195 *);
	void (*evict_inode)(struct inode___195 *);
	void (*put_super)(struct super_block___194 *);
	int (*sync_fs)(struct super_block___194 *, int);
	int (*freeze_super)(struct super_block___194 *);
	int (*freeze_fs)(struct super_block___194 *);
	int (*thaw_super)(struct super_block___194 *);
	int (*unfreeze_fs)(struct super_block___194 *);
	int (*statfs)(struct dentry___194 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___194 *, int *, char *);
	void (*umount_begin)(struct super_block___194 *);
	int (*show_options)(struct seq_file___182 *, struct dentry___194 *);
	int (*show_devname)(struct seq_file___182 *, struct dentry___194 *);
	int (*show_path)(struct seq_file___182 *, struct dentry___194 *);
	int (*show_stats)(struct seq_file___182 *, struct dentry___194 *);
	ssize_t (*quota_read)(struct super_block___194 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___194 *, int, const char *, size_t, loff_t);
	struct dquot___194 ** (*get_dquots)(struct inode___195 *);
	int (*bdev_try_to_free_page)(struct super_block___194 *, struct page___195 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___194 *, struct shrink_control___88 *);
	long int (*free_cached_objects)(struct super_block___194 *, struct shrink_control___88 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___48 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___48 *last_lookup;
	struct hd_struct___48 *part[0];
};

struct block_device_operations___48 {
	int (*open)(struct block_device___195 *, fmode_t);
	void (*release)(struct gendisk___48 *, fmode_t);
	int (*rw_page)(struct block_device___195 *, sector_t, struct page___195 *, unsigned int);
	int (*ioctl)(struct block_device___195 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___195 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___48 *, unsigned int);
	int (*media_changed)(struct gendisk___48 *);
	void (*unlock_native_capacity)(struct gendisk___48 *);
	int (*revalidate_disk)(struct gendisk___48 *);
	int (*getgeo)(struct block_device___195 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___195 *, long unsigned int);
	int (*report_zones)(struct gendisk___48 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___164 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___191(struct page___195 *);

struct bdi_writeback_congested___99 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___99 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bsg_ops___47 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___48 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___48 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___48 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___47(struct request___48 *, blk_status_t);

struct request___48 {
	struct request_queue___48 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___99 *bio;
	struct bio___99 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___99 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___51 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___47 *saved_end_io;
		} flush;
	};
	struct gendisk___48 *rq_disk;
	struct hd_struct___48 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___47 *end_io;
	void *end_io_data;
	struct request___48 *next_rq;
};

struct fwnode_reference_args___123;

struct fwnode_endpoint___123;

struct fwnode_operations___123 {
	struct fwnode_handle___123 * (*get)(struct fwnode_handle___123 *);
	void (*put)(struct fwnode_handle___123 *);
	bool (*device_is_available)(const struct fwnode_handle___123 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___123 *, const struct device___176 *);
	bool (*property_present)(const struct fwnode_handle___123 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___123 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___123 *, const char *, const char **, size_t);
	struct fwnode_handle___123 * (*get_parent)(const struct fwnode_handle___123 *);
	struct fwnode_handle___123 * (*get_next_child_node)(const struct fwnode_handle___123 *, struct fwnode_handle___123 *);
	struct fwnode_handle___123 * (*get_named_child_node)(const struct fwnode_handle___123 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___123 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___123 *);
	struct fwnode_handle___123 * (*graph_get_next_endpoint)(const struct fwnode_handle___123 *, struct fwnode_handle___123 *);
	struct fwnode_handle___123 * (*graph_get_remote_endpoint)(const struct fwnode_handle___123 *);
	struct fwnode_handle___123 * (*graph_get_port_parent)(struct fwnode_handle___123 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___123 *, struct fwnode_endpoint___123 *);
};

struct fwnode_endpoint___123 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___123 *local_fwnode;
};

struct fwnode_reference_args___123 {
	struct fwnode_handle___123 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct elevator_type___47;

struct elevator_mq_ops___47 {
	int (*init_sched)(struct request_queue___48 *, struct elevator_type___47 *);
	void (*exit_sched)(struct elevator_queue___47 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	bool (*allow_merge)(struct request_queue___48 *, struct request___48 *, struct bio___99 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx *, struct bio___99 *);
	int (*request_merge)(struct request_queue___48 *, struct request___48 **, struct bio___99 *);
	void (*request_merged)(struct request_queue___48 *, struct request___48 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___48 *, struct request___48 *, struct request___48 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___48 *, struct bio___99 *);
	void (*finish_request)(struct request___48 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___48 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___48 *, u64);
	void (*started_request)(struct request___48 *);
	void (*requeue_request)(struct request___48 *);
	struct request___48 * (*former_request)(struct request_queue___48 *, struct request___48 *);
	struct request___48 * (*next_request)(struct request_queue___48 *, struct request___48 *);
	void (*init_icq)(struct io_cq___51 *);
	void (*exit_icq)(struct io_cq___51 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___47;

struct elevator_type___47 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___47 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___47 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___164 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___47 {
	struct elevator_type___47 *type;
	void *elevator_data;
	struct kobject___186 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___47 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___47 *, char *);
	ssize_t (*store)(struct elevator_queue___47 *, const char *, size_t);
};

typedef int (*key_restrict_link_func_t___189)(struct key___189 *, const struct key_type *, const union key_payload *, struct key___189 *);

struct key_restriction___189;

struct key___189 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___195 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___189 *restrict_link;
};

struct key_restriction___189 {
	key_restrict_link_func_t___189 check;
	struct key___189 *key;
	struct key_type *keytype;
};

struct seq_operations___180 {
	void * (*start)(struct seq_file___182 *, loff_t *);
	void (*stop)(struct seq_file___182 *, void *);
	void * (*next)(struct seq_file___182 *, void *, loff_t *);
	int (*show)(struct seq_file___182 *, void *);
};

struct cgroup_namespace___163 {
	refcount_t count;
	struct ns_common___11 ns;
	struct user_namespace___172 *user_ns;
	struct ucounts___172 *ucounts;
	struct css_set___163 *root_cset;
};

struct ucounts___172 {
	struct hlist_node node;
	struct user_namespace___172 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___163;

struct bpf_map_ops___163 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___163 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___163 *, struct file___195 *);
	void (*map_free)(struct bpf_map___163 *);
	int (*map_get_next_key)(struct bpf_map___163 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___163 *);
	void * (*map_lookup_elem)(struct bpf_map___163 *, void *);
	int (*map_update_elem)(struct bpf_map___163 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___163 *, void *);
	int (*map_push_elem)(struct bpf_map___163 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___163 *, void *);
	int (*map_peek_elem)(struct bpf_map___163 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___163 *, struct file___195 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___163 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___163 *, void *, struct seq_file___182 *);
	int (*map_check_btf)(const struct bpf_map___163 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___163 {
	const struct bpf_map_ops___163 *ops;
	struct bpf_map___163 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___189 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___163;

typedef void (*kthread_work_func_t___163)(struct kthread_work___163 *);

struct kthread_worker___163;

struct kthread_work___163 {
	struct list_head node;
	kthread_work_func_t___163 func;
	struct kthread_worker___163 *worker;
	int canceling;
};

struct kthread_worker___163 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___195 *task;
	struct kthread_work___163 *current_work;
};

struct kthread_delayed_work___163 {
	struct kthread_work___163 work;
	struct timer_list timer;
};

struct psi_group___163 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___163 *poll_kworker;
	struct kthread_delayed_work___163 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___163;

struct cgroup_rstat_cpu___163;

struct cgroup___163 {
	struct cgroup_subsys_state___164 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___189 *kn;
	struct cgroup_file___163 procs_file;
	struct cgroup_file___163 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___164 *subsys[13];
	struct cgroup_root___163 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___163 *dom_cgrp;
	struct cgroup_rstat_cpu___163 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___22 bpf;
	atomic_t congestion_count;
	struct cgroup___163 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___163 psi;
	int ancestor_ids[0];
};

struct cftype___163;

struct cgroup_subsys___163 {
	struct cgroup_subsys_state___164 * (*css_alloc)(struct cgroup_subsys_state___164 *);
	int (*css_online)(struct cgroup_subsys_state___164 *);
	void (*css_offline)(struct cgroup_subsys_state___164 *);
	void (*css_released)(struct cgroup_subsys_state___164 *);
	void (*css_free)(struct cgroup_subsys_state___164 *);
	void (*css_reset)(struct cgroup_subsys_state___164 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___164 *, int);
	int (*css_extra_stat_show)(struct seq_file___182 *, struct cgroup_subsys_state___164 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___195 *);
	void (*cancel_fork)(struct task_struct___195 *);
	void (*fork)(struct task_struct___195 *);
	void (*exit)(struct task_struct___195 *);
	void (*free)(struct task_struct___195 *);
	void (*bind)(struct cgroup_subsys_state___164 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___163 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___163 *dfl_cftypes;
	struct cftype___163 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___163 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___163 *updated_children;
	struct cgroup___163 *updated_next;
};

struct cgroup_root___163 {
	struct kernfs_root___189 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___163 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___163 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___163 *ss;
	struct list_head node;
	struct kernfs_ops___189 *kf_ops;
	int (*open)(struct kernfs_open_file___189 *);
	void (*release)(struct kernfs_open_file___189 *);
	u64 (*read_u64)(struct cgroup_subsys_state___164 *, struct cftype___163 *);
	s64 (*read_s64)(struct cgroup_subsys_state___164 *, struct cftype___163 *);
	int (*seq_show)(struct seq_file___182 *, void *);
	void * (*seq_start)(struct seq_file___182 *, loff_t *);
	void * (*seq_next)(struct seq_file___182 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___182 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___164 *, struct cftype___163 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___164 *, struct cftype___163 *, s64);
	ssize_t (*write)(struct kernfs_open_file___189 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___189 *, struct poll_table_struct___133 *);
};

struct mem_cgroup_reclaim_iter___88 {
	struct mem_cgroup___88 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___88 {
	struct lruvec___194 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___88 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___88 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct pagevec___9 {
	unsigned char nr;
	bool percpu_pvec_drained;
	struct page___195 *pages[15];
};

struct iomap_page_ops___2;

struct iomap___3 {
	u64 addr;
	loff_t offset;
	u64 length;
	u16 type;
	u16 flags;
	struct block_device___195 *bdev;
	struct dax_device *dax_dev;
	void *inline_data;
	void *private;
	const struct iomap_page_ops___2 *page_ops;
};

struct iomap_page_ops___2 {
	int (*page_prepare)(struct inode___195 *, loff_t, unsigned int, struct iomap___3 *);
	void (*page_done)(struct inode___195 *, loff_t, unsigned int, struct page___195 *, struct iomap___3 *);
};

struct iomap_ops {
	int (*iomap_begin)(struct inode___195 *, loff_t, loff_t, unsigned int, struct iomap___3 *);
	int (*iomap_end)(struct inode___195 *, loff_t, loff_t, ssize_t, unsigned int, struct iomap___3 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernel_param_ops___161 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___161 *);
	int (*get)(char *, const struct kernel_param___161 *);
	void (*free)(void *);
};

struct kparam_array___161;

struct kernel_param___161 {
	const char *name;
	struct module___164 *mod;
	const struct kernel_param_ops___161 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___161 *arr;
	};
};

struct kparam_array___161 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___161 *ops;
	void *elem;
};

struct module_attribute___161 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___161 *, struct module_kobject___161 *, char *);
	ssize_t (*store)(struct module_attribute___161 *, struct module_kobject___161 *, const char *, size_t);
	void (*setup)(struct module___164 *, const char *);
	int (*test)(struct module___164 *);
	void (*free)(struct module___164 *);
};

struct trace_event_class___111;

struct trace_event_call___111 {
	struct list_head list;
	struct trace_event_class___111 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___22 *prog_array;
	int (*perf_perm)(struct trace_event_call___111 *, struct perf_event___118 *);
};

struct node___151 {
	struct device___176 dev;
};

struct perf_cpu_context___118;

struct pmu___118 {
	struct list_head entry;
	struct module___164 *module;
	struct device___176 *dev;
	const struct attribute_group___177 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___118 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___118 *);
	void (*pmu_disable)(struct pmu___118 *);
	int (*event_init)(struct perf_event___118 *);
	void (*event_mapped)(struct perf_event___118 *, struct mm_struct___194 *);
	void (*event_unmapped)(struct perf_event___118 *, struct mm_struct___194 *);
	int (*add)(struct perf_event___118 *, int);
	void (*del)(struct perf_event___118 *, int);
	void (*start)(struct perf_event___118 *, int);
	void (*stop)(struct perf_event___118 *, int);
	void (*read)(struct perf_event___118 *);
	void (*start_txn)(struct pmu___118 *, unsigned int);
	int (*commit_txn)(struct pmu___118 *);
	void (*cancel_txn)(struct pmu___118 *);
	int (*event_idx)(struct perf_event___118 *);
	void (*sched_task)(struct perf_event_context___118 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___118 *);
	int (*filter_match)(struct perf_event___118 *);
	int (*check_period)(struct perf_event___118 *, u64);
};

struct perf_cpu_context___118 {
	struct perf_event_context___118 ctx;
	struct perf_event_context___118 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___118 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___118 {
	struct cgroup_subsys_state___164 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___111 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___111 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___111 *);
	struct list_head * (*get_fields)(struct trace_event_call___111 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___111 *);
};

struct trace_event_file___44;

struct trace_event_buffer___36 {
	struct ring_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___44 *trace_file;
	void *entry;
	long unsigned int flags;
	int pc;
};

struct trace_event_file___44 {
	struct list_head list;
	struct trace_event_call___111 *event_call;
	struct event_filter *filter;
	struct dentry___194 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_dax_pmd_fault_class {
	struct trace_entry ent;
	long unsigned int ino;
	long unsigned int vm_start;
	long unsigned int vm_end;
	long unsigned int vm_flags;
	long unsigned int address;
	long unsigned int pgoff;
	long unsigned int max_pgoff;
	dev_t dev;
	unsigned int flags;
	int result;
	char __data[0];
};

struct trace_event_raw_dax_pmd_load_hole_class {
	struct trace_entry ent;
	long unsigned int ino;
	long unsigned int vm_flags;
	long unsigned int address;
	struct page___195 *zero_page;
	void *radix_entry;
	dev_t dev;
	char __data[0];
};

struct trace_event_raw_dax_pmd_insert_mapping_class {
	struct trace_entry ent;
	long unsigned int ino;
	long unsigned int vm_flags;
	long unsigned int address;
	long int length;
	u64 pfn_val;
	void *radix_entry;
	dev_t dev;
	int write;
	char __data[0];
};

struct trace_event_raw_dax_pte_fault_class {
	struct trace_entry ent;
	long unsigned int ino;
	long unsigned int vm_flags;
	long unsigned int address;
	long unsigned int pgoff;
	dev_t dev;
	unsigned int flags;
	int result;
	char __data[0];
};

struct trace_event_raw_dax_insert_mapping {
	struct trace_entry ent;
	long unsigned int ino;
	long unsigned int vm_flags;
	long unsigned int address;
	void *radix_entry;
	dev_t dev;
	int write;
	char __data[0];
};

struct trace_event_raw_dax_writeback_range_class {
	struct trace_entry ent;
	long unsigned int ino;
	long unsigned int start_index;
	long unsigned int end_index;
	dev_t dev;
	char __data[0];
};

struct trace_event_raw_dax_writeback_one {
	struct trace_entry ent;
	long unsigned int ino;
	long unsigned int pgoff;
	long unsigned int pglen;
	dev_t dev;
	char __data[0];
};

struct trace_event_data_offsets_dax_pmd_fault_class {};

struct trace_event_data_offsets_dax_pmd_load_hole_class {};

struct trace_event_data_offsets_dax_pmd_insert_mapping_class {};

struct trace_event_data_offsets_dax_pte_fault_class {};

struct trace_event_data_offsets_dax_insert_mapping {};

struct trace_event_data_offsets_dax_writeback_range_class {};

struct trace_event_data_offsets_dax_writeback_one {};

struct exceptional_entry_key {
	struct address_space___194 *mapping;
	long unsigned int entry_start;
};

struct wait_exceptional_entry_queue {
	wait_queue_entry_t wait;
	struct exceptional_entry_key key;
};

struct flock64 {
	short int l_type;
	short int l_whence;
	__kernel_loff_t l_start;
	__kernel_loff_t l_len;
	__kernel_pid_t l_pid;
};

struct trace_event_file___45;

struct trace_event_buffer___37 {
	struct ring_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___45 *trace_file;
	void *entry;
	long unsigned int flags;
	int pc;
};

struct trace_event_file___45 {
	struct list_head list;
	struct trace_event_call___98 *event_call;
	struct event_filter *filter;
	struct dentry___170 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_locks_get_lock_context {
	struct trace_entry ent;
	long unsigned int i_ino;
	dev_t s_dev;
	unsigned char type;
	struct file_lock_context *ctx;
	char __data[0];
};

struct trace_event_raw_filelock_lock {
	struct trace_entry ent;
	struct file_lock___171 *fl;
	long unsigned int i_ino;
	dev_t s_dev;
	struct file_lock___171 *fl_next;
	fl_owner_t fl_owner;
	unsigned int fl_pid;
	unsigned int fl_flags;
	unsigned char fl_type;
	loff_t fl_start;
	loff_t fl_end;
	int ret;
	char __data[0];
};

struct trace_event_raw_filelock_lease {
	struct trace_entry ent;
	struct file_lock___171 *fl;
	long unsigned int i_ino;
	dev_t s_dev;
	struct file_lock___171 *fl_next;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	char __data[0];
};

struct trace_event_raw_generic_add_lease {
	struct trace_entry ent;
	long unsigned int i_ino;
	int wcount;
	int dcount;
	int icount;
	dev_t s_dev;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	char __data[0];
};

struct trace_event_data_offsets_locks_get_lock_context {};

struct trace_event_data_offsets_filelock_lock {};

struct trace_event_data_offsets_filelock_lease {};

struct trace_event_data_offsets_generic_add_lease {};

struct file_lock_list_struct {
	spinlock_t lock;
	struct hlist_head hlist;
};

struct locks_iterator {
	int li_cpu;
	loff_t li_pos;
};

typedef unsigned int __kernel_uid_t;

typedef unsigned int __kernel_gid_t;

struct module___165;

struct file___196;

struct kiocb___196;

struct vm_area_struct___196;

struct inode___196;

struct file_lock___196;

struct page___196;

struct file_operations___196 {
	struct module___165 *owner;
	loff_t (*llseek)(struct file___196 *, loff_t, int);
	ssize_t (*read)(struct file___196 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___196 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___196 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___196 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___196 *, bool);
	int (*iterate)(struct file___196 *, struct dir_context *);
	int (*iterate_shared)(struct file___196 *, struct dir_context *);
	__poll_t (*poll)(struct file___196 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___196 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___196 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___196 *, struct vm_area_struct___196 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___196 *, struct file___196 *);
	int (*flush)(struct file___196 *, fl_owner_t);
	int (*release)(struct inode___196 *, struct file___196 *);
	int (*fsync)(struct file___196 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___196 *, int);
	int (*lock)(struct file___196 *, int, struct file_lock___196 *);
	ssize_t (*sendpage)(struct file___196 *, struct page___196 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___196 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___196 *, int, struct file_lock___196 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___196 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___196 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___196 *, long int, struct file_lock___196 **, void **);
	long int (*fallocate)(struct file___196 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___196 *);
	ssize_t (*copy_file_range)(struct file___196 *, loff_t, struct file___196 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___196 *, loff_t, struct file___196 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___196 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___195 {
	u64 seqnum;
	struct vm_area_struct___196 *vmas[4];
};

struct page_frag___195 {
	struct page___196 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___195;

struct pid___155;

struct cred___190;

struct nsproxy___185;

struct signal_struct___172;

struct vm_struct___137;

struct task_struct___196 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___196 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___195 *mm;
	struct mm_struct___195 *active_mm;
	struct vmacache___195 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___196 *real_parent;
	struct task_struct___196 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___196 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___155 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___155 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___155 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___190 *ptracer_cred;
	const struct cred___190 *real_cred;
	const struct cred___190 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___185 *nsproxy;
	struct signal_struct___172 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___196 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___51 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___195 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___196 *oom_reaper_list;
	struct vm_struct___137 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___118 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___196 *pgtable_t___195;

struct address_space___195;

struct dev_pagemap___192;

struct page___196 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___195 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___196 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___195 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___195 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___192 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___195;

struct lruvec___195 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___195 *pgdat;
};

struct zone___195 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___195 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___195 {
	struct zone___195 *zone;
	int zone_idx;
};

struct zonelist___195 {
	struct zoneref___195 _zonerefs[25];
};

struct pglist_data___195 {
	struct zone___195 node_zones[3];
	struct zonelist___195 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___196 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___196 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___195 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___196 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___196 *owner;
};

struct secondary_data___196 {
	void *stack;
	struct task_struct___196 *task;
	long int status;
};

struct blocking_notifier_head___195 {
	struct rw_semaphore___196 rwsem;
	struct notifier_block *head;
};

struct dentry___195;

struct path___195 {
	struct vfsmount *mnt;
	struct dentry___195 *dentry;
};

struct fown_struct___155 {
	rwlock_t lock;
	struct pid___155 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___196 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___195 f_path;
	struct inode___196 *f_inode;
	const struct file_operations___196 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___155 f_owner;
	const struct cred___190 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___195 *f_mapping;
	errseq_t f_wb_err;
};

struct key___190;

struct user_struct___190;

struct cred___190 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___190 *session_keyring;
	struct key___190 *process_keyring;
	struct key___190 *thread_keyring;
	struct key___190 *request_key_auth;
	void *security;
	struct user_struct___190 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___190;

struct kernfs_elem_dir___190 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___190 *root;
};

struct kernfs_node___190;

struct kernfs_syscall_ops___190;

struct kernfs_root___190 {
	struct kernfs_node___190 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___190 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___190 {
	struct kernfs_node___190 *target_kn;
};

struct kernfs_ops___190;

struct kernfs_elem_attr___190 {
	const struct kernfs_ops___190 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___190 *notify_next;
};

struct kernfs_node___190 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___190 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___190 dir;
		struct kernfs_elem_symlink___190 symlink;
		struct kernfs_elem_attr___190 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___190;

struct kernfs_ops___190 {
	int (*open)(struct kernfs_open_file___190 *);
	void (*release)(struct kernfs_open_file___190 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___190 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___190 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___190 *, struct vm_area_struct___196 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___190 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___190 {
	int (*remount_fs)(struct kernfs_root___190 *, int *, char *);
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___190 *);
	int (*mkdir)(struct kernfs_node___190 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___190 *);
	int (*rename)(struct kernfs_node___190 *, struct kernfs_node___190 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___190 *, struct kernfs_root___190 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_operations_struct___192;

struct kernfs_open_file___190 {
	struct kernfs_node___190 *kn;
	struct file___196 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___192 *vm_ops;
};

struct vm_fault___192;

struct vm_operations_struct___192 {
	void (*open)(struct vm_area_struct___196 *);
	void (*close)(struct vm_area_struct___196 *);
	int (*split)(struct vm_area_struct___196 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___196 *);
	vm_fault_t (*fault)(struct vm_fault___192 *);
	vm_fault_t (*huge_fault)(struct vm_fault___192 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___192 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___196 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___192 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___192 *);
	int (*access)(struct vm_area_struct___196 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___196 *);
	int (*set_policy)(struct vm_area_struct___196 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___196 *, long unsigned int);
	struct page___196 * (*find_special_page)(struct vm_area_struct___196 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_area_struct___196 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___196 *vm_next;
	struct vm_area_struct___196 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___195 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___192 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___196 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___187;

struct bin_attribute___177;

struct attribute_group___178 {
	const char *name;
	umode_t (*is_visible)(struct kobject___187 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___187 *, struct bin_attribute___177 *, int);
	struct attribute **attrs;
	struct bin_attribute___177 **bin_attrs;
};

struct kset___186;

struct kobj_type___186;

struct kobject___187 {
	const char *name;
	struct list_head entry;
	struct kobject___187 *parent;
	struct kset___186 *kset;
	struct kobj_type___186 *ktype;
	struct kernfs_node___190 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___177 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___196 *, struct kobject___187 *, struct bin_attribute___177 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___196 *, struct kobject___187 *, struct bin_attribute___177 *, char *, loff_t, size_t);
	int (*mmap)(struct file___196 *, struct kobject___187 *, struct bin_attribute___177 *, struct vm_area_struct___196 *);
};

struct sysfs_ops___186 {
	ssize_t (*show)(struct kobject___187 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___187 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___186;

struct kset___186 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___187 kobj;
	const struct kset_uevent_ops___186 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___186 {
	void (*release)(struct kobject___187 *);
	const struct sysfs_ops___186 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___12 * (*child_ns_type)(struct kobject___187 *);
	const void * (*namespace)(struct kobject___187 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___186 {
	int (* const filter)(struct kset___186 *, struct kobject___187 *);
	const char * (* const name)(struct kset___186 *, struct kobject___187 *);
	int (* const uevent)(struct kset___186 *, struct kobject___187 *, struct kobj_uevent_env *);
};

struct kobj_attribute___186 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___187 *, struct kobj_attribute___186 *, char *);
	ssize_t (*store)(struct kobject___187 *, struct kobj_attribute___186 *, const char *, size_t);
};

struct kernel_param___162;

struct kernel_param_ops___162 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___162 *);
	int (*get)(char *, const struct kernel_param___162 *);
	void (*free)(void *);
};

struct kparam_array___162;

struct kernel_param___162 {
	const char *name;
	struct module___165 *mod;
	const struct kernel_param_ops___162 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___162 *arr;
	};
};

struct kparam_array___162 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___162 *ops;
	void *elem;
};

struct module_kobject___162 {
	struct kobject___187 kobj;
	struct module___165 *mod;
	struct kobject___187 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___162 {
	struct module___165 *mod;
	struct latch_tree_node node;
};

struct module_layout___162 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___162 mtn;
};

struct module_attribute___162;

struct module___165 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___162 mkobj;
	struct module_attribute___162 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___187 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___162 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___162 core_layout;
	struct module_layout___162 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___162 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___162 *, struct module_kobject___162 *, char *);
	ssize_t (*store)(struct module_attribute___162 *, struct module_kobject___162 *, const char *, size_t);
	void (*setup)(struct module___165 *, const char *);
	int (*test)(struct module___165 *);
	void (*free)(struct module___165 *);
};

struct dentry_operations___195;

struct super_block___195;

struct dentry___195 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___195 *d_parent;
	struct qstr d_name;
	struct inode___196 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___195 *d_op;
	struct super_block___195 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___195;

struct address_space___195 {
	struct inode___196 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___196 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___195 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___195;

struct block_device___196;

struct inode___196 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___195 *i_op;
	struct super_block___195 *i_sb;
	struct address_space___195 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___196 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___196 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___195 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___196 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___195 {
	int (*d_revalidate)(struct dentry___195 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___195 *, unsigned int);
	int (*d_hash)(const struct dentry___195 *, struct qstr *);
	int (*d_compare)(const struct dentry___195 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___195 *);
	int (*d_init)(struct dentry___195 *);
	void (*d_release)(struct dentry___195 *);
	void (*d_prune)(struct dentry___195 *);
	void (*d_iput)(struct dentry___195 *, struct inode___196 *);
	char * (*d_dname)(struct dentry___195 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___195 *);
	int (*d_manage)(const struct path___195 *, bool);
	struct dentry___195 * (*d_real)(struct dentry___195 *, const struct inode___196 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___195;

struct mem_dqinfo___195 {
	struct quota_format_type___195 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___195;

struct quota_info___195 {
	unsigned int flags;
	struct rw_semaphore___196 dqio_sem;
	struct inode___196 *files[3];
	struct mem_dqinfo___195 info[3];
	const struct quota_format_ops___195 *ops[3];
};

struct rcuwait___195 {
	struct task_struct___196 *task;
};

struct percpu_rw_semaphore___195 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___196 rw_sem;
	struct rcuwait___195 writer;
	int readers_block;
};

struct sb_writers___195 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___195 rw_sem[3];
};

struct file_system_type___195;

struct super_operations___195;

struct dquot_operations___195;

struct quotactl_ops___195;

struct super_block___195 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___195 *s_type;
	const struct super_operations___195 *s_op;
	const struct dquot_operations___195 *dq_op;
	const struct quotactl_ops___195 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___195 *s_root;
	struct rw_semaphore___196 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___196 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___195 s_dquot;
	struct sb_writers___195 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___195 *s_d_op;
	int cleancache_poolid;
	struct shrinker___88 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct pid_namespace___155;

struct upid___155 {
	int nr;
	struct pid_namespace___155 *ns;
};

struct pid_namespace___155 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___196 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___155 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___195 *proc_self;
	struct dentry___195 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___3 *user_ns;
	struct ucounts___2 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___4 ns;
};

struct pid___155 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___155 numbers[1];
};

struct linux_binfmt___19;

struct core_state___195;

struct mm_struct___195 {
	struct {
		struct vm_area_struct___196 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___196 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___196 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___19 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___195 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___196 *owner;
		struct user_namespace___3 *user_ns;
		struct file___196 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___195 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___192)(struct vm_area_struct___196 *, long unsigned int, const struct page___196 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___192)(struct page___196 *, void *);

struct dev_pagemap___192 {
	dev_page_fault_t___192 page_fault;
	dev_page_free_t___192 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___6 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___195 {
	struct task_struct___196 *task;
	struct core_thread___195 *next;
};

struct core_state___195 {
	atomic_t nr_threads;
	struct core_thread___195 dumper;
	struct completion startup;
};

struct linux_binprm___20;

struct coredump_params___19;

struct linux_binfmt___19 {
	struct list_head lh;
	struct module___165 *module;
	int (*load_binary)(struct linux_binprm___20 *);
	int (*load_shlib)(struct file___196 *);
	int (*core_dump)(struct coredump_params___19 *);
	long unsigned int min_coredump;
};

struct vm_fault___192 {
	struct vm_area_struct___196 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___196 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___196 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___195 prealloc_pte;
};

struct user_struct___190 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___190 *uid_keyring;
	struct key___190 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct nsproxy___185 {
	atomic_t count;
	struct uts_namespace___22 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___155 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct signal_struct___172 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___196 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___196 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___155 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___155 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___195 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___155 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_struct___137 {
	struct vm_struct___137 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___196 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___174 {
	struct task_struct___196 task;
	long unsigned int stack[8192];
};

struct kiocb___196 {
	struct file___196 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___196 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___195 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___196 *ia_file;
};

struct dquot___195 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___195 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___195 {
	int qf_fmt_id;
	const struct quota_format_ops___195 *qf_ops;
	struct module___165 *qf_owner;
	struct quota_format_type___195 *qf_next;
};

struct quota_format_ops___195 {
	int (*check_quota_file)(struct super_block___195 *, int);
	int (*read_file_info)(struct super_block___195 *, int);
	int (*write_file_info)(struct super_block___195 *, int);
	int (*free_file_info)(struct super_block___195 *, int);
	int (*read_dqblk)(struct dquot___195 *);
	int (*commit_dqblk)(struct dquot___195 *);
	int (*release_dqblk)(struct dquot___195 *);
	int (*get_next_id)(struct super_block___195 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___195 {
	int (*write_dquot)(struct dquot___195 *);
	struct dquot___195 * (*alloc_dquot)(struct super_block___195 *, int);
	void (*destroy_dquot)(struct dquot___195 *);
	int (*acquire_dquot)(struct dquot___195 *);
	int (*release_dquot)(struct dquot___195 *);
	int (*mark_dirty)(struct dquot___195 *);
	int (*write_info)(struct super_block___195 *, int);
	qsize_t * (*get_reserved_space)(struct inode___196 *);
	int (*get_projid)(struct inode___196 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___196 *, qsize_t *);
	int (*get_next_id)(struct super_block___195 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___195 {
	int (*quota_on)(struct super_block___195 *, int, int, const struct path___195 *);
	int (*quota_off)(struct super_block___195 *, int);
	int (*quota_enable)(struct super_block___195 *, unsigned int);
	int (*quota_disable)(struct super_block___195 *, unsigned int);
	int (*quota_sync)(struct super_block___195 *, int);
	int (*set_info)(struct super_block___195 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___195 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___195 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___195 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___195 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___195 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___195 {
	int (*writepage)(struct page___196 *, struct writeback_control___3 *);
	int (*readpage)(struct file___196 *, struct page___196 *);
	int (*writepages)(struct address_space___195 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___196 *);
	int (*readpages)(struct file___196 *, struct address_space___195 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___196 *, struct address_space___195 *, loff_t, unsigned int, unsigned int, struct page___196 **, void **);
	int (*write_end)(struct file___196 *, struct address_space___195 *, loff_t, unsigned int, unsigned int, struct page___196 *, void *);
	sector_t (*bmap)(struct address_space___195 *, sector_t);
	void (*invalidatepage)(struct page___196 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___196 *, gfp_t);
	void (*freepage)(struct page___196 *);
	ssize_t (*direct_IO)(struct kiocb___196 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___195 *, struct page___196 *, struct page___196 *, enum migrate_mode);
	bool (*isolate_page)(struct page___196 *, isolate_mode_t);
	void (*putback_page)(struct page___196 *);
	int (*launder_page)(struct page___196 *);
	int (*is_partially_uptodate)(struct page___196 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___196 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___195 *, struct page___196 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___196 *, sector_t *);
	void (*swap_deactivate)(struct file___196 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___196 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___196 *bd_inode;
	struct super_block___195 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___196 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___195 {
	struct dentry___195 * (*lookup)(struct inode___196 *, struct dentry___195 *, unsigned int);
	const char * (*get_link)(struct dentry___195 *, struct inode___196 *, struct delayed_call *);
	int (*permission)(struct inode___196 *, int);
	struct posix_acl * (*get_acl)(struct inode___196 *, int);
	int (*readlink)(struct dentry___195 *, char *, int);
	int (*create)(struct inode___196 *, struct dentry___195 *, umode_t, bool);
	int (*link)(struct dentry___195 *, struct inode___196 *, struct dentry___195 *);
	int (*unlink)(struct inode___196 *, struct dentry___195 *);
	int (*symlink)(struct inode___196 *, struct dentry___195 *, const char *);
	int (*mkdir)(struct inode___196 *, struct dentry___195 *, umode_t);
	int (*rmdir)(struct inode___196 *, struct dentry___195 *);
	int (*mknod)(struct inode___196 *, struct dentry___195 *, umode_t, dev_t);
	int (*rename)(struct inode___196 *, struct dentry___195 *, struct inode___196 *, struct dentry___195 *, unsigned int);
	int (*setattr)(struct dentry___195 *, struct iattr___195 *);
	int (*getattr)(const struct path___195 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___195 *, char *, size_t);
	int (*fiemap)(struct inode___196 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___196 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___196 *, struct dentry___195 *, struct file___196 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___196 *, struct dentry___195 *, umode_t);
	int (*set_acl)(struct inode___196 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___195 {
	void (*fl_copy_lock)(struct file_lock___196 *, struct file_lock___196 *);
	void (*fl_release_private)(struct file_lock___196 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___195;

struct lock_manager_operations___195;

struct file_lock___196 {
	struct file_lock___196 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___196 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___195 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___195 *fl_ops;
	const struct lock_manager_operations___195 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___195 {
	int (*lm_compare_owner)(struct file_lock___196 *, struct file_lock___196 *);
	long unsigned int (*lm_owner_key)(struct file_lock___196 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___196 *);
	int (*lm_grant)(struct file_lock___196 *, int);
	bool (*lm_break)(struct file_lock___196 *);
	int (*lm_change)(struct file_lock___196 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___196 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___195 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___195 *fa_next;
	struct file___196 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___195 {
	const char *name;
	int fs_flags;
	struct dentry___195 * (*mount)(struct file_system_type___195 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___195 *);
	struct module___165 *owner;
	struct file_system_type___195 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___195 {
	struct inode___196 * (*alloc_inode)(struct super_block___195 *);
	void (*destroy_inode)(struct inode___196 *);
	void (*dirty_inode)(struct inode___196 *, int);
	int (*write_inode)(struct inode___196 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___196 *);
	void (*evict_inode)(struct inode___196 *);
	void (*put_super)(struct super_block___195 *);
	int (*sync_fs)(struct super_block___195 *, int);
	int (*freeze_super)(struct super_block___195 *);
	int (*freeze_fs)(struct super_block___195 *);
	int (*thaw_super)(struct super_block___195 *);
	int (*unfreeze_fs)(struct super_block___195 *);
	int (*statfs)(struct dentry___195 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___195 *, int *, char *);
	void (*umount_begin)(struct super_block___195 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___195 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___195 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___195 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___195 *);
	ssize_t (*quota_read)(struct super_block___195 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___195 *, int, const char *, size_t, loff_t);
	struct dquot___195 ** (*get_dquots)(struct inode___196 *);
	int (*bdev_try_to_free_page)(struct super_block___195 *, struct page___196 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___195 *, struct shrink_control___88 *);
	long int (*free_cached_objects)(struct super_block___195 *, struct shrink_control___88 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___192(struct page___196 *);

struct linux_binprm___20 {
	char buf[256];
	struct vm_area_struct___196 *vma;
	long unsigned int vma_pages;
	struct mm_struct___195 *mm;
	long unsigned int p;
	unsigned int called_set_creds: 1;
	unsigned int cap_elevated: 1;
	unsigned int secureexec: 1;
	unsigned int recursion_depth;
	struct file___196 *file;
	struct cred___190 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
};

struct coredump_params___19 {
	union {
		const kernel_siginfo_t *siginfo;
		struct {
			const siginfo_t *siginfo;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	struct pt_regs *regs;
	struct file___196 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
};

typedef int (*key_restrict_link_func_t___190)(struct key___190 *, const struct key_type *, const union key_payload *, struct key___190 *);

struct key_restriction___190;

struct key___190 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___196 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___190 *restrict_link;
};

struct key_restriction___190 {
	key_restrict_link_func_t___190 check;
	struct key___190 *key;
	struct key_type *keytype;
};

struct elf_prpsinfo {
	char pr_state;
	char pr_sname;
	char pr_zomb;
	char pr_nice;
	long unsigned int pr_flag;
	__kernel_uid_t pr_uid;
	__kernel_gid_t pr_gid;
	pid_t pr_pid;
	pid_t pr_ppid;
	pid_t pr_pgrp;
	pid_t pr_sid;
	char pr_fname[16];
	char pr_psargs[80];
};

struct arch_elf_state {};

struct memelfnote {
	const char *name;
	int type;
	unsigned int datasz;
	void *data;
};

struct user_regset___3;

typedef int user_regset_active_fn___3(struct task_struct___196 *, const struct user_regset___3 *);

typedef int user_regset_get_fn___3(struct task_struct___196 *, const struct user_regset___3 *, unsigned int, unsigned int, void *, void *);

typedef int user_regset_set_fn___3(struct task_struct___196 *, const struct user_regset___3 *, unsigned int, unsigned int, const void *, const void *);

typedef int user_regset_writeback_fn___3(struct task_struct___196 *, const struct user_regset___3 *, int);

typedef unsigned int user_regset_get_size_fn___3(struct task_struct___196 *, const struct user_regset___3 *);

struct user_regset___3 {
	user_regset_get_fn___3 *get;
	user_regset_set_fn___3 *set;
	user_regset_active_fn___3 *active;
	user_regset_writeback_fn___3 *writeback;
	user_regset_get_size_fn___3 *get_size;
	unsigned int n;
	unsigned int size;
	unsigned int align;
	unsigned int bias;
	unsigned int core_note_type;
};

struct user_regset_view___3 {
	const char *name;
	const struct user_regset___3 *regsets;
	unsigned int n;
	u32 e_flags;
	u16 e_machine;
	u8 ei_osabi;
};

struct elf_thread_core_info {
	struct elf_thread_core_info *next;
	struct task_struct___196 *task;
	struct elf_prstatus prstatus;
	struct memelfnote notes[0];
};

struct elf_note_info {
	struct elf_thread_core_info *thread;
	struct memelfnote psinfo;
	struct memelfnote signote;
	struct memelfnote auxv;
	struct memelfnote files;
	siginfo_t csigdata;
	size_t size;
	int thread_notes;
};

struct posix_acl_xattr_entry {
	__le16 e_tag;
	__le16 e_perm;
	__le32 e_id;
};

struct posix_acl_xattr_header {
	__le32 a_version;
};

struct module___166;

struct file___197;

struct kiocb___197;

struct iov_iter___96;

struct poll_table_struct___134;

struct vm_area_struct___197;

struct inode___197;

struct file_lock___197;

struct page___197;

struct pipe_inode_info___44;

struct seq_file___183;

struct file_operations___197 {
	struct module___166 *owner;
	loff_t (*llseek)(struct file___197 *, loff_t, int);
	ssize_t (*read)(struct file___197 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___197 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___197 *, struct iov_iter___96 *);
	ssize_t (*write_iter)(struct kiocb___197 *, struct iov_iter___96 *);
	int (*iopoll)(struct kiocb___197 *, bool);
	int (*iterate)(struct file___197 *, struct dir_context *);
	int (*iterate_shared)(struct file___197 *, struct dir_context *);
	__poll_t (*poll)(struct file___197 *, struct poll_table_struct___134 *);
	long int (*unlocked_ioctl)(struct file___197 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___197 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___197 *, struct vm_area_struct___197 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___197 *, struct file___197 *);
	int (*flush)(struct file___197 *, fl_owner_t);
	int (*release)(struct inode___197 *, struct file___197 *);
	int (*fsync)(struct file___197 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___197 *, int);
	int (*lock)(struct file___197 *, int, struct file_lock___197 *);
	ssize_t (*sendpage)(struct file___197 *, struct page___197 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___197 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___197 *, int, struct file_lock___197 *);
	ssize_t (*splice_write)(struct pipe_inode_info___44 *, struct file___197 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___197 *, loff_t *, struct pipe_inode_info___44 *, size_t, unsigned int);
	int (*setlease)(struct file___197 *, long int, struct file_lock___197 **, void **);
	long int (*fallocate)(struct file___197 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___183 *, struct file___197 *);
	ssize_t (*copy_file_range)(struct file___197 *, loff_t, struct file___197 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___197 *, loff_t, struct file___197 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___197 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___196 {
	u64 seqnum;
	struct vm_area_struct___197 *vmas[4];
};

struct page_frag___196 {
	struct page___197 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___119;

struct debug_info___119 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___119 *hbp_break[16];
	struct perf_event___119 *hbp_watch[16];
};

struct thread_struct___119 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___119 debug;
	long: 64;
};

struct mm_struct___196;

struct mem_cgroup___89;

struct pid___156;

struct cred___191;

struct fs_struct___12;

struct files_struct___12;

struct nsproxy___186;

struct signal_struct___173;

struct bio_list___100;

struct backing_dev_info___100;

struct io_context___52;

struct css_set___164;

struct perf_event_context___119;

struct request_queue___49;

struct vm_struct___138;

struct task_struct___197 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___197 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___196 *mm;
	struct mm_struct___196 *active_mm;
	struct vmacache___196 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___197 *real_parent;
	struct task_struct___197 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___197 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___89 *active_memcg;
	long int rh_reserved2;
	struct pid___156 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___156 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___156 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___191 *ptracer_cred;
	const struct cred___191 *real_cred;
	const struct cred___191 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct___12 *fs;
	struct files_struct___12 *files;
	struct nsproxy___186 *nsproxy;
	struct signal_struct___173 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___197 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___100 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___100 *backing_dev_info;
	struct io_context___52 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___164 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___119 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___44 *splice_pipe;
	struct page_frag___196 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___89 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___49 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___197 *oom_reaper_list;
	struct vm_struct___138 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___119 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___119 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___197 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___119)(struct perf_event___119 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___119;

struct fasync_struct___196;

struct pid_namespace___156;

struct trace_event_call___112;

struct perf_cgroup___119;

struct perf_event___119 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___119 *group_leader;
	struct pmu___119 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___119 hw;
	struct perf_event_context___119 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___119 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___197 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___196 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___119 *);
	struct callback_head callback_head;
	struct pid_namespace___156 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___119 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___119 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___112 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___119 *cgrp;
	struct list_head sb_list;
};

typedef struct page___197 *pgtable_t___196;

struct address_space___196;

struct dev_pagemap___193;

struct page___197 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___196 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___197 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___196 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___196 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___193 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___89 *mem_cgroup;
};

struct pglist_data___196;

struct lruvec___196 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___196 *pgdat;
};

struct zone___196 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___196 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___196 {
	struct zone___196 *zone;
	int zone_idx;
};

struct zonelist___196 {
	struct zoneref___196 _zonerefs[25];
};

struct pglist_data___196 {
	struct zone___196 node_zones[3];
	struct zonelist___196 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___197 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___197 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___196 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___197 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___197 *owner;
};

struct secondary_data___197 {
	void *stack;
	struct task_struct___197 *task;
	long int status;
};

struct blocking_notifier_head___196 {
	struct rw_semaphore___197 rwsem;
	struct notifier_block *head;
};

struct cgroup___164;

struct cgroup_subsys___164;

struct cgroup_subsys_state___165 {
	struct cgroup___164 *cgroup;
	struct cgroup_subsys___164 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___165 *parent;
};

struct kernfs_node___191;

struct cgroup_file___164 {
	struct kernfs_node___191 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___89;

struct mem_cgroup___89 {
	struct cgroup_subsys_state___165 css;
	struct mem_cgroup_id___6 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___164 events_file;
	struct cgroup_file___164 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___197 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___89 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct vfsmount___41;

struct dentry___196;

struct path___196 {
	struct vfsmount___41 *mnt;
	struct dentry___196 *dentry;
};

struct fown_struct___156 {
	rwlock_t lock;
	struct pid___156 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___197 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___196 f_path;
	struct inode___197 *f_inode;
	const struct file_operations___197 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___156 f_owner;
	const struct cred___191 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___196 *f_mapping;
	errseq_t f_wb_err;
};

struct dentry_operations___196;

struct super_block___196;

struct dentry___196 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___196 *d_parent;
	struct qstr d_name;
	struct inode___197 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___196 *d_op;
	struct super_block___196 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___196;

struct address_space___196 {
	struct inode___197 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___197 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___196 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___196;

struct bdi_writeback___100;

struct block_device___197;

struct inode___197 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___196 *i_op;
	struct super_block___196 *i_sb;
	struct address_space___196 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___197 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___100 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___197 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___196 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___44 *i_pipe;
		struct block_device___197 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___196 {
	int (*d_revalidate)(struct dentry___196 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___196 *, unsigned int);
	int (*d_hash)(const struct dentry___196 *, struct qstr *);
	int (*d_compare)(const struct dentry___196 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___196 *);
	int (*d_init)(struct dentry___196 *);
	void (*d_release)(struct dentry___196 *);
	void (*d_prune)(struct dentry___196 *);
	void (*d_iput)(struct dentry___196 *, struct inode___197 *);
	char * (*d_dname)(struct dentry___196 *, char *, int);
	struct vfsmount___41 * (*d_automount)(struct path___196 *);
	int (*d_manage)(const struct path___196 *, bool);
	struct dentry___196 * (*d_real)(struct dentry___196 *, const struct inode___197 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___196;

struct mem_dqinfo___196 {
	struct quota_format_type___196 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___196;

struct quota_info___196 {
	unsigned int flags;
	struct rw_semaphore___197 dqio_sem;
	struct inode___197 *files[3];
	struct mem_dqinfo___196 info[3];
	const struct quota_format_ops___196 *ops[3];
};

struct rcuwait___196 {
	struct task_struct___197 *task;
};

struct percpu_rw_semaphore___196 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___197 rw_sem;
	struct rcuwait___196 writer;
	int readers_block;
};

struct sb_writers___196 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___196 rw_sem[3];
};

struct shrink_control___89;

struct shrinker___89 {
	long unsigned int (*count_objects)(struct shrinker___89 *, struct shrink_control___89 *);
	long unsigned int (*scan_objects)(struct shrinker___89 *, struct shrink_control___89 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___196;

struct super_operations___196;

struct dquot_operations___196;

struct quotactl_ops___196;

struct user_namespace___173;

struct super_block___196 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___196 *s_type;
	const struct super_operations___196 *s_op;
	const struct dquot_operations___196 *dq_op;
	const struct quotactl_ops___196 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___196 *s_root;
	struct rw_semaphore___197 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___197 *s_bdev;
	struct backing_dev_info___100 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___196 s_dquot;
	struct sb_writers___196 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___196 *s_d_op;
	int cleancache_poolid;
	struct shrinker___89 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___173 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___41 {
	struct dentry___196 *mnt_root;
	struct super_block___196 *mnt_sb;
	int mnt_flags;
};

struct key___191;

struct ucounts___173;

struct user_namespace___173 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___173 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___11 ns;
	long unsigned int flags;
	struct key___191 *persistent_keyring_register;
	struct rw_semaphore___197 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___173 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct shrink_control___89 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___89 *memcg;
};

struct upid___156 {
	int nr;
	struct pid_namespace___156 *ns;
};

struct pid_namespace___156 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___197 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___156 *parent;
	struct vfsmount___41 *proc_mnt;
	struct dentry___196 *proc_self;
	struct dentry___196 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___173 *user_ns;
	struct ucounts___173 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___11 ns;
};

struct pid___156 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___156 numbers[1];
};

struct vm_operations_struct___193;

struct vm_area_struct___197 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___197 *vm_next;
	struct vm_area_struct___197 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___196 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___193 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___197 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct linux_binfmt___20;

struct core_state___196;

struct mm_struct___196 {
	struct {
		struct vm_area_struct___197 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___197 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___197 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___20 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___196 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___197 *owner;
		struct user_namespace___173 *user_ns;
		struct file___197 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___196 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___193)(struct vm_area_struct___197 *, long unsigned int, const struct page___197 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___193)(struct page___197 *, void *);

struct device___177;

struct dev_pagemap___193 {
	dev_page_fault_t___193 page_fault;
	dev_page_free_t___193 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___177 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct vm_fault___193;

struct vm_operations_struct___193 {
	void (*open)(struct vm_area_struct___197 *);
	void (*close)(struct vm_area_struct___197 *);
	int (*split)(struct vm_area_struct___197 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___197 *);
	vm_fault_t (*fault)(struct vm_fault___193 *);
	vm_fault_t (*huge_fault)(struct vm_fault___193 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___193 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___197 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___193 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___193 *);
	int (*access)(struct vm_area_struct___197 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___197 *);
	int (*set_policy)(struct vm_area_struct___197 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___197 *, long unsigned int);
	struct page___197 * (*find_special_page)(struct vm_area_struct___197 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___196 {
	struct task_struct___197 *task;
	struct core_thread___196 *next;
};

struct core_state___196 {
	atomic_t nr_threads;
	struct core_thread___196 dumper;
	struct completion startup;
};

struct linux_binprm___21;

struct coredump_params___20;

struct linux_binfmt___20 {
	struct list_head lh;
	struct module___166 *module;
	int (*load_binary)(struct linux_binprm___21 *);
	int (*load_shlib)(struct file___197 *);
	int (*core_dump)(struct coredump_params___20 *);
	long unsigned int min_coredump;
};

struct vm_fault___193 {
	struct vm_area_struct___197 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___197 *cow_page;
	struct mem_cgroup___89 *memcg;
	struct page___197 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___196 prealloc_pte;
};

struct user_struct___191 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___191 *uid_keyring;
	struct key___191 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___191 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___191 *session_keyring;
	struct key___191 *process_keyring;
	struct key___191 *thread_keyring;
	struct key___191 *request_key_auth;
	void *security;
	struct user_struct___191 *user;
	struct user_namespace___173 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct fs_struct___12 {
	int users;
	spinlock_t lock;
	seqcount_t seq;
	int umask;
	int in_exec;
	struct path___196 root;
	struct path___196 pwd;
};

struct fdtable___12 {
	unsigned int max_fds;
	struct file___197 **fd;
	long unsigned int *close_on_exec;
	long unsigned int *open_fds;
	long unsigned int *full_fds_bits;
	struct callback_head rcu;
};

struct files_struct___12 {
	atomic_t count;
	bool resize_in_progress;
	wait_queue_head_t resize_wait;
	struct fdtable___12 *fdt;
	struct fdtable___12 fdtab;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t file_lock;
	unsigned int next_fd;
	long unsigned int close_on_exec_init[1];
	long unsigned int open_fds_init[1];
	long unsigned int full_fds_bits_init[1];
	struct file___197 *fd_array[64];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct uts_namespace___23;

struct cgroup_namespace___164;

struct nsproxy___186 {
	atomic_t count;
	struct uts_namespace___23 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___156 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___164 *cgroup_ns;
};

struct signal_struct___173 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___197 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___197 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___156 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___156 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___196 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___156 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___100;

struct bio_list___100 {
	struct bio___100 *head;
	struct bio___100 *tail;
};

struct bdi_writeback_congested___100;

struct bdi_writeback___100 {
	struct backing_dev_info___100 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___100 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___165 *memcg_css;
	struct cgroup_subsys_state___165 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___100 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___100 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___177 *dev;
	struct device___177 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___196 *debug_dir;
	struct dentry___196 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___52;

struct io_context___52 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___52 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___164 {
	struct cgroup_subsys_state___165 *subsys[13];
	refcount_t refcount;
	struct css_set___164 *dom_cset;
	struct cgroup___164 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___164 *mg_src_cgrp;
	struct cgroup___164 *mg_dst_cgrp;
	struct css_set___164 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___119 {
	struct pmu___119 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___197 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___119 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___44;

struct pipe_inode_info___44 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___197 *tmp_page;
	struct fasync_struct___196 *fasync_readers;
	struct fasync_struct___196 *fasync_writers;
	struct pipe_buffer___44 *bufs;
	struct user_struct___191 *user;
};

typedef blk_qc_t make_request_fn___48(struct request_queue___49 *, struct bio___100 *);

struct request___49;

typedef int dma_drain_needed_fn___48(struct request___49 *);

struct kset___187;

struct kobj_type___187;

struct kobject___188 {
	const char *name;
	struct list_head entry;
	struct kobject___188 *parent;
	struct kset___187 *kset;
	struct kobj_type___187 *ktype;
	struct kernfs_node___191 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___48;

struct bsg_class_device___48 {
	struct device___177 *class_dev;
	int minor;
	struct request_queue___49 *queue;
	const struct bsg_ops___48 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___100 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___100 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___48;

struct blkcg_gq___37;

struct request_queue___49 {
	struct list_head queue_head;
	struct request___49 *last_merge;
	struct elevator_queue___48 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___48 *make_request_fn;
	dma_drain_needed_fn___48 *dma_drain_needed;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___100 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___188 kobj;
	struct kobject___188 *mq_kobj;
	struct blk_integrity integrity;
	struct device___177 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___37 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide40;
		union {		};
	};
	struct bsg_class_device___48 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___100 bio_split;
	struct dentry___196 *debugfs_dir;
	struct dentry___196 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___138 {
	struct vm_struct___138 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___197 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___175 {
	struct task_struct___197 task;
	long unsigned int stack[8192];
};

struct io_cq___52 {
	struct request_queue___49 *q;
	struct io_context___52 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___6 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___197 {
	struct file___197 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___197 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___196 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___197 *ia_file;
};

struct dquot___196 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___196 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___196 {
	int qf_fmt_id;
	const struct quota_format_ops___196 *qf_ops;
	struct module___166 *qf_owner;
	struct quota_format_type___196 *qf_next;
};

struct quota_format_ops___196 {
	int (*check_quota_file)(struct super_block___196 *, int);
	int (*read_file_info)(struct super_block___196 *, int);
	int (*write_file_info)(struct super_block___196 *, int);
	int (*free_file_info)(struct super_block___196 *, int);
	int (*read_dqblk)(struct dquot___196 *);
	int (*commit_dqblk)(struct dquot___196 *);
	int (*release_dqblk)(struct dquot___196 *);
	int (*get_next_id)(struct super_block___196 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___196 {
	int (*write_dquot)(struct dquot___196 *);
	struct dquot___196 * (*alloc_dquot)(struct super_block___196 *, int);
	void (*destroy_dquot)(struct dquot___196 *);
	int (*acquire_dquot)(struct dquot___196 *);
	int (*release_dquot)(struct dquot___196 *);
	int (*mark_dirty)(struct dquot___196 *);
	int (*write_info)(struct super_block___196 *, int);
	qsize_t * (*get_reserved_space)(struct inode___197 *);
	int (*get_projid)(struct inode___197 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___197 *, qsize_t *);
	int (*get_next_id)(struct super_block___196 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___196 {
	int (*quota_on)(struct super_block___196 *, int, int, const struct path___196 *);
	int (*quota_off)(struct super_block___196 *, int);
	int (*quota_enable)(struct super_block___196 *, unsigned int);
	int (*quota_disable)(struct super_block___196 *, unsigned int);
	int (*quota_sync)(struct super_block___196 *, int);
	int (*set_info)(struct super_block___196 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___196 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___196 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___196 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___196 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___196 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___163 {
	struct kobject___188 kobj;
	struct module___166 *mod;
	struct kobject___188 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___163 {
	struct module___166 *mod;
	struct latch_tree_node node;
};

struct module_layout___163 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___163 mtn;
};

struct module_attribute___163;

struct kernel_param___163;

struct module___166 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___163 mkobj;
	struct module_attribute___163 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___188 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___163 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___163 core_layout;
	struct module_layout___163 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___112 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___96;

struct swap_info_struct___62;

struct address_space_operations___196 {
	int (*writepage)(struct page___197 *, struct writeback_control___96 *);
	int (*readpage)(struct file___197 *, struct page___197 *);
	int (*writepages)(struct address_space___196 *, struct writeback_control___96 *);
	int (*set_page_dirty)(struct page___197 *);
	int (*readpages)(struct file___197 *, struct address_space___196 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___197 *, struct address_space___196 *, loff_t, unsigned int, unsigned int, struct page___197 **, void **);
	int (*write_end)(struct file___197 *, struct address_space___196 *, loff_t, unsigned int, unsigned int, struct page___197 *, void *);
	sector_t (*bmap)(struct address_space___196 *, sector_t);
	void (*invalidatepage)(struct page___197 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___197 *, gfp_t);
	void (*freepage)(struct page___197 *);
	ssize_t (*direct_IO)(struct kiocb___197 *, struct iov_iter___96 *);
	int (*migratepage)(struct address_space___196 *, struct page___197 *, struct page___197 *, enum migrate_mode);
	bool (*isolate_page)(struct page___197 *, isolate_mode_t);
	void (*putback_page)(struct page___197 *);
	int (*launder_page)(struct page___197 *);
	int (*is_partially_uptodate)(struct page___197 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___197 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___196 *, struct page___197 *);
	int (*swap_activate)(struct swap_info_struct___62 *, struct file___197 *, sector_t *);
	void (*swap_deactivate)(struct file___197 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___96 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___100 *wb;
	struct inode___197 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___100;

struct iov_iter___96 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___100 *bvec;
		struct pipe_inode_info___44 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct swap_info_struct___62 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___197 *bdev;
	struct file___197 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct hd_struct___49;

struct gendisk___49;

struct block_device___197 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___197 *bd_inode;
	struct super_block___196 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___197 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___49 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___49 *bd_disk;
	struct request_queue___49 *bd_queue;
	struct backing_dev_info___100 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___177 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___177 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___177;

struct bus_type___177;

struct device_driver___177;

struct dev_pm_domain___177;

struct fwnode_handle___124;

struct class___177;

struct attribute_group___179;

struct device___177 {
	struct device___177 *parent;
	struct device_private *p;
	struct kobject___188 kobj;
	const char *init_name;
	const struct device_type___177 *type;
	struct mutex mutex;
	struct bus_type___177 *bus;
	struct device_driver___177 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___177 power;
	struct dev_pm_domain___177 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___124 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___177 *class;
	const struct attribute_group___179 **groups;
	void (*release)(struct device___177 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___49 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___177 __dev;
	struct kobject___188 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___49;

struct block_device_operations___49;

struct gendisk___49 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___49 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___49 *part_tbl;
	struct hd_struct___49 part0;
	const struct block_device_operations___49 *fops;
	struct request_queue___49 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___197 lookup_sem;
	struct kobject___188 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___188 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___196 {
	struct dentry___196 * (*lookup)(struct inode___197 *, struct dentry___196 *, unsigned int);
	const char * (*get_link)(struct dentry___196 *, struct inode___197 *, struct delayed_call *);
	int (*permission)(struct inode___197 *, int);
	struct posix_acl * (*get_acl)(struct inode___197 *, int);
	int (*readlink)(struct dentry___196 *, char *, int);
	int (*create)(struct inode___197 *, struct dentry___196 *, umode_t, bool);
	int (*link)(struct dentry___196 *, struct inode___197 *, struct dentry___196 *);
	int (*unlink)(struct inode___197 *, struct dentry___196 *);
	int (*symlink)(struct inode___197 *, struct dentry___196 *, const char *);
	int (*mkdir)(struct inode___197 *, struct dentry___196 *, umode_t);
	int (*rmdir)(struct inode___197 *, struct dentry___196 *);
	int (*mknod)(struct inode___197 *, struct dentry___196 *, umode_t, dev_t);
	int (*rename)(struct inode___197 *, struct dentry___196 *, struct inode___197 *, struct dentry___196 *, unsigned int);
	int (*setattr)(struct dentry___196 *, struct iattr___196 *);
	int (*getattr)(const struct path___196 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___196 *, char *, size_t);
	int (*fiemap)(struct inode___197 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___197 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___197 *, struct dentry___196 *, struct file___197 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___197 *, struct dentry___196 *, umode_t);
	int (*set_acl)(struct inode___197 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___196 {
	void (*fl_copy_lock)(struct file_lock___197 *, struct file_lock___197 *);
	void (*fl_release_private)(struct file_lock___197 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___196;

struct file_lock___197 {
	struct file_lock___197 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___197 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___196 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___196 *fl_ops;
	const struct lock_manager_operations___196 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___196 {
	int (*lm_compare_owner)(struct file_lock___197 *, struct file_lock___197 *);
	long unsigned int (*lm_owner_key)(struct file_lock___197 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___197 *);
	int (*lm_grant)(struct file_lock___197 *, int);
	bool (*lm_break)(struct file_lock___197 *);
	int (*lm_change)(struct file_lock___197 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___197 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___196 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___196 *fa_next;
	struct file___197 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___196 {
	const char *name;
	int fs_flags;
	struct dentry___196 * (*mount)(struct file_system_type___196 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___196 *);
	struct module___166 *owner;
	struct file_system_type___196 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___196 {
	struct inode___197 * (*alloc_inode)(struct super_block___196 *);
	void (*destroy_inode)(struct inode___197 *);
	void (*dirty_inode)(struct inode___197 *, int);
	int (*write_inode)(struct inode___197 *, struct writeback_control___96 *);
	int (*drop_inode)(struct inode___197 *);
	void (*evict_inode)(struct inode___197 *);
	void (*put_super)(struct super_block___196 *);
	int (*sync_fs)(struct super_block___196 *, int);
	int (*freeze_super)(struct super_block___196 *);
	int (*freeze_fs)(struct super_block___196 *);
	int (*thaw_super)(struct super_block___196 *);
	int (*unfreeze_fs)(struct super_block___196 *);
	int (*statfs)(struct dentry___196 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___196 *, int *, char *);
	void (*umount_begin)(struct super_block___196 *);
	int (*show_options)(struct seq_file___183 *, struct dentry___196 *);
	int (*show_devname)(struct seq_file___183 *, struct dentry___196 *);
	int (*show_path)(struct seq_file___183 *, struct dentry___196 *);
	int (*show_stats)(struct seq_file___183 *, struct dentry___196 *);
	ssize_t (*quota_read)(struct super_block___196 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___196 *, int, const char *, size_t, loff_t);
	struct dquot___196 ** (*get_dquots)(struct inode___197 *);
	int (*bdev_try_to_free_page)(struct super_block___196 *, struct page___197 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___196 *, struct shrink_control___89 *);
	long int (*free_cached_objects)(struct super_block___196 *, struct shrink_control___89 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___135)(struct file___197 *, wait_queue_head_t *, struct poll_table_struct___134 *);

struct poll_table_struct___134 {
	poll_queue_proc___135 _qproc;
	__poll_t _key;
};

struct seq_operations___181;

struct seq_file___183 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___181 *op;
	int poll_event;
	const struct file___197 *file;
	void *private;
};

typedef void bio_end_io_t___100(struct bio___100 *);

struct bio_vec___100 {
	struct page___197 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___100;

struct bio___100 {
	struct bio___100 *bi_next;
	struct gendisk___49 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___100 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___37 *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___100 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___100 *bi_io_vec;
	struct bio_set___100 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___100 bi_inline_vecs[0];
};

struct kobj_attribute___187 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___188 *, struct kobj_attribute___187 *, char *);
	ssize_t (*store)(struct kobject___188 *, struct kobj_attribute___187 *, const char *, size_t);
};

typedef void compound_page_dtor___193(struct page___197 *);

typedef int (*key_restrict_link_func_t___191)(struct key___191 *, const struct key_type *, const union key_payload *, struct key___191 *);

struct key_restriction___191;

struct key___191 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___197 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___191 *restrict_link;
};

struct key_restriction___191 {
	key_restrict_link_func_t___191 check;
	struct key___191 *key;
	struct key_type *keytype;
};

struct seq_operations___181 {
	void * (*start)(struct seq_file___183 *, loff_t *);
	void (*stop)(struct seq_file___183 *, void *);
	void * (*next)(struct seq_file___183 *, void *, loff_t *);
	int (*show)(struct seq_file___183 *, void *);
};

struct kernfs_root___191;

struct kernfs_elem_dir___191 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___191 *root;
};

struct kernfs_syscall_ops___191;

struct kernfs_root___191 {
	struct kernfs_node___191 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___191 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___191 {
	struct kernfs_node___191 *target_kn;
};

struct kernfs_ops___191;

struct kernfs_elem_attr___191 {
	const struct kernfs_ops___191 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___191 *notify_next;
};

struct kernfs_node___191 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___191 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___191 dir;
		struct kernfs_elem_symlink___191 symlink;
		struct kernfs_elem_attr___191 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___191;

struct kernfs_ops___191 {
	int (*open)(struct kernfs_open_file___191 *);
	void (*release)(struct kernfs_open_file___191 *);
	int (*seq_show)(struct seq_file___183 *, void *);
	void * (*seq_start)(struct seq_file___183 *, loff_t *);
	void * (*seq_next)(struct seq_file___183 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___183 *, void *);
	ssize_t (*read)(struct kernfs_open_file___191 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___191 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___191 *, struct vm_area_struct___197 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___191 *, struct poll_table_struct___134 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___191 {
	int (*remount_fs)(struct kernfs_root___191 *, int *, char *);
	int (*show_options)(struct seq_file___183 *, struct kernfs_root___191 *);
	int (*mkdir)(struct kernfs_node___191 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___191 *);
	int (*rename)(struct kernfs_node___191 *, struct kernfs_node___191 *, const char *);
	int (*show_path)(struct seq_file___183 *, struct kernfs_node___191 *, struct kernfs_root___191 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___191 {
	struct kernfs_node___191 *kn;
	struct file___197 *file;
	struct seq_file___183 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___193 *vm_ops;
};

struct uts_namespace___23 {
	struct kref kref;
	struct new_utsname name;
	struct user_namespace___173 *user_ns;
	struct ucounts___173 *ucounts;
	struct ns_common___11 ns;
};

struct cgroup_namespace___164 {
	refcount_t count;
	struct ns_common___11 ns;
	struct user_namespace___173 *user_ns;
	struct ucounts___173 *ucounts;
	struct css_set___164 *root_cset;
};

struct ucounts___173 {
	struct hlist_node node;
	struct user_namespace___173 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___164;

struct bpf_map_ops___164 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___164 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___164 *, struct file___197 *);
	void (*map_free)(struct bpf_map___164 *);
	int (*map_get_next_key)(struct bpf_map___164 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___164 *);
	void * (*map_lookup_elem)(struct bpf_map___164 *, void *);
	int (*map_update_elem)(struct bpf_map___164 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___164 *, void *);
	int (*map_push_elem)(struct bpf_map___164 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___164 *, void *);
	int (*map_peek_elem)(struct bpf_map___164 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___164 *, struct file___197 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___164 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___164 *, void *, struct seq_file___183 *);
	int (*map_check_btf)(const struct bpf_map___164 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___164 {
	const struct bpf_map_ops___164 *ops;
	struct bpf_map___164 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___191 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___164;

typedef void (*kthread_work_func_t___164)(struct kthread_work___164 *);

struct kthread_worker___164;

struct kthread_work___164 {
	struct list_head node;
	kthread_work_func_t___164 func;
	struct kthread_worker___164 *worker;
	int canceling;
};

struct kthread_worker___164 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___197 *task;
	struct kthread_work___164 *current_work;
};

struct kthread_delayed_work___164 {
	struct kthread_work___164 work;
	struct timer_list timer;
};

struct psi_group___164 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___164 *poll_kworker;
	struct kthread_delayed_work___164 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___164;

struct cgroup_rstat_cpu___164;

struct cgroup___164 {
	struct cgroup_subsys_state___165 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___191 *kn;
	struct cgroup_file___164 procs_file;
	struct cgroup_file___164 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___165 *subsys[13];
	struct cgroup_root___164 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___164 *dom_cgrp;
	struct cgroup_rstat_cpu___164 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___22 bpf;
	atomic_t congestion_count;
	struct cgroup___164 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___164 psi;
	int ancestor_ids[0];
};

struct cftype___164;

struct cgroup_subsys___164 {
	struct cgroup_subsys_state___165 * (*css_alloc)(struct cgroup_subsys_state___165 *);
	int (*css_online)(struct cgroup_subsys_state___165 *);
	void (*css_offline)(struct cgroup_subsys_state___165 *);
	void (*css_released)(struct cgroup_subsys_state___165 *);
	void (*css_free)(struct cgroup_subsys_state___165 *);
	void (*css_reset)(struct cgroup_subsys_state___165 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___165 *, int);
	int (*css_extra_stat_show)(struct seq_file___183 *, struct cgroup_subsys_state___165 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___197 *);
	void (*cancel_fork)(struct task_struct___197 *);
	void (*fork)(struct task_struct___197 *);
	void (*exit)(struct task_struct___197 *);
	void (*free)(struct task_struct___197 *);
	void (*bind)(struct cgroup_subsys_state___165 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___164 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___164 *dfl_cftypes;
	struct cftype___164 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___164 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___164 *updated_children;
	struct cgroup___164 *updated_next;
};

struct cgroup_root___164 {
	struct kernfs_root___191 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___164 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___164 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___164 *ss;
	struct list_head node;
	struct kernfs_ops___191 *kf_ops;
	int (*open)(struct kernfs_open_file___191 *);
	void (*release)(struct kernfs_open_file___191 *);
	u64 (*read_u64)(struct cgroup_subsys_state___165 *, struct cftype___164 *);
	s64 (*read_s64)(struct cgroup_subsys_state___165 *, struct cftype___164 *);
	int (*seq_show)(struct seq_file___183 *, void *);
	void * (*seq_start)(struct seq_file___183 *, loff_t *);
	void * (*seq_next)(struct seq_file___183 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___183 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___165 *, struct cftype___164 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___165 *, struct cftype___164 *, s64);
	ssize_t (*write)(struct kernfs_open_file___191 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___191 *, struct poll_table_struct___134 *);
};

struct bdi_writeback_congested___100 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___100 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___100 {
	struct bio___100 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___100 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___100 bip_inline_vecs[0];
};

struct blkcg___37;

struct blkg_policy_data___37;

struct blkcg_gq___37 {
	struct request_queue___49 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___37 *blkcg;
	struct bdi_writeback_congested___100 *wb_congested;
	struct blkcg_gq___37 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_rwstat stat_bytes;
	struct blkg_rwstat stat_ios;
	struct blkg_policy_data___37 *pd[5];
	struct callback_head callback_head;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
};

struct mem_cgroup_reclaim_iter___89 {
	struct mem_cgroup___89 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___89 {
	struct lruvec___196 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___89 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___89 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct bin_attribute___178;

struct attribute_group___179 {
	const char *name;
	umode_t (*is_visible)(struct kobject___188 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___188 *, struct bin_attribute___178 *, int);
	struct attribute **attrs;
	struct bin_attribute___178 **bin_attrs;
};

struct bin_attribute___178 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___197 *, struct kobject___188 *, struct bin_attribute___178 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___197 *, struct kobject___188 *, struct bin_attribute___178 *, char *, loff_t, size_t);
	int (*mmap)(struct file___197 *, struct kobject___188 *, struct bin_attribute___178 *, struct vm_area_struct___197 *);
};

struct sysfs_ops___187 {
	ssize_t (*show)(struct kobject___188 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___188 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___187;

struct kset___187 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___188 kobj;
	const struct kset_uevent_ops___187 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___187 {
	void (*release)(struct kobject___188 *);
	const struct sysfs_ops___187 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___12 * (*child_ns_type)(struct kobject___188 *);
	const void * (*namespace)(struct kobject___188 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___187 {
	int (* const filter)(struct kset___187 *, struct kobject___188 *);
	const char * (* const name)(struct kset___187 *, struct kobject___188 *);
	int (* const uevent)(struct kset___187 *, struct kobject___188 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___177 {
	int (*prepare)(struct device___177 *);
	void (*complete)(struct device___177 *);
	int (*suspend)(struct device___177 *);
	int (*resume)(struct device___177 *);
	int (*freeze)(struct device___177 *);
	int (*thaw)(struct device___177 *);
	int (*poweroff)(struct device___177 *);
	int (*restore)(struct device___177 *);
	int (*suspend_late)(struct device___177 *);
	int (*resume_early)(struct device___177 *);
	int (*freeze_late)(struct device___177 *);
	int (*thaw_early)(struct device___177 *);
	int (*poweroff_late)(struct device___177 *);
	int (*restore_early)(struct device___177 *);
	int (*suspend_noirq)(struct device___177 *);
	int (*resume_noirq)(struct device___177 *);
	int (*freeze_noirq)(struct device___177 *);
	int (*thaw_noirq)(struct device___177 *);
	int (*poweroff_noirq)(struct device___177 *);
	int (*restore_noirq)(struct device___177 *);
	int (*runtime_suspend)(struct device___177 *);
	int (*runtime_resume)(struct device___177 *);
	int (*runtime_idle)(struct device___177 *);
};

struct dev_pm_domain___177 {
	struct dev_pm_ops___177 ops;
	void (*detach)(struct device___177 *, bool);
	int (*activate)(struct device___177 *);
	void (*sync)(struct device___177 *);
	void (*dismiss)(struct device___177 *);
};

struct bus_type___177 {
	const char *name;
	const char *dev_name;
	struct device___177 *dev_root;
	const struct attribute_group___179 **bus_groups;
	const struct attribute_group___179 **dev_groups;
	const struct attribute_group___179 **drv_groups;
	int (*match)(struct device___177 *, struct device_driver___177 *);
	int (*uevent)(struct device___177 *, struct kobj_uevent_env *);
	int (*probe)(struct device___177 *);
	int (*remove)(struct device___177 *);
	void (*shutdown)(struct device___177 *);
	int (*online)(struct device___177 *);
	int (*offline)(struct device___177 *);
	int (*suspend)(struct device___177 *, pm_message_t);
	int (*resume)(struct device___177 *);
	int (*num_vf)(struct device___177 *);
	int (*dma_configure)(struct device___177 *);
	const struct dev_pm_ops___177 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___177 {
	const char *name;
	struct bus_type___177 *bus;
	struct module___166 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___177 *);
	int (*remove)(struct device___177 *);
	void (*shutdown)(struct device___177 *);
	int (*suspend)(struct device___177 *, pm_message_t);
	int (*resume)(struct device___177 *);
	const struct attribute_group___179 **groups;
	const struct dev_pm_ops___177 *pm;
	void (*coredump)(struct device___177 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___177 {
	const char *name;
	const struct attribute_group___179 **groups;
	int (*uevent)(struct device___177 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___177 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___177 *);
	const struct dev_pm_ops___177 *pm;
};

struct class___177 {
	const char *name;
	struct module___166 *owner;
	const struct attribute_group___179 **class_groups;
	const struct attribute_group___179 **dev_groups;
	struct kobject___188 *dev_kobj;
	int (*dev_uevent)(struct device___177 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___177 *, umode_t *);
	void (*class_release)(struct class___177 *);
	void (*dev_release)(struct device___177 *);
	int (*shutdown_pre)(struct device___177 *);
	const struct kobj_ns_type_operations___12 *ns_type;
	const void * (*namespace)(struct device___177 *);
	const struct dev_pm_ops___177 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct fwnode_operations___124;

struct fwnode_handle___124 {
	struct fwnode_handle___124 *secondary;
	const struct fwnode_operations___124 *ops;
};

struct node___152 {
	struct device___177 dev;
};

struct subprocess_info___3 {
	struct work_struct work;
	struct completion *complete;
	const char *path;
	char **argv;
	char **envp;
	struct file___197 *file;
	int wait;
	int retval;
	pid_t pid;
	int (*init)(struct subprocess_info___3 *, struct cred___191 *);
	void (*cleanup)(struct subprocess_info___3 *);
	void *data;
};

struct kernel_param_ops___163 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___163 *);
	int (*get)(char *, const struct kernel_param___163 *);
	void (*free)(void *);
};

struct kparam_array___163;

struct kernel_param___163 {
	const char *name;
	struct module___166 *mod;
	const struct kernel_param_ops___163 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___163 *arr;
	};
};

struct kparam_array___163 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___163 *ops;
	void *elem;
};

struct module_attribute___163 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___163 *, struct module_kobject___163 *, char *);
	ssize_t (*store)(struct module_attribute___163 *, struct module_kobject___163 *, const char *, size_t);
	void (*setup)(struct module___166 *, const char *);
	int (*test)(struct module___166 *);
	void (*free)(struct module___166 *);
};

struct trace_event_class___112;

struct trace_event_call___112 {
	struct list_head list;
	struct trace_event_class___112 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___22 *prog_array;
	int (*perf_perm)(struct trace_event_call___112 *, struct perf_event___119 *);
};

struct perf_cpu_context___119;

struct pmu___119 {
	struct list_head entry;
	struct module___166 *module;
	struct device___177 *dev;
	const struct attribute_group___179 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___119 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___119 *);
	void (*pmu_disable)(struct pmu___119 *);
	int (*event_init)(struct perf_event___119 *);
	void (*event_mapped)(struct perf_event___119 *, struct mm_struct___196 *);
	void (*event_unmapped)(struct perf_event___119 *, struct mm_struct___196 *);
	int (*add)(struct perf_event___119 *, int);
	void (*del)(struct perf_event___119 *, int);
	void (*start)(struct perf_event___119 *, int);
	void (*stop)(struct perf_event___119 *, int);
	void (*read)(struct perf_event___119 *);
	void (*start_txn)(struct pmu___119 *, unsigned int);
	int (*commit_txn)(struct pmu___119 *);
	void (*cancel_txn)(struct pmu___119 *);
	int (*event_idx)(struct perf_event___119 *);
	void (*sched_task)(struct perf_event_context___119 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___119 *);
	int (*filter_match)(struct perf_event___119 *);
	int (*check_period)(struct perf_event___119 *, u64);
};

struct perf_cpu_context___119 {
	struct perf_event_context___119 ctx;
	struct perf_event_context___119 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___119 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___119 {
	struct cgroup_subsys_state___165 css;
	struct perf_cgroup_info *info;
};

struct linux_binprm___21 {
	char buf[256];
	struct vm_area_struct___197 *vma;
	long unsigned int vma_pages;
	struct mm_struct___196 *mm;
	long unsigned int p;
	unsigned int called_set_creds: 1;
	unsigned int cap_elevated: 1;
	unsigned int secureexec: 1;
	unsigned int recursion_depth;
	struct file___197 *file;
	struct cred___191 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
};

struct coredump_params___20 {
	union {
		const kernel_siginfo_t *siginfo;
		struct {
			const siginfo_t *siginfo;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	struct pt_regs *regs;
	struct file___197 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
};

struct trace_event_class___112 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___112 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___112 *);
	struct list_head * (*get_fields)(struct trace_event_call___112 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___112 *);
};

struct disk_part_tbl___49 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___49 *last_lookup;
	struct hd_struct___49 *part[0];
};

struct block_device_operations___49 {
	int (*open)(struct block_device___197 *, fmode_t);
	void (*release)(struct gendisk___49 *, fmode_t);
	int (*rw_page)(struct block_device___197 *, sector_t, struct page___197 *, unsigned int);
	int (*ioctl)(struct block_device___197 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___197 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___49 *, unsigned int);
	int (*media_changed)(struct gendisk___49 *);
	void (*unlock_native_capacity)(struct gendisk___49 *);
	int (*revalidate_disk)(struct gendisk___49 *);
	int (*getgeo)(struct block_device___197 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___197 *, long unsigned int);
	int (*report_zones)(struct gendisk___49 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___166 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___48 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___49 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___49 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___49 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___48(struct request___49 *, blk_status_t);

struct request___49 {
	struct request_queue___49 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___100 *bio;
	struct bio___100 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___100 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___52 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___48 *saved_end_io;
		} flush;
	};
	struct gendisk___49 *rq_disk;
	struct hd_struct___49 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___48 *end_io;
	void *end_io_data;
	struct request___49 *next_rq;
};

struct fwnode_reference_args___124;

struct fwnode_endpoint___124;

struct fwnode_operations___124 {
	struct fwnode_handle___124 * (*get)(struct fwnode_handle___124 *);
	void (*put)(struct fwnode_handle___124 *);
	bool (*device_is_available)(const struct fwnode_handle___124 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___124 *, const struct device___177 *);
	bool (*property_present)(const struct fwnode_handle___124 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___124 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___124 *, const char *, const char **, size_t);
	struct fwnode_handle___124 * (*get_parent)(const struct fwnode_handle___124 *);
	struct fwnode_handle___124 * (*get_next_child_node)(const struct fwnode_handle___124 *, struct fwnode_handle___124 *);
	struct fwnode_handle___124 * (*get_named_child_node)(const struct fwnode_handle___124 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___124 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___124 *);
	struct fwnode_handle___124 * (*graph_get_next_endpoint)(const struct fwnode_handle___124 *, struct fwnode_handle___124 *);
	struct fwnode_handle___124 * (*graph_get_remote_endpoint)(const struct fwnode_handle___124 *);
	struct fwnode_handle___124 * (*graph_get_port_parent)(struct fwnode_handle___124 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___124 *, struct fwnode_endpoint___124 *);
};

struct fwnode_endpoint___124 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___124 *local_fwnode;
};

struct fwnode_reference_args___124 {
	struct fwnode_handle___124 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct elevator_type___48;

struct elevator_mq_ops___48 {
	int (*init_sched)(struct request_queue___49 *, struct elevator_type___48 *);
	void (*exit_sched)(struct elevator_queue___48 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	bool (*allow_merge)(struct request_queue___49 *, struct request___49 *, struct bio___100 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx *, struct bio___100 *);
	int (*request_merge)(struct request_queue___49 *, struct request___49 **, struct bio___100 *);
	void (*request_merged)(struct request_queue___49 *, struct request___49 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___49 *, struct request___49 *, struct request___49 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___49 *, struct bio___100 *);
	void (*finish_request)(struct request___49 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___49 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___49 *, u64);
	void (*started_request)(struct request___49 *);
	void (*requeue_request)(struct request___49 *);
	struct request___49 * (*former_request)(struct request_queue___49 *, struct request___49 *);
	struct request___49 * (*next_request)(struct request_queue___49 *, struct request___49 *);
	void (*init_icq)(struct io_cq___52 *);
	void (*exit_icq)(struct io_cq___52 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide39;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___48;

struct elevator_type___48 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___48 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___48 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___166 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___48 {
	struct elevator_type___48 *type;
	void *elevator_data;
	struct kobject___188 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___48 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___48 *, char *);
	ssize_t (*store)(struct elevator_queue___48 *, const char *, size_t);
};

struct blkcg_policy_data___37;

struct blkcg___37 {
	struct cgroup_subsys_state___165 css;
	spinlock_t lock;
	struct xarray blkg_tree;
	struct blkcg_gq___37 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___37 *cpd[5];
	struct list_head all_blkcgs_node;
	struct list_head cgwb_list;
	refcount_t cgwb_refcnt;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct blkcg_policy_data___37 {
	struct blkcg___37 *blkcg;
	int plid;
};

struct blkg_policy_data___37 {
	struct blkcg_gq___37 *blkg;
	int plid;
};

struct pipe_buf_operations___44;

struct pipe_buffer___44 {
	struct page___197 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___44 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___44 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___44 *, struct pipe_buffer___44 *);
	void (*release)(struct pipe_inode_info___44 *, struct pipe_buffer___44 *);
	int (*steal)(struct pipe_inode_info___44 *, struct pipe_buffer___44 *);
	union {
		bool (*get)(struct pipe_inode_info___44 *, struct pipe_buffer___44 *);
		struct {
			void (*get)(struct pipe_inode_info___44 *, struct pipe_buffer___44 *);
		} __UNIQUE_ID_rh_kabi_hide51;
		union {		};
	};
};

struct core_name {
	char *corename;
	int used;
	int size;
};

struct module___167;

struct file___198;

struct kiocb___198;

struct poll_table_struct___135;

struct vm_area_struct___198;

struct inode___198;

struct file_lock___198;

struct page___198;

struct seq_file___184;

struct file_operations___198 {
	struct module___167 *owner;
	loff_t (*llseek)(struct file___198 *, loff_t, int);
	ssize_t (*read)(struct file___198 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___198 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___198 *, struct iov_iter___96 *);
	ssize_t (*write_iter)(struct kiocb___198 *, struct iov_iter___96 *);
	int (*iopoll)(struct kiocb___198 *, bool);
	int (*iterate)(struct file___198 *, struct dir_context *);
	int (*iterate_shared)(struct file___198 *, struct dir_context *);
	__poll_t (*poll)(struct file___198 *, struct poll_table_struct___135 *);
	long int (*unlocked_ioctl)(struct file___198 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___198 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___198 *, struct vm_area_struct___198 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___198 *, struct file___198 *);
	int (*flush)(struct file___198 *, fl_owner_t);
	int (*release)(struct inode___198 *, struct file___198 *);
	int (*fsync)(struct file___198 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___198 *, int);
	int (*lock)(struct file___198 *, int, struct file_lock___198 *);
	ssize_t (*sendpage)(struct file___198 *, struct page___198 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___198 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___198 *, int, struct file_lock___198 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___198 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___198 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___198 *, long int, struct file_lock___198 **, void **);
	long int (*fallocate)(struct file___198 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___184 *, struct file___198 *);
	ssize_t (*copy_file_range)(struct file___198 *, loff_t, struct file___198 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___198 *, loff_t, struct file___198 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___198 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___197 {
	u64 seqnum;
	struct vm_area_struct___198 *vmas[4];
};

struct page_frag___197 {
	struct page___198 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___120;

struct debug_info___120 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___120 *hbp_break[16];
	struct perf_event___120 *hbp_watch[16];
};

struct thread_struct___120 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___120 debug;
	long: 64;
};

struct mm_struct___197;

struct pid___157;

struct cred___192;

struct fs_struct___13;

struct nsproxy___187;

struct signal_struct___174;

struct css_set___165;

struct perf_event_context___120;

struct task_struct___198 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___198 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___197 *mm;
	struct mm_struct___197 *active_mm;
	struct vmacache___197 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___198 *real_parent;
	struct task_struct___198 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___198 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___157 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___157 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___157 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___192 *ptracer_cred;
	const struct cred___192 *real_cred;
	const struct cred___192 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct___13 *fs;
	struct files_struct *files;
	struct nsproxy___187 *nsproxy;
	struct signal_struct___174 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___198 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___52 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___165 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___120 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___197 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___198 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___120 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___120 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___198 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___120)(struct perf_event___120 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___120;

struct fasync_struct___197;

struct pid_namespace___157;

struct trace_event_call___113;

struct perf_cgroup___120;

struct perf_event___120 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___120 *group_leader;
	struct pmu___120 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___120 hw;
	struct perf_event_context___120 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___120 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___198 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___197 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___120 *);
	struct callback_head callback_head;
	struct pid_namespace___157 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___120 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___120 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___113 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___120 *cgrp;
	struct list_head sb_list;
};

struct dentry_operations___197;

struct super_block___197;

struct dentry___197 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___197 *d_parent;
	struct qstr d_name;
	struct inode___198 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___197 *d_op;
	struct super_block___197 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct rw_semaphore___198 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___198 *owner;
};

struct address_space_operations___197;

struct address_space___197 {
	struct inode___198 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___198 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___197 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___197;

struct block_device___198;

struct inode___198 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___197 *i_op;
	struct super_block___197 *i_sb;
	struct address_space___197 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___198 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___198 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___197 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___198 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vfsmount___42;

struct path___197;

struct dentry_operations___197 {
	int (*d_revalidate)(struct dentry___197 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___197 *, unsigned int);
	int (*d_hash)(const struct dentry___197 *, struct qstr *);
	int (*d_compare)(const struct dentry___197 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___197 *);
	int (*d_init)(struct dentry___197 *);
	void (*d_release)(struct dentry___197 *);
	void (*d_prune)(struct dentry___197 *);
	void (*d_iput)(struct dentry___197 *, struct inode___198 *);
	char * (*d_dname)(struct dentry___197 *, char *, int);
	struct vfsmount___42 * (*d_automount)(struct path___197 *);
	int (*d_manage)(const struct path___197 *, bool);
	struct dentry___197 * (*d_real)(struct dentry___197 *, const struct inode___198 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___197;

struct mem_dqinfo___197 {
	struct quota_format_type___197 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___197;

struct quota_info___197 {
	unsigned int flags;
	struct rw_semaphore___198 dqio_sem;
	struct inode___198 *files[3];
	struct mem_dqinfo___197 info[3];
	const struct quota_format_ops___197 *ops[3];
};

struct rcuwait___197 {
	struct task_struct___198 *task;
};

struct percpu_rw_semaphore___197 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___198 rw_sem;
	struct rcuwait___197 writer;
	int readers_block;
};

struct sb_writers___197 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___197 rw_sem[3];
};

struct file_system_type___197;

struct super_operations___197;

struct dquot_operations___197;

struct quotactl_ops___197;

struct export_operations___9;

struct user_namespace___174;

struct super_block___197 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___197 *s_type;
	const struct super_operations___197 *s_op;
	const struct dquot_operations___197 *dq_op;
	const struct quotactl_ops___197 *s_qcop;
	const struct export_operations___9 *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___197 *s_root;
	struct rw_semaphore___198 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___198 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___197 s_dquot;
	struct sb_writers___197 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___197 *s_d_op;
	int cleancache_poolid;
	struct shrinker___89 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___174 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___42 {
	struct dentry___197 *mnt_root;
	struct super_block___197 *mnt_sb;
	int mnt_flags;
};

struct path___197 {
	struct vfsmount___42 *mnt;
	struct dentry___197 *dentry;
};

struct key___192;

struct ucounts___174;

struct user_namespace___174 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___174 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___11 ns;
	long unsigned int flags;
	struct key___192 *persistent_keyring_register;
	struct rw_semaphore___198 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___174 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___198 *pgtable_t___197;

struct dev_pagemap___194;

struct page___198 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___197 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___198 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___197 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___197 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___194 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___197;

struct lruvec___197 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___197 *pgdat;
};

struct zone___197 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___197 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___197 {
	struct zone___197 *zone;
	int zone_idx;
};

struct zonelist___197 {
	struct zoneref___197 _zonerefs[25];
};

struct pglist_data___197 {
	struct zone___197 node_zones[3];
	struct zonelist___197 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___198 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___198 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___197 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___198 {
	void *stack;
	struct task_struct___198 *task;
	long int status;
};

struct blocking_notifier_head___197 {
	struct rw_semaphore___198 rwsem;
	struct notifier_block *head;
};

struct upid___157 {
	int nr;
	struct pid_namespace___157 *ns;
};

struct pid_namespace___157 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___198 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___157 *parent;
	struct vfsmount___42 *proc_mnt;
	struct dentry___197 *proc_self;
	struct dentry___197 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___174 *user_ns;
	struct ucounts___174 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___11 ns;
};

struct pid___157 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___157 numbers[1];
};

struct vm_operations_struct___194;

struct vm_area_struct___198 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___198 *vm_next;
	struct vm_area_struct___198 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___197 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___194 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___198 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___197;

struct mm_struct___197 {
	struct {
		struct vm_area_struct___198 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___198 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___198 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___197 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___198 *owner;
		struct user_namespace___174 *user_ns;
		struct file___198 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___197 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___194)(struct vm_area_struct___198 *, long unsigned int, const struct page___198 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___194)(struct page___198 *, void *);

struct device___178;

struct dev_pagemap___194 {
	dev_page_fault_t___194 page_fault;
	dev_page_free_t___194 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___178 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct fown_struct___157 {
	rwlock_t lock;
	struct pid___157 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___198 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___197 f_path;
	struct inode___198 *f_inode;
	const struct file_operations___198 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___157 f_owner;
	const struct cred___192 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___197 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___194;

struct vm_operations_struct___194 {
	void (*open)(struct vm_area_struct___198 *);
	void (*close)(struct vm_area_struct___198 *);
	int (*split)(struct vm_area_struct___198 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___198 *);
	vm_fault_t (*fault)(struct vm_fault___194 *);
	vm_fault_t (*huge_fault)(struct vm_fault___194 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___194 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___198 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___194 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___194 *);
	int (*access)(struct vm_area_struct___198 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___198 *);
	int (*set_policy)(struct vm_area_struct___198 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___198 *, long unsigned int);
	struct page___198 * (*find_special_page)(struct vm_area_struct___198 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___197 {
	struct task_struct___198 *task;
	struct core_thread___197 *next;
};

struct core_state___197 {
	atomic_t nr_threads;
	struct core_thread___197 dumper;
	struct completion startup;
};

struct vm_fault___194 {
	struct vm_area_struct___198 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___198 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___198 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___197 prealloc_pte;
};

struct user_struct___192 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___192 *uid_keyring;
	struct key___192 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___192 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___192 *session_keyring;
	struct key___192 *process_keyring;
	struct key___192 *thread_keyring;
	struct key___192 *request_key_auth;
	void *security;
	struct user_struct___192 *user;
	struct user_namespace___174 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct fs_struct___13 {
	int users;
	spinlock_t lock;
	seqcount_t seq;
	int umask;
	int in_exec;
	struct path___197 root;
	struct path___197 pwd;
};

struct mnt_namespace___10;

struct cgroup_namespace___165;

struct nsproxy___187 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace___10 *mnt_ns;
	struct pid_namespace___157 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___165 *cgroup_ns;
};

struct signal_struct___174 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___198 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___198 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___157 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___157 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___197 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___157 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___166;

struct cgroup___165;

struct css_set___165 {
	struct cgroup_subsys_state___166 *subsys[13];
	refcount_t refcount;
	struct css_set___165 *dom_cset;
	struct cgroup___165 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___165 *mg_src_cgrp;
	struct cgroup___165 *mg_dst_cgrp;
	struct css_set___165 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___120 {
	struct pmu___120 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___198 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___120 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

union thread_union___176 {
	struct task_struct___198 task;
	long unsigned int stack[8192];
};

struct kiocb___198 {
	struct file___198 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___198 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___197 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___198 *ia_file;
};

struct dquot___197 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___197 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___197 {
	int qf_fmt_id;
	const struct quota_format_ops___197 *qf_ops;
	struct module___167 *qf_owner;
	struct quota_format_type___197 *qf_next;
};

struct quota_format_ops___197 {
	int (*check_quota_file)(struct super_block___197 *, int);
	int (*read_file_info)(struct super_block___197 *, int);
	int (*write_file_info)(struct super_block___197 *, int);
	int (*free_file_info)(struct super_block___197 *, int);
	int (*read_dqblk)(struct dquot___197 *);
	int (*commit_dqblk)(struct dquot___197 *);
	int (*release_dqblk)(struct dquot___197 *);
	int (*get_next_id)(struct super_block___197 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___197 {
	int (*write_dquot)(struct dquot___197 *);
	struct dquot___197 * (*alloc_dquot)(struct super_block___197 *, int);
	void (*destroy_dquot)(struct dquot___197 *);
	int (*acquire_dquot)(struct dquot___197 *);
	int (*release_dquot)(struct dquot___197 *);
	int (*mark_dirty)(struct dquot___197 *);
	int (*write_info)(struct super_block___197 *, int);
	qsize_t * (*get_reserved_space)(struct inode___198 *);
	int (*get_projid)(struct inode___198 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___198 *, qsize_t *);
	int (*get_next_id)(struct super_block___197 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___197 {
	int (*quota_on)(struct super_block___197 *, int, int, const struct path___197 *);
	int (*quota_off)(struct super_block___197 *, int);
	int (*quota_enable)(struct super_block___197 *, unsigned int);
	int (*quota_disable)(struct super_block___197 *, unsigned int);
	int (*quota_sync)(struct super_block___197 *, int);
	int (*set_info)(struct super_block___197 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___197 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___197 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___197 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___197 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___197 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___188;

struct kobj_type___188;

struct kernfs_node___192;

struct kobject___189 {
	const char *name;
	struct list_head entry;
	struct kobject___189 *parent;
	struct kset___188 *kset;
	struct kobj_type___188 *ktype;
	struct kernfs_node___192 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___164 {
	struct kobject___189 kobj;
	struct module___167 *mod;
	struct kobject___189 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___164 {
	struct module___167 *mod;
	struct latch_tree_node node;
};

struct module_layout___164 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___164 mtn;
};

struct module_attribute___164;

struct kernel_param___164;

struct module___167 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___164 mkobj;
	struct module_attribute___164 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___189 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___164 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___164 core_layout;
	struct module_layout___164 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___113 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___197 {
	int (*writepage)(struct page___198 *, struct writeback_control___3 *);
	int (*readpage)(struct file___198 *, struct page___198 *);
	int (*writepages)(struct address_space___197 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___198 *);
	int (*readpages)(struct file___198 *, struct address_space___197 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___198 *, struct address_space___197 *, loff_t, unsigned int, unsigned int, struct page___198 **, void **);
	int (*write_end)(struct file___198 *, struct address_space___197 *, loff_t, unsigned int, unsigned int, struct page___198 *, void *);
	sector_t (*bmap)(struct address_space___197 *, sector_t);
	void (*invalidatepage)(struct page___198 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___198 *, gfp_t);
	void (*freepage)(struct page___198 *);
	ssize_t (*direct_IO)(struct kiocb___198 *, struct iov_iter___96 *);
	int (*migratepage)(struct address_space___197 *, struct page___198 *, struct page___198 *, enum migrate_mode);
	bool (*isolate_page)(struct page___198 *, isolate_mode_t);
	void (*putback_page)(struct page___198 *);
	int (*launder_page)(struct page___198 *);
	int (*is_partially_uptodate)(struct page___198 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___198 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___197 *, struct page___198 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___198 *, sector_t *);
	void (*swap_deactivate)(struct file___198 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___198 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___198 *bd_inode;
	struct super_block___197 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___198 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___197 {
	struct dentry___197 * (*lookup)(struct inode___198 *, struct dentry___197 *, unsigned int);
	const char * (*get_link)(struct dentry___197 *, struct inode___198 *, struct delayed_call *);
	int (*permission)(struct inode___198 *, int);
	struct posix_acl * (*get_acl)(struct inode___198 *, int);
	int (*readlink)(struct dentry___197 *, char *, int);
	int (*create)(struct inode___198 *, struct dentry___197 *, umode_t, bool);
	int (*link)(struct dentry___197 *, struct inode___198 *, struct dentry___197 *);
	int (*unlink)(struct inode___198 *, struct dentry___197 *);
	int (*symlink)(struct inode___198 *, struct dentry___197 *, const char *);
	int (*mkdir)(struct inode___198 *, struct dentry___197 *, umode_t);
	int (*rmdir)(struct inode___198 *, struct dentry___197 *);
	int (*mknod)(struct inode___198 *, struct dentry___197 *, umode_t, dev_t);
	int (*rename)(struct inode___198 *, struct dentry___197 *, struct inode___198 *, struct dentry___197 *, unsigned int);
	int (*setattr)(struct dentry___197 *, struct iattr___197 *);
	int (*getattr)(const struct path___197 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___197 *, char *, size_t);
	int (*fiemap)(struct inode___198 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___198 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___198 *, struct dentry___197 *, struct file___198 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___198 *, struct dentry___197 *, umode_t);
	int (*set_acl)(struct inode___198 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___197 {
	void (*fl_copy_lock)(struct file_lock___198 *, struct file_lock___198 *);
	void (*fl_release_private)(struct file_lock___198 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___197;

struct file_lock___198 {
	struct file_lock___198 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___198 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___197 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___197 *fl_ops;
	const struct lock_manager_operations___197 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___197 {
	int (*lm_compare_owner)(struct file_lock___198 *, struct file_lock___198 *);
	long unsigned int (*lm_owner_key)(struct file_lock___198 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___198 *);
	int (*lm_grant)(struct file_lock___198 *, int);
	bool (*lm_break)(struct file_lock___198 *);
	int (*lm_change)(struct file_lock___198 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___198 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___197 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___197 *fa_next;
	struct file___198 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___197 {
	const char *name;
	int fs_flags;
	struct dentry___197 * (*mount)(struct file_system_type___197 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___197 *);
	struct module___167 *owner;
	struct file_system_type___197 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___197 {
	struct inode___198 * (*alloc_inode)(struct super_block___197 *);
	void (*destroy_inode)(struct inode___198 *);
	void (*dirty_inode)(struct inode___198 *, int);
	int (*write_inode)(struct inode___198 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___198 *);
	void (*evict_inode)(struct inode___198 *);
	void (*put_super)(struct super_block___197 *);
	int (*sync_fs)(struct super_block___197 *, int);
	int (*freeze_super)(struct super_block___197 *);
	int (*freeze_fs)(struct super_block___197 *);
	int (*thaw_super)(struct super_block___197 *);
	int (*unfreeze_fs)(struct super_block___197 *);
	int (*statfs)(struct dentry___197 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___197 *, int *, char *);
	void (*umount_begin)(struct super_block___197 *);
	int (*show_options)(struct seq_file___184 *, struct dentry___197 *);
	int (*show_devname)(struct seq_file___184 *, struct dentry___197 *);
	int (*show_path)(struct seq_file___184 *, struct dentry___197 *);
	int (*show_stats)(struct seq_file___184 *, struct dentry___197 *);
	ssize_t (*quota_read)(struct super_block___197 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___197 *, int, const char *, size_t, loff_t);
	struct dquot___197 ** (*get_dquots)(struct inode___198 *);
	int (*bdev_try_to_free_page)(struct super_block___197 *, struct page___198 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___197 *, struct shrink_control___89 *);
	long int (*free_cached_objects)(struct super_block___197 *, struct shrink_control___89 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct export_operations___9 {
	int (*encode_fh)(struct inode___198 *, __u32 *, int *, struct inode___198 *);
	struct dentry___197 * (*fh_to_dentry)(struct super_block___197 *, struct fid *, int, int);
	struct dentry___197 * (*fh_to_parent)(struct super_block___197 *, struct fid *, int, int);
	int (*get_name)(struct dentry___197 *, char *, struct dentry___197 *);
	struct dentry___197 * (*get_parent)(struct dentry___197 *);
	int (*commit_metadata)(struct inode___198 *);
	int (*get_uuid)(struct super_block___197 *, u8 *, u32 *, u64 *);
	int (*map_blocks)(struct inode___198 *, loff_t, u64, struct iomap *, bool, u32 *);
	int (*commit_blocks)(struct inode___198 *, struct iomap *, int, struct iattr___197 *);
};

typedef void (*poll_queue_proc___136)(struct file___198 *, wait_queue_head_t *, struct poll_table_struct___135 *);

struct poll_table_struct___135 {
	poll_queue_proc___136 _qproc;
	__poll_t _key;
};

struct seq_operations___182;

struct seq_file___184 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___182 *op;
	int poll_event;
	const struct file___198 *file;
	void *private;
};

typedef int (*key_restrict_link_func_t___192)(struct key___192 *, const struct key_type *, const union key_payload *, struct key___192 *);

struct key_restriction___192;

struct key___192 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___198 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___192 *restrict_link;
};

struct key_restriction___192 {
	key_restrict_link_func_t___192 check;
	struct key___192 *key;
	struct key_type *keytype;
};

struct dev_pm_info___178 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___178 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___178;

struct bus_type___178;

struct device_driver___178;

struct dev_pm_domain___178;

struct class___178;

struct attribute_group___180;

struct device___178 {
	struct device___178 *parent;
	struct device_private *p;
	struct kobject___189 kobj;
	const char *init_name;
	const struct device_type___178 *type;
	struct mutex mutex;
	struct bus_type___178 *bus;
	struct device_driver___178 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___178 power;
	struct dev_pm_domain___178 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___178 *class;
	const struct attribute_group___180 **groups;
	void (*release)(struct device___178 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct kobj_attribute___188 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___189 *, struct kobj_attribute___188 *, char *);
	ssize_t (*store)(struct kobject___189 *, struct kobj_attribute___188 *, const char *, size_t);
};

typedef void compound_page_dtor___194(struct page___198 *);

struct seq_operations___182 {
	void * (*start)(struct seq_file___184 *, loff_t *);
	void (*stop)(struct seq_file___184 *, void *);
	void * (*next)(struct seq_file___184 *, void *, loff_t *);
	int (*show)(struct seq_file___184 *, void *);
};

struct mount___10;

struct mnt_namespace___10 {
	atomic_t count;
	struct ns_common___11 ns;
	struct mount___10 *root;
	struct list_head list;
	struct user_namespace___174 *user_ns;
	struct ucounts___174 *ucounts;
	u64 seq;
	wait_queue_head_t poll;
	u64 event;
	unsigned int mounts;
	unsigned int pending_mounts;
};

struct cgroup_namespace___165 {
	refcount_t count;
	struct ns_common___11 ns;
	struct user_namespace___174 *user_ns;
	struct ucounts___174 *ucounts;
	struct css_set___165 *root_cset;
};

struct ucounts___174 {
	struct hlist_node node;
	struct user_namespace___174 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct kernfs_root___192;

struct kernfs_elem_dir___192 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___192 *root;
};

struct kernfs_syscall_ops___192;

struct kernfs_root___192 {
	struct kernfs_node___192 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___192 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___192 {
	struct kernfs_node___192 *target_kn;
};

struct kernfs_ops___192;

struct kernfs_elem_attr___192 {
	const struct kernfs_ops___192 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___192 *notify_next;
};

struct kernfs_node___192 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___192 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___192 dir;
		struct kernfs_elem_symlink___192 symlink;
		struct kernfs_elem_attr___192 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___192;

struct kernfs_ops___192 {
	int (*open)(struct kernfs_open_file___192 *);
	void (*release)(struct kernfs_open_file___192 *);
	int (*seq_show)(struct seq_file___184 *, void *);
	void * (*seq_start)(struct seq_file___184 *, loff_t *);
	void * (*seq_next)(struct seq_file___184 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___184 *, void *);
	ssize_t (*read)(struct kernfs_open_file___192 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___192 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___192 *, struct vm_area_struct___198 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___192 *, struct poll_table_struct___135 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___192 {
	int (*remount_fs)(struct kernfs_root___192 *, int *, char *);
	int (*show_options)(struct seq_file___184 *, struct kernfs_root___192 *);
	int (*mkdir)(struct kernfs_node___192 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___192 *);
	int (*rename)(struct kernfs_node___192 *, struct kernfs_node___192 *, const char *);
	int (*show_path)(struct seq_file___184 *, struct kernfs_node___192 *, struct kernfs_root___192 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___192 {
	struct kernfs_node___192 *kn;
	struct file___198 *file;
	struct seq_file___184 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___194 *vm_ops;
};

struct bin_attribute___179;

struct attribute_group___180 {
	const char *name;
	umode_t (*is_visible)(struct kobject___189 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___189 *, struct bin_attribute___179 *, int);
	struct attribute **attrs;
	struct bin_attribute___179 **bin_attrs;
};

struct bin_attribute___179 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___198 *, struct kobject___189 *, struct bin_attribute___179 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___198 *, struct kobject___189 *, struct bin_attribute___179 *, char *, loff_t, size_t);
	int (*mmap)(struct file___198 *, struct kobject___189 *, struct bin_attribute___179 *, struct vm_area_struct___198 *);
};

struct sysfs_ops___188 {
	ssize_t (*show)(struct kobject___189 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___189 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___188;

struct kset___188 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___189 kobj;
	const struct kset_uevent_ops___188 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___188 {
	void (*release)(struct kobject___189 *);
	const struct sysfs_ops___188 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___12 * (*child_ns_type)(struct kobject___189 *);
	const void * (*namespace)(struct kobject___189 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___188 {
	int (* const filter)(struct kset___188 *, struct kobject___189 *);
	const char * (* const name)(struct kset___188 *, struct kobject___189 *);
	int (* const uevent)(struct kset___188 *, struct kobject___189 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___164 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___164 *);
	int (*get)(char *, const struct kernel_param___164 *);
	void (*free)(void *);
};

struct kparam_array___164;

struct kernel_param___164 {
	const char *name;
	struct module___167 *mod;
	const struct kernel_param_ops___164 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___164 *arr;
	};
};

struct kparam_array___164 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___164 *ops;
	void *elem;
};

struct module_attribute___164 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___164 *, struct module_kobject___164 *, char *);
	ssize_t (*store)(struct module_attribute___164 *, struct module_kobject___164 *, const char *, size_t);
	void (*setup)(struct module___167 *, const char *);
	int (*test)(struct module___167 *);
	void (*free)(struct module___167 *);
};

struct trace_event_class___113;

struct trace_event_call___113 {
	struct list_head list;
	struct trace_event_class___113 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___22 *prog_array;
	int (*perf_perm)(struct trace_event_call___113 *, struct perf_event___120 *);
};

struct dev_pm_ops___178 {
	int (*prepare)(struct device___178 *);
	void (*complete)(struct device___178 *);
	int (*suspend)(struct device___178 *);
	int (*resume)(struct device___178 *);
	int (*freeze)(struct device___178 *);
	int (*thaw)(struct device___178 *);
	int (*poweroff)(struct device___178 *);
	int (*restore)(struct device___178 *);
	int (*suspend_late)(struct device___178 *);
	int (*resume_early)(struct device___178 *);
	int (*freeze_late)(struct device___178 *);
	int (*thaw_early)(struct device___178 *);
	int (*poweroff_late)(struct device___178 *);
	int (*restore_early)(struct device___178 *);
	int (*suspend_noirq)(struct device___178 *);
	int (*resume_noirq)(struct device___178 *);
	int (*freeze_noirq)(struct device___178 *);
	int (*thaw_noirq)(struct device___178 *);
	int (*poweroff_noirq)(struct device___178 *);
	int (*restore_noirq)(struct device___178 *);
	int (*runtime_suspend)(struct device___178 *);
	int (*runtime_resume)(struct device___178 *);
	int (*runtime_idle)(struct device___178 *);
};

struct dev_pm_domain___178 {
	struct dev_pm_ops___178 ops;
	void (*detach)(struct device___178 *, bool);
	int (*activate)(struct device___178 *);
	void (*sync)(struct device___178 *);
	void (*dismiss)(struct device___178 *);
};

struct bus_type___178 {
	const char *name;
	const char *dev_name;
	struct device___178 *dev_root;
	const struct attribute_group___180 **bus_groups;
	const struct attribute_group___180 **dev_groups;
	const struct attribute_group___180 **drv_groups;
	int (*match)(struct device___178 *, struct device_driver___178 *);
	int (*uevent)(struct device___178 *, struct kobj_uevent_env *);
	int (*probe)(struct device___178 *);
	int (*remove)(struct device___178 *);
	void (*shutdown)(struct device___178 *);
	int (*online)(struct device___178 *);
	int (*offline)(struct device___178 *);
	int (*suspend)(struct device___178 *, pm_message_t);
	int (*resume)(struct device___178 *);
	int (*num_vf)(struct device___178 *);
	int (*dma_configure)(struct device___178 *);
	const struct dev_pm_ops___178 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___178 {
	const char *name;
	struct bus_type___178 *bus;
	struct module___167 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___178 *);
	int (*remove)(struct device___178 *);
	void (*shutdown)(struct device___178 *);
	int (*suspend)(struct device___178 *, pm_message_t);
	int (*resume)(struct device___178 *);
	const struct attribute_group___180 **groups;
	const struct dev_pm_ops___178 *pm;
	void (*coredump)(struct device___178 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___178 {
	const char *name;
	const struct attribute_group___180 **groups;
	int (*uevent)(struct device___178 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___178 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___178 *);
	const struct dev_pm_ops___178 *pm;
};

struct class___178 {
	const char *name;
	struct module___167 *owner;
	const struct attribute_group___180 **class_groups;
	const struct attribute_group___180 **dev_groups;
	struct kobject___189 *dev_kobj;
	int (*dev_uevent)(struct device___178 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___178 *, umode_t *);
	void (*class_release)(struct class___178 *);
	void (*dev_release)(struct device___178 *);
	int (*shutdown_pre)(struct device___178 *);
	const struct kobj_ns_type_operations___12 *ns_type;
	const void * (*namespace)(struct device___178 *);
	const struct dev_pm_ops___178 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___153 {
	struct device___178 dev;
};

struct fd___27 {
	struct file___198 *file;
	unsigned int flags;
};

struct bpf_map___165;

struct bpf_map_ops___165 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___165 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___165 *, struct file___198 *);
	void (*map_free)(struct bpf_map___165 *);
	int (*map_get_next_key)(struct bpf_map___165 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___165 *);
	void * (*map_lookup_elem)(struct bpf_map___165 *, void *);
	int (*map_update_elem)(struct bpf_map___165 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___165 *, void *);
	int (*map_push_elem)(struct bpf_map___165 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___165 *, void *);
	int (*map_peek_elem)(struct bpf_map___165 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___165 *, struct file___198 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___165 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___165 *, void *, struct seq_file___184 *);
	int (*map_check_btf)(const struct bpf_map___165 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___165 {
	const struct bpf_map_ops___165 *ops;
	struct bpf_map___165 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___192 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___165;

typedef void (*kthread_work_func_t___165)(struct kthread_work___165 *);

struct kthread_worker___165;

struct kthread_work___165 {
	struct list_head node;
	kthread_work_func_t___165 func;
	struct kthread_worker___165 *worker;
	int canceling;
};

struct kthread_worker___165 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___198 *task;
	struct kthread_work___165 *current_work;
};

struct kthread_delayed_work___165 {
	struct kthread_work___165 work;
	struct timer_list timer;
};

struct psi_group___165 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___165 *poll_kworker;
	struct kthread_delayed_work___165 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___165 {
	struct kernfs_node___192 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___165;

struct cgroup_subsys_state___166 {
	struct cgroup___165 *cgroup;
	struct cgroup_subsys___165 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___166 *parent;
};

struct cgroup_root___165;

struct cgroup_rstat_cpu___165;

struct cgroup___165 {
	struct cgroup_subsys_state___166 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___192 *kn;
	struct cgroup_file___165 procs_file;
	struct cgroup_file___165 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___166 *subsys[13];
	struct cgroup_root___165 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___165 *dom_cgrp;
	struct cgroup_rstat_cpu___165 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___22 bpf;
	atomic_t congestion_count;
	struct cgroup___165 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___165 psi;
	int ancestor_ids[0];
};

struct cftype___165;

struct cgroup_subsys___165 {
	struct cgroup_subsys_state___166 * (*css_alloc)(struct cgroup_subsys_state___166 *);
	int (*css_online)(struct cgroup_subsys_state___166 *);
	void (*css_offline)(struct cgroup_subsys_state___166 *);
	void (*css_released)(struct cgroup_subsys_state___166 *);
	void (*css_free)(struct cgroup_subsys_state___166 *);
	void (*css_reset)(struct cgroup_subsys_state___166 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___166 *, int);
	int (*css_extra_stat_show)(struct seq_file___184 *, struct cgroup_subsys_state___166 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___198 *);
	void (*cancel_fork)(struct task_struct___198 *);
	void (*fork)(struct task_struct___198 *);
	void (*exit)(struct task_struct___198 *);
	void (*free)(struct task_struct___198 *);
	void (*bind)(struct cgroup_subsys_state___166 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___165 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___165 *dfl_cftypes;
	struct cftype___165 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___165 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___165 *updated_children;
	struct cgroup___165 *updated_next;
};

struct cgroup_root___165 {
	struct kernfs_root___192 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___165 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___165 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___165 *ss;
	struct list_head node;
	struct kernfs_ops___192 *kf_ops;
	int (*open)(struct kernfs_open_file___192 *);
	void (*release)(struct kernfs_open_file___192 *);
	u64 (*read_u64)(struct cgroup_subsys_state___166 *, struct cftype___165 *);
	s64 (*read_s64)(struct cgroup_subsys_state___166 *, struct cftype___165 *);
	int (*seq_show)(struct seq_file___184 *, void *);
	void * (*seq_start)(struct seq_file___184 *, loff_t *);
	void * (*seq_next)(struct seq_file___184 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___184 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___166 *, struct cftype___165 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___166 *, struct cftype___165 *, s64);
	ssize_t (*write)(struct kernfs_open_file___192 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___192 *, struct poll_table_struct___135 *);
};

struct perf_cpu_context___120;

struct pmu___120 {
	struct list_head entry;
	struct module___167 *module;
	struct device___178 *dev;
	const struct attribute_group___180 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___120 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___120 *);
	void (*pmu_disable)(struct pmu___120 *);
	int (*event_init)(struct perf_event___120 *);
	void (*event_mapped)(struct perf_event___120 *, struct mm_struct___197 *);
	void (*event_unmapped)(struct perf_event___120 *, struct mm_struct___197 *);
	int (*add)(struct perf_event___120 *, int);
	void (*del)(struct perf_event___120 *, int);
	void (*start)(struct perf_event___120 *, int);
	void (*stop)(struct perf_event___120 *, int);
	void (*read)(struct perf_event___120 *);
	void (*start_txn)(struct pmu___120 *, unsigned int);
	int (*commit_txn)(struct pmu___120 *);
	void (*cancel_txn)(struct pmu___120 *);
	int (*event_idx)(struct perf_event___120 *);
	void (*sched_task)(struct perf_event_context___120 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___120 *);
	int (*filter_match)(struct perf_event___120 *);
	int (*check_period)(struct perf_event___120 *, u64);
};

struct perf_cpu_context___120 {
	struct perf_event_context___120 ctx;
	struct perf_event_context___120 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___120 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___120 {
	struct cgroup_subsys_state___166 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___113 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___113 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___113 *);
	struct list_head * (*get_fields)(struct trace_event_call___113 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___113 *);
};

struct syscall_metadata___57 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___113 *enter_event;
	struct trace_event_call___113 *exit_event;
};

struct mountpoint___10;

struct mount___10 {
	struct hlist_node mnt_hash;
	struct mount___10 *mnt_parent;
	struct dentry___197 *mnt_mountpoint;
	struct vfsmount___42 mnt;
	union {
		struct callback_head mnt_rcu;
		struct llist_node mnt_llist;
	};
	struct mnt_pcp *mnt_pcp;
	struct list_head mnt_mounts;
	struct list_head mnt_child;
	struct list_head mnt_instance;
	const char *mnt_devname;
	struct list_head mnt_list;
	struct list_head mnt_expire;
	struct list_head mnt_share;
	struct list_head mnt_slave_list;
	struct list_head mnt_slave;
	struct mount___10 *mnt_master;
	struct mnt_namespace___10 *mnt_ns;
	struct mountpoint___10 *mnt_mp;
	struct hlist_node mnt_mp_list;
	struct list_head mnt_umounting;
	struct fsnotify_mark_connector *mnt_fsnotify_marks;
	__u32 mnt_fsnotify_mask;
	int mnt_id;
	int mnt_group_id;
	int mnt_expiry_mark;
	struct hlist_head mnt_pins;
	struct fs_pin mnt_umount;
	struct dentry___197 *mnt_ex_mountpoint;
};

struct mountpoint___10 {
	struct hlist_node m_hash;
	struct dentry___197 *m_dentry;
	struct hlist_head m_list;
	int m_count;
};

struct module___168;

struct file___199;

struct kiocb___199;

struct iov_iter___97;

struct vm_area_struct___199;

struct inode___199;

struct file_lock___199;

struct page___199;

struct seq_file___185;

struct file_operations___199 {
	struct module___168 *owner;
	loff_t (*llseek)(struct file___199 *, loff_t, int);
	ssize_t (*read)(struct file___199 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___199 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___199 *, struct iov_iter___97 *);
	ssize_t (*write_iter)(struct kiocb___199 *, struct iov_iter___97 *);
	int (*iopoll)(struct kiocb___199 *, bool);
	int (*iterate)(struct file___199 *, struct dir_context *);
	int (*iterate_shared)(struct file___199 *, struct dir_context *);
	__poll_t (*poll)(struct file___199 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___199 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___199 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___199 *, struct vm_area_struct___199 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___199 *, struct file___199 *);
	int (*flush)(struct file___199 *, fl_owner_t);
	int (*release)(struct inode___199 *, struct file___199 *);
	int (*fsync)(struct file___199 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___199 *, int);
	int (*lock)(struct file___199 *, int, struct file_lock___199 *);
	ssize_t (*sendpage)(struct file___199 *, struct page___199 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___199 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___199 *, int, struct file_lock___199 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___199 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___199 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___199 *, long int, struct file_lock___199 **, void **);
	long int (*fallocate)(struct file___199 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___185 *, struct file___199 *);
	ssize_t (*copy_file_range)(struct file___199 *, loff_t, struct file___199 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___199 *, loff_t, struct file___199 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___199 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___198 {
	u64 seqnum;
	struct vm_area_struct___199 *vmas[4];
};

struct page_frag___198 {
	struct page___199 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___198;

struct mem_cgroup___90;

struct cred___193;

struct nsproxy___188;

struct signal_struct___175;

struct bio_list___101;

struct backing_dev_info___101;

struct io_context___53;

struct css_set___166;

struct request_queue___50;

struct vm_struct___139;

struct task_struct___199 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___199 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___198 *mm;
	struct mm_struct___198 *active_mm;
	struct vmacache___198 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___199 *real_parent;
	struct task_struct___199 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___199 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___90 *active_memcg;
	long int rh_reserved2;
	struct pid___157 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___157 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___157 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___193 *ptracer_cred;
	const struct cred___193 *real_cred;
	const struct cred___193 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___188 *nsproxy;
	struct signal_struct___175 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___199 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___101 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___101 *backing_dev_info;
	struct io_context___53 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___166 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___198 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___90 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___50 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___199 *oom_reaper_list;
	struct vm_struct___139 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___120 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rw_semaphore___199 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___199 *owner;
};

struct key___193;

struct ucounts___175;

struct user_namespace___175 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___175 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___11 ns;
	long unsigned int flags;
	struct key___193 *persistent_keyring_register;
	struct rw_semaphore___199 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___175 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___199 *pgtable_t___198;

struct address_space___198;

struct dev_pagemap___195;

struct page___199 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___198 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___199 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___198 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___198 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___195 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___90 *mem_cgroup;
};

struct pglist_data___198;

struct lruvec___198 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___198 *pgdat;
};

struct zone___198 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___198 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___198 {
	struct zone___198 *zone;
	int zone_idx;
};

struct zonelist___198 {
	struct zoneref___198 _zonerefs[25];
};

struct pglist_data___198 {
	struct zone___198 node_zones[3];
	struct zonelist___198 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___199 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___199 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___198 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___199 {
	void *stack;
	struct task_struct___199 *task;
	long int status;
};

struct blocking_notifier_head___198 {
	struct rw_semaphore___199 rwsem;
	struct notifier_block *head;
};

struct dentry___198;

struct path___198 {
	struct vfsmount *mnt;
	struct dentry___198 *dentry;
};

struct file___199 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___198 f_path;
	struct inode___199 *f_inode;
	const struct file_operations___199 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___157 f_owner;
	const struct cred___193 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___198 *f_mapping;
	errseq_t f_wb_err;
};

struct user_struct___193;

struct cred___193 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___193 *session_keyring;
	struct key___193 *process_keyring;
	struct key___193 *thread_keyring;
	struct key___193 *request_key_auth;
	void *security;
	struct user_struct___193 *user;
	struct user_namespace___175 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___193;

struct kernfs_elem_dir___193 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___193 *root;
};

struct kernfs_node___193;

struct kernfs_syscall_ops___193;

struct kernfs_root___193 {
	struct kernfs_node___193 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___193 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___193 {
	struct kernfs_node___193 *target_kn;
};

struct kernfs_ops___193;

struct kernfs_elem_attr___193 {
	const struct kernfs_ops___193 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___193 *notify_next;
};

struct kernfs_node___193 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___193 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___193 dir;
		struct kernfs_elem_symlink___193 symlink;
		struct kernfs_elem_attr___193 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___193;

struct kernfs_ops___193 {
	int (*open)(struct kernfs_open_file___193 *);
	void (*release)(struct kernfs_open_file___193 *);
	int (*seq_show)(struct seq_file___185 *, void *);
	void * (*seq_start)(struct seq_file___185 *, loff_t *);
	void * (*seq_next)(struct seq_file___185 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___185 *, void *);
	ssize_t (*read)(struct kernfs_open_file___193 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___193 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___193 *, struct vm_area_struct___199 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___193 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___193 {
	int (*remount_fs)(struct kernfs_root___193 *, int *, char *);
	int (*show_options)(struct seq_file___185 *, struct kernfs_root___193 *);
	int (*mkdir)(struct kernfs_node___193 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___193 *);
	int (*rename)(struct kernfs_node___193 *, struct kernfs_node___193 *, const char *);
	int (*show_path)(struct seq_file___185 *, struct kernfs_node___193 *, struct kernfs_root___193 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___183;

struct seq_file___185 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___183 *op;
	int poll_event;
	const struct file___199 *file;
	void *private;
};

struct vm_operations_struct___195;

struct kernfs_open_file___193 {
	struct kernfs_node___193 *kn;
	struct file___199 *file;
	struct seq_file___185 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___195 *vm_ops;
};

struct vm_fault___195;

struct vm_operations_struct___195 {
	void (*open)(struct vm_area_struct___199 *);
	void (*close)(struct vm_area_struct___199 *);
	int (*split)(struct vm_area_struct___199 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___199 *);
	vm_fault_t (*fault)(struct vm_fault___195 *);
	vm_fault_t (*huge_fault)(struct vm_fault___195 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___195 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___199 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___195 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___195 *);
	int (*access)(struct vm_area_struct___199 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___199 *);
	int (*set_policy)(struct vm_area_struct___199 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___199 *, long unsigned int);
	struct page___199 * (*find_special_page)(struct vm_area_struct___199 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_area_struct___199 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___199 *vm_next;
	struct vm_area_struct___199 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___198 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___195 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___199 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___190;

struct bin_attribute___180;

struct attribute_group___181 {
	const char *name;
	umode_t (*is_visible)(struct kobject___190 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___190 *, struct bin_attribute___180 *, int);
	struct attribute **attrs;
	struct bin_attribute___180 **bin_attrs;
};

struct kset___189;

struct kobj_type___189;

struct kobject___190 {
	const char *name;
	struct list_head entry;
	struct kobject___190 *parent;
	struct kset___189 *kset;
	struct kobj_type___189 *ktype;
	struct kernfs_node___193 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___180 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___199 *, struct kobject___190 *, struct bin_attribute___180 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___199 *, struct kobject___190 *, struct bin_attribute___180 *, char *, loff_t, size_t);
	int (*mmap)(struct file___199 *, struct kobject___190 *, struct bin_attribute___180 *, struct vm_area_struct___199 *);
};

struct sysfs_ops___189 {
	ssize_t (*show)(struct kobject___190 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___190 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___189;

struct kset___189 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___190 kobj;
	const struct kset_uevent_ops___189 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___189 {
	void (*release)(struct kobject___190 *);
	const struct sysfs_ops___189 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___12 * (*child_ns_type)(struct kobject___190 *);
	const void * (*namespace)(struct kobject___190 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___189 {
	int (* const filter)(struct kset___189 *, struct kobject___190 *);
	const char * (* const name)(struct kset___189 *, struct kobject___190 *);
	int (* const uevent)(struct kset___189 *, struct kobject___190 *, struct kobj_uevent_env *);
};

struct kobj_attribute___189 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___190 *, struct kobj_attribute___189 *, char *);
	ssize_t (*store)(struct kobject___190 *, struct kobj_attribute___189 *, const char *, size_t);
};

struct kernel_param___165;

struct kernel_param_ops___165 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___165 *);
	int (*get)(char *, const struct kernel_param___165 *);
	void (*free)(void *);
};

struct kparam_array___165;

struct kernel_param___165 {
	const char *name;
	struct module___168 *mod;
	const struct kernel_param_ops___165 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___165 *arr;
	};
};

struct kparam_array___165 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___165 *ops;
	void *elem;
};

struct module_kobject___165 {
	struct kobject___190 kobj;
	struct module___168 *mod;
	struct kobject___190 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___165 {
	struct module___168 *mod;
	struct latch_tree_node node;
};

struct module_layout___165 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___165 mtn;
};

struct module_attribute___165;

struct module___168 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___165 mkobj;
	struct module_attribute___165 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___190 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___165 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___165 core_layout;
	struct module_layout___165 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___165 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___165 *, struct module_kobject___165 *, char *);
	ssize_t (*store)(struct module_attribute___165 *, struct module_kobject___165 *, const char *, size_t);
	void (*setup)(struct module___168 *, const char *);
	int (*test)(struct module___168 *);
	void (*free)(struct module___168 *);
};

struct dentry_operations___198;

struct super_block___198;

struct dentry___198 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___198 *d_parent;
	struct qstr d_name;
	struct inode___199 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___198 *d_op;
	struct super_block___198 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___198;

struct address_space___198 {
	struct inode___199 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___199 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___198 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___198;

struct bdi_writeback___101;

struct block_device___199;

struct inode___199 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___198 *i_op;
	struct super_block___198 *i_sb;
	struct address_space___198 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___199 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___101 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___199 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___198 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___199 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___198 {
	int (*d_revalidate)(struct dentry___198 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___198 *, unsigned int);
	int (*d_hash)(const struct dentry___198 *, struct qstr *);
	int (*d_compare)(const struct dentry___198 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___198 *);
	int (*d_init)(struct dentry___198 *);
	void (*d_release)(struct dentry___198 *);
	void (*d_prune)(struct dentry___198 *);
	void (*d_iput)(struct dentry___198 *, struct inode___199 *);
	char * (*d_dname)(struct dentry___198 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___198 *);
	int (*d_manage)(const struct path___198 *, bool);
	struct dentry___198 * (*d_real)(struct dentry___198 *, const struct inode___199 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___198;

struct mem_dqinfo___198 {
	struct quota_format_type___198 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___198;

struct quota_info___198 {
	unsigned int flags;
	struct rw_semaphore___199 dqio_sem;
	struct inode___199 *files[3];
	struct mem_dqinfo___198 info[3];
	const struct quota_format_ops___198 *ops[3];
};

struct rcuwait___198 {
	struct task_struct___199 *task;
};

struct percpu_rw_semaphore___198 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___199 rw_sem;
	struct rcuwait___198 writer;
	int readers_block;
};

struct sb_writers___198 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___198 rw_sem[3];
};

struct shrink_control___90;

struct shrinker___90 {
	long unsigned int (*count_objects)(struct shrinker___90 *, struct shrink_control___90 *);
	long unsigned int (*scan_objects)(struct shrinker___90 *, struct shrink_control___90 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___198;

struct super_operations___198;

struct dquot_operations___198;

struct quotactl_ops___198;

struct super_block___198 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___198 *s_type;
	const struct super_operations___198 *s_op;
	const struct dquot_operations___198 *dq_op;
	const struct quotactl_ops___198 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___198 *s_root;
	struct rw_semaphore___199 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___199 *s_bdev;
	struct backing_dev_info___101 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___198 s_dquot;
	struct sb_writers___198 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___198 *s_d_op;
	int cleancache_poolid;
	struct shrinker___90 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___175 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___90 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___90 *memcg;
};

struct cgroup___166;

struct cgroup_subsys___166;

struct cgroup_subsys_state___167 {
	struct cgroup___166 *cgroup;
	struct cgroup_subsys___166 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___167 *parent;
};

struct cgroup_file___166 {
	struct kernfs_node___193 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___90;

struct mem_cgroup___90 {
	struct cgroup_subsys_state___167 css;
	struct mem_cgroup_id___2 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___166 events_file;
	struct cgroup_file___166 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___199 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___90 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct core_state___198;

struct mm_struct___198 {
	struct {
		struct vm_area_struct___199 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___199 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___199 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___198 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___199 *owner;
		struct user_namespace___175 *user_ns;
		struct file___199 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___198 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___195)(struct vm_area_struct___199 *, long unsigned int, const struct page___199 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___195)(struct page___199 *, void *);

struct device___179;

struct dev_pagemap___195 {
	dev_page_fault_t___195 page_fault;
	dev_page_free_t___195 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___179 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___198 {
	struct task_struct___199 *task;
	struct core_thread___198 *next;
};

struct core_state___198 {
	atomic_t nr_threads;
	struct core_thread___198 dumper;
	struct completion startup;
};

struct vm_fault___195 {
	struct vm_area_struct___199 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___199 *cow_page;
	struct mem_cgroup___90 *memcg;
	struct page___199 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___198 prealloc_pte;
};

struct user_struct___193 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___193 *uid_keyring;
	struct key___193 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cgroup_namespace___166;

struct nsproxy___188 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___166 *cgroup_ns;
};

struct signal_struct___175 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___199 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___199 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___157 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___157 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___198 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___157 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide45;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___101;

struct bio_list___101 {
	struct bio___101 *head;
	struct bio___101 *tail;
};

struct bdi_writeback_congested___101;

struct bdi_writeback___101 {
	struct backing_dev_info___101 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___101 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___167 *memcg_css;
	struct cgroup_subsys_state___167 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___101 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___101 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___179 *dev;
	struct device___179 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___198 *debug_dir;
	struct dentry___198 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___53;

struct io_context___53 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___53 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___166 {
	struct cgroup_subsys_state___167 *subsys[13];
	refcount_t refcount;
	struct css_set___166 *dom_cset;
	struct cgroup___166 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___166 *mg_src_cgrp;
	struct cgroup___166 *mg_dst_cgrp;
	struct css_set___166 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

typedef blk_qc_t make_request_fn___49(struct request_queue___50 *, struct bio___101 *);

struct request___50;

typedef int dma_drain_needed_fn___49(struct request___50 *);

struct bsg_ops___49;

struct bsg_class_device___49 {
	struct device___179 *class_dev;
	int minor;
	struct request_queue___50 *queue;
	const struct bsg_ops___49 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___101 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___101 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___49;

struct blkcg_gq___38;

struct request_queue___50 {
	struct list_head queue_head;
	struct request___50 *last_merge;
	struct elevator_queue___49 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___49 *make_request_fn;
	dma_drain_needed_fn___49 *dma_drain_needed;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___101 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___190 kobj;
	struct kobject___190 *mq_kobj;
	struct blk_integrity integrity;
	struct device___179 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___38 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	struct bsg_class_device___49 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___101 bio_split;
	struct dentry___198 *debugfs_dir;
	struct dentry___198 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___139 {
	struct vm_struct___139 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___199 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___177 {
	struct task_struct___199 task;
	long unsigned int stack[8192];
};

struct io_cq___53 {
	struct request_queue___50 *q;
	struct io_context___53 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___6 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___199 {
	struct file___199 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___199 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___198 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___199 *ia_file;
};

struct dquot___198 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___198 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___198 {
	int qf_fmt_id;
	const struct quota_format_ops___198 *qf_ops;
	struct module___168 *qf_owner;
	struct quota_format_type___198 *qf_next;
};

struct quota_format_ops___198 {
	int (*check_quota_file)(struct super_block___198 *, int);
	int (*read_file_info)(struct super_block___198 *, int);
	int (*write_file_info)(struct super_block___198 *, int);
	int (*free_file_info)(struct super_block___198 *, int);
	int (*read_dqblk)(struct dquot___198 *);
	int (*commit_dqblk)(struct dquot___198 *);
	int (*release_dqblk)(struct dquot___198 *);
	int (*get_next_id)(struct super_block___198 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___198 {
	int (*write_dquot)(struct dquot___198 *);
	struct dquot___198 * (*alloc_dquot)(struct super_block___198 *, int);
	void (*destroy_dquot)(struct dquot___198 *);
	int (*acquire_dquot)(struct dquot___198 *);
	int (*release_dquot)(struct dquot___198 *);
	int (*mark_dirty)(struct dquot___198 *);
	int (*write_info)(struct super_block___198 *, int);
	qsize_t * (*get_reserved_space)(struct inode___199 *);
	int (*get_projid)(struct inode___199 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___199 *, qsize_t *);
	int (*get_next_id)(struct super_block___198 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___198 {
	int (*quota_on)(struct super_block___198 *, int, int, const struct path___198 *);
	int (*quota_off)(struct super_block___198 *, int);
	int (*quota_enable)(struct super_block___198 *, unsigned int);
	int (*quota_disable)(struct super_block___198 *, unsigned int);
	int (*quota_sync)(struct super_block___198 *, int);
	int (*set_info)(struct super_block___198 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___198 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___198 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___198 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___198 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___198 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___97;

struct swap_info_struct___63;

struct address_space_operations___198 {
	int (*writepage)(struct page___199 *, struct writeback_control___97 *);
	int (*readpage)(struct file___199 *, struct page___199 *);
	int (*writepages)(struct address_space___198 *, struct writeback_control___97 *);
	int (*set_page_dirty)(struct page___199 *);
	int (*readpages)(struct file___199 *, struct address_space___198 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___199 *, struct address_space___198 *, loff_t, unsigned int, unsigned int, struct page___199 **, void **);
	int (*write_end)(struct file___199 *, struct address_space___198 *, loff_t, unsigned int, unsigned int, struct page___199 *, void *);
	sector_t (*bmap)(struct address_space___198 *, sector_t);
	void (*invalidatepage)(struct page___199 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___199 *, gfp_t);
	void (*freepage)(struct page___199 *);
	ssize_t (*direct_IO)(struct kiocb___199 *, struct iov_iter___97 *);
	int (*migratepage)(struct address_space___198 *, struct page___199 *, struct page___199 *, enum migrate_mode);
	bool (*isolate_page)(struct page___199 *, isolate_mode_t);
	void (*putback_page)(struct page___199 *);
	int (*launder_page)(struct page___199 *);
	int (*is_partially_uptodate)(struct page___199 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___199 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___198 *, struct page___199 *);
	int (*swap_activate)(struct swap_info_struct___63 *, struct file___199 *, sector_t *);
	void (*swap_deactivate)(struct file___199 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___97 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___101 *wb;
	struct inode___199 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___101;

struct iov_iter___97 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___101 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct swap_info_struct___63 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___199 *bdev;
	struct file___199 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct hd_struct___50;

struct gendisk___50;

struct block_device___199 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___199 *bd_inode;
	struct super_block___198 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___199 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___50 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___50 *bd_disk;
	struct request_queue___50 *bd_queue;
	struct backing_dev_info___101 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___179 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___179 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___179;

struct bus_type___179;

struct device_driver___179;

struct dev_pm_domain___179;

struct fwnode_handle___125;

struct class___179;

struct device___179 {
	struct device___179 *parent;
	struct device_private *p;
	struct kobject___190 kobj;
	const char *init_name;
	const struct device_type___179 *type;
	struct mutex mutex;
	struct bus_type___179 *bus;
	struct device_driver___179 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___179 power;
	struct dev_pm_domain___179 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___125 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___179 *class;
	const struct attribute_group___181 **groups;
	void (*release)(struct device___179 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___50 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___179 __dev;
	struct kobject___190 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___50;

struct block_device_operations___50;

struct gendisk___50 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___50 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___50 *part_tbl;
	struct hd_struct___50 part0;
	const struct block_device_operations___50 *fops;
	struct request_queue___50 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___199 lookup_sem;
	struct kobject___190 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___190 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___198 {
	struct dentry___198 * (*lookup)(struct inode___199 *, struct dentry___198 *, unsigned int);
	const char * (*get_link)(struct dentry___198 *, struct inode___199 *, struct delayed_call *);
	int (*permission)(struct inode___199 *, int);
	struct posix_acl * (*get_acl)(struct inode___199 *, int);
	int (*readlink)(struct dentry___198 *, char *, int);
	int (*create)(struct inode___199 *, struct dentry___198 *, umode_t, bool);
	int (*link)(struct dentry___198 *, struct inode___199 *, struct dentry___198 *);
	int (*unlink)(struct inode___199 *, struct dentry___198 *);
	int (*symlink)(struct inode___199 *, struct dentry___198 *, const char *);
	int (*mkdir)(struct inode___199 *, struct dentry___198 *, umode_t);
	int (*rmdir)(struct inode___199 *, struct dentry___198 *);
	int (*mknod)(struct inode___199 *, struct dentry___198 *, umode_t, dev_t);
	int (*rename)(struct inode___199 *, struct dentry___198 *, struct inode___199 *, struct dentry___198 *, unsigned int);
	int (*setattr)(struct dentry___198 *, struct iattr___198 *);
	int (*getattr)(const struct path___198 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___198 *, char *, size_t);
	int (*fiemap)(struct inode___199 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___199 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___199 *, struct dentry___198 *, struct file___199 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___199 *, struct dentry___198 *, umode_t);
	int (*set_acl)(struct inode___199 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___198 {
	void (*fl_copy_lock)(struct file_lock___199 *, struct file_lock___199 *);
	void (*fl_release_private)(struct file_lock___199 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___198;

struct lock_manager_operations___198;

struct file_lock___199 {
	struct file_lock___199 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___199 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___198 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___198 *fl_ops;
	const struct lock_manager_operations___198 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___198 {
	int (*lm_compare_owner)(struct file_lock___199 *, struct file_lock___199 *);
	long unsigned int (*lm_owner_key)(struct file_lock___199 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___199 *);
	int (*lm_grant)(struct file_lock___199 *, int);
	bool (*lm_break)(struct file_lock___199 *);
	int (*lm_change)(struct file_lock___199 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___199 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___198 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___198 *fa_next;
	struct file___199 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___198 {
	const char *name;
	int fs_flags;
	struct dentry___198 * (*mount)(struct file_system_type___198 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___198 *);
	struct module___168 *owner;
	struct file_system_type___198 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___198 {
	struct inode___199 * (*alloc_inode)(struct super_block___198 *);
	void (*destroy_inode)(struct inode___199 *);
	void (*dirty_inode)(struct inode___199 *, int);
	int (*write_inode)(struct inode___199 *, struct writeback_control___97 *);
	int (*drop_inode)(struct inode___199 *);
	void (*evict_inode)(struct inode___199 *);
	void (*put_super)(struct super_block___198 *);
	int (*sync_fs)(struct super_block___198 *, int);
	int (*freeze_super)(struct super_block___198 *);
	int (*freeze_fs)(struct super_block___198 *);
	int (*thaw_super)(struct super_block___198 *);
	int (*unfreeze_fs)(struct super_block___198 *);
	int (*statfs)(struct dentry___198 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___198 *, int *, char *);
	void (*umount_begin)(struct super_block___198 *);
	int (*show_options)(struct seq_file___185 *, struct dentry___198 *);
	int (*show_devname)(struct seq_file___185 *, struct dentry___198 *);
	int (*show_path)(struct seq_file___185 *, struct dentry___198 *);
	int (*show_stats)(struct seq_file___185 *, struct dentry___198 *);
	ssize_t (*quota_read)(struct super_block___198 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___198 *, int, const char *, size_t, loff_t);
	struct dquot___198 ** (*get_dquots)(struct inode___199 *);
	int (*bdev_try_to_free_page)(struct super_block___198 *, struct page___199 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___198 *, struct shrink_control___90 *);
	long int (*free_cached_objects)(struct super_block___198 *, struct shrink_control___90 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___101(struct bio___101 *);

struct bio_vec___101 {
	struct page___199 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___101;

struct bio___101 {
	struct bio___101 *bi_next;
	struct gendisk___50 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___101 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___38 *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___101 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___101 *bi_io_vec;
	struct bio_set___101 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___101 bi_inline_vecs[0];
};

typedef void compound_page_dtor___195(struct page___199 *);

struct iomap_page_ops___3;

struct iomap___4 {
	u64 addr;
	loff_t offset;
	u64 length;
	u16 type;
	u16 flags;
	struct block_device___199 *bdev;
	struct dax_device *dax_dev;
	void *inline_data;
	void *private;
	const struct iomap_page_ops___3 *page_ops;
};

struct iomap_page_ops___3 {
	int (*page_prepare)(struct inode___199 *, loff_t, unsigned int, struct iomap___4 *);
	void (*page_done)(struct inode___199 *, loff_t, unsigned int, struct page___199 *, struct iomap___4 *);
};

struct iomap_ops___2 {
	int (*iomap_begin)(struct inode___199 *, loff_t, loff_t, unsigned int, struct iomap___4 *);
	int (*iomap_end)(struct inode___199 *, loff_t, loff_t, ssize_t, unsigned int, struct iomap___4 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct iomap_page {
	atomic_t read_count;
	atomic_t write_count;
	long unsigned int uptodate[2];
};

typedef int iomap_dio_end_io_t(struct kiocb___199 *, ssize_t, unsigned int);

typedef int filler_t___6(void *, struct page___199 *);

typedef int (*key_restrict_link_func_t___193)(struct key___193 *, const struct key_type *, const union key_payload *, struct key___193 *);

struct key_restriction___193;

struct key___193 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___199 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___193 *restrict_link;
};

struct key_restriction___193 {
	key_restrict_link_func_t___193 check;
	struct key___193 *key;
	struct key_type *keytype;
};

struct seq_operations___183 {
	void * (*start)(struct seq_file___185 *, loff_t *);
	void (*stop)(struct seq_file___185 *, void *);
	void * (*next)(struct seq_file___185 *, void *, loff_t *);
	int (*show)(struct seq_file___185 *, void *);
};

struct cgroup_namespace___166 {
	refcount_t count;
	struct ns_common___11 ns;
	struct user_namespace___175 *user_ns;
	struct ucounts___175 *ucounts;
	struct css_set___166 *root_cset;
};

struct ucounts___175 {
	struct hlist_node node;
	struct user_namespace___175 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___166;

struct bpf_map_ops___166 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___166 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___166 *, struct file___199 *);
	void (*map_free)(struct bpf_map___166 *);
	int (*map_get_next_key)(struct bpf_map___166 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___166 *);
	void * (*map_lookup_elem)(struct bpf_map___166 *, void *);
	int (*map_update_elem)(struct bpf_map___166 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___166 *, void *);
	int (*map_push_elem)(struct bpf_map___166 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___166 *, void *);
	int (*map_peek_elem)(struct bpf_map___166 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___166 *, struct file___199 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___166 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___166 *, void *, struct seq_file___185 *);
	int (*map_check_btf)(const struct bpf_map___166 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___166 {
	const struct bpf_map_ops___166 *ops;
	struct bpf_map___166 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___193 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___166;

typedef void (*kthread_work_func_t___166)(struct kthread_work___166 *);

struct kthread_worker___166;

struct kthread_work___166 {
	struct list_head node;
	kthread_work_func_t___166 func;
	struct kthread_worker___166 *worker;
	int canceling;
};

struct kthread_worker___166 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___199 *task;
	struct kthread_work___166 *current_work;
};

struct kthread_delayed_work___166 {
	struct kthread_work___166 work;
	struct timer_list timer;
};

struct psi_group___166 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___166 *poll_kworker;
	struct kthread_delayed_work___166 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___166;

struct cgroup_rstat_cpu___166;

struct cgroup___166 {
	struct cgroup_subsys_state___167 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___193 *kn;
	struct cgroup_file___166 procs_file;
	struct cgroup_file___166 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___167 *subsys[13];
	struct cgroup_root___166 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___166 *dom_cgrp;
	struct cgroup_rstat_cpu___166 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___22 bpf;
	atomic_t congestion_count;
	struct cgroup___166 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___166 psi;
	int ancestor_ids[0];
};

struct cftype___166;

struct cgroup_subsys___166 {
	struct cgroup_subsys_state___167 * (*css_alloc)(struct cgroup_subsys_state___167 *);
	int (*css_online)(struct cgroup_subsys_state___167 *);
	void (*css_offline)(struct cgroup_subsys_state___167 *);
	void (*css_released)(struct cgroup_subsys_state___167 *);
	void (*css_free)(struct cgroup_subsys_state___167 *);
	void (*css_reset)(struct cgroup_subsys_state___167 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___167 *, int);
	int (*css_extra_stat_show)(struct seq_file___185 *, struct cgroup_subsys_state___167 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___199 *);
	void (*cancel_fork)(struct task_struct___199 *);
	void (*fork)(struct task_struct___199 *);
	void (*exit)(struct task_struct___199 *);
	void (*free)(struct task_struct___199 *);
	void (*bind)(struct cgroup_subsys_state___167 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___166 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___166 *dfl_cftypes;
	struct cftype___166 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___166 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___166 *updated_children;
	struct cgroup___166 *updated_next;
};

struct cgroup_root___166 {
	struct kernfs_root___193 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___166 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___166 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___166 *ss;
	struct list_head node;
	struct kernfs_ops___193 *kf_ops;
	int (*open)(struct kernfs_open_file___193 *);
	void (*release)(struct kernfs_open_file___193 *);
	u64 (*read_u64)(struct cgroup_subsys_state___167 *, struct cftype___166 *);
	s64 (*read_s64)(struct cgroup_subsys_state___167 *, struct cftype___166 *);
	int (*seq_show)(struct seq_file___185 *, void *);
	void * (*seq_start)(struct seq_file___185 *, loff_t *);
	void * (*seq_next)(struct seq_file___185 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___185 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___167 *, struct cftype___166 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___167 *, struct cftype___166 *, s64);
	ssize_t (*write)(struct kernfs_open_file___193 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___193 *, struct poll_table_struct___6 *);
};

struct hstate___36 {
	int next_nid_to_alloc;
	int next_nid_to_free;
	unsigned int order;
	long unsigned int mask;
	long unsigned int max_huge_pages;
	long unsigned int nr_huge_pages;
	long unsigned int free_huge_pages;
	long unsigned int resv_huge_pages;
	long unsigned int surplus_huge_pages;
	long unsigned int nr_overcommit_huge_pages;
	struct list_head hugepage_activelist;
	struct list_head hugepage_freelists[8];
	unsigned int nr_huge_pages_node[8];
	unsigned int free_huge_pages_node[8];
	unsigned int surplus_huge_pages_node[8];
	struct cftype___166 cgroup_files[5];
	char name[32];
};

struct bdi_writeback_congested___101 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___101 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___101 {
	struct bio___101 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___101 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___101 bip_inline_vecs[0];
};

struct blkcg___38;

struct blkg_policy_data___38;

struct blkcg_gq___38 {
	struct request_queue___50 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___38 *blkcg;
	struct bdi_writeback_congested___101 *wb_congested;
	struct blkcg_gq___38 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_rwstat stat_bytes;
	struct blkg_rwstat stat_ios;
	struct blkg_policy_data___38 *pd[5];
	struct callback_head callback_head;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
};

struct mem_cgroup_reclaim_iter___90 {
	struct mem_cgroup___90 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___90 {
	struct lruvec___198 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___90 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___90 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct dev_pm_ops___179 {
	int (*prepare)(struct device___179 *);
	void (*complete)(struct device___179 *);
	int (*suspend)(struct device___179 *);
	int (*resume)(struct device___179 *);
	int (*freeze)(struct device___179 *);
	int (*thaw)(struct device___179 *);
	int (*poweroff)(struct device___179 *);
	int (*restore)(struct device___179 *);
	int (*suspend_late)(struct device___179 *);
	int (*resume_early)(struct device___179 *);
	int (*freeze_late)(struct device___179 *);
	int (*thaw_early)(struct device___179 *);
	int (*poweroff_late)(struct device___179 *);
	int (*restore_early)(struct device___179 *);
	int (*suspend_noirq)(struct device___179 *);
	int (*resume_noirq)(struct device___179 *);
	int (*freeze_noirq)(struct device___179 *);
	int (*thaw_noirq)(struct device___179 *);
	int (*poweroff_noirq)(struct device___179 *);
	int (*restore_noirq)(struct device___179 *);
	int (*runtime_suspend)(struct device___179 *);
	int (*runtime_resume)(struct device___179 *);
	int (*runtime_idle)(struct device___179 *);
};

struct dev_pm_domain___179 {
	struct dev_pm_ops___179 ops;
	void (*detach)(struct device___179 *, bool);
	int (*activate)(struct device___179 *);
	void (*sync)(struct device___179 *);
	void (*dismiss)(struct device___179 *);
};

struct bus_type___179 {
	const char *name;
	const char *dev_name;
	struct device___179 *dev_root;
	const struct attribute_group___181 **bus_groups;
	const struct attribute_group___181 **dev_groups;
	const struct attribute_group___181 **drv_groups;
	int (*match)(struct device___179 *, struct device_driver___179 *);
	int (*uevent)(struct device___179 *, struct kobj_uevent_env *);
	int (*probe)(struct device___179 *);
	int (*remove)(struct device___179 *);
	void (*shutdown)(struct device___179 *);
	int (*online)(struct device___179 *);
	int (*offline)(struct device___179 *);
	int (*suspend)(struct device___179 *, pm_message_t);
	int (*resume)(struct device___179 *);
	int (*num_vf)(struct device___179 *);
	int (*dma_configure)(struct device___179 *);
	const struct dev_pm_ops___179 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___179 {
	const char *name;
	struct bus_type___179 *bus;
	struct module___168 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___179 *);
	int (*remove)(struct device___179 *);
	void (*shutdown)(struct device___179 *);
	int (*suspend)(struct device___179 *, pm_message_t);
	int (*resume)(struct device___179 *);
	const struct attribute_group___181 **groups;
	const struct dev_pm_ops___179 *pm;
	void (*coredump)(struct device___179 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___179 {
	const char *name;
	const struct attribute_group___181 **groups;
	int (*uevent)(struct device___179 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___179 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___179 *);
	const struct dev_pm_ops___179 *pm;
};

struct class___179 {
	const char *name;
	struct module___168 *owner;
	const struct attribute_group___181 **class_groups;
	const struct attribute_group___181 **dev_groups;
	struct kobject___190 *dev_kobj;
	int (*dev_uevent)(struct device___179 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___179 *, umode_t *);
	void (*class_release)(struct class___179 *);
	void (*dev_release)(struct device___179 *);
	int (*shutdown_pre)(struct device___179 *);
	const struct kobj_ns_type_operations___12 *ns_type;
	const void * (*namespace)(struct device___179 *);
	const struct dev_pm_ops___179 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct fwnode_operations___125;

struct fwnode_handle___125 {
	struct fwnode_handle___125 *secondary;
	const struct fwnode_operations___125 *ops;
};

struct node___154 {
	struct device___179 dev;
};

struct pagevec___10 {
	unsigned char nr;
	bool percpu_pvec_drained;
	struct page___199 *pages[15];
};

struct disk_part_tbl___50 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___50 *last_lookup;
	struct hd_struct___50 *part[0];
};

struct block_device_operations___50 {
	int (*open)(struct block_device___199 *, fmode_t);
	void (*release)(struct gendisk___50 *, fmode_t);
	int (*rw_page)(struct block_device___199 *, sector_t, struct page___199 *, unsigned int);
	int (*ioctl)(struct block_device___199 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___199 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___50 *, unsigned int);
	int (*media_changed)(struct gendisk___50 *);
	void (*unlock_native_capacity)(struct gendisk___50 *);
	int (*revalidate_disk)(struct gendisk___50 *);
	int (*getgeo)(struct block_device___199 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___199 *, long unsigned int);
	int (*report_zones)(struct gendisk___50 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___168 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___49 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___50 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___50 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___50 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___49(struct request___50 *, blk_status_t);

struct request___50 {
	struct request_queue___50 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___101 *bio;
	struct bio___101 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___101 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___53 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___49 *saved_end_io;
		} flush;
	};
	struct gendisk___50 *rq_disk;
	struct hd_struct___50 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___49 *end_io;
	void *end_io_data;
	struct request___50 *next_rq;
};

struct fwnode_reference_args___125;

struct fwnode_endpoint___125;

struct fwnode_operations___125 {
	struct fwnode_handle___125 * (*get)(struct fwnode_handle___125 *);
	void (*put)(struct fwnode_handle___125 *);
	bool (*device_is_available)(const struct fwnode_handle___125 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___125 *, const struct device___179 *);
	bool (*property_present)(const struct fwnode_handle___125 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___125 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___125 *, const char *, const char **, size_t);
	struct fwnode_handle___125 * (*get_parent)(const struct fwnode_handle___125 *);
	struct fwnode_handle___125 * (*get_next_child_node)(const struct fwnode_handle___125 *, struct fwnode_handle___125 *);
	struct fwnode_handle___125 * (*get_named_child_node)(const struct fwnode_handle___125 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___125 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___125 *);
	struct fwnode_handle___125 * (*graph_get_next_endpoint)(const struct fwnode_handle___125 *, struct fwnode_handle___125 *);
	struct fwnode_handle___125 * (*graph_get_remote_endpoint)(const struct fwnode_handle___125 *);
	struct fwnode_handle___125 * (*graph_get_port_parent)(struct fwnode_handle___125 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___125 *, struct fwnode_endpoint___125 *);
};

struct fwnode_endpoint___125 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___125 *local_fwnode;
};

struct fwnode_reference_args___125 {
	struct fwnode_handle___125 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct elevator_type___49;

struct elevator_mq_ops___49 {
	int (*init_sched)(struct request_queue___50 *, struct elevator_type___49 *);
	void (*exit_sched)(struct elevator_queue___49 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	bool (*allow_merge)(struct request_queue___50 *, struct request___50 *, struct bio___101 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx *, struct bio___101 *);
	int (*request_merge)(struct request_queue___50 *, struct request___50 **, struct bio___101 *);
	void (*request_merged)(struct request_queue___50 *, struct request___50 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___50 *, struct request___50 *, struct request___50 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___50 *, struct bio___101 *);
	void (*finish_request)(struct request___50 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___50 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___50 *, u64);
	void (*started_request)(struct request___50 *);
	void (*requeue_request)(struct request___50 *);
	struct request___50 * (*former_request)(struct request_queue___50 *, struct request___50 *);
	struct request___50 * (*next_request)(struct request_queue___50 *, struct request___50 *);
	void (*init_icq)(struct io_cq___53 *);
	void (*exit_icq)(struct io_cq___53 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___49;

struct elevator_type___49 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___49 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___49 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___168 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___49 {
	struct elevator_type___49 *type;
	void *elevator_data;
	struct kobject___190 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___49 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___49 *, char *);
	ssize_t (*store)(struct elevator_queue___49 *, const char *, size_t);
};

struct blkcg_policy_data___38;

struct blkcg___38 {
	struct cgroup_subsys_state___167 css;
	spinlock_t lock;
	struct xarray blkg_tree;
	struct blkcg_gq___38 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___38 *cpd[5];
	struct list_head all_blkcgs_node;
	struct list_head cgwb_list;
	refcount_t cgwb_refcnt;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct blkcg_policy_data___38 {
	struct blkcg___38 *blkcg;
	int plid;
};

struct blkg_policy_data___38 {
	struct blkcg_gq___38 *blkg;
	int plid;
};

typedef loff_t (*iomap_actor_t)(struct inode___199 *, loff_t, loff_t, void *, struct iomap___4 *);

struct iomap_readpage_ctx {
	struct page___199 *cur_page;
	bool cur_page_in_bio;
	bool is_readahead;
	struct bio___101 *bio;
	struct list_head *pages;
};

struct fiemap_ctx {
	struct fiemap_extent_info *fi;
	struct iomap___4 prev;
};

struct iomap_dio {
	struct kiocb___199 *iocb;
	iomap_dio_end_io_t *end_io;
	loff_t i_size;
	loff_t size;
	atomic_t ref;
	unsigned int flags;
	int error;
	bool wait_for_completion;
	union {
		struct {
			struct iov_iter___97 *iter;
			struct task_struct___199 *waiter;
			struct request_queue___50 *last_queue;
			blk_qc_t cookie;
		} submit;
		struct {
			struct work_struct work;
		} aio;
	};
};

struct iomap_swapfile_info {
	struct iomap___4 iomap;
	struct swap_info_struct___63 *sis;
	uint64_t lowest_ppage;
	uint64_t highest_ppage;
	long unsigned int nr_pages;
	int nr_extents;
};

enum {
	QIF_BLIMITS_B = 0,
	QIF_SPACE_B = 1,
	QIF_ILIMITS_B = 2,
	QIF_INODES_B = 3,
	QIF_BTIME_B = 4,
	QIF_ITIME_B = 5,
};

enum {
	DQF_ROOT_SQUASH_B = 0,
	DQF_SYS_FILE_B = 16,
	DQF_PRIVATE = 17,
};

typedef __kernel_uid32_t qid_t;

enum {
	DQF_INFO_DIRTY_B = 17,
};

enum {
	DQST_LOOKUPS = 0,
	DQST_DROPS = 1,
	DQST_READS = 2,
	DQST_WRITES = 3,
	DQST_CACHE_HITS = 4,
	DQST_ALLOC_DQUOTS = 5,
	DQST_FREE_DQUOTS = 6,
	DQST_SYNCS = 7,
	_DQST_DQSTAT_LAST = 8,
};

enum {
	_DQUOT_USAGE_ENABLED = 0,
	_DQUOT_LIMITS_ENABLED = 1,
	_DQUOT_SUSPENDED = 2,
	_DQUOT_STATE_FLAGS = 3,
};

struct quota_module_name {
	int qm_fmt_id;
	char *qm_mod_name;
};

struct dquot_warn {
	struct super_block___41 *w_sb;
	struct kqid w_dq_id;
	short int w_type;
};

struct qtree_fmt_operations {
	void (*mem2disk_dqblk)(void *, struct dquot___186 *);
	void (*disk2mem_dqblk)(struct dquot___186 *, void *);
	int (*is_id)(void *, struct dquot___186 *);
};

struct qtree_mem_dqinfo {
	struct super_block___186 *dqi_sb;
	int dqi_type;
	unsigned int dqi_blocks;
	unsigned int dqi_free_blk;
	unsigned int dqi_free_entry;
	unsigned int dqi_blocksize_bits;
	unsigned int dqi_entry_size;
	unsigned int dqi_usable_bs;
	unsigned int dqi_qtree_depth;
	const struct qtree_fmt_operations *dqi_ops;
};

struct v2_disk_dqheader {
	__le32 dqh_magic;
	__le32 dqh_version;
};

struct v2r0_disk_dqblk {
	__le32 dqb_id;
	__le32 dqb_ihardlimit;
	__le32 dqb_isoftlimit;
	__le32 dqb_curinodes;
	__le32 dqb_bhardlimit;
	__le32 dqb_bsoftlimit;
	__le64 dqb_curspace;
	__le64 dqb_btime;
	__le64 dqb_itime;
};

struct v2r1_disk_dqblk {
	__le32 dqb_id;
	__le32 dqb_pad;
	__le64 dqb_ihardlimit;
	__le64 dqb_isoftlimit;
	__le64 dqb_curinodes;
	__le64 dqb_bhardlimit;
	__le64 dqb_bsoftlimit;
	__le64 dqb_curspace;
	__le64 dqb_btime;
	__le64 dqb_itime;
};

struct v2_disk_dqinfo {
	__le32 dqi_bgrace;
	__le32 dqi_igrace;
	__le32 dqi_flags;
	__le32 dqi_blocks;
	__le32 dqi_free_blk;
	__le32 dqi_free_entry;
};

struct qt_disk_dqdbheader {
	__le32 dqdh_next_free;
	__le32 dqdh_prev_free;
	__le16 dqdh_entries;
	__le16 dqdh_pad1;
	__le32 dqdh_pad2;
};

struct fs_disk_quota {
	__s8 d_version;
	__s8 d_flags;
	__u16 d_fieldmask;
	__u32 d_id;
	__u64 d_blk_hardlimit;
	__u64 d_blk_softlimit;
	__u64 d_ino_hardlimit;
	__u64 d_ino_softlimit;
	__u64 d_bcount;
	__u64 d_icount;
	__s32 d_itimer;
	__s32 d_btimer;
	__u16 d_iwarns;
	__u16 d_bwarns;
	__s32 d_padding2;
	__u64 d_rtb_hardlimit;
	__u64 d_rtb_softlimit;
	__u64 d_rtbcount;
	__s32 d_rtbtimer;
	__u16 d_rtbwarns;
	__s16 d_padding3;
	char d_padding4[8];
};

struct fs_qfilestat {
	__u64 qfs_ino;
	__u64 qfs_nblks;
	__u32 qfs_nextents;
};

typedef struct fs_qfilestat fs_qfilestat_t;

struct fs_quota_stat {
	__s8 qs_version;
	__u16 qs_flags;
	__s8 qs_pad;
	fs_qfilestat_t qs_uquota;
	fs_qfilestat_t qs_gquota;
	__u32 qs_incoredqs;
	__s32 qs_btimelimit;
	__s32 qs_itimelimit;
	__s32 qs_rtbtimelimit;
	__u16 qs_bwarnlimit;
	__u16 qs_iwarnlimit;
};

struct fs_qfilestatv {
	__u64 qfs_ino;
	__u64 qfs_nblks;
	__u32 qfs_nextents;
	__u32 qfs_pad;
};

struct fs_quota_statv {
	__s8 qs_version;
	__u8 qs_pad1;
	__u16 qs_flags;
	__u32 qs_incoredqs;
	struct fs_qfilestatv qs_uquota;
	struct fs_qfilestatv qs_gquota;
	struct fs_qfilestatv qs_pquota;
	__s32 qs_btimelimit;
	__s32 qs_itimelimit;
	__s32 qs_rtbtimelimit;
	__u16 qs_bwarnlimit;
	__u16 qs_iwarnlimit;
	__u64 qs_pad2[8];
};

struct if_dqblk {
	__u64 dqb_bhardlimit;
	__u64 dqb_bsoftlimit;
	__u64 dqb_curspace;
	__u64 dqb_ihardlimit;
	__u64 dqb_isoftlimit;
	__u64 dqb_curinodes;
	__u64 dqb_btime;
	__u64 dqb_itime;
	__u32 dqb_valid;
};

struct if_nextdqblk {
	__u64 dqb_bhardlimit;
	__u64 dqb_bsoftlimit;
	__u64 dqb_curspace;
	__u64 dqb_ihardlimit;
	__u64 dqb_isoftlimit;
	__u64 dqb_curinodes;
	__u64 dqb_btime;
	__u64 dqb_itime;
	__u32 dqb_valid;
	__u32 dqb_id;
};

struct if_dqinfo {
	__u64 dqi_bgrace;
	__u64 dqi_igrace;
	__u32 dqi_flags;
	__u32 dqi_valid;
};

enum {
	QUOTA_NL_C_UNSPEC = 0,
	QUOTA_NL_C_WARNING = 1,
	__QUOTA_NL_C_MAX = 2,
};

enum {
	QUOTA_NL_A_UNSPEC = 0,
	QUOTA_NL_A_QTYPE = 1,
	QUOTA_NL_A_EXCESS_ID = 2,
	QUOTA_NL_A_WARNING = 3,
	QUOTA_NL_A_DEV_MAJOR = 4,
	QUOTA_NL_A_DEV_MINOR = 5,
	QUOTA_NL_A_CAUSED_ID = 6,
	QUOTA_NL_A_PAD = 7,
	__QUOTA_NL_A_MAX = 8,
};

struct file___200;

struct kiocb___200;

struct vm_area_struct___200;

struct inode___200;

struct file_lock___200;

struct page___200;

struct seq_file___186;

struct file_operations___200 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___200 *, loff_t, int);
	ssize_t (*read)(struct file___200 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___200 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___200 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___200 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___200 *, bool);
	int (*iterate)(struct file___200 *, struct dir_context *);
	int (*iterate_shared)(struct file___200 *, struct dir_context *);
	__poll_t (*poll)(struct file___200 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___200 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___200 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___200 *, struct vm_area_struct___200 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___200 *, struct file___200 *);
	int (*flush)(struct file___200 *, fl_owner_t);
	int (*release)(struct inode___200 *, struct file___200 *);
	int (*fsync)(struct file___200 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___200 *, int);
	int (*lock)(struct file___200 *, int, struct file_lock___200 *);
	ssize_t (*sendpage)(struct file___200 *, struct page___200 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___200 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___200 *, int, struct file_lock___200 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___200 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___200 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___200 *, long int, struct file_lock___200 **, void **);
	long int (*fallocate)(struct file___200 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___186 *, struct file___200 *);
	ssize_t (*copy_file_range)(struct file___200 *, loff_t, struct file___200 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___200 *, loff_t, struct file___200 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___200 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___199 {
	u64 seqnum;
	struct vm_area_struct___200 *vmas[4];
};

struct page_frag___199 {
	struct page___200 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___199;

struct mem_cgroup___91;

struct pid___158;

struct cred___194;

struct nsproxy___189;

struct signal_struct___176;

struct bio_list___102;

struct backing_dev_info___102;

struct css_set___167;

struct task_struct___200 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___200 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___199 *mm;
	struct mm_struct___199 *active_mm;
	struct vmacache___199 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___200 *real_parent;
	struct task_struct___200 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___200 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___91 *active_memcg;
	long int rh_reserved2;
	struct pid___158 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___158 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___158 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___194 *ptracer_cred;
	const struct cred___194 *real_cred;
	const struct cred___194 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___189 *nsproxy;
	struct signal_struct___176 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___200 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___102 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___102 *backing_dev_info;
	struct io_context___53 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___167 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___199 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___91 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___200 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___120 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___200 *pgtable_t___199;

struct address_space___199;

struct dev_pagemap___196;

struct page___200 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___199 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___200 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___199 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___199 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___196 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___91 *mem_cgroup;
};

struct pglist_data___199;

struct lruvec___199 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___199 *pgdat;
};

struct zone___199 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___199 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___199 {
	struct zone___199 *zone;
	int zone_idx;
};

struct zonelist___199 {
	struct zoneref___199 _zonerefs[25];
};

struct pglist_data___199 {
	struct zone___199 node_zones[3];
	struct zonelist___199 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___200 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___200 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___199 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___200 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___200 *owner;
};

struct secondary_data___200 {
	void *stack;
	struct task_struct___200 *task;
	long int status;
};

struct blocking_notifier_head___199 {
	struct rw_semaphore___200 rwsem;
	struct notifier_block *head;
};

struct anon_vma___20;

struct vm_operations_struct___196;

struct vm_area_struct___200 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___200 *vm_next;
	struct vm_area_struct___200 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___199 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma___20 *anon_vma;
	const struct vm_operations_struct___196 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___200 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct linux_binfmt___21;

struct core_state___199;

struct user_namespace___176;

struct mm_struct___199 {
	struct {
		struct vm_area_struct___200 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___200 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___200 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___21 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___199 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___200 *owner;
		struct user_namespace___176 *user_ns;
		struct file___200 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___199 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___199;

struct address_space___199 {
	struct inode___200 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___200 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___199 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___196)(struct vm_area_struct___200 *, long unsigned int, const struct page___200 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___196)(struct page___200 *, void *);

struct device___180;

struct dev_pagemap___196 {
	dev_page_fault_t___196 page_fault;
	dev_page_free_t___196 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___180 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct cgroup___167;

struct cgroup_subsys___167;

struct cgroup_subsys_state___168 {
	struct cgroup___167 *cgroup;
	struct cgroup_subsys___167 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___168 *parent;
};

struct kernfs_node___194;

struct cgroup_file___167 {
	struct kernfs_node___194 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___91;

struct mem_cgroup___91 {
	struct cgroup_subsys_state___168 css;
	struct mem_cgroup_id___8 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___167 events_file;
	struct cgroup_file___167 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___200 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___91 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct vfsmount___43;

struct dentry___199;

struct path___199 {
	struct vfsmount___43 *mnt;
	struct dentry___199 *dentry;
};

struct fown_struct___158 {
	rwlock_t lock;
	struct pid___158 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___200 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___199 f_path;
	struct inode___200 *f_inode;
	const struct file_operations___200 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___158 f_owner;
	const struct cred___194 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___199 *f_mapping;
	errseq_t f_wb_err;
};

struct anon_vma___20 {
	struct anon_vma___20 *root;
	struct rw_semaphore___200 rwsem;
	atomic_t refcount;
	unsigned int degree;
	struct anon_vma___20 *parent;
	struct rb_root_cached rb_root;
};

struct vm_fault___196;

struct vm_operations_struct___196 {
	void (*open)(struct vm_area_struct___200 *);
	void (*close)(struct vm_area_struct___200 *);
	int (*split)(struct vm_area_struct___200 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___200 *);
	vm_fault_t (*fault)(struct vm_fault___196 *);
	vm_fault_t (*huge_fault)(struct vm_fault___196 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___196 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___200 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___196 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___196 *);
	int (*access)(struct vm_area_struct___200 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___200 *);
	int (*set_policy)(struct vm_area_struct___200 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___200 *, long unsigned int);
	struct page___200 * (*find_special_page)(struct vm_area_struct___200 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___199 {
	struct task_struct___200 *task;
	struct core_thread___199 *next;
};

struct core_state___199 {
	atomic_t nr_threads;
	struct core_thread___199 dumper;
	struct completion startup;
};

struct linux_binprm___22;

struct coredump_params___21;

struct linux_binfmt___21 {
	struct list_head lh;
	struct module___11 *module;
	int (*load_binary)(struct linux_binprm___22 *);
	int (*load_shlib)(struct file___200 *);
	int (*core_dump)(struct coredump_params___21 *);
	long unsigned int min_coredump;
};

struct proc_ns_operations___12;

struct ns_common___12 {
	atomic_long_t stashed;
	const struct proc_ns_operations___12 *ops;
	unsigned int inum;
};

struct key___194;

struct ucounts___176;

struct user_namespace___176 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___176 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___12 ns;
	long unsigned int flags;
	struct key___194 *persistent_keyring_register;
	struct rw_semaphore___200 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___176 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___196 {
	struct vm_area_struct___200 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___200 *cow_page;
	struct mem_cgroup___91 *memcg;
	struct page___200 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___199 prealloc_pte;
};

struct shrink_control___91 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___91 *memcg;
};

struct shrinker___91 {
	long unsigned int (*count_objects)(struct shrinker___91 *, struct shrink_control___91 *);
	long unsigned int (*scan_objects)(struct shrinker___91 *, struct shrink_control___91 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct pid_namespace___158;

struct upid___158 {
	int nr;
	struct pid_namespace___158 *ns;
};

struct pid_namespace___158 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___200 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___158 *parent;
	struct vfsmount___43 *proc_mnt;
	struct dentry___199 *proc_self;
	struct dentry___199 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___176 *user_ns;
	struct ucounts___176 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___12 ns;
};

struct pid___158 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___158 numbers[1];
};

struct user_struct___194 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___194 *uid_keyring;
	struct key___194 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___194 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___194 *session_keyring;
	struct key___194 *process_keyring;
	struct key___194 *thread_keyring;
	struct key___194 *request_key_auth;
	void *security;
	struct user_struct___194 *user;
	struct user_namespace___176 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___167;

struct nsproxy___189 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___158 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___167 *cgroup_ns;
};

struct signal_struct___176 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___200 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___200 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___158 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___158 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___199 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___158 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___102;

struct bio_list___102 {
	struct bio___102 *head;
	struct bio___102 *tail;
};

struct bdi_writeback_congested___102;

struct bdi_writeback___102 {
	struct backing_dev_info___102 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___102 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___168 *memcg_css;
	struct cgroup_subsys_state___168 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___102 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___102 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___180 *dev;
	struct device___180 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___199 *debug_dir;
	struct dentry___199 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___167 {
	struct cgroup_subsys_state___168 *subsys[13];
	refcount_t refcount;
	struct css_set___167 *dom_cset;
	struct cgroup___167 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___167 *mg_src_cgrp;
	struct cgroup___167 *mg_dst_cgrp;
	struct css_set___167 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

union thread_union___178 {
	struct task_struct___200 task;
	long unsigned int stack[8192];
};

struct kset___190;

struct kobj_type___190;

struct kobject___191 {
	const char *name;
	struct list_head entry;
	struct kobject___191 *parent;
	struct kset___190 *kset;
	struct kobj_type___190 *ktype;
	struct kernfs_node___194 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___180 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___180 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___180;

struct bus_type___180;

struct device_driver___180;

struct dev_pm_domain___180;

struct class___180;

struct attribute_group___182;

struct device___180 {
	struct device___180 *parent;
	struct device_private *p;
	struct kobject___191 kobj;
	const char *init_name;
	const struct device_type___180 *type;
	struct mutex mutex;
	struct bus_type___180 *bus;
	struct device_driver___180 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___180 power;
	struct dev_pm_domain___180 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___180 *class;
	const struct attribute_group___182 **groups;
	void (*release)(struct device___180 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___199;

struct super_block___199;

struct dentry___199 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___199 *d_parent;
	struct qstr d_name;
	struct inode___200 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___199 *d_op;
	struct super_block___199 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___199;

struct block_device___200;

struct inode___200 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___199 *i_op;
	struct super_block___199 *i_sb;
	struct address_space___199 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___200 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___102 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___200 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___199 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___200 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___199 {
	int (*d_revalidate)(struct dentry___199 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___199 *, unsigned int);
	int (*d_hash)(const struct dentry___199 *, struct qstr *);
	int (*d_compare)(const struct dentry___199 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___199 *);
	int (*d_init)(struct dentry___199 *);
	void (*d_release)(struct dentry___199 *);
	void (*d_prune)(struct dentry___199 *);
	void (*d_iput)(struct dentry___199 *, struct inode___200 *);
	char * (*d_dname)(struct dentry___199 *, char *, int);
	struct vfsmount___43 * (*d_automount)(struct path___199 *);
	int (*d_manage)(const struct path___199 *, bool);
	struct dentry___199 * (*d_real)(struct dentry___199 *, const struct inode___200 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___199;

struct mem_dqinfo___199 {
	struct quota_format_type___199 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___199;

struct quota_info___199 {
	unsigned int flags;
	struct rw_semaphore___200 dqio_sem;
	struct inode___200 *files[3];
	struct mem_dqinfo___199 info[3];
	const struct quota_format_ops___199 *ops[3];
};

struct rcuwait___199 {
	struct task_struct___200 *task;
};

struct percpu_rw_semaphore___199 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___200 rw_sem;
	struct rcuwait___199 writer;
	int readers_block;
};

struct sb_writers___199 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___199 rw_sem[3];
};

struct file_system_type___199;

struct super_operations___199;

struct dquot_operations___199;

struct quotactl_ops___199;

struct xattr_handler___18;

struct super_block___199 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___199 *s_type;
	const struct super_operations___199 *s_op;
	const struct dquot_operations___199 *dq_op;
	const struct quotactl_ops___199 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___199 *s_root;
	struct rw_semaphore___200 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___18 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___200 *s_bdev;
	struct backing_dev_info___102 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___199 s_dquot;
	struct sb_writers___199 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___199 *s_d_op;
	int cleancache_poolid;
	struct shrinker___91 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___176 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___43 {
	struct dentry___199 *mnt_root;
	struct super_block___199 *mnt_sb;
	int mnt_flags;
};

struct kiocb___200 {
	struct file___200 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___200 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___199 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___200 *ia_file;
};

struct dquot___199 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___199 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___199 {
	int qf_fmt_id;
	const struct quota_format_ops___199 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___199 *qf_next;
};

struct quota_format_ops___199 {
	int (*check_quota_file)(struct super_block___199 *, int);
	int (*read_file_info)(struct super_block___199 *, int);
	int (*write_file_info)(struct super_block___199 *, int);
	int (*free_file_info)(struct super_block___199 *, int);
	int (*read_dqblk)(struct dquot___199 *);
	int (*commit_dqblk)(struct dquot___199 *);
	int (*release_dqblk)(struct dquot___199 *);
	int (*get_next_id)(struct super_block___199 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___199 {
	int (*write_dquot)(struct dquot___199 *);
	struct dquot___199 * (*alloc_dquot)(struct super_block___199 *, int);
	void (*destroy_dquot)(struct dquot___199 *);
	int (*acquire_dquot)(struct dquot___199 *);
	int (*release_dquot)(struct dquot___199 *);
	int (*mark_dirty)(struct dquot___199 *);
	int (*write_info)(struct super_block___199 *, int);
	qsize_t * (*get_reserved_space)(struct inode___200 *);
	int (*get_projid)(struct inode___200 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___200 *, qsize_t *);
	int (*get_next_id)(struct super_block___199 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___199 {
	int (*quota_on)(struct super_block___199 *, int, int, const struct path___199 *);
	int (*quota_off)(struct super_block___199 *, int);
	int (*quota_enable)(struct super_block___199 *, unsigned int);
	int (*quota_disable)(struct super_block___199 *, unsigned int);
	int (*quota_sync)(struct super_block___199 *, int);
	int (*set_info)(struct super_block___199 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___199 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___199 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___199 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___199 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___199 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___98;

struct swap_info_struct___64;

struct address_space_operations___199 {
	int (*writepage)(struct page___200 *, struct writeback_control___98 *);
	int (*readpage)(struct file___200 *, struct page___200 *);
	int (*writepages)(struct address_space___199 *, struct writeback_control___98 *);
	int (*set_page_dirty)(struct page___200 *);
	int (*readpages)(struct file___200 *, struct address_space___199 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___200 *, struct address_space___199 *, loff_t, unsigned int, unsigned int, struct page___200 **, void **);
	int (*write_end)(struct file___200 *, struct address_space___199 *, loff_t, unsigned int, unsigned int, struct page___200 *, void *);
	sector_t (*bmap)(struct address_space___199 *, sector_t);
	void (*invalidatepage)(struct page___200 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___200 *, gfp_t);
	void (*freepage)(struct page___200 *);
	ssize_t (*direct_IO)(struct kiocb___200 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___199 *, struct page___200 *, struct page___200 *, enum migrate_mode);
	bool (*isolate_page)(struct page___200 *, isolate_mode_t);
	void (*putback_page)(struct page___200 *);
	int (*launder_page)(struct page___200 *);
	int (*is_partially_uptodate)(struct page___200 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___200 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___199 *, struct page___200 *);
	int (*swap_activate)(struct swap_info_struct___64 *, struct file___200 *, sector_t *);
	void (*swap_deactivate)(struct file___200 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___98 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___102 *wb;
	struct inode___200 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct swap_info_struct___64 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___200 *bdev;
	struct file___200 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___200 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___200 *bd_inode;
	struct super_block___199 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___200 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___102 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___199 {
	struct dentry___199 * (*lookup)(struct inode___200 *, struct dentry___199 *, unsigned int);
	const char * (*get_link)(struct dentry___199 *, struct inode___200 *, struct delayed_call *);
	int (*permission)(struct inode___200 *, int);
	struct posix_acl * (*get_acl)(struct inode___200 *, int);
	int (*readlink)(struct dentry___199 *, char *, int);
	int (*create)(struct inode___200 *, struct dentry___199 *, umode_t, bool);
	int (*link)(struct dentry___199 *, struct inode___200 *, struct dentry___199 *);
	int (*unlink)(struct inode___200 *, struct dentry___199 *);
	int (*symlink)(struct inode___200 *, struct dentry___199 *, const char *);
	int (*mkdir)(struct inode___200 *, struct dentry___199 *, umode_t);
	int (*rmdir)(struct inode___200 *, struct dentry___199 *);
	int (*mknod)(struct inode___200 *, struct dentry___199 *, umode_t, dev_t);
	int (*rename)(struct inode___200 *, struct dentry___199 *, struct inode___200 *, struct dentry___199 *, unsigned int);
	int (*setattr)(struct dentry___199 *, struct iattr___199 *);
	int (*getattr)(const struct path___199 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___199 *, char *, size_t);
	int (*fiemap)(struct inode___200 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___200 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___200 *, struct dentry___199 *, struct file___200 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___200 *, struct dentry___199 *, umode_t);
	int (*set_acl)(struct inode___200 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___199 {
	void (*fl_copy_lock)(struct file_lock___200 *, struct file_lock___200 *);
	void (*fl_release_private)(struct file_lock___200 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___199;

struct lock_manager_operations___199;

struct file_lock___200 {
	struct file_lock___200 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___200 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___199 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___199 *fl_ops;
	const struct lock_manager_operations___199 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___199 {
	int (*lm_compare_owner)(struct file_lock___200 *, struct file_lock___200 *);
	long unsigned int (*lm_owner_key)(struct file_lock___200 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___200 *);
	int (*lm_grant)(struct file_lock___200 *, int);
	bool (*lm_break)(struct file_lock___200 *);
	int (*lm_change)(struct file_lock___200 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___200 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___199 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___199 *fa_next;
	struct file___200 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___199 {
	const char *name;
	int fs_flags;
	struct dentry___199 * (*mount)(struct file_system_type___199 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___199 *);
	struct module___11 *owner;
	struct file_system_type___199 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___199 {
	struct inode___200 * (*alloc_inode)(struct super_block___199 *);
	void (*destroy_inode)(struct inode___200 *);
	void (*dirty_inode)(struct inode___200 *, int);
	int (*write_inode)(struct inode___200 *, struct writeback_control___98 *);
	int (*drop_inode)(struct inode___200 *);
	void (*evict_inode)(struct inode___200 *);
	void (*put_super)(struct super_block___199 *);
	int (*sync_fs)(struct super_block___199 *, int);
	int (*freeze_super)(struct super_block___199 *);
	int (*freeze_fs)(struct super_block___199 *);
	int (*thaw_super)(struct super_block___199 *);
	int (*unfreeze_fs)(struct super_block___199 *);
	int (*statfs)(struct dentry___199 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___199 *, int *, char *);
	void (*umount_begin)(struct super_block___199 *);
	int (*show_options)(struct seq_file___186 *, struct dentry___199 *);
	int (*show_devname)(struct seq_file___186 *, struct dentry___199 *);
	int (*show_path)(struct seq_file___186 *, struct dentry___199 *);
	int (*show_stats)(struct seq_file___186 *, struct dentry___199 *);
	ssize_t (*quota_read)(struct super_block___199 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___199 *, int, const char *, size_t, loff_t);
	struct dquot___199 ** (*get_dquots)(struct inode___200 *);
	int (*bdev_try_to_free_page)(struct super_block___199 *, struct page___200 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___199 *, struct shrink_control___91 *);
	long int (*free_cached_objects)(struct super_block___199 *, struct shrink_control___91 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct xattr_handler___18 {
	const char *name;
	const char *prefix;
	int flags;
	bool (*list)(struct dentry___199 *);
	int (*get)(const struct xattr_handler___18 *, struct dentry___199 *, struct inode___200 *, const char *, void *, size_t);
	int (*set)(const struct xattr_handler___18 *, struct dentry___199 *, struct inode___200 *, const char *, const void *, size_t, int);
};

struct seq_operations___184;

struct seq_file___186 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___184 *op;
	int poll_event;
	const struct file___200 *file;
	void *private;
};

typedef void bio_end_io_t___102(struct bio___102 *);

struct bio_vec___102 {
	struct page___200 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___102;

struct bio_set___102;

struct bio___102 {
	struct bio___102 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___102 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___102 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___102 *bi_io_vec;
	struct bio_set___102 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___102 bi_inline_vecs[0];
};

struct kobj_attribute___190 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___191 *, struct kobj_attribute___190 *, char *);
	ssize_t (*store)(struct kobject___191 *, struct kobj_attribute___190 *, const char *, size_t);
};

typedef void compound_page_dtor___196(struct page___200 *);

struct mm_walk___6 {
	int (*pud_entry)(pud_t *, long unsigned int, long unsigned int, struct mm_walk___6 *);
	int (*pmd_entry)(pmd_t *, long unsigned int, long unsigned int, struct mm_walk___6 *);
	int (*pte_entry)(pte_t *, long unsigned int, long unsigned int, struct mm_walk___6 *);
	int (*pte_hole)(long unsigned int, long unsigned int, struct mm_walk___6 *);
	int (*hugetlb_entry)(pte_t *, long unsigned int, long unsigned int, long unsigned int, struct mm_walk___6 *);
	int (*test_walk)(long unsigned int, long unsigned int, struct mm_walk___6 *);
	struct mm_struct___199 *mm;
	struct vm_area_struct___200 *vma;
	void *private;
};

typedef int (*key_restrict_link_func_t___194)(struct key___194 *, const struct key_type *, const union key_payload *, struct key___194 *);

struct key_restriction___194;

struct key___194 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___200 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___194 *restrict_link;
};

struct key_restriction___194 {
	key_restrict_link_func_t___194 check;
	struct key___194 *key;
	struct key_type *keytype;
};

struct seq_operations___184 {
	void * (*start)(struct seq_file___186 *, loff_t *);
	void (*stop)(struct seq_file___186 *, void *);
	void * (*next)(struct seq_file___186 *, void *, loff_t *);
	int (*show)(struct seq_file___186 *, void *);
};

struct kernfs_root___194;

struct kernfs_elem_dir___194 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___194 *root;
};

struct kernfs_syscall_ops___194;

struct kernfs_root___194 {
	struct kernfs_node___194 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___194 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___194 {
	struct kernfs_node___194 *target_kn;
};

struct kernfs_ops___194;

struct kernfs_elem_attr___194 {
	const struct kernfs_ops___194 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___194 *notify_next;
};

struct kernfs_node___194 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___194 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___194 dir;
		struct kernfs_elem_symlink___194 symlink;
		struct kernfs_elem_attr___194 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___194;

struct kernfs_ops___194 {
	int (*open)(struct kernfs_open_file___194 *);
	void (*release)(struct kernfs_open_file___194 *);
	int (*seq_show)(struct seq_file___186 *, void *);
	void * (*seq_start)(struct seq_file___186 *, loff_t *);
	void * (*seq_next)(struct seq_file___186 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___186 *, void *);
	ssize_t (*read)(struct kernfs_open_file___194 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___194 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___194 *, struct vm_area_struct___200 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___194 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___194 {
	int (*remount_fs)(struct kernfs_root___194 *, int *, char *);
	int (*show_options)(struct seq_file___186 *, struct kernfs_root___194 *);
	int (*mkdir)(struct kernfs_node___194 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___194 *);
	int (*rename)(struct kernfs_node___194 *, struct kernfs_node___194 *, const char *);
	int (*show_path)(struct seq_file___186 *, struct kernfs_node___194 *, struct kernfs_root___194 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___194 {
	struct kernfs_node___194 *kn;
	struct file___200 *file;
	struct seq_file___186 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___196 *vm_ops;
};

struct proc_ns_operations___12 {
	const char *name;
	const char *real_ns_name;
	int type;
	struct ns_common___12 * (*get)(struct task_struct___200 *);
	void (*put)(struct ns_common___12 *);
	int (*install)(struct nsproxy___189 *, struct ns_common___12 *);
	struct user_namespace___176 * (*owner)(struct ns_common___12 *);
	struct ns_common___12 * (*get_parent)(struct ns_common___12 *);
};

struct cgroup_namespace___167 {
	refcount_t count;
	struct ns_common___12 ns;
	struct user_namespace___176 *user_ns;
	struct ucounts___176 *ucounts;
	struct css_set___167 *root_cset;
};

struct ucounts___176 {
	struct hlist_node node;
	struct user_namespace___176 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

typedef int (*proc_write_t___2)(struct file___200 *, char *, size_t);

struct proc_dir_entry___3 {
	atomic_t in_use;
	refcount_t refcnt;
	struct list_head pde_openers;
	spinlock_t pde_unload_lock;
	struct completion *pde_unload_completion;
	const struct inode_operations___199 *proc_iops;
	const struct file_operations___200 *proc_fops;
	union {
		const struct seq_operations___184 *seq_ops;
		int (*single_show)(struct seq_file___186 *, void *);
	};
	proc_write_t___2 write;
	void *data;
	unsigned int state_size;
	unsigned int low_ino;
	nlink_t nlink;
	kuid_t uid;
	kgid_t gid;
	loff_t size;
	struct proc_dir_entry___3 *parent;
	struct rb_root subdir;
	struct rb_node subdir_node;
	char *name;
	umode_t mode;
	u8 namelen;
	char inline_name[0];
};

struct bpf_map___167;

struct bpf_map_ops___167 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___167 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___167 *, struct file___200 *);
	void (*map_free)(struct bpf_map___167 *);
	int (*map_get_next_key)(struct bpf_map___167 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___167 *);
	void * (*map_lookup_elem)(struct bpf_map___167 *, void *);
	int (*map_update_elem)(struct bpf_map___167 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___167 *, void *);
	int (*map_push_elem)(struct bpf_map___167 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___167 *, void *);
	int (*map_peek_elem)(struct bpf_map___167 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___167 *, struct file___200 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___167 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___167 *, void *, struct seq_file___186 *);
	int (*map_check_btf)(const struct bpf_map___167 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___167 {
	const struct bpf_map_ops___167 *ops;
	struct bpf_map___167 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___194 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___167;

typedef void (*kthread_work_func_t___167)(struct kthread_work___167 *);

struct kthread_worker___167;

struct kthread_work___167 {
	struct list_head node;
	kthread_work_func_t___167 func;
	struct kthread_worker___167 *worker;
	int canceling;
};

struct kthread_worker___167 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___200 *task;
	struct kthread_work___167 *current_work;
};

struct kthread_delayed_work___167 {
	struct kthread_work___167 work;
	struct timer_list timer;
};

struct psi_group___167 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___167 *poll_kworker;
	struct kthread_delayed_work___167 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___167;

struct cgroup_rstat_cpu___167;

struct cgroup___167 {
	struct cgroup_subsys_state___168 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___194 *kn;
	struct cgroup_file___167 procs_file;
	struct cgroup_file___167 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___168 *subsys[13];
	struct cgroup_root___167 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___167 *dom_cgrp;
	struct cgroup_rstat_cpu___167 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___22 bpf;
	atomic_t congestion_count;
	struct cgroup___167 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___167 psi;
	int ancestor_ids[0];
};

struct cftype___167;

struct cgroup_subsys___167 {
	struct cgroup_subsys_state___168 * (*css_alloc)(struct cgroup_subsys_state___168 *);
	int (*css_online)(struct cgroup_subsys_state___168 *);
	void (*css_offline)(struct cgroup_subsys_state___168 *);
	void (*css_released)(struct cgroup_subsys_state___168 *);
	void (*css_free)(struct cgroup_subsys_state___168 *);
	void (*css_reset)(struct cgroup_subsys_state___168 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___168 *, int);
	int (*css_extra_stat_show)(struct seq_file___186 *, struct cgroup_subsys_state___168 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___200 *);
	void (*cancel_fork)(struct task_struct___200 *);
	void (*fork)(struct task_struct___200 *);
	void (*exit)(struct task_struct___200 *);
	void (*free)(struct task_struct___200 *);
	void (*bind)(struct cgroup_subsys_state___168 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___167 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___167 *dfl_cftypes;
	struct cftype___167 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___167 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___167 *updated_children;
	struct cgroup___167 *updated_next;
};

struct cgroup_root___167 {
	struct kernfs_root___194 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___167 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___167 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___167 *ss;
	struct list_head node;
	struct kernfs_ops___194 *kf_ops;
	int (*open)(struct kernfs_open_file___194 *);
	void (*release)(struct kernfs_open_file___194 *);
	u64 (*read_u64)(struct cgroup_subsys_state___168 *, struct cftype___167 *);
	s64 (*read_s64)(struct cgroup_subsys_state___168 *, struct cftype___167 *);
	int (*seq_show)(struct seq_file___186 *, void *);
	void * (*seq_start)(struct seq_file___186 *, loff_t *);
	void * (*seq_next)(struct seq_file___186 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___186 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___168 *, struct cftype___167 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___168 *, struct cftype___167 *, s64);
	ssize_t (*write)(struct kernfs_open_file___194 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___194 *, struct poll_table_struct___6 *);
};

struct bin_attribute___181;

struct attribute_group___182 {
	const char *name;
	umode_t (*is_visible)(struct kobject___191 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___191 *, struct bin_attribute___181 *, int);
	struct attribute **attrs;
	struct bin_attribute___181 **bin_attrs;
};

struct hstate___37;

struct hugepage_subpool___8 {
	spinlock_t lock;
	long int count;
	long int max_hpages;
	long int used_hpages;
	struct hstate___37 *hstate;
	long int min_hpages;
	long int rsv_hpages;
};

struct hstate___37 {
	int next_nid_to_alloc;
	int next_nid_to_free;
	unsigned int order;
	long unsigned int mask;
	long unsigned int max_huge_pages;
	long unsigned int nr_huge_pages;
	long unsigned int free_huge_pages;
	long unsigned int resv_huge_pages;
	long unsigned int surplus_huge_pages;
	long unsigned int nr_overcommit_huge_pages;
	struct list_head hugepage_activelist;
	struct list_head hugepage_freelists[8];
	unsigned int nr_huge_pages_node[8];
	unsigned int free_huge_pages_node[8];
	unsigned int surplus_huge_pages_node[8];
	struct cftype___167 cgroup_files[5];
	char name[32];
};

struct hugetlbfs_sb_info___8 {
	long int max_inodes;
	long int free_inodes;
	spinlock_t stat_lock;
	struct hstate___37 *hstate;
	struct hugepage_subpool___8 *spool;
	kuid_t uid;
	kgid_t gid;
	umode_t mode;
};

struct bdi_writeback_congested___102 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___102 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___102 {
	struct bio___102 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___102 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___102 bip_inline_vecs[0];
};

struct bio_set___102 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___102 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___91 {
	struct mem_cgroup___91 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___91 {
	struct lruvec___199 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___91 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___91 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct bin_attribute___181 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___200 *, struct kobject___191 *, struct bin_attribute___181 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___200 *, struct kobject___191 *, struct bin_attribute___181 *, char *, loff_t, size_t);
	int (*mmap)(struct file___200 *, struct kobject___191 *, struct bin_attribute___181 *, struct vm_area_struct___200 *);
};

struct sysfs_ops___190 {
	ssize_t (*show)(struct kobject___191 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___191 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___190;

struct kset___190 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___191 kobj;
	const struct kset_uevent_ops___190 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___190 {
	void (*release)(struct kobject___191 *);
	const struct sysfs_ops___190 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___12 * (*child_ns_type)(struct kobject___191 *);
	const void * (*namespace)(struct kobject___191 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___190 {
	int (* const filter)(struct kset___190 *, struct kobject___191 *);
	const char * (* const name)(struct kset___190 *, struct kobject___191 *);
	int (* const uevent)(struct kset___190 *, struct kobject___191 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___180 {
	int (*prepare)(struct device___180 *);
	void (*complete)(struct device___180 *);
	int (*suspend)(struct device___180 *);
	int (*resume)(struct device___180 *);
	int (*freeze)(struct device___180 *);
	int (*thaw)(struct device___180 *);
	int (*poweroff)(struct device___180 *);
	int (*restore)(struct device___180 *);
	int (*suspend_late)(struct device___180 *);
	int (*resume_early)(struct device___180 *);
	int (*freeze_late)(struct device___180 *);
	int (*thaw_early)(struct device___180 *);
	int (*poweroff_late)(struct device___180 *);
	int (*restore_early)(struct device___180 *);
	int (*suspend_noirq)(struct device___180 *);
	int (*resume_noirq)(struct device___180 *);
	int (*freeze_noirq)(struct device___180 *);
	int (*thaw_noirq)(struct device___180 *);
	int (*poweroff_noirq)(struct device___180 *);
	int (*restore_noirq)(struct device___180 *);
	int (*runtime_suspend)(struct device___180 *);
	int (*runtime_resume)(struct device___180 *);
	int (*runtime_idle)(struct device___180 *);
};

struct dev_pm_domain___180 {
	struct dev_pm_ops___180 ops;
	void (*detach)(struct device___180 *, bool);
	int (*activate)(struct device___180 *);
	void (*sync)(struct device___180 *);
	void (*dismiss)(struct device___180 *);
};

struct bus_type___180 {
	const char *name;
	const char *dev_name;
	struct device___180 *dev_root;
	const struct attribute_group___182 **bus_groups;
	const struct attribute_group___182 **dev_groups;
	const struct attribute_group___182 **drv_groups;
	int (*match)(struct device___180 *, struct device_driver___180 *);
	int (*uevent)(struct device___180 *, struct kobj_uevent_env *);
	int (*probe)(struct device___180 *);
	int (*remove)(struct device___180 *);
	void (*shutdown)(struct device___180 *);
	int (*online)(struct device___180 *);
	int (*offline)(struct device___180 *);
	int (*suspend)(struct device___180 *, pm_message_t);
	int (*resume)(struct device___180 *);
	int (*num_vf)(struct device___180 *);
	int (*dma_configure)(struct device___180 *);
	const struct dev_pm_ops___180 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___180 {
	const char *name;
	struct bus_type___180 *bus;
	struct module___11 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___180 *);
	int (*remove)(struct device___180 *);
	void (*shutdown)(struct device___180 *);
	int (*suspend)(struct device___180 *, pm_message_t);
	int (*resume)(struct device___180 *);
	const struct attribute_group___182 **groups;
	const struct dev_pm_ops___180 *pm;
	void (*coredump)(struct device___180 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___180 {
	const char *name;
	const struct attribute_group___182 **groups;
	int (*uevent)(struct device___180 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___180 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___180 *);
	const struct dev_pm_ops___180 *pm;
};

struct class___180 {
	const char *name;
	struct module___11 *owner;
	const struct attribute_group___182 **class_groups;
	const struct attribute_group___182 **dev_groups;
	struct kobject___191 *dev_kobj;
	int (*dev_uevent)(struct device___180 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___180 *, umode_t *);
	void (*class_release)(struct class___180 *);
	void (*dev_release)(struct device___180 *);
	int (*shutdown_pre)(struct device___180 *);
	const struct kobj_ns_type_operations___12 *ns_type;
	const void * (*namespace)(struct device___180 *);
	const struct dev_pm_ops___180 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___155 {
	struct device___180 dev;
};

struct mmu_gather_batch___8 {
	struct mmu_gather_batch___8 *next;
	unsigned int nr;
	unsigned int max;
	struct page___200 *pages[0];
};

struct mmu_gather___8 {
	struct mm_struct___199 *mm;
	struct mmu_table_batch *batch;
	long unsigned int start;
	long unsigned int end;
	unsigned int fullmm: 1;
	unsigned int need_flush_all: 1;
	struct mmu_gather_batch___8 *active;
	struct mmu_gather_batch___8 local;
	struct page___200 *__pages[8];
	unsigned int batch_count;
	int page_size;
};

struct linux_binprm___22 {
	char buf[256];
	struct vm_area_struct___200 *vma;
	long unsigned int vma_pages;
	struct mm_struct___199 *mm;
	long unsigned int p;
	unsigned int called_set_creds: 1;
	unsigned int cap_elevated: 1;
	unsigned int secureexec: 1;
	unsigned int recursion_depth;
	struct file___200 *file;
	struct cred___194 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
};

struct coredump_params___21 {
	union {
		const kernel_siginfo_t *siginfo;
		struct {
			const siginfo_t *siginfo;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	struct pt_regs *regs;
	struct file___200 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
};

union proc_op___2 {
	int (*proc_get_link)(struct dentry___199 *, struct path___199 *);
	int (*proc_show)(struct seq_file___186 *, struct pid_namespace___158 *, struct pid___158 *, struct task_struct___200 *);
};

struct proc_inode___2 {
	struct pid___158 *pid;
	unsigned int fd;
	union proc_op___2 op;
	struct proc_dir_entry___3 *pde;
	struct ctl_table_header *sysctl;
	struct ctl_table *sysctl_entry;
	struct hlist_node sysctl_inodes;
	const struct proc_ns_operations___12 *ns_ops;
	struct inode___200 vfs_inode;
};

struct mem_size_stats;

struct proc_maps_private {
	struct inode___200 *inode;
	struct task_struct___200 *task;
	struct mm_struct___199 *mm;
	struct mem_size_stats *rollup;
	struct vm_area_struct___200 *tail_vma;
	struct mempolicy *task_mempolicy;
};

struct mem_size_stats {
	bool first;
	long unsigned int resident;
	long unsigned int shared_clean;
	long unsigned int shared_dirty;
	long unsigned int private_clean;
	long unsigned int private_dirty;
	long unsigned int referenced;
	long unsigned int anonymous;
	long unsigned int lazyfree;
	long unsigned int anonymous_thp;
	long unsigned int shmem_thp;
	long unsigned int swap;
	long unsigned int shared_hugetlb;
	long unsigned int private_hugetlb;
	long unsigned int first_vma_start;
	u64 pss;
	u64 pss_locked;
	u64 swap_pss;
	bool check_shmem_swap;
};

enum clear_refs_types {
	CLEAR_REFS_ALL = 1,
	CLEAR_REFS_ANON = 2,
	CLEAR_REFS_MAPPED = 3,
	CLEAR_REFS_SOFT_DIRTY = 4,
	CLEAR_REFS_MM_HIWATER_RSS = 5,
	CLEAR_REFS_LAST = 6,
};

struct clear_refs_private {
	enum clear_refs_types type;
};

typedef struct {
	u64 pme;
} pagemap_entry_t;

struct pagemapread {
	int pos;
	int len;
	pagemap_entry_t *buffer;
	bool show_pfn;
};

struct numa_maps {
	long unsigned int pages;
	long unsigned int anon;
	long unsigned int active;
	long unsigned int writeback;
	long unsigned int mapcount_max;
	long unsigned int dirty;
	long unsigned int swapcache;
	long unsigned int node[8];
};

struct numa_maps_private {
	struct proc_maps_private proc_maps;
	struct numa_maps md;
};

struct module___169;

struct file___201;

struct kiocb___201;

struct poll_table_struct___136;

struct vm_area_struct___201;

struct inode___201;

struct file_lock___201;

struct page___201;

struct file_operations___201 {
	struct module___169 *owner;
	loff_t (*llseek)(struct file___201 *, loff_t, int);
	ssize_t (*read)(struct file___201 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___201 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___201 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___201 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___201 *, bool);
	int (*iterate)(struct file___201 *, struct dir_context *);
	int (*iterate_shared)(struct file___201 *, struct dir_context *);
	__poll_t (*poll)(struct file___201 *, struct poll_table_struct___136 *);
	long int (*unlocked_ioctl)(struct file___201 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___201 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___201 *, struct vm_area_struct___201 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___201 *, struct file___201 *);
	int (*flush)(struct file___201 *, fl_owner_t);
	int (*release)(struct inode___201 *, struct file___201 *);
	int (*fsync)(struct file___201 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___201 *, int);
	int (*lock)(struct file___201 *, int, struct file_lock___201 *);
	ssize_t (*sendpage)(struct file___201 *, struct page___201 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___201 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___201 *, int, struct file_lock___201 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___201 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___201 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___201 *, long int, struct file_lock___201 **, void **);
	long int (*fallocate)(struct file___201 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___37 *, struct file___201 *);
	ssize_t (*copy_file_range)(struct file___201 *, loff_t, struct file___201 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___201 *, loff_t, struct file___201 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___201 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___200 {
	u64 seqnum;
	struct vm_area_struct___201 *vmas[4];
};

struct page_frag___200 {
	struct page___201 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___200;

struct pid___159;

struct cred___195;

struct nsproxy___190;

struct task_struct___201 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___201 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___200 *mm;
	struct mm_struct___200 *active_mm;
	struct vmacache___200 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___201 *real_parent;
	struct task_struct___201 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___201 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___159 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___159 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___159 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___195 *ptracer_cred;
	const struct cred___195 *real_cred;
	const struct cred___195 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___190 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___201 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___53 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___200 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___201 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___120 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___200;

struct super_block___200;

struct dentry___200 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___200 *d_parent;
	struct qstr d_name;
	struct inode___201 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___200 *d_op;
	struct super_block___200 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct rw_semaphore___201 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___201 *owner;
};

struct address_space_operations___200;

struct address_space___200 {
	struct inode___201 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___201 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___200 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___200;

struct block_device___201;

struct inode___201 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___200 *i_op;
	struct super_block___200 *i_sb;
	struct address_space___200 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___201 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___201 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___200 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___201 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vfsmount___44;

struct path___200;

struct dentry_operations___200 {
	int (*d_revalidate)(struct dentry___200 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___200 *, unsigned int);
	int (*d_hash)(const struct dentry___200 *, struct qstr *);
	int (*d_compare)(const struct dentry___200 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___200 *);
	int (*d_init)(struct dentry___200 *);
	void (*d_release)(struct dentry___200 *);
	void (*d_prune)(struct dentry___200 *);
	void (*d_iput)(struct dentry___200 *, struct inode___201 *);
	char * (*d_dname)(struct dentry___200 *, char *, int);
	struct vfsmount___44 * (*d_automount)(struct path___200 *);
	int (*d_manage)(const struct path___200 *, bool);
	struct dentry___200 * (*d_real)(struct dentry___200 *, const struct inode___201 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___200;

struct mem_dqinfo___200 {
	struct quota_format_type___200 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___200;

struct quota_info___200 {
	unsigned int flags;
	struct rw_semaphore___201 dqio_sem;
	struct inode___201 *files[3];
	struct mem_dqinfo___200 info[3];
	const struct quota_format_ops___200 *ops[3];
};

struct rcuwait___200 {
	struct task_struct___201 *task;
};

struct percpu_rw_semaphore___200 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___201 rw_sem;
	struct rcuwait___200 writer;
	int readers_block;
};

struct sb_writers___200 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___200 rw_sem[3];
};

struct file_system_type___200;

struct super_operations___200;

struct dquot_operations___200;

struct quotactl_ops___200;

struct super_block___200 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___200 *s_type;
	const struct super_operations___200 *s_op;
	const struct dquot_operations___200 *dq_op;
	const struct quotactl_ops___200 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___200 *s_root;
	struct rw_semaphore___201 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___201 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___200 s_dquot;
	struct sb_writers___200 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___200 *s_d_op;
	int cleancache_poolid;
	struct shrinker___91 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___44 {
	struct dentry___200 *mnt_root;
	struct super_block___200 *mnt_sb;
	int mnt_flags;
};

struct path___200 {
	struct vfsmount___44 *mnt;
	struct dentry___200 *dentry;
};

typedef struct page___201 *pgtable_t___200;

struct dev_pagemap___197;

struct page___201 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___200 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___201 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___200 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___200 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___197 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___200;

struct lruvec___200 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___200 *pgdat;
};

struct zone___200 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___200 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___200 {
	struct zone___200 *zone;
	int zone_idx;
};

struct zonelist___200 {
	struct zoneref___200 _zonerefs[25];
};

struct pglist_data___200 {
	struct zone___200 node_zones[3];
	struct zonelist___200 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___201 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___201 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___200 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___201 {
	void *stack;
	struct task_struct___201 *task;
	long int status;
};

struct blocking_notifier_head___200 {
	struct rw_semaphore___201 rwsem;
	struct notifier_block *head;
};

struct pid_namespace___159;

struct upid___159 {
	int nr;
	struct pid_namespace___159 *ns;
};

struct proc_ns_operations___13;

struct ns_common___13 {
	atomic_long_t stashed;
	const struct proc_ns_operations___13 *ops;
	unsigned int inum;
};

struct pid_namespace___159 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___201 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___159 *parent;
	struct vfsmount___44 *proc_mnt;
	struct dentry___200 *proc_self;
	struct dentry___200 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___3 *user_ns;
	struct ucounts___2 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___13 ns;
};

struct pid___159 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___159 numbers[1];
};

struct vm_operations_struct___197;

struct vm_area_struct___201 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___201 *vm_next;
	struct vm_area_struct___201 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___200 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___197 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___201 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct linux_binfmt___22;

struct core_state___200;

struct mm_struct___200 {
	struct {
		struct vm_area_struct___201 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___201 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___201 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___22 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___200 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___201 *owner;
		struct user_namespace___3 *user_ns;
		struct file___201 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___200 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___197)(struct vm_area_struct___201 *, long unsigned int, const struct page___201 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___197)(struct page___201 *, void *);

struct dev_pagemap___197 {
	dev_page_fault_t___197 page_fault;
	dev_page_free_t___197 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___6 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct fown_struct___159 {
	rwlock_t lock;
	struct pid___159 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___201 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___200 f_path;
	struct inode___201 *f_inode;
	const struct file_operations___201 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___159 f_owner;
	const struct cred___195 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___200 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___197;

struct vm_operations_struct___197 {
	void (*open)(struct vm_area_struct___201 *);
	void (*close)(struct vm_area_struct___201 *);
	int (*split)(struct vm_area_struct___201 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___201 *);
	vm_fault_t (*fault)(struct vm_fault___197 *);
	vm_fault_t (*huge_fault)(struct vm_fault___197 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___197 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___201 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___197 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___197 *);
	int (*access)(struct vm_area_struct___201 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___201 *);
	int (*set_policy)(struct vm_area_struct___201 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___201 *, long unsigned int);
	struct page___201 * (*find_special_page)(struct vm_area_struct___201 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___200 {
	struct task_struct___201 *task;
	struct core_thread___200 *next;
};

struct core_state___200 {
	atomic_t nr_threads;
	struct core_thread___200 dumper;
	struct completion startup;
};

struct linux_binprm___23;

struct coredump_params___22;

struct linux_binfmt___22 {
	struct list_head lh;
	struct module___169 *module;
	int (*load_binary)(struct linux_binprm___23 *);
	int (*load_shlib)(struct file___201 *);
	int (*core_dump)(struct coredump_params___22 *);
	long unsigned int min_coredump;
};

struct vm_fault___197 {
	struct vm_area_struct___201 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___201 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___201 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___200 prealloc_pte;
};

struct key___195;

struct user_struct___195 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___195 *uid_keyring;
	struct key___195 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___195 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___195 *session_keyring;
	struct key___195 *process_keyring;
	struct key___195 *thread_keyring;
	struct key___195 *request_key_auth;
	void *security;
	struct user_struct___195 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct nsproxy___190 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___159 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___2 *cgroup_ns;
};

union thread_union___179 {
	struct task_struct___201 task;
	long unsigned int stack[8192];
};

struct kiocb___201 {
	struct file___201 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___201 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___200 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___201 *ia_file;
};

struct dquot___200 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___200 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___200 {
	int qf_fmt_id;
	const struct quota_format_ops___200 *qf_ops;
	struct module___169 *qf_owner;
	struct quota_format_type___200 *qf_next;
};

struct quota_format_ops___200 {
	int (*check_quota_file)(struct super_block___200 *, int);
	int (*read_file_info)(struct super_block___200 *, int);
	int (*write_file_info)(struct super_block___200 *, int);
	int (*free_file_info)(struct super_block___200 *, int);
	int (*read_dqblk)(struct dquot___200 *);
	int (*commit_dqblk)(struct dquot___200 *);
	int (*release_dqblk)(struct dquot___200 *);
	int (*get_next_id)(struct super_block___200 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___200 {
	int (*write_dquot)(struct dquot___200 *);
	struct dquot___200 * (*alloc_dquot)(struct super_block___200 *, int);
	void (*destroy_dquot)(struct dquot___200 *);
	int (*acquire_dquot)(struct dquot___200 *);
	int (*release_dquot)(struct dquot___200 *);
	int (*mark_dirty)(struct dquot___200 *);
	int (*write_info)(struct super_block___200 *, int);
	qsize_t * (*get_reserved_space)(struct inode___201 *);
	int (*get_projid)(struct inode___201 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___201 *, qsize_t *);
	int (*get_next_id)(struct super_block___200 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___200 {
	int (*quota_on)(struct super_block___200 *, int, int, const struct path___200 *);
	int (*quota_off)(struct super_block___200 *, int);
	int (*quota_enable)(struct super_block___200 *, unsigned int);
	int (*quota_disable)(struct super_block___200 *, unsigned int);
	int (*quota_sync)(struct super_block___200 *, int);
	int (*set_info)(struct super_block___200 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___200 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___200 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___200 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___200 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___200 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___191;

struct kobj_type___191;

struct kernfs_node___195;

struct kobject___192 {
	const char *name;
	struct list_head entry;
	struct kobject___192 *parent;
	struct kset___191 *kset;
	struct kobj_type___191 *ktype;
	struct kernfs_node___195 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___166 {
	struct kobject___192 kobj;
	struct module___169 *mod;
	struct kobject___192 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___166 {
	struct module___169 *mod;
	struct latch_tree_node node;
};

struct module_layout___166 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___166 mtn;
};

struct module_attribute___166;

struct kernel_param___166;

struct module___169 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___166 mkobj;
	struct module_attribute___166 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___192 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___166 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___166 core_layout;
	struct module_layout___166 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___200 {
	int (*writepage)(struct page___201 *, struct writeback_control___3 *);
	int (*readpage)(struct file___201 *, struct page___201 *);
	int (*writepages)(struct address_space___200 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___201 *);
	int (*readpages)(struct file___201 *, struct address_space___200 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___201 *, struct address_space___200 *, loff_t, unsigned int, unsigned int, struct page___201 **, void **);
	int (*write_end)(struct file___201 *, struct address_space___200 *, loff_t, unsigned int, unsigned int, struct page___201 *, void *);
	sector_t (*bmap)(struct address_space___200 *, sector_t);
	void (*invalidatepage)(struct page___201 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___201 *, gfp_t);
	void (*freepage)(struct page___201 *);
	ssize_t (*direct_IO)(struct kiocb___201 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___200 *, struct page___201 *, struct page___201 *, enum migrate_mode);
	bool (*isolate_page)(struct page___201 *, isolate_mode_t);
	void (*putback_page)(struct page___201 *);
	int (*launder_page)(struct page___201 *);
	int (*is_partially_uptodate)(struct page___201 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___201 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___200 *, struct page___201 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___201 *, sector_t *);
	void (*swap_deactivate)(struct file___201 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___201 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___201 *bd_inode;
	struct super_block___200 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___201 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___200 {
	struct dentry___200 * (*lookup)(struct inode___201 *, struct dentry___200 *, unsigned int);
	const char * (*get_link)(struct dentry___200 *, struct inode___201 *, struct delayed_call *);
	int (*permission)(struct inode___201 *, int);
	struct posix_acl * (*get_acl)(struct inode___201 *, int);
	int (*readlink)(struct dentry___200 *, char *, int);
	int (*create)(struct inode___201 *, struct dentry___200 *, umode_t, bool);
	int (*link)(struct dentry___200 *, struct inode___201 *, struct dentry___200 *);
	int (*unlink)(struct inode___201 *, struct dentry___200 *);
	int (*symlink)(struct inode___201 *, struct dentry___200 *, const char *);
	int (*mkdir)(struct inode___201 *, struct dentry___200 *, umode_t);
	int (*rmdir)(struct inode___201 *, struct dentry___200 *);
	int (*mknod)(struct inode___201 *, struct dentry___200 *, umode_t, dev_t);
	int (*rename)(struct inode___201 *, struct dentry___200 *, struct inode___201 *, struct dentry___200 *, unsigned int);
	int (*setattr)(struct dentry___200 *, struct iattr___200 *);
	int (*getattr)(const struct path___200 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___200 *, char *, size_t);
	int (*fiemap)(struct inode___201 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___201 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___201 *, struct dentry___200 *, struct file___201 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___201 *, struct dentry___200 *, umode_t);
	int (*set_acl)(struct inode___201 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___200 {
	void (*fl_copy_lock)(struct file_lock___201 *, struct file_lock___201 *);
	void (*fl_release_private)(struct file_lock___201 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___200;

struct lock_manager_operations___200;

struct file_lock___201 {
	struct file_lock___201 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___201 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___200 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___200 *fl_ops;
	const struct lock_manager_operations___200 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___200 {
	int (*lm_compare_owner)(struct file_lock___201 *, struct file_lock___201 *);
	long unsigned int (*lm_owner_key)(struct file_lock___201 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___201 *);
	int (*lm_grant)(struct file_lock___201 *, int);
	bool (*lm_break)(struct file_lock___201 *);
	int (*lm_change)(struct file_lock___201 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___201 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___200 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___200 *fa_next;
	struct file___201 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___200 {
	const char *name;
	int fs_flags;
	struct dentry___200 * (*mount)(struct file_system_type___200 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___200 *);
	struct module___169 *owner;
	struct file_system_type___200 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___200 {
	struct inode___201 * (*alloc_inode)(struct super_block___200 *);
	void (*destroy_inode)(struct inode___201 *);
	void (*dirty_inode)(struct inode___201 *, int);
	int (*write_inode)(struct inode___201 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___201 *);
	void (*evict_inode)(struct inode___201 *);
	void (*put_super)(struct super_block___200 *);
	int (*sync_fs)(struct super_block___200 *, int);
	int (*freeze_super)(struct super_block___200 *);
	int (*freeze_fs)(struct super_block___200 *);
	int (*thaw_super)(struct super_block___200 *);
	int (*unfreeze_fs)(struct super_block___200 *);
	int (*statfs)(struct dentry___200 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___200 *, int *, char *);
	void (*umount_begin)(struct super_block___200 *);
	int (*show_options)(struct seq_file___37 *, struct dentry___200 *);
	int (*show_devname)(struct seq_file___37 *, struct dentry___200 *);
	int (*show_path)(struct seq_file___37 *, struct dentry___200 *);
	int (*show_stats)(struct seq_file___37 *, struct dentry___200 *);
	ssize_t (*quota_read)(struct super_block___200 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___200 *, int, const char *, size_t, loff_t);
	struct dquot___200 ** (*get_dquots)(struct inode___201 *);
	int (*bdev_try_to_free_page)(struct super_block___200 *, struct page___201 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___200 *, struct shrink_control___91 *);
	long int (*free_cached_objects)(struct super_block___200 *, struct shrink_control___91 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___137)(struct file___201 *, wait_queue_head_t *, struct poll_table_struct___136 *);

struct poll_table_struct___136 {
	poll_queue_proc___137 _qproc;
	__poll_t _key;
};

struct seq_file___37 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___34 *op;
	int poll_event;
	const struct file___201 *file;
	void *private;
};

typedef int (*proc_write_t___3)(struct file___201 *, char *, size_t);

struct kobj_attribute___191 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___192 *, struct kobj_attribute___191 *, char *);
	ssize_t (*store)(struct kobject___192 *, struct kobj_attribute___191 *, const char *, size_t);
};

typedef void compound_page_dtor___197(struct page___201 *);

struct proc_ns_operations___13 {
	const char *name;
	const char *real_ns_name;
	int type;
	struct ns_common___13 * (*get)(struct task_struct___201 *);
	void (*put)(struct ns_common___13 *);
	int (*install)(struct nsproxy___190 *, struct ns_common___13 *);
	struct user_namespace___3 * (*owner)(struct ns_common___13 *);
	struct ns_common___13 * (*get_parent)(struct ns_common___13 *);
};

enum {
	HIDEPID_OFF = 0,
	HIDEPID_NO_ACCESS = 1,
	HIDEPID_INVISIBLE = 2,
};

struct kernfs_root___195;

struct kernfs_elem_dir___195 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___195 *root;
};

struct kernfs_syscall_ops___195;

struct kernfs_root___195 {
	struct kernfs_node___195 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___195 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___195 {
	struct kernfs_node___195 *target_kn;
};

struct kernfs_ops___195;

struct kernfs_elem_attr___195 {
	const struct kernfs_ops___195 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___195 *notify_next;
};

struct kernfs_node___195 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___195 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___195 dir;
		struct kernfs_elem_symlink___195 symlink;
		struct kernfs_elem_attr___195 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___195;

struct kernfs_ops___195 {
	int (*open)(struct kernfs_open_file___195 *);
	void (*release)(struct kernfs_open_file___195 *);
	int (*seq_show)(struct seq_file___37 *, void *);
	void * (*seq_start)(struct seq_file___37 *, loff_t *);
	void * (*seq_next)(struct seq_file___37 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___37 *, void *);
	ssize_t (*read)(struct kernfs_open_file___195 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___195 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___195 *, struct vm_area_struct___201 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___195 *, struct poll_table_struct___136 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___195 {
	int (*remount_fs)(struct kernfs_root___195 *, int *, char *);
	int (*show_options)(struct seq_file___37 *, struct kernfs_root___195 *);
	int (*mkdir)(struct kernfs_node___195 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___195 *);
	int (*rename)(struct kernfs_node___195 *, struct kernfs_node___195 *, const char *);
	int (*show_path)(struct seq_file___37 *, struct kernfs_node___195 *, struct kernfs_root___195 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___195 {
	struct kernfs_node___195 *kn;
	struct file___201 *file;
	struct seq_file___37 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___197 *vm_ops;
};

struct sysfs_ops___191 {
	ssize_t (*show)(struct kobject___192 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___192 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___191;

struct kset___191 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___192 kobj;
	const struct kset_uevent_ops___191 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___191 {
	void (*release)(struct kobject___192 *);
	const struct sysfs_ops___191 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___12 * (*child_ns_type)(struct kobject___192 *);
	const void * (*namespace)(struct kobject___192 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___191 {
	int (* const filter)(struct kset___191 *, struct kobject___192 *);
	const char * (* const name)(struct kset___191 *, struct kobject___192 *);
	int (* const uevent)(struct kset___191 *, struct kobject___192 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___166 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___166 *);
	int (*get)(char *, const struct kernel_param___166 *);
	void (*free)(void *);
};

struct kparam_array___166;

struct kernel_param___166 {
	const char *name;
	struct module___169 *mod;
	const struct kernel_param_ops___166 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___166 *arr;
	};
};

struct kparam_array___166 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___166 *ops;
	void *elem;
};

struct module_attribute___166 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___166 *, struct module_kobject___166 *, char *);
	ssize_t (*store)(struct module_attribute___166 *, struct module_kobject___166 *, const char *, size_t);
	void (*setup)(struct module___169 *, const char *);
	int (*test)(struct module___169 *);
	void (*free)(struct module___169 *);
};

typedef int (*key_restrict_link_func_t___195)(struct key___195 *, const struct key_type *, const union key_payload *, struct key___195 *);

struct key_restriction___195;

struct key___195 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___201 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___195 *restrict_link;
};

struct key_restriction___195 {
	key_restrict_link_func_t___195 check;
	struct key___195 *key;
	struct key_type *keytype;
};

struct linux_binprm___23 {
	char buf[256];
	struct vm_area_struct___201 *vma;
	long unsigned int vma_pages;
	struct mm_struct___200 *mm;
	long unsigned int p;
	unsigned int called_set_creds: 1;
	unsigned int cap_elevated: 1;
	unsigned int secureexec: 1;
	unsigned int recursion_depth;
	struct file___201 *file;
	struct cred___195 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
};

struct coredump_params___22 {
	union {
		const kernel_siginfo_t *siginfo;
		struct {
			const siginfo_t *siginfo;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	struct pt_regs *regs;
	struct file___201 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
};

struct proc_dir_entry___4 {
	atomic_t in_use;
	refcount_t refcnt;
	struct list_head pde_openers;
	spinlock_t pde_unload_lock;
	struct completion *pde_unload_completion;
	const struct inode_operations___200 *proc_iops;
	const struct file_operations___201 *proc_fops;
	union {
		const struct seq_operations___34 *seq_ops;
		int (*single_show)(struct seq_file___37 *, void *);
	};
	proc_write_t___3 write;
	void *data;
	unsigned int state_size;
	unsigned int low_ino;
	nlink_t nlink;
	kuid_t uid;
	kgid_t gid;
	loff_t size;
	struct proc_dir_entry___4 *parent;
	struct rb_root subdir;
	struct rb_node subdir_node;
	char *name;
	umode_t mode;
	u8 namelen;
	char inline_name[0];
};

union proc_op___3 {
	int (*proc_get_link)(struct dentry___200 *, struct path___200 *);
	int (*proc_show)(struct seq_file___37 *, struct pid_namespace___159 *, struct pid___159 *, struct task_struct___201 *);
};

struct proc_inode___3 {
	struct pid___159 *pid;
	unsigned int fd;
	union proc_op___3 op;
	struct proc_dir_entry___4 *pde;
	struct ctl_table_header *sysctl;
	struct ctl_table *sysctl_entry;
	struct hlist_node sysctl_inodes;
	const struct proc_ns_operations___13 *ns_ops;
	struct inode___201 vfs_inode;
};

struct pde_opener {
	struct file___201 *file;
	struct list_head lh;
	bool closing;
	struct completion *c;
};

enum {
	BIAS = 2147483648,
};

struct module___170;

struct file___202;

struct kiocb___202;

struct vm_area_struct___202;

struct inode___202;

struct file_lock___202;

struct page___202;

struct file_operations___202 {
	struct module___170 *owner;
	loff_t (*llseek)(struct file___202 *, loff_t, int);
	ssize_t (*read)(struct file___202 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___202 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___202 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___202 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___202 *, bool);
	int (*iterate)(struct file___202 *, struct dir_context *);
	int (*iterate_shared)(struct file___202 *, struct dir_context *);
	__poll_t (*poll)(struct file___202 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___202 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___202 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___202 *, struct vm_area_struct___202 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___202 *, struct file___202 *);
	int (*flush)(struct file___202 *, fl_owner_t);
	int (*release)(struct inode___202 *, struct file___202 *);
	int (*fsync)(struct file___202 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___202 *, int);
	int (*lock)(struct file___202 *, int, struct file_lock___202 *);
	ssize_t (*sendpage)(struct file___202 *, struct page___202 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___202 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___202 *, int, struct file_lock___202 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___202 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___202 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___202 *, long int, struct file_lock___202 **, void **);
	long int (*fallocate)(struct file___202 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___202 *);
	ssize_t (*copy_file_range)(struct file___202 *, loff_t, struct file___202 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___202 *, loff_t, struct file___202 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___202 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___201 {
	u64 seqnum;
	struct vm_area_struct___202 *vmas[4];
};

struct page_frag___201 {
	struct page___202 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___201;

struct pid___160;

struct cred___196;

struct nsproxy___191;

struct task_struct___202 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___202 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___201 *mm;
	struct mm_struct___201 *active_mm;
	struct vmacache___201 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___202 *real_parent;
	struct task_struct___202 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___202 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___160 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___160 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___160 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___196 *ptracer_cred;
	const struct cred___196 *real_cred;
	const struct cred___196 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___191 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___202 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___53 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___201 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___202 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___120 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___160;

struct upid___160 {
	int nr;
	struct pid_namespace___160 *ns;
};

struct proc_ns_operations___14;

struct ns_common___14 {
	atomic_long_t stashed;
	const struct proc_ns_operations___14 *ops;
	unsigned int inum;
};

struct vfsmount___45;

struct dentry___201;

struct user_namespace___177;

struct ucounts___177;

struct pid_namespace___160 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___202 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___160 *parent;
	struct vfsmount___45 *proc_mnt;
	struct dentry___201 *proc_self;
	struct dentry___201 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___177 *user_ns;
	struct ucounts___177 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___14 ns;
};

struct pid___160 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___160 numbers[1];
};

struct rw_semaphore___202 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___202 *owner;
};

struct key___196;

struct user_namespace___177 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___177 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___14 ns;
	long unsigned int flags;
	struct key___196 *persistent_keyring_register;
	struct rw_semaphore___202 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___177 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct secondary_data___202 {
	void *stack;
	struct task_struct___202 *task;
	long int status;
};

typedef struct page___202 *pgtable_t___201;

struct address_space___201;

struct dev_pagemap___198;

struct page___202 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___201 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___202 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___201 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___201 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___198 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct user_struct___196 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___196 *uid_keyring;
	struct key___196 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___198;

struct vm_area_struct___202 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___202 *vm_next;
	struct vm_area_struct___202 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___201 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___198 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___202 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct linux_binfmt___23;

struct core_state___201;

struct mm_struct___201 {
	struct {
		struct vm_area_struct___202 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___202 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___202 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___23 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___201 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___202 *owner;
		struct user_namespace___177 *user_ns;
		struct file___202 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___201 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___196 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___196 *session_keyring;
	struct key___196 *process_keyring;
	struct key___196 *thread_keyring;
	struct key___196 *request_key_auth;
	void *security;
	struct user_struct___196 *user;
	struct user_namespace___177 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct nsproxy___191 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___160 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___2 *cgroup_ns;
};

union thread_union___180 {
	struct task_struct___202 task;
	long unsigned int stack[8192];
};

struct address_space_operations___201;

struct address_space___201 {
	struct inode___202 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___202 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___201 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___198)(struct vm_area_struct___202 *, long unsigned int, const struct page___202 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___198)(struct page___202 *, void *);

struct dev_pagemap___198 {
	dev_page_fault_t___198 page_fault;
	dev_page_free_t___198 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___6 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___201 {
	struct vfsmount___45 *mnt;
	struct dentry___201 *dentry;
};

struct fown_struct___160 {
	rwlock_t lock;
	struct pid___160 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___202 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___201 f_path;
	struct inode___202 *f_inode;
	const struct file_operations___202 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___160 f_owner;
	const struct cred___196 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___201 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___198;

struct vm_operations_struct___198 {
	void (*open)(struct vm_area_struct___202 *);
	void (*close)(struct vm_area_struct___202 *);
	int (*split)(struct vm_area_struct___202 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___202 *);
	vm_fault_t (*fault)(struct vm_fault___198 *);
	vm_fault_t (*huge_fault)(struct vm_fault___198 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___198 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___202 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___198 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___198 *);
	int (*access)(struct vm_area_struct___202 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___202 *);
	int (*set_policy)(struct vm_area_struct___202 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___202 *, long unsigned int);
	struct page___202 * (*find_special_page)(struct vm_area_struct___202 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___201 {
	struct task_struct___202 *task;
	struct core_thread___201 *next;
};

struct core_state___201 {
	atomic_t nr_threads;
	struct core_thread___201 dumper;
	struct completion startup;
};

struct linux_binprm___24;

struct coredump_params___23;

struct linux_binfmt___23 {
	struct list_head lh;
	struct module___170 *module;
	int (*load_binary)(struct linux_binprm___24 *);
	int (*load_shlib)(struct file___202 *);
	int (*core_dump)(struct coredump_params___23 *);
	long unsigned int min_coredump;
};

struct vm_fault___198 {
	struct vm_area_struct___202 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___202 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___202 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___201 prealloc_pte;
};

struct dentry_operations___201;

struct super_block___201;

struct dentry___201 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___201 *d_parent;
	struct qstr d_name;
	struct inode___202 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___201 *d_op;
	struct super_block___201 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___201;

struct block_device___202;

struct inode___202 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___201 *i_op;
	struct super_block___201 *i_sb;
	struct address_space___201 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___202 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___202 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___201 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___202 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___201 {
	int (*d_revalidate)(struct dentry___201 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___201 *, unsigned int);
	int (*d_hash)(const struct dentry___201 *, struct qstr *);
	int (*d_compare)(const struct dentry___201 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___201 *);
	int (*d_init)(struct dentry___201 *);
	void (*d_release)(struct dentry___201 *);
	void (*d_prune)(struct dentry___201 *);
	void (*d_iput)(struct dentry___201 *, struct inode___202 *);
	char * (*d_dname)(struct dentry___201 *, char *, int);
	struct vfsmount___45 * (*d_automount)(struct path___201 *);
	int (*d_manage)(const struct path___201 *, bool);
	struct dentry___201 * (*d_real)(struct dentry___201 *, const struct inode___202 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___201;

struct mem_dqinfo___201 {
	struct quota_format_type___201 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___201;

struct quota_info___201 {
	unsigned int flags;
	struct rw_semaphore___202 dqio_sem;
	struct inode___202 *files[3];
	struct mem_dqinfo___201 info[3];
	const struct quota_format_ops___201 *ops[3];
};

struct rcuwait___201 {
	struct task_struct___202 *task;
};

struct percpu_rw_semaphore___201 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___202 rw_sem;
	struct rcuwait___201 writer;
	int readers_block;
};

struct sb_writers___201 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___201 rw_sem[3];
};

struct file_system_type___201;

struct super_operations___201;

struct dquot_operations___201;

struct quotactl_ops___201;

struct super_block___201 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___201 *s_type;
	const struct super_operations___201 *s_op;
	const struct dquot_operations___201 *dq_op;
	const struct quotactl_ops___201 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___201 *s_root;
	struct rw_semaphore___202 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___202 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___201 s_dquot;
	struct sb_writers___201 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___201 *s_d_op;
	int cleancache_poolid;
	struct shrinker___91 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___177 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___45 {
	struct dentry___201 *mnt_root;
	struct super_block___201 *mnt_sb;
	int mnt_flags;
};

struct pglist_data___201;

struct lruvec___201 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___201 *pgdat;
};

struct zone___201 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___201 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___201 {
	struct zone___201 *zone;
	int zone_idx;
};

struct zonelist___201 {
	struct zoneref___201 _zonerefs[25];
};

struct pglist_data___201 {
	struct zone___201 node_zones[3];
	struct zonelist___201 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___202 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___202 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___201 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___201 {
	struct rw_semaphore___202 rwsem;
	struct notifier_block *head;
};

struct kiocb___202 {
	struct file___202 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___202 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___201 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___202 *ia_file;
};

struct dquot___201 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___201 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___201 {
	int qf_fmt_id;
	const struct quota_format_ops___201 *qf_ops;
	struct module___170 *qf_owner;
	struct quota_format_type___201 *qf_next;
};

struct quota_format_ops___201 {
	int (*check_quota_file)(struct super_block___201 *, int);
	int (*read_file_info)(struct super_block___201 *, int);
	int (*write_file_info)(struct super_block___201 *, int);
	int (*free_file_info)(struct super_block___201 *, int);
	int (*read_dqblk)(struct dquot___201 *);
	int (*commit_dqblk)(struct dquot___201 *);
	int (*release_dqblk)(struct dquot___201 *);
	int (*get_next_id)(struct super_block___201 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___201 {
	int (*write_dquot)(struct dquot___201 *);
	struct dquot___201 * (*alloc_dquot)(struct super_block___201 *, int);
	void (*destroy_dquot)(struct dquot___201 *);
	int (*acquire_dquot)(struct dquot___201 *);
	int (*release_dquot)(struct dquot___201 *);
	int (*mark_dirty)(struct dquot___201 *);
	int (*write_info)(struct super_block___201 *, int);
	qsize_t * (*get_reserved_space)(struct inode___202 *);
	int (*get_projid)(struct inode___202 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___202 *, qsize_t *);
	int (*get_next_id)(struct super_block___201 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___201 {
	int (*quota_on)(struct super_block___201 *, int, int, const struct path___201 *);
	int (*quota_off)(struct super_block___201 *, int);
	int (*quota_enable)(struct super_block___201 *, unsigned int);
	int (*quota_disable)(struct super_block___201 *, unsigned int);
	int (*quota_sync)(struct super_block___201 *, int);
	int (*set_info)(struct super_block___201 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___201 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___201 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___201 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___201 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___201 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___192;

struct kobj_type___192;

struct kernfs_node___196;

struct kobject___193 {
	const char *name;
	struct list_head entry;
	struct kobject___193 *parent;
	struct kset___192 *kset;
	struct kobj_type___192 *ktype;
	struct kernfs_node___196 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___167 {
	struct kobject___193 kobj;
	struct module___170 *mod;
	struct kobject___193 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___167 {
	struct module___170 *mod;
	struct latch_tree_node node;
};

struct module_layout___167 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___167 mtn;
};

struct module_attribute___167;

struct kernel_param___167;

struct module___170 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___167 mkobj;
	struct module_attribute___167 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___193 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___167 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___167 core_layout;
	struct module_layout___167 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___201 {
	int (*writepage)(struct page___202 *, struct writeback_control___3 *);
	int (*readpage)(struct file___202 *, struct page___202 *);
	int (*writepages)(struct address_space___201 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___202 *);
	int (*readpages)(struct file___202 *, struct address_space___201 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___202 *, struct address_space___201 *, loff_t, unsigned int, unsigned int, struct page___202 **, void **);
	int (*write_end)(struct file___202 *, struct address_space___201 *, loff_t, unsigned int, unsigned int, struct page___202 *, void *);
	sector_t (*bmap)(struct address_space___201 *, sector_t);
	void (*invalidatepage)(struct page___202 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___202 *, gfp_t);
	void (*freepage)(struct page___202 *);
	ssize_t (*direct_IO)(struct kiocb___202 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___201 *, struct page___202 *, struct page___202 *, enum migrate_mode);
	bool (*isolate_page)(struct page___202 *, isolate_mode_t);
	void (*putback_page)(struct page___202 *);
	int (*launder_page)(struct page___202 *);
	int (*is_partially_uptodate)(struct page___202 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___202 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___201 *, struct page___202 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___202 *, sector_t *);
	void (*swap_deactivate)(struct file___202 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___202 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___202 *bd_inode;
	struct super_block___201 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___202 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___201 {
	struct dentry___201 * (*lookup)(struct inode___202 *, struct dentry___201 *, unsigned int);
	const char * (*get_link)(struct dentry___201 *, struct inode___202 *, struct delayed_call *);
	int (*permission)(struct inode___202 *, int);
	struct posix_acl * (*get_acl)(struct inode___202 *, int);
	int (*readlink)(struct dentry___201 *, char *, int);
	int (*create)(struct inode___202 *, struct dentry___201 *, umode_t, bool);
	int (*link)(struct dentry___201 *, struct inode___202 *, struct dentry___201 *);
	int (*unlink)(struct inode___202 *, struct dentry___201 *);
	int (*symlink)(struct inode___202 *, struct dentry___201 *, const char *);
	int (*mkdir)(struct inode___202 *, struct dentry___201 *, umode_t);
	int (*rmdir)(struct inode___202 *, struct dentry___201 *);
	int (*mknod)(struct inode___202 *, struct dentry___201 *, umode_t, dev_t);
	int (*rename)(struct inode___202 *, struct dentry___201 *, struct inode___202 *, struct dentry___201 *, unsigned int);
	int (*setattr)(struct dentry___201 *, struct iattr___201 *);
	int (*getattr)(const struct path___201 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___201 *, char *, size_t);
	int (*fiemap)(struct inode___202 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___202 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___202 *, struct dentry___201 *, struct file___202 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___202 *, struct dentry___201 *, umode_t);
	int (*set_acl)(struct inode___202 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___201 {
	void (*fl_copy_lock)(struct file_lock___202 *, struct file_lock___202 *);
	void (*fl_release_private)(struct file_lock___202 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___201;

struct lock_manager_operations___201;

struct file_lock___202 {
	struct file_lock___202 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___202 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___201 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___201 *fl_ops;
	const struct lock_manager_operations___201 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___201 {
	int (*lm_compare_owner)(struct file_lock___202 *, struct file_lock___202 *);
	long unsigned int (*lm_owner_key)(struct file_lock___202 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___202 *);
	int (*lm_grant)(struct file_lock___202 *, int);
	bool (*lm_break)(struct file_lock___202 *);
	int (*lm_change)(struct file_lock___202 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___202 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___201 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___201 *fa_next;
	struct file___202 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___201 {
	const char *name;
	int fs_flags;
	struct dentry___201 * (*mount)(struct file_system_type___201 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___201 *);
	struct module___170 *owner;
	struct file_system_type___201 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___201 {
	struct inode___202 * (*alloc_inode)(struct super_block___201 *);
	void (*destroy_inode)(struct inode___202 *);
	void (*dirty_inode)(struct inode___202 *, int);
	int (*write_inode)(struct inode___202 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___202 *);
	void (*evict_inode)(struct inode___202 *);
	void (*put_super)(struct super_block___201 *);
	int (*sync_fs)(struct super_block___201 *, int);
	int (*freeze_super)(struct super_block___201 *);
	int (*freeze_fs)(struct super_block___201 *);
	int (*thaw_super)(struct super_block___201 *);
	int (*unfreeze_fs)(struct super_block___201 *);
	int (*statfs)(struct dentry___201 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___201 *, int *, char *);
	void (*umount_begin)(struct super_block___201 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___201 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___201 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___201 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___201 *);
	ssize_t (*quota_read)(struct super_block___201 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___201 *, int, const char *, size_t, loff_t);
	struct dquot___201 ** (*get_dquots)(struct inode___202 *);
	int (*bdev_try_to_free_page)(struct super_block___201 *, struct page___202 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___201 *, struct shrink_control___91 *);
	long int (*free_cached_objects)(struct super_block___201 *, struct shrink_control___91 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*proc_write_t___4)(struct file___202 *, char *, size_t);

struct kernfs_root___196;

struct kernfs_elem_dir___196 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___196 *root;
};

struct kernfs_syscall_ops___196;

struct kernfs_root___196 {
	struct kernfs_node___196 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___196 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___196 {
	struct kernfs_node___196 *target_kn;
};

struct kernfs_ops___196;

struct kernfs_elem_attr___196 {
	const struct kernfs_ops___196 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___196 *notify_next;
};

struct kernfs_node___196 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___196 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___196 dir;
		struct kernfs_elem_symlink___196 symlink;
		struct kernfs_elem_attr___196 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___196;

struct kernfs_ops___196 {
	int (*open)(struct kernfs_open_file___196 *);
	void (*release)(struct kernfs_open_file___196 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___196 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___196 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___196 *, struct vm_area_struct___202 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___196 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___196 {
	int (*remount_fs)(struct kernfs_root___196 *, int *, char *);
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___196 *);
	int (*mkdir)(struct kernfs_node___196 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___196 *);
	int (*rename)(struct kernfs_node___196 *, struct kernfs_node___196 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___196 *, struct kernfs_root___196 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___196 {
	struct kernfs_node___196 *kn;
	struct file___202 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___198 *vm_ops;
};

struct sysfs_ops___192 {
	ssize_t (*show)(struct kobject___193 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___193 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___192;

struct kset___192 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___193 kobj;
	const struct kset_uevent_ops___192 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___192 {
	void (*release)(struct kobject___193 *);
	const struct sysfs_ops___192 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___12 * (*child_ns_type)(struct kobject___193 *);
	const void * (*namespace)(struct kobject___193 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___192 {
	int (* const filter)(struct kset___192 *, struct kobject___193 *);
	const char * (* const name)(struct kset___192 *, struct kobject___193 *);
	int (* const uevent)(struct kset___192 *, struct kobject___193 *, struct kobj_uevent_env *);
};

struct kobj_attribute___192 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___193 *, struct kobj_attribute___192 *, char *);
	ssize_t (*store)(struct kobject___193 *, struct kobj_attribute___192 *, const char *, size_t);
};

struct kernel_param_ops___167 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___167 *);
	int (*get)(char *, const struct kernel_param___167 *);
	void (*free)(void *);
};

struct kparam_array___167;

struct kernel_param___167 {
	const char *name;
	struct module___170 *mod;
	const struct kernel_param_ops___167 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___167 *arr;
	};
};

struct kparam_array___167 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___167 *ops;
	void *elem;
};

struct module_attribute___167 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___167 *, struct module_kobject___167 *, char *);
	ssize_t (*store)(struct module_attribute___167 *, struct module_kobject___167 *, const char *, size_t);
	void (*setup)(struct module___170 *, const char *);
	int (*test)(struct module___170 *);
	void (*free)(struct module___170 *);
};

struct proc_ns_operations___14 {
	const char *name;
	const char *real_ns_name;
	int type;
	struct ns_common___14 * (*get)(struct task_struct___202 *);
	void (*put)(struct ns_common___14 *);
	int (*install)(struct nsproxy___191 *, struct ns_common___14 *);
	struct user_namespace___177 * (*owner)(struct ns_common___14 *);
	struct ns_common___14 * (*get_parent)(struct ns_common___14 *);
};

struct key_restriction___196;

struct key___196 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___202 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___196 *restrict_link;
};

struct ucounts___177 {
	struct hlist_node node;
	struct user_namespace___177 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

typedef void compound_page_dtor___198(struct page___202 *);

typedef int (*key_restrict_link_func_t___196)(struct key___196 *, const struct key_type *, const union key_payload *, struct key___196 *);

struct key_restriction___196 {
	key_restrict_link_func_t___196 check;
	struct key___196 *key;
	struct key_type *keytype;
};

struct linux_binprm___24 {
	char buf[256];
	struct vm_area_struct___202 *vma;
	long unsigned int vma_pages;
	struct mm_struct___201 *mm;
	long unsigned int p;
	unsigned int called_set_creds: 1;
	unsigned int cap_elevated: 1;
	unsigned int secureexec: 1;
	unsigned int recursion_depth;
	struct file___202 *file;
	struct cred___196 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
};

struct coredump_params___23 {
	union {
		const kernel_siginfo_t *siginfo;
		struct {
			const siginfo_t *siginfo;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	struct pt_regs *regs;
	struct file___202 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
};

struct proc_dir_entry___5 {
	atomic_t in_use;
	refcount_t refcnt;
	struct list_head pde_openers;
	spinlock_t pde_unload_lock;
	struct completion *pde_unload_completion;
	const struct inode_operations___201 *proc_iops;
	const struct file_operations___202 *proc_fops;
	union {
		const struct seq_operations___34 *seq_ops;
		int (*single_show)(struct seq_file___37 *, void *);
	};
	proc_write_t___4 write;
	void *data;
	unsigned int state_size;
	unsigned int low_ino;
	nlink_t nlink;
	kuid_t uid;
	kgid_t gid;
	loff_t size;
	struct proc_dir_entry___5 *parent;
	struct rb_root subdir;
	struct rb_node subdir_node;
	char *name;
	umode_t mode;
	u8 namelen;
	char inline_name[0];
};

enum {
	Opt_gid = 0,
	Opt_hidepid = 1,
	Opt_err = 2,
};

struct module___171;

struct file___203;

struct kiocb___203;

struct iov_iter___98;

struct poll_table_struct___137;

struct vm_area_struct___203;

struct inode___203;

struct file_lock___203;

struct page___203;

struct seq_file___187;

struct file_operations___203 {
	struct module___171 *owner;
	loff_t (*llseek)(struct file___203 *, loff_t, int);
	ssize_t (*read)(struct file___203 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___203 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___203 *, struct iov_iter___98 *);
	ssize_t (*write_iter)(struct kiocb___203 *, struct iov_iter___98 *);
	int (*iopoll)(struct kiocb___203 *, bool);
	int (*iterate)(struct file___203 *, struct dir_context *);
	int (*iterate_shared)(struct file___203 *, struct dir_context *);
	__poll_t (*poll)(struct file___203 *, struct poll_table_struct___137 *);
	long int (*unlocked_ioctl)(struct file___203 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___203 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___203 *, struct vm_area_struct___203 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___203 *, struct file___203 *);
	int (*flush)(struct file___203 *, fl_owner_t);
	int (*release)(struct inode___203 *, struct file___203 *);
	int (*fsync)(struct file___203 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___203 *, int);
	int (*lock)(struct file___203 *, int, struct file_lock___203 *);
	ssize_t (*sendpage)(struct file___203 *, struct page___203 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___203 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___203 *, int, struct file_lock___203 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___203 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___203 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___203 *, long int, struct file_lock___203 **, void **);
	long int (*fallocate)(struct file___203 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___187 *, struct file___203 *);
	ssize_t (*copy_file_range)(struct file___203 *, loff_t, struct file___203 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___203 *, loff_t, struct file___203 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___203 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___202 {
	u64 seqnum;
	struct vm_area_struct___203 *vmas[4];
};

struct page_frag___202 {
	struct page___203 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___202;

struct mem_cgroup___92;

struct pid___161;

struct cred___197;

struct fs_struct___14;

struct files_struct___13;

struct nsproxy___192;

struct signal_struct___177;

struct bio_list___103;

struct backing_dev_info___103;

struct io_context___54;

struct css_set___168;

struct request_queue___51;

struct vm_struct___140;

struct task_struct___203 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___203 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___202 *mm;
	struct mm_struct___202 *active_mm;
	struct vmacache___202 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___203 *real_parent;
	struct task_struct___203 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___203 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___92 *active_memcg;
	long int rh_reserved2;
	struct pid___161 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___161 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___161 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___197 *ptracer_cred;
	const struct cred___197 *real_cred;
	const struct cred___197 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct___14 *fs;
	struct files_struct___13 *files;
	struct nsproxy___192 *nsproxy;
	struct signal_struct___177 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___203 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___103 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___103 *backing_dev_info;
	struct io_context___54 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___168 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___202 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___92 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___51 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___203 *oom_reaper_list;
	struct vm_struct___140 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___120 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___161;

struct upid___161 {
	int nr;
	struct pid_namespace___161 *ns;
};

struct proc_ns_operations___15;

struct ns_common___15 {
	atomic_long_t stashed;
	const struct proc_ns_operations___15 *ops;
	unsigned int inum;
};

struct vfsmount___46;

struct dentry___202;

struct user_namespace___178;

struct ucounts___178;

struct pid_namespace___161 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___203 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___161 *parent;
	struct vfsmount___46 *proc_mnt;
	struct dentry___202 *proc_self;
	struct dentry___202 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___178 *user_ns;
	struct ucounts___178 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___15 ns;
};

struct pid___161 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___161 numbers[1];
};

struct rw_semaphore___203 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___203 *owner;
};

struct key___197;

struct user_namespace___178 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___178 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___15 ns;
	long unsigned int flags;
	struct key___197 *persistent_keyring_register;
	struct rw_semaphore___203 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___178 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct secondary_data___203 {
	void *stack;
	struct task_struct___203 *task;
	long int status;
};

typedef struct page___203 *pgtable_t___202;

struct address_space___202;

struct dev_pagemap___199;

struct page___203 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___202 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___203 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___202 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___202 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___199 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___92 *mem_cgroup;
};

struct user_struct___197;

struct sigqueue___6 {
	struct list_head list;
	int flags;
	kernel_siginfo_t info;
	struct user_struct___197 *user;
};

struct user_struct___197 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___197 *uid_keyring;
	struct key___197 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___199;

struct vm_area_struct___203 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___203 *vm_next;
	struct vm_area_struct___203 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___202 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___199 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___203 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct linux_binfmt___24;

struct core_state___202;

struct mm_struct___202 {
	struct {
		struct vm_area_struct___203 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___203 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___203 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___24 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___202 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___203 *owner;
		struct user_namespace___178 *user_ns;
		struct file___203 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___202 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup___168;

struct cgroup_subsys___168;

struct cgroup_subsys_state___169 {
	struct cgroup___168 *cgroup;
	struct cgroup_subsys___168 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___169 *parent;
};

struct kernfs_node___197;

struct cgroup_file___168 {
	struct kernfs_node___197 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___92;

struct mem_cgroup___92 {
	struct cgroup_subsys_state___169 css;
	struct mem_cgroup_id___2 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___168 events_file;
	struct cgroup_file___168 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___203 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___92 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cred___197 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___197 *session_keyring;
	struct key___197 *process_keyring;
	struct key___197 *thread_keyring;
	struct key___197 *request_key_auth;
	void *security;
	struct user_struct___197 *user;
	struct user_namespace___178 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct path___202 {
	struct vfsmount___46 *mnt;
	struct dentry___202 *dentry;
};

struct fs_struct___14 {
	int users;
	spinlock_t lock;
	seqcount_t seq;
	int umask;
	int in_exec;
	struct path___202 root;
	struct path___202 pwd;
};

struct fdtable___13 {
	unsigned int max_fds;
	struct file___203 **fd;
	long unsigned int *close_on_exec;
	long unsigned int *open_fds;
	long unsigned int *full_fds_bits;
	struct callback_head rcu;
};

struct files_struct___13 {
	atomic_t count;
	bool resize_in_progress;
	wait_queue_head_t resize_wait;
	struct fdtable___13 *fdt;
	struct fdtable___13 fdtab;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t file_lock;
	unsigned int next_fd;
	long unsigned int close_on_exec_init[1];
	long unsigned int open_fds_init[1];
	long unsigned int full_fds_bits_init[1];
	struct file___203 *fd_array[64];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cgroup_namespace___168;

struct nsproxy___192 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___161 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___168 *cgroup_ns;
};

struct signal_struct___177 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___203 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___203 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___161 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___161 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___202 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___161 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___103;

struct bio_list___103 {
	struct bio___103 *head;
	struct bio___103 *tail;
};

struct bdi_writeback_congested___103;

struct bdi_writeback___103 {
	struct backing_dev_info___103 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___103 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___169 *memcg_css;
	struct cgroup_subsys_state___169 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___181;

struct backing_dev_info___103 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___103 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___181 *dev;
	struct device___181 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___202 *debug_dir;
	struct dentry___202 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___54;

struct io_context___54 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___54 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___168 {
	struct cgroup_subsys_state___169 *subsys[13];
	refcount_t refcount;
	struct css_set___168 *dom_cset;
	struct cgroup___168 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___168 *mg_src_cgrp;
	struct cgroup___168 *mg_dst_cgrp;
	struct css_set___168 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

typedef blk_qc_t make_request_fn___50(struct request_queue___51 *, struct bio___103 *);

struct request___51;

typedef int dma_drain_needed_fn___50(struct request___51 *);

struct kset___193;

struct kobj_type___193;

struct kobject___194 {
	const char *name;
	struct list_head entry;
	struct kobject___194 *parent;
	struct kset___193 *kset;
	struct kobj_type___193 *ktype;
	struct kernfs_node___197 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___50;

struct bsg_class_device___50 {
	struct device___181 *class_dev;
	int minor;
	struct request_queue___51 *queue;
	const struct bsg_ops___50 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___103 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___103 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___50;

struct blkcg_gq___39;

struct request_queue___51 {
	struct list_head queue_head;
	struct request___51 *last_merge;
	struct elevator_queue___50 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___50 *make_request_fn;
	dma_drain_needed_fn___50 *dma_drain_needed;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___103 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___194 kobj;
	struct kobject___194 *mq_kobj;
	struct blk_integrity integrity;
	struct device___181 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___39 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide35;
		union {		};
	};
	struct bsg_class_device___50 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___103 bio_split;
	struct dentry___202 *debugfs_dir;
	struct dentry___202 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___140 {
	struct vm_struct___140 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___203 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___181 {
	struct task_struct___203 task;
	long unsigned int stack[8192];
};

struct address_space_operations___202;

struct address_space___202 {
	struct inode___203 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___203 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___202 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___199)(struct vm_area_struct___203 *, long unsigned int, const struct page___203 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___199)(struct page___203 *, void *);

struct dev_pagemap___199 {
	dev_page_fault_t___199 page_fault;
	dev_page_free_t___199 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___181 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct fown_struct___161 {
	rwlock_t lock;
	struct pid___161 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___203 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___202 f_path;
	struct inode___203 *f_inode;
	const struct file_operations___203 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___161 f_owner;
	const struct cred___197 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___202 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___199;

struct vm_operations_struct___199 {
	void (*open)(struct vm_area_struct___203 *);
	void (*close)(struct vm_area_struct___203 *);
	int (*split)(struct vm_area_struct___203 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___203 *);
	vm_fault_t (*fault)(struct vm_fault___199 *);
	vm_fault_t (*huge_fault)(struct vm_fault___199 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___199 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___203 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___199 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___199 *);
	int (*access)(struct vm_area_struct___203 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___203 *);
	int (*set_policy)(struct vm_area_struct___203 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___203 *, long unsigned int);
	struct page___203 * (*find_special_page)(struct vm_area_struct___203 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___202 {
	struct task_struct___203 *task;
	struct core_thread___202 *next;
};

struct core_state___202 {
	atomic_t nr_threads;
	struct core_thread___202 dumper;
	struct completion startup;
};

struct linux_binprm___25;

struct coredump_params___24;

struct linux_binfmt___24 {
	struct list_head lh;
	struct module___171 *module;
	int (*load_binary)(struct linux_binprm___25 *);
	int (*load_shlib)(struct file___203 *);
	int (*core_dump)(struct coredump_params___24 *);
	long unsigned int min_coredump;
};

struct vm_fault___199 {
	struct vm_area_struct___203 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___203 *cow_page;
	struct mem_cgroup___92 *memcg;
	struct page___203 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___202 prealloc_pte;
};

struct dentry_operations___202;

struct super_block___202;

struct dentry___202 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___202 *d_parent;
	struct qstr d_name;
	struct inode___203 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___202 *d_op;
	struct super_block___202 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___202;

struct block_device___203;

struct cdev___34;

struct inode___203 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___202 *i_op;
	struct super_block___202 *i_sb;
	struct address_space___202 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___203 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___103 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___203 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___202 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___203 *i_bdev;
		struct cdev___34 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___202 {
	int (*d_revalidate)(struct dentry___202 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___202 *, unsigned int);
	int (*d_hash)(const struct dentry___202 *, struct qstr *);
	int (*d_compare)(const struct dentry___202 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___202 *);
	int (*d_init)(struct dentry___202 *);
	void (*d_release)(struct dentry___202 *);
	void (*d_prune)(struct dentry___202 *);
	void (*d_iput)(struct dentry___202 *, struct inode___203 *);
	char * (*d_dname)(struct dentry___202 *, char *, int);
	struct vfsmount___46 * (*d_automount)(struct path___202 *);
	int (*d_manage)(const struct path___202 *, bool);
	struct dentry___202 * (*d_real)(struct dentry___202 *, const struct inode___203 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___202;

struct mem_dqinfo___202 {
	struct quota_format_type___202 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___202;

struct quota_info___202 {
	unsigned int flags;
	struct rw_semaphore___203 dqio_sem;
	struct inode___203 *files[3];
	struct mem_dqinfo___202 info[3];
	const struct quota_format_ops___202 *ops[3];
};

struct rcuwait___202 {
	struct task_struct___203 *task;
};

struct percpu_rw_semaphore___202 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___203 rw_sem;
	struct rcuwait___202 writer;
	int readers_block;
};

struct sb_writers___202 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___202 rw_sem[3];
};

struct shrink_control___92;

struct shrinker___92 {
	long unsigned int (*count_objects)(struct shrinker___92 *, struct shrink_control___92 *);
	long unsigned int (*scan_objects)(struct shrinker___92 *, struct shrink_control___92 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___202;

struct super_operations___202;

struct dquot_operations___202;

struct quotactl_ops___202;

struct super_block___202 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___202 *s_type;
	const struct super_operations___202 *s_op;
	const struct dquot_operations___202 *dq_op;
	const struct quotactl_ops___202 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___202 *s_root;
	struct rw_semaphore___203 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___203 *s_bdev;
	struct backing_dev_info___103 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___202 s_dquot;
	struct sb_writers___202 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___202 *s_d_op;
	int cleancache_poolid;
	struct shrinker___92 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___178 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___46 {
	struct dentry___202 *mnt_root;
	struct super_block___202 *mnt_sb;
	int mnt_flags;
};

struct shrink_control___92 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___92 *memcg;
};

struct pglist_data___202;

struct lruvec___202 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___202 *pgdat;
};

struct zone___202 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___202 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___202 {
	struct zone___202 *zone;
	int zone_idx;
};

struct zonelist___202 {
	struct zoneref___202 _zonerefs[25];
};

struct pglist_data___202 {
	struct zone___202 node_zones[3];
	struct zonelist___202 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___203 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___203 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___202 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___202 {
	struct rw_semaphore___203 rwsem;
	struct notifier_block *head;
};

struct io_cq___54 {
	struct request_queue___51 *q;
	struct io_context___54 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___6 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___203 {
	struct file___203 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___203 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___202 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___203 *ia_file;
};

struct dquot___202 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___202 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___202 {
	int qf_fmt_id;
	const struct quota_format_ops___202 *qf_ops;
	struct module___171 *qf_owner;
	struct quota_format_type___202 *qf_next;
};

struct quota_format_ops___202 {
	int (*check_quota_file)(struct super_block___202 *, int);
	int (*read_file_info)(struct super_block___202 *, int);
	int (*write_file_info)(struct super_block___202 *, int);
	int (*free_file_info)(struct super_block___202 *, int);
	int (*read_dqblk)(struct dquot___202 *);
	int (*commit_dqblk)(struct dquot___202 *);
	int (*release_dqblk)(struct dquot___202 *);
	int (*get_next_id)(struct super_block___202 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___202 {
	int (*write_dquot)(struct dquot___202 *);
	struct dquot___202 * (*alloc_dquot)(struct super_block___202 *, int);
	void (*destroy_dquot)(struct dquot___202 *);
	int (*acquire_dquot)(struct dquot___202 *);
	int (*release_dquot)(struct dquot___202 *);
	int (*mark_dirty)(struct dquot___202 *);
	int (*write_info)(struct super_block___202 *, int);
	qsize_t * (*get_reserved_space)(struct inode___203 *);
	int (*get_projid)(struct inode___203 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___203 *, qsize_t *);
	int (*get_next_id)(struct super_block___202 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___202 {
	int (*quota_on)(struct super_block___202 *, int, int, const struct path___202 *);
	int (*quota_off)(struct super_block___202 *, int);
	int (*quota_enable)(struct super_block___202 *, unsigned int);
	int (*quota_disable)(struct super_block___202 *, unsigned int);
	int (*quota_sync)(struct super_block___202 *, int);
	int (*set_info)(struct super_block___202 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___202 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___202 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___202 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___202 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___202 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___168 {
	struct kobject___194 kobj;
	struct module___171 *mod;
	struct kobject___194 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___168 {
	struct module___171 *mod;
	struct latch_tree_node node;
};

struct module_layout___168 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___168 mtn;
};

struct module_attribute___168;

struct kernel_param___168;

struct module___171 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___168 mkobj;
	struct module_attribute___168 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___194 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___168 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___168 core_layout;
	struct module_layout___168 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___99;

struct swap_info_struct___65;

struct address_space_operations___202 {
	int (*writepage)(struct page___203 *, struct writeback_control___99 *);
	int (*readpage)(struct file___203 *, struct page___203 *);
	int (*writepages)(struct address_space___202 *, struct writeback_control___99 *);
	int (*set_page_dirty)(struct page___203 *);
	int (*readpages)(struct file___203 *, struct address_space___202 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___203 *, struct address_space___202 *, loff_t, unsigned int, unsigned int, struct page___203 **, void **);
	int (*write_end)(struct file___203 *, struct address_space___202 *, loff_t, unsigned int, unsigned int, struct page___203 *, void *);
	sector_t (*bmap)(struct address_space___202 *, sector_t);
	void (*invalidatepage)(struct page___203 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___203 *, gfp_t);
	void (*freepage)(struct page___203 *);
	ssize_t (*direct_IO)(struct kiocb___203 *, struct iov_iter___98 *);
	int (*migratepage)(struct address_space___202 *, struct page___203 *, struct page___203 *, enum migrate_mode);
	bool (*isolate_page)(struct page___203 *, isolate_mode_t);
	void (*putback_page)(struct page___203 *);
	int (*launder_page)(struct page___203 *);
	int (*is_partially_uptodate)(struct page___203 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___203 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___202 *, struct page___203 *);
	int (*swap_activate)(struct swap_info_struct___65 *, struct file___203 *, sector_t *);
	void (*swap_deactivate)(struct file___203 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___99 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___103 *wb;
	struct inode___203 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___103;

struct iov_iter___98 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___103 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct swap_info_struct___65 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___203 *bdev;
	struct file___203 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct hd_struct___51;

struct gendisk___51;

struct block_device___203 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___203 *bd_inode;
	struct super_block___202 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___203 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___51 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___51 *bd_disk;
	struct request_queue___51 *bd_queue;
	struct backing_dev_info___103 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___181 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___181 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___181;

struct bus_type___181;

struct device_driver___181;

struct dev_pm_domain___181;

struct fwnode_handle___126;

struct class___181;

struct attribute_group___183;

struct device___181 {
	struct device___181 *parent;
	struct device_private *p;
	struct kobject___194 kobj;
	const char *init_name;
	const struct device_type___181 *type;
	struct mutex mutex;
	struct bus_type___181 *bus;
	struct device_driver___181 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___181 power;
	struct dev_pm_domain___181 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___126 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___181 *class;
	const struct attribute_group___183 **groups;
	void (*release)(struct device___181 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___51 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___181 __dev;
	struct kobject___194 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___51;

struct block_device_operations___51;

struct gendisk___51 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___51 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___51 *part_tbl;
	struct hd_struct___51 part0;
	const struct block_device_operations___51 *fops;
	struct request_queue___51 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___203 lookup_sem;
	struct kobject___194 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___194 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___34 {
	struct kobject___194 kobj;
	struct module___171 *owner;
	const struct file_operations___203 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___202 {
	struct dentry___202 * (*lookup)(struct inode___203 *, struct dentry___202 *, unsigned int);
	const char * (*get_link)(struct dentry___202 *, struct inode___203 *, struct delayed_call *);
	int (*permission)(struct inode___203 *, int);
	struct posix_acl * (*get_acl)(struct inode___203 *, int);
	int (*readlink)(struct dentry___202 *, char *, int);
	int (*create)(struct inode___203 *, struct dentry___202 *, umode_t, bool);
	int (*link)(struct dentry___202 *, struct inode___203 *, struct dentry___202 *);
	int (*unlink)(struct inode___203 *, struct dentry___202 *);
	int (*symlink)(struct inode___203 *, struct dentry___202 *, const char *);
	int (*mkdir)(struct inode___203 *, struct dentry___202 *, umode_t);
	int (*rmdir)(struct inode___203 *, struct dentry___202 *);
	int (*mknod)(struct inode___203 *, struct dentry___202 *, umode_t, dev_t);
	int (*rename)(struct inode___203 *, struct dentry___202 *, struct inode___203 *, struct dentry___202 *, unsigned int);
	int (*setattr)(struct dentry___202 *, struct iattr___202 *);
	int (*getattr)(const struct path___202 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___202 *, char *, size_t);
	int (*fiemap)(struct inode___203 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___203 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___203 *, struct dentry___202 *, struct file___203 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___203 *, struct dentry___202 *, umode_t);
	int (*set_acl)(struct inode___203 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___202 {
	void (*fl_copy_lock)(struct file_lock___203 *, struct file_lock___203 *);
	void (*fl_release_private)(struct file_lock___203 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___202;

struct lock_manager_operations___202;

struct file_lock___203 {
	struct file_lock___203 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___203 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___202 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___202 *fl_ops;
	const struct lock_manager_operations___202 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___202 {
	int (*lm_compare_owner)(struct file_lock___203 *, struct file_lock___203 *);
	long unsigned int (*lm_owner_key)(struct file_lock___203 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___203 *);
	int (*lm_grant)(struct file_lock___203 *, int);
	bool (*lm_break)(struct file_lock___203 *);
	int (*lm_change)(struct file_lock___203 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___203 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___202 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___202 *fa_next;
	struct file___203 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___202 {
	const char *name;
	int fs_flags;
	struct dentry___202 * (*mount)(struct file_system_type___202 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___202 *);
	struct module___171 *owner;
	struct file_system_type___202 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___202 {
	struct inode___203 * (*alloc_inode)(struct super_block___202 *);
	void (*destroy_inode)(struct inode___203 *);
	void (*dirty_inode)(struct inode___203 *, int);
	int (*write_inode)(struct inode___203 *, struct writeback_control___99 *);
	int (*drop_inode)(struct inode___203 *);
	void (*evict_inode)(struct inode___203 *);
	void (*put_super)(struct super_block___202 *);
	int (*sync_fs)(struct super_block___202 *, int);
	int (*freeze_super)(struct super_block___202 *);
	int (*freeze_fs)(struct super_block___202 *);
	int (*thaw_super)(struct super_block___202 *);
	int (*unfreeze_fs)(struct super_block___202 *);
	int (*statfs)(struct dentry___202 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___202 *, int *, char *);
	void (*umount_begin)(struct super_block___202 *);
	int (*show_options)(struct seq_file___187 *, struct dentry___202 *);
	int (*show_devname)(struct seq_file___187 *, struct dentry___202 *);
	int (*show_path)(struct seq_file___187 *, struct dentry___202 *);
	int (*show_stats)(struct seq_file___187 *, struct dentry___202 *);
	ssize_t (*quota_read)(struct super_block___202 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___202 *, int, const char *, size_t, loff_t);
	struct dquot___202 ** (*get_dquots)(struct inode___203 *);
	int (*bdev_try_to_free_page)(struct super_block___202 *, struct page___203 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___202 *, struct shrink_control___92 *);
	long int (*free_cached_objects)(struct super_block___202 *, struct shrink_control___92 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___138)(struct file___203 *, wait_queue_head_t *, struct poll_table_struct___137 *);

struct poll_table_struct___137 {
	poll_queue_proc___138 _qproc;
	__poll_t _key;
};

struct seq_operations___185;

struct seq_file___187 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___185 *op;
	int poll_event;
	const struct file___203 *file;
	void *private;
};

typedef void bio_end_io_t___103(struct bio___103 *);

struct bio_vec___103 {
	struct page___203 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___103;

struct bio___103 {
	struct bio___103 *bi_next;
	struct gendisk___51 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___103 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___39 *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___103 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___103 *bi_io_vec;
	struct bio_set___103 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___103 bi_inline_vecs[0];
};

typedef int (*proc_write_t___5)(struct file___203 *, char *, size_t);

typedef int (*key_restrict_link_func_t___197)(struct key___197 *, const struct key_type *, const union key_payload *, struct key___197 *);

struct key_restriction___197;

struct key___197 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___203 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___197 *restrict_link;
};

struct key_restriction___197 {
	key_restrict_link_func_t___197 check;
	struct key___197 *key;
	struct key_type *keytype;
};

struct seq_operations___185 {
	void * (*start)(struct seq_file___187 *, loff_t *);
	void (*stop)(struct seq_file___187 *, void *);
	void * (*next)(struct seq_file___187 *, void *, loff_t *);
	int (*show)(struct seq_file___187 *, void *);
};

struct kobj_attribute___193 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___194 *, struct kobj_attribute___193 *, char *);
	ssize_t (*store)(struct kobject___194 *, struct kobj_attribute___193 *, const char *, size_t);
};

typedef void compound_page_dtor___199(struct page___203 *);

struct kernfs_root___197;

struct kernfs_elem_dir___197 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___197 *root;
};

struct kernfs_syscall_ops___197;

struct kernfs_root___197 {
	struct kernfs_node___197 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___197 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___197 {
	struct kernfs_node___197 *target_kn;
};

struct kernfs_ops___197;

struct kernfs_elem_attr___197 {
	const struct kernfs_ops___197 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___197 *notify_next;
};

struct kernfs_node___197 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___197 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___197 dir;
		struct kernfs_elem_symlink___197 symlink;
		struct kernfs_elem_attr___197 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___197;

struct kernfs_ops___197 {
	int (*open)(struct kernfs_open_file___197 *);
	void (*release)(struct kernfs_open_file___197 *);
	int (*seq_show)(struct seq_file___187 *, void *);
	void * (*seq_start)(struct seq_file___187 *, loff_t *);
	void * (*seq_next)(struct seq_file___187 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___187 *, void *);
	ssize_t (*read)(struct kernfs_open_file___197 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___197 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___197 *, struct vm_area_struct___203 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___197 *, struct poll_table_struct___137 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___197 {
	int (*remount_fs)(struct kernfs_root___197 *, int *, char *);
	int (*show_options)(struct seq_file___187 *, struct kernfs_root___197 *);
	int (*mkdir)(struct kernfs_node___197 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___197 *);
	int (*rename)(struct kernfs_node___197 *, struct kernfs_node___197 *, const char *);
	int (*show_path)(struct seq_file___187 *, struct kernfs_node___197 *, struct kernfs_root___197 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___197 {
	struct kernfs_node___197 *kn;
	struct file___203 *file;
	struct seq_file___187 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___199 *vm_ops;
};

struct proc_ns_operations___15 {
	const char *name;
	const char *real_ns_name;
	int type;
	struct ns_common___15 * (*get)(struct task_struct___203 *);
	void (*put)(struct ns_common___15 *);
	int (*install)(struct nsproxy___192 *, struct ns_common___15 *);
	struct user_namespace___178 * (*owner)(struct ns_common___15 *);
	struct ns_common___15 * (*get_parent)(struct ns_common___15 *);
};

struct cgroup_namespace___168 {
	refcount_t count;
	struct ns_common___15 ns;
	struct user_namespace___178 *user_ns;
	struct ucounts___178 *ucounts;
	struct css_set___168 *root_cset;
};

struct ucounts___178 {
	struct hlist_node node;
	struct user_namespace___178 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct proc_dir_entry___6 {
	atomic_t in_use;
	refcount_t refcnt;
	struct list_head pde_openers;
	spinlock_t pde_unload_lock;
	struct completion *pde_unload_completion;
	const struct inode_operations___202 *proc_iops;
	const struct file_operations___203 *proc_fops;
	union {
		const struct seq_operations___185 *seq_ops;
		int (*single_show)(struct seq_file___187 *, void *);
	};
	proc_write_t___5 write;
	void *data;
	unsigned int state_size;
	unsigned int low_ino;
	nlink_t nlink;
	kuid_t uid;
	kgid_t gid;
	loff_t size;
	struct proc_dir_entry___6 *parent;
	struct rb_root subdir;
	struct rb_node subdir_node;
	char *name;
	umode_t mode;
	u8 namelen;
	char inline_name[0];
};

struct bpf_map___168;

struct bpf_map_ops___168 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___168 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___168 *, struct file___203 *);
	void (*map_free)(struct bpf_map___168 *);
	int (*map_get_next_key)(struct bpf_map___168 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___168 *);
	void * (*map_lookup_elem)(struct bpf_map___168 *, void *);
	int (*map_update_elem)(struct bpf_map___168 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___168 *, void *);
	int (*map_push_elem)(struct bpf_map___168 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___168 *, void *);
	int (*map_peek_elem)(struct bpf_map___168 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___168 *, struct file___203 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___168 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___168 *, void *, struct seq_file___187 *);
	int (*map_check_btf)(const struct bpf_map___168 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___168 {
	const struct bpf_map_ops___168 *ops;
	struct bpf_map___168 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___197 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___168;

typedef void (*kthread_work_func_t___168)(struct kthread_work___168 *);

struct kthread_worker___168;

struct kthread_work___168 {
	struct list_head node;
	kthread_work_func_t___168 func;
	struct kthread_worker___168 *worker;
	int canceling;
};

struct kthread_worker___168 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___203 *task;
	struct kthread_work___168 *current_work;
};

struct kthread_delayed_work___168 {
	struct kthread_work___168 work;
	struct timer_list timer;
};

struct psi_group___168 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___168 *poll_kworker;
	struct kthread_delayed_work___168 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___168;

struct cgroup_rstat_cpu___168;

struct cgroup___168 {
	struct cgroup_subsys_state___169 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___197 *kn;
	struct cgroup_file___168 procs_file;
	struct cgroup_file___168 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___169 *subsys[13];
	struct cgroup_root___168 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___168 *dom_cgrp;
	struct cgroup_rstat_cpu___168 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___22 bpf;
	atomic_t congestion_count;
	struct cgroup___168 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___168 psi;
	int ancestor_ids[0];
};

struct cftype___168;

struct cgroup_subsys___168 {
	struct cgroup_subsys_state___169 * (*css_alloc)(struct cgroup_subsys_state___169 *);
	int (*css_online)(struct cgroup_subsys_state___169 *);
	void (*css_offline)(struct cgroup_subsys_state___169 *);
	void (*css_released)(struct cgroup_subsys_state___169 *);
	void (*css_free)(struct cgroup_subsys_state___169 *);
	void (*css_reset)(struct cgroup_subsys_state___169 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___169 *, int);
	int (*css_extra_stat_show)(struct seq_file___187 *, struct cgroup_subsys_state___169 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___203 *);
	void (*cancel_fork)(struct task_struct___203 *);
	void (*fork)(struct task_struct___203 *);
	void (*exit)(struct task_struct___203 *);
	void (*free)(struct task_struct___203 *);
	void (*bind)(struct cgroup_subsys_state___169 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___168 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___168 *dfl_cftypes;
	struct cftype___168 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___168 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___168 *updated_children;
	struct cgroup___168 *updated_next;
};

struct cgroup_root___168 {
	struct kernfs_root___197 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___168 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___168 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___168 *ss;
	struct list_head node;
	struct kernfs_ops___197 *kf_ops;
	int (*open)(struct kernfs_open_file___197 *);
	void (*release)(struct kernfs_open_file___197 *);
	u64 (*read_u64)(struct cgroup_subsys_state___169 *, struct cftype___168 *);
	s64 (*read_s64)(struct cgroup_subsys_state___169 *, struct cftype___168 *);
	int (*seq_show)(struct seq_file___187 *, void *);
	void * (*seq_start)(struct seq_file___187 *, loff_t *);
	void * (*seq_next)(struct seq_file___187 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___187 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___169 *, struct cftype___168 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___169 *, struct cftype___168 *, s64);
	ssize_t (*write)(struct kernfs_open_file___197 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___197 *, struct poll_table_struct___137 *);
};

struct bdi_writeback_congested___103 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___103 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___103 {
	struct bio___103 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___103 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___103 bip_inline_vecs[0];
};

struct blkcg___39;

struct blkg_policy_data___39;

struct blkcg_gq___39 {
	struct request_queue___51 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___39 *blkcg;
	struct bdi_writeback_congested___103 *wb_congested;
	struct blkcg_gq___39 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_rwstat stat_bytes;
	struct blkg_rwstat stat_ios;
	struct blkg_policy_data___39 *pd[5];
	struct callback_head callback_head;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
};

struct mem_cgroup_reclaim_iter___92 {
	struct mem_cgroup___92 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___92 {
	struct lruvec___202 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___92 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___92 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct bin_attribute___182;

struct attribute_group___183 {
	const char *name;
	umode_t (*is_visible)(struct kobject___194 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___194 *, struct bin_attribute___182 *, int);
	struct attribute **attrs;
	struct bin_attribute___182 **bin_attrs;
};

struct bin_attribute___182 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___203 *, struct kobject___194 *, struct bin_attribute___182 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___203 *, struct kobject___194 *, struct bin_attribute___182 *, char *, loff_t, size_t);
	int (*mmap)(struct file___203 *, struct kobject___194 *, struct bin_attribute___182 *, struct vm_area_struct___203 *);
};

struct sysfs_ops___193 {
	ssize_t (*show)(struct kobject___194 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___194 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___193;

struct kset___193 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___194 kobj;
	const struct kset_uevent_ops___193 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___193 {
	void (*release)(struct kobject___194 *);
	const struct sysfs_ops___193 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___12 * (*child_ns_type)(struct kobject___194 *);
	const void * (*namespace)(struct kobject___194 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___193 {
	int (* const filter)(struct kset___193 *, struct kobject___194 *);
	const char * (* const name)(struct kset___193 *, struct kobject___194 *);
	int (* const uevent)(struct kset___193 *, struct kobject___194 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___181 {
	int (*prepare)(struct device___181 *);
	void (*complete)(struct device___181 *);
	int (*suspend)(struct device___181 *);
	int (*resume)(struct device___181 *);
	int (*freeze)(struct device___181 *);
	int (*thaw)(struct device___181 *);
	int (*poweroff)(struct device___181 *);
	int (*restore)(struct device___181 *);
	int (*suspend_late)(struct device___181 *);
	int (*resume_early)(struct device___181 *);
	int (*freeze_late)(struct device___181 *);
	int (*thaw_early)(struct device___181 *);
	int (*poweroff_late)(struct device___181 *);
	int (*restore_early)(struct device___181 *);
	int (*suspend_noirq)(struct device___181 *);
	int (*resume_noirq)(struct device___181 *);
	int (*freeze_noirq)(struct device___181 *);
	int (*thaw_noirq)(struct device___181 *);
	int (*poweroff_noirq)(struct device___181 *);
	int (*restore_noirq)(struct device___181 *);
	int (*runtime_suspend)(struct device___181 *);
	int (*runtime_resume)(struct device___181 *);
	int (*runtime_idle)(struct device___181 *);
};

struct dev_pm_domain___181 {
	struct dev_pm_ops___181 ops;
	void (*detach)(struct device___181 *, bool);
	int (*activate)(struct device___181 *);
	void (*sync)(struct device___181 *);
	void (*dismiss)(struct device___181 *);
};

struct bus_type___181 {
	const char *name;
	const char *dev_name;
	struct device___181 *dev_root;
	const struct attribute_group___183 **bus_groups;
	const struct attribute_group___183 **dev_groups;
	const struct attribute_group___183 **drv_groups;
	int (*match)(struct device___181 *, struct device_driver___181 *);
	int (*uevent)(struct device___181 *, struct kobj_uevent_env *);
	int (*probe)(struct device___181 *);
	int (*remove)(struct device___181 *);
	void (*shutdown)(struct device___181 *);
	int (*online)(struct device___181 *);
	int (*offline)(struct device___181 *);
	int (*suspend)(struct device___181 *, pm_message_t);
	int (*resume)(struct device___181 *);
	int (*num_vf)(struct device___181 *);
	int (*dma_configure)(struct device___181 *);
	const struct dev_pm_ops___181 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___181 {
	const char *name;
	struct bus_type___181 *bus;
	struct module___171 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___181 *);
	int (*remove)(struct device___181 *);
	void (*shutdown)(struct device___181 *);
	int (*suspend)(struct device___181 *, pm_message_t);
	int (*resume)(struct device___181 *);
	const struct attribute_group___183 **groups;
	const struct dev_pm_ops___181 *pm;
	void (*coredump)(struct device___181 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___181 {
	const char *name;
	const struct attribute_group___183 **groups;
	int (*uevent)(struct device___181 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___181 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___181 *);
	const struct dev_pm_ops___181 *pm;
};

struct class___181 {
	const char *name;
	struct module___171 *owner;
	const struct attribute_group___183 **class_groups;
	const struct attribute_group___183 **dev_groups;
	struct kobject___194 *dev_kobj;
	int (*dev_uevent)(struct device___181 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___181 *, umode_t *);
	void (*class_release)(struct class___181 *);
	void (*dev_release)(struct device___181 *);
	int (*shutdown_pre)(struct device___181 *);
	const struct kobj_ns_type_operations___12 *ns_type;
	const void * (*namespace)(struct device___181 *);
	const struct dev_pm_ops___181 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct fwnode_operations___126;

struct fwnode_handle___126 {
	struct fwnode_handle___126 *secondary;
	const struct fwnode_operations___126 *ops;
};

struct node___156 {
	struct device___181 dev;
};

struct kernel_param_ops___168 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___168 *);
	int (*get)(char *, const struct kernel_param___168 *);
	void (*free)(void *);
};

struct kparam_array___168;

struct kernel_param___168 {
	const char *name;
	struct module___171 *mod;
	const struct kernel_param_ops___168 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___168 *arr;
	};
};

struct kparam_array___168 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___168 *ops;
	void *elem;
};

struct module_attribute___168 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___168 *, struct module_kobject___168 *, char *);
	ssize_t (*store)(struct module_attribute___168 *, struct module_kobject___168 *, const char *, size_t);
	void (*setup)(struct module___171 *, const char *);
	int (*test)(struct module___171 *);
	void (*free)(struct module___171 *);
};

struct disk_part_tbl___51 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___51 *last_lookup;
	struct hd_struct___51 *part[0];
};

struct block_device_operations___51 {
	int (*open)(struct block_device___203 *, fmode_t);
	void (*release)(struct gendisk___51 *, fmode_t);
	int (*rw_page)(struct block_device___203 *, sector_t, struct page___203 *, unsigned int);
	int (*ioctl)(struct block_device___203 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___203 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___51 *, unsigned int);
	int (*media_changed)(struct gendisk___51 *);
	void (*unlock_native_capacity)(struct gendisk___51 *);
	int (*revalidate_disk)(struct gendisk___51 *);
	int (*getgeo)(struct block_device___203 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___203 *, long unsigned int);
	int (*report_zones)(struct gendisk___51 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___171 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___50 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___51 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___51 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___51 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___50(struct request___51 *, blk_status_t);

struct request___51 {
	struct request_queue___51 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___103 *bio;
	struct bio___103 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___103 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___54 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___50 *saved_end_io;
		} flush;
	};
	struct gendisk___51 *rq_disk;
	struct hd_struct___51 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___50 *end_io;
	void *end_io_data;
	struct request___51 *next_rq;
};

struct fwnode_reference_args___126;

struct fwnode_endpoint___126;

struct fwnode_operations___126 {
	struct fwnode_handle___126 * (*get)(struct fwnode_handle___126 *);
	void (*put)(struct fwnode_handle___126 *);
	bool (*device_is_available)(const struct fwnode_handle___126 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___126 *, const struct device___181 *);
	bool (*property_present)(const struct fwnode_handle___126 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___126 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___126 *, const char *, const char **, size_t);
	struct fwnode_handle___126 * (*get_parent)(const struct fwnode_handle___126 *);
	struct fwnode_handle___126 * (*get_next_child_node)(const struct fwnode_handle___126 *, struct fwnode_handle___126 *);
	struct fwnode_handle___126 * (*get_named_child_node)(const struct fwnode_handle___126 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___126 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___126 *);
	struct fwnode_handle___126 * (*graph_get_next_endpoint)(const struct fwnode_handle___126 *, struct fwnode_handle___126 *);
	struct fwnode_handle___126 * (*graph_get_remote_endpoint)(const struct fwnode_handle___126 *);
	struct fwnode_handle___126 * (*graph_get_port_parent)(struct fwnode_handle___126 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___126 *, struct fwnode_endpoint___126 *);
};

struct fwnode_endpoint___126 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___126 *local_fwnode;
};

struct fwnode_reference_args___126 {
	struct fwnode_handle___126 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct elevator_type___50;

struct elevator_mq_ops___50 {
	int (*init_sched)(struct request_queue___51 *, struct elevator_type___50 *);
	void (*exit_sched)(struct elevator_queue___50 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	bool (*allow_merge)(struct request_queue___51 *, struct request___51 *, struct bio___103 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx *, struct bio___103 *);
	int (*request_merge)(struct request_queue___51 *, struct request___51 **, struct bio___103 *);
	void (*request_merged)(struct request_queue___51 *, struct request___51 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___51 *, struct request___51 *, struct request___51 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___51 *, struct bio___103 *);
	void (*finish_request)(struct request___51 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___51 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___51 *, u64);
	void (*started_request)(struct request___51 *);
	void (*requeue_request)(struct request___51 *);
	struct request___51 * (*former_request)(struct request_queue___51 *, struct request___51 *);
	struct request___51 * (*next_request)(struct request_queue___51 *, struct request___51 *);
	void (*init_icq)(struct io_cq___54 *);
	void (*exit_icq)(struct io_cq___54 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___50;

struct elevator_type___50 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___50 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___50 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___171 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___50 {
	struct elevator_type___50 *type;
	void *elevator_data;
	struct kobject___194 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___50 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___50 *, char *);
	ssize_t (*store)(struct elevator_queue___50 *, const char *, size_t);
};

struct blkcg_policy_data___39;

struct blkcg___39 {
	struct cgroup_subsys_state___169 css;
	spinlock_t lock;
	struct xarray blkg_tree;
	struct blkcg_gq___39 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___39 *cpd[5];
	struct list_head all_blkcgs_node;
	struct list_head cgwb_list;
	refcount_t cgwb_refcnt;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct blkcg_policy_data___39 {
	struct blkcg___39 *blkcg;
	int plid;
};

struct blkg_policy_data___39 {
	struct blkcg_gq___39 *blkg;
	int plid;
};

struct reciprocal_value {
	u32 m;
	u8 sh1;
	u8 sh2;
};

struct flex_array_part;

struct flex_array {
	union {
		struct {
			int element_size;
			int total_nr_elements;
			int elems_per_part;
			struct reciprocal_value reciprocal_elems;
			struct flex_array_part *parts[0];
		};
		char padding[65536];
	};
};

struct cpu_timer_list___5 {
	struct list_head entry;
	u64 expires;
	u64 incr;
	struct task_struct___203 *task;
	int firing;
};

struct k_clock___5;

struct k_itimer___5 {
	struct list_head list;
	struct hlist_node t_hash;
	spinlock_t it_lock;
	const struct k_clock___5 *kclock;
	clockid_t it_clock;
	timer_t it_id;
	int it_active;
	s64 it_overrun;
	s64 it_overrun_last;
	int it_requeue_pending;
	int it_sigev_notify;
	ktime_t it_interval;
	struct signal_struct___177 *it_signal;
	union {
		struct pid___161 *it_pid;
		struct task_struct___203 *it_process;
	};
	struct sigqueue___6 *sigq;
	union {
		struct {
			struct hrtimer timer;
		} real;
		struct cpu_timer_list___5 cpu;
		struct {
			struct alarm alarmtimer;
		} alarm;
		struct callback_head rcu;
	} it;
};

struct linux_binprm___25 {
	char buf[256];
	struct vm_area_struct___203 *vma;
	long unsigned int vma_pages;
	struct mm_struct___202 *mm;
	long unsigned int p;
	unsigned int called_set_creds: 1;
	unsigned int cap_elevated: 1;
	unsigned int secureexec: 1;
	unsigned int recursion_depth;
	struct file___203 *file;
	struct cred___197 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
};

struct coredump_params___24 {
	union {
		const kernel_siginfo_t *siginfo;
		struct {
			const siginfo_t *siginfo;
		} __UNIQUE_ID_rh_kabi_hide48;
		union {		};
	};
	struct pt_regs *regs;
	struct file___203 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
};

union proc_op___4 {
	int (*proc_get_link)(struct dentry___202 *, struct path___202 *);
	int (*proc_show)(struct seq_file___187 *, struct pid_namespace___161 *, struct pid___161 *, struct task_struct___203 *);
};

struct proc_inode___4 {
	struct pid___161 *pid;
	unsigned int fd;
	union proc_op___4 op;
	struct proc_dir_entry___6 *pde;
	struct ctl_table_header *sysctl;
	struct ctl_table *sysctl_entry;
	struct hlist_node sysctl_inodes;
	const struct proc_ns_operations___15 *ns_ops;
	struct inode___203 vfs_inode;
};

typedef struct dentry___202 *instantiate_t(struct dentry___202 *, struct task_struct___203 *, const void *);

struct pid_entry {
	const char *name;
	unsigned int len;
	umode_t mode;
	const struct inode_operations___202 *iop;
	const struct file_operations___203 *fop;
	union proc_op___4 op;
};

struct limit_names {
	const char *name;
	const char *unit;
};

struct map_files_info {
	long unsigned int start;
	long unsigned int end;
	fmode_t mode;
};

struct timers_private {
	struct pid___161 *pid;
	struct task_struct___203 *task;
	struct sighand_struct *sighand;
	struct pid_namespace___161 *ns;
	long unsigned int flags;
};

struct tgid_iter {
	unsigned int tgid;
	struct task_struct___203 *task;
};

struct module___172;

struct file___204;

struct kiocb___204;

struct vm_area_struct___204;

struct inode___204;

struct file_lock___204;

struct page___204;

struct seq_file___188;

struct file_operations___204 {
	struct module___172 *owner;
	loff_t (*llseek)(struct file___204 *, loff_t, int);
	ssize_t (*read)(struct file___204 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___204 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___204 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___204 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___204 *, bool);
	int (*iterate)(struct file___204 *, struct dir_context *);
	int (*iterate_shared)(struct file___204 *, struct dir_context *);
	__poll_t (*poll)(struct file___204 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___204 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___204 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___204 *, struct vm_area_struct___204 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___204 *, struct file___204 *);
	int (*flush)(struct file___204 *, fl_owner_t);
	int (*release)(struct inode___204 *, struct file___204 *);
	int (*fsync)(struct file___204 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___204 *, int);
	int (*lock)(struct file___204 *, int, struct file_lock___204 *);
	ssize_t (*sendpage)(struct file___204 *, struct page___204 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___204 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___204 *, int, struct file_lock___204 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___204 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___204 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___204 *, long int, struct file_lock___204 **, void **);
	long int (*fallocate)(struct file___204 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___188 *, struct file___204 *);
	ssize_t (*copy_file_range)(struct file___204 *, loff_t, struct file___204 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___204 *, loff_t, struct file___204 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___204 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___203 {
	u64 seqnum;
	struct vm_area_struct___204 *vmas[4];
};

struct page_frag___203 {
	struct page___204 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___203;

struct cred___198;

struct task_struct___204 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___204 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___203 *mm;
	struct mm_struct___203 *active_mm;
	struct vmacache___203 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___204 *real_parent;
	struct task_struct___204 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___204 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___161 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___161 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___161 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___198 *ptracer_cred;
	const struct cred___198 *real_cred;
	const struct cred___198 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___204 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___54 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___203 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___204 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___120 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___203;

struct super_block___203;

struct dentry___203 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___203 *d_parent;
	struct qstr d_name;
	struct inode___204 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___203 *d_op;
	struct super_block___203 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct rw_semaphore___204 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___204 *owner;
};

struct address_space_operations___203;

struct address_space___203 {
	struct inode___204 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___204 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___203 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___203;

struct block_device___204;

struct inode___204 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___203 *i_op;
	struct super_block___203 *i_sb;
	struct address_space___203 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___204 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___204 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___203 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___204 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vfsmount___47;

struct path___203;

struct dentry_operations___203 {
	int (*d_revalidate)(struct dentry___203 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___203 *, unsigned int);
	int (*d_hash)(const struct dentry___203 *, struct qstr *);
	int (*d_compare)(const struct dentry___203 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___203 *);
	int (*d_init)(struct dentry___203 *);
	void (*d_release)(struct dentry___203 *);
	void (*d_prune)(struct dentry___203 *);
	void (*d_iput)(struct dentry___203 *, struct inode___204 *);
	char * (*d_dname)(struct dentry___203 *, char *, int);
	struct vfsmount___47 * (*d_automount)(struct path___203 *);
	int (*d_manage)(const struct path___203 *, bool);
	struct dentry___203 * (*d_real)(struct dentry___203 *, const struct inode___204 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___203;

struct mem_dqinfo___203 {
	struct quota_format_type___203 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___203;

struct quota_info___203 {
	unsigned int flags;
	struct rw_semaphore___204 dqio_sem;
	struct inode___204 *files[3];
	struct mem_dqinfo___203 info[3];
	const struct quota_format_ops___203 *ops[3];
};

struct rcuwait___203 {
	struct task_struct___204 *task;
};

struct percpu_rw_semaphore___203 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___204 rw_sem;
	struct rcuwait___203 writer;
	int readers_block;
};

struct sb_writers___203 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___203 rw_sem[3];
};

struct file_system_type___203;

struct super_operations___203;

struct dquot_operations___203;

struct quotactl_ops___203;

struct super_block___203 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___203 *s_type;
	const struct super_operations___203 *s_op;
	const struct dquot_operations___203 *dq_op;
	const struct quotactl_ops___203 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___203 *s_root;
	struct rw_semaphore___204 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___204 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___203 s_dquot;
	struct sb_writers___203 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___203 *s_d_op;
	int cleancache_poolid;
	struct shrinker___92 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___47 {
	struct dentry___203 *mnt_root;
	struct super_block___203 *mnt_sb;
	int mnt_flags;
};

struct path___203 {
	struct vfsmount___47 *mnt;
	struct dentry___203 *dentry;
};

typedef struct page___204 *pgtable_t___203;

struct dev_pagemap___200;

struct page___204 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___203 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___204 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___203 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___203 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___200 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___203;

struct lruvec___203 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___203 *pgdat;
};

struct zone___203 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___203 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___203 {
	struct zone___203 *zone;
	int zone_idx;
};

struct zonelist___203 {
	struct zoneref___203 _zonerefs[25];
};

struct pglist_data___203 {
	struct zone___203 node_zones[3];
	struct zonelist___203 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___204 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___204 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___203 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___204 {
	void *stack;
	struct task_struct___204 *task;
	long int status;
};

struct blocking_notifier_head___203 {
	struct rw_semaphore___204 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___200;

struct vm_area_struct___204 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___204 *vm_next;
	struct vm_area_struct___204 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___203 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___200 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___204 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct linux_binfmt___25;

struct core_state___203;

struct mm_struct___203 {
	struct {
		struct vm_area_struct___204 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___204 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___204 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___25 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___203 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___204 *owner;
		struct user_namespace___3 *user_ns;
		struct file___204 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___203 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___200)(struct vm_area_struct___204 *, long unsigned int, const struct page___204 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___200)(struct page___204 *, void *);

struct dev_pagemap___200 {
	dev_page_fault_t___200 page_fault;
	dev_page_free_t___200 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___6 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct file___204 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___203 f_path;
	struct inode___204 *f_inode;
	const struct file_operations___204 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___161 f_owner;
	const struct cred___198 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___203 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___200;

struct vm_operations_struct___200 {
	void (*open)(struct vm_area_struct___204 *);
	void (*close)(struct vm_area_struct___204 *);
	int (*split)(struct vm_area_struct___204 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___204 *);
	vm_fault_t (*fault)(struct vm_fault___200 *);
	vm_fault_t (*huge_fault)(struct vm_fault___200 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___200 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___204 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___200 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___200 *);
	int (*access)(struct vm_area_struct___204 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___204 *);
	int (*set_policy)(struct vm_area_struct___204 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___204 *, long unsigned int);
	struct page___204 * (*find_special_page)(struct vm_area_struct___204 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___203 {
	struct task_struct___204 *task;
	struct core_thread___203 *next;
};

struct core_state___203 {
	atomic_t nr_threads;
	struct core_thread___203 dumper;
	struct completion startup;
};

struct linux_binprm___26;

struct coredump_params___25;

struct linux_binfmt___25 {
	struct list_head lh;
	struct module___172 *module;
	int (*load_binary)(struct linux_binprm___26 *);
	int (*load_shlib)(struct file___204 *);
	int (*core_dump)(struct coredump_params___25 *);
	long unsigned int min_coredump;
};

struct vm_fault___200 {
	struct vm_area_struct___204 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___204 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___204 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___203 prealloc_pte;
};

struct key___198;

struct user_struct___198 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___198 *uid_keyring;
	struct key___198 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___198 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___198 *session_keyring;
	struct key___198 *process_keyring;
	struct key___198 *thread_keyring;
	struct key___198 *request_key_auth;
	void *security;
	struct user_struct___198 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

union thread_union___182 {
	struct task_struct___204 task;
	long unsigned int stack[8192];
};

struct kiocb___204 {
	struct file___204 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___204 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___203 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___204 *ia_file;
};

struct dquot___203 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___203 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___203 {
	int qf_fmt_id;
	const struct quota_format_ops___203 *qf_ops;
	struct module___172 *qf_owner;
	struct quota_format_type___203 *qf_next;
};

struct quota_format_ops___203 {
	int (*check_quota_file)(struct super_block___203 *, int);
	int (*read_file_info)(struct super_block___203 *, int);
	int (*write_file_info)(struct super_block___203 *, int);
	int (*free_file_info)(struct super_block___203 *, int);
	int (*read_dqblk)(struct dquot___203 *);
	int (*commit_dqblk)(struct dquot___203 *);
	int (*release_dqblk)(struct dquot___203 *);
	int (*get_next_id)(struct super_block___203 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___203 {
	int (*write_dquot)(struct dquot___203 *);
	struct dquot___203 * (*alloc_dquot)(struct super_block___203 *, int);
	void (*destroy_dquot)(struct dquot___203 *);
	int (*acquire_dquot)(struct dquot___203 *);
	int (*release_dquot)(struct dquot___203 *);
	int (*mark_dirty)(struct dquot___203 *);
	int (*write_info)(struct super_block___203 *, int);
	qsize_t * (*get_reserved_space)(struct inode___204 *);
	int (*get_projid)(struct inode___204 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___204 *, qsize_t *);
	int (*get_next_id)(struct super_block___203 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___203 {
	int (*quota_on)(struct super_block___203 *, int, int, const struct path___203 *);
	int (*quota_off)(struct super_block___203 *, int);
	int (*quota_enable)(struct super_block___203 *, unsigned int);
	int (*quota_disable)(struct super_block___203 *, unsigned int);
	int (*quota_sync)(struct super_block___203 *, int);
	int (*set_info)(struct super_block___203 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___203 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___203 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___203 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___203 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___203 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___194;

struct kobj_type___194;

struct kernfs_node___198;

struct kobject___195 {
	const char *name;
	struct list_head entry;
	struct kobject___195 *parent;
	struct kset___194 *kset;
	struct kobj_type___194 *ktype;
	struct kernfs_node___198 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___169 {
	struct kobject___195 kobj;
	struct module___172 *mod;
	struct kobject___195 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___169 {
	struct module___172 *mod;
	struct latch_tree_node node;
};

struct module_layout___169 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___169 mtn;
};

struct module_attribute___169;

struct kernel_param___169;

struct module___172 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___169 mkobj;
	struct module_attribute___169 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___195 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___169 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___169 core_layout;
	struct module_layout___169 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___203 {
	int (*writepage)(struct page___204 *, struct writeback_control___3 *);
	int (*readpage)(struct file___204 *, struct page___204 *);
	int (*writepages)(struct address_space___203 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___204 *);
	int (*readpages)(struct file___204 *, struct address_space___203 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___204 *, struct address_space___203 *, loff_t, unsigned int, unsigned int, struct page___204 **, void **);
	int (*write_end)(struct file___204 *, struct address_space___203 *, loff_t, unsigned int, unsigned int, struct page___204 *, void *);
	sector_t (*bmap)(struct address_space___203 *, sector_t);
	void (*invalidatepage)(struct page___204 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___204 *, gfp_t);
	void (*freepage)(struct page___204 *);
	ssize_t (*direct_IO)(struct kiocb___204 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___203 *, struct page___204 *, struct page___204 *, enum migrate_mode);
	bool (*isolate_page)(struct page___204 *, isolate_mode_t);
	void (*putback_page)(struct page___204 *);
	int (*launder_page)(struct page___204 *);
	int (*is_partially_uptodate)(struct page___204 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___204 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___203 *, struct page___204 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___204 *, sector_t *);
	void (*swap_deactivate)(struct file___204 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___204 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___204 *bd_inode;
	struct super_block___203 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___204 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___203 {
	struct dentry___203 * (*lookup)(struct inode___204 *, struct dentry___203 *, unsigned int);
	const char * (*get_link)(struct dentry___203 *, struct inode___204 *, struct delayed_call *);
	int (*permission)(struct inode___204 *, int);
	struct posix_acl * (*get_acl)(struct inode___204 *, int);
	int (*readlink)(struct dentry___203 *, char *, int);
	int (*create)(struct inode___204 *, struct dentry___203 *, umode_t, bool);
	int (*link)(struct dentry___203 *, struct inode___204 *, struct dentry___203 *);
	int (*unlink)(struct inode___204 *, struct dentry___203 *);
	int (*symlink)(struct inode___204 *, struct dentry___203 *, const char *);
	int (*mkdir)(struct inode___204 *, struct dentry___203 *, umode_t);
	int (*rmdir)(struct inode___204 *, struct dentry___203 *);
	int (*mknod)(struct inode___204 *, struct dentry___203 *, umode_t, dev_t);
	int (*rename)(struct inode___204 *, struct dentry___203 *, struct inode___204 *, struct dentry___203 *, unsigned int);
	int (*setattr)(struct dentry___203 *, struct iattr___203 *);
	int (*getattr)(const struct path___203 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___203 *, char *, size_t);
	int (*fiemap)(struct inode___204 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___204 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___204 *, struct dentry___203 *, struct file___204 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___204 *, struct dentry___203 *, umode_t);
	int (*set_acl)(struct inode___204 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___203 {
	void (*fl_copy_lock)(struct file_lock___204 *, struct file_lock___204 *);
	void (*fl_release_private)(struct file_lock___204 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___203;

struct lock_manager_operations___203;

struct file_lock___204 {
	struct file_lock___204 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___204 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___203 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___203 *fl_ops;
	const struct lock_manager_operations___203 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___203 {
	int (*lm_compare_owner)(struct file_lock___204 *, struct file_lock___204 *);
	long unsigned int (*lm_owner_key)(struct file_lock___204 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___204 *);
	int (*lm_grant)(struct file_lock___204 *, int);
	bool (*lm_break)(struct file_lock___204 *);
	int (*lm_change)(struct file_lock___204 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___204 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___203 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___203 *fa_next;
	struct file___204 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___203 {
	const char *name;
	int fs_flags;
	struct dentry___203 * (*mount)(struct file_system_type___203 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___203 *);
	struct module___172 *owner;
	struct file_system_type___203 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___203 {
	struct inode___204 * (*alloc_inode)(struct super_block___203 *);
	void (*destroy_inode)(struct inode___204 *);
	void (*dirty_inode)(struct inode___204 *, int);
	int (*write_inode)(struct inode___204 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___204 *);
	void (*evict_inode)(struct inode___204 *);
	void (*put_super)(struct super_block___203 *);
	int (*sync_fs)(struct super_block___203 *, int);
	int (*freeze_super)(struct super_block___203 *);
	int (*freeze_fs)(struct super_block___203 *);
	int (*thaw_super)(struct super_block___203 *);
	int (*unfreeze_fs)(struct super_block___203 *);
	int (*statfs)(struct dentry___203 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___203 *, int *, char *);
	void (*umount_begin)(struct super_block___203 *);
	int (*show_options)(struct seq_file___188 *, struct dentry___203 *);
	int (*show_devname)(struct seq_file___188 *, struct dentry___203 *);
	int (*show_path)(struct seq_file___188 *, struct dentry___203 *);
	int (*show_stats)(struct seq_file___188 *, struct dentry___203 *);
	ssize_t (*quota_read)(struct super_block___203 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___203 *, int, const char *, size_t, loff_t);
	struct dquot___203 ** (*get_dquots)(struct inode___204 *);
	int (*bdev_try_to_free_page)(struct super_block___203 *, struct page___204 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___203 *, struct shrink_control___92 *);
	long int (*free_cached_objects)(struct super_block___203 *, struct shrink_control___92 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___186;

struct seq_file___188 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___186 *op;
	int poll_event;
	const struct file___204 *file;
	void *private;
};

typedef int (*proc_write_t___6)(struct file___204 *, char *, size_t);

struct kobj_attribute___194 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___195 *, struct kobj_attribute___194 *, char *);
	ssize_t (*store)(struct kobject___195 *, struct kobj_attribute___194 *, const char *, size_t);
};

typedef void compound_page_dtor___200(struct page___204 *);

struct kernfs_root___198;

struct kernfs_elem_dir___198 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___198 *root;
};

struct kernfs_syscall_ops___198;

struct kernfs_root___198 {
	struct kernfs_node___198 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___198 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___198 {
	struct kernfs_node___198 *target_kn;
};

struct kernfs_ops___198;

struct kernfs_elem_attr___198 {
	const struct kernfs_ops___198 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___198 *notify_next;
};

struct kernfs_node___198 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___198 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___198 dir;
		struct kernfs_elem_symlink___198 symlink;
		struct kernfs_elem_attr___198 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___198;

struct kernfs_ops___198 {
	int (*open)(struct kernfs_open_file___198 *);
	void (*release)(struct kernfs_open_file___198 *);
	int (*seq_show)(struct seq_file___188 *, void *);
	void * (*seq_start)(struct seq_file___188 *, loff_t *);
	void * (*seq_next)(struct seq_file___188 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___188 *, void *);
	ssize_t (*read)(struct kernfs_open_file___198 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___198 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___198 *, struct vm_area_struct___204 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___198 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___198 {
	int (*remount_fs)(struct kernfs_root___198 *, int *, char *);
	int (*show_options)(struct seq_file___188 *, struct kernfs_root___198 *);
	int (*mkdir)(struct kernfs_node___198 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___198 *);
	int (*rename)(struct kernfs_node___198 *, struct kernfs_node___198 *, const char *);
	int (*show_path)(struct seq_file___188 *, struct kernfs_node___198 *, struct kernfs_root___198 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___198 {
	struct kernfs_node___198 *kn;
	struct file___204 *file;
	struct seq_file___188 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___200 *vm_ops;
};

struct sysfs_ops___194 {
	ssize_t (*show)(struct kobject___195 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___195 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___194;

struct kset___194 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___195 kobj;
	const struct kset_uevent_ops___194 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___194 {
	void (*release)(struct kobject___195 *);
	const struct sysfs_ops___194 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___12 * (*child_ns_type)(struct kobject___195 *);
	const void * (*namespace)(struct kobject___195 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___194 {
	int (* const filter)(struct kset___194 *, struct kobject___195 *);
	const char * (* const name)(struct kset___194 *, struct kobject___195 *);
	int (* const uevent)(struct kset___194 *, struct kobject___195 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___169 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___169 *);
	int (*get)(char *, const struct kernel_param___169 *);
	void (*free)(void *);
};

struct kparam_array___169;

struct kernel_param___169 {
	const char *name;
	struct module___172 *mod;
	const struct kernel_param_ops___169 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___169 *arr;
	};
};

struct kparam_array___169 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___169 *ops;
	void *elem;
};

struct module_attribute___169 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___169 *, struct module_kobject___169 *, char *);
	ssize_t (*store)(struct module_attribute___169 *, struct module_kobject___169 *, const char *, size_t);
	void (*setup)(struct module___172 *, const char *);
	int (*test)(struct module___172 *);
	void (*free)(struct module___172 *);
};

typedef int (*key_restrict_link_func_t___198)(struct key___198 *, const struct key_type *, const union key_payload *, struct key___198 *);

struct key_restriction___198;

struct key___198 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___204 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___198 *restrict_link;
};

struct key_restriction___198 {
	key_restrict_link_func_t___198 check;
	struct key___198 *key;
	struct key_type *keytype;
};

struct seq_operations___186 {
	void * (*start)(struct seq_file___188 *, loff_t *);
	void (*stop)(struct seq_file___188 *, void *);
	void * (*next)(struct seq_file___188 *, void *, loff_t *);
	int (*show)(struct seq_file___188 *, void *);
};

struct proc_ns_operations___16;

struct ns_common___16 {
	atomic_long_t stashed;
	const struct proc_ns_operations___16 *ops;
	unsigned int inum;
};

struct proc_ns_operations___16 {
	const char *name;
	const char *real_ns_name;
	int type;
	struct ns_common___16 * (*get)(struct task_struct___204 *);
	void (*put)(struct ns_common___16 *);
	int (*install)(struct nsproxy___8 *, struct ns_common___16 *);
	struct user_namespace___3 * (*owner)(struct ns_common___16 *);
	struct ns_common___16 * (*get_parent)(struct ns_common___16 *);
};

struct linux_binprm___26 {
	char buf[256];
	struct vm_area_struct___204 *vma;
	long unsigned int vma_pages;
	struct mm_struct___203 *mm;
	long unsigned int p;
	unsigned int called_set_creds: 1;
	unsigned int cap_elevated: 1;
	unsigned int secureexec: 1;
	unsigned int recursion_depth;
	struct file___204 *file;
	struct cred___198 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
};

struct coredump_params___25 {
	union {
		const kernel_siginfo_t *siginfo;
		struct {
			const siginfo_t *siginfo;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	struct pt_regs *regs;
	struct file___204 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
};

struct proc_dir_entry___7 {
	atomic_t in_use;
	refcount_t refcnt;
	struct list_head pde_openers;
	spinlock_t pde_unload_lock;
	struct completion *pde_unload_completion;
	const struct inode_operations___203 *proc_iops;
	const struct file_operations___204 *proc_fops;
	union {
		const struct seq_operations___186 *seq_ops;
		int (*single_show)(struct seq_file___188 *, void *);
	};
	proc_write_t___6 write;
	void *data;
	unsigned int state_size;
	unsigned int low_ino;
	nlink_t nlink;
	kuid_t uid;
	kgid_t gid;
	loff_t size;
	struct proc_dir_entry___7 *parent;
	struct rb_root subdir;
	struct rb_node subdir_node;
	char *name;
	umode_t mode;
	u8 namelen;
	char inline_name[0];
};

union proc_op___5 {
	int (*proc_get_link)(struct dentry___203 *, struct path___203 *);
	int (*proc_show)(struct seq_file___188 *, struct pid_namespace *, struct pid___161 *, struct task_struct___204 *);
};

struct proc_inode___5 {
	struct pid___161 *pid;
	unsigned int fd;
	union proc_op___5 op;
	struct proc_dir_entry___7 *pde;
	struct ctl_table_header *sysctl;
	struct ctl_table *sysctl_entry;
	struct hlist_node sysctl_inodes;
	const struct proc_ns_operations___16 *ns_ops;
	struct inode___204 vfs_inode;
};

struct file___205;

struct kiocb___205;

struct vm_area_struct___205;

struct inode___205;

struct file_lock___205;

struct page___205;

struct seq_file___189;

struct file_operations___205 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___205 *, loff_t, int);
	ssize_t (*read)(struct file___205 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___205 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___205 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___205 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___205 *, bool);
	int (*iterate)(struct file___205 *, struct dir_context *);
	int (*iterate_shared)(struct file___205 *, struct dir_context *);
	__poll_t (*poll)(struct file___205 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___205 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___205 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___205 *, struct vm_area_struct___205 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___205 *, struct file___205 *);
	int (*flush)(struct file___205 *, fl_owner_t);
	int (*release)(struct inode___205 *, struct file___205 *);
	int (*fsync)(struct file___205 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___205 *, int);
	int (*lock)(struct file___205 *, int, struct file_lock___205 *);
	ssize_t (*sendpage)(struct file___205 *, struct page___205 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___205 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___205 *, int, struct file_lock___205 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___205 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___205 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___205 *, long int, struct file_lock___205 **, void **);
	long int (*fallocate)(struct file___205 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___189 *, struct file___205 *);
	ssize_t (*copy_file_range)(struct file___205 *, loff_t, struct file___205 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___205 *, loff_t, struct file___205 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___205 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___204 {
	u64 seqnum;
	struct vm_area_struct___205 *vmas[4];
};

struct page_frag___204 {
	struct page___205 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___204;

struct mem_cgroup___93;

struct pid___162;

struct cred___199;

struct fs_struct___15;

struct files_struct___14;

struct nsproxy___193;

struct signal_struct___178;

struct bio_list___104;

struct backing_dev_info___104;

struct io_context___55;

struct css_set___169;

struct request_queue___52;

struct vm_struct___141;

struct task_struct___205 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___205 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___204 *mm;
	struct mm_struct___204 *active_mm;
	struct vmacache___204 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___205 *real_parent;
	struct task_struct___205 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___205 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___93 *active_memcg;
	long int rh_reserved2;
	struct pid___162 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___162 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___162 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___199 *ptracer_cred;
	const struct cred___199 *real_cred;
	const struct cred___199 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct___15 *fs;
	struct files_struct___14 *files;
	struct nsproxy___193 *nsproxy;
	struct signal_struct___178 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___205 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___104 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___104 *backing_dev_info;
	struct io_context___55 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___169 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___204 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___93 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___52 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___205 *oom_reaper_list;
	struct vm_struct___141 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___120 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct secondary_data___205 {
	void *stack;
	struct task_struct___205 *task;
	long int status;
};

typedef int (*proc_write_t___7)(struct file___205 *, char *, size_t);

struct inode_operations___204;

struct seq_operations___187;

struct proc_dir_entry___8 {
	atomic_t in_use;
	refcount_t refcnt;
	struct list_head pde_openers;
	spinlock_t pde_unload_lock;
	struct completion *pde_unload_completion;
	const struct inode_operations___204 *proc_iops;
	const struct file_operations___205 *proc_fops;
	union {
		const struct seq_operations___187 *seq_ops;
		int (*single_show)(struct seq_file___189 *, void *);
	};
	proc_write_t___7 write;
	void *data;
	unsigned int state_size;
	unsigned int low_ino;
	nlink_t nlink;
	kuid_t uid;
	kgid_t gid;
	loff_t size;
	struct proc_dir_entry___8 *parent;
	struct rb_root subdir;
	struct rb_node subdir_node;
	char *name;
	umode_t mode;
	u8 namelen;
	char inline_name[0];
};

struct pid_namespace___162;

struct upid___162 {
	int nr;
	struct pid_namespace___162 *ns;
};

struct proc_ns_operations___17;

struct ns_common___17 {
	atomic_long_t stashed;
	const struct proc_ns_operations___17 *ops;
	unsigned int inum;
};

struct dentry___204;

struct user_namespace___179;

struct ucounts___179;

struct pid_namespace___162 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___205 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___162 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___204 *proc_self;
	struct dentry___204 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___179 *user_ns;
	struct ucounts___179 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___17 ns;
};

struct pid___162 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___162 numbers[1];
};

struct rw_semaphore___205 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___205 *owner;
};

struct key___199;

struct user_namespace___179 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___179 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___17 ns;
	long unsigned int flags;
	struct key___199 *persistent_keyring_register;
	struct rw_semaphore___205 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___179 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___205 *pgtable_t___204;

struct address_space___204;

struct dev_pagemap___201;

struct page___205 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___204 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___205 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___204 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___204 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___201 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___93 *mem_cgroup;
};

struct user_struct___199 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___199 *uid_keyring;
	struct key___199 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___201;

struct vm_area_struct___205 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___205 *vm_next;
	struct vm_area_struct___205 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___204 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___201 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___205 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct linux_binfmt___26;

struct core_state___204;

struct mm_struct___204 {
	struct {
		struct vm_area_struct___205 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___205 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___205 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___26 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___204 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___205 *owner;
		struct user_namespace___179 *user_ns;
		struct file___205 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___204 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup___169;

struct cgroup_subsys___169;

struct cgroup_subsys_state___170 {
	struct cgroup___169 *cgroup;
	struct cgroup_subsys___169 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___170 *parent;
};

struct kernfs_node___199;

struct cgroup_file___169 {
	struct kernfs_node___199 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___93;

struct mem_cgroup___93 {
	struct cgroup_subsys_state___170 css;
	struct mem_cgroup_id___8 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___169 events_file;
	struct cgroup_file___169 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___205 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___93 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cred___199 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___199 *session_keyring;
	struct key___199 *process_keyring;
	struct key___199 *thread_keyring;
	struct key___199 *request_key_auth;
	void *security;
	struct user_struct___199 *user;
	struct user_namespace___179 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct path___204 {
	struct vfsmount *mnt;
	struct dentry___204 *dentry;
};

struct fs_struct___15 {
	int users;
	spinlock_t lock;
	seqcount_t seq;
	int umask;
	int in_exec;
	struct path___204 root;
	struct path___204 pwd;
};

struct fdtable___14 {
	unsigned int max_fds;
	struct file___205 **fd;
	long unsigned int *close_on_exec;
	long unsigned int *open_fds;
	long unsigned int *full_fds_bits;
	struct callback_head rcu;
};

struct files_struct___14 {
	atomic_t count;
	bool resize_in_progress;
	wait_queue_head_t resize_wait;
	struct fdtable___14 *fdt;
	struct fdtable___14 fdtab;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t file_lock;
	unsigned int next_fd;
	long unsigned int close_on_exec_init[1];
	long unsigned int open_fds_init[1];
	long unsigned int full_fds_bits_init[1];
	struct file___205 *fd_array[64];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cgroup_namespace___169;

struct nsproxy___193 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___162 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___169 *cgroup_ns;
};

struct tty_struct___17;

struct signal_struct___178 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___205 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___205 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___162 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___162 *tty_old_pgrp;
	int leader;
	struct tty_struct___17 *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___204 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___162 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___104;

struct bio_list___104 {
	struct bio___104 *head;
	struct bio___104 *tail;
};

struct bdi_writeback_congested___104;

struct bdi_writeback___104 {
	struct backing_dev_info___104 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___104 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___170 *memcg_css;
	struct cgroup_subsys_state___170 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___182;

struct backing_dev_info___104 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___104 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___182 *dev;
	struct device___182 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___204 *debug_dir;
	struct dentry___204 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___55;

struct io_context___55 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___55 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___169 {
	struct cgroup_subsys_state___170 *subsys[13];
	refcount_t refcount;
	struct css_set___169 *dom_cset;
	struct cgroup___169 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___169 *mg_src_cgrp;
	struct cgroup___169 *mg_dst_cgrp;
	struct css_set___169 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

typedef blk_qc_t make_request_fn___51(struct request_queue___52 *, struct bio___104 *);

struct request___52;

typedef int dma_drain_needed_fn___51(struct request___52 *);

struct kset___195;

struct kobj_type___195;

struct kobject___196 {
	const char *name;
	struct list_head entry;
	struct kobject___196 *parent;
	struct kset___195 *kset;
	struct kobj_type___195 *ktype;
	struct kernfs_node___199 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___51;

struct bsg_class_device___51 {
	struct device___182 *class_dev;
	int minor;
	struct request_queue___52 *queue;
	const struct bsg_ops___51 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___104 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___104 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___51;

struct blkcg_gq___40;

struct request_queue___52 {
	struct list_head queue_head;
	struct request___52 *last_merge;
	struct elevator_queue___51 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___51 *make_request_fn;
	dma_drain_needed_fn___51 *dma_drain_needed;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___104 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___196 kobj;
	struct kobject___196 *mq_kobj;
	struct blk_integrity integrity;
	struct device___182 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___40 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	struct bsg_class_device___51 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___104 bio_split;
	struct dentry___204 *debugfs_dir;
	struct dentry___204 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___141 {
	struct vm_struct___141 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___205 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___183 {
	struct task_struct___205 task;
	long unsigned int stack[8192];
};

struct dentry_operations___204;

struct super_block___204;

struct dentry___204 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___204 *d_parent;
	struct qstr d_name;
	struct inode___205 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___204 *d_op;
	struct super_block___204 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___204;

struct address_space___204 {
	struct inode___205 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___205 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___204 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___205;

struct cdev___35;

struct inode___205 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___204 *i_op;
	struct super_block___204 *i_sb;
	struct address_space___204 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___205 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___104 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___205 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___204 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___205 *i_bdev;
		struct cdev___35 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___204 {
	int (*d_revalidate)(struct dentry___204 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___204 *, unsigned int);
	int (*d_hash)(const struct dentry___204 *, struct qstr *);
	int (*d_compare)(const struct dentry___204 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___204 *);
	int (*d_init)(struct dentry___204 *);
	void (*d_release)(struct dentry___204 *);
	void (*d_prune)(struct dentry___204 *);
	void (*d_iput)(struct dentry___204 *, struct inode___205 *);
	char * (*d_dname)(struct dentry___204 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___204 *);
	int (*d_manage)(const struct path___204 *, bool);
	struct dentry___204 * (*d_real)(struct dentry___204 *, const struct inode___205 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___204;

struct mem_dqinfo___204 {
	struct quota_format_type___204 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___204;

struct quota_info___204 {
	unsigned int flags;
	struct rw_semaphore___205 dqio_sem;
	struct inode___205 *files[3];
	struct mem_dqinfo___204 info[3];
	const struct quota_format_ops___204 *ops[3];
};

struct rcuwait___204 {
	struct task_struct___205 *task;
};

struct percpu_rw_semaphore___204 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___205 rw_sem;
	struct rcuwait___204 writer;
	int readers_block;
};

struct sb_writers___204 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___204 rw_sem[3];
};

struct shrink_control___93;

struct shrinker___93 {
	long unsigned int (*count_objects)(struct shrinker___93 *, struct shrink_control___93 *);
	long unsigned int (*scan_objects)(struct shrinker___93 *, struct shrink_control___93 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___204;

struct super_operations___204;

struct dquot_operations___204;

struct quotactl_ops___204;

struct super_block___204 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___204 *s_type;
	const struct super_operations___204 *s_op;
	const struct dquot_operations___204 *dq_op;
	const struct quotactl_ops___204 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___204 *s_root;
	struct rw_semaphore___205 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___205 *s_bdev;
	struct backing_dev_info___104 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___204 s_dquot;
	struct sb_writers___204 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___204 *s_d_op;
	int cleancache_poolid;
	struct shrinker___93 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___179 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___93 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___93 *memcg;
};

struct pglist_data___204;

struct lruvec___204 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___204 *pgdat;
};

struct zone___204 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___204 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___204 {
	struct zone___204 *zone;
	int zone_idx;
};

struct zonelist___204 {
	struct zoneref___204 _zonerefs[25];
};

struct pglist_data___204 {
	struct zone___204 node_zones[3];
	struct zonelist___204 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___205 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___205 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___204 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___204 {
	struct rw_semaphore___205 rwsem;
	struct notifier_block *head;
};

typedef int (*dev_page_fault_t___201)(struct vm_area_struct___205 *, long unsigned int, const struct page___205 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___201)(struct page___205 *, void *);

struct dev_pagemap___201 {
	dev_page_fault_t___201 page_fault;
	dev_page_free_t___201 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___182 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct fown_struct___162 {
	rwlock_t lock;
	struct pid___162 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___205 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___204 f_path;
	struct inode___205 *f_inode;
	const struct file_operations___205 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___162 f_owner;
	const struct cred___199 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___204 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___201;

struct vm_operations_struct___201 {
	void (*open)(struct vm_area_struct___205 *);
	void (*close)(struct vm_area_struct___205 *);
	int (*split)(struct vm_area_struct___205 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___205 *);
	vm_fault_t (*fault)(struct vm_fault___201 *);
	vm_fault_t (*huge_fault)(struct vm_fault___201 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___201 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___205 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___201 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___201 *);
	int (*access)(struct vm_area_struct___205 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___205 *);
	int (*set_policy)(struct vm_area_struct___205 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___205 *, long unsigned int);
	struct page___205 * (*find_special_page)(struct vm_area_struct___205 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___204 {
	struct task_struct___205 *task;
	struct core_thread___204 *next;
};

struct core_state___204 {
	atomic_t nr_threads;
	struct core_thread___204 dumper;
	struct completion startup;
};

struct linux_binprm___27;

struct coredump_params___26;

struct linux_binfmt___26 {
	struct list_head lh;
	struct module___11 *module;
	int (*load_binary)(struct linux_binprm___27 *);
	int (*load_shlib)(struct file___205 *);
	int (*core_dump)(struct coredump_params___26 *);
	long unsigned int min_coredump;
};

struct vm_fault___201 {
	struct vm_area_struct___205 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___205 *cow_page;
	struct mem_cgroup___93 *memcg;
	struct page___205 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___204 prealloc_pte;
};

struct io_cq___55 {
	struct request_queue___52 *q;
	struct io_context___55 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___6 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___205 {
	struct file___205 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___205 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___204 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___205 *ia_file;
};

struct dquot___204 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___204 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___204 {
	int qf_fmt_id;
	const struct quota_format_ops___204 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___204 *qf_next;
};

struct quota_format_ops___204 {
	int (*check_quota_file)(struct super_block___204 *, int);
	int (*read_file_info)(struct super_block___204 *, int);
	int (*write_file_info)(struct super_block___204 *, int);
	int (*free_file_info)(struct super_block___204 *, int);
	int (*read_dqblk)(struct dquot___204 *);
	int (*commit_dqblk)(struct dquot___204 *);
	int (*release_dqblk)(struct dquot___204 *);
	int (*get_next_id)(struct super_block___204 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___204 {
	int (*write_dquot)(struct dquot___204 *);
	struct dquot___204 * (*alloc_dquot)(struct super_block___204 *, int);
	void (*destroy_dquot)(struct dquot___204 *);
	int (*acquire_dquot)(struct dquot___204 *);
	int (*release_dquot)(struct dquot___204 *);
	int (*mark_dirty)(struct dquot___204 *);
	int (*write_info)(struct super_block___204 *, int);
	qsize_t * (*get_reserved_space)(struct inode___205 *);
	int (*get_projid)(struct inode___205 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___205 *, qsize_t *);
	int (*get_next_id)(struct super_block___204 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___204 {
	int (*quota_on)(struct super_block___204 *, int, int, const struct path___204 *);
	int (*quota_off)(struct super_block___204 *, int);
	int (*quota_enable)(struct super_block___204 *, unsigned int);
	int (*quota_disable)(struct super_block___204 *, unsigned int);
	int (*quota_sync)(struct super_block___204 *, int);
	int (*set_info)(struct super_block___204 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___204 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___204 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___204 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___204 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___204 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___100;

struct swap_info_struct___66;

struct address_space_operations___204 {
	int (*writepage)(struct page___205 *, struct writeback_control___100 *);
	int (*readpage)(struct file___205 *, struct page___205 *);
	int (*writepages)(struct address_space___204 *, struct writeback_control___100 *);
	int (*set_page_dirty)(struct page___205 *);
	int (*readpages)(struct file___205 *, struct address_space___204 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___205 *, struct address_space___204 *, loff_t, unsigned int, unsigned int, struct page___205 **, void **);
	int (*write_end)(struct file___205 *, struct address_space___204 *, loff_t, unsigned int, unsigned int, struct page___205 *, void *);
	sector_t (*bmap)(struct address_space___204 *, sector_t);
	void (*invalidatepage)(struct page___205 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___205 *, gfp_t);
	void (*freepage)(struct page___205 *);
	ssize_t (*direct_IO)(struct kiocb___205 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___204 *, struct page___205 *, struct page___205 *, enum migrate_mode);
	bool (*isolate_page)(struct page___205 *, isolate_mode_t);
	void (*putback_page)(struct page___205 *);
	int (*launder_page)(struct page___205 *);
	int (*is_partially_uptodate)(struct page___205 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___205 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___204 *, struct page___205 *);
	int (*swap_activate)(struct swap_info_struct___66 *, struct file___205 *, sector_t *);
	void (*swap_deactivate)(struct file___205 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___100 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___104 *wb;
	struct inode___205 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct swap_info_struct___66 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___205 *bdev;
	struct file___205 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct hd_struct___52;

struct gendisk___52;

struct block_device___205 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___205 *bd_inode;
	struct super_block___204 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___205 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___52 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___52 *bd_disk;
	struct request_queue___52 *bd_queue;
	struct backing_dev_info___104 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___182 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___182 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___182;

struct bus_type___182;

struct device_driver___182;

struct dev_pm_domain___182;

struct fwnode_handle___127;

struct class___182;

struct attribute_group___184;

struct device___182 {
	struct device___182 *parent;
	struct device_private *p;
	struct kobject___196 kobj;
	const char *init_name;
	const struct device_type___182 *type;
	struct mutex mutex;
	struct bus_type___182 *bus;
	struct device_driver___182 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___182 power;
	struct dev_pm_domain___182 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___127 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___182 *class;
	const struct attribute_group___184 **groups;
	void (*release)(struct device___182 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___52 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___182 __dev;
	struct kobject___196 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___52;

struct block_device_operations___52;

struct gendisk___52 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___52 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___52 *part_tbl;
	struct hd_struct___52 part0;
	const struct block_device_operations___52 *fops;
	struct request_queue___52 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___205 lookup_sem;
	struct kobject___196 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___196 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___35 {
	struct kobject___196 kobj;
	struct module___11 *owner;
	const struct file_operations___205 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___204 {
	struct dentry___204 * (*lookup)(struct inode___205 *, struct dentry___204 *, unsigned int);
	const char * (*get_link)(struct dentry___204 *, struct inode___205 *, struct delayed_call *);
	int (*permission)(struct inode___205 *, int);
	struct posix_acl * (*get_acl)(struct inode___205 *, int);
	int (*readlink)(struct dentry___204 *, char *, int);
	int (*create)(struct inode___205 *, struct dentry___204 *, umode_t, bool);
	int (*link)(struct dentry___204 *, struct inode___205 *, struct dentry___204 *);
	int (*unlink)(struct inode___205 *, struct dentry___204 *);
	int (*symlink)(struct inode___205 *, struct dentry___204 *, const char *);
	int (*mkdir)(struct inode___205 *, struct dentry___204 *, umode_t);
	int (*rmdir)(struct inode___205 *, struct dentry___204 *);
	int (*mknod)(struct inode___205 *, struct dentry___204 *, umode_t, dev_t);
	int (*rename)(struct inode___205 *, struct dentry___204 *, struct inode___205 *, struct dentry___204 *, unsigned int);
	int (*setattr)(struct dentry___204 *, struct iattr___204 *);
	int (*getattr)(const struct path___204 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___204 *, char *, size_t);
	int (*fiemap)(struct inode___205 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___205 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___205 *, struct dentry___204 *, struct file___205 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___205 *, struct dentry___204 *, umode_t);
	int (*set_acl)(struct inode___205 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___204 {
	void (*fl_copy_lock)(struct file_lock___205 *, struct file_lock___205 *);
	void (*fl_release_private)(struct file_lock___205 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___204;

struct lock_manager_operations___204;

struct file_lock___205 {
	struct file_lock___205 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___205 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___204 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___204 *fl_ops;
	const struct lock_manager_operations___204 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___204 {
	int (*lm_compare_owner)(struct file_lock___205 *, struct file_lock___205 *);
	long unsigned int (*lm_owner_key)(struct file_lock___205 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___205 *);
	int (*lm_grant)(struct file_lock___205 *, int);
	bool (*lm_break)(struct file_lock___205 *);
	int (*lm_change)(struct file_lock___205 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___205 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___204 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___204 *fa_next;
	struct file___205 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___204 {
	const char *name;
	int fs_flags;
	struct dentry___204 * (*mount)(struct file_system_type___204 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___204 *);
	struct module___11 *owner;
	struct file_system_type___204 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___204 {
	struct inode___205 * (*alloc_inode)(struct super_block___204 *);
	void (*destroy_inode)(struct inode___205 *);
	void (*dirty_inode)(struct inode___205 *, int);
	int (*write_inode)(struct inode___205 *, struct writeback_control___100 *);
	int (*drop_inode)(struct inode___205 *);
	void (*evict_inode)(struct inode___205 *);
	void (*put_super)(struct super_block___204 *);
	int (*sync_fs)(struct super_block___204 *, int);
	int (*freeze_super)(struct super_block___204 *);
	int (*freeze_fs)(struct super_block___204 *);
	int (*thaw_super)(struct super_block___204 *);
	int (*unfreeze_fs)(struct super_block___204 *);
	int (*statfs)(struct dentry___204 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___204 *, int *, char *);
	void (*umount_begin)(struct super_block___204 *);
	int (*show_options)(struct seq_file___189 *, struct dentry___204 *);
	int (*show_devname)(struct seq_file___189 *, struct dentry___204 *);
	int (*show_path)(struct seq_file___189 *, struct dentry___204 *);
	int (*show_stats)(struct seq_file___189 *, struct dentry___204 *);
	ssize_t (*quota_read)(struct super_block___204 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___204 *, int, const char *, size_t, loff_t);
	struct dquot___204 ** (*get_dquots)(struct inode___205 *);
	int (*bdev_try_to_free_page)(struct super_block___204 *, struct page___205 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___204 *, struct shrink_control___93 *);
	long int (*free_cached_objects)(struct super_block___204 *, struct shrink_control___93 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_file___189 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___187 *op;
	int poll_event;
	const struct file___205 *file;
	void *private;
};

typedef void bio_end_io_t___104(struct bio___104 *);

struct bio_vec___104 {
	struct page___205 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___104;

struct bio___104 {
	struct bio___104 *bi_next;
	struct gendisk___52 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___104 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___40 *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___104 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___104 *bi_io_vec;
	struct bio_set___104 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___104 bi_inline_vecs[0];
};

struct kernfs_root___199;

struct kernfs_elem_dir___199 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___199 *root;
};

struct kernfs_syscall_ops___199;

struct kernfs_root___199 {
	struct kernfs_node___199 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___199 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___199 {
	struct kernfs_node___199 *target_kn;
};

struct kernfs_ops___199;

struct kernfs_elem_attr___199 {
	const struct kernfs_ops___199 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___199 *notify_next;
};

struct kernfs_node___199 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___199 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___199 dir;
		struct kernfs_elem_symlink___199 symlink;
		struct kernfs_elem_attr___199 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___199;

struct kernfs_ops___199 {
	int (*open)(struct kernfs_open_file___199 *);
	void (*release)(struct kernfs_open_file___199 *);
	int (*seq_show)(struct seq_file___189 *, void *);
	void * (*seq_start)(struct seq_file___189 *, loff_t *);
	void * (*seq_next)(struct seq_file___189 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___189 *, void *);
	ssize_t (*read)(struct kernfs_open_file___199 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___199 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___199 *, struct vm_area_struct___205 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___199 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___199 {
	int (*remount_fs)(struct kernfs_root___199 *, int *, char *);
	int (*show_options)(struct seq_file___189 *, struct kernfs_root___199 *);
	int (*mkdir)(struct kernfs_node___199 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___199 *);
	int (*rename)(struct kernfs_node___199 *, struct kernfs_node___199 *, const char *);
	int (*show_path)(struct seq_file___189 *, struct kernfs_node___199 *, struct kernfs_root___199 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___199 {
	struct kernfs_node___199 *kn;
	struct file___205 *file;
	struct seq_file___189 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___201 *vm_ops;
};

struct bin_attribute___183;

struct attribute_group___184 {
	const char *name;
	umode_t (*is_visible)(struct kobject___196 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___196 *, struct bin_attribute___183 *, int);
	struct attribute **attrs;
	struct bin_attribute___183 **bin_attrs;
};

struct bin_attribute___183 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___205 *, struct kobject___196 *, struct bin_attribute___183 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___205 *, struct kobject___196 *, struct bin_attribute___183 *, char *, loff_t, size_t);
	int (*mmap)(struct file___205 *, struct kobject___196 *, struct bin_attribute___183 *, struct vm_area_struct___205 *);
};

struct sysfs_ops___195 {
	ssize_t (*show)(struct kobject___196 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___196 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___195;

struct kset___195 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___196 kobj;
	const struct kset_uevent_ops___195 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___195 {
	void (*release)(struct kobject___196 *);
	const struct sysfs_ops___195 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___12 * (*child_ns_type)(struct kobject___196 *);
	const void * (*namespace)(struct kobject___196 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___195 {
	int (* const filter)(struct kset___195 *, struct kobject___196 *);
	const char * (* const name)(struct kset___195 *, struct kobject___196 *);
	int (* const uevent)(struct kset___195 *, struct kobject___196 *, struct kobj_uevent_env *);
};

struct kobj_attribute___195 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___196 *, struct kobj_attribute___195 *, char *);
	ssize_t (*store)(struct kobject___196 *, struct kobj_attribute___195 *, const char *, size_t);
};

struct dev_pm_ops___182 {
	int (*prepare)(struct device___182 *);
	void (*complete)(struct device___182 *);
	int (*suspend)(struct device___182 *);
	int (*resume)(struct device___182 *);
	int (*freeze)(struct device___182 *);
	int (*thaw)(struct device___182 *);
	int (*poweroff)(struct device___182 *);
	int (*restore)(struct device___182 *);
	int (*suspend_late)(struct device___182 *);
	int (*resume_early)(struct device___182 *);
	int (*freeze_late)(struct device___182 *);
	int (*thaw_early)(struct device___182 *);
	int (*poweroff_late)(struct device___182 *);
	int (*restore_early)(struct device___182 *);
	int (*suspend_noirq)(struct device___182 *);
	int (*resume_noirq)(struct device___182 *);
	int (*freeze_noirq)(struct device___182 *);
	int (*thaw_noirq)(struct device___182 *);
	int (*poweroff_noirq)(struct device___182 *);
	int (*restore_noirq)(struct device___182 *);
	int (*runtime_suspend)(struct device___182 *);
	int (*runtime_resume)(struct device___182 *);
	int (*runtime_idle)(struct device___182 *);
};

struct dev_pm_domain___182 {
	struct dev_pm_ops___182 ops;
	void (*detach)(struct device___182 *, bool);
	int (*activate)(struct device___182 *);
	void (*sync)(struct device___182 *);
	void (*dismiss)(struct device___182 *);
};

struct bus_type___182 {
	const char *name;
	const char *dev_name;
	struct device___182 *dev_root;
	const struct attribute_group___184 **bus_groups;
	const struct attribute_group___184 **dev_groups;
	const struct attribute_group___184 **drv_groups;
	int (*match)(struct device___182 *, struct device_driver___182 *);
	int (*uevent)(struct device___182 *, struct kobj_uevent_env *);
	int (*probe)(struct device___182 *);
	int (*remove)(struct device___182 *);
	void (*shutdown)(struct device___182 *);
	int (*online)(struct device___182 *);
	int (*offline)(struct device___182 *);
	int (*suspend)(struct device___182 *, pm_message_t);
	int (*resume)(struct device___182 *);
	int (*num_vf)(struct device___182 *);
	int (*dma_configure)(struct device___182 *);
	const struct dev_pm_ops___182 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___182 {
	const char *name;
	struct bus_type___182 *bus;
	struct module___11 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___182 *);
	int (*remove)(struct device___182 *);
	void (*shutdown)(struct device___182 *);
	int (*suspend)(struct device___182 *, pm_message_t);
	int (*resume)(struct device___182 *);
	const struct attribute_group___184 **groups;
	const struct dev_pm_ops___182 *pm;
	void (*coredump)(struct device___182 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___182 {
	const char *name;
	const struct attribute_group___184 **groups;
	int (*uevent)(struct device___182 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___182 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___182 *);
	const struct dev_pm_ops___182 *pm;
};

struct class___182 {
	const char *name;
	struct module___11 *owner;
	const struct attribute_group___184 **class_groups;
	const struct attribute_group___184 **dev_groups;
	struct kobject___196 *dev_kobj;
	int (*dev_uevent)(struct device___182 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___182 *, umode_t *);
	void (*class_release)(struct class___182 *);
	void (*dev_release)(struct device___182 *);
	int (*shutdown_pre)(struct device___182 *);
	const struct kobj_ns_type_operations___12 *ns_type;
	const void * (*namespace)(struct device___182 *);
	const struct dev_pm_ops___182 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct fwnode_operations___127;

struct fwnode_handle___127 {
	struct fwnode_handle___127 *secondary;
	const struct fwnode_operations___127 *ops;
};

typedef int (*key_restrict_link_func_t___199)(struct key___199 *, const struct key_type *, const union key_payload *, struct key___199 *);

struct key_restriction___199;

struct key___199 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___205 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___199 *restrict_link;
};

struct key_restriction___199 {
	key_restrict_link_func_t___199 check;
	struct key___199 *key;
	struct key_type *keytype;
};

struct seq_operations___187 {
	void * (*start)(struct seq_file___189 *, loff_t *);
	void (*stop)(struct seq_file___189 *, void *);
	void * (*next)(struct seq_file___189 *, void *, loff_t *);
	int (*show)(struct seq_file___189 *, void *);
};

struct tty_driver___17;

struct tty_operations___17 {
	struct tty_struct___17 * (*lookup)(struct tty_driver___17 *, struct file___205 *, int);
	int (*install)(struct tty_driver___17 *, struct tty_struct___17 *);
	void (*remove)(struct tty_driver___17 *, struct tty_struct___17 *);
	int (*open)(struct tty_struct___17 *, struct file___205 *);
	void (*close)(struct tty_struct___17 *, struct file___205 *);
	void (*shutdown)(struct tty_struct___17 *);
	void (*cleanup)(struct tty_struct___17 *);
	int (*write)(struct tty_struct___17 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___17 *, unsigned char);
	void (*flush_chars)(struct tty_struct___17 *);
	int (*write_room)(struct tty_struct___17 *);
	int (*chars_in_buffer)(struct tty_struct___17 *);
	int (*ioctl)(struct tty_struct___17 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___17 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___17 *, struct ktermios *);
	void (*throttle)(struct tty_struct___17 *);
	void (*unthrottle)(struct tty_struct___17 *);
	void (*stop)(struct tty_struct___17 *);
	void (*start)(struct tty_struct___17 *);
	void (*hangup)(struct tty_struct___17 *);
	int (*break_ctl)(struct tty_struct___17 *, int);
	void (*flush_buffer)(struct tty_struct___17 *);
	void (*set_ldisc)(struct tty_struct___17 *);
	void (*wait_until_sent)(struct tty_struct___17 *, int);
	void (*send_xchar)(struct tty_struct___17 *, char);
	int (*tiocmget)(struct tty_struct___17 *);
	int (*tiocmset)(struct tty_struct___17 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___17 *, struct winsize *);
	int (*set_termiox)(struct tty_struct___17 *, struct termiox *);
	int (*get_icount)(struct tty_struct___17 *, struct serial_icounter_struct *);
	void (*show_fdinfo)(struct tty_struct___17 *, struct seq_file___189 *);
	int (*poll_init)(struct tty_driver___17 *, int, char *);
	int (*poll_get_char)(struct tty_driver___17 *, int);
	void (*poll_put_char)(struct tty_driver___17 *, int, char);
	int (*proc_show)(struct seq_file___189 *, void *);
};

struct tty_ldisc___17;

struct tty_port___17;

struct tty_struct___17 {
	int magic;
	struct kref kref;
	struct device___182 *dev;
	struct tty_driver___17 *driver;
	const struct tty_operations___17 *ops;
	int index;
	struct ld_semaphore ldisc_sem;
	struct tty_ldisc___17 *ldisc;
	struct mutex atomic_write_lock;
	struct mutex legacy_mutex;
	struct mutex throttle_mutex;
	struct rw_semaphore___205 termios_rwsem;
	struct mutex winsize_mutex;
	spinlock_t ctrl_lock;
	spinlock_t flow_lock;
	struct ktermios termios;
	struct ktermios termios_locked;
	struct termiox *termiox;
	char name[64];
	struct pid___162 *pgrp;
	struct pid___162 *session;
	long unsigned int flags;
	int count;
	struct winsize winsize;
	long unsigned int stopped: 1;
	long unsigned int flow_stopped: 1;
	int: 30;
	long unsigned int unused: 62;
	int hw_stopped;
	long unsigned int ctrl_status: 8;
	long unsigned int packet: 1;
	int: 23;
	long unsigned int unused_ctrl: 55;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___17 *link;
	struct fasync_struct___204 *fasync;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	spinlock_t files_lock;
	struct list_head tty_files;
	int closing;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___17 *port;
};

struct tty_driver___17 {
	int magic;
	struct kref kref;
	struct cdev___35 **cdevs;
	struct module___11 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry___8 *proc_entry;
	struct tty_driver___17 *other;
	struct tty_struct___17 **ttys;
	struct tty_port___17 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___17 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___17;

struct tty_port_client_operations___17;

struct tty_port___17 {
	struct tty_bufhead buf;
	struct tty_struct___17 *tty;
	struct tty_struct___17 *itty;
	const struct tty_port_operations___17 *ops;
	const struct tty_port_client_operations___17 *client_ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	unsigned char low_latency: 1;
	struct mutex mutex;
	struct mutex buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
	void *client_data;
};

struct tty_ldisc_ops___17 {
	int magic;
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___17 *);
	void (*close)(struct tty_struct___17 *);
	void (*flush_buffer)(struct tty_struct___17 *);
	ssize_t (*read)(struct tty_struct___17 *, struct file___205 *, unsigned char *, size_t);
	ssize_t (*write)(struct tty_struct___17 *, struct file___205 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___17 *, struct file___205 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___17 *, struct file___205 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___17 *, struct ktermios *);
	__poll_t (*poll)(struct tty_struct___17 *, struct file___205 *, struct poll_table_struct___6 *);
	int (*hangup)(struct tty_struct___17 *);
	void (*receive_buf)(struct tty_struct___17 *, const unsigned char *, char *, int);
	void (*write_wakeup)(struct tty_struct___17 *);
	void (*dcd_change)(struct tty_struct___17 *, unsigned int);
	int (*receive_buf2)(struct tty_struct___17 *, const unsigned char *, char *, int);
	struct module___11 *owner;
	int refcount;
};

struct tty_ldisc___17 {
	struct tty_ldisc_ops___17 *ops;
	struct tty_struct___17 *tty;
};

struct tty_port_operations___17 {
	int (*carrier_raised)(struct tty_port___17 *);
	void (*dtr_rts)(struct tty_port___17 *, int);
	void (*shutdown)(struct tty_port___17 *);
	int (*activate)(struct tty_port___17 *, struct tty_struct___17 *);
	void (*destruct)(struct tty_port___17 *);
};

struct tty_port_client_operations___17 {
	int (*receive_buf)(struct tty_port___17 *, const unsigned char *, const unsigned char *, size_t);
	void (*write_wakeup)(struct tty_port___17 *);
};

typedef void compound_page_dtor___201(struct page___205 *);

struct fwnode_reference_args___127;

struct fwnode_endpoint___127;

struct fwnode_operations___127 {
	struct fwnode_handle___127 * (*get)(struct fwnode_handle___127 *);
	void (*put)(struct fwnode_handle___127 *);
	bool (*device_is_available)(const struct fwnode_handle___127 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___127 *, const struct device___182 *);
	bool (*property_present)(const struct fwnode_handle___127 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___127 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___127 *, const char *, const char **, size_t);
	struct fwnode_handle___127 * (*get_parent)(const struct fwnode_handle___127 *);
	struct fwnode_handle___127 * (*get_next_child_node)(const struct fwnode_handle___127 *, struct fwnode_handle___127 *);
	struct fwnode_handle___127 * (*get_named_child_node)(const struct fwnode_handle___127 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___127 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___127 *);
	struct fwnode_handle___127 * (*graph_get_next_endpoint)(const struct fwnode_handle___127 *, struct fwnode_handle___127 *);
	struct fwnode_handle___127 * (*graph_get_remote_endpoint)(const struct fwnode_handle___127 *);
	struct fwnode_handle___127 * (*graph_get_port_parent)(struct fwnode_handle___127 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___127 *, struct fwnode_endpoint___127 *);
};

struct fwnode_endpoint___127 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___127 *local_fwnode;
};

struct fwnode_reference_args___127 {
	struct fwnode_handle___127 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct proc_ns_operations___17 {
	const char *name;
	const char *real_ns_name;
	int type;
	struct ns_common___17 * (*get)(struct task_struct___205 *);
	void (*put)(struct ns_common___17 *);
	int (*install)(struct nsproxy___193 *, struct ns_common___17 *);
	struct user_namespace___179 * (*owner)(struct ns_common___17 *);
	struct ns_common___17 * (*get_parent)(struct ns_common___17 *);
};

struct cgroup_namespace___169 {
	refcount_t count;
	struct ns_common___17 ns;
	struct user_namespace___179 *user_ns;
	struct ucounts___179 *ucounts;
	struct css_set___169 *root_cset;
};

struct ucounts___179 {
	struct hlist_node node;
	struct user_namespace___179 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___169;

struct bpf_map_ops___169 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___169 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___169 *, struct file___205 *);
	void (*map_free)(struct bpf_map___169 *);
	int (*map_get_next_key)(struct bpf_map___169 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___169 *);
	void * (*map_lookup_elem)(struct bpf_map___169 *, void *);
	int (*map_update_elem)(struct bpf_map___169 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___169 *, void *);
	int (*map_push_elem)(struct bpf_map___169 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___169 *, void *);
	int (*map_peek_elem)(struct bpf_map___169 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___169 *, struct file___205 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___169 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___169 *, void *, struct seq_file___189 *);
	int (*map_check_btf)(const struct bpf_map___169 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___169 {
	const struct bpf_map_ops___169 *ops;
	struct bpf_map___169 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___199 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___169;

typedef void (*kthread_work_func_t___169)(struct kthread_work___169 *);

struct kthread_worker___169;

struct kthread_work___169 {
	struct list_head node;
	kthread_work_func_t___169 func;
	struct kthread_worker___169 *worker;
	int canceling;
};

struct kthread_worker___169 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___205 *task;
	struct kthread_work___169 *current_work;
};

struct kthread_delayed_work___169 {
	struct kthread_work___169 work;
	struct timer_list timer;
};

struct psi_group___169 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___169 *poll_kworker;
	struct kthread_delayed_work___169 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___169;

struct cgroup_rstat_cpu___169;

struct cgroup___169 {
	struct cgroup_subsys_state___170 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___199 *kn;
	struct cgroup_file___169 procs_file;
	struct cgroup_file___169 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___170 *subsys[13];
	struct cgroup_root___169 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___169 *dom_cgrp;
	struct cgroup_rstat_cpu___169 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___22 bpf;
	atomic_t congestion_count;
	struct cgroup___169 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___169 psi;
	int ancestor_ids[0];
};

struct cftype___169;

struct cgroup_subsys___169 {
	struct cgroup_subsys_state___170 * (*css_alloc)(struct cgroup_subsys_state___170 *);
	int (*css_online)(struct cgroup_subsys_state___170 *);
	void (*css_offline)(struct cgroup_subsys_state___170 *);
	void (*css_released)(struct cgroup_subsys_state___170 *);
	void (*css_free)(struct cgroup_subsys_state___170 *);
	void (*css_reset)(struct cgroup_subsys_state___170 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___170 *, int);
	int (*css_extra_stat_show)(struct seq_file___189 *, struct cgroup_subsys_state___170 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___205 *);
	void (*cancel_fork)(struct task_struct___205 *);
	void (*fork)(struct task_struct___205 *);
	void (*exit)(struct task_struct___205 *);
	void (*free)(struct task_struct___205 *);
	void (*bind)(struct cgroup_subsys_state___170 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___169 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___169 *dfl_cftypes;
	struct cftype___169 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___169 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___169 *updated_children;
	struct cgroup___169 *updated_next;
};

struct cgroup_root___169 {
	struct kernfs_root___199 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___169 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___169 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___169 *ss;
	struct list_head node;
	struct kernfs_ops___199 *kf_ops;
	int (*open)(struct kernfs_open_file___199 *);
	void (*release)(struct kernfs_open_file___199 *);
	u64 (*read_u64)(struct cgroup_subsys_state___170 *, struct cftype___169 *);
	s64 (*read_s64)(struct cgroup_subsys_state___170 *, struct cftype___169 *);
	int (*seq_show)(struct seq_file___189 *, void *);
	void * (*seq_start)(struct seq_file___189 *, loff_t *);
	void * (*seq_next)(struct seq_file___189 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___189 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___170 *, struct cftype___169 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___170 *, struct cftype___169 *, s64);
	ssize_t (*write)(struct kernfs_open_file___199 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___199 *, struct poll_table_struct___6 *);
};

struct hstate___38 {
	int next_nid_to_alloc;
	int next_nid_to_free;
	unsigned int order;
	long unsigned int mask;
	long unsigned int max_huge_pages;
	long unsigned int nr_huge_pages;
	long unsigned int free_huge_pages;
	long unsigned int resv_huge_pages;
	long unsigned int surplus_huge_pages;
	long unsigned int nr_overcommit_huge_pages;
	struct list_head hugepage_activelist;
	struct list_head hugepage_freelists[8];
	unsigned int nr_huge_pages_node[8];
	unsigned int free_huge_pages_node[8];
	unsigned int surplus_huge_pages_node[8];
	struct cftype___169 cgroup_files[5];
	char name[32];
};

struct bdi_writeback_congested___104 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___104 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___104 {
	struct bio___104 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___104 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___104 bip_inline_vecs[0];
};

struct blkcg___40;

struct blkg_policy_data___40;

struct blkcg_gq___40 {
	struct request_queue___52 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___40 *blkcg;
	struct bdi_writeback_congested___104 *wb_congested;
	struct blkcg_gq___40 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_rwstat stat_bytes;
	struct blkg_rwstat stat_ios;
	struct blkg_policy_data___40 *pd[5];
	struct callback_head callback_head;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
};

struct mem_cgroup_reclaim_iter___93 {
	struct mem_cgroup___93 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___93 {
	struct lruvec___204 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___93 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___93 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct node___157 {
	struct device___182 dev;
};

struct disk_part_tbl___52 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___52 *last_lookup;
	struct hd_struct___52 *part[0];
};

struct block_device_operations___52 {
	int (*open)(struct block_device___205 *, fmode_t);
	void (*release)(struct gendisk___52 *, fmode_t);
	int (*rw_page)(struct block_device___205 *, sector_t, struct page___205 *, unsigned int);
	int (*ioctl)(struct block_device___205 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___205 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___52 *, unsigned int);
	int (*media_changed)(struct gendisk___52 *);
	void (*unlock_native_capacity)(struct gendisk___52 *);
	int (*revalidate_disk)(struct gendisk___52 *);
	int (*getgeo)(struct block_device___205 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___205 *, long unsigned int);
	int (*report_zones)(struct gendisk___52 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___11 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___51 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___52 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___52 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___52 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___51(struct request___52 *, blk_status_t);

struct request___52 {
	struct request_queue___52 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___104 *bio;
	struct bio___104 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___104 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___55 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___51 *saved_end_io;
		} flush;
	};
	struct gendisk___52 *rq_disk;
	struct hd_struct___52 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___51 *end_io;
	void *end_io_data;
	struct request___52 *next_rq;
};

struct elevator_type___51;

struct elevator_mq_ops___51 {
	int (*init_sched)(struct request_queue___52 *, struct elevator_type___51 *);
	void (*exit_sched)(struct elevator_queue___51 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	bool (*allow_merge)(struct request_queue___52 *, struct request___52 *, struct bio___104 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx *, struct bio___104 *);
	int (*request_merge)(struct request_queue___52 *, struct request___52 **, struct bio___104 *);
	void (*request_merged)(struct request_queue___52 *, struct request___52 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___52 *, struct request___52 *, struct request___52 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___52 *, struct bio___104 *);
	void (*finish_request)(struct request___52 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___52 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___52 *, u64);
	void (*started_request)(struct request___52 *);
	void (*requeue_request)(struct request___52 *);
	struct request___52 * (*former_request)(struct request_queue___52 *, struct request___52 *);
	struct request___52 * (*next_request)(struct request_queue___52 *, struct request___52 *);
	void (*init_icq)(struct io_cq___55 *);
	void (*exit_icq)(struct io_cq___55 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___51;

struct elevator_type___51 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___51 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___51 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___11 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___51 {
	struct elevator_type___51 *type;
	void *elevator_data;
	struct kobject___196 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___51 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___51 *, char *);
	ssize_t (*store)(struct elevator_queue___51 *, const char *, size_t);
};

struct blkcg_policy_data___40;

struct blkcg___40 {
	struct cgroup_subsys_state___170 css;
	spinlock_t lock;
	struct xarray blkg_tree;
	struct blkcg_gq___40 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___40 *cpd[5];
	struct list_head all_blkcgs_node;
	struct list_head cgwb_list;
	refcount_t cgwb_refcnt;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct blkcg_policy_data___40 {
	struct blkcg___40 *blkcg;
	int plid;
};

struct blkg_policy_data___40 {
	struct blkcg_gq___40 *blkg;
	int plid;
};

struct linux_binprm___27 {
	char buf[256];
	struct vm_area_struct___205 *vma;
	long unsigned int vma_pages;
	struct mm_struct___204 *mm;
	long unsigned int p;
	unsigned int called_set_creds: 1;
	unsigned int cap_elevated: 1;
	unsigned int secureexec: 1;
	unsigned int recursion_depth;
	struct file___205 *file;
	struct cred___199 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
};

struct coredump_params___26 {
	union {
		const kernel_siginfo_t *siginfo;
		struct {
			const siginfo_t *siginfo;
		} __UNIQUE_ID_rh_kabi_hide42;
		union {		};
	};
	struct pt_regs *regs;
	struct file___205 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
};

union proc_op___6 {
	int (*proc_get_link)(struct dentry___204 *, struct path___204 *);
	int (*proc_show)(struct seq_file___189 *, struct pid_namespace___162 *, struct pid___162 *, struct task_struct___205 *);
};

struct proc_inode___6 {
	struct pid___162 *pid;
	unsigned int fd;
	union proc_op___6 op;
	struct proc_dir_entry___8 *pde;
	struct ctl_table_header *sysctl;
	struct ctl_table *sysctl_entry;
	struct hlist_node sysctl_inodes;
	const struct proc_ns_operations___17 *ns_ops;
	struct inode___205 vfs_inode;
};

struct file___206;

struct kiocb___206;

struct poll_table_struct___138;

struct vm_area_struct___206;

struct inode___206;

struct file_lock___206;

struct page___206;

struct seq_file___190;

struct file_operations___206 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___206 *, loff_t, int);
	ssize_t (*read)(struct file___206 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___206 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___206 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___206 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___206 *, bool);
	int (*iterate)(struct file___206 *, struct dir_context *);
	int (*iterate_shared)(struct file___206 *, struct dir_context *);
	__poll_t (*poll)(struct file___206 *, struct poll_table_struct___138 *);
	long int (*unlocked_ioctl)(struct file___206 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___206 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___206 *, struct vm_area_struct___206 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___206 *, struct file___206 *);
	int (*flush)(struct file___206 *, fl_owner_t);
	int (*release)(struct inode___206 *, struct file___206 *);
	int (*fsync)(struct file___206 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___206 *, int);
	int (*lock)(struct file___206 *, int, struct file_lock___206 *);
	ssize_t (*sendpage)(struct file___206 *, struct page___206 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___206 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___206 *, int, struct file_lock___206 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___206 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___206 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___206 *, long int, struct file_lock___206 **, void **);
	long int (*fallocate)(struct file___206 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___190 *, struct file___206 *);
	ssize_t (*copy_file_range)(struct file___206 *, loff_t, struct file___206 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___206 *, loff_t, struct file___206 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___206 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___205 {
	u64 seqnum;
	struct vm_area_struct___206 *vmas[4];
};

struct page_frag___205 {
	struct page___206 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___205;

struct cred___200;

struct files_struct___15;

struct signal_struct___179;

struct task_struct___206 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___206 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___205 *mm;
	struct mm_struct___205 *active_mm;
	struct vmacache___205 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___206 *real_parent;
	struct task_struct___206 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___206 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___162 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___162 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___162 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___200 *ptracer_cred;
	const struct cred___200 *real_cred;
	const struct cred___200 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct___15 *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___179 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___206 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___55 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___205 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___206 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___120 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct key___200;

struct user_struct___200 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___200 *uid_keyring;
	struct key___200 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct secondary_data___206 {
	void *stack;
	struct task_struct___206 *task;
	long int status;
};

typedef struct page___206 *pgtable_t___205;

struct address_space___205;

struct dev_pagemap___202;

struct page___206 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___205 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___206 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___205 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___205 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___202 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct vm_operations_struct___202;

struct vm_area_struct___206 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___206 *vm_next;
	struct vm_area_struct___206 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___205 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___202 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___206 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct rw_semaphore___206 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___206 *owner;
};

struct linux_binfmt___27;

struct core_state___205;

struct mm_struct___205 {
	struct {
		struct vm_area_struct___206 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___206 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___206 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___27 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___205 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___206 *owner;
		struct user_namespace___3 *user_ns;
		struct file___206 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___205 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___200 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___200 *session_keyring;
	struct key___200 *process_keyring;
	struct key___200 *thread_keyring;
	struct key___200 *request_key_auth;
	void *security;
	struct user_struct___200 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct fdtable___15 {
	unsigned int max_fds;
	struct file___206 **fd;
	long unsigned int *close_on_exec;
	long unsigned int *open_fds;
	long unsigned int *full_fds_bits;
	struct callback_head rcu;
};

struct files_struct___15 {
	atomic_t count;
	bool resize_in_progress;
	wait_queue_head_t resize_wait;
	struct fdtable___15 *fdt;
	struct fdtable___15 fdtab;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t file_lock;
	unsigned int next_fd;
	long unsigned int close_on_exec_init[1];
	long unsigned int open_fds_init[1];
	long unsigned int full_fds_bits_init[1];
	struct file___206 *fd_array[64];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct signal_struct___179 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___206 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___206 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___162 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___162 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___205 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___162 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

union thread_union___184 {
	struct task_struct___206 task;
	long unsigned int stack[8192];
};

typedef int (*key_restrict_link_func_t___200)(struct key___200 *, const struct key_type *, const union key_payload *, struct key___200 *);

struct key_restriction___200;

struct key___200 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___206 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___200 *restrict_link;
};

struct key_restriction___200 {
	key_restrict_link_func_t___200 check;
	struct key___200 *key;
	struct key_type *keytype;
};

struct dentry_operations___205;

struct super_block___205;

struct dentry___205 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___205 *d_parent;
	struct qstr d_name;
	struct inode___206 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___205 *d_op;
	struct super_block___205 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___205;

struct address_space___205 {
	struct inode___206 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___206 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___205 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___205;

struct block_device___206;

struct inode___206 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___205 *i_op;
	struct super_block___205 *i_sb;
	struct address_space___205 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___206 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___206 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___205 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___206 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vfsmount___48;

struct path___205;

struct dentry_operations___205 {
	int (*d_revalidate)(struct dentry___205 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___205 *, unsigned int);
	int (*d_hash)(const struct dentry___205 *, struct qstr *);
	int (*d_compare)(const struct dentry___205 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___205 *);
	int (*d_init)(struct dentry___205 *);
	void (*d_release)(struct dentry___205 *);
	void (*d_prune)(struct dentry___205 *);
	void (*d_iput)(struct dentry___205 *, struct inode___206 *);
	char * (*d_dname)(struct dentry___205 *, char *, int);
	struct vfsmount___48 * (*d_automount)(struct path___205 *);
	int (*d_manage)(const struct path___205 *, bool);
	struct dentry___205 * (*d_real)(struct dentry___205 *, const struct inode___206 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___205;

struct mem_dqinfo___205 {
	struct quota_format_type___205 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___205;

struct quota_info___205 {
	unsigned int flags;
	struct rw_semaphore___206 dqio_sem;
	struct inode___206 *files[3];
	struct mem_dqinfo___205 info[3];
	const struct quota_format_ops___205 *ops[3];
};

struct rcuwait___205 {
	struct task_struct___206 *task;
};

struct percpu_rw_semaphore___205 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___206 rw_sem;
	struct rcuwait___205 writer;
	int readers_block;
};

struct sb_writers___205 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___205 rw_sem[3];
};

struct file_system_type___205;

struct super_operations___205;

struct dquot_operations___205;

struct quotactl_ops___205;

struct super_block___205 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___205 *s_type;
	const struct super_operations___205 *s_op;
	const struct dquot_operations___205 *dq_op;
	const struct quotactl_ops___205 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___205 *s_root;
	struct rw_semaphore___206 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___206 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___205 s_dquot;
	struct sb_writers___205 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___205 *s_d_op;
	int cleancache_poolid;
	struct shrinker___93 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___48 {
	struct dentry___205 *mnt_root;
	struct super_block___205 *mnt_sb;
	int mnt_flags;
};

struct path___205 {
	struct vfsmount___48 *mnt;
	struct dentry___205 *dentry;
};

struct pglist_data___205;

struct lruvec___205 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___205 *pgdat;
};

struct zone___205 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___205 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___205 {
	struct zone___205 *zone;
	int zone_idx;
};

struct zonelist___205 {
	struct zoneref___205 _zonerefs[25];
};

struct pglist_data___205 {
	struct zone___205 node_zones[3];
	struct zonelist___205 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___206 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___206 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___205 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___205 {
	struct rw_semaphore___206 rwsem;
	struct notifier_block *head;
};

typedef int (*dev_page_fault_t___202)(struct vm_area_struct___206 *, long unsigned int, const struct page___206 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___202)(struct page___206 *, void *);

struct dev_pagemap___202 {
	dev_page_fault_t___202 page_fault;
	dev_page_free_t___202 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___6 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct file___206 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___205 f_path;
	struct inode___206 *f_inode;
	const struct file_operations___206 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___162 f_owner;
	const struct cred___200 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___205 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___202;

struct vm_operations_struct___202 {
	void (*open)(struct vm_area_struct___206 *);
	void (*close)(struct vm_area_struct___206 *);
	int (*split)(struct vm_area_struct___206 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___206 *);
	vm_fault_t (*fault)(struct vm_fault___202 *);
	vm_fault_t (*huge_fault)(struct vm_fault___202 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___202 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___206 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___202 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___202 *);
	int (*access)(struct vm_area_struct___206 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___206 *);
	int (*set_policy)(struct vm_area_struct___206 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___206 *, long unsigned int);
	struct page___206 * (*find_special_page)(struct vm_area_struct___206 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___205 {
	struct task_struct___206 *task;
	struct core_thread___205 *next;
};

struct core_state___205 {
	atomic_t nr_threads;
	struct core_thread___205 dumper;
	struct completion startup;
};

struct linux_binprm___28;

struct coredump_params___27;

struct linux_binfmt___27 {
	struct list_head lh;
	struct module___11 *module;
	int (*load_binary)(struct linux_binprm___28 *);
	int (*load_shlib)(struct file___206 *);
	int (*core_dump)(struct coredump_params___27 *);
	long unsigned int min_coredump;
};

struct vm_fault___202 {
	struct vm_area_struct___206 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___206 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___206 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___205 prealloc_pte;
};

struct kiocb___206 {
	struct file___206 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___206 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___205 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___206 *ia_file;
};

struct dquot___205 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___205 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___205 {
	int qf_fmt_id;
	const struct quota_format_ops___205 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___205 *qf_next;
};

struct quota_format_ops___205 {
	int (*check_quota_file)(struct super_block___205 *, int);
	int (*read_file_info)(struct super_block___205 *, int);
	int (*write_file_info)(struct super_block___205 *, int);
	int (*free_file_info)(struct super_block___205 *, int);
	int (*read_dqblk)(struct dquot___205 *);
	int (*commit_dqblk)(struct dquot___205 *);
	int (*release_dqblk)(struct dquot___205 *);
	int (*get_next_id)(struct super_block___205 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___205 {
	int (*write_dquot)(struct dquot___205 *);
	struct dquot___205 * (*alloc_dquot)(struct super_block___205 *, int);
	void (*destroy_dquot)(struct dquot___205 *);
	int (*acquire_dquot)(struct dquot___205 *);
	int (*release_dquot)(struct dquot___205 *);
	int (*mark_dirty)(struct dquot___205 *);
	int (*write_info)(struct super_block___205 *, int);
	qsize_t * (*get_reserved_space)(struct inode___206 *);
	int (*get_projid)(struct inode___206 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___206 *, qsize_t *);
	int (*get_next_id)(struct super_block___205 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___205 {
	int (*quota_on)(struct super_block___205 *, int, int, const struct path___205 *);
	int (*quota_off)(struct super_block___205 *, int);
	int (*quota_enable)(struct super_block___205 *, unsigned int);
	int (*quota_disable)(struct super_block___205 *, unsigned int);
	int (*quota_sync)(struct super_block___205 *, int);
	int (*set_info)(struct super_block___205 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___205 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___205 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___205 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___205 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___205 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___205 {
	int (*writepage)(struct page___206 *, struct writeback_control___3 *);
	int (*readpage)(struct file___206 *, struct page___206 *);
	int (*writepages)(struct address_space___205 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___206 *);
	int (*readpages)(struct file___206 *, struct address_space___205 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___206 *, struct address_space___205 *, loff_t, unsigned int, unsigned int, struct page___206 **, void **);
	int (*write_end)(struct file___206 *, struct address_space___205 *, loff_t, unsigned int, unsigned int, struct page___206 *, void *);
	sector_t (*bmap)(struct address_space___205 *, sector_t);
	void (*invalidatepage)(struct page___206 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___206 *, gfp_t);
	void (*freepage)(struct page___206 *);
	ssize_t (*direct_IO)(struct kiocb___206 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___205 *, struct page___206 *, struct page___206 *, enum migrate_mode);
	bool (*isolate_page)(struct page___206 *, isolate_mode_t);
	void (*putback_page)(struct page___206 *);
	int (*launder_page)(struct page___206 *);
	int (*is_partially_uptodate)(struct page___206 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___206 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___205 *, struct page___206 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___206 *, sector_t *);
	void (*swap_deactivate)(struct file___206 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___206 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___206 *bd_inode;
	struct super_block___205 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___206 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___205 {
	struct dentry___205 * (*lookup)(struct inode___206 *, struct dentry___205 *, unsigned int);
	const char * (*get_link)(struct dentry___205 *, struct inode___206 *, struct delayed_call *);
	int (*permission)(struct inode___206 *, int);
	struct posix_acl * (*get_acl)(struct inode___206 *, int);
	int (*readlink)(struct dentry___205 *, char *, int);
	int (*create)(struct inode___206 *, struct dentry___205 *, umode_t, bool);
	int (*link)(struct dentry___205 *, struct inode___206 *, struct dentry___205 *);
	int (*unlink)(struct inode___206 *, struct dentry___205 *);
	int (*symlink)(struct inode___206 *, struct dentry___205 *, const char *);
	int (*mkdir)(struct inode___206 *, struct dentry___205 *, umode_t);
	int (*rmdir)(struct inode___206 *, struct dentry___205 *);
	int (*mknod)(struct inode___206 *, struct dentry___205 *, umode_t, dev_t);
	int (*rename)(struct inode___206 *, struct dentry___205 *, struct inode___206 *, struct dentry___205 *, unsigned int);
	int (*setattr)(struct dentry___205 *, struct iattr___205 *);
	int (*getattr)(const struct path___205 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___205 *, char *, size_t);
	int (*fiemap)(struct inode___206 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___206 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___206 *, struct dentry___205 *, struct file___206 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___206 *, struct dentry___205 *, umode_t);
	int (*set_acl)(struct inode___206 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___205 {
	void (*fl_copy_lock)(struct file_lock___206 *, struct file_lock___206 *);
	void (*fl_release_private)(struct file_lock___206 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___205;

struct lock_manager_operations___205;

struct file_lock___206 {
	struct file_lock___206 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___206 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___205 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___205 *fl_ops;
	const struct lock_manager_operations___205 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___205 {
	int (*lm_compare_owner)(struct file_lock___206 *, struct file_lock___206 *);
	long unsigned int (*lm_owner_key)(struct file_lock___206 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___206 *);
	int (*lm_grant)(struct file_lock___206 *, int);
	bool (*lm_break)(struct file_lock___206 *);
	int (*lm_change)(struct file_lock___206 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___206 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___205 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___205 *fa_next;
	struct file___206 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___205 {
	const char *name;
	int fs_flags;
	struct dentry___205 * (*mount)(struct file_system_type___205 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___205 *);
	struct module___11 *owner;
	struct file_system_type___205 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___205 {
	struct inode___206 * (*alloc_inode)(struct super_block___205 *);
	void (*destroy_inode)(struct inode___206 *);
	void (*dirty_inode)(struct inode___206 *, int);
	int (*write_inode)(struct inode___206 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___206 *);
	void (*evict_inode)(struct inode___206 *);
	void (*put_super)(struct super_block___205 *);
	int (*sync_fs)(struct super_block___205 *, int);
	int (*freeze_super)(struct super_block___205 *);
	int (*freeze_fs)(struct super_block___205 *);
	int (*thaw_super)(struct super_block___205 *);
	int (*unfreeze_fs)(struct super_block___205 *);
	int (*statfs)(struct dentry___205 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___205 *, int *, char *);
	void (*umount_begin)(struct super_block___205 *);
	int (*show_options)(struct seq_file___190 *, struct dentry___205 *);
	int (*show_devname)(struct seq_file___190 *, struct dentry___205 *);
	int (*show_path)(struct seq_file___190 *, struct dentry___205 *);
	int (*show_stats)(struct seq_file___190 *, struct dentry___205 *);
	ssize_t (*quota_read)(struct super_block___205 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___205 *, int, const char *, size_t, loff_t);
	struct dquot___205 ** (*get_dquots)(struct inode___206 *);
	int (*bdev_try_to_free_page)(struct super_block___205 *, struct page___206 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___205 *, struct shrink_control___93 *);
	long int (*free_cached_objects)(struct super_block___205 *, struct shrink_control___93 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___139)(struct file___206 *, wait_queue_head_t *, struct poll_table_struct___138 *);

struct poll_table_struct___138 {
	poll_queue_proc___139 _qproc;
	__poll_t _key;
};

struct seq_operations___188;

struct seq_file___190 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___188 *op;
	int poll_event;
	const struct file___206 *file;
	void *private;
};

typedef void compound_page_dtor___202(struct page___206 *);

struct seq_operations___188 {
	void * (*start)(struct seq_file___190 *, loff_t *);
	void (*stop)(struct seq_file___190 *, void *);
	void * (*next)(struct seq_file___190 *, void *, loff_t *);
	int (*show)(struct seq_file___190 *, void *);
};

typedef int (*proc_write_t___8)(struct file___206 *, char *, size_t);

struct proc_ns_operations___18;

struct ns_common___18 {
	atomic_long_t stashed;
	const struct proc_ns_operations___18 *ops;
	unsigned int inum;
};

struct proc_ns_operations___18 {
	const char *name;
	const char *real_ns_name;
	int type;
	struct ns_common___18 * (*get)(struct task_struct___206 *);
	void (*put)(struct ns_common___18 *);
	int (*install)(struct nsproxy___8 *, struct ns_common___18 *);
	struct user_namespace___3 * (*owner)(struct ns_common___18 *);
	struct ns_common___18 * (*get_parent)(struct ns_common___18 *);
};

struct mount___11;

struct mnt_namespace___11 {
	atomic_t count;
	struct ns_common___18 ns;
	struct mount___11 *root;
	struct list_head list;
	struct user_namespace___3 *user_ns;
	struct ucounts___2 *ucounts;
	u64 seq;
	wait_queue_head_t poll;
	u64 event;
	unsigned int mounts;
	unsigned int pending_mounts;
};

struct mountpoint___11;

struct mount___11 {
	struct hlist_node mnt_hash;
	struct mount___11 *mnt_parent;
	struct dentry___205 *mnt_mountpoint;
	struct vfsmount___48 mnt;
	union {
		struct callback_head mnt_rcu;
		struct llist_node mnt_llist;
	};
	struct mnt_pcp *mnt_pcp;
	struct list_head mnt_mounts;
	struct list_head mnt_child;
	struct list_head mnt_instance;
	const char *mnt_devname;
	struct list_head mnt_list;
	struct list_head mnt_expire;
	struct list_head mnt_share;
	struct list_head mnt_slave_list;
	struct list_head mnt_slave;
	struct mount___11 *mnt_master;
	struct mnt_namespace___11 *mnt_ns;
	struct mountpoint___11 *mnt_mp;
	struct hlist_node mnt_mp_list;
	struct list_head mnt_umounting;
	struct fsnotify_mark_connector *mnt_fsnotify_marks;
	__u32 mnt_fsnotify_mask;
	int mnt_id;
	int mnt_group_id;
	int mnt_expiry_mark;
	struct hlist_head mnt_pins;
	struct fs_pin mnt_umount;
	struct dentry___205 *mnt_ex_mountpoint;
};

struct mountpoint___11 {
	struct hlist_node m_hash;
	struct dentry___205 *m_dentry;
	struct hlist_head m_list;
	int m_count;
};

struct linux_binprm___28 {
	char buf[256];
	struct vm_area_struct___206 *vma;
	long unsigned int vma_pages;
	struct mm_struct___205 *mm;
	long unsigned int p;
	unsigned int called_set_creds: 1;
	unsigned int cap_elevated: 1;
	unsigned int secureexec: 1;
	unsigned int recursion_depth;
	struct file___206 *file;
	struct cred___200 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
};

struct coredump_params___27 {
	union {
		const kernel_siginfo_t *siginfo;
		struct {
			const siginfo_t *siginfo;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	struct pt_regs *regs;
	struct file___206 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
};

struct proc_dir_entry___9 {
	atomic_t in_use;
	refcount_t refcnt;
	struct list_head pde_openers;
	spinlock_t pde_unload_lock;
	struct completion *pde_unload_completion;
	const struct inode_operations___205 *proc_iops;
	const struct file_operations___206 *proc_fops;
	union {
		const struct seq_operations___188 *seq_ops;
		int (*single_show)(struct seq_file___190 *, void *);
	};
	proc_write_t___8 write;
	void *data;
	unsigned int state_size;
	unsigned int low_ino;
	nlink_t nlink;
	kuid_t uid;
	kgid_t gid;
	loff_t size;
	struct proc_dir_entry___9 *parent;
	struct rb_root subdir;
	struct rb_node subdir_node;
	char *name;
	umode_t mode;
	u8 namelen;
	char inline_name[0];
};

union proc_op___7 {
	int (*proc_get_link)(struct dentry___205 *, struct path___205 *);
	int (*proc_show)(struct seq_file___190 *, struct pid_namespace *, struct pid___162 *, struct task_struct___206 *);
};

struct proc_inode___7 {
	struct pid___162 *pid;
	unsigned int fd;
	union proc_op___7 op;
	struct proc_dir_entry___9 *pde;
	struct ctl_table_header *sysctl;
	struct ctl_table *sysctl_entry;
	struct hlist_node sysctl_inodes;
	const struct proc_ns_operations___18 *ns_ops;
	struct inode___206 vfs_inode;
};

typedef struct dentry___205 *instantiate_t___2(struct dentry___205 *, struct task_struct___206 *, const void *);

struct fd_data {
	fmode_t mode;
	unsigned int fd;
};

struct module___173;

struct file___207;

struct kiocb___207;

struct vm_area_struct___207;

struct inode___207;

struct file_lock___207;

struct page___207;

struct seq_file___191;

struct file_operations___207 {
	struct module___173 *owner;
	loff_t (*llseek)(struct file___207 *, loff_t, int);
	ssize_t (*read)(struct file___207 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___207 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___207 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___207 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___207 *, bool);
	int (*iterate)(struct file___207 *, struct dir_context *);
	int (*iterate_shared)(struct file___207 *, struct dir_context *);
	__poll_t (*poll)(struct file___207 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___207 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___207 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___207 *, struct vm_area_struct___207 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___207 *, struct file___207 *);
	int (*flush)(struct file___207 *, fl_owner_t);
	int (*release)(struct inode___207 *, struct file___207 *);
	int (*fsync)(struct file___207 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___207 *, int);
	int (*lock)(struct file___207 *, int, struct file_lock___207 *);
	ssize_t (*sendpage)(struct file___207 *, struct page___207 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___207 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___207 *, int, struct file_lock___207 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___207 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___207 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___207 *, long int, struct file_lock___207 **, void **);
	long int (*fallocate)(struct file___207 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___191 *, struct file___207 *);
	ssize_t (*copy_file_range)(struct file___207 *, loff_t, struct file___207 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___207 *, loff_t, struct file___207 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___207 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___206 {
	u64 seqnum;
	struct vm_area_struct___207 *vmas[4];
};

struct page_frag___206 {
	struct page___207 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___206;

struct cred___201;

struct task_struct___207 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___207 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___206 *mm;
	struct mm_struct___206 *active_mm;
	struct vmacache___206 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___207 *real_parent;
	struct task_struct___207 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___207 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___162 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___162 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___162 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___201 *ptracer_cred;
	const struct cred___201 *real_cred;
	const struct cred___201 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___207 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___55 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___206 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___207 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___120 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct secondary_data___207 {
	void *stack;
	struct task_struct___207 *task;
	long int status;
};

typedef struct page___207 *pgtable_t___206;

struct address_space___206;

struct page___207 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___206 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___207 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___206 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___206 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___202 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct key___201;

struct user_struct___201 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___201 *uid_keyring;
	struct key___201 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_area_struct___207 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___207 *vm_next;
	struct vm_area_struct___207 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___206 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___13 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___207 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct rw_semaphore___207 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___207 *owner;
};

struct linux_binfmt___28;

struct core_state___206;

struct mm_struct___206 {
	struct {
		struct vm_area_struct___207 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___207 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___207 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___28 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___206 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___207 *owner;
		struct user_namespace___3 *user_ns;
		struct file___207 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___206 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___201 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___201 *session_keyring;
	struct key___201 *process_keyring;
	struct key___201 *thread_keyring;
	struct key___201 *request_key_auth;
	void *security;
	struct user_struct___201 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

union thread_union___185 {
	struct task_struct___207 task;
	long unsigned int stack[8192];
};

struct address_space_operations___206;

struct address_space___206 {
	struct inode___207 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___207 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___206 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dentry___206;

struct path___206 {
	struct vfsmount *mnt;
	struct dentry___206 *dentry;
};

struct file___207 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___206 f_path;
	struct inode___207 *f_inode;
	const struct file_operations___207 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___162 f_owner;
	const struct cred___201 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___206 *f_mapping;
	errseq_t f_wb_err;
};

struct core_thread___206 {
	struct task_struct___207 *task;
	struct core_thread___206 *next;
};

struct core_state___206 {
	atomic_t nr_threads;
	struct core_thread___206 dumper;
	struct completion startup;
};

struct linux_binprm___29;

struct coredump_params___28;

struct linux_binfmt___28 {
	struct list_head lh;
	struct module___173 *module;
	int (*load_binary)(struct linux_binprm___29 *);
	int (*load_shlib)(struct file___207 *);
	int (*core_dump)(struct coredump_params___28 *);
	long unsigned int min_coredump;
};

struct pglist_data___206;

struct lruvec___206 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___206 *pgdat;
};

struct zone___206 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___206 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___206 {
	struct zone___206 *zone;
	int zone_idx;
};

struct zonelist___206 {
	struct zoneref___206 _zonerefs[25];
};

struct pglist_data___206 {
	struct zone___206 node_zones[3];
	struct zonelist___206 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___207 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___207 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___206 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___206 {
	struct rw_semaphore___207 rwsem;
	struct notifier_block *head;
};

struct kernfs_root___200;

struct kernfs_elem_dir___200 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___200 *root;
};

struct kernfs_node___200;

struct kernfs_syscall_ops___200;

struct kernfs_root___200 {
	struct kernfs_node___200 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___200 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___200 {
	struct kernfs_node___200 *target_kn;
};

struct kernfs_ops___200;

struct kernfs_elem_attr___200 {
	const struct kernfs_ops___200 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___200 *notify_next;
};

struct kernfs_node___200 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___200 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___200 dir;
		struct kernfs_elem_symlink___200 symlink;
		struct kernfs_elem_attr___200 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___200;

struct kernfs_ops___200 {
	int (*open)(struct kernfs_open_file___200 *);
	void (*release)(struct kernfs_open_file___200 *);
	int (*seq_show)(struct seq_file___191 *, void *);
	void * (*seq_start)(struct seq_file___191 *, loff_t *);
	void * (*seq_next)(struct seq_file___191 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___191 *, void *);
	ssize_t (*read)(struct kernfs_open_file___200 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___200 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___200 *, struct vm_area_struct___207 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___200 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___200 {
	int (*remount_fs)(struct kernfs_root___200 *, int *, char *);
	int (*show_options)(struct seq_file___191 *, struct kernfs_root___200 *);
	int (*mkdir)(struct kernfs_node___200 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___200 *);
	int (*rename)(struct kernfs_node___200 *, struct kernfs_node___200 *, const char *);
	int (*show_path)(struct seq_file___191 *, struct kernfs_node___200 *, struct kernfs_root___200 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___189;

struct seq_file___191 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___189 *op;
	int poll_event;
	const struct file___207 *file;
	void *private;
};

struct kernfs_open_file___200 {
	struct kernfs_node___200 *kn;
	struct file___207 *file;
	struct seq_file___191 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___13 *vm_ops;
};

struct kobject___197;

struct bin_attribute___184;

struct attribute_group___185 {
	const char *name;
	umode_t (*is_visible)(struct kobject___197 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___197 *, struct bin_attribute___184 *, int);
	struct attribute **attrs;
	struct bin_attribute___184 **bin_attrs;
};

struct kset___196;

struct kobj_type___196;

struct kobject___197 {
	const char *name;
	struct list_head entry;
	struct kobject___197 *parent;
	struct kset___196 *kset;
	struct kobj_type___196 *ktype;
	struct kernfs_node___200 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___184 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___207 *, struct kobject___197 *, struct bin_attribute___184 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___207 *, struct kobject___197 *, struct bin_attribute___184 *, char *, loff_t, size_t);
	int (*mmap)(struct file___207 *, struct kobject___197 *, struct bin_attribute___184 *, struct vm_area_struct___207 *);
};

struct sysfs_ops___196 {
	ssize_t (*show)(struct kobject___197 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___197 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___196;

struct kset___196 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___197 kobj;
	const struct kset_uevent_ops___196 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___196 {
	void (*release)(struct kobject___197 *);
	const struct sysfs_ops___196 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___12 * (*child_ns_type)(struct kobject___197 *);
	const void * (*namespace)(struct kobject___197 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___196 {
	int (* const filter)(struct kset___196 *, struct kobject___197 *);
	const char * (* const name)(struct kset___196 *, struct kobject___197 *);
	int (* const uevent)(struct kset___196 *, struct kobject___197 *, struct kobj_uevent_env *);
};

struct kernel_param___170;

struct kernel_param_ops___170 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___170 *);
	int (*get)(char *, const struct kernel_param___170 *);
	void (*free)(void *);
};

struct kparam_array___170;

struct kernel_param___170 {
	const char *name;
	struct module___173 *mod;
	const struct kernel_param_ops___170 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___170 *arr;
	};
};

struct kparam_array___170 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___170 *ops;
	void *elem;
};

struct module_kobject___170 {
	struct kobject___197 kobj;
	struct module___173 *mod;
	struct kobject___197 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___170 {
	struct module___173 *mod;
	struct latch_tree_node node;
};

struct module_layout___170 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___170 mtn;
};

struct module_attribute___170;

struct module___173 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___170 mkobj;
	struct module_attribute___170 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___197 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___170 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___170 core_layout;
	struct module_layout___170 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___170 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___170 *, struct module_kobject___170 *, char *);
	ssize_t (*store)(struct module_attribute___170 *, struct module_kobject___170 *, const char *, size_t);
	void (*setup)(struct module___173 *, const char *);
	int (*test)(struct module___173 *);
	void (*free)(struct module___173 *);
};

struct dentry_operations___206;

struct super_block___206;

struct dentry___206 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___206 *d_parent;
	struct qstr d_name;
	struct inode___207 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___206 *d_op;
	struct super_block___206 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___206;

struct block_device___207;

struct cdev___36;

struct inode___207 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___206 *i_op;
	struct super_block___206 *i_sb;
	struct address_space___206 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___207 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___207 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___206 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___207 *i_bdev;
		struct cdev___36 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___206 {
	int (*d_revalidate)(struct dentry___206 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___206 *, unsigned int);
	int (*d_hash)(const struct dentry___206 *, struct qstr *);
	int (*d_compare)(const struct dentry___206 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___206 *);
	int (*d_init)(struct dentry___206 *);
	void (*d_release)(struct dentry___206 *);
	void (*d_prune)(struct dentry___206 *);
	void (*d_iput)(struct dentry___206 *, struct inode___207 *);
	char * (*d_dname)(struct dentry___206 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___206 *);
	int (*d_manage)(const struct path___206 *, bool);
	struct dentry___206 * (*d_real)(struct dentry___206 *, const struct inode___207 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___206;

struct mem_dqinfo___206 {
	struct quota_format_type___206 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___206;

struct quota_info___206 {
	unsigned int flags;
	struct rw_semaphore___207 dqio_sem;
	struct inode___207 *files[3];
	struct mem_dqinfo___206 info[3];
	const struct quota_format_ops___206 *ops[3];
};

struct rcuwait___206 {
	struct task_struct___207 *task;
};

struct percpu_rw_semaphore___206 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___207 rw_sem;
	struct rcuwait___206 writer;
	int readers_block;
};

struct sb_writers___206 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___206 rw_sem[3];
};

struct file_system_type___206;

struct super_operations___206;

struct dquot_operations___206;

struct quotactl_ops___206;

struct super_block___206 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___206 *s_type;
	const struct super_operations___206 *s_op;
	const struct dquot_operations___206 *dq_op;
	const struct quotactl_ops___206 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___206 *s_root;
	struct rw_semaphore___207 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___207 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___206 s_dquot;
	struct sb_writers___206 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___206 *s_d_op;
	int cleancache_poolid;
	struct shrinker___93 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___207 {
	struct file___207 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___207 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___206 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___207 *ia_file;
};

struct dquot___206 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___206 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___206 {
	int qf_fmt_id;
	const struct quota_format_ops___206 *qf_ops;
	struct module___173 *qf_owner;
	struct quota_format_type___206 *qf_next;
};

struct quota_format_ops___206 {
	int (*check_quota_file)(struct super_block___206 *, int);
	int (*read_file_info)(struct super_block___206 *, int);
	int (*write_file_info)(struct super_block___206 *, int);
	int (*free_file_info)(struct super_block___206 *, int);
	int (*read_dqblk)(struct dquot___206 *);
	int (*commit_dqblk)(struct dquot___206 *);
	int (*release_dqblk)(struct dquot___206 *);
	int (*get_next_id)(struct super_block___206 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___206 {
	int (*write_dquot)(struct dquot___206 *);
	struct dquot___206 * (*alloc_dquot)(struct super_block___206 *, int);
	void (*destroy_dquot)(struct dquot___206 *);
	int (*acquire_dquot)(struct dquot___206 *);
	int (*release_dquot)(struct dquot___206 *);
	int (*mark_dirty)(struct dquot___206 *);
	int (*write_info)(struct super_block___206 *, int);
	qsize_t * (*get_reserved_space)(struct inode___207 *);
	int (*get_projid)(struct inode___207 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___207 *, qsize_t *);
	int (*get_next_id)(struct super_block___206 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___206 {
	int (*quota_on)(struct super_block___206 *, int, int, const struct path___206 *);
	int (*quota_off)(struct super_block___206 *, int);
	int (*quota_enable)(struct super_block___206 *, unsigned int);
	int (*quota_disable)(struct super_block___206 *, unsigned int);
	int (*quota_sync)(struct super_block___206 *, int);
	int (*set_info)(struct super_block___206 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___206 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___206 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___206 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___206 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___206 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___206 {
	int (*writepage)(struct page___207 *, struct writeback_control___3 *);
	int (*readpage)(struct file___207 *, struct page___207 *);
	int (*writepages)(struct address_space___206 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___207 *);
	int (*readpages)(struct file___207 *, struct address_space___206 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___207 *, struct address_space___206 *, loff_t, unsigned int, unsigned int, struct page___207 **, void **);
	int (*write_end)(struct file___207 *, struct address_space___206 *, loff_t, unsigned int, unsigned int, struct page___207 *, void *);
	sector_t (*bmap)(struct address_space___206 *, sector_t);
	void (*invalidatepage)(struct page___207 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___207 *, gfp_t);
	void (*freepage)(struct page___207 *);
	ssize_t (*direct_IO)(struct kiocb___207 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___206 *, struct page___207 *, struct page___207 *, enum migrate_mode);
	bool (*isolate_page)(struct page___207 *, isolate_mode_t);
	void (*putback_page)(struct page___207 *);
	int (*launder_page)(struct page___207 *);
	int (*is_partially_uptodate)(struct page___207 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___207 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___206 *, struct page___207 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___207 *, sector_t *);
	void (*swap_deactivate)(struct file___207 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___207 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___207 *bd_inode;
	struct super_block___206 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___207 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___36 {
	struct kobject___197 kobj;
	struct module___173 *owner;
	const struct file_operations___207 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___206 {
	struct dentry___206 * (*lookup)(struct inode___207 *, struct dentry___206 *, unsigned int);
	const char * (*get_link)(struct dentry___206 *, struct inode___207 *, struct delayed_call *);
	int (*permission)(struct inode___207 *, int);
	struct posix_acl * (*get_acl)(struct inode___207 *, int);
	int (*readlink)(struct dentry___206 *, char *, int);
	int (*create)(struct inode___207 *, struct dentry___206 *, umode_t, bool);
	int (*link)(struct dentry___206 *, struct inode___207 *, struct dentry___206 *);
	int (*unlink)(struct inode___207 *, struct dentry___206 *);
	int (*symlink)(struct inode___207 *, struct dentry___206 *, const char *);
	int (*mkdir)(struct inode___207 *, struct dentry___206 *, umode_t);
	int (*rmdir)(struct inode___207 *, struct dentry___206 *);
	int (*mknod)(struct inode___207 *, struct dentry___206 *, umode_t, dev_t);
	int (*rename)(struct inode___207 *, struct dentry___206 *, struct inode___207 *, struct dentry___206 *, unsigned int);
	int (*setattr)(struct dentry___206 *, struct iattr___206 *);
	int (*getattr)(const struct path___206 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___206 *, char *, size_t);
	int (*fiemap)(struct inode___207 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___207 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___207 *, struct dentry___206 *, struct file___207 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___207 *, struct dentry___206 *, umode_t);
	int (*set_acl)(struct inode___207 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___206 {
	void (*fl_copy_lock)(struct file_lock___207 *, struct file_lock___207 *);
	void (*fl_release_private)(struct file_lock___207 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___206;

struct lock_manager_operations___206;

struct file_lock___207 {
	struct file_lock___207 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___207 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___206 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___206 *fl_ops;
	const struct lock_manager_operations___206 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___206 {
	int (*lm_compare_owner)(struct file_lock___207 *, struct file_lock___207 *);
	long unsigned int (*lm_owner_key)(struct file_lock___207 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___207 *);
	int (*lm_grant)(struct file_lock___207 *, int);
	bool (*lm_break)(struct file_lock___207 *);
	int (*lm_change)(struct file_lock___207 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___207 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___206 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___206 *fa_next;
	struct file___207 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___206 {
	const char *name;
	int fs_flags;
	struct dentry___206 * (*mount)(struct file_system_type___206 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___206 *);
	struct module___173 *owner;
	struct file_system_type___206 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___206 {
	struct inode___207 * (*alloc_inode)(struct super_block___206 *);
	void (*destroy_inode)(struct inode___207 *);
	void (*dirty_inode)(struct inode___207 *, int);
	int (*write_inode)(struct inode___207 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___207 *);
	void (*evict_inode)(struct inode___207 *);
	void (*put_super)(struct super_block___206 *);
	int (*sync_fs)(struct super_block___206 *, int);
	int (*freeze_super)(struct super_block___206 *);
	int (*freeze_fs)(struct super_block___206 *);
	int (*thaw_super)(struct super_block___206 *);
	int (*unfreeze_fs)(struct super_block___206 *);
	int (*statfs)(struct dentry___206 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___206 *, int *, char *);
	void (*umount_begin)(struct super_block___206 *);
	int (*show_options)(struct seq_file___191 *, struct dentry___206 *);
	int (*show_devname)(struct seq_file___191 *, struct dentry___206 *);
	int (*show_path)(struct seq_file___191 *, struct dentry___206 *);
	int (*show_stats)(struct seq_file___191 *, struct dentry___206 *);
	ssize_t (*quota_read)(struct super_block___206 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___206 *, int, const char *, size_t, loff_t);
	struct dquot___206 ** (*get_dquots)(struct inode___207 *);
	int (*bdev_try_to_free_page)(struct super_block___206 *, struct page___207 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___206 *, struct shrink_control___93 *);
	long int (*free_cached_objects)(struct super_block___206 *, struct shrink_control___93 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*proc_write_t___9)(struct file___207 *, char *, size_t);

struct device___183;

struct dev_pm_ops___183 {
	int (*prepare)(struct device___183 *);
	void (*complete)(struct device___183 *);
	int (*suspend)(struct device___183 *);
	int (*resume)(struct device___183 *);
	int (*freeze)(struct device___183 *);
	int (*thaw)(struct device___183 *);
	int (*poweroff)(struct device___183 *);
	int (*restore)(struct device___183 *);
	int (*suspend_late)(struct device___183 *);
	int (*resume_early)(struct device___183 *);
	int (*freeze_late)(struct device___183 *);
	int (*thaw_early)(struct device___183 *);
	int (*poweroff_late)(struct device___183 *);
	int (*restore_early)(struct device___183 *);
	int (*suspend_noirq)(struct device___183 *);
	int (*resume_noirq)(struct device___183 *);
	int (*freeze_noirq)(struct device___183 *);
	int (*thaw_noirq)(struct device___183 *);
	int (*poweroff_noirq)(struct device___183 *);
	int (*restore_noirq)(struct device___183 *);
	int (*runtime_suspend)(struct device___183 *);
	int (*runtime_resume)(struct device___183 *);
	int (*runtime_idle)(struct device___183 *);
};

struct dev_pm_info___183 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___183 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___183;

struct bus_type___183;

struct device_driver___183;

struct dev_pm_domain___183;

struct class___183;

struct device___183 {
	struct device___183 *parent;
	struct device_private *p;
	struct kobject___197 kobj;
	const char *init_name;
	const struct device_type___183 *type;
	struct mutex mutex;
	struct bus_type___183 *bus;
	struct device_driver___183 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___183 power;
	struct dev_pm_domain___183 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___183 *class;
	const struct attribute_group___185 **groups;
	void (*release)(struct device___183 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___183 {
	struct dev_pm_ops___183 ops;
	void (*detach)(struct device___183 *, bool);
	int (*activate)(struct device___183 *);
	void (*sync)(struct device___183 *);
	void (*dismiss)(struct device___183 *);
};

struct bus_type___183 {
	const char *name;
	const char *dev_name;
	struct device___183 *dev_root;
	const struct attribute_group___185 **bus_groups;
	const struct attribute_group___185 **dev_groups;
	const struct attribute_group___185 **drv_groups;
	int (*match)(struct device___183 *, struct device_driver___183 *);
	int (*uevent)(struct device___183 *, struct kobj_uevent_env *);
	int (*probe)(struct device___183 *);
	int (*remove)(struct device___183 *);
	void (*shutdown)(struct device___183 *);
	int (*online)(struct device___183 *);
	int (*offline)(struct device___183 *);
	int (*suspend)(struct device___183 *, pm_message_t);
	int (*resume)(struct device___183 *);
	int (*num_vf)(struct device___183 *);
	int (*dma_configure)(struct device___183 *);
	const struct dev_pm_ops___183 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___183 {
	const char *name;
	struct bus_type___183 *bus;
	struct module___173 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___183 *);
	int (*remove)(struct device___183 *);
	void (*shutdown)(struct device___183 *);
	int (*suspend)(struct device___183 *, pm_message_t);
	int (*resume)(struct device___183 *);
	const struct attribute_group___185 **groups;
	const struct dev_pm_ops___183 *pm;
	void (*coredump)(struct device___183 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___183 {
	const char *name;
	const struct attribute_group___185 **groups;
	int (*uevent)(struct device___183 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___183 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___183 *);
	const struct dev_pm_ops___183 *pm;
};

struct class___183 {
	const char *name;
	struct module___173 *owner;
	const struct attribute_group___185 **class_groups;
	const struct attribute_group___185 **dev_groups;
	struct kobject___197 *dev_kobj;
	int (*dev_uevent)(struct device___183 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___183 *, umode_t *);
	void (*class_release)(struct class___183 *);
	void (*dev_release)(struct device___183 *);
	int (*shutdown_pre)(struct device___183 *);
	const struct kobj_ns_type_operations___12 *ns_type;
	const void * (*namespace)(struct device___183 *);
	const struct dev_pm_ops___183 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

typedef int (*key_restrict_link_func_t___201)(struct key___201 *, const struct key_type *, const union key_payload *, struct key___201 *);

struct key_restriction___201;

struct key___201 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___207 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___201 *restrict_link;
};

struct key_restriction___201 {
	key_restrict_link_func_t___201 check;
	struct key___201 *key;
	struct key_type *keytype;
};

struct seq_operations___189 {
	void * (*start)(struct seq_file___191 *, loff_t *);
	void (*stop)(struct seq_file___191 *, void *);
	void * (*next)(struct seq_file___191 *, void *, loff_t *);
	int (*show)(struct seq_file___191 *, void *);
};

struct tty_struct___18;

struct tty_driver___18;

struct tty_operations___18 {
	struct tty_struct___18 * (*lookup)(struct tty_driver___18 *, struct file___207 *, int);
	int (*install)(struct tty_driver___18 *, struct tty_struct___18 *);
	void (*remove)(struct tty_driver___18 *, struct tty_struct___18 *);
	int (*open)(struct tty_struct___18 *, struct file___207 *);
	void (*close)(struct tty_struct___18 *, struct file___207 *);
	void (*shutdown)(struct tty_struct___18 *);
	void (*cleanup)(struct tty_struct___18 *);
	int (*write)(struct tty_struct___18 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___18 *, unsigned char);
	void (*flush_chars)(struct tty_struct___18 *);
	int (*write_room)(struct tty_struct___18 *);
	int (*chars_in_buffer)(struct tty_struct___18 *);
	int (*ioctl)(struct tty_struct___18 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___18 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___18 *, struct ktermios *);
	void (*throttle)(struct tty_struct___18 *);
	void (*unthrottle)(struct tty_struct___18 *);
	void (*stop)(struct tty_struct___18 *);
	void (*start)(struct tty_struct___18 *);
	void (*hangup)(struct tty_struct___18 *);
	int (*break_ctl)(struct tty_struct___18 *, int);
	void (*flush_buffer)(struct tty_struct___18 *);
	void (*set_ldisc)(struct tty_struct___18 *);
	void (*wait_until_sent)(struct tty_struct___18 *, int);
	void (*send_xchar)(struct tty_struct___18 *, char);
	int (*tiocmget)(struct tty_struct___18 *);
	int (*tiocmset)(struct tty_struct___18 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___18 *, struct winsize *);
	int (*set_termiox)(struct tty_struct___18 *, struct termiox *);
	int (*get_icount)(struct tty_struct___18 *, struct serial_icounter_struct *);
	void (*show_fdinfo)(struct tty_struct___18 *, struct seq_file___191 *);
	int (*poll_init)(struct tty_driver___18 *, int, char *);
	int (*poll_get_char)(struct tty_driver___18 *, int);
	void (*poll_put_char)(struct tty_driver___18 *, int, char);
	int (*proc_show)(struct seq_file___191 *, void *);
};

struct tty_ldisc___18;

struct tty_port___18;

struct tty_struct___18 {
	int magic;
	struct kref kref;
	struct device___183 *dev;
	struct tty_driver___18 *driver;
	const struct tty_operations___18 *ops;
	int index;
	struct ld_semaphore ldisc_sem;
	struct tty_ldisc___18 *ldisc;
	struct mutex atomic_write_lock;
	struct mutex legacy_mutex;
	struct mutex throttle_mutex;
	struct rw_semaphore___207 termios_rwsem;
	struct mutex winsize_mutex;
	spinlock_t ctrl_lock;
	spinlock_t flow_lock;
	struct ktermios termios;
	struct ktermios termios_locked;
	struct termiox *termiox;
	char name[64];
	struct pid___162 *pgrp;
	struct pid___162 *session;
	long unsigned int flags;
	int count;
	struct winsize winsize;
	long unsigned int stopped: 1;
	long unsigned int flow_stopped: 1;
	int: 30;
	long unsigned int unused: 62;
	int hw_stopped;
	long unsigned int ctrl_status: 8;
	long unsigned int packet: 1;
	int: 23;
	long unsigned int unused_ctrl: 55;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___18 *link;
	struct fasync_struct___206 *fasync;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	spinlock_t files_lock;
	struct list_head tty_files;
	int closing;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___18 *port;
};

struct proc_dir_entry___10;

struct tty_driver___18 {
	int magic;
	struct kref kref;
	struct cdev___36 **cdevs;
	struct module___173 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry___10 *proc_entry;
	struct tty_driver___18 *other;
	struct tty_struct___18 **ttys;
	struct tty_port___18 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___18 *ops;
	struct list_head tty_drivers;
};

struct proc_dir_entry___10 {
	atomic_t in_use;
	refcount_t refcnt;
	struct list_head pde_openers;
	spinlock_t pde_unload_lock;
	struct completion *pde_unload_completion;
	const struct inode_operations___206 *proc_iops;
	const struct file_operations___207 *proc_fops;
	union {
		const struct seq_operations___189 *seq_ops;
		int (*single_show)(struct seq_file___191 *, void *);
	};
	proc_write_t___9 write;
	void *data;
	unsigned int state_size;
	unsigned int low_ino;
	nlink_t nlink;
	kuid_t uid;
	kgid_t gid;
	loff_t size;
	struct proc_dir_entry___10 *parent;
	struct rb_root subdir;
	struct rb_node subdir_node;
	char *name;
	umode_t mode;
	u8 namelen;
	char inline_name[0];
};

struct tty_port_operations___18;

struct tty_port_client_operations___18;

struct tty_port___18 {
	struct tty_bufhead buf;
	struct tty_struct___18 *tty;
	struct tty_struct___18 *itty;
	const struct tty_port_operations___18 *ops;
	const struct tty_port_client_operations___18 *client_ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	unsigned char low_latency: 1;
	struct mutex mutex;
	struct mutex buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
	void *client_data;
};

struct tty_ldisc_ops___18 {
	int magic;
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___18 *);
	void (*close)(struct tty_struct___18 *);
	void (*flush_buffer)(struct tty_struct___18 *);
	ssize_t (*read)(struct tty_struct___18 *, struct file___207 *, unsigned char *, size_t);
	ssize_t (*write)(struct tty_struct___18 *, struct file___207 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___18 *, struct file___207 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___18 *, struct file___207 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___18 *, struct ktermios *);
	__poll_t (*poll)(struct tty_struct___18 *, struct file___207 *, struct poll_table_struct___6 *);
	int (*hangup)(struct tty_struct___18 *);
	void (*receive_buf)(struct tty_struct___18 *, const unsigned char *, char *, int);
	void (*write_wakeup)(struct tty_struct___18 *);
	void (*dcd_change)(struct tty_struct___18 *, unsigned int);
	int (*receive_buf2)(struct tty_struct___18 *, const unsigned char *, char *, int);
	struct module___173 *owner;
	int refcount;
};

struct tty_ldisc___18 {
	struct tty_ldisc_ops___18 *ops;
	struct tty_struct___18 *tty;
};

struct tty_port_operations___18 {
	int (*carrier_raised)(struct tty_port___18 *);
	void (*dtr_rts)(struct tty_port___18 *, int);
	void (*shutdown)(struct tty_port___18 *);
	int (*activate)(struct tty_port___18 *, struct tty_struct___18 *);
	void (*destruct)(struct tty_port___18 *);
};

struct tty_port_client_operations___18 {
	int (*receive_buf)(struct tty_port___18 *, const unsigned char *, const unsigned char *, size_t);
	void (*write_wakeup)(struct tty_port___18 *);
};

struct proc_ns_operations___19;

struct ns_common___19 {
	atomic_long_t stashed;
	const struct proc_ns_operations___19 *ops;
	unsigned int inum;
};

struct proc_ns_operations___19 {
	const char *name;
	const char *real_ns_name;
	int type;
	struct ns_common___19 * (*get)(struct task_struct___207 *);
	void (*put)(struct ns_common___19 *);
	int (*install)(struct nsproxy___8 *, struct ns_common___19 *);
	struct user_namespace___3 * (*owner)(struct ns_common___19 *);
	struct ns_common___19 * (*get_parent)(struct ns_common___19 *);
};

struct linux_binprm___29 {
	char buf[256];
	struct vm_area_struct___207 *vma;
	long unsigned int vma_pages;
	struct mm_struct___206 *mm;
	long unsigned int p;
	unsigned int called_set_creds: 1;
	unsigned int cap_elevated: 1;
	unsigned int secureexec: 1;
	unsigned int recursion_depth;
	struct file___207 *file;
	struct cred___201 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
};

struct coredump_params___28 {
	union {
		const kernel_siginfo_t *siginfo;
		struct {
			const siginfo_t *siginfo;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	struct pt_regs *regs;
	struct file___207 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
};

struct file___208;

struct kiocb___208;

struct vm_area_struct___208;

struct inode___208;

struct file_lock___208;

struct page___208;

struct seq_file___192;

struct file_operations___208 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___208 *, loff_t, int);
	ssize_t (*read)(struct file___208 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___208 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___208 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___208 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___208 *, bool);
	int (*iterate)(struct file___208 *, struct dir_context *);
	int (*iterate_shared)(struct file___208 *, struct dir_context *);
	__poll_t (*poll)(struct file___208 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___208 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___208 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___208 *, struct vm_area_struct___208 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___208 *, struct file___208 *);
	int (*flush)(struct file___208 *, fl_owner_t);
	int (*release)(struct inode___208 *, struct file___208 *);
	int (*fsync)(struct file___208 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___208 *, int);
	int (*lock)(struct file___208 *, int, struct file_lock___208 *);
	ssize_t (*sendpage)(struct file___208 *, struct page___208 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___208 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___208 *, int, struct file_lock___208 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___208 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___208 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___208 *, long int, struct file_lock___208 **, void **);
	long int (*fallocate)(struct file___208 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___192 *, struct file___208 *);
	ssize_t (*copy_file_range)(struct file___208 *, loff_t, struct file___208 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___208 *, loff_t, struct file___208 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___208 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___207 {
	u64 seqnum;
	struct vm_area_struct___208 *vmas[4];
};

struct page_frag___207 {
	struct page___208 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___207;

struct cred___202;

struct task_struct___208 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___208 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___207 *mm;
	struct mm_struct___207 *active_mm;
	struct vmacache___207 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___208 *real_parent;
	struct task_struct___208 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___208 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___162 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___162 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___162 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___202 *ptracer_cred;
	const struct cred___202 *real_cred;
	const struct cred___202 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___208 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___55 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide21;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___207 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___208 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___120 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rw_semaphore___208 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___208 *owner;
};

struct secondary_data___208 {
	void *stack;
	struct task_struct___208 *task;
	long int status;
};

struct blocking_notifier_head___207 {
	struct rw_semaphore___208 rwsem;
	struct notifier_block *head;
};

typedef struct page___208 *pgtable_t___207;

struct address_space___207;

struct page___208 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___207 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___208 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___207 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___207 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___202 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___207;

struct lruvec___207 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___207 *pgdat;
};

struct zone___207 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___207 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___207 {
	struct zone___207 *zone;
	int zone_idx;
};

struct zonelist___207 {
	struct zoneref___207 _zonerefs[25];
};

struct pglist_data___207 {
	struct zone___207 node_zones[3];
	struct zonelist___207 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___208 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___208 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___207 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct kernfs_root___201;

struct kernfs_elem_dir___201 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___201 *root;
};

struct kernfs_node___201;

struct kernfs_syscall_ops___201;

struct kernfs_root___201 {
	struct kernfs_node___201 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___201 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___201 {
	struct kernfs_node___201 *target_kn;
};

struct kernfs_ops___201;

struct kernfs_elem_attr___201 {
	const struct kernfs_ops___201 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___201 *notify_next;
};

struct kernfs_node___201 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___201 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___201 dir;
		struct kernfs_elem_symlink___201 symlink;
		struct kernfs_elem_attr___201 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___201;

struct kernfs_ops___201 {
	int (*open)(struct kernfs_open_file___201 *);
	void (*release)(struct kernfs_open_file___201 *);
	int (*seq_show)(struct seq_file___192 *, void *);
	void * (*seq_start)(struct seq_file___192 *, loff_t *);
	void * (*seq_next)(struct seq_file___192 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___192 *, void *);
	ssize_t (*read)(struct kernfs_open_file___201 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___201 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___201 *, struct vm_area_struct___208 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___201 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___201 {
	int (*remount_fs)(struct kernfs_root___201 *, int *, char *);
	int (*show_options)(struct seq_file___192 *, struct kernfs_root___201 *);
	int (*mkdir)(struct kernfs_node___201 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___201 *);
	int (*rename)(struct kernfs_node___201 *, struct kernfs_node___201 *, const char *);
	int (*show_path)(struct seq_file___192 *, struct kernfs_node___201 *, struct kernfs_root___201 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___190;

struct seq_file___192 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___190 *op;
	int poll_event;
	const struct file___208 *file;
	void *private;
};

struct kernfs_open_file___201 {
	struct kernfs_node___201 *kn;
	struct file___208 *file;
	struct seq_file___192 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___13 *vm_ops;
};

struct dentry___207;

struct path___207 {
	struct vfsmount *mnt;
	struct dentry___207 *dentry;
};

struct file___208 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___207 f_path;
	struct inode___208 *f_inode;
	const struct file_operations___208 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___162 f_owner;
	const struct cred___202 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___207 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_area_struct___208 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___208 *vm_next;
	struct vm_area_struct___208 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___207 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___13 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___208 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___197;

struct kobj_type___197;

struct kobject___198 {
	const char *name;
	struct list_head entry;
	struct kobject___198 *parent;
	struct kset___197 *kset;
	struct kobj_type___197 *ktype;
	struct kernfs_node___201 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sysfs_ops___197 {
	ssize_t (*show)(struct kobject___198 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___198 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___197;

struct kset___197 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___198 kobj;
	const struct kset_uevent_ops___197 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___197 {
	void (*release)(struct kobject___198 *);
	const struct sysfs_ops___197 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___12 * (*child_ns_type)(struct kobject___198 *);
	const void * (*namespace)(struct kobject___198 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___197 {
	int (* const filter)(struct kset___197 *, struct kobject___198 *);
	const char * (* const name)(struct kset___197 *, struct kobject___198 *);
	int (* const uevent)(struct kset___197 *, struct kobject___198 *, struct kobj_uevent_env *);
};

struct cpufreq_governor___3;

struct cpufreq_policy___3 {
	cpumask_var_t cpus;
	cpumask_var_t related_cpus;
	cpumask_var_t real_cpus;
	unsigned int shared_type;
	unsigned int cpu;
	struct clk *clk;
	struct cpufreq_cpuinfo cpuinfo;
	unsigned int min;
	unsigned int max;
	unsigned int cur;
	unsigned int restore_freq;
	unsigned int suspend_freq;
	unsigned int policy;
	unsigned int last_policy;
	struct cpufreq_governor___3 *governor;
	void *governor_data;
	char last_governor[16];
	struct work_struct update;
	struct cpufreq_user_policy user_policy;
	struct cpufreq_frequency_table *freq_table;
	enum cpufreq_table_sorting freq_table_sorted;
	struct list_head policy_list;
	struct kobject___198 kobj;
	struct completion kobj_unregister;
	struct rw_semaphore___208 rwsem;
	bool fast_switch_possible;
	bool fast_switch_enabled;
	unsigned int transition_delay_us;
	bool dvfs_possible_from_any_cpu;
	unsigned int cached_target_freq;
	int cached_resolved_idx;
	bool transition_ongoing;
	spinlock_t transition_lock;
	wait_queue_head_t transition_wait;
	struct task_struct___208 *transition_task;
	struct cpufreq_stats *stats;
	void *driver_data;
};

struct cpufreq_governor___3 {
	char name[16];
	int (*init)(struct cpufreq_policy___3 *);
	void (*exit)(struct cpufreq_policy___3 *);
	int (*start)(struct cpufreq_policy___3 *);
	void (*stop)(struct cpufreq_policy___3 *);
	void (*limits)(struct cpufreq_policy___3 *);
	ssize_t (*show_setspeed)(struct cpufreq_policy___3 *, char *);
	int (*store_setspeed)(struct cpufreq_policy___3 *, unsigned int);
	bool dynamic_switching;
	struct list_head governor_list;
	struct module___11 *owner;
};

struct freq_attr___3 {
	struct attribute attr;
	ssize_t (*show)(struct cpufreq_policy___3 *, char *);
	ssize_t (*store)(struct cpufreq_policy___3 *, const char *, size_t);
};

struct dentry_operations___207;

struct super_block___207;

struct dentry___207 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___207 *d_parent;
	struct qstr d_name;
	struct inode___208 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___207 *d_op;
	struct super_block___207 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___207;

struct address_space___207 {
	struct inode___208 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___208 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___207 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___207;

struct block_device___208;

struct inode___208 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___207 *i_op;
	struct super_block___207 *i_sb;
	struct address_space___207 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___208 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___208 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___207 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___208 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___207 {
	int (*d_revalidate)(struct dentry___207 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___207 *, unsigned int);
	int (*d_hash)(const struct dentry___207 *, struct qstr *);
	int (*d_compare)(const struct dentry___207 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___207 *);
	int (*d_init)(struct dentry___207 *);
	void (*d_release)(struct dentry___207 *);
	void (*d_prune)(struct dentry___207 *);
	void (*d_iput)(struct dentry___207 *, struct inode___208 *);
	char * (*d_dname)(struct dentry___207 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___207 *);
	int (*d_manage)(const struct path___207 *, bool);
	struct dentry___207 * (*d_real)(struct dentry___207 *, const struct inode___208 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___207;

struct mem_dqinfo___207 {
	struct quota_format_type___207 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___207;

struct quota_info___207 {
	unsigned int flags;
	struct rw_semaphore___208 dqio_sem;
	struct inode___208 *files[3];
	struct mem_dqinfo___207 info[3];
	const struct quota_format_ops___207 *ops[3];
};

struct rcuwait___207 {
	struct task_struct___208 *task;
};

struct percpu_rw_semaphore___207 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___208 rw_sem;
	struct rcuwait___207 writer;
	int readers_block;
};

struct sb_writers___207 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___207 rw_sem[3];
};

struct file_system_type___207;

struct super_operations___207;

struct dquot_operations___207;

struct quotactl_ops___207;

struct super_block___207 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___207 *s_type;
	const struct super_operations___207 *s_op;
	const struct dquot_operations___207 *dq_op;
	const struct quotactl_ops___207 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___207 *s_root;
	struct rw_semaphore___208 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___208 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___207 s_dquot;
	struct sb_writers___207 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___207 *s_d_op;
	int cleancache_poolid;
	struct shrinker___93 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct core_state___207;

struct mm_struct___207 {
	struct {
		struct vm_area_struct___208 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___208 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___208 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___207 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___208 *owner;
		struct user_namespace___3 *user_ns;
		struct file___208 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___207 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct core_thread___207 {
	struct task_struct___208 *task;
	struct core_thread___207 *next;
};

struct core_state___207 {
	atomic_t nr_threads;
	struct core_thread___207 dumper;
	struct completion startup;
};

struct key___202;

struct user_struct___202 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___202 *uid_keyring;
	struct key___202 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___202 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___202 *session_keyring;
	struct key___202 *process_keyring;
	struct key___202 *thread_keyring;
	struct key___202 *request_key_auth;
	void *security;
	struct user_struct___202 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kiocb___208 {
	struct file___208 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___208 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___207 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___208 *ia_file;
};

struct dquot___207 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___207 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___207 {
	int qf_fmt_id;
	const struct quota_format_ops___207 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___207 *qf_next;
};

struct quota_format_ops___207 {
	int (*check_quota_file)(struct super_block___207 *, int);
	int (*read_file_info)(struct super_block___207 *, int);
	int (*write_file_info)(struct super_block___207 *, int);
	int (*free_file_info)(struct super_block___207 *, int);
	int (*read_dqblk)(struct dquot___207 *);
	int (*commit_dqblk)(struct dquot___207 *);
	int (*release_dqblk)(struct dquot___207 *);
	int (*get_next_id)(struct super_block___207 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___207 {
	int (*write_dquot)(struct dquot___207 *);
	struct dquot___207 * (*alloc_dquot)(struct super_block___207 *, int);
	void (*destroy_dquot)(struct dquot___207 *);
	int (*acquire_dquot)(struct dquot___207 *);
	int (*release_dquot)(struct dquot___207 *);
	int (*mark_dirty)(struct dquot___207 *);
	int (*write_info)(struct super_block___207 *, int);
	qsize_t * (*get_reserved_space)(struct inode___208 *);
	int (*get_projid)(struct inode___208 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___208 *, qsize_t *);
	int (*get_next_id)(struct super_block___207 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___207 {
	int (*quota_on)(struct super_block___207 *, int, int, const struct path___207 *);
	int (*quota_off)(struct super_block___207 *, int);
	int (*quota_enable)(struct super_block___207 *, unsigned int);
	int (*quota_disable)(struct super_block___207 *, unsigned int);
	int (*quota_sync)(struct super_block___207 *, int);
	int (*set_info)(struct super_block___207 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___207 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___207 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___207 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___207 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___207 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___207 {
	int (*writepage)(struct page___208 *, struct writeback_control___3 *);
	int (*readpage)(struct file___208 *, struct page___208 *);
	int (*writepages)(struct address_space___207 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___208 *);
	int (*readpages)(struct file___208 *, struct address_space___207 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___208 *, struct address_space___207 *, loff_t, unsigned int, unsigned int, struct page___208 **, void **);
	int (*write_end)(struct file___208 *, struct address_space___207 *, loff_t, unsigned int, unsigned int, struct page___208 *, void *);
	sector_t (*bmap)(struct address_space___207 *, sector_t);
	void (*invalidatepage)(struct page___208 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___208 *, gfp_t);
	void (*freepage)(struct page___208 *);
	ssize_t (*direct_IO)(struct kiocb___208 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___207 *, struct page___208 *, struct page___208 *, enum migrate_mode);
	bool (*isolate_page)(struct page___208 *, isolate_mode_t);
	void (*putback_page)(struct page___208 *);
	int (*launder_page)(struct page___208 *);
	int (*is_partially_uptodate)(struct page___208 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___208 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___207 *, struct page___208 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___208 *, sector_t *);
	void (*swap_deactivate)(struct file___208 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___208 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___208 *bd_inode;
	struct super_block___207 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___208 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___207 {
	struct dentry___207 * (*lookup)(struct inode___208 *, struct dentry___207 *, unsigned int);
	const char * (*get_link)(struct dentry___207 *, struct inode___208 *, struct delayed_call *);
	int (*permission)(struct inode___208 *, int);
	struct posix_acl * (*get_acl)(struct inode___208 *, int);
	int (*readlink)(struct dentry___207 *, char *, int);
	int (*create)(struct inode___208 *, struct dentry___207 *, umode_t, bool);
	int (*link)(struct dentry___207 *, struct inode___208 *, struct dentry___207 *);
	int (*unlink)(struct inode___208 *, struct dentry___207 *);
	int (*symlink)(struct inode___208 *, struct dentry___207 *, const char *);
	int (*mkdir)(struct inode___208 *, struct dentry___207 *, umode_t);
	int (*rmdir)(struct inode___208 *, struct dentry___207 *);
	int (*mknod)(struct inode___208 *, struct dentry___207 *, umode_t, dev_t);
	int (*rename)(struct inode___208 *, struct dentry___207 *, struct inode___208 *, struct dentry___207 *, unsigned int);
	int (*setattr)(struct dentry___207 *, struct iattr___207 *);
	int (*getattr)(const struct path___207 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___207 *, char *, size_t);
	int (*fiemap)(struct inode___208 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___208 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___208 *, struct dentry___207 *, struct file___208 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___208 *, struct dentry___207 *, umode_t);
	int (*set_acl)(struct inode___208 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___207 {
	void (*fl_copy_lock)(struct file_lock___208 *, struct file_lock___208 *);
	void (*fl_release_private)(struct file_lock___208 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___207;

struct lock_manager_operations___207;

struct file_lock___208 {
	struct file_lock___208 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___208 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___207 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___207 *fl_ops;
	const struct lock_manager_operations___207 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___207 {
	int (*lm_compare_owner)(struct file_lock___208 *, struct file_lock___208 *);
	long unsigned int (*lm_owner_key)(struct file_lock___208 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___208 *);
	int (*lm_grant)(struct file_lock___208 *, int);
	bool (*lm_break)(struct file_lock___208 *);
	int (*lm_change)(struct file_lock___208 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___208 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___207 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___207 *fa_next;
	struct file___208 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___207 {
	const char *name;
	int fs_flags;
	struct dentry___207 * (*mount)(struct file_system_type___207 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___207 *);
	struct module___11 *owner;
	struct file_system_type___207 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___207 {
	struct inode___208 * (*alloc_inode)(struct super_block___207 *);
	void (*destroy_inode)(struct inode___208 *);
	void (*dirty_inode)(struct inode___208 *, int);
	int (*write_inode)(struct inode___208 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___208 *);
	void (*evict_inode)(struct inode___208 *);
	void (*put_super)(struct super_block___207 *);
	int (*sync_fs)(struct super_block___207 *, int);
	int (*freeze_super)(struct super_block___207 *);
	int (*freeze_fs)(struct super_block___207 *);
	int (*thaw_super)(struct super_block___207 *);
	int (*unfreeze_fs)(struct super_block___207 *);
	int (*statfs)(struct dentry___207 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___207 *, int *, char *);
	void (*umount_begin)(struct super_block___207 *);
	int (*show_options)(struct seq_file___192 *, struct dentry___207 *);
	int (*show_devname)(struct seq_file___192 *, struct dentry___207 *);
	int (*show_path)(struct seq_file___192 *, struct dentry___207 *);
	int (*show_stats)(struct seq_file___192 *, struct dentry___207 *);
	ssize_t (*quota_read)(struct super_block___207 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___207 *, int, const char *, size_t, loff_t);
	struct dquot___207 ** (*get_dquots)(struct inode___208 *);
	int (*bdev_try_to_free_page)(struct super_block___207 *, struct page___208 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___207 *, struct shrink_control___93 *);
	long int (*free_cached_objects)(struct super_block___207 *, struct shrink_control___93 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*key_restrict_link_func_t___202)(struct key___202 *, const struct key_type *, const union key_payload *, struct key___202 *);

struct key_restriction___202;

struct key___202 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___208 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___202 *restrict_link;
};

struct key_restriction___202 {
	key_restrict_link_func_t___202 check;
	struct key___202 *key;
	struct key_type *keytype;
};

struct seq_operations___190 {
	void * (*start)(struct seq_file___192 *, loff_t *);
	void (*stop)(struct seq_file___192 *, void *);
	void * (*next)(struct seq_file___192 *, void *, loff_t *);
	int (*show)(struct seq_file___192 *, void *);
};

struct file___209;

struct kiocb___209;

struct vm_area_struct___209;

struct inode___209;

struct file_lock___209;

struct page___209;

struct seq_file___193;

struct file_operations___209 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___209 *, loff_t, int);
	ssize_t (*read)(struct file___209 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___209 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___209 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___209 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___209 *, bool);
	int (*iterate)(struct file___209 *, struct dir_context *);
	int (*iterate_shared)(struct file___209 *, struct dir_context *);
	__poll_t (*poll)(struct file___209 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___209 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___209 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___209 *, struct vm_area_struct___209 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___209 *, struct file___209 *);
	int (*flush)(struct file___209 *, fl_owner_t);
	int (*release)(struct inode___209 *, struct file___209 *);
	int (*fsync)(struct file___209 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___209 *, int);
	int (*lock)(struct file___209 *, int, struct file_lock___209 *);
	ssize_t (*sendpage)(struct file___209 *, struct page___209 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___209 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___209 *, int, struct file_lock___209 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___209 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___209 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___209 *, long int, struct file_lock___209 **, void **);
	long int (*fallocate)(struct file___209 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___193 *, struct file___209 *);
	ssize_t (*copy_file_range)(struct file___209 *, loff_t, struct file___209 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___209 *, loff_t, struct file___209 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___209 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___208 {
	u64 seqnum;
	struct vm_area_struct___209 *vmas[4];
};

struct page_frag___208 {
	struct page___209 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___208;

struct mem_cgroup___94;

struct cred___203;

struct nsproxy___194;

struct bio_list___105;

struct backing_dev_info___105;

struct css_set___170;

struct vm_struct___142;

struct task_struct___209 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___209 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___208 *mm;
	struct mm_struct___208 *active_mm;
	struct vmacache___208 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___209 *real_parent;
	struct task_struct___209 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___209 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___94 *active_memcg;
	long int rh_reserved2;
	struct pid___162 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___162 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___162 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___203 *ptracer_cred;
	const struct cred___203 *real_cred;
	const struct cred___203 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___194 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___209 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___105 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___105 *backing_dev_info;
	struct io_context___55 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___170 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___208 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___94 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___209 *oom_reaper_list;
	struct vm_struct___142 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___120 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___208;

struct super_block___208;

struct dentry___208 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___208 *d_parent;
	struct qstr d_name;
	struct inode___209 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___208 *d_op;
	struct super_block___208 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct rw_semaphore___209 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___209 *owner;
};

struct address_space_operations___208;

struct address_space___208 {
	struct inode___209 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___209 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___208 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___208;

struct bdi_writeback___105;

struct block_device___209;

struct inode___209 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___208 *i_op;
	struct super_block___208 *i_sb;
	struct address_space___208 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___209 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___105 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___209 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___208 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___209 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___208;

struct dentry_operations___208 {
	int (*d_revalidate)(struct dentry___208 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___208 *, unsigned int);
	int (*d_hash)(const struct dentry___208 *, struct qstr *);
	int (*d_compare)(const struct dentry___208 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___208 *);
	int (*d_init)(struct dentry___208 *);
	void (*d_release)(struct dentry___208 *);
	void (*d_prune)(struct dentry___208 *);
	void (*d_iput)(struct dentry___208 *, struct inode___209 *);
	char * (*d_dname)(struct dentry___208 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___208 *);
	int (*d_manage)(const struct path___208 *, bool);
	struct dentry___208 * (*d_real)(struct dentry___208 *, const struct inode___209 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___208;

struct mem_dqinfo___208 {
	struct quota_format_type___208 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___208;

struct quota_info___208 {
	unsigned int flags;
	struct rw_semaphore___209 dqio_sem;
	struct inode___209 *files[3];
	struct mem_dqinfo___208 info[3];
	const struct quota_format_ops___208 *ops[3];
};

struct rcuwait___208 {
	struct task_struct___209 *task;
};

struct percpu_rw_semaphore___208 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___209 rw_sem;
	struct rcuwait___208 writer;
	int readers_block;
};

struct sb_writers___208 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___208 rw_sem[3];
};

struct shrink_control___94;

struct shrinker___94 {
	long unsigned int (*count_objects)(struct shrinker___94 *, struct shrink_control___94 *);
	long unsigned int (*scan_objects)(struct shrinker___94 *, struct shrink_control___94 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___208;

struct super_operations___208;

struct dquot_operations___208;

struct quotactl_ops___208;

struct user_namespace___180;

struct super_block___208 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___208 *s_type;
	const struct super_operations___208 *s_op;
	const struct dquot_operations___208 *dq_op;
	const struct quotactl_ops___208 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___208 *s_root;
	struct rw_semaphore___209 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___209 *s_bdev;
	struct backing_dev_info___105 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___208 s_dquot;
	struct sb_writers___208 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___208 *s_d_op;
	int cleancache_poolid;
	struct shrinker___94 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___180 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct path___208 {
	struct vfsmount *mnt;
	struct dentry___208 *dentry;
};

struct proc_ns_operations___20;

struct ns_common___20 {
	atomic_long_t stashed;
	const struct proc_ns_operations___20 *ops;
	unsigned int inum;
};

struct key___203;

struct ucounts___180;

struct user_namespace___180 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___180 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___20 ns;
	long unsigned int flags;
	struct key___203 *persistent_keyring_register;
	struct rw_semaphore___209 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___180 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct shrink_control___94 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___94 *memcg;
};

struct cgroup___170;

struct cgroup_subsys___170;

struct cgroup_subsys_state___171 {
	struct cgroup___170 *cgroup;
	struct cgroup_subsys___170 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___171 *parent;
};

struct kernfs_node___202;

struct cgroup_file___170 {
	struct kernfs_node___202 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___94;

struct mem_cgroup___94 {
	struct cgroup_subsys_state___171 css;
	struct mem_cgroup_id___6 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___170 events_file;
	struct cgroup_file___170 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___209 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___94 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___209 *pgtable_t___208;

struct dev_pagemap___203;

struct page___209 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___208 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___209 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___208 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___208 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___203 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___94 *mem_cgroup;
};

struct pglist_data___208;

struct lruvec___208 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___208 *pgdat;
};

struct zone___208 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___208 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___208 {
	struct zone___208 *zone;
	int zone_idx;
};

struct zonelist___208 {
	struct zoneref___208 _zonerefs[25];
};

struct pglist_data___208 {
	struct zone___208 node_zones[3];
	struct zonelist___208 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___209 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___209 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___208 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___209 {
	void *stack;
	struct task_struct___209 *task;
	long int status;
};

struct blocking_notifier_head___208 {
	struct rw_semaphore___209 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___203;

struct vm_area_struct___209 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___209 *vm_next;
	struct vm_area_struct___209 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___208 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___203 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___209 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct linux_binfmt___29;

struct core_state___208;

struct mm_struct___208 {
	struct {
		struct vm_area_struct___209 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___209 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___209 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___29 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___208 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___209 *owner;
		struct user_namespace___180 *user_ns;
		struct file___209 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___208 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___203)(struct vm_area_struct___209 *, long unsigned int, const struct page___209 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___203)(struct page___209 *, void *);

struct device___184;

struct dev_pagemap___203 {
	dev_page_fault_t___203 page_fault;
	dev_page_free_t___203 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___184 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct file___209 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___208 f_path;
	struct inode___209 *f_inode;
	const struct file_operations___209 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___162 f_owner;
	const struct cred___203 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___208 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___203;

struct vm_operations_struct___203 {
	void (*open)(struct vm_area_struct___209 *);
	void (*close)(struct vm_area_struct___209 *);
	int (*split)(struct vm_area_struct___209 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___209 *);
	vm_fault_t (*fault)(struct vm_fault___203 *);
	vm_fault_t (*huge_fault)(struct vm_fault___203 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___203 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___209 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___203 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___203 *);
	int (*access)(struct vm_area_struct___209 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___209 *);
	int (*set_policy)(struct vm_area_struct___209 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___209 *, long unsigned int);
	struct page___209 * (*find_special_page)(struct vm_area_struct___209 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___208 {
	struct task_struct___209 *task;
	struct core_thread___208 *next;
};

struct core_state___208 {
	atomic_t nr_threads;
	struct core_thread___208 dumper;
	struct completion startup;
};

struct linux_binprm___30;

struct coredump_params___29;

struct linux_binfmt___29 {
	struct list_head lh;
	struct module___11 *module;
	int (*load_binary)(struct linux_binprm___30 *);
	int (*load_shlib)(struct file___209 *);
	int (*core_dump)(struct coredump_params___29 *);
	long unsigned int min_coredump;
};

struct vm_fault___203 {
	struct vm_area_struct___209 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___209 *cow_page;
	struct mem_cgroup___94 *memcg;
	struct page___209 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___208 prealloc_pte;
};

struct user_struct___203 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___203 *uid_keyring;
	struct key___203 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___203 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___203 *session_keyring;
	struct key___203 *process_keyring;
	struct key___203 *thread_keyring;
	struct key___203 *request_key_auth;
	void *security;
	struct user_struct___203 *user;
	struct user_namespace___180 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___170;

struct nsproxy___194 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___170 *cgroup_ns;
};

struct bio___105;

struct bio_list___105 {
	struct bio___105 *head;
	struct bio___105 *tail;
};

struct bdi_writeback_congested___105;

struct bdi_writeback___105 {
	struct backing_dev_info___105 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___105 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___171 *memcg_css;
	struct cgroup_subsys_state___171 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___105 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___105 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___184 *dev;
	struct device___184 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___208 *debug_dir;
	struct dentry___208 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___170 {
	struct cgroup_subsys_state___171 *subsys[13];
	refcount_t refcount;
	struct css_set___170 *dom_cset;
	struct cgroup___170 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___170 *mg_src_cgrp;
	struct cgroup___170 *mg_dst_cgrp;
	struct css_set___170 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct vm_struct___142 {
	struct vm_struct___142 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___209 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___186 {
	struct task_struct___209 task;
	long unsigned int stack[8192];
};

struct kiocb___209 {
	struct file___209 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___209 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___208 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___209 *ia_file;
};

struct dquot___208 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___208 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___208 {
	int qf_fmt_id;
	const struct quota_format_ops___208 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___208 *qf_next;
};

struct quota_format_ops___208 {
	int (*check_quota_file)(struct super_block___208 *, int);
	int (*read_file_info)(struct super_block___208 *, int);
	int (*write_file_info)(struct super_block___208 *, int);
	int (*free_file_info)(struct super_block___208 *, int);
	int (*read_dqblk)(struct dquot___208 *);
	int (*commit_dqblk)(struct dquot___208 *);
	int (*release_dqblk)(struct dquot___208 *);
	int (*get_next_id)(struct super_block___208 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___208 {
	int (*write_dquot)(struct dquot___208 *);
	struct dquot___208 * (*alloc_dquot)(struct super_block___208 *, int);
	void (*destroy_dquot)(struct dquot___208 *);
	int (*acquire_dquot)(struct dquot___208 *);
	int (*release_dquot)(struct dquot___208 *);
	int (*mark_dirty)(struct dquot___208 *);
	int (*write_info)(struct super_block___208 *, int);
	qsize_t * (*get_reserved_space)(struct inode___209 *);
	int (*get_projid)(struct inode___209 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___209 *, qsize_t *);
	int (*get_next_id)(struct super_block___208 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___208 {
	int (*quota_on)(struct super_block___208 *, int, int, const struct path___208 *);
	int (*quota_off)(struct super_block___208 *, int);
	int (*quota_enable)(struct super_block___208 *, unsigned int);
	int (*quota_disable)(struct super_block___208 *, unsigned int);
	int (*quota_sync)(struct super_block___208 *, int);
	int (*set_info)(struct super_block___208 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___208 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___208 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___208 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___208 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___208 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___101;

struct swap_info_struct___67;

struct address_space_operations___208 {
	int (*writepage)(struct page___209 *, struct writeback_control___101 *);
	int (*readpage)(struct file___209 *, struct page___209 *);
	int (*writepages)(struct address_space___208 *, struct writeback_control___101 *);
	int (*set_page_dirty)(struct page___209 *);
	int (*readpages)(struct file___209 *, struct address_space___208 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___209 *, struct address_space___208 *, loff_t, unsigned int, unsigned int, struct page___209 **, void **);
	int (*write_end)(struct file___209 *, struct address_space___208 *, loff_t, unsigned int, unsigned int, struct page___209 *, void *);
	sector_t (*bmap)(struct address_space___208 *, sector_t);
	void (*invalidatepage)(struct page___209 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___209 *, gfp_t);
	void (*freepage)(struct page___209 *);
	ssize_t (*direct_IO)(struct kiocb___209 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___208 *, struct page___209 *, struct page___209 *, enum migrate_mode);
	bool (*isolate_page)(struct page___209 *, isolate_mode_t);
	void (*putback_page)(struct page___209 *);
	int (*launder_page)(struct page___209 *);
	int (*is_partially_uptodate)(struct page___209 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___209 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___208 *, struct page___209 *);
	int (*swap_activate)(struct swap_info_struct___67 *, struct file___209 *, sector_t *);
	void (*swap_deactivate)(struct file___209 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___101 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___105 *wb;
	struct inode___209 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct swap_info_struct___67 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___209 *bdev;
	struct file___209 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___209 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___209 *bd_inode;
	struct super_block___208 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___209 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___105 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___208 {
	struct dentry___208 * (*lookup)(struct inode___209 *, struct dentry___208 *, unsigned int);
	const char * (*get_link)(struct dentry___208 *, struct inode___209 *, struct delayed_call *);
	int (*permission)(struct inode___209 *, int);
	struct posix_acl * (*get_acl)(struct inode___209 *, int);
	int (*readlink)(struct dentry___208 *, char *, int);
	int (*create)(struct inode___209 *, struct dentry___208 *, umode_t, bool);
	int (*link)(struct dentry___208 *, struct inode___209 *, struct dentry___208 *);
	int (*unlink)(struct inode___209 *, struct dentry___208 *);
	int (*symlink)(struct inode___209 *, struct dentry___208 *, const char *);
	int (*mkdir)(struct inode___209 *, struct dentry___208 *, umode_t);
	int (*rmdir)(struct inode___209 *, struct dentry___208 *);
	int (*mknod)(struct inode___209 *, struct dentry___208 *, umode_t, dev_t);
	int (*rename)(struct inode___209 *, struct dentry___208 *, struct inode___209 *, struct dentry___208 *, unsigned int);
	int (*setattr)(struct dentry___208 *, struct iattr___208 *);
	int (*getattr)(const struct path___208 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___208 *, char *, size_t);
	int (*fiemap)(struct inode___209 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___209 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___209 *, struct dentry___208 *, struct file___209 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___209 *, struct dentry___208 *, umode_t);
	int (*set_acl)(struct inode___209 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___208 {
	void (*fl_copy_lock)(struct file_lock___209 *, struct file_lock___209 *);
	void (*fl_release_private)(struct file_lock___209 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___208;

struct lock_manager_operations___208;

struct file_lock___209 {
	struct file_lock___209 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___209 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___208 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___208 *fl_ops;
	const struct lock_manager_operations___208 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___208 {
	int (*lm_compare_owner)(struct file_lock___209 *, struct file_lock___209 *);
	long unsigned int (*lm_owner_key)(struct file_lock___209 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___209 *);
	int (*lm_grant)(struct file_lock___209 *, int);
	bool (*lm_break)(struct file_lock___209 *);
	int (*lm_change)(struct file_lock___209 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___209 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___208 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___208 *fa_next;
	struct file___209 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___208 {
	const char *name;
	int fs_flags;
	struct dentry___208 * (*mount)(struct file_system_type___208 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___208 *);
	struct module___11 *owner;
	struct file_system_type___208 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___208 {
	struct inode___209 * (*alloc_inode)(struct super_block___208 *);
	void (*destroy_inode)(struct inode___209 *);
	void (*dirty_inode)(struct inode___209 *, int);
	int (*write_inode)(struct inode___209 *, struct writeback_control___101 *);
	int (*drop_inode)(struct inode___209 *);
	void (*evict_inode)(struct inode___209 *);
	void (*put_super)(struct super_block___208 *);
	int (*sync_fs)(struct super_block___208 *, int);
	int (*freeze_super)(struct super_block___208 *);
	int (*freeze_fs)(struct super_block___208 *);
	int (*thaw_super)(struct super_block___208 *);
	int (*unfreeze_fs)(struct super_block___208 *);
	int (*statfs)(struct dentry___208 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___208 *, int *, char *);
	void (*umount_begin)(struct super_block___208 *);
	int (*show_options)(struct seq_file___193 *, struct dentry___208 *);
	int (*show_devname)(struct seq_file___193 *, struct dentry___208 *);
	int (*show_path)(struct seq_file___193 *, struct dentry___208 *);
	int (*show_stats)(struct seq_file___193 *, struct dentry___208 *);
	ssize_t (*quota_read)(struct super_block___208 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___208 *, int, const char *, size_t, loff_t);
	struct dquot___208 ** (*get_dquots)(struct inode___209 *);
	int (*bdev_try_to_free_page)(struct super_block___208 *, struct page___209 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___208 *, struct shrink_control___94 *);
	long int (*free_cached_objects)(struct super_block___208 *, struct shrink_control___94 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___191;

struct seq_file___193 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___191 *op;
	int poll_event;
	const struct file___209 *file;
	void *private;
};

struct kset___198;

struct kobj_type___198;

struct kobject___199 {
	const char *name;
	struct list_head entry;
	struct kobject___199 *parent;
	struct kset___198 *kset;
	struct kobj_type___198 *ktype;
	struct kernfs_node___202 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___105(struct bio___105 *);

struct bio_vec___105 {
	struct page___209 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___105;

struct bio_set___105;

struct bio___105 {
	struct bio___105 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___105 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___105 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___105 *bi_io_vec;
	struct bio_set___105 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___105 bi_inline_vecs[0];
};

struct dev_pm_info___184 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___184 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___184;

struct bus_type___184;

struct device_driver___184;

struct dev_pm_domain___184;

struct class___184;

struct attribute_group___186;

struct device___184 {
	struct device___184 *parent;
	struct device_private *p;
	struct kobject___199 kobj;
	const char *init_name;
	const struct device_type___184 *type;
	struct mutex mutex;
	struct bus_type___184 *bus;
	struct device_driver___184 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___184 power;
	struct dev_pm_domain___184 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___184 *class;
	const struct attribute_group___186 **groups;
	void (*release)(struct device___184 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct kobj_attribute___196 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___199 *, struct kobj_attribute___196 *, char *);
	ssize_t (*store)(struct kobject___199 *, struct kobj_attribute___196 *, const char *, size_t);
};

typedef void compound_page_dtor___203(struct page___209 *);

typedef int (*key_restrict_link_func_t___203)(struct key___203 *, const struct key_type *, const union key_payload *, struct key___203 *);

struct key_restriction___203;

struct key___203 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___209 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___203 *restrict_link;
};

struct key_restriction___203 {
	key_restrict_link_func_t___203 check;
	struct key___203 *key;
	struct key_type *keytype;
};

struct seq_operations___191 {
	void * (*start)(struct seq_file___193 *, loff_t *);
	void (*stop)(struct seq_file___193 *, void *);
	void * (*next)(struct seq_file___193 *, void *, loff_t *);
	int (*show)(struct seq_file___193 *, void *);
};

struct kernfs_root___202;

struct kernfs_elem_dir___202 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___202 *root;
};

struct kernfs_syscall_ops___202;

struct kernfs_root___202 {
	struct kernfs_node___202 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___202 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___202 {
	struct kernfs_node___202 *target_kn;
};

struct kernfs_ops___202;

struct kernfs_elem_attr___202 {
	const struct kernfs_ops___202 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___202 *notify_next;
};

struct kernfs_node___202 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___202 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___202 dir;
		struct kernfs_elem_symlink___202 symlink;
		struct kernfs_elem_attr___202 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___202;

struct kernfs_ops___202 {
	int (*open)(struct kernfs_open_file___202 *);
	void (*release)(struct kernfs_open_file___202 *);
	int (*seq_show)(struct seq_file___193 *, void *);
	void * (*seq_start)(struct seq_file___193 *, loff_t *);
	void * (*seq_next)(struct seq_file___193 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___193 *, void *);
	ssize_t (*read)(struct kernfs_open_file___202 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___202 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___202 *, struct vm_area_struct___209 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___202 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___202 {
	int (*remount_fs)(struct kernfs_root___202 *, int *, char *);
	int (*show_options)(struct seq_file___193 *, struct kernfs_root___202 *);
	int (*mkdir)(struct kernfs_node___202 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___202 *);
	int (*rename)(struct kernfs_node___202 *, struct kernfs_node___202 *, const char *);
	int (*show_path)(struct seq_file___193 *, struct kernfs_node___202 *, struct kernfs_root___202 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___202 {
	struct kernfs_node___202 *kn;
	struct file___209 *file;
	struct seq_file___193 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___203 *vm_ops;
};

struct proc_ns_operations___20 {
	const char *name;
	const char *real_ns_name;
	int type;
	struct ns_common___20 * (*get)(struct task_struct___209 *);
	void (*put)(struct ns_common___20 *);
	int (*install)(struct nsproxy___194 *, struct ns_common___20 *);
	struct user_namespace___180 * (*owner)(struct ns_common___20 *);
	struct ns_common___20 * (*get_parent)(struct ns_common___20 *);
};

struct cgroup_namespace___170 {
	refcount_t count;
	struct ns_common___20 ns;
	struct user_namespace___180 *user_ns;
	struct ucounts___180 *ucounts;
	struct css_set___170 *root_cset;
};

struct ucounts___180 {
	struct hlist_node node;
	struct user_namespace___180 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

typedef int (*proc_write_t___10)(struct file___209 *, char *, size_t);

struct proc_dir_entry___11 {
	atomic_t in_use;
	refcount_t refcnt;
	struct list_head pde_openers;
	spinlock_t pde_unload_lock;
	struct completion *pde_unload_completion;
	const struct inode_operations___208 *proc_iops;
	const struct file_operations___209 *proc_fops;
	union {
		const struct seq_operations___191 *seq_ops;
		int (*single_show)(struct seq_file___193 *, void *);
	};
	proc_write_t___10 write;
	void *data;
	unsigned int state_size;
	unsigned int low_ino;
	nlink_t nlink;
	kuid_t uid;
	kgid_t gid;
	loff_t size;
	struct proc_dir_entry___11 *parent;
	struct rb_root subdir;
	struct rb_node subdir_node;
	char *name;
	umode_t mode;
	u8 namelen;
	char inline_name[0];
};

struct bpf_map___170;

struct bpf_map_ops___170 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___170 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___170 *, struct file___209 *);
	void (*map_free)(struct bpf_map___170 *);
	int (*map_get_next_key)(struct bpf_map___170 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___170 *);
	void * (*map_lookup_elem)(struct bpf_map___170 *, void *);
	int (*map_update_elem)(struct bpf_map___170 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___170 *, void *);
	int (*map_push_elem)(struct bpf_map___170 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___170 *, void *);
	int (*map_peek_elem)(struct bpf_map___170 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___170 *, struct file___209 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___170 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___170 *, void *, struct seq_file___193 *);
	int (*map_check_btf)(const struct bpf_map___170 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___170 {
	const struct bpf_map_ops___170 *ops;
	struct bpf_map___170 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___203 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___170;

typedef void (*kthread_work_func_t___170)(struct kthread_work___170 *);

struct kthread_worker___170;

struct kthread_work___170 {
	struct list_head node;
	kthread_work_func_t___170 func;
	struct kthread_worker___170 *worker;
	int canceling;
};

struct kthread_worker___170 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___209 *task;
	struct kthread_work___170 *current_work;
};

struct kthread_delayed_work___170 {
	struct kthread_work___170 work;
	struct timer_list timer;
};

struct psi_group___170 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___170 *poll_kworker;
	struct kthread_delayed_work___170 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___170;

struct cgroup_rstat_cpu___170;

struct cgroup___170 {
	struct cgroup_subsys_state___171 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___202 *kn;
	struct cgroup_file___170 procs_file;
	struct cgroup_file___170 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___171 *subsys[13];
	struct cgroup_root___170 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___170 *dom_cgrp;
	struct cgroup_rstat_cpu___170 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___22 bpf;
	atomic_t congestion_count;
	struct cgroup___170 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___170 psi;
	int ancestor_ids[0];
};

struct cftype___170;

struct cgroup_subsys___170 {
	struct cgroup_subsys_state___171 * (*css_alloc)(struct cgroup_subsys_state___171 *);
	int (*css_online)(struct cgroup_subsys_state___171 *);
	void (*css_offline)(struct cgroup_subsys_state___171 *);
	void (*css_released)(struct cgroup_subsys_state___171 *);
	void (*css_free)(struct cgroup_subsys_state___171 *);
	void (*css_reset)(struct cgroup_subsys_state___171 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___171 *, int);
	int (*css_extra_stat_show)(struct seq_file___193 *, struct cgroup_subsys_state___171 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___209 *);
	void (*cancel_fork)(struct task_struct___209 *);
	void (*fork)(struct task_struct___209 *);
	void (*exit)(struct task_struct___209 *);
	void (*free)(struct task_struct___209 *);
	void (*bind)(struct cgroup_subsys_state___171 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___170 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___170 *dfl_cftypes;
	struct cftype___170 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___170 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___170 *updated_children;
	struct cgroup___170 *updated_next;
};

struct cgroup_root___170 {
	struct kernfs_root___202 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___170 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___170 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___170 *ss;
	struct list_head node;
	struct kernfs_ops___202 *kf_ops;
	int (*open)(struct kernfs_open_file___202 *);
	void (*release)(struct kernfs_open_file___202 *);
	u64 (*read_u64)(struct cgroup_subsys_state___171 *, struct cftype___170 *);
	s64 (*read_s64)(struct cgroup_subsys_state___171 *, struct cftype___170 *);
	int (*seq_show)(struct seq_file___193 *, void *);
	void * (*seq_start)(struct seq_file___193 *, loff_t *);
	void * (*seq_next)(struct seq_file___193 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___193 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___171 *, struct cftype___170 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___171 *, struct cftype___170 *, s64);
	ssize_t (*write)(struct kernfs_open_file___202 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___202 *, struct poll_table_struct___6 *);
};

struct bin_attribute___185;

struct attribute_group___186 {
	const char *name;
	umode_t (*is_visible)(struct kobject___199 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___199 *, struct bin_attribute___185 *, int);
	struct attribute **attrs;
	struct bin_attribute___185 **bin_attrs;
};

struct hstate___39 {
	int next_nid_to_alloc;
	int next_nid_to_free;
	unsigned int order;
	long unsigned int mask;
	long unsigned int max_huge_pages;
	long unsigned int nr_huge_pages;
	long unsigned int free_huge_pages;
	long unsigned int resv_huge_pages;
	long unsigned int surplus_huge_pages;
	long unsigned int nr_overcommit_huge_pages;
	struct list_head hugepage_activelist;
	struct list_head hugepage_freelists[8];
	unsigned int nr_huge_pages_node[8];
	unsigned int free_huge_pages_node[8];
	unsigned int surplus_huge_pages_node[8];
	struct cftype___170 cgroup_files[5];
	char name[32];
};

struct bdi_writeback_congested___105 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___105 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___105 {
	struct bio___105 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___105 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___105 bip_inline_vecs[0];
};

struct bio_set___105 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___105 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___94 {
	struct mem_cgroup___94 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___94 {
	struct lruvec___208 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___94 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___94 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct bin_attribute___185 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___209 *, struct kobject___199 *, struct bin_attribute___185 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___209 *, struct kobject___199 *, struct bin_attribute___185 *, char *, loff_t, size_t);
	int (*mmap)(struct file___209 *, struct kobject___199 *, struct bin_attribute___185 *, struct vm_area_struct___209 *);
};

struct sysfs_ops___198 {
	ssize_t (*show)(struct kobject___199 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___199 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___198;

struct kset___198 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___199 kobj;
	const struct kset_uevent_ops___198 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___198 {
	void (*release)(struct kobject___199 *);
	const struct sysfs_ops___198 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___12 * (*child_ns_type)(struct kobject___199 *);
	const void * (*namespace)(struct kobject___199 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___198 {
	int (* const filter)(struct kset___198 *, struct kobject___199 *);
	const char * (* const name)(struct kset___198 *, struct kobject___199 *);
	int (* const uevent)(struct kset___198 *, struct kobject___199 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___184 {
	int (*prepare)(struct device___184 *);
	void (*complete)(struct device___184 *);
	int (*suspend)(struct device___184 *);
	int (*resume)(struct device___184 *);
	int (*freeze)(struct device___184 *);
	int (*thaw)(struct device___184 *);
	int (*poweroff)(struct device___184 *);
	int (*restore)(struct device___184 *);
	int (*suspend_late)(struct device___184 *);
	int (*resume_early)(struct device___184 *);
	int (*freeze_late)(struct device___184 *);
	int (*thaw_early)(struct device___184 *);
	int (*poweroff_late)(struct device___184 *);
	int (*restore_early)(struct device___184 *);
	int (*suspend_noirq)(struct device___184 *);
	int (*resume_noirq)(struct device___184 *);
	int (*freeze_noirq)(struct device___184 *);
	int (*thaw_noirq)(struct device___184 *);
	int (*poweroff_noirq)(struct device___184 *);
	int (*restore_noirq)(struct device___184 *);
	int (*runtime_suspend)(struct device___184 *);
	int (*runtime_resume)(struct device___184 *);
	int (*runtime_idle)(struct device___184 *);
};

struct dev_pm_domain___184 {
	struct dev_pm_ops___184 ops;
	void (*detach)(struct device___184 *, bool);
	int (*activate)(struct device___184 *);
	void (*sync)(struct device___184 *);
	void (*dismiss)(struct device___184 *);
};

struct bus_type___184 {
	const char *name;
	const char *dev_name;
	struct device___184 *dev_root;
	const struct attribute_group___186 **bus_groups;
	const struct attribute_group___186 **dev_groups;
	const struct attribute_group___186 **drv_groups;
	int (*match)(struct device___184 *, struct device_driver___184 *);
	int (*uevent)(struct device___184 *, struct kobj_uevent_env *);
	int (*probe)(struct device___184 *);
	int (*remove)(struct device___184 *);
	void (*shutdown)(struct device___184 *);
	int (*online)(struct device___184 *);
	int (*offline)(struct device___184 *);
	int (*suspend)(struct device___184 *, pm_message_t);
	int (*resume)(struct device___184 *);
	int (*num_vf)(struct device___184 *);
	int (*dma_configure)(struct device___184 *);
	const struct dev_pm_ops___184 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___184 {
	const char *name;
	struct bus_type___184 *bus;
	struct module___11 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___184 *);
	int (*remove)(struct device___184 *);
	void (*shutdown)(struct device___184 *);
	int (*suspend)(struct device___184 *, pm_message_t);
	int (*resume)(struct device___184 *);
	const struct attribute_group___186 **groups;
	const struct dev_pm_ops___184 *pm;
	void (*coredump)(struct device___184 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___184 {
	const char *name;
	const struct attribute_group___186 **groups;
	int (*uevent)(struct device___184 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___184 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___184 *);
	const struct dev_pm_ops___184 *pm;
};

struct class___184 {
	const char *name;
	struct module___11 *owner;
	const struct attribute_group___186 **class_groups;
	const struct attribute_group___186 **dev_groups;
	struct kobject___199 *dev_kobj;
	int (*dev_uevent)(struct device___184 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___184 *, umode_t *);
	void (*class_release)(struct class___184 *);
	void (*dev_release)(struct device___184 *);
	int (*shutdown_pre)(struct device___184 *);
	const struct kobj_ns_type_operations___12 *ns_type;
	const void * (*namespace)(struct device___184 *);
	const struct dev_pm_ops___184 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___158 {
	struct device___184 dev;
};

struct linux_binprm___30 {
	char buf[256];
	struct vm_area_struct___209 *vma;
	long unsigned int vma_pages;
	struct mm_struct___208 *mm;
	long unsigned int p;
	unsigned int called_set_creds: 1;
	unsigned int cap_elevated: 1;
	unsigned int secureexec: 1;
	unsigned int recursion_depth;
	struct file___209 *file;
	struct cred___203 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
};

struct coredump_params___29 {
	union {
		const kernel_siginfo_t *siginfo;
		struct {
			const siginfo_t *siginfo;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	struct pt_regs *regs;
	struct file___209 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
};

struct file___210;

struct kiocb___210;

struct iov_iter___99;

struct vm_area_struct___210;

struct inode___210;

struct file_lock___210;

struct page___210;

struct pipe_inode_info___45;

struct seq_file___194;

struct file_operations___210 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___210 *, loff_t, int);
	ssize_t (*read)(struct file___210 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___210 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___210 *, struct iov_iter___99 *);
	ssize_t (*write_iter)(struct kiocb___210 *, struct iov_iter___99 *);
	int (*iopoll)(struct kiocb___210 *, bool);
	int (*iterate)(struct file___210 *, struct dir_context *);
	int (*iterate_shared)(struct file___210 *, struct dir_context *);
	__poll_t (*poll)(struct file___210 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___210 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___210 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___210 *, struct vm_area_struct___210 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___210 *, struct file___210 *);
	int (*flush)(struct file___210 *, fl_owner_t);
	int (*release)(struct inode___210 *, struct file___210 *);
	int (*fsync)(struct file___210 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___210 *, int);
	int (*lock)(struct file___210 *, int, struct file_lock___210 *);
	ssize_t (*sendpage)(struct file___210 *, struct page___210 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___210 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___210 *, int, struct file_lock___210 *);
	ssize_t (*splice_write)(struct pipe_inode_info___45 *, struct file___210 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___210 *, loff_t *, struct pipe_inode_info___45 *, size_t, unsigned int);
	int (*setlease)(struct file___210 *, long int, struct file_lock___210 **, void **);
	long int (*fallocate)(struct file___210 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___194 *, struct file___210 *);
	ssize_t (*copy_file_range)(struct file___210 *, loff_t, struct file___210 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___210 *, loff_t, struct file___210 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___210 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___209 {
	u64 seqnum;
	struct vm_area_struct___210 *vmas[4];
};

struct page_frag___209 {
	struct page___210 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___209;

struct pid___163;

struct cred___204;

struct nsproxy___195;

struct signal_struct___180;

struct vm_struct___143;

struct task_struct___210 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___210 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___209 *mm;
	struct mm_struct___209 *active_mm;
	struct vmacache___209 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___210 *real_parent;
	struct task_struct___210 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___210 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___163 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___163 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___163 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___204 *ptracer_cred;
	const struct cred___204 *real_cred;
	const struct cred___204 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___195 *nsproxy;
	struct signal_struct___180 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___210 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___55 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___45 *splice_pipe;
	struct page_frag___209 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___210 *oom_reaper_list;
	struct vm_struct___143 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___120 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___209;

struct super_block___209;

struct dentry___209 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___209 *d_parent;
	struct qstr d_name;
	struct inode___210 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___209 *d_op;
	struct super_block___209 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct rw_semaphore___210 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___210 *owner;
};

struct address_space_operations___209;

struct address_space___209 {
	struct inode___210 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___210 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___209 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___209;

struct block_device___210;

struct inode___210 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___209 *i_op;
	struct super_block___209 *i_sb;
	struct address_space___209 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___210 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___210 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___209 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___45 *i_pipe;
		struct block_device___210 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___209;

struct dentry_operations___209 {
	int (*d_revalidate)(struct dentry___209 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___209 *, unsigned int);
	int (*d_hash)(const struct dentry___209 *, struct qstr *);
	int (*d_compare)(const struct dentry___209 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___209 *);
	int (*d_init)(struct dentry___209 *);
	void (*d_release)(struct dentry___209 *);
	void (*d_prune)(struct dentry___209 *);
	void (*d_iput)(struct dentry___209 *, struct inode___210 *);
	char * (*d_dname)(struct dentry___209 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___209 *);
	int (*d_manage)(const struct path___209 *, bool);
	struct dentry___209 * (*d_real)(struct dentry___209 *, const struct inode___210 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___209;

struct mem_dqinfo___209 {
	struct quota_format_type___209 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___209;

struct quota_info___209 {
	unsigned int flags;
	struct rw_semaphore___210 dqio_sem;
	struct inode___210 *files[3];
	struct mem_dqinfo___209 info[3];
	const struct quota_format_ops___209 *ops[3];
};

struct rcuwait___209 {
	struct task_struct___210 *task;
};

struct percpu_rw_semaphore___209 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___210 rw_sem;
	struct rcuwait___209 writer;
	int readers_block;
};

struct sb_writers___209 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___209 rw_sem[3];
};

struct file_system_type___209;

struct super_operations___209;

struct dquot_operations___209;

struct quotactl_ops___209;

struct user_namespace___181;

struct super_block___209 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___209 *s_type;
	const struct super_operations___209 *s_op;
	const struct dquot_operations___209 *dq_op;
	const struct quotactl_ops___209 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___209 *s_root;
	struct rw_semaphore___210 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___210 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___209 s_dquot;
	struct sb_writers___209 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___209 *s_d_op;
	int cleancache_poolid;
	struct shrinker___94 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___181 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct path___209 {
	struct vfsmount *mnt;
	struct dentry___209 *dentry;
};

struct proc_ns_operations___21;

struct ns_common___21 {
	atomic_long_t stashed;
	const struct proc_ns_operations___21 *ops;
	unsigned int inum;
};

struct key___204;

struct ucounts___181;

struct user_namespace___181 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___181 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___21 ns;
	long unsigned int flags;
	struct key___204 *persistent_keyring_register;
	struct rw_semaphore___210 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___181 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___210 *pgtable_t___209;

struct dev_pagemap___204;

struct page___210 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___209 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___210 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___209 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___209 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___204 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___209;

struct lruvec___209 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___209 *pgdat;
};

struct zone___209 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___209 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___209 {
	struct zone___209 *zone;
	int zone_idx;
};

struct zonelist___209 {
	struct zoneref___209 _zonerefs[25];
};

struct pglist_data___209 {
	struct zone___209 node_zones[3];
	struct zonelist___209 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___210 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___210 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___209 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___210 {
	void *stack;
	struct task_struct___210 *task;
	long int status;
};

struct blocking_notifier_head___209 {
	struct rw_semaphore___210 rwsem;
	struct notifier_block *head;
};

struct pid_namespace___163;

struct upid___163 {
	int nr;
	struct pid_namespace___163 *ns;
};

struct pid_namespace___163 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___210 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___163 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___209 *proc_self;
	struct dentry___209 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___181 *user_ns;
	struct ucounts___181 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___21 ns;
};

struct pid___163 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___163 numbers[1];
};

struct vm_operations_struct___204;

struct vm_area_struct___210 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___210 *vm_next;
	struct vm_area_struct___210 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___209 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___204 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___210 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct linux_binfmt___30;

struct core_state___209;

struct mm_struct___209 {
	struct {
		struct vm_area_struct___210 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___210 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___210 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___30 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___209 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___210 *owner;
		struct user_namespace___181 *user_ns;
		struct file___210 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___209 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___204)(struct vm_area_struct___210 *, long unsigned int, const struct page___210 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___204)(struct page___210 *, void *);

struct device___185;

struct dev_pagemap___204 {
	dev_page_fault_t___204 page_fault;
	dev_page_free_t___204 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___185 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct fown_struct___163 {
	rwlock_t lock;
	struct pid___163 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___210 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___209 f_path;
	struct inode___210 *f_inode;
	const struct file_operations___210 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___163 f_owner;
	const struct cred___204 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___209 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___204;

struct vm_operations_struct___204 {
	void (*open)(struct vm_area_struct___210 *);
	void (*close)(struct vm_area_struct___210 *);
	int (*split)(struct vm_area_struct___210 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___210 *);
	vm_fault_t (*fault)(struct vm_fault___204 *);
	vm_fault_t (*huge_fault)(struct vm_fault___204 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___204 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___210 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___204 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___204 *);
	int (*access)(struct vm_area_struct___210 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___210 *);
	int (*set_policy)(struct vm_area_struct___210 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___210 *, long unsigned int);
	struct page___210 * (*find_special_page)(struct vm_area_struct___210 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___209 {
	struct task_struct___210 *task;
	struct core_thread___209 *next;
};

struct core_state___209 {
	atomic_t nr_threads;
	struct core_thread___209 dumper;
	struct completion startup;
};

struct linux_binprm___31;

struct coredump_params___30;

struct linux_binfmt___30 {
	struct list_head lh;
	struct module___11 *module;
	int (*load_binary)(struct linux_binprm___31 *);
	int (*load_shlib)(struct file___210 *);
	int (*core_dump)(struct coredump_params___30 *);
	long unsigned int min_coredump;
};

struct vm_fault___204 {
	struct vm_area_struct___210 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___210 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___210 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___209 prealloc_pte;
};

struct user_struct___204 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___204 *uid_keyring;
	struct key___204 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___204 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___204 *session_keyring;
	struct key___204 *process_keyring;
	struct key___204 *thread_keyring;
	struct key___204 *request_key_auth;
	void *security;
	struct user_struct___204 *user;
	struct user_namespace___181 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct uts_namespace___24;

struct ipc_namespace___2;

struct net___34;

struct nsproxy___195 {
	atomic_t count;
	struct uts_namespace___24 *uts_ns;
	struct ipc_namespace___2 *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___163 *pid_ns_for_children;
	struct net___34 *net_ns;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct signal_struct___180 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___210 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___210 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___163 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___163 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___209 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___163 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct fasync_struct___209;

struct pipe_buffer___45;

struct pipe_inode_info___45 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___210 *tmp_page;
	struct fasync_struct___209 *fasync_readers;
	struct fasync_struct___209 *fasync_writers;
	struct pipe_buffer___45 *bufs;
	struct user_struct___204 *user;
};

struct vm_struct___143 {
	struct vm_struct___143 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___210 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___187 {
	struct task_struct___210 task;
	long unsigned int stack[8192];
};

struct kiocb___210 {
	struct file___210 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___210 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___209 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___210 *ia_file;
};

struct dquot___209 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___209 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___209 {
	int qf_fmt_id;
	const struct quota_format_ops___209 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___209 *qf_next;
};

struct quota_format_ops___209 {
	int (*check_quota_file)(struct super_block___209 *, int);
	int (*read_file_info)(struct super_block___209 *, int);
	int (*write_file_info)(struct super_block___209 *, int);
	int (*free_file_info)(struct super_block___209 *, int);
	int (*read_dqblk)(struct dquot___209 *);
	int (*commit_dqblk)(struct dquot___209 *);
	int (*release_dqblk)(struct dquot___209 *);
	int (*get_next_id)(struct super_block___209 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___209 {
	int (*write_dquot)(struct dquot___209 *);
	struct dquot___209 * (*alloc_dquot)(struct super_block___209 *, int);
	void (*destroy_dquot)(struct dquot___209 *);
	int (*acquire_dquot)(struct dquot___209 *);
	int (*release_dquot)(struct dquot___209 *);
	int (*mark_dirty)(struct dquot___209 *);
	int (*write_info)(struct super_block___209 *, int);
	qsize_t * (*get_reserved_space)(struct inode___210 *);
	int (*get_projid)(struct inode___210 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___210 *, qsize_t *);
	int (*get_next_id)(struct super_block___209 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___209 {
	int (*quota_on)(struct super_block___209 *, int, int, const struct path___209 *);
	int (*quota_off)(struct super_block___209 *, int);
	int (*quota_enable)(struct super_block___209 *, unsigned int);
	int (*quota_disable)(struct super_block___209 *, unsigned int);
	int (*quota_sync)(struct super_block___209 *, int);
	int (*set_info)(struct super_block___209 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___209 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___209 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___209 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___209 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___209 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___209 {
	int (*writepage)(struct page___210 *, struct writeback_control___3 *);
	int (*readpage)(struct file___210 *, struct page___210 *);
	int (*writepages)(struct address_space___209 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___210 *);
	int (*readpages)(struct file___210 *, struct address_space___209 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___210 *, struct address_space___209 *, loff_t, unsigned int, unsigned int, struct page___210 **, void **);
	int (*write_end)(struct file___210 *, struct address_space___209 *, loff_t, unsigned int, unsigned int, struct page___210 *, void *);
	sector_t (*bmap)(struct address_space___209 *, sector_t);
	void (*invalidatepage)(struct page___210 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___210 *, gfp_t);
	void (*freepage)(struct page___210 *);
	ssize_t (*direct_IO)(struct kiocb___210 *, struct iov_iter___99 *);
	int (*migratepage)(struct address_space___209 *, struct page___210 *, struct page___210 *, enum migrate_mode);
	bool (*isolate_page)(struct page___210 *, isolate_mode_t);
	void (*putback_page)(struct page___210 *);
	int (*launder_page)(struct page___210 *);
	int (*is_partially_uptodate)(struct page___210 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___210 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___209 *, struct page___210 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___210 *, sector_t *);
	void (*swap_deactivate)(struct file___210 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct iov_iter___99 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___3 *bvec;
		struct pipe_inode_info___45 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___210 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___210 *bd_inode;
	struct super_block___209 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___210 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___209 {
	struct dentry___209 * (*lookup)(struct inode___210 *, struct dentry___209 *, unsigned int);
	const char * (*get_link)(struct dentry___209 *, struct inode___210 *, struct delayed_call *);
	int (*permission)(struct inode___210 *, int);
	struct posix_acl * (*get_acl)(struct inode___210 *, int);
	int (*readlink)(struct dentry___209 *, char *, int);
	int (*create)(struct inode___210 *, struct dentry___209 *, umode_t, bool);
	int (*link)(struct dentry___209 *, struct inode___210 *, struct dentry___209 *);
	int (*unlink)(struct inode___210 *, struct dentry___209 *);
	int (*symlink)(struct inode___210 *, struct dentry___209 *, const char *);
	int (*mkdir)(struct inode___210 *, struct dentry___209 *, umode_t);
	int (*rmdir)(struct inode___210 *, struct dentry___209 *);
	int (*mknod)(struct inode___210 *, struct dentry___209 *, umode_t, dev_t);
	int (*rename)(struct inode___210 *, struct dentry___209 *, struct inode___210 *, struct dentry___209 *, unsigned int);
	int (*setattr)(struct dentry___209 *, struct iattr___209 *);
	int (*getattr)(const struct path___209 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___209 *, char *, size_t);
	int (*fiemap)(struct inode___210 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___210 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___210 *, struct dentry___209 *, struct file___210 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___210 *, struct dentry___209 *, umode_t);
	int (*set_acl)(struct inode___210 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___209 {
	void (*fl_copy_lock)(struct file_lock___210 *, struct file_lock___210 *);
	void (*fl_release_private)(struct file_lock___210 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___209;

struct file_lock___210 {
	struct file_lock___210 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___210 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___209 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___209 *fl_ops;
	const struct lock_manager_operations___209 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___209 {
	int (*lm_compare_owner)(struct file_lock___210 *, struct file_lock___210 *);
	long unsigned int (*lm_owner_key)(struct file_lock___210 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___210 *);
	int (*lm_grant)(struct file_lock___210 *, int);
	bool (*lm_break)(struct file_lock___210 *);
	int (*lm_change)(struct file_lock___210 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___210 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___209 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___209 *fa_next;
	struct file___210 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___209 {
	const char *name;
	int fs_flags;
	struct dentry___209 * (*mount)(struct file_system_type___209 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___209 *);
	struct module___11 *owner;
	struct file_system_type___209 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___209 {
	struct inode___210 * (*alloc_inode)(struct super_block___209 *);
	void (*destroy_inode)(struct inode___210 *);
	void (*dirty_inode)(struct inode___210 *, int);
	int (*write_inode)(struct inode___210 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___210 *);
	void (*evict_inode)(struct inode___210 *);
	void (*put_super)(struct super_block___209 *);
	int (*sync_fs)(struct super_block___209 *, int);
	int (*freeze_super)(struct super_block___209 *);
	int (*freeze_fs)(struct super_block___209 *);
	int (*thaw_super)(struct super_block___209 *);
	int (*unfreeze_fs)(struct super_block___209 *);
	int (*statfs)(struct dentry___209 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___209 *, int *, char *);
	void (*umount_begin)(struct super_block___209 *);
	int (*show_options)(struct seq_file___194 *, struct dentry___209 *);
	int (*show_devname)(struct seq_file___194 *, struct dentry___209 *);
	int (*show_path)(struct seq_file___194 *, struct dentry___209 *);
	int (*show_stats)(struct seq_file___194 *, struct dentry___209 *);
	ssize_t (*quota_read)(struct super_block___209 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___209 *, int, const char *, size_t, loff_t);
	struct dquot___209 ** (*get_dquots)(struct inode___210 *);
	int (*bdev_try_to_free_page)(struct super_block___209 *, struct page___210 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___209 *, struct shrink_control___94 *);
	long int (*free_cached_objects)(struct super_block___209 *, struct shrink_control___94 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___192;

struct seq_file___194 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___192 *op;
	int poll_event;
	const struct file___210 *file;
	void *private;
};

struct kset___199;

struct kobj_type___199;

struct kernfs_node___203;

struct kobject___200 {
	const char *name;
	struct list_head entry;
	struct kobject___200 *parent;
	struct kset___199 *kset;
	struct kobj_type___199 *ktype;
	struct kernfs_node___203 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*proc_write_t___11)(struct file___210 *, char *, size_t);

struct uts_namespace___24 {
	struct kref kref;
	struct new_utsname name;
	struct user_namespace___181 *user_ns;
	struct ucounts___181 *ucounts;
	struct ns_common___21 ns;
};

struct ipc_ids___2 {
	int in_use;
	short unsigned int seq;
	struct rw_semaphore___210 rwsem;
	struct idr ipcs_idr;
	int max_idx;
	int last_idx;
	int next_id;
	struct rhashtable key_ht;
};

struct ipc_namespace___2 {
	refcount_t count;
	struct ipc_ids___2 ids[3];
	int sem_ctls[4];
	int used_sems;
	unsigned int msg_ctlmax;
	unsigned int msg_ctlmnb;
	unsigned int msg_ctlmni;
	atomic_t msg_bytes;
	atomic_t msg_hdrs;
	size_t shm_ctlmax;
	size_t shm_ctlall;
	long unsigned int shm_tot;
	int shm_ctlmni;
	int shm_rmid_forced;
	struct notifier_block ipcns_nb;
	struct vfsmount *mq_mnt;
	unsigned int mq_queues_count;
	unsigned int mq_queues_max;
	unsigned int mq_msg_max;
	unsigned int mq_msgsize_max;
	unsigned int mq_msg_default;
	unsigned int mq_msgsize_default;
	struct user_namespace___181 *user_ns;
	struct ucounts___181 *ucounts;
	struct ns_common___21 ns;
};

struct dst_ops___32 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___32 *);
	struct dst_entry___2 * (*check)(struct dst_entry___2 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___2 *);
	unsigned int (*mtu)(const struct dst_entry___2 *);
	u32 * (*cow_metrics)(struct dst_entry___2 *, long unsigned int);
	void (*destroy)(struct dst_entry___2 *);
	void (*ifdown)(struct dst_entry___2 *, struct net_device *, int);
	struct dst_entry___2 * (*negative_advice)(struct dst_entry___2 *);
	void (*link_failure)(struct sk_buff___26 *);
	void (*update_pmtu)(struct dst_entry___2 *, struct sock *, struct sk_buff___26 *, u32);
	void (*redirect)(struct dst_entry___2 *, struct sock *, struct sk_buff___26 *);
	int (*local_out)(struct net___34 *, struct sock *, struct sk_buff___26 *);
	struct neighbour___2 * (*neigh_lookup)(const struct dst_entry___2 *, struct sk_buff___26 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___2 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___32 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___23 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___32 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct sock *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops *notifier_ops;
	struct fib_notifier_ops *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_xfrm___32 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___32 xfrm4_dst_ops;
	struct dst_ops___32 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct net___34 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___181 *user_ns;
	struct ucounts___181 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___21 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___23 ipv4;
	struct netns_ipv6___32 ipv6;
	struct netns_sctp___12 sctp;
	struct netns_nf nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___23 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock *nfnl;
	struct sock *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___32 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef int (*key_restrict_link_func_t___204)(struct key___204 *, const struct key_type *, const union key_payload *, struct key___204 *);

struct key_restriction___204;

struct key___204 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___210 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___204 *restrict_link;
};

struct key_restriction___204 {
	key_restrict_link_func_t___204 check;
	struct key___204 *key;
	struct key_type *keytype;
};

struct dev_pm_info___185 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___185 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___185;

struct bus_type___185;

struct device_driver___185;

struct dev_pm_domain___185;

struct dma_map_ops___42;

struct fwnode_handle___128;

struct class___185;

struct attribute_group___187;

struct device___185 {
	struct device___185 *parent;
	struct device_private *p;
	struct kobject___200 kobj;
	const char *init_name;
	const struct device_type___185 *type;
	struct mutex mutex;
	struct bus_type___185 *bus;
	struct device_driver___185 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___185 power;
	struct dev_pm_domain___185 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___42 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___128 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___185 *class;
	const struct attribute_group___187 **groups;
	void (*release)(struct device___185 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct kobj_attribute___197 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___200 *, struct kobj_attribute___197 *, char *);
	ssize_t (*store)(struct kobject___200 *, struct kobj_attribute___197 *, const char *, size_t);
};

typedef void compound_page_dtor___204(struct page___210 *);

struct proc_ns_operations___21 {
	const char *name;
	const char *real_ns_name;
	int type;
	struct ns_common___21 * (*get)(struct task_struct___210 *);
	void (*put)(struct ns_common___21 *);
	int (*install)(struct nsproxy___195 *, struct ns_common___21 *);
	struct user_namespace___181 * (*owner)(struct ns_common___21 *);
	struct ns_common___21 * (*get_parent)(struct ns_common___21 *);
};

struct ucounts___181 {
	struct hlist_node node;
	struct user_namespace___181 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct proc_dir_entry {
	atomic_t in_use;
	refcount_t refcnt;
	struct list_head pde_openers;
	spinlock_t pde_unload_lock;
	struct completion *pde_unload_completion;
	const struct inode_operations___209 *proc_iops;
	const struct file_operations___210 *proc_fops;
	union {
		const struct seq_operations___192 *seq_ops;
		int (*single_show)(struct seq_file___194 *, void *);
	};
	proc_write_t___11 write;
	void *data;
	unsigned int state_size;
	unsigned int low_ino;
	nlink_t nlink;
	kuid_t uid;
	kgid_t gid;
	loff_t size;
	struct proc_dir_entry *parent;
	struct rb_root subdir;
	struct rb_node subdir_node;
	char *name;
	umode_t mode;
	u8 namelen;
	char inline_name[0];
};

struct kernfs_root___203;

struct kernfs_elem_dir___203 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___203 *root;
};

struct kernfs_syscall_ops___203;

struct kernfs_root___203 {
	struct kernfs_node___203 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___203 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___203 {
	struct kernfs_node___203 *target_kn;
};

struct kernfs_ops___203;

struct kernfs_elem_attr___203 {
	const struct kernfs_ops___203 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___203 *notify_next;
};

struct kernfs_node___203 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___203 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___203 dir;
		struct kernfs_elem_symlink___203 symlink;
		struct kernfs_elem_attr___203 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___203;

struct kernfs_ops___203 {
	int (*open)(struct kernfs_open_file___203 *);
	void (*release)(struct kernfs_open_file___203 *);
	int (*seq_show)(struct seq_file___194 *, void *);
	void * (*seq_start)(struct seq_file___194 *, loff_t *);
	void * (*seq_next)(struct seq_file___194 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___194 *, void *);
	ssize_t (*read)(struct kernfs_open_file___203 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___203 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___203 *, struct vm_area_struct___210 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___203 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___203 {
	int (*remount_fs)(struct kernfs_root___203 *, int *, char *);
	int (*show_options)(struct seq_file___194 *, struct kernfs_root___203 *);
	int (*mkdir)(struct kernfs_node___203 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___203 *);
	int (*rename)(struct kernfs_node___203 *, struct kernfs_node___203 *, const char *);
	int (*show_path)(struct seq_file___194 *, struct kernfs_node___203 *, struct kernfs_root___203 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___203 {
	struct kernfs_node___203 *kn;
	struct file___210 *file;
	struct seq_file___194 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___204 *vm_ops;
};

struct bin_attribute___186;

struct attribute_group___187 {
	const char *name;
	umode_t (*is_visible)(struct kobject___200 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___200 *, struct bin_attribute___186 *, int);
	struct attribute **attrs;
	struct bin_attribute___186 **bin_attrs;
};

struct bin_attribute___186 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___210 *, struct kobject___200 *, struct bin_attribute___186 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___210 *, struct kobject___200 *, struct bin_attribute___186 *, char *, loff_t, size_t);
	int (*mmap)(struct file___210 *, struct kobject___200 *, struct bin_attribute___186 *, struct vm_area_struct___210 *);
};

struct sysfs_ops___199 {
	ssize_t (*show)(struct kobject___200 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___200 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___199;

struct kset___199 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___200 kobj;
	const struct kset_uevent_ops___199 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___199 {
	void (*release)(struct kobject___200 *);
	const struct sysfs_ops___199 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___12 * (*child_ns_type)(struct kobject___200 *);
	const void * (*namespace)(struct kobject___200 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___199 {
	int (* const filter)(struct kset___199 *, struct kobject___200 *);
	const char * (* const name)(struct kset___199 *, struct kobject___200 *);
	int (* const uevent)(struct kset___199 *, struct kobject___200 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___185 {
	int (*prepare)(struct device___185 *);
	void (*complete)(struct device___185 *);
	int (*suspend)(struct device___185 *);
	int (*resume)(struct device___185 *);
	int (*freeze)(struct device___185 *);
	int (*thaw)(struct device___185 *);
	int (*poweroff)(struct device___185 *);
	int (*restore)(struct device___185 *);
	int (*suspend_late)(struct device___185 *);
	int (*resume_early)(struct device___185 *);
	int (*freeze_late)(struct device___185 *);
	int (*thaw_early)(struct device___185 *);
	int (*poweroff_late)(struct device___185 *);
	int (*restore_early)(struct device___185 *);
	int (*suspend_noirq)(struct device___185 *);
	int (*resume_noirq)(struct device___185 *);
	int (*freeze_noirq)(struct device___185 *);
	int (*thaw_noirq)(struct device___185 *);
	int (*poweroff_noirq)(struct device___185 *);
	int (*restore_noirq)(struct device___185 *);
	int (*runtime_suspend)(struct device___185 *);
	int (*runtime_resume)(struct device___185 *);
	int (*runtime_idle)(struct device___185 *);
};

struct dev_pm_domain___185 {
	struct dev_pm_ops___185 ops;
	void (*detach)(struct device___185 *, bool);
	int (*activate)(struct device___185 *);
	void (*sync)(struct device___185 *);
	void (*dismiss)(struct device___185 *);
};

struct bus_type___185 {
	const char *name;
	const char *dev_name;
	struct device___185 *dev_root;
	const struct attribute_group___187 **bus_groups;
	const struct attribute_group___187 **dev_groups;
	const struct attribute_group___187 **drv_groups;
	int (*match)(struct device___185 *, struct device_driver___185 *);
	int (*uevent)(struct device___185 *, struct kobj_uevent_env *);
	int (*probe)(struct device___185 *);
	int (*remove)(struct device___185 *);
	void (*shutdown)(struct device___185 *);
	int (*online)(struct device___185 *);
	int (*offline)(struct device___185 *);
	int (*suspend)(struct device___185 *, pm_message_t);
	int (*resume)(struct device___185 *);
	int (*num_vf)(struct device___185 *);
	int (*dma_configure)(struct device___185 *);
	const struct dev_pm_ops___185 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___185 {
	const char *name;
	struct bus_type___185 *bus;
	struct module___11 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___185 *);
	int (*remove)(struct device___185 *);
	void (*shutdown)(struct device___185 *);
	int (*suspend)(struct device___185 *, pm_message_t);
	int (*resume)(struct device___185 *);
	const struct attribute_group___187 **groups;
	const struct dev_pm_ops___185 *pm;
	void (*coredump)(struct device___185 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___185 {
	const char *name;
	const struct attribute_group___187 **groups;
	int (*uevent)(struct device___185 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___185 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___185 *);
	const struct dev_pm_ops___185 *pm;
};

struct class___185 {
	const char *name;
	struct module___11 *owner;
	const struct attribute_group___187 **class_groups;
	const struct attribute_group___187 **dev_groups;
	struct kobject___200 *dev_kobj;
	int (*dev_uevent)(struct device___185 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___185 *, umode_t *);
	void (*class_release)(struct class___185 *);
	void (*dev_release)(struct device___185 *);
	int (*shutdown_pre)(struct device___185 *);
	const struct kobj_ns_type_operations___12 *ns_type;
	const void * (*namespace)(struct device___185 *);
	const struct dev_pm_ops___185 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___42 {
	void * (*alloc)(struct device___185 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___185 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___185 *, struct vm_area_struct___210 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___185 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___185 *, struct page___210 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___185 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___185 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___185 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___185 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___185 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___185 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___185 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___185 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___185 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___185 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___185 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___185 *, u64);
	u64 (*get_required_mask)(struct device___185 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___128;

struct fwnode_handle___128 {
	struct fwnode_handle___128 *secondary;
	const struct fwnode_operations___128 *ops;
};

struct fwnode_reference_args___128;

struct fwnode_endpoint___128;

struct fwnode_operations___128 {
	struct fwnode_handle___128 * (*get)(struct fwnode_handle___128 *);
	void (*put)(struct fwnode_handle___128 *);
	bool (*device_is_available)(const struct fwnode_handle___128 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___128 *, const struct device___185 *);
	bool (*property_present)(const struct fwnode_handle___128 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___128 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___128 *, const char *, const char **, size_t);
	struct fwnode_handle___128 * (*get_parent)(const struct fwnode_handle___128 *);
	struct fwnode_handle___128 * (*get_next_child_node)(const struct fwnode_handle___128 *, struct fwnode_handle___128 *);
	struct fwnode_handle___128 * (*get_named_child_node)(const struct fwnode_handle___128 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___128 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___128 *);
	struct fwnode_handle___128 * (*graph_get_next_endpoint)(const struct fwnode_handle___128 *, struct fwnode_handle___128 *);
	struct fwnode_handle___128 * (*graph_get_remote_endpoint)(const struct fwnode_handle___128 *);
	struct fwnode_handle___128 * (*graph_get_port_parent)(struct fwnode_handle___128 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___128 *, struct fwnode_endpoint___128 *);
};

struct fwnode_endpoint___128 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___128 *local_fwnode;
};

struct fwnode_reference_args___128 {
	struct fwnode_handle___128 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___45;

struct pipe_buffer___45 {
	struct page___210 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___45 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___45 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___45 *, struct pipe_buffer___45 *);
	void (*release)(struct pipe_inode_info___45 *, struct pipe_buffer___45 *);
	int (*steal)(struct pipe_inode_info___45 *, struct pipe_buffer___45 *);
	union {
		bool (*get)(struct pipe_inode_info___45 *, struct pipe_buffer___45 *);
		struct {
			void (*get)(struct pipe_inode_info___45 *, struct pipe_buffer___45 *);
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
};

struct seq_operations___192 {
	void * (*start)(struct seq_file___194 *, loff_t *);
	void (*stop)(struct seq_file___194 *, void *);
	void * (*next)(struct seq_file___194 *, void *, loff_t *);
	int (*show)(struct seq_file___194 *, void *);
};

struct linux_binprm___31 {
	char buf[256];
	struct vm_area_struct___210 *vma;
	long unsigned int vma_pages;
	struct mm_struct___209 *mm;
	long unsigned int p;
	unsigned int called_set_creds: 1;
	unsigned int cap_elevated: 1;
	unsigned int secureexec: 1;
	unsigned int recursion_depth;
	struct file___210 *file;
	struct cred___204 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
};

struct coredump_params___30 {
	union {
		const kernel_siginfo_t *siginfo;
		struct {
			const siginfo_t *siginfo;
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	struct pt_regs *regs;
	struct file___210 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
};

union proc_op___8 {
	int (*proc_get_link)(struct dentry___209 *, struct path___209 *);
	int (*proc_show)(struct seq_file___194 *, struct pid_namespace___163 *, struct pid___163 *, struct task_struct___210 *);
};

struct proc_inode___8 {
	struct pid___163 *pid;
	unsigned int fd;
	union proc_op___8 op;
	struct proc_dir_entry *pde;
	struct ctl_table_header *sysctl;
	struct ctl_table *sysctl_entry;
	struct hlist_node sysctl_inodes;
	const struct proc_ns_operations___21 *ns_ops;
	struct inode___210 vfs_inode;
};

struct file___211;

struct kiocb___211;

struct vm_area_struct___211;

struct inode___211;

struct file_lock___211;

struct page___211;

struct file_operations___211 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___211 *, loff_t, int);
	ssize_t (*read)(struct file___211 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___211 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___211 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___211 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___211 *, bool);
	int (*iterate)(struct file___211 *, struct dir_context *);
	int (*iterate_shared)(struct file___211 *, struct dir_context *);
	__poll_t (*poll)(struct file___211 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___211 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___211 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___211 *, struct vm_area_struct___211 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___211 *, struct file___211 *);
	int (*flush)(struct file___211 *, fl_owner_t);
	int (*release)(struct inode___211 *, struct file___211 *);
	int (*fsync)(struct file___211 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___211 *, int);
	int (*lock)(struct file___211 *, int, struct file_lock___211 *);
	ssize_t (*sendpage)(struct file___211 *, struct page___211 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___211 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___211 *, int, struct file_lock___211 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___211 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___211 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___211 *, long int, struct file_lock___211 **, void **);
	long int (*fallocate)(struct file___211 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___211 *);
	ssize_t (*copy_file_range)(struct file___211 *, loff_t, struct file___211 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___211 *, loff_t, struct file___211 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___211 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___210 {
	u64 seqnum;
	struct vm_area_struct___211 *vmas[4];
};

struct page_frag___210 {
	struct page___211 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___210;

struct pid___164;

struct nsproxy___196;

struct task_struct___211 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___211 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___210 *mm;
	struct mm_struct___210 *active_mm;
	struct vmacache___210 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___211 *real_parent;
	struct task_struct___211 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___211 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___164 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___164 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___164 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___2 *ptracer_cred;
	const struct cred___2 *real_cred;
	const struct cred___2 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___196 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___211 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___55 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___210 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___211 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___120 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___164;

struct upid___164 {
	int nr;
	struct pid_namespace___164 *ns;
};

struct proc_ns_operations___22;

struct ns_common___22 {
	atomic_long_t stashed;
	const struct proc_ns_operations___22 *ops;
	unsigned int inum;
};

struct dentry___210;

struct pid_namespace___164 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___211 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___164 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___210 *proc_self;
	struct dentry___210 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___3 *user_ns;
	struct ucounts___2 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___22 ns;
};

struct pid___164 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___164 numbers[1];
};

struct secondary_data___211 {
	void *stack;
	struct task_struct___211 *task;
	long int status;
};

typedef struct page___211 *pgtable_t___210;

struct address_space___210;

struct dev_pagemap___205;

struct page___211 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___210 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___211 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___210 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___210 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___205 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct vm_operations_struct___205;

struct vm_area_struct___211 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___211 *vm_next;
	struct vm_area_struct___211 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___210 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___205 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___211 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct rw_semaphore___211 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___211 *owner;
};

struct linux_binfmt___31;

struct core_state___210;

struct mm_struct___210 {
	struct {
		struct vm_area_struct___211 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___211 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___211 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___31 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___210 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___211 *owner;
		struct user_namespace___3 *user_ns;
		struct file___211 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___210 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct nsproxy___196 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___164 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___2 *cgroup_ns;
};

union thread_union___188 {
	struct task_struct___211 task;
	long unsigned int stack[8192];
};

struct pglist_data___210;

struct lruvec___210 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___210 *pgdat;
};

struct zone___210 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___210 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___210 {
	struct zone___210 *zone;
	int zone_idx;
};

struct zonelist___210 {
	struct zoneref___210 _zonerefs[25];
};

struct pglist_data___210 {
	struct zone___210 node_zones[3];
	struct zonelist___210 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___211 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___211 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___210 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___210 {
	struct rw_semaphore___211 rwsem;
	struct notifier_block *head;
};

struct address_space_operations___210;

struct address_space___210 {
	struct inode___211 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___211 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___210 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___205)(struct vm_area_struct___211 *, long unsigned int, const struct page___211 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___205)(struct page___211 *, void *);

struct dev_pagemap___205 {
	dev_page_fault_t___205 page_fault;
	dev_page_free_t___205 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___6 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___210 {
	struct vfsmount *mnt;
	struct dentry___210 *dentry;
};

struct fown_struct___164 {
	rwlock_t lock;
	struct pid___164 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___211 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___210 f_path;
	struct inode___211 *f_inode;
	const struct file_operations___211 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___164 f_owner;
	const struct cred___2 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___210 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___205;

struct vm_operations_struct___205 {
	void (*open)(struct vm_area_struct___211 *);
	void (*close)(struct vm_area_struct___211 *);
	int (*split)(struct vm_area_struct___211 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___211 *);
	vm_fault_t (*fault)(struct vm_fault___205 *);
	vm_fault_t (*huge_fault)(struct vm_fault___205 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___205 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___211 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___205 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___205 *);
	int (*access)(struct vm_area_struct___211 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___211 *);
	int (*set_policy)(struct vm_area_struct___211 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___211 *, long unsigned int);
	struct page___211 * (*find_special_page)(struct vm_area_struct___211 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___210 {
	struct task_struct___211 *task;
	struct core_thread___210 *next;
};

struct core_state___210 {
	atomic_t nr_threads;
	struct core_thread___210 dumper;
	struct completion startup;
};

struct linux_binprm___32;

struct coredump_params___31;

struct linux_binfmt___31 {
	struct list_head lh;
	struct module___11 *module;
	int (*load_binary)(struct linux_binprm___32 *);
	int (*load_shlib)(struct file___211 *);
	int (*core_dump)(struct coredump_params___31 *);
	long unsigned int min_coredump;
};

struct vm_fault___205 {
	struct vm_area_struct___211 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___211 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___211 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___210 prealloc_pte;
};

struct dentry_operations___210;

struct super_block___210;

struct dentry___210 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___210 *d_parent;
	struct qstr d_name;
	struct inode___211 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___210 *d_op;
	struct super_block___210 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___210;

struct block_device___211;

struct inode___211 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___210 *i_op;
	struct super_block___210 *i_sb;
	struct address_space___210 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___211 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___211 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___210 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___211 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___210 {
	int (*d_revalidate)(struct dentry___210 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___210 *, unsigned int);
	int (*d_hash)(const struct dentry___210 *, struct qstr *);
	int (*d_compare)(const struct dentry___210 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___210 *);
	int (*d_init)(struct dentry___210 *);
	void (*d_release)(struct dentry___210 *);
	void (*d_prune)(struct dentry___210 *);
	void (*d_iput)(struct dentry___210 *, struct inode___211 *);
	char * (*d_dname)(struct dentry___210 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___210 *);
	int (*d_manage)(const struct path___210 *, bool);
	struct dentry___210 * (*d_real)(struct dentry___210 *, const struct inode___211 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___210;

struct mem_dqinfo___210 {
	struct quota_format_type___210 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___210;

struct quota_info___210 {
	unsigned int flags;
	struct rw_semaphore___211 dqio_sem;
	struct inode___211 *files[3];
	struct mem_dqinfo___210 info[3];
	const struct quota_format_ops___210 *ops[3];
};

struct rcuwait___210 {
	struct task_struct___211 *task;
};

struct percpu_rw_semaphore___210 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___211 rw_sem;
	struct rcuwait___210 writer;
	int readers_block;
};

struct sb_writers___210 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___210 rw_sem[3];
};

struct file_system_type___210;

struct super_operations___210;

struct dquot_operations___210;

struct quotactl_ops___210;

struct super_block___210 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___210 *s_type;
	const struct super_operations___210 *s_op;
	const struct dquot_operations___210 *dq_op;
	const struct quotactl_ops___210 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___210 *s_root;
	struct rw_semaphore___211 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___211 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___210 s_dquot;
	struct sb_writers___210 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___210 *s_d_op;
	int cleancache_poolid;
	struct shrinker___94 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___211 {
	struct file___211 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___211 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___210 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___211 *ia_file;
};

struct dquot___210 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___210 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___210 {
	int qf_fmt_id;
	const struct quota_format_ops___210 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___210 *qf_next;
};

struct quota_format_ops___210 {
	int (*check_quota_file)(struct super_block___210 *, int);
	int (*read_file_info)(struct super_block___210 *, int);
	int (*write_file_info)(struct super_block___210 *, int);
	int (*free_file_info)(struct super_block___210 *, int);
	int (*read_dqblk)(struct dquot___210 *);
	int (*commit_dqblk)(struct dquot___210 *);
	int (*release_dqblk)(struct dquot___210 *);
	int (*get_next_id)(struct super_block___210 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___210 {
	int (*write_dquot)(struct dquot___210 *);
	struct dquot___210 * (*alloc_dquot)(struct super_block___210 *, int);
	void (*destroy_dquot)(struct dquot___210 *);
	int (*acquire_dquot)(struct dquot___210 *);
	int (*release_dquot)(struct dquot___210 *);
	int (*mark_dirty)(struct dquot___210 *);
	int (*write_info)(struct super_block___210 *, int);
	qsize_t * (*get_reserved_space)(struct inode___211 *);
	int (*get_projid)(struct inode___211 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___211 *, qsize_t *);
	int (*get_next_id)(struct super_block___210 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___210 {
	int (*quota_on)(struct super_block___210 *, int, int, const struct path___210 *);
	int (*quota_off)(struct super_block___210 *, int);
	int (*quota_enable)(struct super_block___210 *, unsigned int);
	int (*quota_disable)(struct super_block___210 *, unsigned int);
	int (*quota_sync)(struct super_block___210 *, int);
	int (*set_info)(struct super_block___210 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___210 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___210 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___210 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___210 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___210 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___210 {
	int (*writepage)(struct page___211 *, struct writeback_control___3 *);
	int (*readpage)(struct file___211 *, struct page___211 *);
	int (*writepages)(struct address_space___210 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___211 *);
	int (*readpages)(struct file___211 *, struct address_space___210 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___211 *, struct address_space___210 *, loff_t, unsigned int, unsigned int, struct page___211 **, void **);
	int (*write_end)(struct file___211 *, struct address_space___210 *, loff_t, unsigned int, unsigned int, struct page___211 *, void *);
	sector_t (*bmap)(struct address_space___210 *, sector_t);
	void (*invalidatepage)(struct page___211 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___211 *, gfp_t);
	void (*freepage)(struct page___211 *);
	ssize_t (*direct_IO)(struct kiocb___211 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___210 *, struct page___211 *, struct page___211 *, enum migrate_mode);
	bool (*isolate_page)(struct page___211 *, isolate_mode_t);
	void (*putback_page)(struct page___211 *);
	int (*launder_page)(struct page___211 *);
	int (*is_partially_uptodate)(struct page___211 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___211 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___210 *, struct page___211 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___211 *, sector_t *);
	void (*swap_deactivate)(struct file___211 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___211 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___211 *bd_inode;
	struct super_block___210 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___211 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___210 {
	struct dentry___210 * (*lookup)(struct inode___211 *, struct dentry___210 *, unsigned int);
	const char * (*get_link)(struct dentry___210 *, struct inode___211 *, struct delayed_call *);
	int (*permission)(struct inode___211 *, int);
	struct posix_acl * (*get_acl)(struct inode___211 *, int);
	int (*readlink)(struct dentry___210 *, char *, int);
	int (*create)(struct inode___211 *, struct dentry___210 *, umode_t, bool);
	int (*link)(struct dentry___210 *, struct inode___211 *, struct dentry___210 *);
	int (*unlink)(struct inode___211 *, struct dentry___210 *);
	int (*symlink)(struct inode___211 *, struct dentry___210 *, const char *);
	int (*mkdir)(struct inode___211 *, struct dentry___210 *, umode_t);
	int (*rmdir)(struct inode___211 *, struct dentry___210 *);
	int (*mknod)(struct inode___211 *, struct dentry___210 *, umode_t, dev_t);
	int (*rename)(struct inode___211 *, struct dentry___210 *, struct inode___211 *, struct dentry___210 *, unsigned int);
	int (*setattr)(struct dentry___210 *, struct iattr___210 *);
	int (*getattr)(const struct path___210 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___210 *, char *, size_t);
	int (*fiemap)(struct inode___211 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___211 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___211 *, struct dentry___210 *, struct file___211 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___211 *, struct dentry___210 *, umode_t);
	int (*set_acl)(struct inode___211 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___210 {
	void (*fl_copy_lock)(struct file_lock___211 *, struct file_lock___211 *);
	void (*fl_release_private)(struct file_lock___211 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___210;

struct lock_manager_operations___210;

struct file_lock___211 {
	struct file_lock___211 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___211 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___210 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___210 *fl_ops;
	const struct lock_manager_operations___210 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___210 {
	int (*lm_compare_owner)(struct file_lock___211 *, struct file_lock___211 *);
	long unsigned int (*lm_owner_key)(struct file_lock___211 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___211 *);
	int (*lm_grant)(struct file_lock___211 *, int);
	bool (*lm_break)(struct file_lock___211 *);
	int (*lm_change)(struct file_lock___211 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___211 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___210 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___210 *fa_next;
	struct file___211 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___210 {
	const char *name;
	int fs_flags;
	struct dentry___210 * (*mount)(struct file_system_type___210 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___210 *);
	struct module___11 *owner;
	struct file_system_type___210 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___210 {
	struct inode___211 * (*alloc_inode)(struct super_block___210 *);
	void (*destroy_inode)(struct inode___211 *);
	void (*dirty_inode)(struct inode___211 *, int);
	int (*write_inode)(struct inode___211 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___211 *);
	void (*evict_inode)(struct inode___211 *);
	void (*put_super)(struct super_block___210 *);
	int (*sync_fs)(struct super_block___210 *, int);
	int (*freeze_super)(struct super_block___210 *);
	int (*freeze_fs)(struct super_block___210 *);
	int (*thaw_super)(struct super_block___210 *);
	int (*unfreeze_fs)(struct super_block___210 *);
	int (*statfs)(struct dentry___210 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___210 *, int *, char *);
	void (*umount_begin)(struct super_block___210 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___210 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___210 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___210 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___210 *);
	ssize_t (*quota_read)(struct super_block___210 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___210 *, int, const char *, size_t, loff_t);
	struct dquot___210 ** (*get_dquots)(struct inode___211 *);
	int (*bdev_try_to_free_page)(struct super_block___210 *, struct page___211 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___210 *, struct shrink_control___94 *);
	long int (*free_cached_objects)(struct super_block___210 *, struct shrink_control___94 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___205(struct page___211 *);

struct proc_ns_operations___22 {
	const char *name;
	const char *real_ns_name;
	int type;
	struct ns_common___22 * (*get)(struct task_struct___211 *);
	void (*put)(struct ns_common___22 *);
	int (*install)(struct nsproxy___196 *, struct ns_common___22 *);
	struct user_namespace___3 * (*owner)(struct ns_common___22 *);
	struct ns_common___22 * (*get_parent)(struct ns_common___22 *);
};

typedef int (*proc_write_t___12)(struct file___211 *, char *, size_t);

struct linux_binprm___32 {
	char buf[256];
	struct vm_area_struct___211 *vma;
	long unsigned int vma_pages;
	struct mm_struct___210 *mm;
	long unsigned int p;
	unsigned int called_set_creds: 1;
	unsigned int cap_elevated: 1;
	unsigned int secureexec: 1;
	unsigned int recursion_depth;
	struct file___211 *file;
	struct cred___2 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
};

struct coredump_params___31 {
	union {
		const kernel_siginfo_t *siginfo;
		struct {
			const siginfo_t *siginfo;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	struct pt_regs *regs;
	struct file___211 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
};

struct proc_dir_entry___12 {
	atomic_t in_use;
	refcount_t refcnt;
	struct list_head pde_openers;
	spinlock_t pde_unload_lock;
	struct completion *pde_unload_completion;
	const struct inode_operations___210 *proc_iops;
	const struct file_operations___211 *proc_fops;
	union {
		const struct seq_operations___192 *seq_ops;
		int (*single_show)(struct seq_file___194 *, void *);
	};
	proc_write_t___12 write;
	void *data;
	unsigned int state_size;
	unsigned int low_ino;
	nlink_t nlink;
	kuid_t uid;
	kgid_t gid;
	loff_t size;
	struct proc_dir_entry___12 *parent;
	struct rb_root subdir;
	struct rb_node subdir_node;
	char *name;
	umode_t mode;
	u8 namelen;
	char inline_name[0];
};

struct module___174;

struct file___212;

struct kiocb___212;

struct poll_table_struct___139;

struct vm_area_struct___212;

struct inode___212;

struct file_lock___212;

struct page___212;

struct file_operations___212 {
	struct module___174 *owner;
	loff_t (*llseek)(struct file___212 *, loff_t, int);
	ssize_t (*read)(struct file___212 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___212 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___212 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___212 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___212 *, bool);
	int (*iterate)(struct file___212 *, struct dir_context *);
	int (*iterate_shared)(struct file___212 *, struct dir_context *);
	__poll_t (*poll)(struct file___212 *, struct poll_table_struct___139 *);
	long int (*unlocked_ioctl)(struct file___212 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___212 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___212 *, struct vm_area_struct___212 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___212 *, struct file___212 *);
	int (*flush)(struct file___212 *, fl_owner_t);
	int (*release)(struct inode___212 *, struct file___212 *);
	int (*fsync)(struct file___212 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___212 *, int);
	int (*lock)(struct file___212 *, int, struct file_lock___212 *);
	ssize_t (*sendpage)(struct file___212 *, struct page___212 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___212 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___212 *, int, struct file_lock___212 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___212 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___212 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___212 *, long int, struct file_lock___212 **, void **);
	long int (*fallocate)(struct file___212 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___212 *);
	ssize_t (*copy_file_range)(struct file___212 *, loff_t, struct file___212 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___212 *, loff_t, struct file___212 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___212 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___211 {
	u64 seqnum;
	struct vm_area_struct___212 *vmas[4];
};

struct page_frag___211 {
	struct page___212 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___211;

struct cred___205;

struct task_struct___212 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___212 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___211 *mm;
	struct mm_struct___211 *active_mm;
	struct vmacache___211 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___212 *real_parent;
	struct task_struct___212 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___212 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___164 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___164 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___164 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___205 *ptracer_cred;
	const struct cred___205 *real_cred;
	const struct cred___205 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___212 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___55 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___211 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___212 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___120 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct secondary_data___212 {
	void *stack;
	struct task_struct___212 *task;
	long int status;
};

struct dentry_operations___211;

struct super_block___211;

struct dentry___211 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___211 *d_parent;
	struct qstr d_name;
	struct inode___212 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___211 *d_op;
	struct super_block___211 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct rw_semaphore___212 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___212 *owner;
};

struct address_space_operations___211;

struct address_space___211 {
	struct inode___212 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___212 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___211 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___211;

struct block_device___212;

struct inode___212 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___211 *i_op;
	struct super_block___211 *i_sb;
	struct address_space___211 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___212 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___212 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___211 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___212 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___211;

struct dentry_operations___211 {
	int (*d_revalidate)(struct dentry___211 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___211 *, unsigned int);
	int (*d_hash)(const struct dentry___211 *, struct qstr *);
	int (*d_compare)(const struct dentry___211 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___211 *);
	int (*d_init)(struct dentry___211 *);
	void (*d_release)(struct dentry___211 *);
	void (*d_prune)(struct dentry___211 *);
	void (*d_iput)(struct dentry___211 *, struct inode___212 *);
	char * (*d_dname)(struct dentry___211 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___211 *);
	int (*d_manage)(const struct path___211 *, bool);
	struct dentry___211 * (*d_real)(struct dentry___211 *, const struct inode___212 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___211;

struct mem_dqinfo___211 {
	struct quota_format_type___211 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___211;

struct quota_info___211 {
	unsigned int flags;
	struct rw_semaphore___212 dqio_sem;
	struct inode___212 *files[3];
	struct mem_dqinfo___211 info[3];
	const struct quota_format_ops___211 *ops[3];
};

struct rcuwait___211 {
	struct task_struct___212 *task;
};

struct percpu_rw_semaphore___211 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___212 rw_sem;
	struct rcuwait___211 writer;
	int readers_block;
};

struct sb_writers___211 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___211 rw_sem[3];
};

struct file_system_type___211;

struct super_operations___211;

struct dquot_operations___211;

struct quotactl_ops___211;

struct super_block___211 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___211 *s_type;
	const struct super_operations___211 *s_op;
	const struct dquot_operations___211 *dq_op;
	const struct quotactl_ops___211 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___211 *s_root;
	struct rw_semaphore___212 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___212 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___211 s_dquot;
	struct sb_writers___211 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___211 *s_d_op;
	int cleancache_poolid;
	struct shrinker___94 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct path___211 {
	struct vfsmount *mnt;
	struct dentry___211 *dentry;
};

typedef struct page___212 *pgtable_t___211;

struct dev_pagemap___206;

struct page___212 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___211 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___212 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___211 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___211 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___206 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___211;

struct lruvec___211 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___211 *pgdat;
};

struct zone___211 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___211 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___211 {
	struct zone___211 *zone;
	int zone_idx;
};

struct zonelist___211 {
	struct zoneref___211 _zonerefs[25];
};

struct pglist_data___211 {
	struct zone___211 node_zones[3];
	struct zonelist___211 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___212 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___212 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___211 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___211 {
	struct rw_semaphore___212 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___206;

struct vm_area_struct___212 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___212 *vm_next;
	struct vm_area_struct___212 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___211 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___206 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___212 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct linux_binfmt___32;

struct core_state___211;

struct mm_struct___211 {
	struct {
		struct vm_area_struct___212 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___212 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___212 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___32 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___211 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___212 *owner;
		struct user_namespace___3 *user_ns;
		struct file___212 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___211 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___206)(struct vm_area_struct___212 *, long unsigned int, const struct page___212 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___206)(struct page___212 *, void *);

struct dev_pagemap___206 {
	dev_page_fault_t___206 page_fault;
	dev_page_free_t___206 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___6 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct file___212 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___211 f_path;
	struct inode___212 *f_inode;
	const struct file_operations___212 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___164 f_owner;
	const struct cred___205 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___211 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___206;

struct vm_operations_struct___206 {
	void (*open)(struct vm_area_struct___212 *);
	void (*close)(struct vm_area_struct___212 *);
	int (*split)(struct vm_area_struct___212 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___212 *);
	vm_fault_t (*fault)(struct vm_fault___206 *);
	vm_fault_t (*huge_fault)(struct vm_fault___206 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___206 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___212 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___206 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___206 *);
	int (*access)(struct vm_area_struct___212 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___212 *);
	int (*set_policy)(struct vm_area_struct___212 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___212 *, long unsigned int);
	struct page___212 * (*find_special_page)(struct vm_area_struct___212 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___211 {
	struct task_struct___212 *task;
	struct core_thread___211 *next;
};

struct core_state___211 {
	atomic_t nr_threads;
	struct core_thread___211 dumper;
	struct completion startup;
};

struct linux_binprm___33;

struct coredump_params___32;

struct linux_binfmt___32 {
	struct list_head lh;
	struct module___174 *module;
	int (*load_binary)(struct linux_binprm___33 *);
	int (*load_shlib)(struct file___212 *);
	int (*core_dump)(struct coredump_params___32 *);
	long unsigned int min_coredump;
};

struct vm_fault___206 {
	struct vm_area_struct___212 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___212 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___212 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___211 prealloc_pte;
};

struct key___205;

struct user_struct___205 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___205 *uid_keyring;
	struct key___205 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___205 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___205 *session_keyring;
	struct key___205 *process_keyring;
	struct key___205 *thread_keyring;
	struct key___205 *request_key_auth;
	void *security;
	struct user_struct___205 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

union thread_union___189 {
	struct task_struct___212 task;
	long unsigned int stack[8192];
};

struct kiocb___212 {
	struct file___212 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___212 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___211 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___212 *ia_file;
};

struct dquot___211 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___211 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___211 {
	int qf_fmt_id;
	const struct quota_format_ops___211 *qf_ops;
	struct module___174 *qf_owner;
	struct quota_format_type___211 *qf_next;
};

struct quota_format_ops___211 {
	int (*check_quota_file)(struct super_block___211 *, int);
	int (*read_file_info)(struct super_block___211 *, int);
	int (*write_file_info)(struct super_block___211 *, int);
	int (*free_file_info)(struct super_block___211 *, int);
	int (*read_dqblk)(struct dquot___211 *);
	int (*commit_dqblk)(struct dquot___211 *);
	int (*release_dqblk)(struct dquot___211 *);
	int (*get_next_id)(struct super_block___211 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___211 {
	int (*write_dquot)(struct dquot___211 *);
	struct dquot___211 * (*alloc_dquot)(struct super_block___211 *, int);
	void (*destroy_dquot)(struct dquot___211 *);
	int (*acquire_dquot)(struct dquot___211 *);
	int (*release_dquot)(struct dquot___211 *);
	int (*mark_dirty)(struct dquot___211 *);
	int (*write_info)(struct super_block___211 *, int);
	qsize_t * (*get_reserved_space)(struct inode___212 *);
	int (*get_projid)(struct inode___212 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___212 *, qsize_t *);
	int (*get_next_id)(struct super_block___211 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___211 {
	int (*quota_on)(struct super_block___211 *, int, int, const struct path___211 *);
	int (*quota_off)(struct super_block___211 *, int);
	int (*quota_enable)(struct super_block___211 *, unsigned int);
	int (*quota_disable)(struct super_block___211 *, unsigned int);
	int (*quota_sync)(struct super_block___211 *, int);
	int (*set_info)(struct super_block___211 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___211 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___211 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___211 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___211 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___211 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___200;

struct kobj_type___200;

struct kernfs_node___204;

struct kobject___201 {
	const char *name;
	struct list_head entry;
	struct kobject___201 *parent;
	struct kset___200 *kset;
	struct kobj_type___200 *ktype;
	struct kernfs_node___204 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___171 {
	struct kobject___201 kobj;
	struct module___174 *mod;
	struct kobject___201 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___171 {
	struct module___174 *mod;
	struct latch_tree_node node;
};

struct module_layout___171 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___171 mtn;
};

struct module_attribute___171;

struct kernel_param___171;

struct module___174 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___171 mkobj;
	struct module_attribute___171 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___201 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___171 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___171 core_layout;
	struct module_layout___171 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___211 {
	int (*writepage)(struct page___212 *, struct writeback_control___3 *);
	int (*readpage)(struct file___212 *, struct page___212 *);
	int (*writepages)(struct address_space___211 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___212 *);
	int (*readpages)(struct file___212 *, struct address_space___211 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___212 *, struct address_space___211 *, loff_t, unsigned int, unsigned int, struct page___212 **, void **);
	int (*write_end)(struct file___212 *, struct address_space___211 *, loff_t, unsigned int, unsigned int, struct page___212 *, void *);
	sector_t (*bmap)(struct address_space___211 *, sector_t);
	void (*invalidatepage)(struct page___212 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___212 *, gfp_t);
	void (*freepage)(struct page___212 *);
	ssize_t (*direct_IO)(struct kiocb___212 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___211 *, struct page___212 *, struct page___212 *, enum migrate_mode);
	bool (*isolate_page)(struct page___212 *, isolate_mode_t);
	void (*putback_page)(struct page___212 *);
	int (*launder_page)(struct page___212 *);
	int (*is_partially_uptodate)(struct page___212 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___212 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___211 *, struct page___212 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___212 *, sector_t *);
	void (*swap_deactivate)(struct file___212 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___212 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___212 *bd_inode;
	struct super_block___211 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___212 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___211 {
	struct dentry___211 * (*lookup)(struct inode___212 *, struct dentry___211 *, unsigned int);
	const char * (*get_link)(struct dentry___211 *, struct inode___212 *, struct delayed_call *);
	int (*permission)(struct inode___212 *, int);
	struct posix_acl * (*get_acl)(struct inode___212 *, int);
	int (*readlink)(struct dentry___211 *, char *, int);
	int (*create)(struct inode___212 *, struct dentry___211 *, umode_t, bool);
	int (*link)(struct dentry___211 *, struct inode___212 *, struct dentry___211 *);
	int (*unlink)(struct inode___212 *, struct dentry___211 *);
	int (*symlink)(struct inode___212 *, struct dentry___211 *, const char *);
	int (*mkdir)(struct inode___212 *, struct dentry___211 *, umode_t);
	int (*rmdir)(struct inode___212 *, struct dentry___211 *);
	int (*mknod)(struct inode___212 *, struct dentry___211 *, umode_t, dev_t);
	int (*rename)(struct inode___212 *, struct dentry___211 *, struct inode___212 *, struct dentry___211 *, unsigned int);
	int (*setattr)(struct dentry___211 *, struct iattr___211 *);
	int (*getattr)(const struct path___211 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___211 *, char *, size_t);
	int (*fiemap)(struct inode___212 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___212 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___212 *, struct dentry___211 *, struct file___212 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___212 *, struct dentry___211 *, umode_t);
	int (*set_acl)(struct inode___212 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___211 {
	void (*fl_copy_lock)(struct file_lock___212 *, struct file_lock___212 *);
	void (*fl_release_private)(struct file_lock___212 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___211;

struct lock_manager_operations___211;

struct file_lock___212 {
	struct file_lock___212 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___212 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___211 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___211 *fl_ops;
	const struct lock_manager_operations___211 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___211 {
	int (*lm_compare_owner)(struct file_lock___212 *, struct file_lock___212 *);
	long unsigned int (*lm_owner_key)(struct file_lock___212 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___212 *);
	int (*lm_grant)(struct file_lock___212 *, int);
	bool (*lm_break)(struct file_lock___212 *);
	int (*lm_change)(struct file_lock___212 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___212 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___211 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___211 *fa_next;
	struct file___212 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___211 {
	const char *name;
	int fs_flags;
	struct dentry___211 * (*mount)(struct file_system_type___211 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___211 *);
	struct module___174 *owner;
	struct file_system_type___211 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___211 {
	struct inode___212 * (*alloc_inode)(struct super_block___211 *);
	void (*destroy_inode)(struct inode___212 *);
	void (*dirty_inode)(struct inode___212 *, int);
	int (*write_inode)(struct inode___212 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___212 *);
	void (*evict_inode)(struct inode___212 *);
	void (*put_super)(struct super_block___211 *);
	int (*sync_fs)(struct super_block___211 *, int);
	int (*freeze_super)(struct super_block___211 *);
	int (*freeze_fs)(struct super_block___211 *);
	int (*thaw_super)(struct super_block___211 *);
	int (*unfreeze_fs)(struct super_block___211 *);
	int (*statfs)(struct dentry___211 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___211 *, int *, char *);
	void (*umount_begin)(struct super_block___211 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___211 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___211 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___211 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___211 *);
	ssize_t (*quota_read)(struct super_block___211 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___211 *, int, const char *, size_t, loff_t);
	struct dquot___211 ** (*get_dquots)(struct inode___212 *);
	int (*bdev_try_to_free_page)(struct super_block___211 *, struct page___212 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___211 *, struct shrink_control___94 *);
	long int (*free_cached_objects)(struct super_block___211 *, struct shrink_control___94 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___140)(struct file___212 *, wait_queue_head_t *, struct poll_table_struct___139 *);

struct poll_table_struct___139 {
	poll_queue_proc___140 _qproc;
	__poll_t _key;
};

typedef struct poll_table_struct___139 poll_table___18;

typedef int (*proc_write_t___13)(struct file___212 *, char *, size_t);

typedef int (*key_restrict_link_func_t___205)(struct key___205 *, const struct key_type *, const union key_payload *, struct key___205 *);

struct key_restriction___205;

struct key___205 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___212 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___205 *restrict_link;
};

struct key_restriction___205 {
	key_restrict_link_func_t___205 check;
	struct key___205 *key;
	struct key_type *keytype;
};

struct kobj_attribute___198 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___201 *, struct kobj_attribute___198 *, char *);
	ssize_t (*store)(struct kobject___201 *, struct kobj_attribute___198 *, const char *, size_t);
};

typedef void compound_page_dtor___206(struct page___212 *);

struct kernfs_root___204;

struct kernfs_elem_dir___204 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___204 *root;
};

struct kernfs_syscall_ops___204;

struct kernfs_root___204 {
	struct kernfs_node___204 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___204 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___204 {
	struct kernfs_node___204 *target_kn;
};

struct kernfs_ops___204;

struct kernfs_elem_attr___204 {
	const struct kernfs_ops___204 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___204 *notify_next;
};

struct kernfs_node___204 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___204 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___204 dir;
		struct kernfs_elem_symlink___204 symlink;
		struct kernfs_elem_attr___204 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___204;

struct kernfs_ops___204 {
	int (*open)(struct kernfs_open_file___204 *);
	void (*release)(struct kernfs_open_file___204 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___204 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___204 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___204 *, struct vm_area_struct___212 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___204 *, struct poll_table_struct___139 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___204 {
	int (*remount_fs)(struct kernfs_root___204 *, int *, char *);
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___204 *);
	int (*mkdir)(struct kernfs_node___204 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___204 *);
	int (*rename)(struct kernfs_node___204 *, struct kernfs_node___204 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___204 *, struct kernfs_root___204 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___204 {
	struct kernfs_node___204 *kn;
	struct file___212 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___206 *vm_ops;
};

struct sysfs_ops___200 {
	ssize_t (*show)(struct kobject___201 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___201 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___200;

struct kset___200 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___201 kobj;
	const struct kset_uevent_ops___200 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___200 {
	void (*release)(struct kobject___201 *);
	const struct sysfs_ops___200 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___12 * (*child_ns_type)(struct kobject___201 *);
	const void * (*namespace)(struct kobject___201 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___200 {
	int (* const filter)(struct kset___200 *, struct kobject___201 *);
	const char * (* const name)(struct kset___200 *, struct kobject___201 *);
	int (* const uevent)(struct kset___200 *, struct kobject___201 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___171 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___171 *);
	int (*get)(char *, const struct kernel_param___171 *);
	void (*free)(void *);
};

struct kparam_array___171;

struct kernel_param___171 {
	const char *name;
	struct module___174 *mod;
	const struct kernel_param_ops___171 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___171 *arr;
	};
};

struct kparam_array___171 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___171 *ops;
	void *elem;
};

struct module_attribute___171 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___171 *, struct module_kobject___171 *, char *);
	ssize_t (*store)(struct module_attribute___171 *, struct module_kobject___171 *, const char *, size_t);
	void (*setup)(struct module___174 *, const char *);
	int (*test)(struct module___174 *);
	void (*free)(struct module___174 *);
};

struct proc_ns_operations___23;

struct ns_common___23 {
	atomic_long_t stashed;
	const struct proc_ns_operations___23 *ops;
	unsigned int inum;
};

struct proc_ns_operations___23 {
	const char *name;
	const char *real_ns_name;
	int type;
	struct ns_common___23 * (*get)(struct task_struct___212 *);
	void (*put)(struct ns_common___23 *);
	int (*install)(struct nsproxy___8 *, struct ns_common___23 *);
	struct user_namespace___3 * (*owner)(struct ns_common___23 *);
	struct ns_common___23 * (*get_parent)(struct ns_common___23 *);
};

struct linux_binprm___33 {
	char buf[256];
	struct vm_area_struct___212 *vma;
	long unsigned int vma_pages;
	struct mm_struct___211 *mm;
	long unsigned int p;
	unsigned int called_set_creds: 1;
	unsigned int cap_elevated: 1;
	unsigned int secureexec: 1;
	unsigned int recursion_depth;
	struct file___212 *file;
	struct cred___205 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
};

struct coredump_params___32 {
	union {
		const kernel_siginfo_t *siginfo;
		struct {
			const siginfo_t *siginfo;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	struct pt_regs *regs;
	struct file___212 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
};

struct proc_dir_entry___13 {
	atomic_t in_use;
	refcount_t refcnt;
	struct list_head pde_openers;
	spinlock_t pde_unload_lock;
	struct completion *pde_unload_completion;
	const struct inode_operations___211 *proc_iops;
	const struct file_operations___212 *proc_fops;
	union {
		const struct seq_operations___192 *seq_ops;
		int (*single_show)(struct seq_file___194 *, void *);
	};
	proc_write_t___13 write;
	void *data;
	unsigned int state_size;
	unsigned int low_ino;
	nlink_t nlink;
	kuid_t uid;
	kgid_t gid;
	loff_t size;
	struct proc_dir_entry___13 *parent;
	struct rb_root subdir;
	struct rb_node subdir_node;
	char *name;
	umode_t mode;
	u8 namelen;
	char inline_name[0];
};

union proc_op___9 {
	int (*proc_get_link)(struct dentry___211 *, struct path___211 *);
	int (*proc_show)(struct seq_file___9 *, struct pid_namespace *, struct pid___164 *, struct task_struct___212 *);
};

struct proc_inode___9 {
	struct pid___164 *pid;
	unsigned int fd;
	union proc_op___9 op;
	struct proc_dir_entry___13 *pde;
	struct ctl_table_header *sysctl;
	struct ctl_table *sysctl_entry;
	struct hlist_node sysctl_inodes;
	const struct proc_ns_operations___23 *ns_ops;
	struct inode___212 vfs_inode;
};

struct module___175;

struct file___213;

struct kiocb___213;

struct iov_iter___100;

struct vm_area_struct___213;

struct inode___213;

struct file_lock___213;

struct page___213;

struct pipe_inode_info___46;

struct seq_file___195;

struct file_operations___213 {
	struct module___175 *owner;
	loff_t (*llseek)(struct file___213 *, loff_t, int);
	ssize_t (*read)(struct file___213 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___213 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___213 *, struct iov_iter___100 *);
	ssize_t (*write_iter)(struct kiocb___213 *, struct iov_iter___100 *);
	int (*iopoll)(struct kiocb___213 *, bool);
	int (*iterate)(struct file___213 *, struct dir_context *);
	int (*iterate_shared)(struct file___213 *, struct dir_context *);
	__poll_t (*poll)(struct file___213 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___213 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___213 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___213 *, struct vm_area_struct___213 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___213 *, struct file___213 *);
	int (*flush)(struct file___213 *, fl_owner_t);
	int (*release)(struct inode___213 *, struct file___213 *);
	int (*fsync)(struct file___213 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___213 *, int);
	int (*lock)(struct file___213 *, int, struct file_lock___213 *);
	ssize_t (*sendpage)(struct file___213 *, struct page___213 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___213 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___213 *, int, struct file_lock___213 *);
	ssize_t (*splice_write)(struct pipe_inode_info___46 *, struct file___213 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___213 *, loff_t *, struct pipe_inode_info___46 *, size_t, unsigned int);
	int (*setlease)(struct file___213 *, long int, struct file_lock___213 **, void **);
	long int (*fallocate)(struct file___213 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___195 *, struct file___213 *);
	ssize_t (*copy_file_range)(struct file___213 *, loff_t, struct file___213 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___213 *, loff_t, struct file___213 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___213 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___212 {
	u64 seqnum;
	struct vm_area_struct___213 *vmas[4];
};

struct page_frag___212 {
	struct page___213 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___212;

struct cred___206;

struct nsproxy___197;

struct vm_struct___144;

struct task_struct___213 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___213 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___212 *mm;
	struct mm_struct___212 *active_mm;
	struct vmacache___212 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___213 *real_parent;
	struct task_struct___213 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___213 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___164 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___164 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___164 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___206 *ptracer_cred;
	const struct cred___206 *real_cred;
	const struct cred___206 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___197 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___213 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___55 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___46 *splice_pipe;
	struct page_frag___212 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___213 *oom_reaper_list;
	struct vm_struct___144 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___120 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct secondary_data___213 {
	void *stack;
	struct task_struct___213 *task;
	long int status;
};

typedef struct page___213 *pgtable_t___212;

struct address_space___212;

struct dev_pagemap___207;

struct page___213 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___212 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___213 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___212 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___212 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___207 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct key___206;

struct user_struct___206 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___206 *uid_keyring;
	struct key___206 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___207;

struct vm_area_struct___213 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___213 *vm_next;
	struct vm_area_struct___213 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___212 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___207 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___213 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct rw_semaphore___213 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___213 *owner;
};

struct linux_binfmt___33;

struct core_state___212;

struct mm_struct___212 {
	struct {
		struct vm_area_struct___213 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___213 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___213 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___33 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___212 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___213 *owner;
		struct user_namespace___3 *user_ns;
		struct file___213 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___212 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___206 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___206 *session_keyring;
	struct key___206 *process_keyring;
	struct key___206 *thread_keyring;
	struct key___206 *request_key_auth;
	void *security;
	struct user_struct___206 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___35;

struct nsproxy___197 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net___35 *net_ns;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct fasync_struct___212;

struct pipe_buffer___46;

struct pipe_inode_info___46 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___213 *tmp_page;
	struct fasync_struct___212 *fasync_readers;
	struct fasync_struct___212 *fasync_writers;
	struct pipe_buffer___46 *bufs;
	struct user_struct___206 *user;
};

struct vm_struct___144 {
	struct vm_struct___144 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___213 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___190 {
	struct task_struct___213 task;
	long unsigned int stack[8192];
};

struct address_space_operations___212;

struct address_space___212 {
	struct inode___213 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___213 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___212 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___207)(struct vm_area_struct___213 *, long unsigned int, const struct page___213 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___207)(struct page___213 *, void *);

struct device___186;

struct dev_pagemap___207 {
	dev_page_fault_t___207 page_fault;
	dev_page_free_t___207 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___186 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct vfsmount___49;

struct dentry___212;

struct path___212 {
	struct vfsmount___49 *mnt;
	struct dentry___212 *dentry;
};

struct file___213 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___212 f_path;
	struct inode___213 *f_inode;
	const struct file_operations___213 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___164 f_owner;
	const struct cred___206 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___212 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___207;

struct vm_operations_struct___207 {
	void (*open)(struct vm_area_struct___213 *);
	void (*close)(struct vm_area_struct___213 *);
	int (*split)(struct vm_area_struct___213 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___213 *);
	vm_fault_t (*fault)(struct vm_fault___207 *);
	vm_fault_t (*huge_fault)(struct vm_fault___207 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___207 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___213 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___207 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___207 *);
	int (*access)(struct vm_area_struct___213 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___213 *);
	int (*set_policy)(struct vm_area_struct___213 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___213 *, long unsigned int);
	struct page___213 * (*find_special_page)(struct vm_area_struct___213 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___212 {
	struct task_struct___213 *task;
	struct core_thread___212 *next;
};

struct core_state___212 {
	atomic_t nr_threads;
	struct core_thread___212 dumper;
	struct completion startup;
};

struct linux_binprm___34;

struct coredump_params___33;

struct linux_binfmt___33 {
	struct list_head lh;
	struct module___175 *module;
	int (*load_binary)(struct linux_binprm___34 *);
	int (*load_shlib)(struct file___213 *);
	int (*core_dump)(struct coredump_params___33 *);
	long unsigned int min_coredump;
};

struct vm_fault___207 {
	struct vm_area_struct___213 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___213 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___213 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___212 prealloc_pte;
};

struct dentry_operations___212;

struct super_block___212;

struct dentry___212 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___212 *d_parent;
	struct qstr d_name;
	struct inode___213 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___212 *d_op;
	struct super_block___212 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___212;

struct block_device___213;

struct inode___213 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___212 *i_op;
	struct super_block___212 *i_sb;
	struct address_space___212 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___213 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___213 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___212 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___46 *i_pipe;
		struct block_device___213 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___212 {
	int (*d_revalidate)(struct dentry___212 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___212 *, unsigned int);
	int (*d_hash)(const struct dentry___212 *, struct qstr *);
	int (*d_compare)(const struct dentry___212 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___212 *);
	int (*d_init)(struct dentry___212 *);
	void (*d_release)(struct dentry___212 *);
	void (*d_prune)(struct dentry___212 *);
	void (*d_iput)(struct dentry___212 *, struct inode___213 *);
	char * (*d_dname)(struct dentry___212 *, char *, int);
	struct vfsmount___49 * (*d_automount)(struct path___212 *);
	int (*d_manage)(const struct path___212 *, bool);
	struct dentry___212 * (*d_real)(struct dentry___212 *, const struct inode___213 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___212;

struct mem_dqinfo___212 {
	struct quota_format_type___212 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___212;

struct quota_info___212 {
	unsigned int flags;
	struct rw_semaphore___213 dqio_sem;
	struct inode___213 *files[3];
	struct mem_dqinfo___212 info[3];
	const struct quota_format_ops___212 *ops[3];
};

struct rcuwait___212 {
	struct task_struct___213 *task;
};

struct percpu_rw_semaphore___212 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___213 rw_sem;
	struct rcuwait___212 writer;
	int readers_block;
};

struct sb_writers___212 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___212 rw_sem[3];
};

struct file_system_type___212;

struct super_operations___212;

struct dquot_operations___212;

struct quotactl_ops___212;

struct super_block___212 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___212 *s_type;
	const struct super_operations___212 *s_op;
	const struct dquot_operations___212 *dq_op;
	const struct quotactl_ops___212 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___212 *s_root;
	struct rw_semaphore___213 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___213 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___212 s_dquot;
	struct sb_writers___212 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___212 *s_d_op;
	int cleancache_poolid;
	struct shrinker___94 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___49 {
	struct dentry___212 *mnt_root;
	struct super_block___212 *mnt_sb;
	int mnt_flags;
};

struct pglist_data___212;

struct lruvec___212 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___212 *pgdat;
};

struct zone___212 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___212 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___212 {
	struct zone___212 *zone;
	int zone_idx;
};

struct zonelist___212 {
	struct zoneref___212 _zonerefs[25];
};

struct pglist_data___212 {
	struct zone___212 node_zones[3];
	struct zonelist___212 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___213 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___213 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___212 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___212 {
	struct rw_semaphore___213 rwsem;
	struct notifier_block *head;
};

struct kiocb___213 {
	struct file___213 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___213 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___212 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___213 *ia_file;
};

struct dquot___212 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___212 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___212 {
	int qf_fmt_id;
	const struct quota_format_ops___212 *qf_ops;
	struct module___175 *qf_owner;
	struct quota_format_type___212 *qf_next;
};

struct quota_format_ops___212 {
	int (*check_quota_file)(struct super_block___212 *, int);
	int (*read_file_info)(struct super_block___212 *, int);
	int (*write_file_info)(struct super_block___212 *, int);
	int (*free_file_info)(struct super_block___212 *, int);
	int (*read_dqblk)(struct dquot___212 *);
	int (*commit_dqblk)(struct dquot___212 *);
	int (*release_dqblk)(struct dquot___212 *);
	int (*get_next_id)(struct super_block___212 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___212 {
	int (*write_dquot)(struct dquot___212 *);
	struct dquot___212 * (*alloc_dquot)(struct super_block___212 *, int);
	void (*destroy_dquot)(struct dquot___212 *);
	int (*acquire_dquot)(struct dquot___212 *);
	int (*release_dquot)(struct dquot___212 *);
	int (*mark_dirty)(struct dquot___212 *);
	int (*write_info)(struct super_block___212 *, int);
	qsize_t * (*get_reserved_space)(struct inode___213 *);
	int (*get_projid)(struct inode___213 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___213 *, qsize_t *);
	int (*get_next_id)(struct super_block___212 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___212 {
	int (*quota_on)(struct super_block___212 *, int, int, const struct path___212 *);
	int (*quota_off)(struct super_block___212 *, int);
	int (*quota_enable)(struct super_block___212 *, unsigned int);
	int (*quota_disable)(struct super_block___212 *, unsigned int);
	int (*quota_sync)(struct super_block___212 *, int);
	int (*set_info)(struct super_block___212 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___212 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___212 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___212 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___212 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___212 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___201;

struct kobj_type___201;

struct kernfs_node___205;

struct kobject___202 {
	const char *name;
	struct list_head entry;
	struct kobject___202 *parent;
	struct kset___201 *kset;
	struct kobj_type___201 *ktype;
	struct kernfs_node___205 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___172 {
	struct kobject___202 kobj;
	struct module___175 *mod;
	struct kobject___202 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___172 {
	struct module___175 *mod;
	struct latch_tree_node node;
};

struct module_layout___172 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___172 mtn;
};

struct module_attribute___172;

struct kernel_param___172;

struct module___175 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___172 mkobj;
	struct module_attribute___172 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___202 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___172 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___172 core_layout;
	struct module_layout___172 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___212 {
	int (*writepage)(struct page___213 *, struct writeback_control___3 *);
	int (*readpage)(struct file___213 *, struct page___213 *);
	int (*writepages)(struct address_space___212 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___213 *);
	int (*readpages)(struct file___213 *, struct address_space___212 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___213 *, struct address_space___212 *, loff_t, unsigned int, unsigned int, struct page___213 **, void **);
	int (*write_end)(struct file___213 *, struct address_space___212 *, loff_t, unsigned int, unsigned int, struct page___213 *, void *);
	sector_t (*bmap)(struct address_space___212 *, sector_t);
	void (*invalidatepage)(struct page___213 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___213 *, gfp_t);
	void (*freepage)(struct page___213 *);
	ssize_t (*direct_IO)(struct kiocb___213 *, struct iov_iter___100 *);
	int (*migratepage)(struct address_space___212 *, struct page___213 *, struct page___213 *, enum migrate_mode);
	bool (*isolate_page)(struct page___213 *, isolate_mode_t);
	void (*putback_page)(struct page___213 *);
	int (*launder_page)(struct page___213 *);
	int (*is_partially_uptodate)(struct page___213 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___213 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___212 *, struct page___213 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___213 *, sector_t *);
	void (*swap_deactivate)(struct file___213 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct iov_iter___100 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___3 *bvec;
		struct pipe_inode_info___46 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___213 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___213 *bd_inode;
	struct super_block___212 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___213 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___212 {
	struct dentry___212 * (*lookup)(struct inode___213 *, struct dentry___212 *, unsigned int);
	const char * (*get_link)(struct dentry___212 *, struct inode___213 *, struct delayed_call *);
	int (*permission)(struct inode___213 *, int);
	struct posix_acl * (*get_acl)(struct inode___213 *, int);
	int (*readlink)(struct dentry___212 *, char *, int);
	int (*create)(struct inode___213 *, struct dentry___212 *, umode_t, bool);
	int (*link)(struct dentry___212 *, struct inode___213 *, struct dentry___212 *);
	int (*unlink)(struct inode___213 *, struct dentry___212 *);
	int (*symlink)(struct inode___213 *, struct dentry___212 *, const char *);
	int (*mkdir)(struct inode___213 *, struct dentry___212 *, umode_t);
	int (*rmdir)(struct inode___213 *, struct dentry___212 *);
	int (*mknod)(struct inode___213 *, struct dentry___212 *, umode_t, dev_t);
	int (*rename)(struct inode___213 *, struct dentry___212 *, struct inode___213 *, struct dentry___212 *, unsigned int);
	int (*setattr)(struct dentry___212 *, struct iattr___212 *);
	int (*getattr)(const struct path___212 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___212 *, char *, size_t);
	int (*fiemap)(struct inode___213 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___213 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___213 *, struct dentry___212 *, struct file___213 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___213 *, struct dentry___212 *, umode_t);
	int (*set_acl)(struct inode___213 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___212 {
	void (*fl_copy_lock)(struct file_lock___213 *, struct file_lock___213 *);
	void (*fl_release_private)(struct file_lock___213 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___212;

struct file_lock___213 {
	struct file_lock___213 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___213 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___212 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___212 *fl_ops;
	const struct lock_manager_operations___212 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___212 {
	int (*lm_compare_owner)(struct file_lock___213 *, struct file_lock___213 *);
	long unsigned int (*lm_owner_key)(struct file_lock___213 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___213 *);
	int (*lm_grant)(struct file_lock___213 *, int);
	bool (*lm_break)(struct file_lock___213 *);
	int (*lm_change)(struct file_lock___213 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___213 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___212 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___212 *fa_next;
	struct file___213 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___212 {
	const char *name;
	int fs_flags;
	struct dentry___212 * (*mount)(struct file_system_type___212 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___212 *);
	struct module___175 *owner;
	struct file_system_type___212 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___212 {
	struct inode___213 * (*alloc_inode)(struct super_block___212 *);
	void (*destroy_inode)(struct inode___213 *);
	void (*dirty_inode)(struct inode___213 *, int);
	int (*write_inode)(struct inode___213 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___213 *);
	void (*evict_inode)(struct inode___213 *);
	void (*put_super)(struct super_block___212 *);
	int (*sync_fs)(struct super_block___212 *, int);
	int (*freeze_super)(struct super_block___212 *);
	int (*freeze_fs)(struct super_block___212 *);
	int (*thaw_super)(struct super_block___212 *);
	int (*unfreeze_fs)(struct super_block___212 *);
	int (*statfs)(struct dentry___212 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___212 *, int *, char *);
	void (*umount_begin)(struct super_block___212 *);
	int (*show_options)(struct seq_file___195 *, struct dentry___212 *);
	int (*show_devname)(struct seq_file___195 *, struct dentry___212 *);
	int (*show_path)(struct seq_file___195 *, struct dentry___212 *);
	int (*show_stats)(struct seq_file___195 *, struct dentry___212 *);
	ssize_t (*quota_read)(struct super_block___212 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___212 *, int, const char *, size_t, loff_t);
	struct dquot___212 ** (*get_dquots)(struct inode___213 *);
	int (*bdev_try_to_free_page)(struct super_block___212 *, struct page___213 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___212 *, struct shrink_control___94 *);
	long int (*free_cached_objects)(struct super_block___212 *, struct shrink_control___94 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___193;

struct seq_file___195 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___193 *op;
	int poll_event;
	const struct file___213 *file;
	void *private;
};

typedef int (*proc_write_t___14)(struct file___213 *, char *, size_t);

struct kernfs_root___205;

struct kernfs_elem_dir___205 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___205 *root;
};

struct kernfs_syscall_ops___205;

struct kernfs_root___205 {
	struct kernfs_node___205 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___205 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___205 {
	struct kernfs_node___205 *target_kn;
};

struct kernfs_ops___205;

struct kernfs_elem_attr___205 {
	const struct kernfs_ops___205 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___205 *notify_next;
};

struct kernfs_node___205 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___205 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___205 dir;
		struct kernfs_elem_symlink___205 symlink;
		struct kernfs_elem_attr___205 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___205;

struct kernfs_ops___205 {
	int (*open)(struct kernfs_open_file___205 *);
	void (*release)(struct kernfs_open_file___205 *);
	int (*seq_show)(struct seq_file___195 *, void *);
	void * (*seq_start)(struct seq_file___195 *, loff_t *);
	void * (*seq_next)(struct seq_file___195 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___195 *, void *);
	ssize_t (*read)(struct kernfs_open_file___205 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___205 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___205 *, struct vm_area_struct___213 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___205 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___205 {
	int (*remount_fs)(struct kernfs_root___205 *, int *, char *);
	int (*show_options)(struct seq_file___195 *, struct kernfs_root___205 *);
	int (*mkdir)(struct kernfs_node___205 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___205 *);
	int (*rename)(struct kernfs_node___205 *, struct kernfs_node___205 *, const char *);
	int (*show_path)(struct seq_file___195 *, struct kernfs_node___205 *, struct kernfs_root___205 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___205 {
	struct kernfs_node___205 *kn;
	struct file___213 *file;
	struct seq_file___195 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___207 *vm_ops;
};

struct bin_attribute___187;

struct attribute_group___188 {
	const char *name;
	umode_t (*is_visible)(struct kobject___202 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___202 *, struct bin_attribute___187 *, int);
	struct attribute **attrs;
	struct bin_attribute___187 **bin_attrs;
};

struct bin_attribute___187 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___213 *, struct kobject___202 *, struct bin_attribute___187 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___213 *, struct kobject___202 *, struct bin_attribute___187 *, char *, loff_t, size_t);
	int (*mmap)(struct file___213 *, struct kobject___202 *, struct bin_attribute___187 *, struct vm_area_struct___213 *);
};

struct sysfs_ops___201 {
	ssize_t (*show)(struct kobject___202 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___202 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___201;

struct kset___201 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___202 kobj;
	const struct kset_uevent_ops___201 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___201 {
	void (*release)(struct kobject___202 *);
	const struct sysfs_ops___201 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___12 * (*child_ns_type)(struct kobject___202 *);
	const void * (*namespace)(struct kobject___202 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___201 {
	int (* const filter)(struct kset___201 *, struct kobject___202 *);
	const char * (* const name)(struct kset___201 *, struct kobject___202 *);
	int (* const uevent)(struct kset___201 *, struct kobject___202 *, struct kobj_uevent_env *);
};

struct kobj_attribute___199 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___202 *, struct kobj_attribute___199 *, char *);
	ssize_t (*store)(struct kobject___202 *, struct kobj_attribute___199 *, const char *, size_t);
};

struct kernel_param_ops___172 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___172 *);
	int (*get)(char *, const struct kernel_param___172 *);
	void (*free)(void *);
};

struct kparam_array___172;

struct kernel_param___172 {
	const char *name;
	struct module___175 *mod;
	const struct kernel_param_ops___172 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___172 *arr;
	};
};

struct kparam_array___172 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___172 *ops;
	void *elem;
};

struct module_attribute___172 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___172 *, struct module_kobject___172 *, char *);
	ssize_t (*store)(struct module_attribute___172 *, struct module_kobject___172 *, const char *, size_t);
	void (*setup)(struct module___175 *, const char *);
	int (*test)(struct module___175 *);
	void (*free)(struct module___175 *);
};

struct proc_ns_operations___24;

struct ns_common___24 {
	atomic_long_t stashed;
	const struct proc_ns_operations___24 *ops;
	unsigned int inum;
};

struct proc_dir_entry___14;

struct netns_mib___2 {
	struct tcp_mib *tcp_statistics;
	struct ipstats_mib *ip_statistics;
	struct linux_mib *net_statistics;
	struct udp_mib *udp_statistics;
	struct udp_mib *udplite_statistics;
	struct icmp_mib *icmp_statistics;
	struct icmpmsg_mib *icmpmsg_statistics;
	struct proc_dir_entry___14 *proc_net_devsnmp6;
	struct udp_mib *udp_stats_in6;
	struct udp_mib *udplite_stats_in6;
	struct ipstats_mib *ipv6_statistics;
	struct icmpv6_mib *icmpv6_statistics;
	struct icmpv6msg_mib *icmpv6msg_statistics;
	struct linux_xfrm_mib *xfrm_statistics;
};

struct dst_ops___33 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___33 *);
	struct dst_entry___2 * (*check)(struct dst_entry___2 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___2 *);
	unsigned int (*mtu)(const struct dst_entry___2 *);
	u32 * (*cow_metrics)(struct dst_entry___2 *, long unsigned int);
	void (*destroy)(struct dst_entry___2 *);
	void (*ifdown)(struct dst_entry___2 *, struct net_device *, int);
	struct dst_entry___2 * (*negative_advice)(struct dst_entry___2 *);
	void (*link_failure)(struct sk_buff___26 *);
	void (*update_pmtu)(struct dst_entry___2 *, struct sock *, struct sk_buff___26 *, u32);
	void (*redirect)(struct dst_entry___2 *, struct sock *, struct sk_buff___26 *);
	int (*local_out)(struct net___35 *, struct sock *, struct sk_buff___26 *);
	struct neighbour___2 * (*neigh_lookup)(const struct dst_entry___2 *, struct sk_buff___26 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___2 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___33 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___23 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___33 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct sock *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops *notifier_ops;
	struct fib_notifier_ops *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___13 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry___14 *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf___2 {
	struct proc_dir_entry___14 *proc_netfilter;
	const struct nf_queue_handler *queue_handler;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header *nf_log_dir_header;
	struct nf_hook_entries *hooks_ipv4[5];
	struct nf_hook_entries *hooks_ipv6[5];
	struct nf_hook_entries *hooks_arp[3];
	struct nf_hook_entries *hooks_bridge[5];
	bool defrag_ipv4;
	bool defrag_ipv6;
};

struct netns_xfrm___33 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___33 xfrm4_dst_ops;
	struct dst_ops___33 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_can___2 {
	struct proc_dir_entry___14 *proc_dir;
	struct proc_dir_entry___14 *pde_version;
	struct proc_dir_entry___14 *pde_stats;
	struct proc_dir_entry___14 *pde_reset_stats;
	struct proc_dir_entry___14 *pde_rcvlist_all;
	struct proc_dir_entry___14 *pde_rcvlist_fil;
	struct proc_dir_entry___14 *pde_rcvlist_inv;
	struct proc_dir_entry___14 *pde_rcvlist_sff;
	struct proc_dir_entry___14 *pde_rcvlist_eff;
	struct proc_dir_entry___14 *pde_rcvlist_err;
	struct proc_dir_entry___14 *bcmproc_dir;
	struct can_dev_rcv_lists *can_rx_alldev_list;
	spinlock_t can_rcvlists_lock;
	struct timer_list can_stattimer;
	struct s_stats *can_stats;
	struct s_pstats *can_pstats;
	struct hlist_head cgw_list;
};

struct net___35 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___3 *user_ns;
	struct ucounts___2 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___24 ns;
	struct proc_dir_entry___14 *proc_net;
	struct proc_dir_entry___14 *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device *loopback_dev;
	struct netns_core core;
	struct netns_mib___2 mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___23 ipv4;
	struct netns_ipv6___33 ipv6;
	struct netns_sctp___13 sctp;
	struct netns_nf___2 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___23 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock *nfnl;
	struct sock *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___33 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can___2 can;
	struct sock *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct proc_dir_entry___14 {
	atomic_t in_use;
	refcount_t refcnt;
	struct list_head pde_openers;
	spinlock_t pde_unload_lock;
	struct completion *pde_unload_completion;
	const struct inode_operations___212 *proc_iops;
	const struct file_operations___213 *proc_fops;
	union {
		const struct seq_operations___193 *seq_ops;
		int (*single_show)(struct seq_file___195 *, void *);
	};
	proc_write_t___14 write;
	void *data;
	unsigned int state_size;
	unsigned int low_ino;
	nlink_t nlink;
	kuid_t uid;
	kgid_t gid;
	loff_t size;
	struct proc_dir_entry___14 *parent;
	struct rb_root subdir;
	struct rb_node subdir_node;
	char *name;
	umode_t mode;
	u8 namelen;
	char inline_name[0];
};

struct proc_ns_operations___24 {
	const char *name;
	const char *real_ns_name;
	int type;
	struct ns_common___24 * (*get)(struct task_struct___213 *);
	void (*put)(struct ns_common___24 *);
	int (*install)(struct nsproxy___197 *, struct ns_common___24 *);
	struct user_namespace___3 * (*owner)(struct ns_common___24 *);
	struct ns_common___24 * (*get_parent)(struct ns_common___24 *);
};

struct dev_pm_ops___186 {
	int (*prepare)(struct device___186 *);
	void (*complete)(struct device___186 *);
	int (*suspend)(struct device___186 *);
	int (*resume)(struct device___186 *);
	int (*freeze)(struct device___186 *);
	int (*thaw)(struct device___186 *);
	int (*poweroff)(struct device___186 *);
	int (*restore)(struct device___186 *);
	int (*suspend_late)(struct device___186 *);
	int (*resume_early)(struct device___186 *);
	int (*freeze_late)(struct device___186 *);
	int (*thaw_early)(struct device___186 *);
	int (*poweroff_late)(struct device___186 *);
	int (*restore_early)(struct device___186 *);
	int (*suspend_noirq)(struct device___186 *);
	int (*resume_noirq)(struct device___186 *);
	int (*freeze_noirq)(struct device___186 *);
	int (*thaw_noirq)(struct device___186 *);
	int (*poweroff_noirq)(struct device___186 *);
	int (*restore_noirq)(struct device___186 *);
	int (*runtime_suspend)(struct device___186 *);
	int (*runtime_resume)(struct device___186 *);
	int (*runtime_idle)(struct device___186 *);
};

struct dev_pm_info___186 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___186 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___186;

struct bus_type___186;

struct device_driver___186;

struct dev_pm_domain___186;

struct dma_map_ops___43;

struct fwnode_handle___129;

struct class___186;

struct device___186 {
	struct device___186 *parent;
	struct device_private *p;
	struct kobject___202 kobj;
	const char *init_name;
	const struct device_type___186 *type;
	struct mutex mutex;
	struct bus_type___186 *bus;
	struct device_driver___186 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___186 power;
	struct dev_pm_domain___186 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___43 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___129 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___186 *class;
	const struct attribute_group___188 **groups;
	void (*release)(struct device___186 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___186 {
	struct dev_pm_ops___186 ops;
	void (*detach)(struct device___186 *, bool);
	int (*activate)(struct device___186 *);
	void (*sync)(struct device___186 *);
	void (*dismiss)(struct device___186 *);
};

struct bus_type___186 {
	const char *name;
	const char *dev_name;
	struct device___186 *dev_root;
	const struct attribute_group___188 **bus_groups;
	const struct attribute_group___188 **dev_groups;
	const struct attribute_group___188 **drv_groups;
	int (*match)(struct device___186 *, struct device_driver___186 *);
	int (*uevent)(struct device___186 *, struct kobj_uevent_env *);
	int (*probe)(struct device___186 *);
	int (*remove)(struct device___186 *);
	void (*shutdown)(struct device___186 *);
	int (*online)(struct device___186 *);
	int (*offline)(struct device___186 *);
	int (*suspend)(struct device___186 *, pm_message_t);
	int (*resume)(struct device___186 *);
	int (*num_vf)(struct device___186 *);
	int (*dma_configure)(struct device___186 *);
	const struct dev_pm_ops___186 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___186 {
	const char *name;
	struct bus_type___186 *bus;
	struct module___175 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___186 *);
	int (*remove)(struct device___186 *);
	void (*shutdown)(struct device___186 *);
	int (*suspend)(struct device___186 *, pm_message_t);
	int (*resume)(struct device___186 *);
	const struct attribute_group___188 **groups;
	const struct dev_pm_ops___186 *pm;
	void (*coredump)(struct device___186 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___186 {
	const char *name;
	const struct attribute_group___188 **groups;
	int (*uevent)(struct device___186 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___186 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___186 *);
	const struct dev_pm_ops___186 *pm;
};

struct class___186 {
	const char *name;
	struct module___175 *owner;
	const struct attribute_group___188 **class_groups;
	const struct attribute_group___188 **dev_groups;
	struct kobject___202 *dev_kobj;
	int (*dev_uevent)(struct device___186 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___186 *, umode_t *);
	void (*class_release)(struct class___186 *);
	void (*dev_release)(struct device___186 *);
	int (*shutdown_pre)(struct device___186 *);
	const struct kobj_ns_type_operations___12 *ns_type;
	const void * (*namespace)(struct device___186 *);
	const struct dev_pm_ops___186 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___43 {
	void * (*alloc)(struct device___186 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___186 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___186 *, struct vm_area_struct___213 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___186 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___186 *, struct page___213 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___186 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___186 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___186 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___186 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___186 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___186 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___186 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___186 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___186 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___186 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___186 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___186 *, u64);
	u64 (*get_required_mask)(struct device___186 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___129;

struct fwnode_handle___129 {
	struct fwnode_handle___129 *secondary;
	const struct fwnode_operations___129 *ops;
};

typedef void compound_page_dtor___207(struct page___213 *);

struct fwnode_reference_args___129;

struct fwnode_endpoint___129;

struct fwnode_operations___129 {
	struct fwnode_handle___129 * (*get)(struct fwnode_handle___129 *);
	void (*put)(struct fwnode_handle___129 *);
	bool (*device_is_available)(const struct fwnode_handle___129 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___129 *, const struct device___186 *);
	bool (*property_present)(const struct fwnode_handle___129 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___129 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___129 *, const char *, const char **, size_t);
	struct fwnode_handle___129 * (*get_parent)(const struct fwnode_handle___129 *);
	struct fwnode_handle___129 * (*get_next_child_node)(const struct fwnode_handle___129 *, struct fwnode_handle___129 *);
	struct fwnode_handle___129 * (*get_named_child_node)(const struct fwnode_handle___129 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___129 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___129 *);
	struct fwnode_handle___129 * (*graph_get_next_endpoint)(const struct fwnode_handle___129 *, struct fwnode_handle___129 *);
	struct fwnode_handle___129 * (*graph_get_remote_endpoint)(const struct fwnode_handle___129 *);
	struct fwnode_handle___129 * (*graph_get_port_parent)(struct fwnode_handle___129 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___129 *, struct fwnode_endpoint___129 *);
};

struct fwnode_endpoint___129 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___129 *local_fwnode;
};

struct fwnode_reference_args___129 {
	struct fwnode_handle___129 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___46;

struct pipe_buffer___46 {
	struct page___213 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___46 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___46 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___46 *, struct pipe_buffer___46 *);
	void (*release)(struct pipe_inode_info___46 *, struct pipe_buffer___46 *);
	int (*steal)(struct pipe_inode_info___46 *, struct pipe_buffer___46 *);
	union {
		bool (*get)(struct pipe_inode_info___46 *, struct pipe_buffer___46 *);
		struct {
			void (*get)(struct pipe_inode_info___46 *, struct pipe_buffer___46 *);
		} __UNIQUE_ID_rh_kabi_hide21;
		union {		};
	};
};

typedef int (*key_restrict_link_func_t___206)(struct key___206 *, const struct key_type *, const union key_payload *, struct key___206 *);

struct key_restriction___206;

struct key___206 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___213 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___206 *restrict_link;
};

struct key_restriction___206 {
	key_restrict_link_func_t___206 check;
	struct key___206 *key;
	struct key_type *keytype;
};

struct seq_operations___193 {
	void * (*start)(struct seq_file___195 *, loff_t *);
	void (*stop)(struct seq_file___195 *, void *);
	void * (*next)(struct seq_file___195 *, void *, loff_t *);
	int (*show)(struct seq_file___195 *, void *);
};

struct seq_net_private {
	struct net___35 *net;
};

struct pernet_operations___24 {
	struct list_head list;
	int (*init)(struct net___35 *);
	void (*exit)(struct net___35 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct linux_binprm___34 {
	char buf[256];
	struct vm_area_struct___213 *vma;
	long unsigned int vma_pages;
	struct mm_struct___212 *mm;
	long unsigned int p;
	unsigned int called_set_creds: 1;
	unsigned int cap_elevated: 1;
	unsigned int secureexec: 1;
	unsigned int recursion_depth;
	struct file___213 *file;
	struct cred___206 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
};

struct coredump_params___33 {
	union {
		const kernel_siginfo_t *siginfo;
		struct {
			const siginfo_t *siginfo;
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	struct pt_regs *regs;
	struct file___213 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
};

union proc_op___10 {
	int (*proc_get_link)(struct dentry___212 *, struct path___212 *);
	int (*proc_show)(struct seq_file___195 *, struct pid_namespace *, struct pid___164 *, struct task_struct___213 *);
};

struct proc_inode___10 {
	struct pid___164 *pid;
	unsigned int fd;
	union proc_op___10 op;
	struct proc_dir_entry___14 *pde;
	struct ctl_table_header *sysctl;
	struct ctl_table *sysctl_entry;
	struct hlist_node sysctl_inodes;
	const struct proc_ns_operations___24 *ns_ops;
	struct inode___213 vfs_inode;
};

struct file___214;

struct kiocb___214;

struct vm_area_struct___214;

struct inode___214;

struct file_lock___214;

struct page___214;

struct file_operations___214 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___214 *, loff_t, int);
	ssize_t (*read)(struct file___214 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___214 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___214 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___214 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___214 *, bool);
	int (*iterate)(struct file___214 *, struct dir_context *);
	int (*iterate_shared)(struct file___214 *, struct dir_context *);
	__poll_t (*poll)(struct file___214 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___214 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___214 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___214 *, struct vm_area_struct___214 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___214 *, struct file___214 *);
	int (*flush)(struct file___214 *, fl_owner_t);
	int (*release)(struct inode___214 *, struct file___214 *);
	int (*fsync)(struct file___214 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___214 *, int);
	int (*lock)(struct file___214 *, int, struct file_lock___214 *);
	ssize_t (*sendpage)(struct file___214 *, struct page___214 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___214 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___214 *, int, struct file_lock___214 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___214 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___214 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___214 *, long int, struct file_lock___214 **, void **);
	long int (*fallocate)(struct file___214 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___214 *);
	ssize_t (*copy_file_range)(struct file___214 *, loff_t, struct file___214 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___214 *, loff_t, struct file___214 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___214 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___213 {
	u64 seqnum;
	struct vm_area_struct___214 *vmas[4];
};

struct page_frag___213 {
	struct page___214 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___213;

struct pid___165;

struct cred___207;

struct nsproxy___198;

struct signal_struct___181;

struct vm_struct___145;

struct task_struct___214 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___214 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___213 *mm;
	struct mm_struct___213 *active_mm;
	struct vmacache___213 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___214 *real_parent;
	struct task_struct___214 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___214 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___165 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___165 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___165 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___207 *ptracer_cred;
	const struct cred___207 *real_cred;
	const struct cred___207 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___198 *nsproxy;
	struct signal_struct___181 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___214 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___55 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___213 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___214 *oom_reaper_list;
	struct vm_struct___145 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___120 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___165;

struct upid___165 {
	int nr;
	struct pid_namespace___165 *ns;
};

struct proc_ns_operations___25;

struct ns_common___25 {
	atomic_long_t stashed;
	const struct proc_ns_operations___25 *ops;
	unsigned int inum;
};

struct dentry___213;

struct pid_namespace___165 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___214 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___165 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___213 *proc_self;
	struct dentry___213 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___3 *user_ns;
	struct ucounts___2 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___25 ns;
};

struct pid___165 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___165 numbers[1];
};

struct secondary_data___214 {
	void *stack;
	struct task_struct___214 *task;
	long int status;
};

typedef struct page___214 *pgtable_t___213;

struct address_space___213;

struct dev_pagemap___208;

struct page___214 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___213 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___214 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___213 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___213 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___208 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct key___207;

struct user_struct___207 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___207 *uid_keyring;
	struct key___207 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___208;

struct vm_area_struct___214 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___214 *vm_next;
	struct vm_area_struct___214 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___213 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___208 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___214 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct rw_semaphore___214 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___214 *owner;
};

struct linux_binfmt___34;

struct core_state___213;

struct mm_struct___213 {
	struct {
		struct vm_area_struct___214 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___214 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___214 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___34 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___213 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___214 *owner;
		struct user_namespace___3 *user_ns;
		struct file___214 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___213 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___207 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___207 *session_keyring;
	struct key___207 *process_keyring;
	struct key___207 *thread_keyring;
	struct key___207 *request_key_auth;
	void *security;
	struct user_struct___207 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct nsproxy___198 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___165 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct signal_struct___181 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___214 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___214 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___165 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___165 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___213 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___165 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_struct___145 {
	struct vm_struct___145 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___214 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___191 {
	struct task_struct___214 task;
	long unsigned int stack[8192];
};

typedef int (*key_restrict_link_func_t___207)(struct key___207 *, const struct key_type *, const union key_payload *, struct key___207 *);

struct key_restriction___207;

struct key___207 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___214 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___207 *restrict_link;
};

struct key_restriction___207 {
	key_restrict_link_func_t___207 check;
	struct key___207 *key;
	struct key_type *keytype;
};

struct pglist_data___213;

struct lruvec___213 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___213 *pgdat;
};

struct zone___213 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___213 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___213 {
	struct zone___213 *zone;
	int zone_idx;
};

struct zonelist___213 {
	struct zoneref___213 _zonerefs[25];
};

struct pglist_data___213 {
	struct zone___213 node_zones[3];
	struct zonelist___213 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___214 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___214 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___213 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

typedef struct pglist_data___213 pg_data_t___15;

struct blocking_notifier_head___213 {
	struct rw_semaphore___214 rwsem;
	struct notifier_block *head;
};

struct address_space_operations___213;

struct address_space___213 {
	struct inode___214 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___214 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___213 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___208)(struct vm_area_struct___214 *, long unsigned int, const struct page___214 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___208)(struct page___214 *, void *);

struct device___187;

struct dev_pagemap___208 {
	dev_page_fault_t___208 page_fault;
	dev_page_free_t___208 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___187 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___213 {
	struct vfsmount *mnt;
	struct dentry___213 *dentry;
};

struct fown_struct___165 {
	rwlock_t lock;
	struct pid___165 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___214 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___213 f_path;
	struct inode___214 *f_inode;
	const struct file_operations___214 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___165 f_owner;
	const struct cred___207 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___213 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___208;

struct vm_operations_struct___208 {
	void (*open)(struct vm_area_struct___214 *);
	void (*close)(struct vm_area_struct___214 *);
	int (*split)(struct vm_area_struct___214 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___214 *);
	vm_fault_t (*fault)(struct vm_fault___208 *);
	vm_fault_t (*huge_fault)(struct vm_fault___208 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___208 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___214 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___208 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___208 *);
	int (*access)(struct vm_area_struct___214 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___214 *);
	int (*set_policy)(struct vm_area_struct___214 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___214 *, long unsigned int);
	struct page___214 * (*find_special_page)(struct vm_area_struct___214 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___213 {
	struct task_struct___214 *task;
	struct core_thread___213 *next;
};

struct core_state___213 {
	atomic_t nr_threads;
	struct core_thread___213 dumper;
	struct completion startup;
};

struct linux_binprm___35;

struct coredump_params___34;

struct linux_binfmt___34 {
	struct list_head lh;
	struct module___11 *module;
	int (*load_binary)(struct linux_binprm___35 *);
	int (*load_shlib)(struct file___214 *);
	int (*core_dump)(struct coredump_params___34 *);
	long unsigned int min_coredump;
};

struct vm_fault___208 {
	struct vm_area_struct___214 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___214 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___214 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___213 prealloc_pte;
};

struct kset___202;

struct kobj_type___202;

struct kernfs_node___206;

struct kobject___203 {
	const char *name;
	struct list_head entry;
	struct kobject___203 *parent;
	struct kset___202 *kset;
	struct kobj_type___202 *ktype;
	struct kernfs_node___206 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___187 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___187 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___187;

struct bus_type___187;

struct device_driver___187;

struct dev_pm_domain___187;

struct fwnode_handle___130;

struct class___187;

struct attribute_group___189;

struct device___187 {
	struct device___187 *parent;
	struct device_private *p;
	struct kobject___203 kobj;
	const char *init_name;
	const struct device_type___187 *type;
	struct mutex mutex;
	struct bus_type___187 *bus;
	struct device_driver___187 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___187 power;
	struct dev_pm_domain___187 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___130 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___187 *class;
	const struct attribute_group___189 **groups;
	void (*release)(struct device___187 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___213;

struct super_block___213;

struct dentry___213 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___213 *d_parent;
	struct qstr d_name;
	struct inode___214 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___213 *d_op;
	struct super_block___213 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___213;

struct block_device___214;

struct inode___214 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___213 *i_op;
	struct super_block___213 *i_sb;
	struct address_space___213 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___214 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___214 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___213 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___214 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___213 {
	int (*d_revalidate)(struct dentry___213 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___213 *, unsigned int);
	int (*d_hash)(const struct dentry___213 *, struct qstr *);
	int (*d_compare)(const struct dentry___213 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___213 *);
	int (*d_init)(struct dentry___213 *);
	void (*d_release)(struct dentry___213 *);
	void (*d_prune)(struct dentry___213 *);
	void (*d_iput)(struct dentry___213 *, struct inode___214 *);
	char * (*d_dname)(struct dentry___213 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___213 *);
	int (*d_manage)(const struct path___213 *, bool);
	struct dentry___213 * (*d_real)(struct dentry___213 *, const struct inode___214 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___213;

struct mem_dqinfo___213 {
	struct quota_format_type___213 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___213;

struct quota_info___213 {
	unsigned int flags;
	struct rw_semaphore___214 dqio_sem;
	struct inode___214 *files[3];
	struct mem_dqinfo___213 info[3];
	const struct quota_format_ops___213 *ops[3];
};

struct rcuwait___213 {
	struct task_struct___214 *task;
};

struct percpu_rw_semaphore___213 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___214 rw_sem;
	struct rcuwait___213 writer;
	int readers_block;
};

struct sb_writers___213 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___213 rw_sem[3];
};

struct file_system_type___213;

struct super_operations___213;

struct dquot_operations___213;

struct quotactl_ops___213;

struct super_block___213 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___213 *s_type;
	const struct super_operations___213 *s_op;
	const struct dquot_operations___213 *dq_op;
	const struct quotactl_ops___213 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___213 *s_root;
	struct rw_semaphore___214 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___214 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___213 s_dquot;
	struct sb_writers___213 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___213 *s_d_op;
	int cleancache_poolid;
	struct shrinker___94 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___214 {
	struct file___214 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___214 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___213 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___214 *ia_file;
};

struct dquot___213 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___213 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___213 {
	int qf_fmt_id;
	const struct quota_format_ops___213 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___213 *qf_next;
};

struct quota_format_ops___213 {
	int (*check_quota_file)(struct super_block___213 *, int);
	int (*read_file_info)(struct super_block___213 *, int);
	int (*write_file_info)(struct super_block___213 *, int);
	int (*free_file_info)(struct super_block___213 *, int);
	int (*read_dqblk)(struct dquot___213 *);
	int (*commit_dqblk)(struct dquot___213 *);
	int (*release_dqblk)(struct dquot___213 *);
	int (*get_next_id)(struct super_block___213 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___213 {
	int (*write_dquot)(struct dquot___213 *);
	struct dquot___213 * (*alloc_dquot)(struct super_block___213 *, int);
	void (*destroy_dquot)(struct dquot___213 *);
	int (*acquire_dquot)(struct dquot___213 *);
	int (*release_dquot)(struct dquot___213 *);
	int (*mark_dirty)(struct dquot___213 *);
	int (*write_info)(struct super_block___213 *, int);
	qsize_t * (*get_reserved_space)(struct inode___214 *);
	int (*get_projid)(struct inode___214 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___214 *, qsize_t *);
	int (*get_next_id)(struct super_block___213 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___213 {
	int (*quota_on)(struct super_block___213 *, int, int, const struct path___213 *);
	int (*quota_off)(struct super_block___213 *, int);
	int (*quota_enable)(struct super_block___213 *, unsigned int);
	int (*quota_disable)(struct super_block___213 *, unsigned int);
	int (*quota_sync)(struct super_block___213 *, int);
	int (*set_info)(struct super_block___213 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___213 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___213 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___213 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___213 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___213 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___213 {
	int (*writepage)(struct page___214 *, struct writeback_control___3 *);
	int (*readpage)(struct file___214 *, struct page___214 *);
	int (*writepages)(struct address_space___213 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___214 *);
	int (*readpages)(struct file___214 *, struct address_space___213 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___214 *, struct address_space___213 *, loff_t, unsigned int, unsigned int, struct page___214 **, void **);
	int (*write_end)(struct file___214 *, struct address_space___213 *, loff_t, unsigned int, unsigned int, struct page___214 *, void *);
	sector_t (*bmap)(struct address_space___213 *, sector_t);
	void (*invalidatepage)(struct page___214 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___214 *, gfp_t);
	void (*freepage)(struct page___214 *);
	ssize_t (*direct_IO)(struct kiocb___214 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___213 *, struct page___214 *, struct page___214 *, enum migrate_mode);
	bool (*isolate_page)(struct page___214 *, isolate_mode_t);
	void (*putback_page)(struct page___214 *);
	int (*launder_page)(struct page___214 *);
	int (*is_partially_uptodate)(struct page___214 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___214 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___213 *, struct page___214 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___214 *, sector_t *);
	void (*swap_deactivate)(struct file___214 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___214 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___214 *bd_inode;
	struct super_block___213 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___214 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___213 {
	struct dentry___213 * (*lookup)(struct inode___214 *, struct dentry___213 *, unsigned int);
	const char * (*get_link)(struct dentry___213 *, struct inode___214 *, struct delayed_call *);
	int (*permission)(struct inode___214 *, int);
	struct posix_acl * (*get_acl)(struct inode___214 *, int);
	int (*readlink)(struct dentry___213 *, char *, int);
	int (*create)(struct inode___214 *, struct dentry___213 *, umode_t, bool);
	int (*link)(struct dentry___213 *, struct inode___214 *, struct dentry___213 *);
	int (*unlink)(struct inode___214 *, struct dentry___213 *);
	int (*symlink)(struct inode___214 *, struct dentry___213 *, const char *);
	int (*mkdir)(struct inode___214 *, struct dentry___213 *, umode_t);
	int (*rmdir)(struct inode___214 *, struct dentry___213 *);
	int (*mknod)(struct inode___214 *, struct dentry___213 *, umode_t, dev_t);
	int (*rename)(struct inode___214 *, struct dentry___213 *, struct inode___214 *, struct dentry___213 *, unsigned int);
	int (*setattr)(struct dentry___213 *, struct iattr___213 *);
	int (*getattr)(const struct path___213 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___213 *, char *, size_t);
	int (*fiemap)(struct inode___214 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___214 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___214 *, struct dentry___213 *, struct file___214 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___214 *, struct dentry___213 *, umode_t);
	int (*set_acl)(struct inode___214 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___213 {
	void (*fl_copy_lock)(struct file_lock___214 *, struct file_lock___214 *);
	void (*fl_release_private)(struct file_lock___214 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___213;

struct lock_manager_operations___213;

struct file_lock___214 {
	struct file_lock___214 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___214 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___213 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___213 *fl_ops;
	const struct lock_manager_operations___213 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___213 {
	int (*lm_compare_owner)(struct file_lock___214 *, struct file_lock___214 *);
	long unsigned int (*lm_owner_key)(struct file_lock___214 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___214 *);
	int (*lm_grant)(struct file_lock___214 *, int);
	bool (*lm_break)(struct file_lock___214 *);
	int (*lm_change)(struct file_lock___214 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___214 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___213 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___213 *fa_next;
	struct file___214 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___213 {
	const char *name;
	int fs_flags;
	struct dentry___213 * (*mount)(struct file_system_type___213 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___213 *);
	struct module___11 *owner;
	struct file_system_type___213 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___213 {
	struct inode___214 * (*alloc_inode)(struct super_block___213 *);
	void (*destroy_inode)(struct inode___214 *);
	void (*dirty_inode)(struct inode___214 *, int);
	int (*write_inode)(struct inode___214 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___214 *);
	void (*evict_inode)(struct inode___214 *);
	void (*put_super)(struct super_block___213 *);
	int (*sync_fs)(struct super_block___213 *, int);
	int (*freeze_super)(struct super_block___213 *);
	int (*freeze_fs)(struct super_block___213 *);
	int (*thaw_super)(struct super_block___213 *);
	int (*unfreeze_fs)(struct super_block___213 *);
	int (*statfs)(struct dentry___213 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___213 *, int *, char *);
	void (*umount_begin)(struct super_block___213 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___213 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___213 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___213 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___213 *);
	ssize_t (*quota_read)(struct super_block___213 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___213 *, int, const char *, size_t, loff_t);
	struct dquot___213 ** (*get_dquots)(struct inode___214 *);
	int (*bdev_try_to_free_page)(struct super_block___213 *, struct page___214 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___213 *, struct shrink_control___94 *);
	long int (*free_cached_objects)(struct super_block___213 *, struct shrink_control___94 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_attribute___200 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___203 *, struct kobj_attribute___200 *, char *);
	ssize_t (*store)(struct kobject___203 *, struct kobj_attribute___200 *, const char *, size_t);
};

typedef void compound_page_dtor___208(struct page___214 *);

struct proc_ns_operations___25 {
	const char *name;
	const char *real_ns_name;
	int type;
	struct ns_common___25 * (*get)(struct task_struct___214 *);
	void (*put)(struct ns_common___25 *);
	int (*install)(struct nsproxy___198 *, struct ns_common___25 *);
	struct user_namespace___3 * (*owner)(struct ns_common___25 *);
	struct ns_common___25 * (*get_parent)(struct ns_common___25 *);
};

typedef int (*proc_write_t___15)(struct file___214 *, char *, size_t);

enum kcore_type {
	KCORE_TEXT = 0,
	KCORE_VMALLOC = 1,
	KCORE_RAM = 2,
	KCORE_VMEMMAP = 3,
	KCORE_USER = 4,
	KCORE_OTHER = 5,
	KCORE_REMAP = 6,
};

struct kcore_list {
	struct list_head list;
	long unsigned int addr;
	long unsigned int vaddr;
	size_t size;
	int type;
};

struct fwnode_operations___130;

struct fwnode_handle___130 {
	struct fwnode_handle___130 *secondary;
	const struct fwnode_operations___130 *ops;
};

struct fwnode_reference_args___130;

struct fwnode_endpoint___130;

struct fwnode_operations___130 {
	struct fwnode_handle___130 * (*get)(struct fwnode_handle___130 *);
	void (*put)(struct fwnode_handle___130 *);
	bool (*device_is_available)(const struct fwnode_handle___130 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___130 *, const struct device___187 *);
	bool (*property_present)(const struct fwnode_handle___130 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___130 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___130 *, const char *, const char **, size_t);
	struct fwnode_handle___130 * (*get_parent)(const struct fwnode_handle___130 *);
	struct fwnode_handle___130 * (*get_next_child_node)(const struct fwnode_handle___130 *, struct fwnode_handle___130 *);
	struct fwnode_handle___130 * (*get_named_child_node)(const struct fwnode_handle___130 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___130 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___130 *);
	struct fwnode_handle___130 * (*graph_get_next_endpoint)(const struct fwnode_handle___130 *, struct fwnode_handle___130 *);
	struct fwnode_handle___130 * (*graph_get_remote_endpoint)(const struct fwnode_handle___130 *);
	struct fwnode_handle___130 * (*graph_get_port_parent)(struct fwnode_handle___130 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___130 *, struct fwnode_endpoint___130 *);
};

struct fwnode_endpoint___130 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___130 *local_fwnode;
};

struct fwnode_reference_args___130 {
	struct fwnode_handle___130 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct kernfs_root___206;

struct kernfs_elem_dir___206 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___206 *root;
};

struct kernfs_syscall_ops___206;

struct kernfs_root___206 {
	struct kernfs_node___206 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___206 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___206 {
	struct kernfs_node___206 *target_kn;
};

struct kernfs_ops___206;

struct kernfs_elem_attr___206 {
	const struct kernfs_ops___206 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___206 *notify_next;
};

struct kernfs_node___206 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___206 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___206 dir;
		struct kernfs_elem_symlink___206 symlink;
		struct kernfs_elem_attr___206 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___206;

struct kernfs_ops___206 {
	int (*open)(struct kernfs_open_file___206 *);
	void (*release)(struct kernfs_open_file___206 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___206 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___206 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___206 *, struct vm_area_struct___214 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___206 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___206 {
	int (*remount_fs)(struct kernfs_root___206 *, int *, char *);
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___206 *);
	int (*mkdir)(struct kernfs_node___206 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___206 *);
	int (*rename)(struct kernfs_node___206 *, struct kernfs_node___206 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___206 *, struct kernfs_root___206 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___206 {
	struct kernfs_node___206 *kn;
	struct file___214 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___208 *vm_ops;
};

struct bin_attribute___188;

struct attribute_group___189 {
	const char *name;
	umode_t (*is_visible)(struct kobject___203 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___203 *, struct bin_attribute___188 *, int);
	struct attribute **attrs;
	struct bin_attribute___188 **bin_attrs;
};

struct bin_attribute___188 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___214 *, struct kobject___203 *, struct bin_attribute___188 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___214 *, struct kobject___203 *, struct bin_attribute___188 *, char *, loff_t, size_t);
	int (*mmap)(struct file___214 *, struct kobject___203 *, struct bin_attribute___188 *, struct vm_area_struct___214 *);
};

struct sysfs_ops___202 {
	ssize_t (*show)(struct kobject___203 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___203 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___202;

struct kset___202 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___203 kobj;
	const struct kset_uevent_ops___202 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___202 {
	void (*release)(struct kobject___203 *);
	const struct sysfs_ops___202 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___12 * (*child_ns_type)(struct kobject___203 *);
	const void * (*namespace)(struct kobject___203 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___202 {
	int (* const filter)(struct kset___202 *, struct kobject___203 *);
	const char * (* const name)(struct kset___202 *, struct kobject___203 *);
	int (* const uevent)(struct kset___202 *, struct kobject___203 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___187 {
	int (*prepare)(struct device___187 *);
	void (*complete)(struct device___187 *);
	int (*suspend)(struct device___187 *);
	int (*resume)(struct device___187 *);
	int (*freeze)(struct device___187 *);
	int (*thaw)(struct device___187 *);
	int (*poweroff)(struct device___187 *);
	int (*restore)(struct device___187 *);
	int (*suspend_late)(struct device___187 *);
	int (*resume_early)(struct device___187 *);
	int (*freeze_late)(struct device___187 *);
	int (*thaw_early)(struct device___187 *);
	int (*poweroff_late)(struct device___187 *);
	int (*restore_early)(struct device___187 *);
	int (*suspend_noirq)(struct device___187 *);
	int (*resume_noirq)(struct device___187 *);
	int (*freeze_noirq)(struct device___187 *);
	int (*thaw_noirq)(struct device___187 *);
	int (*poweroff_noirq)(struct device___187 *);
	int (*restore_noirq)(struct device___187 *);
	int (*runtime_suspend)(struct device___187 *);
	int (*runtime_resume)(struct device___187 *);
	int (*runtime_idle)(struct device___187 *);
};

struct dev_pm_domain___187 {
	struct dev_pm_ops___187 ops;
	void (*detach)(struct device___187 *, bool);
	int (*activate)(struct device___187 *);
	void (*sync)(struct device___187 *);
	void (*dismiss)(struct device___187 *);
};

struct bus_type___187 {
	const char *name;
	const char *dev_name;
	struct device___187 *dev_root;
	const struct attribute_group___189 **bus_groups;
	const struct attribute_group___189 **dev_groups;
	const struct attribute_group___189 **drv_groups;
	int (*match)(struct device___187 *, struct device_driver___187 *);
	int (*uevent)(struct device___187 *, struct kobj_uevent_env *);
	int (*probe)(struct device___187 *);
	int (*remove)(struct device___187 *);
	void (*shutdown)(struct device___187 *);
	int (*online)(struct device___187 *);
	int (*offline)(struct device___187 *);
	int (*suspend)(struct device___187 *, pm_message_t);
	int (*resume)(struct device___187 *);
	int (*num_vf)(struct device___187 *);
	int (*dma_configure)(struct device___187 *);
	const struct dev_pm_ops___187 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___187 {
	const char *name;
	struct bus_type___187 *bus;
	struct module___11 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___187 *);
	int (*remove)(struct device___187 *);
	void (*shutdown)(struct device___187 *);
	int (*suspend)(struct device___187 *, pm_message_t);
	int (*resume)(struct device___187 *);
	const struct attribute_group___189 **groups;
	const struct dev_pm_ops___187 *pm;
	void (*coredump)(struct device___187 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___187 {
	const char *name;
	const struct attribute_group___189 **groups;
	int (*uevent)(struct device___187 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___187 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___187 *);
	const struct dev_pm_ops___187 *pm;
};

struct class___187 {
	const char *name;
	struct module___11 *owner;
	const struct attribute_group___189 **class_groups;
	const struct attribute_group___189 **dev_groups;
	struct kobject___203 *dev_kobj;
	int (*dev_uevent)(struct device___187 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___187 *, umode_t *);
	void (*class_release)(struct class___187 *);
	void (*dev_release)(struct device___187 *);
	int (*shutdown_pre)(struct device___187 *);
	const struct kobj_ns_type_operations___12 *ns_type;
	const void * (*namespace)(struct device___187 *);
	const struct dev_pm_ops___187 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___159 {
	struct device___187 dev;
};

struct linux_binprm___35 {
	char buf[256];
	struct vm_area_struct___214 *vma;
	long unsigned int vma_pages;
	struct mm_struct___213 *mm;
	long unsigned int p;
	unsigned int called_set_creds: 1;
	unsigned int cap_elevated: 1;
	unsigned int secureexec: 1;
	unsigned int recursion_depth;
	struct file___214 *file;
	struct cred___207 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
};

struct coredump_params___34 {
	union {
		const kernel_siginfo_t *siginfo;
		struct {
			const siginfo_t *siginfo;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	struct pt_regs *regs;
	struct file___214 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
};

struct proc_dir_entry___15 {
	atomic_t in_use;
	refcount_t refcnt;
	struct list_head pde_openers;
	spinlock_t pde_unload_lock;
	struct completion *pde_unload_completion;
	const struct inode_operations___213 *proc_iops;
	const struct file_operations___214 *proc_fops;
	union {
		const struct seq_operations___193 *seq_ops;
		int (*single_show)(struct seq_file___195 *, void *);
	};
	proc_write_t___15 write;
	void *data;
	unsigned int state_size;
	unsigned int low_ino;
	nlink_t nlink;
	kuid_t uid;
	kgid_t gid;
	loff_t size;
	struct proc_dir_entry___15 *parent;
	struct rb_root subdir;
	struct rb_node subdir_node;
	char *name;
	umode_t mode;
	u8 namelen;
	char inline_name[0];
};

struct module___176;

struct file___215;

struct kiocb___215;

struct vm_area_struct___215;

struct inode___215;

struct file_lock___215;

struct page___215;

struct file_operations___215 {
	struct module___176 *owner;
	loff_t (*llseek)(struct file___215 *, loff_t, int);
	ssize_t (*read)(struct file___215 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___215 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___215 *, struct iov_iter___100 *);
	ssize_t (*write_iter)(struct kiocb___215 *, struct iov_iter___100 *);
	int (*iopoll)(struct kiocb___215 *, bool);
	int (*iterate)(struct file___215 *, struct dir_context *);
	int (*iterate_shared)(struct file___215 *, struct dir_context *);
	__poll_t (*poll)(struct file___215 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___215 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___215 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___215 *, struct vm_area_struct___215 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___215 *, struct file___215 *);
	int (*flush)(struct file___215 *, fl_owner_t);
	int (*release)(struct inode___215 *, struct file___215 *);
	int (*fsync)(struct file___215 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___215 *, int);
	int (*lock)(struct file___215 *, int, struct file_lock___215 *);
	ssize_t (*sendpage)(struct file___215 *, struct page___215 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___215 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___215 *, int, struct file_lock___215 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___215 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___215 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___215 *, long int, struct file_lock___215 **, void **);
	long int (*fallocate)(struct file___215 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___215 *);
	ssize_t (*copy_file_range)(struct file___215 *, loff_t, struct file___215 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___215 *, loff_t, struct file___215 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___215 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___214 {
	u64 seqnum;
	struct vm_area_struct___215 *vmas[4];
};

struct page_frag___214 {
	struct page___215 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___214;

struct pid___166;

struct cred___208;

struct nsproxy___199;

struct signal_struct___182;

struct vm_struct___146;

struct task_struct___215 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___215 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___214 *mm;
	struct mm_struct___214 *active_mm;
	struct vmacache___214 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___215 *real_parent;
	struct task_struct___215 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___215 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___166 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___166 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___166 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___208 *ptracer_cred;
	const struct cred___208 *real_cred;
	const struct cred___208 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___199 *nsproxy;
	struct signal_struct___182 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___215 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___55 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___214 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___215 *oom_reaper_list;
	struct vm_struct___146 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___120 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___215 *pgtable_t___214;

struct address_space___214;

struct dev_pagemap___209;

struct page___215 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___214 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___215 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___214 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___214 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___209 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___214;

struct lruvec___214 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___214 *pgdat;
};

struct zone___214 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___214 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___214 {
	struct zone___214 *zone;
	int zone_idx;
};

struct zonelist___214 {
	struct zoneref___214 _zonerefs[25];
};

struct pglist_data___214 {
	struct zone___214 node_zones[3];
	struct zonelist___214 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___215 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___215 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___214 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___215 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___215 *owner;
};

struct secondary_data___215 {
	void *stack;
	struct task_struct___215 *task;
	long int status;
};

struct blocking_notifier_head___214 {
	struct rw_semaphore___215 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___209;

struct vm_area_struct___215 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___215 *vm_next;
	struct vm_area_struct___215 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___214 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___209 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___215 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct linux_binfmt___35;

struct core_state___214;

struct mm_struct___214 {
	struct {
		struct vm_area_struct___215 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___215 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___215 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___35 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___214 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___215 *owner;
		struct user_namespace___3 *user_ns;
		struct file___215 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___214 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___214;

struct address_space___214 {
	struct inode___215 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___215 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___214 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___209)(struct vm_area_struct___215 *, long unsigned int, const struct page___215 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___209)(struct page___215 *, void *);

struct dev_pagemap___209 {
	dev_page_fault_t___209 page_fault;
	dev_page_free_t___209 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___6 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct dentry___214;

struct path___214 {
	struct vfsmount *mnt;
	struct dentry___214 *dentry;
};

struct fown_struct___166 {
	rwlock_t lock;
	struct pid___166 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___215 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___214 f_path;
	struct inode___215 *f_inode;
	const struct file_operations___215 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___166 f_owner;
	const struct cred___208 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___214 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___209;

struct vm_operations_struct___209 {
	void (*open)(struct vm_area_struct___215 *);
	void (*close)(struct vm_area_struct___215 *);
	int (*split)(struct vm_area_struct___215 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___215 *);
	vm_fault_t (*fault)(struct vm_fault___209 *);
	vm_fault_t (*huge_fault)(struct vm_fault___209 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___209 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___215 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___209 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___209 *);
	int (*access)(struct vm_area_struct___215 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___215 *);
	int (*set_policy)(struct vm_area_struct___215 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___215 *, long unsigned int);
	struct page___215 * (*find_special_page)(struct vm_area_struct___215 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___214 {
	struct task_struct___215 *task;
	struct core_thread___214 *next;
};

struct core_state___214 {
	atomic_t nr_threads;
	struct core_thread___214 dumper;
	struct completion startup;
};

struct linux_binprm___36;

struct coredump_params___35;

struct linux_binfmt___35 {
	struct list_head lh;
	struct module___176 *module;
	int (*load_binary)(struct linux_binprm___36 *);
	int (*load_shlib)(struct file___215 *);
	int (*core_dump)(struct coredump_params___35 *);
	long unsigned int min_coredump;
};

struct vm_fault___209 {
	struct vm_area_struct___215 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___215 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___215 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___214 prealloc_pte;
};

struct pid_namespace___166;

struct upid___166 {
	int nr;
	struct pid_namespace___166 *ns;
};

struct proc_ns_operations___26;

struct ns_common___26 {
	atomic_long_t stashed;
	const struct proc_ns_operations___26 *ops;
	unsigned int inum;
};

struct pid_namespace___166 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___215 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___166 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___214 *proc_self;
	struct dentry___214 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___3 *user_ns;
	struct ucounts___2 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___26 ns;
};

struct pid___166 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___166 numbers[1];
};

struct key___208;

struct user_struct___208 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___208 *uid_keyring;
	struct key___208 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___208 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___208 *session_keyring;
	struct key___208 *process_keyring;
	struct key___208 *thread_keyring;
	struct key___208 *request_key_auth;
	void *security;
	struct user_struct___208 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct nsproxy___199 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___166 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct signal_struct___182 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___215 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___215 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___166 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___166 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___214 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___166 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_struct___146 {
	struct vm_struct___146 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___215 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___192 {
	struct task_struct___215 task;
	long unsigned int stack[8192];
};

struct dentry_operations___214;

struct super_block___214;

struct dentry___214 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___214 *d_parent;
	struct qstr d_name;
	struct inode___215 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___214 *d_op;
	struct super_block___214 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___214;

struct block_device___215;

struct inode___215 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___214 *i_op;
	struct super_block___214 *i_sb;
	struct address_space___214 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___215 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___215 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___214 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___215 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___214 {
	int (*d_revalidate)(struct dentry___214 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___214 *, unsigned int);
	int (*d_hash)(const struct dentry___214 *, struct qstr *);
	int (*d_compare)(const struct dentry___214 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___214 *);
	int (*d_init)(struct dentry___214 *);
	void (*d_release)(struct dentry___214 *);
	void (*d_prune)(struct dentry___214 *);
	void (*d_iput)(struct dentry___214 *, struct inode___215 *);
	char * (*d_dname)(struct dentry___214 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___214 *);
	int (*d_manage)(const struct path___214 *, bool);
	struct dentry___214 * (*d_real)(struct dentry___214 *, const struct inode___215 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___214;

struct mem_dqinfo___214 {
	struct quota_format_type___214 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___214;

struct quota_info___214 {
	unsigned int flags;
	struct rw_semaphore___215 dqio_sem;
	struct inode___215 *files[3];
	struct mem_dqinfo___214 info[3];
	const struct quota_format_ops___214 *ops[3];
};

struct rcuwait___214 {
	struct task_struct___215 *task;
};

struct percpu_rw_semaphore___214 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___215 rw_sem;
	struct rcuwait___214 writer;
	int readers_block;
};

struct sb_writers___214 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___214 rw_sem[3];
};

struct file_system_type___214;

struct super_operations___214;

struct dquot_operations___214;

struct quotactl_ops___214;

struct super_block___214 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___214 *s_type;
	const struct super_operations___214 *s_op;
	const struct dquot_operations___214 *dq_op;
	const struct quotactl_ops___214 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___214 *s_root;
	struct rw_semaphore___215 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___215 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___214 s_dquot;
	struct sb_writers___214 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___214 *s_d_op;
	int cleancache_poolid;
	struct shrinker___94 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___215 {
	struct file___215 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___215 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___214 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___215 *ia_file;
};

struct dquot___214 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___214 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___214 {
	int qf_fmt_id;
	const struct quota_format_ops___214 *qf_ops;
	struct module___176 *qf_owner;
	struct quota_format_type___214 *qf_next;
};

struct quota_format_ops___214 {
	int (*check_quota_file)(struct super_block___214 *, int);
	int (*read_file_info)(struct super_block___214 *, int);
	int (*write_file_info)(struct super_block___214 *, int);
	int (*free_file_info)(struct super_block___214 *, int);
	int (*read_dqblk)(struct dquot___214 *);
	int (*commit_dqblk)(struct dquot___214 *);
	int (*release_dqblk)(struct dquot___214 *);
	int (*get_next_id)(struct super_block___214 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___214 {
	int (*write_dquot)(struct dquot___214 *);
	struct dquot___214 * (*alloc_dquot)(struct super_block___214 *, int);
	void (*destroy_dquot)(struct dquot___214 *);
	int (*acquire_dquot)(struct dquot___214 *);
	int (*release_dquot)(struct dquot___214 *);
	int (*mark_dirty)(struct dquot___214 *);
	int (*write_info)(struct super_block___214 *, int);
	qsize_t * (*get_reserved_space)(struct inode___215 *);
	int (*get_projid)(struct inode___215 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___215 *, qsize_t *);
	int (*get_next_id)(struct super_block___214 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___214 {
	int (*quota_on)(struct super_block___214 *, int, int, const struct path___214 *);
	int (*quota_off)(struct super_block___214 *, int);
	int (*quota_enable)(struct super_block___214 *, unsigned int);
	int (*quota_disable)(struct super_block___214 *, unsigned int);
	int (*quota_sync)(struct super_block___214 *, int);
	int (*set_info)(struct super_block___214 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___214 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___214 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___214 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___214 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___214 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___203;

struct kobj_type___203;

struct kernfs_node___207;

struct kobject___204 {
	const char *name;
	struct list_head entry;
	struct kobject___204 *parent;
	struct kset___203 *kset;
	struct kobj_type___203 *ktype;
	struct kernfs_node___207 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___173 {
	struct kobject___204 kobj;
	struct module___176 *mod;
	struct kobject___204 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___173 {
	struct module___176 *mod;
	struct latch_tree_node node;
};

struct module_layout___173 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___173 mtn;
};

struct module_attribute___173;

struct kernel_param___173;

struct module___176 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___173 mkobj;
	struct module_attribute___173 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___204 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___173 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___173 core_layout;
	struct module_layout___173 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___214 {
	int (*writepage)(struct page___215 *, struct writeback_control___3 *);
	int (*readpage)(struct file___215 *, struct page___215 *);
	int (*writepages)(struct address_space___214 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___215 *);
	int (*readpages)(struct file___215 *, struct address_space___214 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___215 *, struct address_space___214 *, loff_t, unsigned int, unsigned int, struct page___215 **, void **);
	int (*write_end)(struct file___215 *, struct address_space___214 *, loff_t, unsigned int, unsigned int, struct page___215 *, void *);
	sector_t (*bmap)(struct address_space___214 *, sector_t);
	void (*invalidatepage)(struct page___215 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___215 *, gfp_t);
	void (*freepage)(struct page___215 *);
	ssize_t (*direct_IO)(struct kiocb___215 *, struct iov_iter___100 *);
	int (*migratepage)(struct address_space___214 *, struct page___215 *, struct page___215 *, enum migrate_mode);
	bool (*isolate_page)(struct page___215 *, isolate_mode_t);
	void (*putback_page)(struct page___215 *);
	int (*launder_page)(struct page___215 *);
	int (*is_partially_uptodate)(struct page___215 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___215 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___214 *, struct page___215 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___215 *, sector_t *);
	void (*swap_deactivate)(struct file___215 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___215 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___215 *bd_inode;
	struct super_block___214 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___215 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___214 {
	struct dentry___214 * (*lookup)(struct inode___215 *, struct dentry___214 *, unsigned int);
	const char * (*get_link)(struct dentry___214 *, struct inode___215 *, struct delayed_call *);
	int (*permission)(struct inode___215 *, int);
	struct posix_acl * (*get_acl)(struct inode___215 *, int);
	int (*readlink)(struct dentry___214 *, char *, int);
	int (*create)(struct inode___215 *, struct dentry___214 *, umode_t, bool);
	int (*link)(struct dentry___214 *, struct inode___215 *, struct dentry___214 *);
	int (*unlink)(struct inode___215 *, struct dentry___214 *);
	int (*symlink)(struct inode___215 *, struct dentry___214 *, const char *);
	int (*mkdir)(struct inode___215 *, struct dentry___214 *, umode_t);
	int (*rmdir)(struct inode___215 *, struct dentry___214 *);
	int (*mknod)(struct inode___215 *, struct dentry___214 *, umode_t, dev_t);
	int (*rename)(struct inode___215 *, struct dentry___214 *, struct inode___215 *, struct dentry___214 *, unsigned int);
	int (*setattr)(struct dentry___214 *, struct iattr___214 *);
	int (*getattr)(const struct path___214 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___214 *, char *, size_t);
	int (*fiemap)(struct inode___215 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___215 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___215 *, struct dentry___214 *, struct file___215 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___215 *, struct dentry___214 *, umode_t);
	int (*set_acl)(struct inode___215 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___214 {
	void (*fl_copy_lock)(struct file_lock___215 *, struct file_lock___215 *);
	void (*fl_release_private)(struct file_lock___215 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___214;

struct lock_manager_operations___214;

struct file_lock___215 {
	struct file_lock___215 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___215 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___214 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___214 *fl_ops;
	const struct lock_manager_operations___214 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___214 {
	int (*lm_compare_owner)(struct file_lock___215 *, struct file_lock___215 *);
	long unsigned int (*lm_owner_key)(struct file_lock___215 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___215 *);
	int (*lm_grant)(struct file_lock___215 *, int);
	bool (*lm_break)(struct file_lock___215 *);
	int (*lm_change)(struct file_lock___215 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___215 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___214 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___214 *fa_next;
	struct file___215 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___214 {
	const char *name;
	int fs_flags;
	struct dentry___214 * (*mount)(struct file_system_type___214 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___214 *);
	struct module___176 *owner;
	struct file_system_type___214 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___214 {
	struct inode___215 * (*alloc_inode)(struct super_block___214 *);
	void (*destroy_inode)(struct inode___215 *);
	void (*dirty_inode)(struct inode___215 *, int);
	int (*write_inode)(struct inode___215 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___215 *);
	void (*evict_inode)(struct inode___215 *);
	void (*put_super)(struct super_block___214 *);
	int (*sync_fs)(struct super_block___214 *, int);
	int (*freeze_super)(struct super_block___214 *);
	int (*freeze_fs)(struct super_block___214 *);
	int (*thaw_super)(struct super_block___214 *);
	int (*unfreeze_fs)(struct super_block___214 *);
	int (*statfs)(struct dentry___214 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___214 *, int *, char *);
	void (*umount_begin)(struct super_block___214 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___214 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___214 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___214 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___214 *);
	ssize_t (*quota_read)(struct super_block___214 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___214 *, int, const char *, size_t, loff_t);
	struct dquot___214 ** (*get_dquots)(struct inode___215 *);
	int (*bdev_try_to_free_page)(struct super_block___214 *, struct page___215 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___214 *, struct shrink_control___94 *);
	long int (*free_cached_objects)(struct super_block___214 *, struct shrink_control___94 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_attribute___201 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___204 *, struct kobj_attribute___201 *, char *);
	ssize_t (*store)(struct kobject___204 *, struct kobj_attribute___201 *, const char *, size_t);
};

typedef void compound_page_dtor___209(struct page___215 *);

struct vmcore {
	struct list_head list;
	long long unsigned int paddr;
	long long unsigned int size;
	loff_t offset;
};

struct vmcoredd_node {
	struct list_head list;
	void *buf;
	unsigned int size;
};

typedef struct elf64_note Elf64_Nhdr;

typedef int (*key_restrict_link_func_t___208)(struct key___208 *, const struct key_type *, const union key_payload *, struct key___208 *);

struct key_restriction___208;

struct key___208 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___215 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___208 *restrict_link;
};

struct key_restriction___208 {
	key_restrict_link_func_t___208 check;
	struct key___208 *key;
	struct key_type *keytype;
};

struct proc_ns_operations___26 {
	const char *name;
	const char *real_ns_name;
	int type;
	struct ns_common___26 * (*get)(struct task_struct___215 *);
	void (*put)(struct ns_common___26 *);
	int (*install)(struct nsproxy___199 *, struct ns_common___26 *);
	struct user_namespace___3 * (*owner)(struct ns_common___26 *);
	struct ns_common___26 * (*get_parent)(struct ns_common___26 *);
};

struct kernfs_root___207;

struct kernfs_elem_dir___207 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___207 *root;
};

struct kernfs_syscall_ops___207;

struct kernfs_root___207 {
	struct kernfs_node___207 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___207 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___207 {
	struct kernfs_node___207 *target_kn;
};

struct kernfs_ops___207;

struct kernfs_elem_attr___207 {
	const struct kernfs_ops___207 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___207 *notify_next;
};

struct kernfs_node___207 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___207 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___207 dir;
		struct kernfs_elem_symlink___207 symlink;
		struct kernfs_elem_attr___207 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___207;

struct kernfs_ops___207 {
	int (*open)(struct kernfs_open_file___207 *);
	void (*release)(struct kernfs_open_file___207 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___207 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___207 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___207 *, struct vm_area_struct___215 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___207 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___207 {
	int (*remount_fs)(struct kernfs_root___207 *, int *, char *);
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___207 *);
	int (*mkdir)(struct kernfs_node___207 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___207 *);
	int (*rename)(struct kernfs_node___207 *, struct kernfs_node___207 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___207 *, struct kernfs_root___207 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___207 {
	struct kernfs_node___207 *kn;
	struct file___215 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___209 *vm_ops;
};

struct sysfs_ops___203 {
	ssize_t (*show)(struct kobject___204 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___204 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___203;

struct kset___203 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___204 kobj;
	const struct kset_uevent_ops___203 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___203 {
	void (*release)(struct kobject___204 *);
	const struct sysfs_ops___203 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___12 * (*child_ns_type)(struct kobject___204 *);
	const void * (*namespace)(struct kobject___204 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___203 {
	int (* const filter)(struct kset___203 *, struct kobject___204 *);
	const char * (* const name)(struct kset___203 *, struct kobject___204 *);
	int (* const uevent)(struct kset___203 *, struct kobject___204 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___173 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___173 *);
	int (*get)(char *, const struct kernel_param___173 *);
	void (*free)(void *);
};

struct kparam_array___173;

struct kernel_param___173 {
	const char *name;
	struct module___176 *mod;
	const struct kernel_param_ops___173 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___173 *arr;
	};
};

struct kparam_array___173 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___173 *ops;
	void *elem;
};

struct module_attribute___173 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___173 *, struct module_kobject___173 *, char *);
	ssize_t (*store)(struct module_attribute___173 *, struct module_kobject___173 *, const char *, size_t);
	void (*setup)(struct module___176 *, const char *);
	int (*test)(struct module___176 *);
	void (*free)(struct module___176 *);
};

struct kimage___17;

typedef void *kexec_load_t___17(struct kimage___17 *, char *, long unsigned int, char *, long unsigned int, char *, long unsigned int);

struct kexec_file_ops___18 {
	kexec_probe_t *probe;
	kexec_load_t___17 *load;
	kexec_cleanup_t *cleanup;
};

struct kimage___17 {
	kimage_entry_t head;
	kimage_entry_t *entry;
	kimage_entry_t *last_entry;
	long unsigned int start;
	struct page___215 *control_code_page;
	struct page___215 *swap_page;
	void *vmcoreinfo_data_copy;
	long unsigned int nr_segments;
	struct kexec_segment segment[16];
	struct list_head control_pages;
	struct list_head dest_pages;
	struct list_head unusable_pages;
	long unsigned int control_page;
	unsigned int type: 1;
	unsigned int preserve_context: 1;
	unsigned int file_mode: 1;
	struct kimage_arch arch;
	void *kernel_buf;
	long unsigned int kernel_buf_len;
	void *initrd_buf;
	long unsigned int initrd_buf_len;
	char *cmdline_buf;
	long unsigned int cmdline_buf_len;
	const struct kexec_file_ops___18 *fops;
	void *image_loader_data;
	struct purgatory_info purgatory_info;
};

typedef int (*proc_write_t___16)(struct file___215 *, char *, size_t);

struct vmcoredd_header {
	__u32 n_namesz;
	__u32 n_descsz;
	__u32 n_type;
	__u8 name[8];
	__u8 dump_name[44];
};

struct vmcoredd_data {
	char dump_name[44];
	unsigned int size;
	int (*vmcoredd_callback)(struct vmcoredd_data *, void *);
};

struct linux_binprm___36 {
	char buf[256];
	struct vm_area_struct___215 *vma;
	long unsigned int vma_pages;
	struct mm_struct___214 *mm;
	long unsigned int p;
	unsigned int called_set_creds: 1;
	unsigned int cap_elevated: 1;
	unsigned int secureexec: 1;
	unsigned int recursion_depth;
	struct file___215 *file;
	struct cred___208 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
};

struct coredump_params___35 {
	union {
		const kernel_siginfo_t *siginfo;
		struct {
			const siginfo_t *siginfo;
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	struct pt_regs *regs;
	struct file___215 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
};

struct proc_dir_entry___16 {
	atomic_t in_use;
	refcount_t refcnt;
	struct list_head pde_openers;
	spinlock_t pde_unload_lock;
	struct completion *pde_unload_completion;
	const struct inode_operations___214 *proc_iops;
	const struct file_operations___215 *proc_fops;
	union {
		const struct seq_operations___193 *seq_ops;
		int (*single_show)(struct seq_file___195 *, void *);
	};
	proc_write_t___16 write;
	void *data;
	unsigned int state_size;
	unsigned int low_ino;
	nlink_t nlink;
	kuid_t uid;
	kgid_t gid;
	loff_t size;
	struct proc_dir_entry___16 *parent;
	struct rb_root subdir;
	struct rb_node subdir_node;
	char *name;
	umode_t mode;
	u8 namelen;
	char inline_name[0];
};

typedef void (*poll_queue_proc___141)(struct file___212 *, wait_queue_head_t *, struct poll_table_struct___5 *);

typedef struct poll_table_struct___5 poll_table___19;

struct file___216;

struct kiocb___216;

struct vm_area_struct___216;

struct inode___216;

struct file_lock___216;

struct page___216;

struct seq_file___196;

struct file_operations___216 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___216 *, loff_t, int);
	ssize_t (*read)(struct file___216 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___216 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___216 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___216 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___216 *, bool);
	int (*iterate)(struct file___216 *, struct dir_context *);
	int (*iterate_shared)(struct file___216 *, struct dir_context *);
	__poll_t (*poll)(struct file___216 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___216 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___216 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___216 *, struct vm_area_struct___216 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___216 *, struct file___216 *);
	int (*flush)(struct file___216 *, fl_owner_t);
	int (*release)(struct inode___216 *, struct file___216 *);
	int (*fsync)(struct file___216 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___216 *, int);
	int (*lock)(struct file___216 *, int, struct file_lock___216 *);
	ssize_t (*sendpage)(struct file___216 *, struct page___216 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___216 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___216 *, int, struct file_lock___216 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___216 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___216 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___216 *, long int, struct file_lock___216 **, void **);
	long int (*fallocate)(struct file___216 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___196 *, struct file___216 *);
	ssize_t (*copy_file_range)(struct file___216 *, loff_t, struct file___216 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___216 *, loff_t, struct file___216 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___216 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___215 {
	u64 seqnum;
	struct vm_area_struct___216 *vmas[4];
};

struct page_frag___215 {
	struct page___216 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___215;

struct mem_cgroup___95;

struct cred___209;

struct nsproxy___200;

struct bio_list___106;

struct backing_dev_info___106;

struct css_set___171;

struct task_struct___216 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___216 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___215 *mm;
	struct mm_struct___215 *active_mm;
	struct vmacache___215 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___216 *real_parent;
	struct task_struct___216 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___216 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___95 *active_memcg;
	long int rh_reserved2;
	struct pid___166 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___166 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___166 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___209 *ptracer_cred;
	const struct cred___209 *real_cred;
	const struct cred___209 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___200 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___216 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___106 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___106 *backing_dev_info;
	struct io_context___55 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___171 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___215 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___95 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___216 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___120 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___216 *pgtable_t___215;

struct address_space___215;

struct dev_pagemap___210;

struct page___216 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___215 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___216 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___215 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___215 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___210 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___95 *mem_cgroup;
};

struct pglist_data___215;

struct lruvec___215 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___215 *pgdat;
};

struct zone___215 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___215 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___215 {
	struct zone___215 *zone;
	int zone_idx;
};

struct zonelist___215 {
	struct zoneref___215 _zonerefs[25];
};

struct pglist_data___215 {
	struct zone___215 node_zones[3];
	struct zonelist___215 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___216 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___216 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___215 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___216 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___216 *owner;
};

struct secondary_data___216 {
	void *stack;
	struct task_struct___216 *task;
	long int status;
};

struct blocking_notifier_head___215 {
	struct rw_semaphore___216 rwsem;
	struct notifier_block *head;
};

struct anon_vma___21;

struct vm_operations_struct___210;

struct vm_area_struct___216 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___216 *vm_next;
	struct vm_area_struct___216 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___215 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma___21 *anon_vma;
	const struct vm_operations_struct___210 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___216 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct linux_binfmt___36;

struct core_state___215;

struct user_namespace___182;

struct mm_struct___215 {
	struct {
		struct vm_area_struct___216 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___216 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___216 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___36 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___215 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___216 *owner;
		struct user_namespace___182 *user_ns;
		struct file___216 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___215 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___215;

struct address_space___215 {
	struct inode___216 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___216 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___215 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___210)(struct vm_area_struct___216 *, long unsigned int, const struct page___216 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___210)(struct page___216 *, void *);

struct dev_pagemap___210 {
	dev_page_fault_t___210 page_fault;
	dev_page_free_t___210 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___6 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct cgroup___171;

struct cgroup_subsys___171;

struct cgroup_subsys_state___172 {
	struct cgroup___171 *cgroup;
	struct cgroup_subsys___171 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___172 *parent;
};

struct kernfs_node___208;

struct cgroup_file___171 {
	struct kernfs_node___208 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___95;

struct mem_cgroup___95 {
	struct cgroup_subsys_state___172 css;
	struct mem_cgroup_id___6 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___171 events_file;
	struct cgroup_file___171 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___216 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___95 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry___215;

struct path___215 {
	struct vfsmount *mnt;
	struct dentry___215 *dentry;
};

struct file___216 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___215 f_path;
	struct inode___216 *f_inode;
	const struct file_operations___216 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___166 f_owner;
	const struct cred___209 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___215 *f_mapping;
	errseq_t f_wb_err;
};

struct anon_vma___21 {
	struct anon_vma___21 *root;
	struct rw_semaphore___216 rwsem;
	atomic_t refcount;
	unsigned int degree;
	struct anon_vma___21 *parent;
	struct rb_root_cached rb_root;
};

struct vm_fault___210;

struct vm_operations_struct___210 {
	void (*open)(struct vm_area_struct___216 *);
	void (*close)(struct vm_area_struct___216 *);
	int (*split)(struct vm_area_struct___216 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___216 *);
	vm_fault_t (*fault)(struct vm_fault___210 *);
	vm_fault_t (*huge_fault)(struct vm_fault___210 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___210 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___216 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___210 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___210 *);
	int (*access)(struct vm_area_struct___216 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___216 *);
	int (*set_policy)(struct vm_area_struct___216 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___216 *, long unsigned int);
	struct page___216 * (*find_special_page)(struct vm_area_struct___216 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___215 {
	struct task_struct___216 *task;
	struct core_thread___215 *next;
};

struct core_state___215 {
	atomic_t nr_threads;
	struct core_thread___215 dumper;
	struct completion startup;
};

struct linux_binprm___37;

struct coredump_params___36;

struct linux_binfmt___36 {
	struct list_head lh;
	struct module___11 *module;
	int (*load_binary)(struct linux_binprm___37 *);
	int (*load_shlib)(struct file___216 *);
	int (*core_dump)(struct coredump_params___36 *);
	long unsigned int min_coredump;
};

struct proc_ns_operations___27;

struct ns_common___27 {
	atomic_long_t stashed;
	const struct proc_ns_operations___27 *ops;
	unsigned int inum;
};

struct key___209;

struct ucounts___182;

struct user_namespace___182 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___182 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___27 ns;
	long unsigned int flags;
	struct key___209 *persistent_keyring_register;
	struct rw_semaphore___216 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___182 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___210 {
	struct vm_area_struct___216 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___216 *cow_page;
	struct mem_cgroup___95 *memcg;
	struct page___216 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___215 prealloc_pte;
};

struct dentry_operations___215;

struct super_block___215;

struct dentry___215 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___215 *d_parent;
	struct qstr d_name;
	struct inode___216 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___215 *d_op;
	struct super_block___215 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___215;

struct bdi_writeback___106;

struct block_device___216;

struct inode___216 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___215 *i_op;
	struct super_block___215 *i_sb;
	struct address_space___215 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___216 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___106 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___216 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___215 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___216 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___215 {
	int (*d_revalidate)(struct dentry___215 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___215 *, unsigned int);
	int (*d_hash)(const struct dentry___215 *, struct qstr *);
	int (*d_compare)(const struct dentry___215 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___215 *);
	int (*d_init)(struct dentry___215 *);
	void (*d_release)(struct dentry___215 *);
	void (*d_prune)(struct dentry___215 *);
	void (*d_iput)(struct dentry___215 *, struct inode___216 *);
	char * (*d_dname)(struct dentry___215 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___215 *);
	int (*d_manage)(const struct path___215 *, bool);
	struct dentry___215 * (*d_real)(struct dentry___215 *, const struct inode___216 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___215;

struct mem_dqinfo___215 {
	struct quota_format_type___215 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___215;

struct quota_info___215 {
	unsigned int flags;
	struct rw_semaphore___216 dqio_sem;
	struct inode___216 *files[3];
	struct mem_dqinfo___215 info[3];
	const struct quota_format_ops___215 *ops[3];
};

struct rcuwait___215 {
	struct task_struct___216 *task;
};

struct percpu_rw_semaphore___215 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___216 rw_sem;
	struct rcuwait___215 writer;
	int readers_block;
};

struct sb_writers___215 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___215 rw_sem[3];
};

struct shrink_control___95;

struct shrinker___95 {
	long unsigned int (*count_objects)(struct shrinker___95 *, struct shrink_control___95 *);
	long unsigned int (*scan_objects)(struct shrinker___95 *, struct shrink_control___95 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___215;

struct super_operations___215;

struct dquot_operations___215;

struct quotactl_ops___215;

struct super_block___215 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___215 *s_type;
	const struct super_operations___215 *s_op;
	const struct dquot_operations___215 *dq_op;
	const struct quotactl_ops___215 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___215 *s_root;
	struct rw_semaphore___216 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___216 *s_bdev;
	struct backing_dev_info___106 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___215 s_dquot;
	struct sb_writers___215 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___215 *s_d_op;
	int cleancache_poolid;
	struct shrinker___95 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___182 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___95 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___95 *memcg;
};

struct user_struct___209 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___209 *uid_keyring;
	struct key___209 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___209 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___209 *session_keyring;
	struct key___209 *process_keyring;
	struct key___209 *thread_keyring;
	struct key___209 *request_key_auth;
	void *security;
	struct user_struct___209 *user;
	struct user_namespace___182 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___171;

struct nsproxy___200 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___171 *cgroup_ns;
};

struct bio___106;

struct bio_list___106 {
	struct bio___106 *head;
	struct bio___106 *tail;
};

struct bdi_writeback_congested___106;

struct bdi_writeback___106 {
	struct backing_dev_info___106 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___106 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___172 *memcg_css;
	struct cgroup_subsys_state___172 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___106 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___106 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___6 *dev;
	struct device___6 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___215 *debug_dir;
	struct dentry___215 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___171 {
	struct cgroup_subsys_state___172 *subsys[13];
	refcount_t refcount;
	struct css_set___171 *dom_cset;
	struct cgroup___171 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___171 *mg_src_cgrp;
	struct cgroup___171 *mg_dst_cgrp;
	struct css_set___171 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

union thread_union___193 {
	struct task_struct___216 task;
	long unsigned int stack[8192];
};

struct kiocb___216 {
	struct file___216 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___216 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___215 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___216 *ia_file;
};

struct dquot___215 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___215 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___215 {
	int qf_fmt_id;
	const struct quota_format_ops___215 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___215 *qf_next;
};

struct quota_format_ops___215 {
	int (*check_quota_file)(struct super_block___215 *, int);
	int (*read_file_info)(struct super_block___215 *, int);
	int (*write_file_info)(struct super_block___215 *, int);
	int (*free_file_info)(struct super_block___215 *, int);
	int (*read_dqblk)(struct dquot___215 *);
	int (*commit_dqblk)(struct dquot___215 *);
	int (*release_dqblk)(struct dquot___215 *);
	int (*get_next_id)(struct super_block___215 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___215 {
	int (*write_dquot)(struct dquot___215 *);
	struct dquot___215 * (*alloc_dquot)(struct super_block___215 *, int);
	void (*destroy_dquot)(struct dquot___215 *);
	int (*acquire_dquot)(struct dquot___215 *);
	int (*release_dquot)(struct dquot___215 *);
	int (*mark_dirty)(struct dquot___215 *);
	int (*write_info)(struct super_block___215 *, int);
	qsize_t * (*get_reserved_space)(struct inode___216 *);
	int (*get_projid)(struct inode___216 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___216 *, qsize_t *);
	int (*get_next_id)(struct super_block___215 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___215 {
	int (*quota_on)(struct super_block___215 *, int, int, const struct path___215 *);
	int (*quota_off)(struct super_block___215 *, int);
	int (*quota_enable)(struct super_block___215 *, unsigned int);
	int (*quota_disable)(struct super_block___215 *, unsigned int);
	int (*quota_sync)(struct super_block___215 *, int);
	int (*set_info)(struct super_block___215 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___215 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___215 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___215 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___215 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___215 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___102;

struct address_space_operations___215 {
	int (*writepage)(struct page___216 *, struct writeback_control___102 *);
	int (*readpage)(struct file___216 *, struct page___216 *);
	int (*writepages)(struct address_space___215 *, struct writeback_control___102 *);
	int (*set_page_dirty)(struct page___216 *);
	int (*readpages)(struct file___216 *, struct address_space___215 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___216 *, struct address_space___215 *, loff_t, unsigned int, unsigned int, struct page___216 **, void **);
	int (*write_end)(struct file___216 *, struct address_space___215 *, loff_t, unsigned int, unsigned int, struct page___216 *, void *);
	sector_t (*bmap)(struct address_space___215 *, sector_t);
	void (*invalidatepage)(struct page___216 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___216 *, gfp_t);
	void (*freepage)(struct page___216 *);
	ssize_t (*direct_IO)(struct kiocb___216 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___215 *, struct page___216 *, struct page___216 *, enum migrate_mode);
	bool (*isolate_page)(struct page___216 *, isolate_mode_t);
	void (*putback_page)(struct page___216 *);
	int (*launder_page)(struct page___216 *);
	int (*is_partially_uptodate)(struct page___216 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___216 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___215 *, struct page___216 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___216 *, sector_t *);
	void (*swap_deactivate)(struct file___216 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___102 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___106 *wb;
	struct inode___216 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___216 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___216 *bd_inode;
	struct super_block___215 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___216 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___106 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___215 {
	struct dentry___215 * (*lookup)(struct inode___216 *, struct dentry___215 *, unsigned int);
	const char * (*get_link)(struct dentry___215 *, struct inode___216 *, struct delayed_call *);
	int (*permission)(struct inode___216 *, int);
	struct posix_acl * (*get_acl)(struct inode___216 *, int);
	int (*readlink)(struct dentry___215 *, char *, int);
	int (*create)(struct inode___216 *, struct dentry___215 *, umode_t, bool);
	int (*link)(struct dentry___215 *, struct inode___216 *, struct dentry___215 *);
	int (*unlink)(struct inode___216 *, struct dentry___215 *);
	int (*symlink)(struct inode___216 *, struct dentry___215 *, const char *);
	int (*mkdir)(struct inode___216 *, struct dentry___215 *, umode_t);
	int (*rmdir)(struct inode___216 *, struct dentry___215 *);
	int (*mknod)(struct inode___216 *, struct dentry___215 *, umode_t, dev_t);
	int (*rename)(struct inode___216 *, struct dentry___215 *, struct inode___216 *, struct dentry___215 *, unsigned int);
	int (*setattr)(struct dentry___215 *, struct iattr___215 *);
	int (*getattr)(const struct path___215 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___215 *, char *, size_t);
	int (*fiemap)(struct inode___216 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___216 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___216 *, struct dentry___215 *, struct file___216 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___216 *, struct dentry___215 *, umode_t);
	int (*set_acl)(struct inode___216 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___215 {
	void (*fl_copy_lock)(struct file_lock___216 *, struct file_lock___216 *);
	void (*fl_release_private)(struct file_lock___216 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___215;

struct lock_manager_operations___215;

struct file_lock___216 {
	struct file_lock___216 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___216 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___215 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___215 *fl_ops;
	const struct lock_manager_operations___215 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___215 {
	int (*lm_compare_owner)(struct file_lock___216 *, struct file_lock___216 *);
	long unsigned int (*lm_owner_key)(struct file_lock___216 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___216 *);
	int (*lm_grant)(struct file_lock___216 *, int);
	bool (*lm_break)(struct file_lock___216 *);
	int (*lm_change)(struct file_lock___216 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___216 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___215 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___215 *fa_next;
	struct file___216 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___215 {
	const char *name;
	int fs_flags;
	struct dentry___215 * (*mount)(struct file_system_type___215 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___215 *);
	struct module___11 *owner;
	struct file_system_type___215 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___215 {
	struct inode___216 * (*alloc_inode)(struct super_block___215 *);
	void (*destroy_inode)(struct inode___216 *);
	void (*dirty_inode)(struct inode___216 *, int);
	int (*write_inode)(struct inode___216 *, struct writeback_control___102 *);
	int (*drop_inode)(struct inode___216 *);
	void (*evict_inode)(struct inode___216 *);
	void (*put_super)(struct super_block___215 *);
	int (*sync_fs)(struct super_block___215 *, int);
	int (*freeze_super)(struct super_block___215 *);
	int (*freeze_fs)(struct super_block___215 *);
	int (*thaw_super)(struct super_block___215 *);
	int (*unfreeze_fs)(struct super_block___215 *);
	int (*statfs)(struct dentry___215 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___215 *, int *, char *);
	void (*umount_begin)(struct super_block___215 *);
	int (*show_options)(struct seq_file___196 *, struct dentry___215 *);
	int (*show_devname)(struct seq_file___196 *, struct dentry___215 *);
	int (*show_path)(struct seq_file___196 *, struct dentry___215 *);
	int (*show_stats)(struct seq_file___196 *, struct dentry___215 *);
	ssize_t (*quota_read)(struct super_block___215 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___215 *, int, const char *, size_t, loff_t);
	struct dquot___215 ** (*get_dquots)(struct inode___216 *);
	int (*bdev_try_to_free_page)(struct super_block___215 *, struct page___216 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___215 *, struct shrink_control___95 *);
	long int (*free_cached_objects)(struct super_block___215 *, struct shrink_control___95 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___194;

struct seq_file___196 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___194 *op;
	int poll_event;
	const struct file___216 *file;
	void *private;
};

typedef void bio_end_io_t___106(struct bio___106 *);

struct bio_vec___106 {
	struct page___216 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___106;

struct bio_set___106;

struct bio___106 {
	struct bio___106 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___106 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___106 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___106 *bi_io_vec;
	struct bio_set___106 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___106 bi_inline_vecs[0];
};

typedef void compound_page_dtor___210(struct page___216 *);

typedef int (*key_restrict_link_func_t___209)(struct key___209 *, const struct key_type *, const union key_payload *, struct key___209 *);

struct key_restriction___209;

struct key___209 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___216 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___209 *restrict_link;
};

struct key_restriction___209 {
	key_restrict_link_func_t___209 check;
	struct key___209 *key;
	struct key_type *keytype;
};

struct seq_operations___194 {
	void * (*start)(struct seq_file___196 *, loff_t *);
	void (*stop)(struct seq_file___196 *, void *);
	void * (*next)(struct seq_file___196 *, void *, loff_t *);
	int (*show)(struct seq_file___196 *, void *);
};

struct kernfs_root___208;

struct kernfs_elem_dir___208 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___208 *root;
};

struct kernfs_syscall_ops___208;

struct kernfs_root___208 {
	struct kernfs_node___208 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___208 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___208 {
	struct kernfs_node___208 *target_kn;
};

struct kernfs_ops___208;

struct kernfs_elem_attr___208 {
	const struct kernfs_ops___208 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___208 *notify_next;
};

struct kernfs_node___208 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___208 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___208 dir;
		struct kernfs_elem_symlink___208 symlink;
		struct kernfs_elem_attr___208 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___208;

struct kernfs_ops___208 {
	int (*open)(struct kernfs_open_file___208 *);
	void (*release)(struct kernfs_open_file___208 *);
	int (*seq_show)(struct seq_file___196 *, void *);
	void * (*seq_start)(struct seq_file___196 *, loff_t *);
	void * (*seq_next)(struct seq_file___196 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___196 *, void *);
	ssize_t (*read)(struct kernfs_open_file___208 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___208 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___208 *, struct vm_area_struct___216 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___208 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___208 {
	int (*remount_fs)(struct kernfs_root___208 *, int *, char *);
	int (*show_options)(struct seq_file___196 *, struct kernfs_root___208 *);
	int (*mkdir)(struct kernfs_node___208 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___208 *);
	int (*rename)(struct kernfs_node___208 *, struct kernfs_node___208 *, const char *);
	int (*show_path)(struct seq_file___196 *, struct kernfs_node___208 *, struct kernfs_root___208 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___208 {
	struct kernfs_node___208 *kn;
	struct file___216 *file;
	struct seq_file___196 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___210 *vm_ops;
};

struct proc_ns_operations___27 {
	const char *name;
	const char *real_ns_name;
	int type;
	struct ns_common___27 * (*get)(struct task_struct___216 *);
	void (*put)(struct ns_common___27 *);
	int (*install)(struct nsproxy___200 *, struct ns_common___27 *);
	struct user_namespace___182 * (*owner)(struct ns_common___27 *);
	struct ns_common___27 * (*get_parent)(struct ns_common___27 *);
};

struct cgroup_namespace___171 {
	refcount_t count;
	struct ns_common___27 ns;
	struct user_namespace___182 *user_ns;
	struct ucounts___182 *ucounts;
	struct css_set___171 *root_cset;
};

struct ucounts___182 {
	struct hlist_node node;
	struct user_namespace___182 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

typedef int (*proc_write_t___17)(struct file___216 *, char *, size_t);

struct proc_dir_entry___17 {
	atomic_t in_use;
	refcount_t refcnt;
	struct list_head pde_openers;
	spinlock_t pde_unload_lock;
	struct completion *pde_unload_completion;
	const struct inode_operations___215 *proc_iops;
	const struct file_operations___216 *proc_fops;
	union {
		const struct seq_operations___194 *seq_ops;
		int (*single_show)(struct seq_file___196 *, void *);
	};
	proc_write_t___17 write;
	void *data;
	unsigned int state_size;
	unsigned int low_ino;
	nlink_t nlink;
	kuid_t uid;
	kgid_t gid;
	loff_t size;
	struct proc_dir_entry___17 *parent;
	struct rb_root subdir;
	struct rb_node subdir_node;
	char *name;
	umode_t mode;
	u8 namelen;
	char inline_name[0];
};

struct bpf_map___171;

struct bpf_map_ops___171 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___171 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___171 *, struct file___216 *);
	void (*map_free)(struct bpf_map___171 *);
	int (*map_get_next_key)(struct bpf_map___171 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___171 *);
	void * (*map_lookup_elem)(struct bpf_map___171 *, void *);
	int (*map_update_elem)(struct bpf_map___171 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___171 *, void *);
	int (*map_push_elem)(struct bpf_map___171 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___171 *, void *);
	int (*map_peek_elem)(struct bpf_map___171 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___171 *, struct file___216 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___171 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___171 *, void *, struct seq_file___196 *);
	int (*map_check_btf)(const struct bpf_map___171 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___171 {
	const struct bpf_map_ops___171 *ops;
	struct bpf_map___171 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___209 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___171;

typedef void (*kthread_work_func_t___171)(struct kthread_work___171 *);

struct kthread_worker___171;

struct kthread_work___171 {
	struct list_head node;
	kthread_work_func_t___171 func;
	struct kthread_worker___171 *worker;
	int canceling;
};

struct kthread_worker___171 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___216 *task;
	struct kthread_work___171 *current_work;
};

struct kthread_delayed_work___171 {
	struct kthread_work___171 work;
	struct timer_list timer;
};

struct psi_group___171 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___171 *poll_kworker;
	struct kthread_delayed_work___171 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___171;

struct cgroup_rstat_cpu___171;

struct cgroup___171 {
	struct cgroup_subsys_state___172 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___208 *kn;
	struct cgroup_file___171 procs_file;
	struct cgroup_file___171 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___172 *subsys[13];
	struct cgroup_root___171 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___171 *dom_cgrp;
	struct cgroup_rstat_cpu___171 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___22 bpf;
	atomic_t congestion_count;
	struct cgroup___171 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___171 psi;
	int ancestor_ids[0];
};

struct cftype___171;

struct cgroup_subsys___171 {
	struct cgroup_subsys_state___172 * (*css_alloc)(struct cgroup_subsys_state___172 *);
	int (*css_online)(struct cgroup_subsys_state___172 *);
	void (*css_offline)(struct cgroup_subsys_state___172 *);
	void (*css_released)(struct cgroup_subsys_state___172 *);
	void (*css_free)(struct cgroup_subsys_state___172 *);
	void (*css_reset)(struct cgroup_subsys_state___172 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___172 *, int);
	int (*css_extra_stat_show)(struct seq_file___196 *, struct cgroup_subsys_state___172 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___216 *);
	void (*cancel_fork)(struct task_struct___216 *);
	void (*fork)(struct task_struct___216 *);
	void (*exit)(struct task_struct___216 *);
	void (*free)(struct task_struct___216 *);
	void (*bind)(struct cgroup_subsys_state___172 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___171 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___171 *dfl_cftypes;
	struct cftype___171 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___171 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___171 *updated_children;
	struct cgroup___171 *updated_next;
};

struct cgroup_root___171 {
	struct kernfs_root___208 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___171 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___171 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___171 *ss;
	struct list_head node;
	struct kernfs_ops___208 *kf_ops;
	int (*open)(struct kernfs_open_file___208 *);
	void (*release)(struct kernfs_open_file___208 *);
	u64 (*read_u64)(struct cgroup_subsys_state___172 *, struct cftype___171 *);
	s64 (*read_s64)(struct cgroup_subsys_state___172 *, struct cftype___171 *);
	int (*seq_show)(struct seq_file___196 *, void *);
	void * (*seq_start)(struct seq_file___196 *, loff_t *);
	void * (*seq_next)(struct seq_file___196 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___196 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___172 *, struct cftype___171 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___172 *, struct cftype___171 *, s64);
	ssize_t (*write)(struct kernfs_open_file___208 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___208 *, struct poll_table_struct___6 *);
};

struct bdi_writeback_congested___106 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___106 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___106 {
	struct bio___106 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___106 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___106 bip_inline_vecs[0];
};

struct bio_set___106 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___106 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___95 {
	struct mem_cgroup___95 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___95 {
	struct lruvec___215 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___95 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___95 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct hstate___40 {
	int next_nid_to_alloc;
	int next_nid_to_free;
	unsigned int order;
	long unsigned int mask;
	long unsigned int max_huge_pages;
	long unsigned int nr_huge_pages;
	long unsigned int free_huge_pages;
	long unsigned int resv_huge_pages;
	long unsigned int surplus_huge_pages;
	long unsigned int nr_overcommit_huge_pages;
	struct list_head hugepage_activelist;
	struct list_head hugepage_freelists[8];
	unsigned int nr_huge_pages_node[8];
	unsigned int free_huge_pages_node[8];
	unsigned int surplus_huge_pages_node[8];
	struct cftype___171 cgroup_files[5];
	char name[32];
};

struct linux_binprm___37 {
	char buf[256];
	struct vm_area_struct___216 *vma;
	long unsigned int vma_pages;
	struct mm_struct___215 *mm;
	long unsigned int p;
	unsigned int called_set_creds: 1;
	unsigned int cap_elevated: 1;
	unsigned int secureexec: 1;
	unsigned int recursion_depth;
	struct file___216 *file;
	struct cred___209 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
};

struct coredump_params___36 {
	union {
		const kernel_siginfo_t *siginfo;
		struct {
			const siginfo_t *siginfo;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	struct pt_regs *regs;
	struct file___216 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
};

struct kernfs_root___209;

struct kernfs_elem_dir___209 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___209 *root;
};

struct kernfs_node___209;

struct kernfs_syscall_ops___209;

struct kernfs_root___209 {
	struct kernfs_node___209 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___209 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___209 {
	struct kernfs_node___209 *target_kn;
};

struct kernfs_ops___209;

struct kernfs_elem_attr___209 {
	const struct kernfs_ops___209 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___209 *notify_next;
};

struct kernfs_node___209 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___209 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___209 dir;
		struct kernfs_elem_symlink___209 symlink;
		struct kernfs_elem_attr___209 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___209;

struct kernfs_ops___209 {
	int (*open)(struct kernfs_open_file___209 *);
	void (*release)(struct kernfs_open_file___209 *);
	int (*seq_show)(struct seq_file___186 *, void *);
	void * (*seq_start)(struct seq_file___186 *, loff_t *);
	void * (*seq_next)(struct seq_file___186 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___186 *, void *);
	ssize_t (*read)(struct kernfs_open_file___209 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___209 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___209 *, struct vm_area_struct___200 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___209 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_iattrs {
	kuid_t ia_uid;
	kgid_t ia_gid;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct simple_xattrs xattrs;
};

struct kernfs_syscall_ops___209 {
	int (*remount_fs)(struct kernfs_root___209 *, int *, char *);
	int (*show_options)(struct seq_file___186 *, struct kernfs_root___209 *);
	int (*mkdir)(struct kernfs_node___209 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___209 *);
	int (*rename)(struct kernfs_node___209 *, struct kernfs_node___209 *, const char *);
	int (*show_path)(struct seq_file___186 *, struct kernfs_node___209 *, struct kernfs_root___209 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___209 {
	struct kernfs_node___209 *kn;
	struct file___200 *file;
	struct seq_file___186 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___196 *vm_ops;
};

struct kernfs_super_info {
	struct super_block___199 *sb;
	struct kernfs_root___209 *root;
	const void *ns;
	struct list_head node;
};

struct file___217;

struct kiocb___217;

struct vm_area_struct___217;

struct inode___217;

struct file_lock___217;

struct page___217;

struct seq_file___197;

struct file_operations___217 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___217 *, loff_t, int);
	ssize_t (*read)(struct file___217 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___217 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___217 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___217 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___217 *, bool);
	int (*iterate)(struct file___217 *, struct dir_context *);
	int (*iterate_shared)(struct file___217 *, struct dir_context *);
	__poll_t (*poll)(struct file___217 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___217 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___217 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___217 *, struct vm_area_struct___217 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___217 *, struct file___217 *);
	int (*flush)(struct file___217 *, fl_owner_t);
	int (*release)(struct inode___217 *, struct file___217 *);
	int (*fsync)(struct file___217 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___217 *, int);
	int (*lock)(struct file___217 *, int, struct file_lock___217 *);
	ssize_t (*sendpage)(struct file___217 *, struct page___217 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___217 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___217 *, int, struct file_lock___217 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___217 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___217 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___217 *, long int, struct file_lock___217 **, void **);
	long int (*fallocate)(struct file___217 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___197 *, struct file___217 *);
	ssize_t (*copy_file_range)(struct file___217 *, loff_t, struct file___217 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___217 *, loff_t, struct file___217 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___217 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___216 {
	u64 seqnum;
	struct vm_area_struct___217 *vmas[4];
};

struct page_frag___216 {
	struct page___217 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___216;

struct cred___210;

struct nsproxy___201;

struct bio_list___107;

struct backing_dev_info___107;

struct io_context___56;

struct css_set___172;

struct request_queue___53;

struct vm_struct___147;

struct task_struct___217 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___217 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___216 *mm;
	struct mm_struct___216 *active_mm;
	struct vmacache___216 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___217 *real_parent;
	struct task_struct___217 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___217 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___166 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___166 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___166 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___210 *ptracer_cred;
	const struct cred___210 *real_cred;
	const struct cred___210 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___201 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___217 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___107 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___107 *backing_dev_info;
	struct io_context___56 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___172 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___216 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___53 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___217 *oom_reaper_list;
	struct vm_struct___147 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___120 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___217 *pgtable_t___216;

struct address_space___216;

struct dev_pagemap___211;

struct page___217 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___216 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___217 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___216 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___216 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___211 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___216;

struct lruvec___216 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___216 *pgdat;
};

struct zone___216 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___216 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___216 {
	struct zone___216 *zone;
	int zone_idx;
};

struct zonelist___216 {
	struct zoneref___216 _zonerefs[25];
};

struct pglist_data___216 {
	struct zone___216 node_zones[3];
	struct zonelist___216 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___217 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___217 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___216 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___217 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___217 *owner;
};

struct secondary_data___217 {
	void *stack;
	struct task_struct___217 *task;
	long int status;
};

struct blocking_notifier_head___216 {
	struct rw_semaphore___217 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___211;

struct vm_area_struct___217 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___217 *vm_next;
	struct vm_area_struct___217 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___216 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___211 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___217 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___216;

struct user_namespace___183;

struct mm_struct___216 {
	struct {
		struct vm_area_struct___217 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___217 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___217 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___216 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___217 *owner;
		struct user_namespace___183 *user_ns;
		struct file___217 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___216 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___216;

struct address_space___216 {
	struct inode___217 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___217 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___216 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___211)(struct vm_area_struct___217 *, long unsigned int, const struct page___217 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___211)(struct page___217 *, void *);

struct device___188;

struct dev_pagemap___211 {
	dev_page_fault_t___211 page_fault;
	dev_page_free_t___211 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___188 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct dentry___216;

struct path___216 {
	struct vfsmount *mnt;
	struct dentry___216 *dentry;
};

struct file___217 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___216 f_path;
	struct inode___217 *f_inode;
	const struct file_operations___217 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___166 f_owner;
	const struct cred___210 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___216 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___211;

struct vm_operations_struct___211 {
	void (*open)(struct vm_area_struct___217 *);
	void (*close)(struct vm_area_struct___217 *);
	int (*split)(struct vm_area_struct___217 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___217 *);
	vm_fault_t (*fault)(struct vm_fault___211 *);
	vm_fault_t (*huge_fault)(struct vm_fault___211 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___211 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___217 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___211 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___211 *);
	int (*access)(struct vm_area_struct___217 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___217 *);
	int (*set_policy)(struct vm_area_struct___217 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___217 *, long unsigned int);
	struct page___217 * (*find_special_page)(struct vm_area_struct___217 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___216 {
	struct task_struct___217 *task;
	struct core_thread___216 *next;
};

struct core_state___216 {
	atomic_t nr_threads;
	struct core_thread___216 dumper;
	struct completion startup;
};

struct key___210;

struct ucounts___183;

struct user_namespace___183 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___183 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___27 ns;
	long unsigned int flags;
	struct key___210 *persistent_keyring_register;
	struct rw_semaphore___217 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___183 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___211 {
	struct vm_area_struct___217 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___217 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___217 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___216 prealloc_pte;
};

struct user_struct___210 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___210 *uid_keyring;
	struct key___210 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___210 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___210 *session_keyring;
	struct key___210 *process_keyring;
	struct key___210 *thread_keyring;
	struct key___210 *request_key_auth;
	void *security;
	struct user_struct___210 *user;
	struct user_namespace___183 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___172;

struct nsproxy___201 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___172 *cgroup_ns;
};

struct bio___107;

struct bio_list___107 {
	struct bio___107 *head;
	struct bio___107 *tail;
};

struct bdi_writeback_congested___107;

struct cgroup_subsys_state___173;

struct bdi_writeback___107 {
	struct backing_dev_info___107 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___107 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___173 *memcg_css;
	struct cgroup_subsys_state___173 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___107 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___107 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___188 *dev;
	struct device___188 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___216 *debug_dir;
	struct dentry___216 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___56;

struct io_context___56 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___56 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___172;

struct css_set___172 {
	struct cgroup_subsys_state___173 *subsys[13];
	refcount_t refcount;
	struct css_set___172 *dom_cset;
	struct cgroup___172 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___172 *mg_src_cgrp;
	struct cgroup___172 *mg_dst_cgrp;
	struct css_set___172 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

typedef blk_qc_t make_request_fn___52(struct request_queue___53 *, struct bio___107 *);

struct request___53;

typedef int dma_drain_needed_fn___52(struct request___53 *);

struct kset___204;

struct kobj_type___204;

struct kernfs_node___210;

struct kobject___205 {
	const char *name;
	struct list_head entry;
	struct kobject___205 *parent;
	struct kset___204 *kset;
	struct kobj_type___204 *ktype;
	struct kernfs_node___210 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___52;

struct bsg_class_device___52 {
	struct device___188 *class_dev;
	int minor;
	struct request_queue___53 *queue;
	const struct bsg_ops___52 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___107 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___107 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___52;

struct blkcg_gq___41;

struct request_queue___53 {
	struct list_head queue_head;
	struct request___53 *last_merge;
	struct elevator_queue___52 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___52 *make_request_fn;
	dma_drain_needed_fn___52 *dma_drain_needed;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___107 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___205 kobj;
	struct kobject___205 *mq_kobj;
	struct blk_integrity integrity;
	struct device___188 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___41 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	struct bsg_class_device___52 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___107 bio_split;
	struct dentry___216 *debugfs_dir;
	struct dentry___216 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___147 {
	struct vm_struct___147 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___217 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dev_pm_info___188 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___188 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___188;

struct bus_type___188;

struct device_driver___188;

struct dev_pm_domain___188;

struct fwnode_handle___131;

struct class___188;

struct attribute_group___190;

struct device___188 {
	struct device___188 *parent;
	struct device_private *p;
	struct kobject___205 kobj;
	const char *init_name;
	const struct device_type___188 *type;
	struct mutex mutex;
	struct bus_type___188 *bus;
	struct device_driver___188 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___188 power;
	struct dev_pm_domain___188 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___131 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___188 *class;
	const struct attribute_group___190 **groups;
	void (*release)(struct device___188 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___216;

struct super_block___216;

struct dentry___216 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___216 *d_parent;
	struct qstr d_name;
	struct inode___217 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___216 *d_op;
	struct super_block___216 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___216;

struct block_device___217;

struct inode___217 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___216 *i_op;
	struct super_block___216 *i_sb;
	struct address_space___216 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___217 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___107 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___217 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___216 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___217 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___216 {
	int (*d_revalidate)(struct dentry___216 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___216 *, unsigned int);
	int (*d_hash)(const struct dentry___216 *, struct qstr *);
	int (*d_compare)(const struct dentry___216 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___216 *);
	int (*d_init)(struct dentry___216 *);
	void (*d_release)(struct dentry___216 *);
	void (*d_prune)(struct dentry___216 *);
	void (*d_iput)(struct dentry___216 *, struct inode___217 *);
	char * (*d_dname)(struct dentry___216 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___216 *);
	int (*d_manage)(const struct path___216 *, bool);
	struct dentry___216 * (*d_real)(struct dentry___216 *, const struct inode___217 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___216;

struct mem_dqinfo___216 {
	struct quota_format_type___216 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___216;

struct quota_info___216 {
	unsigned int flags;
	struct rw_semaphore___217 dqio_sem;
	struct inode___217 *files[3];
	struct mem_dqinfo___216 info[3];
	const struct quota_format_ops___216 *ops[3];
};

struct rcuwait___216 {
	struct task_struct___217 *task;
};

struct percpu_rw_semaphore___216 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___217 rw_sem;
	struct rcuwait___216 writer;
	int readers_block;
};

struct sb_writers___216 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___216 rw_sem[3];
};

struct file_system_type___216;

struct super_operations___216;

struct dquot_operations___216;

struct quotactl_ops___216;

struct xattr_handler___19;

struct super_block___216 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___216 *s_type;
	const struct super_operations___216 *s_op;
	const struct dquot_operations___216 *dq_op;
	const struct quotactl_ops___216 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___216 *s_root;
	struct rw_semaphore___217 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___19 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___217 *s_bdev;
	struct backing_dev_info___107 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___216 s_dquot;
	struct sb_writers___216 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___216 *s_d_op;
	int cleancache_poolid;
	struct shrinker___95 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___183 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct io_cq___56 {
	struct request_queue___53 *q;
	struct io_context___56 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___6 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___217 {
	struct file___217 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___217 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___216 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___217 *ia_file;
};

struct dquot___216 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___216 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___216 {
	int qf_fmt_id;
	const struct quota_format_ops___216 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___216 *qf_next;
};

struct quota_format_ops___216 {
	int (*check_quota_file)(struct super_block___216 *, int);
	int (*read_file_info)(struct super_block___216 *, int);
	int (*write_file_info)(struct super_block___216 *, int);
	int (*free_file_info)(struct super_block___216 *, int);
	int (*read_dqblk)(struct dquot___216 *);
	int (*commit_dqblk)(struct dquot___216 *);
	int (*release_dqblk)(struct dquot___216 *);
	int (*get_next_id)(struct super_block___216 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___216 {
	int (*write_dquot)(struct dquot___216 *);
	struct dquot___216 * (*alloc_dquot)(struct super_block___216 *, int);
	void (*destroy_dquot)(struct dquot___216 *);
	int (*acquire_dquot)(struct dquot___216 *);
	int (*release_dquot)(struct dquot___216 *);
	int (*mark_dirty)(struct dquot___216 *);
	int (*write_info)(struct super_block___216 *, int);
	qsize_t * (*get_reserved_space)(struct inode___217 *);
	int (*get_projid)(struct inode___217 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___217 *, qsize_t *);
	int (*get_next_id)(struct super_block___216 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___216 {
	int (*quota_on)(struct super_block___216 *, int, int, const struct path___216 *);
	int (*quota_off)(struct super_block___216 *, int);
	int (*quota_enable)(struct super_block___216 *, unsigned int);
	int (*quota_disable)(struct super_block___216 *, unsigned int);
	int (*quota_sync)(struct super_block___216 *, int);
	int (*set_info)(struct super_block___216 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___216 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___216 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___216 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___216 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___216 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___103;

struct address_space_operations___216 {
	int (*writepage)(struct page___217 *, struct writeback_control___103 *);
	int (*readpage)(struct file___217 *, struct page___217 *);
	int (*writepages)(struct address_space___216 *, struct writeback_control___103 *);
	int (*set_page_dirty)(struct page___217 *);
	int (*readpages)(struct file___217 *, struct address_space___216 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___217 *, struct address_space___216 *, loff_t, unsigned int, unsigned int, struct page___217 **, void **);
	int (*write_end)(struct file___217 *, struct address_space___216 *, loff_t, unsigned int, unsigned int, struct page___217 *, void *);
	sector_t (*bmap)(struct address_space___216 *, sector_t);
	void (*invalidatepage)(struct page___217 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___217 *, gfp_t);
	void (*freepage)(struct page___217 *);
	ssize_t (*direct_IO)(struct kiocb___217 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___216 *, struct page___217 *, struct page___217 *, enum migrate_mode);
	bool (*isolate_page)(struct page___217 *, isolate_mode_t);
	void (*putback_page)(struct page___217 *);
	int (*launder_page)(struct page___217 *);
	int (*is_partially_uptodate)(struct page___217 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___217 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___216 *, struct page___217 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___217 *, sector_t *);
	void (*swap_deactivate)(struct file___217 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___103 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___107 *wb;
	struct inode___217 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct hd_struct___53;

struct gendisk___53;

struct block_device___217 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___217 *bd_inode;
	struct super_block___216 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___217 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___53 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___53 *bd_disk;
	struct request_queue___53 *bd_queue;
	struct backing_dev_info___107 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct hd_struct___53 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___188 __dev;
	struct kobject___205 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___53;

struct block_device_operations___53;

struct gendisk___53 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___53 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___53 *part_tbl;
	struct hd_struct___53 part0;
	const struct block_device_operations___53 *fops;
	struct request_queue___53 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___217 lookup_sem;
	struct kobject___205 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___205 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___216 {
	struct dentry___216 * (*lookup)(struct inode___217 *, struct dentry___216 *, unsigned int);
	const char * (*get_link)(struct dentry___216 *, struct inode___217 *, struct delayed_call *);
	int (*permission)(struct inode___217 *, int);
	struct posix_acl * (*get_acl)(struct inode___217 *, int);
	int (*readlink)(struct dentry___216 *, char *, int);
	int (*create)(struct inode___217 *, struct dentry___216 *, umode_t, bool);
	int (*link)(struct dentry___216 *, struct inode___217 *, struct dentry___216 *);
	int (*unlink)(struct inode___217 *, struct dentry___216 *);
	int (*symlink)(struct inode___217 *, struct dentry___216 *, const char *);
	int (*mkdir)(struct inode___217 *, struct dentry___216 *, umode_t);
	int (*rmdir)(struct inode___217 *, struct dentry___216 *);
	int (*mknod)(struct inode___217 *, struct dentry___216 *, umode_t, dev_t);
	int (*rename)(struct inode___217 *, struct dentry___216 *, struct inode___217 *, struct dentry___216 *, unsigned int);
	int (*setattr)(struct dentry___216 *, struct iattr___216 *);
	int (*getattr)(const struct path___216 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___216 *, char *, size_t);
	int (*fiemap)(struct inode___217 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___217 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___217 *, struct dentry___216 *, struct file___217 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___217 *, struct dentry___216 *, umode_t);
	int (*set_acl)(struct inode___217 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___216 {
	void (*fl_copy_lock)(struct file_lock___217 *, struct file_lock___217 *);
	void (*fl_release_private)(struct file_lock___217 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___216;

struct lock_manager_operations___216;

struct file_lock___217 {
	struct file_lock___217 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___217 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___216 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___216 *fl_ops;
	const struct lock_manager_operations___216 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___216 {
	int (*lm_compare_owner)(struct file_lock___217 *, struct file_lock___217 *);
	long unsigned int (*lm_owner_key)(struct file_lock___217 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___217 *);
	int (*lm_grant)(struct file_lock___217 *, int);
	bool (*lm_break)(struct file_lock___217 *);
	int (*lm_change)(struct file_lock___217 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___217 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___216 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___216 *fa_next;
	struct file___217 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___216 {
	const char *name;
	int fs_flags;
	struct dentry___216 * (*mount)(struct file_system_type___216 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___216 *);
	struct module___11 *owner;
	struct file_system_type___216 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___216 {
	struct inode___217 * (*alloc_inode)(struct super_block___216 *);
	void (*destroy_inode)(struct inode___217 *);
	void (*dirty_inode)(struct inode___217 *, int);
	int (*write_inode)(struct inode___217 *, struct writeback_control___103 *);
	int (*drop_inode)(struct inode___217 *);
	void (*evict_inode)(struct inode___217 *);
	void (*put_super)(struct super_block___216 *);
	int (*sync_fs)(struct super_block___216 *, int);
	int (*freeze_super)(struct super_block___216 *);
	int (*freeze_fs)(struct super_block___216 *);
	int (*thaw_super)(struct super_block___216 *);
	int (*unfreeze_fs)(struct super_block___216 *);
	int (*statfs)(struct dentry___216 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___216 *, int *, char *);
	void (*umount_begin)(struct super_block___216 *);
	int (*show_options)(struct seq_file___197 *, struct dentry___216 *);
	int (*show_devname)(struct seq_file___197 *, struct dentry___216 *);
	int (*show_path)(struct seq_file___197 *, struct dentry___216 *);
	int (*show_stats)(struct seq_file___197 *, struct dentry___216 *);
	ssize_t (*quota_read)(struct super_block___216 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___216 *, int, const char *, size_t, loff_t);
	struct dquot___216 ** (*get_dquots)(struct inode___217 *);
	int (*bdev_try_to_free_page)(struct super_block___216 *, struct page___217 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___216 *, struct shrink_control___95 *);
	long int (*free_cached_objects)(struct super_block___216 *, struct shrink_control___95 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct xattr_handler___19 {
	const char *name;
	const char *prefix;
	int flags;
	bool (*list)(struct dentry___216 *);
	int (*get)(const struct xattr_handler___19 *, struct dentry___216 *, struct inode___217 *, const char *, void *, size_t);
	int (*set)(const struct xattr_handler___19 *, struct dentry___216 *, struct inode___217 *, const char *, const void *, size_t, int);
};

struct seq_operations___195;

struct seq_file___197 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___195 *op;
	int poll_event;
	const struct file___217 *file;
	void *private;
};

typedef void bio_end_io_t___107(struct bio___107 *);

struct bio_vec___107 {
	struct page___217 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___107;

struct bio___107 {
	struct bio___107 *bi_next;
	struct gendisk___53 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___107 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___41 *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___107 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___107 *bi_io_vec;
	struct bio_set___107 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___107 bi_inline_vecs[0];
};

struct kobj_attribute___202 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___205 *, struct kobj_attribute___202 *, char *);
	ssize_t (*store)(struct kobject___205 *, struct kobj_attribute___202 *, const char *, size_t);
};

typedef void compound_page_dtor___211(struct page___217 *);

struct bio_integrity_payload___107 {
	struct bio___107 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___107 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___107 bip_inline_vecs[0];
};

struct blkcg___41;

struct blkg_policy_data___41;

struct blkcg_gq___41 {
	struct request_queue___53 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___41 *blkcg;
	struct bdi_writeback_congested___107 *wb_congested;
	struct blkcg_gq___41 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_rwstat stat_bytes;
	struct blkg_rwstat stat_ios;
	struct blkg_policy_data___41 *pd[5];
	struct callback_head callback_head;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
};

struct dev_pm_ops___188;

struct device_type___188 {
	const char *name;
	const struct attribute_group___190 **groups;
	int (*uevent)(struct device___188 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___188 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___188 *);
	const struct dev_pm_ops___188 *pm;
};

struct class___188 {
	const char *name;
	struct module___11 *owner;
	const struct attribute_group___190 **class_groups;
	const struct attribute_group___190 **dev_groups;
	struct kobject___205 *dev_kobj;
	int (*dev_uevent)(struct device___188 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___188 *, umode_t *);
	void (*class_release)(struct class___188 *);
	void (*dev_release)(struct device___188 *);
	int (*shutdown_pre)(struct device___188 *);
	const struct kobj_ns_type_operations___12 *ns_type;
	const void * (*namespace)(struct device___188 *);
	const struct dev_pm_ops___188 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

enum kernfs_node_flag {
	KERNFS_ACTIVATED = 16,
	KERNFS_NS = 32,
	KERNFS_HAS_SEQ_SHOW = 64,
	KERNFS_HAS_MMAP = 128,
	KERNFS_LOCKDEP = 256,
	KERNFS_SUICIDAL = 1024,
	KERNFS_SUICIDED = 2048,
	KERNFS_EMPTY_DIR = 4096,
	KERNFS_HAS_RELEASE = 8192,
};

struct kernfs_root___210;

struct kernfs_elem_dir___210 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___210 *root;
};

struct kernfs_syscall_ops___210;

struct kernfs_root___210 {
	struct kernfs_node___210 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___210 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___210 {
	struct kernfs_node___210 *target_kn;
};

struct kernfs_ops___210;

struct kernfs_elem_attr___210 {
	const struct kernfs_ops___210 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___210 *notify_next;
};

struct kernfs_node___210 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___210 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___210 dir;
		struct kernfs_elem_symlink___210 symlink;
		struct kernfs_elem_attr___210 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___210;

struct kernfs_ops___210 {
	int (*open)(struct kernfs_open_file___210 *);
	void (*release)(struct kernfs_open_file___210 *);
	int (*seq_show)(struct seq_file___197 *, void *);
	void * (*seq_start)(struct seq_file___197 *, loff_t *);
	void * (*seq_next)(struct seq_file___197 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___197 *, void *);
	ssize_t (*read)(struct kernfs_open_file___210 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___210 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___210 *, struct vm_area_struct___217 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___210 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___210 {
	int (*remount_fs)(struct kernfs_root___210 *, int *, char *);
	int (*show_options)(struct seq_file___197 *, struct kernfs_root___210 *);
	int (*mkdir)(struct kernfs_node___210 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___210 *);
	int (*rename)(struct kernfs_node___210 *, struct kernfs_node___210 *, const char *);
	int (*show_path)(struct seq_file___197 *, struct kernfs_node___210 *, struct kernfs_root___210 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___210 {
	struct kernfs_node___210 *kn;
	struct file___217 *file;
	struct seq_file___197 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___211 *vm_ops;
};

struct bin_attribute___189;

struct attribute_group___190 {
	const char *name;
	umode_t (*is_visible)(struct kobject___205 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___205 *, struct bin_attribute___189 *, int);
	struct attribute **attrs;
	struct bin_attribute___189 **bin_attrs;
};

struct bin_attribute___189 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___217 *, struct kobject___205 *, struct bin_attribute___189 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___217 *, struct kobject___205 *, struct bin_attribute___189 *, char *, loff_t, size_t);
	int (*mmap)(struct file___217 *, struct kobject___205 *, struct bin_attribute___189 *, struct vm_area_struct___217 *);
};

struct sysfs_ops___204 {
	ssize_t (*show)(struct kobject___205 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___205 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___204;

struct kset___204 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___205 kobj;
	const struct kset_uevent_ops___204 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___204 {
	void (*release)(struct kobject___205 *);
	const struct sysfs_ops___204 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___12 * (*child_ns_type)(struct kobject___205 *);
	const void * (*namespace)(struct kobject___205 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___204 {
	int (* const filter)(struct kset___204 *, struct kobject___205 *);
	const char * (* const name)(struct kset___204 *, struct kobject___205 *);
	int (* const uevent)(struct kset___204 *, struct kobject___205 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___188 {
	int (*prepare)(struct device___188 *);
	void (*complete)(struct device___188 *);
	int (*suspend)(struct device___188 *);
	int (*resume)(struct device___188 *);
	int (*freeze)(struct device___188 *);
	int (*thaw)(struct device___188 *);
	int (*poweroff)(struct device___188 *);
	int (*restore)(struct device___188 *);
	int (*suspend_late)(struct device___188 *);
	int (*resume_early)(struct device___188 *);
	int (*freeze_late)(struct device___188 *);
	int (*thaw_early)(struct device___188 *);
	int (*poweroff_late)(struct device___188 *);
	int (*restore_early)(struct device___188 *);
	int (*suspend_noirq)(struct device___188 *);
	int (*resume_noirq)(struct device___188 *);
	int (*freeze_noirq)(struct device___188 *);
	int (*thaw_noirq)(struct device___188 *);
	int (*poweroff_noirq)(struct device___188 *);
	int (*restore_noirq)(struct device___188 *);
	int (*runtime_suspend)(struct device___188 *);
	int (*runtime_resume)(struct device___188 *);
	int (*runtime_idle)(struct device___188 *);
};

struct dev_pm_domain___188 {
	struct dev_pm_ops___188 ops;
	void (*detach)(struct device___188 *, bool);
	int (*activate)(struct device___188 *);
	void (*sync)(struct device___188 *);
	void (*dismiss)(struct device___188 *);
};

struct bus_type___188 {
	const char *name;
	const char *dev_name;
	struct device___188 *dev_root;
	const struct attribute_group___190 **bus_groups;
	const struct attribute_group___190 **dev_groups;
	const struct attribute_group___190 **drv_groups;
	int (*match)(struct device___188 *, struct device_driver___188 *);
	int (*uevent)(struct device___188 *, struct kobj_uevent_env *);
	int (*probe)(struct device___188 *);
	int (*remove)(struct device___188 *);
	void (*shutdown)(struct device___188 *);
	int (*online)(struct device___188 *);
	int (*offline)(struct device___188 *);
	int (*suspend)(struct device___188 *, pm_message_t);
	int (*resume)(struct device___188 *);
	int (*num_vf)(struct device___188 *);
	int (*dma_configure)(struct device___188 *);
	const struct dev_pm_ops___188 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___188 {
	const char *name;
	struct bus_type___188 *bus;
	struct module___11 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___188 *);
	int (*remove)(struct device___188 *);
	void (*shutdown)(struct device___188 *);
	int (*suspend)(struct device___188 *, pm_message_t);
	int (*resume)(struct device___188 *);
	const struct attribute_group___190 **groups;
	const struct dev_pm_ops___188 *pm;
	void (*coredump)(struct device___188 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct fwnode_operations___131;

struct fwnode_handle___131 {
	struct fwnode_handle___131 *secondary;
	const struct fwnode_operations___131 *ops;
};

struct disk_part_tbl___53 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___53 *last_lookup;
	struct hd_struct___53 *part[0];
};

struct block_device_operations___53 {
	int (*open)(struct block_device___217 *, fmode_t);
	void (*release)(struct gendisk___53 *, fmode_t);
	int (*rw_page)(struct block_device___217 *, sector_t, struct page___217 *, unsigned int);
	int (*ioctl)(struct block_device___217 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___217 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___53 *, unsigned int);
	int (*media_changed)(struct gendisk___53 *);
	void (*unlock_native_capacity)(struct gendisk___53 *);
	int (*revalidate_disk)(struct gendisk___53 *);
	int (*getgeo)(struct block_device___217 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___217 *, long unsigned int);
	int (*report_zones)(struct gendisk___53 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___11 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bdi_writeback_congested___107 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___107 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct cgroup_subsys___172;

struct cgroup_subsys_state___173 {
	struct cgroup___172 *cgroup;
	struct cgroup_subsys___172 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___173 *parent;
};

struct bsg_ops___52 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___53 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___53 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___53 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___52(struct request___53 *, blk_status_t);

struct request___53 {
	struct request_queue___53 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___107 *bio;
	struct bio___107 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___107 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___56 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___52 *saved_end_io;
		} flush;
	};
	struct gendisk___53 *rq_disk;
	struct hd_struct___53 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___52 *end_io;
	void *end_io_data;
	struct request___53 *next_rq;
};

struct fwnode_reference_args___131;

struct fwnode_endpoint___131;

struct fwnode_operations___131 {
	struct fwnode_handle___131 * (*get)(struct fwnode_handle___131 *);
	void (*put)(struct fwnode_handle___131 *);
	bool (*device_is_available)(const struct fwnode_handle___131 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___131 *, const struct device___188 *);
	bool (*property_present)(const struct fwnode_handle___131 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___131 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___131 *, const char *, const char **, size_t);
	struct fwnode_handle___131 * (*get_parent)(const struct fwnode_handle___131 *);
	struct fwnode_handle___131 * (*get_next_child_node)(const struct fwnode_handle___131 *, struct fwnode_handle___131 *);
	struct fwnode_handle___131 * (*get_named_child_node)(const struct fwnode_handle___131 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___131 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___131 *);
	struct fwnode_handle___131 * (*graph_get_next_endpoint)(const struct fwnode_handle___131 *, struct fwnode_handle___131 *);
	struct fwnode_handle___131 * (*graph_get_remote_endpoint)(const struct fwnode_handle___131 *);
	struct fwnode_handle___131 * (*graph_get_port_parent)(struct fwnode_handle___131 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___131 *, struct fwnode_endpoint___131 *);
};

struct fwnode_endpoint___131 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___131 *local_fwnode;
};

struct fwnode_reference_args___131 {
	struct fwnode_handle___131 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct elevator_type___52;

struct elevator_mq_ops___52 {
	int (*init_sched)(struct request_queue___53 *, struct elevator_type___52 *);
	void (*exit_sched)(struct elevator_queue___52 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	bool (*allow_merge)(struct request_queue___53 *, struct request___53 *, struct bio___107 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx *, struct bio___107 *);
	int (*request_merge)(struct request_queue___53 *, struct request___53 **, struct bio___107 *);
	void (*request_merged)(struct request_queue___53 *, struct request___53 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___53 *, struct request___53 *, struct request___53 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___53 *, struct bio___107 *);
	void (*finish_request)(struct request___53 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___53 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___53 *, u64);
	void (*started_request)(struct request___53 *);
	void (*requeue_request)(struct request___53 *);
	struct request___53 * (*former_request)(struct request_queue___53 *, struct request___53 *);
	struct request___53 * (*next_request)(struct request_queue___53 *, struct request___53 *);
	void (*init_icq)(struct io_cq___56 *);
	void (*exit_icq)(struct io_cq___56 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___52;

struct elevator_type___52 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___52 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___52 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___11 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___52 {
	struct elevator_type___52 *type;
	void *elevator_data;
	struct kobject___205 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___52 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___52 *, char *);
	ssize_t (*store)(struct elevator_queue___52 *, const char *, size_t);
};

typedef int (*key_restrict_link_func_t___210)(struct key___210 *, const struct key_type *, const union key_payload *, struct key___210 *);

struct key_restriction___210;

struct key___210 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___217 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___210 *restrict_link;
};

struct key_restriction___210 {
	key_restrict_link_func_t___210 check;
	struct key___210 *key;
	struct key_type *keytype;
};

struct seq_operations___195 {
	void * (*start)(struct seq_file___197 *, loff_t *);
	void (*stop)(struct seq_file___197 *, void *);
	void * (*next)(struct seq_file___197 *, void *, loff_t *);
	int (*show)(struct seq_file___197 *, void *);
};

struct cgroup_namespace___172 {
	refcount_t count;
	struct ns_common___27 ns;
	struct user_namespace___183 *user_ns;
	struct ucounts___183 *ucounts;
	struct css_set___172 *root_cset;
};

struct ucounts___183 {
	struct hlist_node node;
	struct user_namespace___183 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___172;

struct bpf_map_ops___172 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___172 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___172 *, struct file___217 *);
	void (*map_free)(struct bpf_map___172 *);
	int (*map_get_next_key)(struct bpf_map___172 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___172 *);
	void * (*map_lookup_elem)(struct bpf_map___172 *, void *);
	int (*map_update_elem)(struct bpf_map___172 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___172 *, void *);
	int (*map_push_elem)(struct bpf_map___172 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___172 *, void *);
	int (*map_peek_elem)(struct bpf_map___172 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___172 *, struct file___217 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___172 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___172 *, void *, struct seq_file___197 *);
	int (*map_check_btf)(const struct bpf_map___172 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___172 {
	const struct bpf_map_ops___172 *ops;
	struct bpf_map___172 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___210 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___172;

typedef void (*kthread_work_func_t___172)(struct kthread_work___172 *);

struct kthread_worker___172;

struct kthread_work___172 {
	struct list_head node;
	kthread_work_func_t___172 func;
	struct kthread_worker___172 *worker;
	int canceling;
};

struct kthread_worker___172 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___217 *task;
	struct kthread_work___172 *current_work;
};

struct kthread_delayed_work___172 {
	struct kthread_work___172 work;
	struct timer_list timer;
};

struct psi_group___172 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___172 *poll_kworker;
	struct kthread_delayed_work___172 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___172 {
	struct kernfs_node___210 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_root___172;

struct cgroup_rstat_cpu___172;

struct cgroup___172 {
	struct cgroup_subsys_state___173 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___210 *kn;
	struct cgroup_file___172 procs_file;
	struct cgroup_file___172 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___173 *subsys[13];
	struct cgroup_root___172 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___172 *dom_cgrp;
	struct cgroup_rstat_cpu___172 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___22 bpf;
	atomic_t congestion_count;
	struct cgroup___172 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___172 psi;
	int ancestor_ids[0];
};

struct cftype___172;

struct cgroup_subsys___172 {
	struct cgroup_subsys_state___173 * (*css_alloc)(struct cgroup_subsys_state___173 *);
	int (*css_online)(struct cgroup_subsys_state___173 *);
	void (*css_offline)(struct cgroup_subsys_state___173 *);
	void (*css_released)(struct cgroup_subsys_state___173 *);
	void (*css_free)(struct cgroup_subsys_state___173 *);
	void (*css_reset)(struct cgroup_subsys_state___173 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___173 *, int);
	int (*css_extra_stat_show)(struct seq_file___197 *, struct cgroup_subsys_state___173 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___217 *);
	void (*cancel_fork)(struct task_struct___217 *);
	void (*fork)(struct task_struct___217 *);
	void (*exit)(struct task_struct___217 *);
	void (*free)(struct task_struct___217 *);
	void (*bind)(struct cgroup_subsys_state___173 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___172 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___172 *dfl_cftypes;
	struct cftype___172 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___172 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___172 *updated_children;
	struct cgroup___172 *updated_next;
};

struct cgroup_root___172 {
	struct kernfs_root___210 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___172 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___172 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___172 *ss;
	struct list_head node;
	struct kernfs_ops___210 *kf_ops;
	int (*open)(struct kernfs_open_file___210 *);
	void (*release)(struct kernfs_open_file___210 *);
	u64 (*read_u64)(struct cgroup_subsys_state___173 *, struct cftype___172 *);
	s64 (*read_s64)(struct cgroup_subsys_state___173 *, struct cftype___172 *);
	int (*seq_show)(struct seq_file___197 *, void *);
	void * (*seq_start)(struct seq_file___197 *, loff_t *);
	void * (*seq_next)(struct seq_file___197 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___197 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___173 *, struct cftype___172 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___173 *, struct cftype___172 *, s64);
	ssize_t (*write)(struct kernfs_open_file___210 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___210 *, struct poll_table_struct___6 *);
};

struct blkcg_policy_data___41;

struct blkcg___41 {
	struct cgroup_subsys_state___173 css;
	spinlock_t lock;
	struct xarray blkg_tree;
	struct blkcg_gq___41 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___41 *cpd[5];
	struct list_head all_blkcgs_node;
	struct list_head cgwb_list;
	refcount_t cgwb_refcnt;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct blkcg_policy_data___41 {
	struct blkcg___41 *blkcg;
	int plid;
};

struct blkg_policy_data___41 {
	struct blkcg_gq___41 *blkg;
	int plid;
};

typedef struct poll_table_struct___108 poll_table___20;

struct kernfs_open_node {
	atomic_t refcnt;
	atomic_t event;
	wait_queue_head_t poll;
	struct list_head files;
};

struct kernfs_super_info___2 {
	struct super_block___160 *sb;
	struct kernfs_root___157 *root;
	const void *ns;
	struct list_head node;
};

struct kernfs_root___211;

struct kernfs_elem_dir___211 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___211 *root;
};

struct kernfs_node___211;

struct kernfs_syscall_ops___211;

struct kernfs_root___211 {
	struct kernfs_node___211 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___211 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___211 {
	struct kernfs_node___211 *target_kn;
};

struct kernfs_ops___211;

struct kernfs_elem_attr___211 {
	const struct kernfs_ops___211 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___211 *notify_next;
};

struct kernfs_node___211 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___211 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___211 dir;
		struct kernfs_elem_symlink___211 symlink;
		struct kernfs_elem_attr___211 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___211;

struct kernfs_ops___211 {
	int (*open)(struct kernfs_open_file___211 *);
	void (*release)(struct kernfs_open_file___211 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___211 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___211 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___211 *, struct vm_area_struct___217 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___211 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___211 {
	int (*remount_fs)(struct kernfs_root___211 *, int *, char *);
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___211 *);
	int (*mkdir)(struct kernfs_node___211 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___211 *);
	int (*rename)(struct kernfs_node___211 *, struct kernfs_node___211 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___211 *, struct kernfs_root___211 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___211 {
	struct kernfs_node___211 *kn;
	struct file___217 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___13 *vm_ops;
};

struct file___218;

struct kiocb___218;

struct vm_area_struct___218;

struct inode___218;

struct file_lock___218;

struct page___218;

struct seq_file___198;

struct file_operations___218 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___218 *, loff_t, int);
	ssize_t (*read)(struct file___218 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___218 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___218 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___218 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___218 *, bool);
	int (*iterate)(struct file___218 *, struct dir_context *);
	int (*iterate_shared)(struct file___218 *, struct dir_context *);
	__poll_t (*poll)(struct file___218 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___218 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___218 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___218 *, struct vm_area_struct___218 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___218 *, struct file___218 *);
	int (*flush)(struct file___218 *, fl_owner_t);
	int (*release)(struct inode___218 *, struct file___218 *);
	int (*fsync)(struct file___218 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___218 *, int);
	int (*lock)(struct file___218 *, int, struct file_lock___218 *);
	ssize_t (*sendpage)(struct file___218 *, struct page___218 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___218 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___218 *, int, struct file_lock___218 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___218 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___218 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___218 *, long int, struct file_lock___218 **, void **);
	long int (*fallocate)(struct file___218 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___198 *, struct file___218 *);
	ssize_t (*copy_file_range)(struct file___218 *, loff_t, struct file___218 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___218 *, loff_t, struct file___218 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___218 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___217 {
	u64 seqnum;
	struct vm_area_struct___218 *vmas[4];
};

struct page_frag___217 {
	struct page___218 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___217;

struct cred___211;

struct nsproxy___202;

struct bio_list___108;

struct backing_dev_info___108;

struct io_context___57;

struct css_set___173;

struct request_queue___54;

struct vm_struct___148;

struct task_struct___218 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___218 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___217 *mm;
	struct mm_struct___217 *active_mm;
	struct vmacache___217 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___218 *real_parent;
	struct task_struct___218 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___218 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___166 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___166 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___166 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___211 *ptracer_cred;
	const struct cred___211 *real_cred;
	const struct cred___211 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___202 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___218 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___108 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___108 *backing_dev_info;
	struct io_context___57 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___173 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___217 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___54 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___218 *oom_reaper_list;
	struct vm_struct___148 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___120 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___218 *pgtable_t___217;

struct address_space___217;

struct dev_pagemap___212;

struct page___218 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___217 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___218 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___217 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___217 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___212 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___217;

struct lruvec___217 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___217 *pgdat;
};

struct zone___217 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___217 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___217 {
	struct zone___217 *zone;
	int zone_idx;
};

struct zonelist___217 {
	struct zoneref___217 _zonerefs[25];
};

struct pglist_data___217 {
	struct zone___217 node_zones[3];
	struct zonelist___217 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___218 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___218 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___217 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___218 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___218 *owner;
};

struct secondary_data___218 {
	void *stack;
	struct task_struct___218 *task;
	long int status;
};

struct blocking_notifier_head___217 {
	struct rw_semaphore___218 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___212;

struct vm_area_struct___218 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___218 *vm_next;
	struct vm_area_struct___218 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___217 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___212 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___218 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___217;

struct user_namespace___184;

struct mm_struct___217 {
	struct {
		struct vm_area_struct___218 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___218 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___218 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___217 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___218 *owner;
		struct user_namespace___184 *user_ns;
		struct file___218 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___217 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___217;

struct address_space___217 {
	struct inode___218 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___218 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___217 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___212)(struct vm_area_struct___218 *, long unsigned int, const struct page___218 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___212)(struct page___218 *, void *);

struct device___189;

struct dev_pagemap___212 {
	dev_page_fault_t___212 page_fault;
	dev_page_free_t___212 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___189 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct dentry___217;

struct path___217 {
	struct vfsmount *mnt;
	struct dentry___217 *dentry;
};

struct file___218 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___217 f_path;
	struct inode___218 *f_inode;
	const struct file_operations___218 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___166 f_owner;
	const struct cred___211 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___217 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___212;

struct vm_operations_struct___212 {
	void (*open)(struct vm_area_struct___218 *);
	void (*close)(struct vm_area_struct___218 *);
	int (*split)(struct vm_area_struct___218 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___218 *);
	vm_fault_t (*fault)(struct vm_fault___212 *);
	vm_fault_t (*huge_fault)(struct vm_fault___212 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___212 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___218 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___212 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___212 *);
	int (*access)(struct vm_area_struct___218 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___218 *);
	int (*set_policy)(struct vm_area_struct___218 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___218 *, long unsigned int);
	struct page___218 * (*find_special_page)(struct vm_area_struct___218 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___217 {
	struct task_struct___218 *task;
	struct core_thread___217 *next;
};

struct core_state___217 {
	atomic_t nr_threads;
	struct core_thread___217 dumper;
	struct completion startup;
};

struct key___211;

struct ucounts___184;

struct user_namespace___184 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___184 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___27 ns;
	long unsigned int flags;
	struct key___211 *persistent_keyring_register;
	struct rw_semaphore___218 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___184 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___212 {
	struct vm_area_struct___218 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___218 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___218 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___217 prealloc_pte;
};

struct user_struct___211 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___211 *uid_keyring;
	struct key___211 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___211 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___211 *session_keyring;
	struct key___211 *process_keyring;
	struct key___211 *thread_keyring;
	struct key___211 *request_key_auth;
	void *security;
	struct user_struct___211 *user;
	struct user_namespace___184 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___173;

struct nsproxy___202 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___173 *cgroup_ns;
};

struct bio___108;

struct bio_list___108 {
	struct bio___108 *head;
	struct bio___108 *tail;
};

struct bdi_writeback_congested___108;

struct cgroup_subsys_state___174;

struct bdi_writeback___108 {
	struct backing_dev_info___108 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___108 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___174 *memcg_css;
	struct cgroup_subsys_state___174 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___108 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___108 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___189 *dev;
	struct device___189 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___217 *debug_dir;
	struct dentry___217 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___57;

struct io_context___57 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___57 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___173;

struct css_set___173 {
	struct cgroup_subsys_state___174 *subsys[13];
	refcount_t refcount;
	struct css_set___173 *dom_cset;
	struct cgroup___173 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___173 *mg_src_cgrp;
	struct cgroup___173 *mg_dst_cgrp;
	struct css_set___173 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

typedef blk_qc_t make_request_fn___53(struct request_queue___54 *, struct bio___108 *);

struct request___54;

typedef int dma_drain_needed_fn___53(struct request___54 *);

struct kset___205;

struct kobj_type___205;

struct kernfs_node___212;

struct kobject___206 {
	const char *name;
	struct list_head entry;
	struct kobject___206 *parent;
	struct kset___205 *kset;
	struct kobj_type___205 *ktype;
	struct kernfs_node___212 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___53;

struct bsg_class_device___53 {
	struct device___189 *class_dev;
	int minor;
	struct request_queue___54 *queue;
	const struct bsg_ops___53 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___108 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___108 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___53;

struct blkcg_gq___42;

struct request_queue___54 {
	struct list_head queue_head;
	struct request___54 *last_merge;
	struct elevator_queue___53 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___53 *make_request_fn;
	dma_drain_needed_fn___53 *dma_drain_needed;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___108 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___206 kobj;
	struct kobject___206 *mq_kobj;
	struct blk_integrity integrity;
	struct device___189 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___42 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	struct bsg_class_device___53 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___108 bio_split;
	struct dentry___217 *debugfs_dir;
	struct dentry___217 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___148 {
	struct vm_struct___148 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___218 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dev_pm_info___189 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___189 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___189;

struct bus_type___189;

struct device_driver___189;

struct dev_pm_domain___189;

struct fwnode_handle___132;

struct class___189;

struct attribute_group___191;

struct device___189 {
	struct device___189 *parent;
	struct device_private *p;
	struct kobject___206 kobj;
	const char *init_name;
	const struct device_type___189 *type;
	struct mutex mutex;
	struct bus_type___189 *bus;
	struct device_driver___189 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___189 power;
	struct dev_pm_domain___189 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___132 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___189 *class;
	const struct attribute_group___191 **groups;
	void (*release)(struct device___189 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___217;

struct super_block___217;

struct dentry___217 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___217 *d_parent;
	struct qstr d_name;
	struct inode___218 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___217 *d_op;
	struct super_block___217 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___217;

struct block_device___218;

struct inode___218 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___217 *i_op;
	struct super_block___217 *i_sb;
	struct address_space___217 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___218 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___108 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___218 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___217 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___218 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___217 {
	int (*d_revalidate)(struct dentry___217 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___217 *, unsigned int);
	int (*d_hash)(const struct dentry___217 *, struct qstr *);
	int (*d_compare)(const struct dentry___217 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___217 *);
	int (*d_init)(struct dentry___217 *);
	void (*d_release)(struct dentry___217 *);
	void (*d_prune)(struct dentry___217 *);
	void (*d_iput)(struct dentry___217 *, struct inode___218 *);
	char * (*d_dname)(struct dentry___217 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___217 *);
	int (*d_manage)(const struct path___217 *, bool);
	struct dentry___217 * (*d_real)(struct dentry___217 *, const struct inode___218 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___217;

struct mem_dqinfo___217 {
	struct quota_format_type___217 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___217;

struct quota_info___217 {
	unsigned int flags;
	struct rw_semaphore___218 dqio_sem;
	struct inode___218 *files[3];
	struct mem_dqinfo___217 info[3];
	const struct quota_format_ops___217 *ops[3];
};

struct rcuwait___217 {
	struct task_struct___218 *task;
};

struct percpu_rw_semaphore___217 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___218 rw_sem;
	struct rcuwait___217 writer;
	int readers_block;
};

struct sb_writers___217 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___217 rw_sem[3];
};

struct file_system_type___217;

struct super_operations___217;

struct dquot_operations___217;

struct quotactl_ops___217;

struct super_block___217 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___217 *s_type;
	const struct super_operations___217 *s_op;
	const struct dquot_operations___217 *dq_op;
	const struct quotactl_ops___217 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___217 *s_root;
	struct rw_semaphore___218 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___218 *s_bdev;
	struct backing_dev_info___108 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___217 s_dquot;
	struct sb_writers___217 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___217 *s_d_op;
	int cleancache_poolid;
	struct shrinker___95 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___184 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct io_cq___57 {
	struct request_queue___54 *q;
	struct io_context___57 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___6 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___218 {
	struct file___218 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___218 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___217 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___218 *ia_file;
};

struct dquot___217 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___217 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___217 {
	int qf_fmt_id;
	const struct quota_format_ops___217 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___217 *qf_next;
};

struct quota_format_ops___217 {
	int (*check_quota_file)(struct super_block___217 *, int);
	int (*read_file_info)(struct super_block___217 *, int);
	int (*write_file_info)(struct super_block___217 *, int);
	int (*free_file_info)(struct super_block___217 *, int);
	int (*read_dqblk)(struct dquot___217 *);
	int (*commit_dqblk)(struct dquot___217 *);
	int (*release_dqblk)(struct dquot___217 *);
	int (*get_next_id)(struct super_block___217 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___217 {
	int (*write_dquot)(struct dquot___217 *);
	struct dquot___217 * (*alloc_dquot)(struct super_block___217 *, int);
	void (*destroy_dquot)(struct dquot___217 *);
	int (*acquire_dquot)(struct dquot___217 *);
	int (*release_dquot)(struct dquot___217 *);
	int (*mark_dirty)(struct dquot___217 *);
	int (*write_info)(struct super_block___217 *, int);
	qsize_t * (*get_reserved_space)(struct inode___218 *);
	int (*get_projid)(struct inode___218 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___218 *, qsize_t *);
	int (*get_next_id)(struct super_block___217 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___217 {
	int (*quota_on)(struct super_block___217 *, int, int, const struct path___217 *);
	int (*quota_off)(struct super_block___217 *, int);
	int (*quota_enable)(struct super_block___217 *, unsigned int);
	int (*quota_disable)(struct super_block___217 *, unsigned int);
	int (*quota_sync)(struct super_block___217 *, int);
	int (*set_info)(struct super_block___217 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___217 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___217 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___217 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___217 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___217 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___104;

struct address_space_operations___217 {
	int (*writepage)(struct page___218 *, struct writeback_control___104 *);
	int (*readpage)(struct file___218 *, struct page___218 *);
	int (*writepages)(struct address_space___217 *, struct writeback_control___104 *);
	int (*set_page_dirty)(struct page___218 *);
	int (*readpages)(struct file___218 *, struct address_space___217 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___218 *, struct address_space___217 *, loff_t, unsigned int, unsigned int, struct page___218 **, void **);
	int (*write_end)(struct file___218 *, struct address_space___217 *, loff_t, unsigned int, unsigned int, struct page___218 *, void *);
	sector_t (*bmap)(struct address_space___217 *, sector_t);
	void (*invalidatepage)(struct page___218 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___218 *, gfp_t);
	void (*freepage)(struct page___218 *);
	ssize_t (*direct_IO)(struct kiocb___218 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___217 *, struct page___218 *, struct page___218 *, enum migrate_mode);
	bool (*isolate_page)(struct page___218 *, isolate_mode_t);
	void (*putback_page)(struct page___218 *);
	int (*launder_page)(struct page___218 *);
	int (*is_partially_uptodate)(struct page___218 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___218 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___217 *, struct page___218 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___218 *, sector_t *);
	void (*swap_deactivate)(struct file___218 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___104 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___108 *wb;
	struct inode___218 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct hd_struct___54;

struct gendisk___54;

struct block_device___218 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___218 *bd_inode;
	struct super_block___217 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___218 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___54 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___54 *bd_disk;
	struct request_queue___54 *bd_queue;
	struct backing_dev_info___108 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct hd_struct___54 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___189 __dev;
	struct kobject___206 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___54;

struct block_device_operations___54;

struct gendisk___54 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___54 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___54 *part_tbl;
	struct hd_struct___54 part0;
	const struct block_device_operations___54 *fops;
	struct request_queue___54 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___218 lookup_sem;
	struct kobject___206 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___206 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___217 {
	struct dentry___217 * (*lookup)(struct inode___218 *, struct dentry___217 *, unsigned int);
	const char * (*get_link)(struct dentry___217 *, struct inode___218 *, struct delayed_call *);
	int (*permission)(struct inode___218 *, int);
	struct posix_acl * (*get_acl)(struct inode___218 *, int);
	int (*readlink)(struct dentry___217 *, char *, int);
	int (*create)(struct inode___218 *, struct dentry___217 *, umode_t, bool);
	int (*link)(struct dentry___217 *, struct inode___218 *, struct dentry___217 *);
	int (*unlink)(struct inode___218 *, struct dentry___217 *);
	int (*symlink)(struct inode___218 *, struct dentry___217 *, const char *);
	int (*mkdir)(struct inode___218 *, struct dentry___217 *, umode_t);
	int (*rmdir)(struct inode___218 *, struct dentry___217 *);
	int (*mknod)(struct inode___218 *, struct dentry___217 *, umode_t, dev_t);
	int (*rename)(struct inode___218 *, struct dentry___217 *, struct inode___218 *, struct dentry___217 *, unsigned int);
	int (*setattr)(struct dentry___217 *, struct iattr___217 *);
	int (*getattr)(const struct path___217 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___217 *, char *, size_t);
	int (*fiemap)(struct inode___218 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___218 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___218 *, struct dentry___217 *, struct file___218 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___218 *, struct dentry___217 *, umode_t);
	int (*set_acl)(struct inode___218 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___217 {
	void (*fl_copy_lock)(struct file_lock___218 *, struct file_lock___218 *);
	void (*fl_release_private)(struct file_lock___218 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___217;

struct lock_manager_operations___217;

struct file_lock___218 {
	struct file_lock___218 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___218 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___217 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___217 *fl_ops;
	const struct lock_manager_operations___217 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___217 {
	int (*lm_compare_owner)(struct file_lock___218 *, struct file_lock___218 *);
	long unsigned int (*lm_owner_key)(struct file_lock___218 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___218 *);
	int (*lm_grant)(struct file_lock___218 *, int);
	bool (*lm_break)(struct file_lock___218 *);
	int (*lm_change)(struct file_lock___218 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___218 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___217 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___217 *fa_next;
	struct file___218 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___217 {
	const char *name;
	int fs_flags;
	struct dentry___217 * (*mount)(struct file_system_type___217 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___217 *);
	struct module___11 *owner;
	struct file_system_type___217 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___217 {
	struct inode___218 * (*alloc_inode)(struct super_block___217 *);
	void (*destroy_inode)(struct inode___218 *);
	void (*dirty_inode)(struct inode___218 *, int);
	int (*write_inode)(struct inode___218 *, struct writeback_control___104 *);
	int (*drop_inode)(struct inode___218 *);
	void (*evict_inode)(struct inode___218 *);
	void (*put_super)(struct super_block___217 *);
	int (*sync_fs)(struct super_block___217 *, int);
	int (*freeze_super)(struct super_block___217 *);
	int (*freeze_fs)(struct super_block___217 *);
	int (*thaw_super)(struct super_block___217 *);
	int (*unfreeze_fs)(struct super_block___217 *);
	int (*statfs)(struct dentry___217 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___217 *, int *, char *);
	void (*umount_begin)(struct super_block___217 *);
	int (*show_options)(struct seq_file___198 *, struct dentry___217 *);
	int (*show_devname)(struct seq_file___198 *, struct dentry___217 *);
	int (*show_path)(struct seq_file___198 *, struct dentry___217 *);
	int (*show_stats)(struct seq_file___198 *, struct dentry___217 *);
	ssize_t (*quota_read)(struct super_block___217 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___217 *, int, const char *, size_t, loff_t);
	struct dquot___217 ** (*get_dquots)(struct inode___218 *);
	int (*bdev_try_to_free_page)(struct super_block___217 *, struct page___218 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___217 *, struct shrink_control___95 *);
	long int (*free_cached_objects)(struct super_block___217 *, struct shrink_control___95 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___196;

struct seq_file___198 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___196 *op;
	int poll_event;
	const struct file___218 *file;
	void *private;
};

typedef void bio_end_io_t___108(struct bio___108 *);

struct bio_vec___108 {
	struct page___218 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___108;

struct bio___108 {
	struct bio___108 *bi_next;
	struct gendisk___54 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___108 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___42 *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___108 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___108 *bi_io_vec;
	struct bio_set___108 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___108 bi_inline_vecs[0];
};

struct kobj_attribute___203 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___206 *, struct kobj_attribute___203 *, char *);
	ssize_t (*store)(struct kobject___206 *, struct kobj_attribute___203 *, const char *, size_t);
};

typedef void compound_page_dtor___212(struct page___218 *);

struct bio_integrity_payload___108 {
	struct bio___108 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___108 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___108 bip_inline_vecs[0];
};

struct blkcg___42;

struct blkg_policy_data___42;

struct blkcg_gq___42 {
	struct request_queue___54 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___42 *blkcg;
	struct bdi_writeback_congested___108 *wb_congested;
	struct blkcg_gq___42 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_rwstat stat_bytes;
	struct blkg_rwstat stat_ios;
	struct blkg_policy_data___42 *pd[5];
	struct callback_head callback_head;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
};

struct dev_pm_ops___189;

struct device_type___189 {
	const char *name;
	const struct attribute_group___191 **groups;
	int (*uevent)(struct device___189 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___189 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___189 *);
	const struct dev_pm_ops___189 *pm;
};

struct class___189 {
	const char *name;
	struct module___11 *owner;
	const struct attribute_group___191 **class_groups;
	const struct attribute_group___191 **dev_groups;
	struct kobject___206 *dev_kobj;
	int (*dev_uevent)(struct device___189 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___189 *, umode_t *);
	void (*class_release)(struct class___189 *);
	void (*dev_release)(struct device___189 *);
	int (*shutdown_pre)(struct device___189 *);
	const struct kobj_ns_type_operations___12 *ns_type;
	const void * (*namespace)(struct device___189 *);
	const struct dev_pm_ops___189 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct kernfs_root___212;

struct kernfs_elem_dir___212 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___212 *root;
};

struct kernfs_syscall_ops___212;

struct kernfs_root___212 {
	struct kernfs_node___212 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___212 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___212 {
	struct kernfs_node___212 *target_kn;
};

struct kernfs_ops___212;

struct kernfs_elem_attr___212 {
	const struct kernfs_ops___212 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___212 *notify_next;
};

struct kernfs_node___212 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___212 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___212 dir;
		struct kernfs_elem_symlink___212 symlink;
		struct kernfs_elem_attr___212 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___212;

struct kernfs_ops___212 {
	int (*open)(struct kernfs_open_file___212 *);
	void (*release)(struct kernfs_open_file___212 *);
	int (*seq_show)(struct seq_file___198 *, void *);
	void * (*seq_start)(struct seq_file___198 *, loff_t *);
	void * (*seq_next)(struct seq_file___198 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___198 *, void *);
	ssize_t (*read)(struct kernfs_open_file___212 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___212 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___212 *, struct vm_area_struct___218 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___212 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___212 {
	int (*remount_fs)(struct kernfs_root___212 *, int *, char *);
	int (*show_options)(struct seq_file___198 *, struct kernfs_root___212 *);
	int (*mkdir)(struct kernfs_node___212 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___212 *);
	int (*rename)(struct kernfs_node___212 *, struct kernfs_node___212 *, const char *);
	int (*show_path)(struct seq_file___198 *, struct kernfs_node___212 *, struct kernfs_root___212 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___212 {
	struct kernfs_node___212 *kn;
	struct file___218 *file;
	struct seq_file___198 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___212 *vm_ops;
};

struct bin_attribute___190;

struct attribute_group___191 {
	const char *name;
	umode_t (*is_visible)(struct kobject___206 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___206 *, struct bin_attribute___190 *, int);
	struct attribute **attrs;
	struct bin_attribute___190 **bin_attrs;
};

struct bin_attribute___190 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___218 *, struct kobject___206 *, struct bin_attribute___190 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___218 *, struct kobject___206 *, struct bin_attribute___190 *, char *, loff_t, size_t);
	int (*mmap)(struct file___218 *, struct kobject___206 *, struct bin_attribute___190 *, struct vm_area_struct___218 *);
};

struct sysfs_ops___205 {
	ssize_t (*show)(struct kobject___206 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___206 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___205;

struct kset___205 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___206 kobj;
	const struct kset_uevent_ops___205 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___205 {
	void (*release)(struct kobject___206 *);
	const struct sysfs_ops___205 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___12 * (*child_ns_type)(struct kobject___206 *);
	const void * (*namespace)(struct kobject___206 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___205 {
	int (* const filter)(struct kset___205 *, struct kobject___206 *);
	const char * (* const name)(struct kset___205 *, struct kobject___206 *);
	int (* const uevent)(struct kset___205 *, struct kobject___206 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___189 {
	int (*prepare)(struct device___189 *);
	void (*complete)(struct device___189 *);
	int (*suspend)(struct device___189 *);
	int (*resume)(struct device___189 *);
	int (*freeze)(struct device___189 *);
	int (*thaw)(struct device___189 *);
	int (*poweroff)(struct device___189 *);
	int (*restore)(struct device___189 *);
	int (*suspend_late)(struct device___189 *);
	int (*resume_early)(struct device___189 *);
	int (*freeze_late)(struct device___189 *);
	int (*thaw_early)(struct device___189 *);
	int (*poweroff_late)(struct device___189 *);
	int (*restore_early)(struct device___189 *);
	int (*suspend_noirq)(struct device___189 *);
	int (*resume_noirq)(struct device___189 *);
	int (*freeze_noirq)(struct device___189 *);
	int (*thaw_noirq)(struct device___189 *);
	int (*poweroff_noirq)(struct device___189 *);
	int (*restore_noirq)(struct device___189 *);
	int (*runtime_suspend)(struct device___189 *);
	int (*runtime_resume)(struct device___189 *);
	int (*runtime_idle)(struct device___189 *);
};

struct dev_pm_domain___189 {
	struct dev_pm_ops___189 ops;
	void (*detach)(struct device___189 *, bool);
	int (*activate)(struct device___189 *);
	void (*sync)(struct device___189 *);
	void (*dismiss)(struct device___189 *);
};

struct bus_type___189 {
	const char *name;
	const char *dev_name;
	struct device___189 *dev_root;
	const struct attribute_group___191 **bus_groups;
	const struct attribute_group___191 **dev_groups;
	const struct attribute_group___191 **drv_groups;
	int (*match)(struct device___189 *, struct device_driver___189 *);
	int (*uevent)(struct device___189 *, struct kobj_uevent_env *);
	int (*probe)(struct device___189 *);
	int (*remove)(struct device___189 *);
	void (*shutdown)(struct device___189 *);
	int (*online)(struct device___189 *);
	int (*offline)(struct device___189 *);
	int (*suspend)(struct device___189 *, pm_message_t);
	int (*resume)(struct device___189 *);
	int (*num_vf)(struct device___189 *);
	int (*dma_configure)(struct device___189 *);
	const struct dev_pm_ops___189 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___189 {
	const char *name;
	struct bus_type___189 *bus;
	struct module___11 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___189 *);
	int (*remove)(struct device___189 *);
	void (*shutdown)(struct device___189 *);
	int (*suspend)(struct device___189 *, pm_message_t);
	int (*resume)(struct device___189 *);
	const struct attribute_group___191 **groups;
	const struct dev_pm_ops___189 *pm;
	void (*coredump)(struct device___189 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct fwnode_operations___132;

struct fwnode_handle___132 {
	struct fwnode_handle___132 *secondary;
	const struct fwnode_operations___132 *ops;
};

struct disk_part_tbl___54 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___54 *last_lookup;
	struct hd_struct___54 *part[0];
};

struct block_device_operations___54 {
	int (*open)(struct block_device___218 *, fmode_t);
	void (*release)(struct gendisk___54 *, fmode_t);
	int (*rw_page)(struct block_device___218 *, sector_t, struct page___218 *, unsigned int);
	int (*ioctl)(struct block_device___218 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___218 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___54 *, unsigned int);
	int (*media_changed)(struct gendisk___54 *);
	void (*unlock_native_capacity)(struct gendisk___54 *);
	int (*revalidate_disk)(struct gendisk___54 *);
	int (*getgeo)(struct block_device___218 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___218 *, long unsigned int);
	int (*report_zones)(struct gendisk___54 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___11 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bdi_writeback_congested___108 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___108 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct cgroup_subsys___173;

struct cgroup_subsys_state___174 {
	struct cgroup___173 *cgroup;
	struct cgroup_subsys___173 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___174 *parent;
};

struct bsg_ops___53 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___54 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___54 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___54 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___53(struct request___54 *, blk_status_t);

struct request___54 {
	struct request_queue___54 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___108 *bio;
	struct bio___108 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___108 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___57 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___53 *saved_end_io;
		} flush;
	};
	struct gendisk___54 *rq_disk;
	struct hd_struct___54 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___53 *end_io;
	void *end_io_data;
	struct request___54 *next_rq;
};

struct fwnode_reference_args___132;

struct fwnode_endpoint___132;

struct fwnode_operations___132 {
	struct fwnode_handle___132 * (*get)(struct fwnode_handle___132 *);
	void (*put)(struct fwnode_handle___132 *);
	bool (*device_is_available)(const struct fwnode_handle___132 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___132 *, const struct device___189 *);
	bool (*property_present)(const struct fwnode_handle___132 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___132 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___132 *, const char *, const char **, size_t);
	struct fwnode_handle___132 * (*get_parent)(const struct fwnode_handle___132 *);
	struct fwnode_handle___132 * (*get_next_child_node)(const struct fwnode_handle___132 *, struct fwnode_handle___132 *);
	struct fwnode_handle___132 * (*get_named_child_node)(const struct fwnode_handle___132 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___132 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___132 *);
	struct fwnode_handle___132 * (*graph_get_next_endpoint)(const struct fwnode_handle___132 *, struct fwnode_handle___132 *);
	struct fwnode_handle___132 * (*graph_get_remote_endpoint)(const struct fwnode_handle___132 *);
	struct fwnode_handle___132 * (*graph_get_port_parent)(struct fwnode_handle___132 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___132 *, struct fwnode_endpoint___132 *);
};

struct fwnode_endpoint___132 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___132 *local_fwnode;
};

struct fwnode_reference_args___132 {
	struct fwnode_handle___132 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct elevator_type___53;

struct elevator_mq_ops___53 {
	int (*init_sched)(struct request_queue___54 *, struct elevator_type___53 *);
	void (*exit_sched)(struct elevator_queue___53 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	bool (*allow_merge)(struct request_queue___54 *, struct request___54 *, struct bio___108 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx *, struct bio___108 *);
	int (*request_merge)(struct request_queue___54 *, struct request___54 **, struct bio___108 *);
	void (*request_merged)(struct request_queue___54 *, struct request___54 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___54 *, struct request___54 *, struct request___54 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___54 *, struct bio___108 *);
	void (*finish_request)(struct request___54 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___54 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___54 *, u64);
	void (*started_request)(struct request___54 *);
	void (*requeue_request)(struct request___54 *);
	struct request___54 * (*former_request)(struct request_queue___54 *, struct request___54 *);
	struct request___54 * (*next_request)(struct request_queue___54 *, struct request___54 *);
	void (*init_icq)(struct io_cq___57 *);
	void (*exit_icq)(struct io_cq___57 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___53;

struct elevator_type___53 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___53 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___53 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___11 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___53 {
	struct elevator_type___53 *type;
	void *elevator_data;
	struct kobject___206 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___53 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___53 *, char *);
	ssize_t (*store)(struct elevator_queue___53 *, const char *, size_t);
};

typedef int (*key_restrict_link_func_t___211)(struct key___211 *, const struct key_type *, const union key_payload *, struct key___211 *);

struct key_restriction___211;

struct key___211 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___218 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___211 *restrict_link;
};

struct key_restriction___211 {
	key_restrict_link_func_t___211 check;
	struct key___211 *key;
	struct key_type *keytype;
};

struct seq_operations___196 {
	void * (*start)(struct seq_file___198 *, loff_t *);
	void (*stop)(struct seq_file___198 *, void *);
	void * (*next)(struct seq_file___198 *, void *, loff_t *);
	int (*show)(struct seq_file___198 *, void *);
};

struct cgroup_namespace___173 {
	refcount_t count;
	struct ns_common___27 ns;
	struct user_namespace___184 *user_ns;
	struct ucounts___184 *ucounts;
	struct css_set___173 *root_cset;
};

struct ucounts___184 {
	struct hlist_node node;
	struct user_namespace___184 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___173;

struct bpf_map_ops___173 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___173 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___173 *, struct file___218 *);
	void (*map_free)(struct bpf_map___173 *);
	int (*map_get_next_key)(struct bpf_map___173 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___173 *);
	void * (*map_lookup_elem)(struct bpf_map___173 *, void *);
	int (*map_update_elem)(struct bpf_map___173 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___173 *, void *);
	int (*map_push_elem)(struct bpf_map___173 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___173 *, void *);
	int (*map_peek_elem)(struct bpf_map___173 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___173 *, struct file___218 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___173 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___173 *, void *, struct seq_file___198 *);
	int (*map_check_btf)(const struct bpf_map___173 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___173 {
	const struct bpf_map_ops___173 *ops;
	struct bpf_map___173 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___211 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___173;

typedef void (*kthread_work_func_t___173)(struct kthread_work___173 *);

struct kthread_worker___173;

struct kthread_work___173 {
	struct list_head node;
	kthread_work_func_t___173 func;
	struct kthread_worker___173 *worker;
	int canceling;
};

struct kthread_worker___173 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___218 *task;
	struct kthread_work___173 *current_work;
};

struct kthread_delayed_work___173 {
	struct kthread_work___173 work;
	struct timer_list timer;
};

struct psi_group___173 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___173 *poll_kworker;
	struct kthread_delayed_work___173 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___173 {
	struct kernfs_node___212 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_root___173;

struct cgroup_rstat_cpu___173;

struct cgroup___173 {
	struct cgroup_subsys_state___174 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___212 *kn;
	struct cgroup_file___173 procs_file;
	struct cgroup_file___173 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___174 *subsys[13];
	struct cgroup_root___173 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___173 *dom_cgrp;
	struct cgroup_rstat_cpu___173 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___22 bpf;
	atomic_t congestion_count;
	struct cgroup___173 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___173 psi;
	int ancestor_ids[0];
};

struct cftype___173;

struct cgroup_subsys___173 {
	struct cgroup_subsys_state___174 * (*css_alloc)(struct cgroup_subsys_state___174 *);
	int (*css_online)(struct cgroup_subsys_state___174 *);
	void (*css_offline)(struct cgroup_subsys_state___174 *);
	void (*css_released)(struct cgroup_subsys_state___174 *);
	void (*css_free)(struct cgroup_subsys_state___174 *);
	void (*css_reset)(struct cgroup_subsys_state___174 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___174 *, int);
	int (*css_extra_stat_show)(struct seq_file___198 *, struct cgroup_subsys_state___174 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___218 *);
	void (*cancel_fork)(struct task_struct___218 *);
	void (*fork)(struct task_struct___218 *);
	void (*exit)(struct task_struct___218 *);
	void (*free)(struct task_struct___218 *);
	void (*bind)(struct cgroup_subsys_state___174 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___173 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___173 *dfl_cftypes;
	struct cftype___173 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___173 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___173 *updated_children;
	struct cgroup___173 *updated_next;
};

struct cgroup_root___173 {
	struct kernfs_root___212 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___173 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___173 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___173 *ss;
	struct list_head node;
	struct kernfs_ops___212 *kf_ops;
	int (*open)(struct kernfs_open_file___212 *);
	void (*release)(struct kernfs_open_file___212 *);
	u64 (*read_u64)(struct cgroup_subsys_state___174 *, struct cftype___173 *);
	s64 (*read_s64)(struct cgroup_subsys_state___174 *, struct cftype___173 *);
	int (*seq_show)(struct seq_file___198 *, void *);
	void * (*seq_start)(struct seq_file___198 *, loff_t *);
	void * (*seq_next)(struct seq_file___198 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___198 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___174 *, struct cftype___173 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___174 *, struct cftype___173 *, s64);
	ssize_t (*write)(struct kernfs_open_file___212 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___212 *, struct poll_table_struct___6 *);
};

struct blkcg_policy_data___42;

struct blkcg___42 {
	struct cgroup_subsys_state___174 css;
	spinlock_t lock;
	struct xarray blkg_tree;
	struct blkcg_gq___42 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___42 *cpd[5];
	struct list_head all_blkcgs_node;
	struct list_head cgwb_list;
	refcount_t cgwb_refcnt;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct blkcg_policy_data___42 {
	struct blkcg___42 *blkcg;
	int plid;
};

struct blkg_policy_data___42 {
	struct blkcg_gq___42 *blkg;
	int plid;
};

struct config_group;

struct config_item_type;

struct config_item {
	char *ci_name;
	char ci_namebuf[20];
	struct kref ci_kref;
	struct list_head ci_entry;
	struct config_item *ci_parent;
	struct config_group *ci_group;
	const struct config_item_type *ci_type;
	struct dentry___217 *ci_dentry;
};

struct configfs_subsystem;

struct config_group {
	struct config_item cg_item;
	struct list_head cg_children;
	struct configfs_subsystem *cg_subsys;
	struct list_head default_groups;
	struct list_head group_entry;
};

struct configfs_item_operations;

struct configfs_group_operations;

struct configfs_attribute;

struct configfs_bin_attribute;

struct config_item_type {
	struct module___11 *ct_owner;
	struct configfs_item_operations *ct_item_ops;
	struct configfs_group_operations *ct_group_ops;
	struct configfs_attribute **ct_attrs;
	struct configfs_bin_attribute **ct_bin_attrs;
};

struct configfs_item_operations {
	void (*release)(struct config_item *);
	int (*allow_link)(struct config_item *, struct config_item *);
	void (*drop_link)(struct config_item *, struct config_item *);
};

struct configfs_group_operations {
	struct config_item * (*make_item)(struct config_group *, const char *);
	struct config_group * (*make_group)(struct config_group *, const char *);
	int (*commit_item)(struct config_item *);
	void (*disconnect_notify)(struct config_group *, struct config_item *);
	void (*drop_item)(struct config_group *, struct config_item *);
};

struct configfs_attribute {
	const char *ca_name;
	struct module___11 *ca_owner;
	umode_t ca_mode;
	ssize_t (*show)(struct config_item *, char *);
	ssize_t (*store)(struct config_item *, const char *, size_t);
};

struct configfs_bin_attribute {
	struct configfs_attribute cb_attr;
	void *cb_private;
	size_t cb_max_size;
	ssize_t (*read)(struct config_item *, void *, size_t);
	ssize_t (*write)(struct config_item *, const void *, size_t);
};

struct configfs_subsystem {
	struct config_group su_group;
	struct mutex su_mutex;
};

struct configfs_dirent {
	atomic_t s_count;
	int s_dependent_count;
	struct list_head s_sibling;
	struct list_head s_children;
	struct list_head s_links;
	void *s_element;
	int s_type;
	umode_t s_mode;
	struct dentry___217 *s_dentry;
	struct iattr___217 *s_iattr;
};

struct config_group___2;

struct config_item_type___2;

struct config_item___2 {
	char *ci_name;
	char ci_namebuf[20];
	struct kref ci_kref;
	struct list_head ci_entry;
	struct config_item___2 *ci_parent;
	struct config_group___2 *ci_group;
	const struct config_item_type___2 *ci_type;
	struct dentry___212 *ci_dentry;
};

struct configfs_subsystem___2;

struct config_group___2 {
	struct config_item___2 cg_item;
	struct list_head cg_children;
	struct configfs_subsystem___2 *cg_subsys;
	struct list_head default_groups;
	struct list_head group_entry;
};

struct configfs_item_operations___2;

struct configfs_group_operations___2;

struct configfs_attribute___2;

struct configfs_bin_attribute___2;

struct config_item_type___2 {
	struct module___175 *ct_owner;
	struct configfs_item_operations___2 *ct_item_ops;
	struct configfs_group_operations___2 *ct_group_ops;
	struct configfs_attribute___2 **ct_attrs;
	struct configfs_bin_attribute___2 **ct_bin_attrs;
};

struct configfs_item_operations___2 {
	void (*release)(struct config_item___2 *);
	int (*allow_link)(struct config_item___2 *, struct config_item___2 *);
	void (*drop_link)(struct config_item___2 *, struct config_item___2 *);
};

struct configfs_group_operations___2 {
	struct config_item___2 * (*make_item)(struct config_group___2 *, const char *);
	struct config_group___2 * (*make_group)(struct config_group___2 *, const char *);
	int (*commit_item)(struct config_item___2 *);
	void (*disconnect_notify)(struct config_group___2 *, struct config_item___2 *);
	void (*drop_item)(struct config_group___2 *, struct config_item___2 *);
};

struct configfs_attribute___2 {
	const char *ca_name;
	struct module___175 *ca_owner;
	umode_t ca_mode;
	ssize_t (*show)(struct config_item___2 *, char *);
	ssize_t (*store)(struct config_item___2 *, const char *, size_t);
};

struct configfs_bin_attribute___2 {
	struct configfs_attribute___2 cb_attr;
	void *cb_private;
	size_t cb_max_size;
	ssize_t (*read)(struct config_item___2 *, void *, size_t);
	ssize_t (*write)(struct config_item___2 *, const void *, size_t);
};

struct configfs_subsystem___2 {
	struct config_group___2 su_group;
	struct mutex su_mutex;
};

struct configfs_dirent___2 {
	atomic_t s_count;
	int s_dependent_count;
	struct list_head s_sibling;
	struct list_head s_children;
	struct list_head s_links;
	void *s_element;
	int s_type;
	umode_t s_mode;
	struct dentry___212 *s_dentry;
	struct iattr___212 *s_iattr;
};

struct configfs_symlink {
	struct list_head sl_list;
	struct config_item___2 *sl_target;
};

struct configfs_buffer {
	size_t count;
	loff_t pos;
	char *page;
	struct configfs_item_operations___2 *ops;
	struct mutex mutex;
	int needs_read_fill;
	bool read_in_progress;
	bool write_in_progress;
	char *bin_buffer;
	int bin_buffer_size;
};

struct module_version_attribute___2 {
	struct module_attribute___172 mattr;
	const char *module_name;
	const char *version;
};

struct config_group___3;

struct config_item_type___3;

struct dentry___218;

struct config_item___3 {
	char *ci_name;
	char ci_namebuf[20];
	struct kref ci_kref;
	struct list_head ci_entry;
	struct config_item___3 *ci_parent;
	struct config_group___3 *ci_group;
	const struct config_item_type___3 *ci_type;
	struct dentry___218 *ci_dentry;
};

struct configfs_subsystem___3;

struct config_group___3 {
	struct config_item___3 cg_item;
	struct list_head cg_children;
	struct configfs_subsystem___3 *cg_subsys;
	struct list_head default_groups;
	struct list_head group_entry;
};

struct configfs_item_operations___3;

struct configfs_group_operations___3;

struct configfs_attribute___3;

struct configfs_bin_attribute___3;

struct config_item_type___3 {
	struct module___168 *ct_owner;
	struct configfs_item_operations___3 *ct_item_ops;
	struct configfs_group_operations___3 *ct_group_ops;
	struct configfs_attribute___3 **ct_attrs;
	struct configfs_bin_attribute___3 **ct_bin_attrs;
};

struct configfs_item_operations___3 {
	void (*release)(struct config_item___3 *);
	int (*allow_link)(struct config_item___3 *, struct config_item___3 *);
	void (*drop_link)(struct config_item___3 *, struct config_item___3 *);
};

struct configfs_group_operations___3 {
	struct config_item___3 * (*make_item)(struct config_group___3 *, const char *);
	struct config_group___3 * (*make_group)(struct config_group___3 *, const char *);
	int (*commit_item)(struct config_item___3 *);
	void (*disconnect_notify)(struct config_group___3 *, struct config_item___3 *);
	void (*drop_item)(struct config_group___3 *, struct config_item___3 *);
};

struct configfs_attribute___3 {
	const char *ca_name;
	struct module___168 *ca_owner;
	umode_t ca_mode;
	ssize_t (*show)(struct config_item___3 *, char *);
	ssize_t (*store)(struct config_item___3 *, const char *, size_t);
};

struct configfs_bin_attribute___3 {
	struct configfs_attribute___3 cb_attr;
	void *cb_private;
	size_t cb_max_size;
	ssize_t (*read)(struct config_item___3 *, void *, size_t);
	ssize_t (*write)(struct config_item___3 *, const void *, size_t);
};

struct configfs_subsystem___3 {
	struct config_group___3 su_group;
	struct mutex su_mutex;
};

struct module___177;

struct file___219;

struct kiocb___219;

struct vm_area_struct___219;

struct inode___219;

struct file_lock___219;

struct page___219;

struct seq_file___199;

struct file_operations___219 {
	struct module___177 *owner;
	loff_t (*llseek)(struct file___219 *, loff_t, int);
	ssize_t (*read)(struct file___219 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___219 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___219 *, struct iov_iter___100 *);
	ssize_t (*write_iter)(struct kiocb___219 *, struct iov_iter___100 *);
	int (*iopoll)(struct kiocb___219 *, bool);
	int (*iterate)(struct file___219 *, struct dir_context *);
	int (*iterate_shared)(struct file___219 *, struct dir_context *);
	__poll_t (*poll)(struct file___219 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___219 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___219 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___219 *, struct vm_area_struct___219 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___219 *, struct file___219 *);
	int (*flush)(struct file___219 *, fl_owner_t);
	int (*release)(struct inode___219 *, struct file___219 *);
	int (*fsync)(struct file___219 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___219 *, int);
	int (*lock)(struct file___219 *, int, struct file_lock___219 *);
	ssize_t (*sendpage)(struct file___219 *, struct page___219 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___219 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___219 *, int, struct file_lock___219 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___219 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___219 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___219 *, long int, struct file_lock___219 **, void **);
	long int (*fallocate)(struct file___219 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___199 *, struct file___219 *);
	ssize_t (*copy_file_range)(struct file___219 *, loff_t, struct file___219 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___219 *, loff_t, struct file___219 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___219 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___218 {
	u64 seqnum;
	struct vm_area_struct___219 *vmas[4];
};

struct page_frag___218 {
	struct page___219 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___218;

struct pid___167;

struct cred___212;

struct nsproxy___203;

struct signal_struct___183;

struct task_struct___219 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___219 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___218 *mm;
	struct mm_struct___218 *active_mm;
	struct vmacache___218 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___219 *real_parent;
	struct task_struct___219 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___219 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___167 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___167 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___167 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___212 *ptracer_cred;
	const struct cred___212 *real_cred;
	const struct cred___212 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___203 *nsproxy;
	struct signal_struct___183 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___219 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___57 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___218 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___219 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___120 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rw_semaphore___219 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___219 *owner;
};

struct key___212;

struct ucounts___185;

struct user_namespace___185 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___185 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___27 ns;
	long unsigned int flags;
	struct key___212 *persistent_keyring_register;
	struct rw_semaphore___219 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___185 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___219 *pgtable_t___218;

struct address_space___218;

struct dev_pagemap___213;

struct page___219 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___218 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___219 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___218 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___218 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___213 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___218;

struct lruvec___218 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___218 *pgdat;
};

struct zone___218 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___218 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___218 {
	struct zone___218 *zone;
	int zone_idx;
};

struct zonelist___218 {
	struct zoneref___218 _zonerefs[25];
};

struct pglist_data___218 {
	struct zone___218 node_zones[3];
	struct zonelist___218 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___219 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___219 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___218 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___219 {
	void *stack;
	struct task_struct___219 *task;
	long int status;
};

struct blocking_notifier_head___218 {
	struct rw_semaphore___219 rwsem;
	struct notifier_block *head;
};

struct vfsmount___50;

struct dentry___219;

struct path___218 {
	struct vfsmount___50 *mnt;
	struct dentry___219 *dentry;
};

struct fown_struct___167 {
	rwlock_t lock;
	struct pid___167 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___219 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___218 f_path;
	struct inode___219 *f_inode;
	const struct file_operations___219 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___167 f_owner;
	const struct cred___212 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___218 *f_mapping;
	errseq_t f_wb_err;
};

struct user_struct___212;

struct cred___212 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___212 *session_keyring;
	struct key___212 *process_keyring;
	struct key___212 *thread_keyring;
	struct key___212 *request_key_auth;
	void *security;
	struct user_struct___212 *user;
	struct user_namespace___185 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___213;

struct kernfs_elem_dir___213 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___213 *root;
};

struct kernfs_node___213;

struct kernfs_syscall_ops___213;

struct kernfs_root___213 {
	struct kernfs_node___213 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___213 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___213 {
	struct kernfs_node___213 *target_kn;
};

struct kernfs_ops___213;

struct kernfs_elem_attr___213 {
	const struct kernfs_ops___213 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___213 *notify_next;
};

struct kernfs_node___213 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___213 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___213 dir;
		struct kernfs_elem_symlink___213 symlink;
		struct kernfs_elem_attr___213 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___213;

struct kernfs_ops___213 {
	int (*open)(struct kernfs_open_file___213 *);
	void (*release)(struct kernfs_open_file___213 *);
	int (*seq_show)(struct seq_file___199 *, void *);
	void * (*seq_start)(struct seq_file___199 *, loff_t *);
	void * (*seq_next)(struct seq_file___199 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___199 *, void *);
	ssize_t (*read)(struct kernfs_open_file___213 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___213 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___213 *, struct vm_area_struct___219 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___213 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___213 {
	int (*remount_fs)(struct kernfs_root___213 *, int *, char *);
	int (*show_options)(struct seq_file___199 *, struct kernfs_root___213 *);
	int (*mkdir)(struct kernfs_node___213 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___213 *);
	int (*rename)(struct kernfs_node___213 *, struct kernfs_node___213 *, const char *);
	int (*show_path)(struct seq_file___199 *, struct kernfs_node___213 *, struct kernfs_root___213 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___197;

struct seq_file___199 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___197 *op;
	int poll_event;
	const struct file___219 *file;
	void *private;
};

struct vm_operations_struct___213;

struct kernfs_open_file___213 {
	struct kernfs_node___213 *kn;
	struct file___219 *file;
	struct seq_file___199 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___213 *vm_ops;
};

struct vm_fault___213;

struct vm_operations_struct___213 {
	void (*open)(struct vm_area_struct___219 *);
	void (*close)(struct vm_area_struct___219 *);
	int (*split)(struct vm_area_struct___219 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___219 *);
	vm_fault_t (*fault)(struct vm_fault___213 *);
	vm_fault_t (*huge_fault)(struct vm_fault___213 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___213 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___219 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___213 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___213 *);
	int (*access)(struct vm_area_struct___219 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___219 *);
	int (*set_policy)(struct vm_area_struct___219 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___219 *, long unsigned int);
	struct page___219 * (*find_special_page)(struct vm_area_struct___219 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_area_struct___219 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___219 *vm_next;
	struct vm_area_struct___219 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___218 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___213 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___219 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___207;

struct bin_attribute___191;

struct attribute_group___192 {
	const char *name;
	umode_t (*is_visible)(struct kobject___207 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___207 *, struct bin_attribute___191 *, int);
	struct attribute **attrs;
	struct bin_attribute___191 **bin_attrs;
};

struct kset___206;

struct kobj_type___206;

struct kobject___207 {
	const char *name;
	struct list_head entry;
	struct kobject___207 *parent;
	struct kset___206 *kset;
	struct kobj_type___206 *ktype;
	struct kernfs_node___213 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___191 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___219 *, struct kobject___207 *, struct bin_attribute___191 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___219 *, struct kobject___207 *, struct bin_attribute___191 *, char *, loff_t, size_t);
	int (*mmap)(struct file___219 *, struct kobject___207 *, struct bin_attribute___191 *, struct vm_area_struct___219 *);
};

struct sysfs_ops___206 {
	ssize_t (*show)(struct kobject___207 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___207 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___206;

struct kset___206 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___207 kobj;
	const struct kset_uevent_ops___206 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___206 {
	void (*release)(struct kobject___207 *);
	const struct sysfs_ops___206 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___12 * (*child_ns_type)(struct kobject___207 *);
	const void * (*namespace)(struct kobject___207 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___206 {
	int (* const filter)(struct kset___206 *, struct kobject___207 *);
	const char * (* const name)(struct kset___206 *, struct kobject___207 *);
	int (* const uevent)(struct kset___206 *, struct kobject___207 *, struct kobj_uevent_env *);
};

struct kobj_attribute___204 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___207 *, struct kobj_attribute___204 *, char *);
	ssize_t (*store)(struct kobject___207 *, struct kobj_attribute___204 *, const char *, size_t);
};

struct kernel_param___174;

struct kernel_param_ops___174 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___174 *);
	int (*get)(char *, const struct kernel_param___174 *);
	void (*free)(void *);
};

struct kparam_array___174;

struct kernel_param___174 {
	const char *name;
	struct module___177 *mod;
	const struct kernel_param_ops___174 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___174 *arr;
	};
};

struct kparam_array___174 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___174 *ops;
	void *elem;
};

struct module_kobject___174 {
	struct kobject___207 kobj;
	struct module___177 *mod;
	struct kobject___207 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___174 {
	struct module___177 *mod;
	struct latch_tree_node node;
};

struct module_layout___174 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___174 mtn;
};

struct module_attribute___174;

struct module___177 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___174 mkobj;
	struct module_attribute___174 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___207 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___174 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___174 core_layout;
	struct module_layout___174 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___174 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___174 *, struct module_kobject___174 *, char *);
	ssize_t (*store)(struct module_attribute___174 *, struct module_kobject___174 *, const char *, size_t);
	void (*setup)(struct module___177 *, const char *);
	int (*test)(struct module___177 *);
	void (*free)(struct module___177 *);
};

struct dentry_operations___218;

struct super_block___218;

struct dentry___219 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___219 *d_parent;
	struct qstr d_name;
	struct inode___219 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___218 *d_op;
	struct super_block___218 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___218;

struct address_space___218 {
	struct inode___219 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___219 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___218 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___218;

struct block_device___219;

struct cdev___37;

struct inode___219 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___218 *i_op;
	struct super_block___218 *i_sb;
	struct address_space___218 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___219 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___219 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___218 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___219 *i_bdev;
		struct cdev___37 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___218 {
	int (*d_revalidate)(struct dentry___219 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___219 *, unsigned int);
	int (*d_hash)(const struct dentry___219 *, struct qstr *);
	int (*d_compare)(const struct dentry___219 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___219 *);
	int (*d_init)(struct dentry___219 *);
	void (*d_release)(struct dentry___219 *);
	void (*d_prune)(struct dentry___219 *);
	void (*d_iput)(struct dentry___219 *, struct inode___219 *);
	char * (*d_dname)(struct dentry___219 *, char *, int);
	struct vfsmount___50 * (*d_automount)(struct path___218 *);
	int (*d_manage)(const struct path___218 *, bool);
	struct dentry___219 * (*d_real)(struct dentry___219 *, const struct inode___219 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___218;

struct mem_dqinfo___218 {
	struct quota_format_type___218 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___218;

struct quota_info___218 {
	unsigned int flags;
	struct rw_semaphore___219 dqio_sem;
	struct inode___219 *files[3];
	struct mem_dqinfo___218 info[3];
	const struct quota_format_ops___218 *ops[3];
};

struct rcuwait___218 {
	struct task_struct___219 *task;
};

struct percpu_rw_semaphore___218 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___219 rw_sem;
	struct rcuwait___218 writer;
	int readers_block;
};

struct sb_writers___218 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___218 rw_sem[3];
};

struct file_system_type___218;

struct super_operations___218;

struct dquot_operations___218;

struct quotactl_ops___218;

struct super_block___218 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___218 *s_type;
	const struct super_operations___218 *s_op;
	const struct dquot_operations___218 *dq_op;
	const struct quotactl_ops___218 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___219 *s_root;
	struct rw_semaphore___219 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___219 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___218 s_dquot;
	struct sb_writers___218 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___218 *s_d_op;
	int cleancache_poolid;
	struct shrinker___95 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___185 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___50 {
	struct dentry___219 *mnt_root;
	struct super_block___218 *mnt_sb;
	int mnt_flags;
};

struct pid_namespace___167;

struct upid___167 {
	int nr;
	struct pid_namespace___167 *ns;
};

struct pid_namespace___167 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___219 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___167 *parent;
	struct vfsmount___50 *proc_mnt;
	struct dentry___219 *proc_self;
	struct dentry___219 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___185 *user_ns;
	struct ucounts___185 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___167 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___167 numbers[1];
};

struct core_state___218;

struct mm_struct___218 {
	struct {
		struct vm_area_struct___219 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___219 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___219 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___218 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___219 *owner;
		struct user_namespace___185 *user_ns;
		struct file___219 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___218 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___213)(struct vm_area_struct___219 *, long unsigned int, const struct page___219 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___213)(struct page___219 *, void *);

struct device___190;

struct dev_pagemap___213 {
	dev_page_fault_t___213 page_fault;
	dev_page_free_t___213 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___190 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___218 {
	struct task_struct___219 *task;
	struct core_thread___218 *next;
};

struct core_state___218 {
	atomic_t nr_threads;
	struct core_thread___218 dumper;
	struct completion startup;
};

struct vm_fault___213 {
	struct vm_area_struct___219 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___219 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___219 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___218 prealloc_pte;
};

struct user_struct___212 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___212 *uid_keyring;
	struct key___212 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct nsproxy___203 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___167 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct tty_struct___19;

struct signal_struct___183 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___219 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___219 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___167 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___167 *tty_old_pgrp;
	int leader;
	struct tty_struct___19 *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___218 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___167 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

union thread_union___194 {
	struct task_struct___219 task;
	long unsigned int stack[8192];
};

struct kiocb___219 {
	struct file___219 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___219 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___218 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___219 *ia_file;
};

struct dquot___218 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___218 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___218 {
	int qf_fmt_id;
	const struct quota_format_ops___218 *qf_ops;
	struct module___177 *qf_owner;
	struct quota_format_type___218 *qf_next;
};

struct quota_format_ops___218 {
	int (*check_quota_file)(struct super_block___218 *, int);
	int (*read_file_info)(struct super_block___218 *, int);
	int (*write_file_info)(struct super_block___218 *, int);
	int (*free_file_info)(struct super_block___218 *, int);
	int (*read_dqblk)(struct dquot___218 *);
	int (*commit_dqblk)(struct dquot___218 *);
	int (*release_dqblk)(struct dquot___218 *);
	int (*get_next_id)(struct super_block___218 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___218 {
	int (*write_dquot)(struct dquot___218 *);
	struct dquot___218 * (*alloc_dquot)(struct super_block___218 *, int);
	void (*destroy_dquot)(struct dquot___218 *);
	int (*acquire_dquot)(struct dquot___218 *);
	int (*release_dquot)(struct dquot___218 *);
	int (*mark_dirty)(struct dquot___218 *);
	int (*write_info)(struct super_block___218 *, int);
	qsize_t * (*get_reserved_space)(struct inode___219 *);
	int (*get_projid)(struct inode___219 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___219 *, qsize_t *);
	int (*get_next_id)(struct super_block___218 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___218 {
	int (*quota_on)(struct super_block___218 *, int, int, const struct path___218 *);
	int (*quota_off)(struct super_block___218 *, int);
	int (*quota_enable)(struct super_block___218 *, unsigned int);
	int (*quota_disable)(struct super_block___218 *, unsigned int);
	int (*quota_sync)(struct super_block___218 *, int);
	int (*set_info)(struct super_block___218 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___218 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___218 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___218 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___218 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___218 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___218 {
	int (*writepage)(struct page___219 *, struct writeback_control___3 *);
	int (*readpage)(struct file___219 *, struct page___219 *);
	int (*writepages)(struct address_space___218 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___219 *);
	int (*readpages)(struct file___219 *, struct address_space___218 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___219 *, struct address_space___218 *, loff_t, unsigned int, unsigned int, struct page___219 **, void **);
	int (*write_end)(struct file___219 *, struct address_space___218 *, loff_t, unsigned int, unsigned int, struct page___219 *, void *);
	sector_t (*bmap)(struct address_space___218 *, sector_t);
	void (*invalidatepage)(struct page___219 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___219 *, gfp_t);
	void (*freepage)(struct page___219 *);
	ssize_t (*direct_IO)(struct kiocb___219 *, struct iov_iter___100 *);
	int (*migratepage)(struct address_space___218 *, struct page___219 *, struct page___219 *, enum migrate_mode);
	bool (*isolate_page)(struct page___219 *, isolate_mode_t);
	void (*putback_page)(struct page___219 *);
	int (*launder_page)(struct page___219 *);
	int (*is_partially_uptodate)(struct page___219 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___219 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___218 *, struct page___219 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___219 *, sector_t *);
	void (*swap_deactivate)(struct file___219 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___219 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___219 *bd_inode;
	struct super_block___218 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___219 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___37 {
	struct kobject___207 kobj;
	struct module___177 *owner;
	const struct file_operations___219 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___218 {
	struct dentry___219 * (*lookup)(struct inode___219 *, struct dentry___219 *, unsigned int);
	const char * (*get_link)(struct dentry___219 *, struct inode___219 *, struct delayed_call *);
	int (*permission)(struct inode___219 *, int);
	struct posix_acl * (*get_acl)(struct inode___219 *, int);
	int (*readlink)(struct dentry___219 *, char *, int);
	int (*create)(struct inode___219 *, struct dentry___219 *, umode_t, bool);
	int (*link)(struct dentry___219 *, struct inode___219 *, struct dentry___219 *);
	int (*unlink)(struct inode___219 *, struct dentry___219 *);
	int (*symlink)(struct inode___219 *, struct dentry___219 *, const char *);
	int (*mkdir)(struct inode___219 *, struct dentry___219 *, umode_t);
	int (*rmdir)(struct inode___219 *, struct dentry___219 *);
	int (*mknod)(struct inode___219 *, struct dentry___219 *, umode_t, dev_t);
	int (*rename)(struct inode___219 *, struct dentry___219 *, struct inode___219 *, struct dentry___219 *, unsigned int);
	int (*setattr)(struct dentry___219 *, struct iattr___218 *);
	int (*getattr)(const struct path___218 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___219 *, char *, size_t);
	int (*fiemap)(struct inode___219 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___219 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___219 *, struct dentry___219 *, struct file___219 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___219 *, struct dentry___219 *, umode_t);
	int (*set_acl)(struct inode___219 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___218 {
	void (*fl_copy_lock)(struct file_lock___219 *, struct file_lock___219 *);
	void (*fl_release_private)(struct file_lock___219 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___218;

struct lock_manager_operations___218;

struct file_lock___219 {
	struct file_lock___219 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___219 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___218 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___218 *fl_ops;
	const struct lock_manager_operations___218 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___218 {
	int (*lm_compare_owner)(struct file_lock___219 *, struct file_lock___219 *);
	long unsigned int (*lm_owner_key)(struct file_lock___219 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___219 *);
	int (*lm_grant)(struct file_lock___219 *, int);
	bool (*lm_break)(struct file_lock___219 *);
	int (*lm_change)(struct file_lock___219 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___219 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___218 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___218 *fa_next;
	struct file___219 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___218 {
	const char *name;
	int fs_flags;
	struct dentry___219 * (*mount)(struct file_system_type___218 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___218 *);
	struct module___177 *owner;
	struct file_system_type___218 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___218 {
	struct inode___219 * (*alloc_inode)(struct super_block___218 *);
	void (*destroy_inode)(struct inode___219 *);
	void (*dirty_inode)(struct inode___219 *, int);
	int (*write_inode)(struct inode___219 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___219 *);
	void (*evict_inode)(struct inode___219 *);
	void (*put_super)(struct super_block___218 *);
	int (*sync_fs)(struct super_block___218 *, int);
	int (*freeze_super)(struct super_block___218 *);
	int (*freeze_fs)(struct super_block___218 *);
	int (*thaw_super)(struct super_block___218 *);
	int (*unfreeze_fs)(struct super_block___218 *);
	int (*statfs)(struct dentry___219 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___218 *, int *, char *);
	void (*umount_begin)(struct super_block___218 *);
	int (*show_options)(struct seq_file___199 *, struct dentry___219 *);
	int (*show_devname)(struct seq_file___199 *, struct dentry___219 *);
	int (*show_path)(struct seq_file___199 *, struct dentry___219 *);
	int (*show_stats)(struct seq_file___199 *, struct dentry___219 *);
	ssize_t (*quota_read)(struct super_block___218 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___218 *, int, const char *, size_t, loff_t);
	struct dquot___218 ** (*get_dquots)(struct inode___219 *);
	int (*bdev_try_to_free_page)(struct super_block___218 *, struct page___219 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___218 *, struct shrink_control___95 *);
	long int (*free_cached_objects)(struct super_block___218 *, struct shrink_control___95 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_ops___190 {
	int (*prepare)(struct device___190 *);
	void (*complete)(struct device___190 *);
	int (*suspend)(struct device___190 *);
	int (*resume)(struct device___190 *);
	int (*freeze)(struct device___190 *);
	int (*thaw)(struct device___190 *);
	int (*poweroff)(struct device___190 *);
	int (*restore)(struct device___190 *);
	int (*suspend_late)(struct device___190 *);
	int (*resume_early)(struct device___190 *);
	int (*freeze_late)(struct device___190 *);
	int (*thaw_early)(struct device___190 *);
	int (*poweroff_late)(struct device___190 *);
	int (*restore_early)(struct device___190 *);
	int (*suspend_noirq)(struct device___190 *);
	int (*resume_noirq)(struct device___190 *);
	int (*freeze_noirq)(struct device___190 *);
	int (*thaw_noirq)(struct device___190 *);
	int (*poweroff_noirq)(struct device___190 *);
	int (*restore_noirq)(struct device___190 *);
	int (*runtime_suspend)(struct device___190 *);
	int (*runtime_resume)(struct device___190 *);
	int (*runtime_idle)(struct device___190 *);
};

struct dev_pm_info___190 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___190 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___190;

struct bus_type___190;

struct device_driver___190;

struct dev_pm_domain___190;

struct class___190;

struct device___190 {
	struct device___190 *parent;
	struct device_private *p;
	struct kobject___207 kobj;
	const char *init_name;
	const struct device_type___190 *type;
	struct mutex mutex;
	struct bus_type___190 *bus;
	struct device_driver___190 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___190 power;
	struct dev_pm_domain___190 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___190 *class;
	const struct attribute_group___192 **groups;
	void (*release)(struct device___190 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___190 {
	struct dev_pm_ops___190 ops;
	void (*detach)(struct device___190 *, bool);
	int (*activate)(struct device___190 *);
	void (*sync)(struct device___190 *);
	void (*dismiss)(struct device___190 *);
};

struct bus_type___190 {
	const char *name;
	const char *dev_name;
	struct device___190 *dev_root;
	const struct attribute_group___192 **bus_groups;
	const struct attribute_group___192 **dev_groups;
	const struct attribute_group___192 **drv_groups;
	int (*match)(struct device___190 *, struct device_driver___190 *);
	int (*uevent)(struct device___190 *, struct kobj_uevent_env *);
	int (*probe)(struct device___190 *);
	int (*remove)(struct device___190 *);
	void (*shutdown)(struct device___190 *);
	int (*online)(struct device___190 *);
	int (*offline)(struct device___190 *);
	int (*suspend)(struct device___190 *, pm_message_t);
	int (*resume)(struct device___190 *);
	int (*num_vf)(struct device___190 *);
	int (*dma_configure)(struct device___190 *);
	const struct dev_pm_ops___190 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___190 {
	const char *name;
	struct bus_type___190 *bus;
	struct module___177 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___190 *);
	int (*remove)(struct device___190 *);
	void (*shutdown)(struct device___190 *);
	int (*suspend)(struct device___190 *, pm_message_t);
	int (*resume)(struct device___190 *);
	const struct attribute_group___192 **groups;
	const struct dev_pm_ops___190 *pm;
	void (*coredump)(struct device___190 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___190 {
	const char *name;
	const struct attribute_group___192 **groups;
	int (*uevent)(struct device___190 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___190 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___190 *);
	const struct dev_pm_ops___190 *pm;
};

struct class___190 {
	const char *name;
	struct module___177 *owner;
	const struct attribute_group___192 **class_groups;
	const struct attribute_group___192 **dev_groups;
	struct kobject___207 *dev_kobj;
	int (*dev_uevent)(struct device___190 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___190 *, umode_t *);
	void (*class_release)(struct class___190 *);
	void (*dev_release)(struct device___190 *);
	int (*shutdown_pre)(struct device___190 *);
	const struct kobj_ns_type_operations___12 *ns_type;
	const void * (*namespace)(struct device___190 *);
	const struct dev_pm_ops___190 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

typedef int (*key_restrict_link_func_t___212)(struct key___212 *, const struct key_type *, const union key_payload *, struct key___212 *);

struct key_restriction___212;

struct key___212 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___219 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___212 *restrict_link;
};

struct key_restriction___212 {
	key_restrict_link_func_t___212 check;
	struct key___212 *key;
	struct key_type *keytype;
};

struct seq_operations___197 {
	void * (*start)(struct seq_file___199 *, loff_t *);
	void (*stop)(struct seq_file___199 *, void *);
	void * (*next)(struct seq_file___199 *, void *, loff_t *);
	int (*show)(struct seq_file___199 *, void *);
};

struct tty_driver___19;

struct tty_operations___19 {
	struct tty_struct___19 * (*lookup)(struct tty_driver___19 *, struct file___219 *, int);
	int (*install)(struct tty_driver___19 *, struct tty_struct___19 *);
	void (*remove)(struct tty_driver___19 *, struct tty_struct___19 *);
	int (*open)(struct tty_struct___19 *, struct file___219 *);
	void (*close)(struct tty_struct___19 *, struct file___219 *);
	void (*shutdown)(struct tty_struct___19 *);
	void (*cleanup)(struct tty_struct___19 *);
	int (*write)(struct tty_struct___19 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___19 *, unsigned char);
	void (*flush_chars)(struct tty_struct___19 *);
	int (*write_room)(struct tty_struct___19 *);
	int (*chars_in_buffer)(struct tty_struct___19 *);
	int (*ioctl)(struct tty_struct___19 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___19 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___19 *, struct ktermios *);
	void (*throttle)(struct tty_struct___19 *);
	void (*unthrottle)(struct tty_struct___19 *);
	void (*stop)(struct tty_struct___19 *);
	void (*start)(struct tty_struct___19 *);
	void (*hangup)(struct tty_struct___19 *);
	int (*break_ctl)(struct tty_struct___19 *, int);
	void (*flush_buffer)(struct tty_struct___19 *);
	void (*set_ldisc)(struct tty_struct___19 *);
	void (*wait_until_sent)(struct tty_struct___19 *, int);
	void (*send_xchar)(struct tty_struct___19 *, char);
	int (*tiocmget)(struct tty_struct___19 *);
	int (*tiocmset)(struct tty_struct___19 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___19 *, struct winsize *);
	int (*set_termiox)(struct tty_struct___19 *, struct termiox *);
	int (*get_icount)(struct tty_struct___19 *, struct serial_icounter_struct *);
	void (*show_fdinfo)(struct tty_struct___19 *, struct seq_file___199 *);
	int (*poll_init)(struct tty_driver___19 *, int, char *);
	int (*poll_get_char)(struct tty_driver___19 *, int);
	void (*poll_put_char)(struct tty_driver___19 *, int, char);
	int (*proc_show)(struct seq_file___199 *, void *);
};

struct tty_ldisc___19;

struct tty_port___19;

struct tty_struct___19 {
	int magic;
	struct kref kref;
	struct device___190 *dev;
	struct tty_driver___19 *driver;
	const struct tty_operations___19 *ops;
	int index;
	struct ld_semaphore ldisc_sem;
	struct tty_ldisc___19 *ldisc;
	struct mutex atomic_write_lock;
	struct mutex legacy_mutex;
	struct mutex throttle_mutex;
	struct rw_semaphore___219 termios_rwsem;
	struct mutex winsize_mutex;
	spinlock_t ctrl_lock;
	spinlock_t flow_lock;
	struct ktermios termios;
	struct ktermios termios_locked;
	struct termiox *termiox;
	char name[64];
	struct pid___167 *pgrp;
	struct pid___167 *session;
	long unsigned int flags;
	int count;
	struct winsize winsize;
	long unsigned int stopped: 1;
	long unsigned int flow_stopped: 1;
	int: 30;
	long unsigned int unused: 62;
	int hw_stopped;
	long unsigned int ctrl_status: 8;
	long unsigned int packet: 1;
	int: 23;
	long unsigned int unused_ctrl: 55;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___19 *link;
	struct fasync_struct___218 *fasync;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	spinlock_t files_lock;
	struct list_head tty_files;
	int closing;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___19 *port;
};

struct tty_driver___19 {
	int magic;
	struct kref kref;
	struct cdev___37 **cdevs;
	struct module___177 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___19 *other;
	struct tty_struct___19 **ttys;
	struct tty_port___19 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___19 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___19;

struct tty_port_client_operations___19;

struct tty_port___19 {
	struct tty_bufhead buf;
	struct tty_struct___19 *tty;
	struct tty_struct___19 *itty;
	const struct tty_port_operations___19 *ops;
	const struct tty_port_client_operations___19 *client_ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	unsigned char low_latency: 1;
	struct mutex mutex;
	struct mutex buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
	void *client_data;
};

struct tty_ldisc_ops___19 {
	int magic;
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___19 *);
	void (*close)(struct tty_struct___19 *);
	void (*flush_buffer)(struct tty_struct___19 *);
	ssize_t (*read)(struct tty_struct___19 *, struct file___219 *, unsigned char *, size_t);
	ssize_t (*write)(struct tty_struct___19 *, struct file___219 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___19 *, struct file___219 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___19 *, struct file___219 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___19 *, struct ktermios *);
	__poll_t (*poll)(struct tty_struct___19 *, struct file___219 *, struct poll_table_struct___6 *);
	int (*hangup)(struct tty_struct___19 *);
	void (*receive_buf)(struct tty_struct___19 *, const unsigned char *, char *, int);
	void (*write_wakeup)(struct tty_struct___19 *);
	void (*dcd_change)(struct tty_struct___19 *, unsigned int);
	int (*receive_buf2)(struct tty_struct___19 *, const unsigned char *, char *, int);
	struct module___177 *owner;
	int refcount;
};

struct tty_ldisc___19 {
	struct tty_ldisc_ops___19 *ops;
	struct tty_struct___19 *tty;
};

struct tty_port_operations___19 {
	int (*carrier_raised)(struct tty_port___19 *);
	void (*dtr_rts)(struct tty_port___19 *, int);
	void (*shutdown)(struct tty_port___19 *);
	int (*activate)(struct tty_port___19 *, struct tty_struct___19 *);
	void (*destruct)(struct tty_port___19 *);
};

struct tty_port_client_operations___19 {
	int (*receive_buf)(struct tty_port___19 *, const unsigned char *, const unsigned char *, size_t);
	void (*write_wakeup)(struct tty_port___19 *);
};

struct ucounts___185 {
	struct hlist_node node;
	struct user_namespace___185 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

typedef void compound_page_dtor___213(struct page___219 *);

struct pts_mount_opts {
	int setuid;
	int setgid;
	kuid_t uid;
	kgid_t gid;
	umode_t mode;
	umode_t ptmxmode;
	int reserve;
	int max;
};

enum {
	Opt_uid = 0,
	Opt_gid___2 = 1,
	Opt_mode = 2,
	Opt_ptmxmode = 3,
	Opt_newinstance = 4,
	Opt_max = 5,
	Opt_err___2 = 6,
};

struct pts_fs_info {
	struct ida allocated_ptys;
	struct pts_mount_opts mount_opts;
	struct super_block___218 *sb;
	struct dentry___219 *ptmx_dentry;
};

struct dcookie_struct {
	struct path___197 path;
	struct list_head hash_list;
};

struct dcookie_user {
	struct list_head next;
};

struct ramfs_mount_opts {
	umode_t mode;
};

struct ramfs_fs_info {
	struct ramfs_mount_opts mount_opts;
};

enum {
	Opt_mode___2 = 0,
	Opt_err___3 = 1,
};

struct file___220;

struct kiocb___220;

struct iov_iter___101;

struct vm_area_struct___220;

struct inode___220;

struct file_lock___220;

struct page___220;

struct seq_file___200;

struct file_operations___220 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___220 *, loff_t, int);
	ssize_t (*read)(struct file___220 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___220 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___220 *, struct iov_iter___101 *);
	ssize_t (*write_iter)(struct kiocb___220 *, struct iov_iter___101 *);
	int (*iopoll)(struct kiocb___220 *, bool);
	int (*iterate)(struct file___220 *, struct dir_context *);
	int (*iterate_shared)(struct file___220 *, struct dir_context *);
	__poll_t (*poll)(struct file___220 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___220 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___220 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___220 *, struct vm_area_struct___220 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___220 *, struct file___220 *);
	int (*flush)(struct file___220 *, fl_owner_t);
	int (*release)(struct inode___220 *, struct file___220 *);
	int (*fsync)(struct file___220 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___220 *, int);
	int (*lock)(struct file___220 *, int, struct file_lock___220 *);
	ssize_t (*sendpage)(struct file___220 *, struct page___220 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___220 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___220 *, int, struct file_lock___220 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___220 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___220 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___220 *, long int, struct file_lock___220 **, void **);
	long int (*fallocate)(struct file___220 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___200 *, struct file___220 *);
	ssize_t (*copy_file_range)(struct file___220 *, loff_t, struct file___220 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___220 *, loff_t, struct file___220 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___220 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___219 {
	u64 seqnum;
	struct vm_area_struct___220 *vmas[4];
};

struct page_frag___219 {
	struct page___220 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___219;

struct cred___213;

struct nsproxy___204;

struct signal_struct___184;

struct bio_list___109;

struct backing_dev_info___109;

struct io_context___58;

struct css_set___174;

struct request_queue___55;

struct vm_struct___149;

struct task_struct___220 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___220 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___219 *mm;
	struct mm_struct___219 *active_mm;
	struct vmacache___219 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___220 *real_parent;
	struct task_struct___220 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___220 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___167 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___167 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___167 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___213 *ptracer_cred;
	const struct cred___213 *real_cred;
	const struct cred___213 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___204 *nsproxy;
	struct signal_struct___184 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___220 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___109 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___109 *backing_dev_info;
	struct io_context___58 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___174 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___219 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___55 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___220 *oom_reaper_list;
	struct vm_struct___149 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___120 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct key___213;

struct user_struct___213 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___213 *uid_keyring;
	struct key___213 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct rw_semaphore___220 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___220 *owner;
};

struct ucounts___186;

struct user_namespace___186 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___186 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___27 ns;
	long unsigned int flags;
	struct key___213 *persistent_keyring_register;
	struct rw_semaphore___220 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___186 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct secondary_data___220 {
	void *stack;
	struct task_struct___220 *task;
	long int status;
};

typedef struct page___220 *pgtable_t___219;

struct address_space___219;

struct dev_pagemap___214;

struct page___220 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___219 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___220 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___219 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___219 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___214 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct vm_operations_struct___214;

struct vm_area_struct___220 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___220 *vm_next;
	struct vm_area_struct___220 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___219 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___214 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___220 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___219;

struct mm_struct___219 {
	struct {
		struct vm_area_struct___220 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___220 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___220 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___219 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___220 *owner;
		struct user_namespace___186 *user_ns;
		struct file___220 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___219 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___213 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___213 *session_keyring;
	struct key___213 *process_keyring;
	struct key___213 *thread_keyring;
	struct key___213 *request_key_auth;
	void *security;
	struct user_struct___213 *user;
	struct user_namespace___186 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___174;

struct nsproxy___204 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___174 *cgroup_ns;
};

struct signal_struct___184 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___220 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___220 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___167 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___167 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___219 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___167 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___109;

struct bio_list___109 {
	struct bio___109 *head;
	struct bio___109 *tail;
};

struct bdi_writeback_congested___109;

struct cgroup_subsys_state___175;

struct bdi_writeback___109 {
	struct backing_dev_info___109 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___109 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___175 *memcg_css;
	struct cgroup_subsys_state___175 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___191;

struct dentry___220;

struct backing_dev_info___109 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___109 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___191 *dev;
	struct device___191 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___220 *debug_dir;
	struct dentry___220 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___58;

struct io_context___58 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___58 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___174;

struct css_set___174 {
	struct cgroup_subsys_state___175 *subsys[13];
	refcount_t refcount;
	struct css_set___174 *dom_cset;
	struct cgroup___174 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___174 *mg_src_cgrp;
	struct cgroup___174 *mg_dst_cgrp;
	struct css_set___174 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

typedef blk_qc_t make_request_fn___54(struct request_queue___55 *, struct bio___109 *);

struct request___55;

typedef int dma_drain_needed_fn___54(struct request___55 *);

struct kset___207;

struct kobj_type___207;

struct kernfs_node___214;

struct kobject___208 {
	const char *name;
	struct list_head entry;
	struct kobject___208 *parent;
	struct kset___207 *kset;
	struct kobj_type___207 *ktype;
	struct kernfs_node___214 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___54;

struct bsg_class_device___54 {
	struct device___191 *class_dev;
	int minor;
	struct request_queue___55 *queue;
	const struct bsg_ops___54 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___109 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___109 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___54;

struct blkcg_gq___43;

struct request_queue___55 {
	struct list_head queue_head;
	struct request___55 *last_merge;
	struct elevator_queue___54 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___54 *make_request_fn;
	dma_drain_needed_fn___54 *dma_drain_needed;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___109 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___208 kobj;
	struct kobject___208 *mq_kobj;
	struct blk_integrity integrity;
	struct device___191 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___43 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	struct bsg_class_device___54 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___109 bio_split;
	struct dentry___220 *debugfs_dir;
	struct dentry___220 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___149 {
	struct vm_struct___149 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___220 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___195 {
	struct task_struct___220 task;
	long unsigned int stack[8192];
};

typedef int (*key_restrict_link_func_t___213)(struct key___213 *, const struct key_type *, const union key_payload *, struct key___213 *);

struct key_restriction___213;

struct key___213 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___220 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___213 *restrict_link;
};

struct key_restriction___213 {
	key_restrict_link_func_t___213 check;
	struct key___213 *key;
	struct key_type *keytype;
};

struct dentry_operations___219;

struct super_block___219;

struct dentry___220 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___220 *d_parent;
	struct qstr d_name;
	struct inode___220 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___219 *d_op;
	struct super_block___219 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___219;

struct address_space___219 {
	struct inode___220 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___220 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___219 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___219;

struct block_device___220;

struct inode___220 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___219 *i_op;
	struct super_block___219 *i_sb;
	struct address_space___219 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___220 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___109 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___220 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___219 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___220 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vfsmount___51;

struct path___219;

struct dentry_operations___219 {
	int (*d_revalidate)(struct dentry___220 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___220 *, unsigned int);
	int (*d_hash)(const struct dentry___220 *, struct qstr *);
	int (*d_compare)(const struct dentry___220 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___220 *);
	int (*d_init)(struct dentry___220 *);
	void (*d_release)(struct dentry___220 *);
	void (*d_prune)(struct dentry___220 *);
	void (*d_iput)(struct dentry___220 *, struct inode___220 *);
	char * (*d_dname)(struct dentry___220 *, char *, int);
	struct vfsmount___51 * (*d_automount)(struct path___219 *);
	int (*d_manage)(const struct path___219 *, bool);
	struct dentry___220 * (*d_real)(struct dentry___220 *, const struct inode___220 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___219;

struct mem_dqinfo___219 {
	struct quota_format_type___219 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___219;

struct quota_info___219 {
	unsigned int flags;
	struct rw_semaphore___220 dqio_sem;
	struct inode___220 *files[3];
	struct mem_dqinfo___219 info[3];
	const struct quota_format_ops___219 *ops[3];
};

struct rcuwait___219 {
	struct task_struct___220 *task;
};

struct percpu_rw_semaphore___219 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___220 rw_sem;
	struct rcuwait___219 writer;
	int readers_block;
};

struct sb_writers___219 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___219 rw_sem[3];
};

struct file_system_type___219;

struct super_operations___219;

struct dquot_operations___219;

struct quotactl_ops___219;

struct super_block___219 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___219 *s_type;
	const struct super_operations___219 *s_op;
	const struct dquot_operations___219 *dq_op;
	const struct quotactl_ops___219 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___220 *s_root;
	struct rw_semaphore___220 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___220 *s_bdev;
	struct backing_dev_info___109 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___219 s_dquot;
	struct sb_writers___219 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___219 *s_d_op;
	int cleancache_poolid;
	struct shrinker___95 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___186 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___51 {
	struct dentry___220 *mnt_root;
	struct super_block___219 *mnt_sb;
	int mnt_flags;
};

struct path___219 {
	struct vfsmount___51 *mnt;
	struct dentry___220 *dentry;
};

struct pglist_data___219;

struct lruvec___219 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___219 *pgdat;
};

struct zone___219 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___219 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___219 {
	struct zone___219 *zone;
	int zone_idx;
};

struct zonelist___219 {
	struct zoneref___219 _zonerefs[25];
};

struct pglist_data___219 {
	struct zone___219 node_zones[3];
	struct zonelist___219 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___220 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___220 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___219 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___219 {
	struct rw_semaphore___220 rwsem;
	struct notifier_block *head;
};

typedef int (*dev_page_fault_t___214)(struct vm_area_struct___220 *, long unsigned int, const struct page___220 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___214)(struct page___220 *, void *);

struct dev_pagemap___214 {
	dev_page_fault_t___214 page_fault;
	dev_page_free_t___214 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___191 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct file___220 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___219 f_path;
	struct inode___220 *f_inode;
	const struct file_operations___220 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___167 f_owner;
	const struct cred___213 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___219 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___214;

struct vm_operations_struct___214 {
	void (*open)(struct vm_area_struct___220 *);
	void (*close)(struct vm_area_struct___220 *);
	int (*split)(struct vm_area_struct___220 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___220 *);
	vm_fault_t (*fault)(struct vm_fault___214 *);
	vm_fault_t (*huge_fault)(struct vm_fault___214 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___214 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___220 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___214 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___214 *);
	int (*access)(struct vm_area_struct___220 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___220 *);
	int (*set_policy)(struct vm_area_struct___220 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___220 *, long unsigned int);
	struct page___220 * (*find_special_page)(struct vm_area_struct___220 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___219 {
	struct task_struct___220 *task;
	struct core_thread___219 *next;
};

struct core_state___219 {
	atomic_t nr_threads;
	struct core_thread___219 dumper;
	struct completion startup;
};

struct vm_fault___214 {
	struct vm_area_struct___220 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___220 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___220 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___219 prealloc_pte;
};

struct io_cq___58 {
	struct request_queue___55 *q;
	struct io_context___58 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___6 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___220 {
	struct file___220 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___220 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___219 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___220 *ia_file;
};

struct dquot___219 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___219 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___219 {
	int qf_fmt_id;
	const struct quota_format_ops___219 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___219 *qf_next;
};

struct quota_format_ops___219 {
	int (*check_quota_file)(struct super_block___219 *, int);
	int (*read_file_info)(struct super_block___219 *, int);
	int (*write_file_info)(struct super_block___219 *, int);
	int (*free_file_info)(struct super_block___219 *, int);
	int (*read_dqblk)(struct dquot___219 *);
	int (*commit_dqblk)(struct dquot___219 *);
	int (*release_dqblk)(struct dquot___219 *);
	int (*get_next_id)(struct super_block___219 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___219 {
	int (*write_dquot)(struct dquot___219 *);
	struct dquot___219 * (*alloc_dquot)(struct super_block___219 *, int);
	void (*destroy_dquot)(struct dquot___219 *);
	int (*acquire_dquot)(struct dquot___219 *);
	int (*release_dquot)(struct dquot___219 *);
	int (*mark_dirty)(struct dquot___219 *);
	int (*write_info)(struct super_block___219 *, int);
	qsize_t * (*get_reserved_space)(struct inode___220 *);
	int (*get_projid)(struct inode___220 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___220 *, qsize_t *);
	int (*get_next_id)(struct super_block___219 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___219 {
	int (*quota_on)(struct super_block___219 *, int, int, const struct path___219 *);
	int (*quota_off)(struct super_block___219 *, int);
	int (*quota_enable)(struct super_block___219 *, unsigned int);
	int (*quota_disable)(struct super_block___219 *, unsigned int);
	int (*quota_sync)(struct super_block___219 *, int);
	int (*set_info)(struct super_block___219 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___219 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___219 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___219 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___219 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___219 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___105;

struct address_space_operations___219 {
	int (*writepage)(struct page___220 *, struct writeback_control___105 *);
	int (*readpage)(struct file___220 *, struct page___220 *);
	int (*writepages)(struct address_space___219 *, struct writeback_control___105 *);
	int (*set_page_dirty)(struct page___220 *);
	int (*readpages)(struct file___220 *, struct address_space___219 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___220 *, struct address_space___219 *, loff_t, unsigned int, unsigned int, struct page___220 **, void **);
	int (*write_end)(struct file___220 *, struct address_space___219 *, loff_t, unsigned int, unsigned int, struct page___220 *, void *);
	sector_t (*bmap)(struct address_space___219 *, sector_t);
	void (*invalidatepage)(struct page___220 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___220 *, gfp_t);
	void (*freepage)(struct page___220 *);
	ssize_t (*direct_IO)(struct kiocb___220 *, struct iov_iter___101 *);
	int (*migratepage)(struct address_space___219 *, struct page___220 *, struct page___220 *, enum migrate_mode);
	bool (*isolate_page)(struct page___220 *, isolate_mode_t);
	void (*putback_page)(struct page___220 *);
	int (*launder_page)(struct page___220 *);
	int (*is_partially_uptodate)(struct page___220 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___220 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___219 *, struct page___220 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___220 *, sector_t *);
	void (*swap_deactivate)(struct file___220 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___105 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___109 *wb;
	struct inode___220 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___109;

struct iov_iter___101 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___109 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct hd_struct___55;

struct gendisk___55;

struct block_device___220 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___220 *bd_inode;
	struct super_block___219 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___220 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___55 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___55 *bd_disk;
	struct request_queue___55 *bd_queue;
	struct backing_dev_info___109 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___191 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___191 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___191;

struct bus_type___191;

struct device_driver___191;

struct dev_pm_domain___191;

struct fwnode_handle___133;

struct class___191;

struct attribute_group___193;

struct device___191 {
	struct device___191 *parent;
	struct device_private *p;
	struct kobject___208 kobj;
	const char *init_name;
	const struct device_type___191 *type;
	struct mutex mutex;
	struct bus_type___191 *bus;
	struct device_driver___191 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___191 power;
	struct dev_pm_domain___191 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___133 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___191 *class;
	const struct attribute_group___193 **groups;
	void (*release)(struct device___191 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___55 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___191 __dev;
	struct kobject___208 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___55;

struct block_device_operations___55;

struct gendisk___55 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___55 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___55 *part_tbl;
	struct hd_struct___55 part0;
	const struct block_device_operations___55 *fops;
	struct request_queue___55 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___220 lookup_sem;
	struct kobject___208 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___208 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___219 {
	struct dentry___220 * (*lookup)(struct inode___220 *, struct dentry___220 *, unsigned int);
	const char * (*get_link)(struct dentry___220 *, struct inode___220 *, struct delayed_call *);
	int (*permission)(struct inode___220 *, int);
	struct posix_acl * (*get_acl)(struct inode___220 *, int);
	int (*readlink)(struct dentry___220 *, char *, int);
	int (*create)(struct inode___220 *, struct dentry___220 *, umode_t, bool);
	int (*link)(struct dentry___220 *, struct inode___220 *, struct dentry___220 *);
	int (*unlink)(struct inode___220 *, struct dentry___220 *);
	int (*symlink)(struct inode___220 *, struct dentry___220 *, const char *);
	int (*mkdir)(struct inode___220 *, struct dentry___220 *, umode_t);
	int (*rmdir)(struct inode___220 *, struct dentry___220 *);
	int (*mknod)(struct inode___220 *, struct dentry___220 *, umode_t, dev_t);
	int (*rename)(struct inode___220 *, struct dentry___220 *, struct inode___220 *, struct dentry___220 *, unsigned int);
	int (*setattr)(struct dentry___220 *, struct iattr___219 *);
	int (*getattr)(const struct path___219 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___220 *, char *, size_t);
	int (*fiemap)(struct inode___220 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___220 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___220 *, struct dentry___220 *, struct file___220 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___220 *, struct dentry___220 *, umode_t);
	int (*set_acl)(struct inode___220 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___219 {
	void (*fl_copy_lock)(struct file_lock___220 *, struct file_lock___220 *);
	void (*fl_release_private)(struct file_lock___220 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___219;

struct lock_manager_operations___219;

struct file_lock___220 {
	struct file_lock___220 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___220 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___219 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___219 *fl_ops;
	const struct lock_manager_operations___219 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___219 {
	int (*lm_compare_owner)(struct file_lock___220 *, struct file_lock___220 *);
	long unsigned int (*lm_owner_key)(struct file_lock___220 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___220 *);
	int (*lm_grant)(struct file_lock___220 *, int);
	bool (*lm_break)(struct file_lock___220 *);
	int (*lm_change)(struct file_lock___220 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___220 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___219 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___219 *fa_next;
	struct file___220 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___219 {
	const char *name;
	int fs_flags;
	struct dentry___220 * (*mount)(struct file_system_type___219 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___219 *);
	struct module___11 *owner;
	struct file_system_type___219 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___219 {
	struct inode___220 * (*alloc_inode)(struct super_block___219 *);
	void (*destroy_inode)(struct inode___220 *);
	void (*dirty_inode)(struct inode___220 *, int);
	int (*write_inode)(struct inode___220 *, struct writeback_control___105 *);
	int (*drop_inode)(struct inode___220 *);
	void (*evict_inode)(struct inode___220 *);
	void (*put_super)(struct super_block___219 *);
	int (*sync_fs)(struct super_block___219 *, int);
	int (*freeze_super)(struct super_block___219 *);
	int (*freeze_fs)(struct super_block___219 *);
	int (*thaw_super)(struct super_block___219 *);
	int (*unfreeze_fs)(struct super_block___219 *);
	int (*statfs)(struct dentry___220 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___219 *, int *, char *);
	void (*umount_begin)(struct super_block___219 *);
	int (*show_options)(struct seq_file___200 *, struct dentry___220 *);
	int (*show_devname)(struct seq_file___200 *, struct dentry___220 *);
	int (*show_path)(struct seq_file___200 *, struct dentry___220 *);
	int (*show_stats)(struct seq_file___200 *, struct dentry___220 *);
	ssize_t (*quota_read)(struct super_block___219 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___219 *, int, const char *, size_t, loff_t);
	struct dquot___219 ** (*get_dquots)(struct inode___220 *);
	int (*bdev_try_to_free_page)(struct super_block___219 *, struct page___220 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___219 *, struct shrink_control___95 *);
	long int (*free_cached_objects)(struct super_block___219 *, struct shrink_control___95 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___198;

struct seq_file___200 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___198 *op;
	int poll_event;
	const struct file___220 *file;
	void *private;
};

typedef void bio_end_io_t___109(struct bio___109 *);

struct bio_vec___109 {
	struct page___220 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___109;

struct bio___109 {
	struct bio___109 *bi_next;
	struct gendisk___55 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___109 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___43 *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___109 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___109 *bi_io_vec;
	struct bio_set___109 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___109 bi_inline_vecs[0];
};

struct bdi_writeback_congested___109 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___109 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct cgroup_subsys___174;

struct cgroup_subsys_state___175 {
	struct cgroup___174 *cgroup;
	struct cgroup_subsys___174 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___175 *parent;
};

struct bio_integrity_payload___109 {
	struct bio___109 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___109 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___109 bip_inline_vecs[0];
};

struct blkcg___43;

struct blkg_policy_data___43;

struct blkcg_gq___43 {
	struct request_queue___55 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___43 *blkcg;
	struct bdi_writeback_congested___109 *wb_congested;
	struct blkcg_gq___43 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_rwstat stat_bytes;
	struct blkg_rwstat stat_ios;
	struct blkg_policy_data___43 *pd[5];
	struct callback_head callback_head;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
};

struct seq_operations___198 {
	void * (*start)(struct seq_file___200 *, loff_t *);
	void (*stop)(struct seq_file___200 *, void *);
	void * (*next)(struct seq_file___200 *, void *, loff_t *);
	int (*show)(struct seq_file___200 *, void *);
};

struct kernfs_root___214;

struct kernfs_elem_dir___214 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___214 *root;
};

struct kernfs_syscall_ops___214;

struct kernfs_root___214 {
	struct kernfs_node___214 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___214 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___214 {
	struct kernfs_node___214 *target_kn;
};

struct kernfs_ops___214;

struct kernfs_elem_attr___214 {
	const struct kernfs_ops___214 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___214 *notify_next;
};

struct kernfs_node___214 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___214 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___214 dir;
		struct kernfs_elem_symlink___214 symlink;
		struct kernfs_elem_attr___214 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___214;

struct kernfs_ops___214 {
	int (*open)(struct kernfs_open_file___214 *);
	void (*release)(struct kernfs_open_file___214 *);
	int (*seq_show)(struct seq_file___200 *, void *);
	void * (*seq_start)(struct seq_file___200 *, loff_t *);
	void * (*seq_next)(struct seq_file___200 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___200 *, void *);
	ssize_t (*read)(struct kernfs_open_file___214 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___214 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___214 *, struct vm_area_struct___220 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___214 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___214 {
	int (*remount_fs)(struct kernfs_root___214 *, int *, char *);
	int (*show_options)(struct seq_file___200 *, struct kernfs_root___214 *);
	int (*mkdir)(struct kernfs_node___214 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___214 *);
	int (*rename)(struct kernfs_node___214 *, struct kernfs_node___214 *, const char *);
	int (*show_path)(struct seq_file___200 *, struct kernfs_node___214 *, struct kernfs_root___214 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___214 {
	struct kernfs_node___214 *kn;
	struct file___220 *file;
	struct seq_file___200 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___214 *vm_ops;
};

struct cgroup_namespace___174 {
	refcount_t count;
	struct ns_common___27 ns;
	struct user_namespace___186 *user_ns;
	struct ucounts___186 *ucounts;
	struct css_set___174 *root_cset;
};

struct ucounts___186 {
	struct hlist_node node;
	struct user_namespace___186 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___174;

struct bpf_map_ops___174 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___174 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___174 *, struct file___220 *);
	void (*map_free)(struct bpf_map___174 *);
	int (*map_get_next_key)(struct bpf_map___174 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___174 *);
	void * (*map_lookup_elem)(struct bpf_map___174 *, void *);
	int (*map_update_elem)(struct bpf_map___174 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___174 *, void *);
	int (*map_push_elem)(struct bpf_map___174 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___174 *, void *);
	int (*map_peek_elem)(struct bpf_map___174 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___174 *, struct file___220 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___174 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___174 *, void *, struct seq_file___200 *);
	int (*map_check_btf)(const struct bpf_map___174 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___174 {
	const struct bpf_map_ops___174 *ops;
	struct bpf_map___174 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___213 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___174;

typedef void (*kthread_work_func_t___174)(struct kthread_work___174 *);

struct kthread_worker___174;

struct kthread_work___174 {
	struct list_head node;
	kthread_work_func_t___174 func;
	struct kthread_worker___174 *worker;
	int canceling;
};

struct kthread_worker___174 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___220 *task;
	struct kthread_work___174 *current_work;
};

struct kthread_delayed_work___174 {
	struct kthread_work___174 work;
	struct timer_list timer;
};

struct psi_group___174 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___174 *poll_kworker;
	struct kthread_delayed_work___174 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___174 {
	struct kernfs_node___214 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_root___174;

struct cgroup_rstat_cpu___174;

struct cgroup___174 {
	struct cgroup_subsys_state___175 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___214 *kn;
	struct cgroup_file___174 procs_file;
	struct cgroup_file___174 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___175 *subsys[13];
	struct cgroup_root___174 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___174 *dom_cgrp;
	struct cgroup_rstat_cpu___174 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___22 bpf;
	atomic_t congestion_count;
	struct cgroup___174 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___174 psi;
	int ancestor_ids[0];
};

struct cftype___174;

struct cgroup_subsys___174 {
	struct cgroup_subsys_state___175 * (*css_alloc)(struct cgroup_subsys_state___175 *);
	int (*css_online)(struct cgroup_subsys_state___175 *);
	void (*css_offline)(struct cgroup_subsys_state___175 *);
	void (*css_released)(struct cgroup_subsys_state___175 *);
	void (*css_free)(struct cgroup_subsys_state___175 *);
	void (*css_reset)(struct cgroup_subsys_state___175 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___175 *, int);
	int (*css_extra_stat_show)(struct seq_file___200 *, struct cgroup_subsys_state___175 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___220 *);
	void (*cancel_fork)(struct task_struct___220 *);
	void (*fork)(struct task_struct___220 *);
	void (*exit)(struct task_struct___220 *);
	void (*free)(struct task_struct___220 *);
	void (*bind)(struct cgroup_subsys_state___175 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___174 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___174 *dfl_cftypes;
	struct cftype___174 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___174 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___174 *updated_children;
	struct cgroup___174 *updated_next;
};

struct cgroup_root___174 {
	struct kernfs_root___214 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___174 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___174 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___174 *ss;
	struct list_head node;
	struct kernfs_ops___214 *kf_ops;
	int (*open)(struct kernfs_open_file___214 *);
	void (*release)(struct kernfs_open_file___214 *);
	u64 (*read_u64)(struct cgroup_subsys_state___175 *, struct cftype___174 *);
	s64 (*read_s64)(struct cgroup_subsys_state___175 *, struct cftype___174 *);
	int (*seq_show)(struct seq_file___200 *, void *);
	void * (*seq_start)(struct seq_file___200 *, loff_t *);
	void * (*seq_next)(struct seq_file___200 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___200 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___175 *, struct cftype___174 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___175 *, struct cftype___174 *, s64);
	ssize_t (*write)(struct kernfs_open_file___214 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___214 *, struct poll_table_struct___6 *);
};

struct kobj_attribute___205 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___208 *, struct kobj_attribute___205 *, char *);
	ssize_t (*store)(struct kobject___208 *, struct kobj_attribute___205 *, const char *, size_t);
};

typedef void compound_page_dtor___214(struct page___220 *);

struct dev_pm_ops___191;

struct device_type___191 {
	const char *name;
	const struct attribute_group___193 **groups;
	int (*uevent)(struct device___191 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___191 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___191 *);
	const struct dev_pm_ops___191 *pm;
};

struct class___191 {
	const char *name;
	struct module___11 *owner;
	const struct attribute_group___193 **class_groups;
	const struct attribute_group___193 **dev_groups;
	struct kobject___208 *dev_kobj;
	int (*dev_uevent)(struct device___191 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___191 *, umode_t *);
	void (*class_release)(struct class___191 *);
	void (*dev_release)(struct device___191 *);
	int (*shutdown_pre)(struct device___191 *);
	const struct kobj_ns_type_operations___12 *ns_type;
	const void * (*namespace)(struct device___191 *);
	const struct dev_pm_ops___191 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct bin_attribute___192;

struct attribute_group___193 {
	const char *name;
	umode_t (*is_visible)(struct kobject___208 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___208 *, struct bin_attribute___192 *, int);
	struct attribute **attrs;
	struct bin_attribute___192 **bin_attrs;
};

struct bin_attribute___192 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___220 *, struct kobject___208 *, struct bin_attribute___192 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___220 *, struct kobject___208 *, struct bin_attribute___192 *, char *, loff_t, size_t);
	int (*mmap)(struct file___220 *, struct kobject___208 *, struct bin_attribute___192 *, struct vm_area_struct___220 *);
};

struct sysfs_ops___207 {
	ssize_t (*show)(struct kobject___208 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___208 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___207;

struct kset___207 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___208 kobj;
	const struct kset_uevent_ops___207 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___207 {
	void (*release)(struct kobject___208 *);
	const struct sysfs_ops___207 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___12 * (*child_ns_type)(struct kobject___208 *);
	const void * (*namespace)(struct kobject___208 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___207 {
	int (* const filter)(struct kset___207 *, struct kobject___208 *);
	const char * (* const name)(struct kset___207 *, struct kobject___208 *);
	int (* const uevent)(struct kset___207 *, struct kobject___208 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___191 {
	int (*prepare)(struct device___191 *);
	void (*complete)(struct device___191 *);
	int (*suspend)(struct device___191 *);
	int (*resume)(struct device___191 *);
	int (*freeze)(struct device___191 *);
	int (*thaw)(struct device___191 *);
	int (*poweroff)(struct device___191 *);
	int (*restore)(struct device___191 *);
	int (*suspend_late)(struct device___191 *);
	int (*resume_early)(struct device___191 *);
	int (*freeze_late)(struct device___191 *);
	int (*thaw_early)(struct device___191 *);
	int (*poweroff_late)(struct device___191 *);
	int (*restore_early)(struct device___191 *);
	int (*suspend_noirq)(struct device___191 *);
	int (*resume_noirq)(struct device___191 *);
	int (*freeze_noirq)(struct device___191 *);
	int (*thaw_noirq)(struct device___191 *);
	int (*poweroff_noirq)(struct device___191 *);
	int (*restore_noirq)(struct device___191 *);
	int (*runtime_suspend)(struct device___191 *);
	int (*runtime_resume)(struct device___191 *);
	int (*runtime_idle)(struct device___191 *);
};

struct dev_pm_domain___191 {
	struct dev_pm_ops___191 ops;
	void (*detach)(struct device___191 *, bool);
	int (*activate)(struct device___191 *);
	void (*sync)(struct device___191 *);
	void (*dismiss)(struct device___191 *);
};

struct bus_type___191 {
	const char *name;
	const char *dev_name;
	struct device___191 *dev_root;
	const struct attribute_group___193 **bus_groups;
	const struct attribute_group___193 **dev_groups;
	const struct attribute_group___193 **drv_groups;
	int (*match)(struct device___191 *, struct device_driver___191 *);
	int (*uevent)(struct device___191 *, struct kobj_uevent_env *);
	int (*probe)(struct device___191 *);
	int (*remove)(struct device___191 *);
	void (*shutdown)(struct device___191 *);
	int (*online)(struct device___191 *);
	int (*offline)(struct device___191 *);
	int (*suspend)(struct device___191 *, pm_message_t);
	int (*resume)(struct device___191 *);
	int (*num_vf)(struct device___191 *);
	int (*dma_configure)(struct device___191 *);
	const struct dev_pm_ops___191 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___191 {
	const char *name;
	struct bus_type___191 *bus;
	struct module___11 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___191 *);
	int (*remove)(struct device___191 *);
	void (*shutdown)(struct device___191 *);
	int (*suspend)(struct device___191 *, pm_message_t);
	int (*resume)(struct device___191 *);
	const struct attribute_group___193 **groups;
	const struct dev_pm_ops___191 *pm;
	void (*coredump)(struct device___191 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct fwnode_operations___133;

struct fwnode_handle___133 {
	struct fwnode_handle___133 *secondary;
	const struct fwnode_operations___133 *ops;
};

struct disk_part_tbl___55 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___55 *last_lookup;
	struct hd_struct___55 *part[0];
};

struct block_device_operations___55 {
	int (*open)(struct block_device___220 *, fmode_t);
	void (*release)(struct gendisk___55 *, fmode_t);
	int (*rw_page)(struct block_device___220 *, sector_t, struct page___220 *, unsigned int);
	int (*ioctl)(struct block_device___220 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___220 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___55 *, unsigned int);
	int (*media_changed)(struct gendisk___55 *);
	void (*unlock_native_capacity)(struct gendisk___55 *);
	int (*revalidate_disk)(struct gendisk___55 *);
	int (*getgeo)(struct block_device___220 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___220 *, long unsigned int);
	int (*report_zones)(struct gendisk___55 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___11 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___54 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___55 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___55 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___55 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___54(struct request___55 *, blk_status_t);

struct request___55 {
	struct request_queue___55 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___109 *bio;
	struct bio___109 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___109 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___58 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___54 *saved_end_io;
		} flush;
	};
	struct gendisk___55 *rq_disk;
	struct hd_struct___55 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___54 *end_io;
	void *end_io_data;
	struct request___55 *next_rq;
};

struct fwnode_reference_args___133;

struct fwnode_endpoint___133;

struct fwnode_operations___133 {
	struct fwnode_handle___133 * (*get)(struct fwnode_handle___133 *);
	void (*put)(struct fwnode_handle___133 *);
	bool (*device_is_available)(const struct fwnode_handle___133 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___133 *, const struct device___191 *);
	bool (*property_present)(const struct fwnode_handle___133 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___133 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___133 *, const char *, const char **, size_t);
	struct fwnode_handle___133 * (*get_parent)(const struct fwnode_handle___133 *);
	struct fwnode_handle___133 * (*get_next_child_node)(const struct fwnode_handle___133 *, struct fwnode_handle___133 *);
	struct fwnode_handle___133 * (*get_named_child_node)(const struct fwnode_handle___133 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___133 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___133 *);
	struct fwnode_handle___133 * (*graph_get_next_endpoint)(const struct fwnode_handle___133 *, struct fwnode_handle___133 *);
	struct fwnode_handle___133 * (*graph_get_remote_endpoint)(const struct fwnode_handle___133 *);
	struct fwnode_handle___133 * (*graph_get_port_parent)(struct fwnode_handle___133 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___133 *, struct fwnode_endpoint___133 *);
};

struct fwnode_endpoint___133 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___133 *local_fwnode;
};

struct fwnode_reference_args___133 {
	struct fwnode_handle___133 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct elevator_type___54;

struct elevator_mq_ops___54 {
	int (*init_sched)(struct request_queue___55 *, struct elevator_type___54 *);
	void (*exit_sched)(struct elevator_queue___54 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	bool (*allow_merge)(struct request_queue___55 *, struct request___55 *, struct bio___109 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx *, struct bio___109 *);
	int (*request_merge)(struct request_queue___55 *, struct request___55 **, struct bio___109 *);
	void (*request_merged)(struct request_queue___55 *, struct request___55 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___55 *, struct request___55 *, struct request___55 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___55 *, struct bio___109 *);
	void (*finish_request)(struct request___55 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___55 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___55 *, u64);
	void (*started_request)(struct request___55 *);
	void (*requeue_request)(struct request___55 *);
	struct request___55 * (*former_request)(struct request_queue___55 *, struct request___55 *);
	struct request___55 * (*next_request)(struct request_queue___55 *, struct request___55 *);
	void (*init_icq)(struct io_cq___58 *);
	void (*exit_icq)(struct io_cq___58 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___54;

struct elevator_type___54 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___54 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___54 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___11 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___54 {
	struct elevator_type___54 *type;
	void *elevator_data;
	struct kobject___208 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___54 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___54 *, char *);
	ssize_t (*store)(struct elevator_queue___54 *, const char *, size_t);
};

struct blkcg_policy_data___43;

struct blkcg___43 {
	struct cgroup_subsys_state___175 css;
	spinlock_t lock;
	struct xarray blkg_tree;
	struct blkcg_gq___43 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___43 *cpd[5];
	struct list_head all_blkcgs_node;
	struct list_head cgwb_list;
	refcount_t cgwb_refcnt;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct blkcg_policy_data___43 {
	struct blkcg___43 *blkcg;
	int plid;
};

struct blkg_policy_data___43 {
	struct blkcg_gq___43 *blkg;
	int plid;
};

struct hstate___41;

struct hugepage_subpool___9 {
	spinlock_t lock;
	long int count;
	long int max_hpages;
	long int used_hpages;
	struct hstate___41 *hstate;
	long int min_hpages;
	long int rsv_hpages;
};

struct hstate___41 {
	int next_nid_to_alloc;
	int next_nid_to_free;
	unsigned int order;
	long unsigned int mask;
	long unsigned int max_huge_pages;
	long unsigned int nr_huge_pages;
	long unsigned int free_huge_pages;
	long unsigned int resv_huge_pages;
	long unsigned int surplus_huge_pages;
	long unsigned int nr_overcommit_huge_pages;
	struct list_head hugepage_activelist;
	struct list_head hugepage_freelists[8];
	unsigned int nr_huge_pages_node[8];
	unsigned int free_huge_pages_node[8];
	unsigned int surplus_huge_pages_node[8];
	struct cftype___174 cgroup_files[5];
	char name[32];
};

struct hugetlbfs_sb_info___9 {
	long int max_inodes;
	long int free_inodes;
	spinlock_t stat_lock;
	struct hstate___41 *hstate;
	struct hugepage_subpool___9 *spool;
	kuid_t uid;
	kgid_t gid;
	umode_t mode;
};

struct hugetlbfs_inode_info___2 {
	struct shared_policy policy;
	struct inode___220 vfs_inode;
	unsigned int seals;
};

struct pagevec___11 {
	unsigned char nr;
	bool percpu_pvec_drained;
	struct page___220 *pages[15];
};

struct hugetlbfs_config {
	struct hstate___41 *hstate;
	long int max_hpages;
	long int nr_inodes;
	long int min_hpages;
	kuid_t uid;
	kgid_t gid;
	umode_t mode;
};

enum {
	Opt_size = 0,
	Opt_nr_inodes = 1,
	Opt_mode___3 = 2,
	Opt_uid___2 = 3,
	Opt_gid___3 = 4,
	Opt_pagesize = 5,
	Opt_min_size = 6,
	Opt_err___4 = 7,
};

enum hugetlbfs_size_type {
	NO_SIZE = 0,
	SIZE_STD = 1,
	SIZE_PERCENT = 2,
};

struct inode___221;

struct dentry___221;

struct super_block___220;

struct iattr___220;

struct export_operations___10 {
	int (*encode_fh)(struct inode___221 *, __u32 *, int *, struct inode___221 *);
	struct dentry___221 * (*fh_to_dentry)(struct super_block___220 *, struct fid *, int, int);
	struct dentry___221 * (*fh_to_parent)(struct super_block___220 *, struct fid *, int, int);
	int (*get_name)(struct dentry___221 *, char *, struct dentry___221 *);
	struct dentry___221 * (*get_parent)(struct dentry___221 *);
	int (*commit_metadata)(struct inode___221 *);
	int (*get_uuid)(struct super_block___220 *, u8 *, u32 *, u64 *);
	int (*map_blocks)(struct inode___221 *, loff_t, u64, struct iomap *, bool, u32 *);
	int (*commit_blocks)(struct inode___221 *, struct iomap *, int, struct iattr___220 *);
};

struct task_struct___221;

struct rw_semaphore___221 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___221 *owner;
};

struct address_space_operations___220;

struct address_space___220 {
	struct inode___221 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___221 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___220 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___220;

struct file_operations___221;

struct block_device___221;

struct inode___221 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___220 *i_op;
	struct super_block___220 *i_sb;
	struct address_space___220 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___221 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___221 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___220 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___221 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___220;

struct dentry___221 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___221 *d_parent;
	struct qstr d_name;
	struct inode___221 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___220 *d_op;
	struct super_block___220 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct quota_format_type___220;

struct mem_dqinfo___220 {
	struct quota_format_type___220 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___220;

struct quota_info___220 {
	unsigned int flags;
	struct rw_semaphore___221 dqio_sem;
	struct inode___221 *files[3];
	struct mem_dqinfo___220 info[3];
	const struct quota_format_ops___220 *ops[3];
};

struct rcuwait___220 {
	struct task_struct___221 *task;
};

struct percpu_rw_semaphore___220 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___221 rw_sem;
	struct rcuwait___220 writer;
	int readers_block;
};

struct sb_writers___220 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___220 rw_sem[3];
};

struct file_system_type___220;

struct super_operations___220;

struct dquot_operations___220;

struct quotactl_ops___220;

struct super_block___220 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___220 *s_type;
	const struct super_operations___220 *s_op;
	const struct dquot_operations___220 *dq_op;
	const struct quotactl_ops___220 *s_qcop;
	const struct export_operations___10 *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___221 *s_root;
	struct rw_semaphore___221 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___221 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___220 s_dquot;
	struct sb_writers___220 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___220 *s_d_op;
	int cleancache_poolid;
	struct shrinker___95 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct file___221;

struct iattr___220 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___221 *ia_file;
};

struct module___178;

struct kiocb___221;

struct vm_area_struct___221;

struct file_lock___221;

struct page___221;

struct file_operations___221 {
	struct module___178 *owner;
	loff_t (*llseek)(struct file___221 *, loff_t, int);
	ssize_t (*read)(struct file___221 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___221 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___221 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___221 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___221 *, bool);
	int (*iterate)(struct file___221 *, struct dir_context *);
	int (*iterate_shared)(struct file___221 *, struct dir_context *);
	__poll_t (*poll)(struct file___221 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___221 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___221 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___221 *, struct vm_area_struct___221 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___221 *, struct file___221 *);
	int (*flush)(struct file___221 *, fl_owner_t);
	int (*release)(struct inode___221 *, struct file___221 *);
	int (*fsync)(struct file___221 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___221 *, int);
	int (*lock)(struct file___221 *, int, struct file_lock___221 *);
	ssize_t (*sendpage)(struct file___221 *, struct page___221 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___221 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___221 *, int, struct file_lock___221 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___221 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___221 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___221 *, long int, struct file_lock___221 **, void **);
	long int (*fallocate)(struct file___221 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___221 *);
	ssize_t (*copy_file_range)(struct file___221 *, loff_t, struct file___221 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___221 *, loff_t, struct file___221 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___221 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___220 {
	u64 seqnum;
	struct vm_area_struct___221 *vmas[4];
};

struct page_frag___220 {
	struct page___221 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___220;

struct cred___214;

struct task_struct___221 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___221 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___220 *mm;
	struct mm_struct___220 *active_mm;
	struct vmacache___220 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___221 *real_parent;
	struct task_struct___221 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___221 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___167 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___167 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___167 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___214 *ptracer_cred;
	const struct cred___214 *real_cred;
	const struct cred___214 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___221 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___58 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___220 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___221 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___120 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct vfsmount___52;

struct path___220;

struct dentry_operations___220 {
	int (*d_revalidate)(struct dentry___221 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___221 *, unsigned int);
	int (*d_hash)(const struct dentry___221 *, struct qstr *);
	int (*d_compare)(const struct dentry___221 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___221 *);
	int (*d_init)(struct dentry___221 *);
	void (*d_release)(struct dentry___221 *);
	void (*d_prune)(struct dentry___221 *);
	void (*d_iput)(struct dentry___221 *, struct inode___221 *);
	char * (*d_dname)(struct dentry___221 *, char *, int);
	struct vfsmount___52 * (*d_automount)(struct path___220 *);
	int (*d_manage)(const struct path___220 *, bool);
	struct dentry___221 * (*d_real)(struct dentry___221 *, const struct inode___221 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct vfsmount___52 {
	struct dentry___221 *mnt_root;
	struct super_block___220 *mnt_sb;
	int mnt_flags;
};

struct path___220 {
	struct vfsmount___52 *mnt;
	struct dentry___221 *dentry;
};

typedef struct page___221 *pgtable_t___220;

struct page___221 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___220 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___221 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___220 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___220 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___214 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___220;

struct lruvec___220 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___220 *pgdat;
};

struct zone___220 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___220 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___220 {
	struct zone___220 *zone;
	int zone_idx;
};

struct zonelist___220 {
	struct zoneref___220 _zonerefs[25];
};

struct pglist_data___220 {
	struct zone___220 node_zones[3];
	struct zonelist___220 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___221 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___221 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___220 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___221 {
	void *stack;
	struct task_struct___221 *task;
	long int status;
};

struct blocking_notifier_head___220 {
	struct rw_semaphore___221 rwsem;
	struct notifier_block *head;
};

struct vm_area_struct___221 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___221 *vm_next;
	struct vm_area_struct___221 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___220 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___13 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___221 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___220;

struct mm_struct___220 {
	struct {
		struct vm_area_struct___221 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___221 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___221 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___220 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___221 *owner;
		struct user_namespace___3 *user_ns;
		struct file___221 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___220 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct file___221 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___220 f_path;
	struct inode___221 *f_inode;
	const struct file_operations___221 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___167 f_owner;
	const struct cred___214 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___220 *f_mapping;
	errseq_t f_wb_err;
};

struct core_thread___220 {
	struct task_struct___221 *task;
	struct core_thread___220 *next;
};

struct core_state___220 {
	atomic_t nr_threads;
	struct core_thread___220 dumper;
	struct completion startup;
};

struct key___214;

struct user_struct___214 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___214 *uid_keyring;
	struct key___214 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___214 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___214 *session_keyring;
	struct key___214 *process_keyring;
	struct key___214 *thread_keyring;
	struct key___214 *request_key_auth;
	void *security;
	struct user_struct___214 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kiocb___221 {
	struct file___221 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___221 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dquot___220 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___220 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___220 {
	int qf_fmt_id;
	const struct quota_format_ops___220 *qf_ops;
	struct module___178 *qf_owner;
	struct quota_format_type___220 *qf_next;
};

struct quota_format_ops___220 {
	int (*check_quota_file)(struct super_block___220 *, int);
	int (*read_file_info)(struct super_block___220 *, int);
	int (*write_file_info)(struct super_block___220 *, int);
	int (*free_file_info)(struct super_block___220 *, int);
	int (*read_dqblk)(struct dquot___220 *);
	int (*commit_dqblk)(struct dquot___220 *);
	int (*release_dqblk)(struct dquot___220 *);
	int (*get_next_id)(struct super_block___220 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___220 {
	int (*write_dquot)(struct dquot___220 *);
	struct dquot___220 * (*alloc_dquot)(struct super_block___220 *, int);
	void (*destroy_dquot)(struct dquot___220 *);
	int (*acquire_dquot)(struct dquot___220 *);
	int (*release_dquot)(struct dquot___220 *);
	int (*mark_dirty)(struct dquot___220 *);
	int (*write_info)(struct super_block___220 *, int);
	qsize_t * (*get_reserved_space)(struct inode___221 *);
	int (*get_projid)(struct inode___221 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___221 *, qsize_t *);
	int (*get_next_id)(struct super_block___220 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___220 {
	int (*quota_on)(struct super_block___220 *, int, int, const struct path___220 *);
	int (*quota_off)(struct super_block___220 *, int);
	int (*quota_enable)(struct super_block___220 *, unsigned int);
	int (*quota_disable)(struct super_block___220 *, unsigned int);
	int (*quota_sync)(struct super_block___220 *, int);
	int (*set_info)(struct super_block___220 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___220 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___220 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___220 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___220 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___220 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___208;

struct kobj_type___208;

struct kernfs_node___215;

struct kobject___209 {
	const char *name;
	struct list_head entry;
	struct kobject___209 *parent;
	struct kset___208 *kset;
	struct kobj_type___208 *ktype;
	struct kernfs_node___215 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___175 {
	struct kobject___209 kobj;
	struct module___178 *mod;
	struct kobject___209 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___175 {
	struct module___178 *mod;
	struct latch_tree_node node;
};

struct module_layout___175 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___175 mtn;
};

struct module_attribute___175;

struct kernel_param___175;

struct module___178 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___175 mkobj;
	struct module_attribute___175 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___209 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___175 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___175 core_layout;
	struct module_layout___175 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___220 {
	int (*writepage)(struct page___221 *, struct writeback_control___3 *);
	int (*readpage)(struct file___221 *, struct page___221 *);
	int (*writepages)(struct address_space___220 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___221 *);
	int (*readpages)(struct file___221 *, struct address_space___220 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___221 *, struct address_space___220 *, loff_t, unsigned int, unsigned int, struct page___221 **, void **);
	int (*write_end)(struct file___221 *, struct address_space___220 *, loff_t, unsigned int, unsigned int, struct page___221 *, void *);
	sector_t (*bmap)(struct address_space___220 *, sector_t);
	void (*invalidatepage)(struct page___221 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___221 *, gfp_t);
	void (*freepage)(struct page___221 *);
	ssize_t (*direct_IO)(struct kiocb___221 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___220 *, struct page___221 *, struct page___221 *, enum migrate_mode);
	bool (*isolate_page)(struct page___221 *, isolate_mode_t);
	void (*putback_page)(struct page___221 *);
	int (*launder_page)(struct page___221 *);
	int (*is_partially_uptodate)(struct page___221 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___221 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___220 *, struct page___221 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___221 *, sector_t *);
	void (*swap_deactivate)(struct file___221 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___221 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___221 *bd_inode;
	struct super_block___220 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___221 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___220 {
	struct dentry___221 * (*lookup)(struct inode___221 *, struct dentry___221 *, unsigned int);
	const char * (*get_link)(struct dentry___221 *, struct inode___221 *, struct delayed_call *);
	int (*permission)(struct inode___221 *, int);
	struct posix_acl * (*get_acl)(struct inode___221 *, int);
	int (*readlink)(struct dentry___221 *, char *, int);
	int (*create)(struct inode___221 *, struct dentry___221 *, umode_t, bool);
	int (*link)(struct dentry___221 *, struct inode___221 *, struct dentry___221 *);
	int (*unlink)(struct inode___221 *, struct dentry___221 *);
	int (*symlink)(struct inode___221 *, struct dentry___221 *, const char *);
	int (*mkdir)(struct inode___221 *, struct dentry___221 *, umode_t);
	int (*rmdir)(struct inode___221 *, struct dentry___221 *);
	int (*mknod)(struct inode___221 *, struct dentry___221 *, umode_t, dev_t);
	int (*rename)(struct inode___221 *, struct dentry___221 *, struct inode___221 *, struct dentry___221 *, unsigned int);
	int (*setattr)(struct dentry___221 *, struct iattr___220 *);
	int (*getattr)(const struct path___220 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___221 *, char *, size_t);
	int (*fiemap)(struct inode___221 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___221 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___221 *, struct dentry___221 *, struct file___221 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___221 *, struct dentry___221 *, umode_t);
	int (*set_acl)(struct inode___221 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___220 {
	void (*fl_copy_lock)(struct file_lock___221 *, struct file_lock___221 *);
	void (*fl_release_private)(struct file_lock___221 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___220;

struct lock_manager_operations___220;

struct file_lock___221 {
	struct file_lock___221 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___221 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___220 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___220 *fl_ops;
	const struct lock_manager_operations___220 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___220 {
	int (*lm_compare_owner)(struct file_lock___221 *, struct file_lock___221 *);
	long unsigned int (*lm_owner_key)(struct file_lock___221 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___221 *);
	int (*lm_grant)(struct file_lock___221 *, int);
	bool (*lm_break)(struct file_lock___221 *);
	int (*lm_change)(struct file_lock___221 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___221 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___220 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___220 *fa_next;
	struct file___221 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___220 {
	const char *name;
	int fs_flags;
	struct dentry___221 * (*mount)(struct file_system_type___220 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___220 *);
	struct module___178 *owner;
	struct file_system_type___220 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___220 {
	struct inode___221 * (*alloc_inode)(struct super_block___220 *);
	void (*destroy_inode)(struct inode___221 *);
	void (*dirty_inode)(struct inode___221 *, int);
	int (*write_inode)(struct inode___221 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___221 *);
	void (*evict_inode)(struct inode___221 *);
	void (*put_super)(struct super_block___220 *);
	int (*sync_fs)(struct super_block___220 *, int);
	int (*freeze_super)(struct super_block___220 *);
	int (*freeze_fs)(struct super_block___220 *);
	int (*thaw_super)(struct super_block___220 *);
	int (*unfreeze_fs)(struct super_block___220 *);
	int (*statfs)(struct dentry___221 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___220 *, int *, char *);
	void (*umount_begin)(struct super_block___220 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___221 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___221 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___221 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___221 *);
	ssize_t (*quota_read)(struct super_block___220 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___220 *, int, const char *, size_t, loff_t);
	struct dquot___220 ** (*get_dquots)(struct inode___221 *);
	int (*bdev_try_to_free_page)(struct super_block___220 *, struct page___221 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___220 *, struct shrink_control___95 *);
	long int (*free_cached_objects)(struct super_block___220 *, struct shrink_control___95 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_root___215;

struct kernfs_elem_dir___215 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___215 *root;
};

struct kernfs_syscall_ops___215;

struct kernfs_root___215 {
	struct kernfs_node___215 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___215 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___215 {
	struct kernfs_node___215 *target_kn;
};

struct kernfs_ops___215;

struct kernfs_elem_attr___215 {
	const struct kernfs_ops___215 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___215 *notify_next;
};

struct kernfs_node___215 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___215 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___215 dir;
		struct kernfs_elem_symlink___215 symlink;
		struct kernfs_elem_attr___215 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___215;

struct kernfs_ops___215 {
	int (*open)(struct kernfs_open_file___215 *);
	void (*release)(struct kernfs_open_file___215 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___215 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___215 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___215 *, struct vm_area_struct___221 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___215 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___215 {
	int (*remount_fs)(struct kernfs_root___215 *, int *, char *);
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___215 *);
	int (*mkdir)(struct kernfs_node___215 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___215 *);
	int (*rename)(struct kernfs_node___215 *, struct kernfs_node___215 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___215 *, struct kernfs_root___215 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___215 {
	struct kernfs_node___215 *kn;
	struct file___221 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___13 *vm_ops;
};

struct sysfs_ops___208 {
	ssize_t (*show)(struct kobject___209 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___209 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___208;

struct kset___208 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___209 kobj;
	const struct kset_uevent_ops___208 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___208 {
	void (*release)(struct kobject___209 *);
	const struct sysfs_ops___208 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___12 * (*child_ns_type)(struct kobject___209 *);
	const void * (*namespace)(struct kobject___209 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___208 {
	int (* const filter)(struct kset___208 *, struct kobject___209 *);
	const char * (* const name)(struct kset___208 *, struct kobject___209 *);
	int (* const uevent)(struct kset___208 *, struct kobject___209 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___175 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___175 *);
	int (*get)(char *, const struct kernel_param___175 *);
	void (*free)(void *);
};

struct kparam_array___175;

struct kernel_param___175 {
	const char *name;
	struct module___178 *mod;
	const struct kernel_param_ops___175 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___175 *arr;
	};
};

struct kparam_array___175 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___175 *ops;
	void *elem;
};

struct module_attribute___175 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___175 *, struct module_kobject___175 *, char *);
	ssize_t (*store)(struct module_attribute___175 *, struct module_kobject___175 *, const char *, size_t);
	void (*setup)(struct module___178 *, const char *);
	int (*test)(struct module___178 *);
	void (*free)(struct module___178 *);
};

typedef int (*key_restrict_link_func_t___214)(struct key___214 *, const struct key_type *, const union key_payload *, struct key___214 *);

struct key_restriction___214;

struct key___214 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___221 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___214 *restrict_link;
};

struct key_restriction___214 {
	key_restrict_link_func_t___214 check;
	struct key___214 *key;
	struct key_type *keytype;
};

struct getdents_callback___2 {
	struct dir_context ctx;
	char *name;
	u64 ino;
	int found;
	int sequence;
};

typedef u16 wchar_t;

typedef u32 unicode_t;

struct nls_table {
	const char *charset;
	const char *alias;
	int (*uni2char)(wchar_t, unsigned char *, int);
	int (*char2uni)(const unsigned char *, int, wchar_t *);
	const unsigned char *charset2lower;
	const unsigned char *charset2upper;
	struct module___177 *owner;
	struct nls_table *next;
};

enum utf16_endian {
	UTF16_HOST_ENDIAN = 0,
	UTF16_LITTLE_ENDIAN = 1,
	UTF16_BIG_ENDIAN = 2,
};

struct utf8_table {
	int cmask;
	int cval;
	int shift;
	long int lmask;
	long int lval;
};

struct module___179;

struct file___222;

struct kiocb___222;

struct vm_area_struct___222;

struct inode___222;

struct file_lock___222;

struct page___222;

struct file_operations___222 {
	struct module___179 *owner;
	loff_t (*llseek)(struct file___222 *, loff_t, int);
	ssize_t (*read)(struct file___222 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___222 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___222 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___222 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___222 *, bool);
	int (*iterate)(struct file___222 *, struct dir_context *);
	int (*iterate_shared)(struct file___222 *, struct dir_context *);
	__poll_t (*poll)(struct file___222 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___222 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___222 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___222 *, struct vm_area_struct___222 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___222 *, struct file___222 *);
	int (*flush)(struct file___222 *, fl_owner_t);
	int (*release)(struct inode___222 *, struct file___222 *);
	int (*fsync)(struct file___222 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___222 *, int);
	int (*lock)(struct file___222 *, int, struct file_lock___222 *);
	ssize_t (*sendpage)(struct file___222 *, struct page___222 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___222 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___222 *, int, struct file_lock___222 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___222 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___222 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___222 *, long int, struct file_lock___222 **, void **);
	long int (*fallocate)(struct file___222 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___222 *);
	ssize_t (*copy_file_range)(struct file___222 *, loff_t, struct file___222 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___222 *, loff_t, struct file___222 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___222 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___221 {
	u64 seqnum;
	struct vm_area_struct___222 *vmas[4];
};

struct page_frag___221 {
	struct page___222 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___221;

struct cred___215;

struct signal_struct___185;

struct task_struct___222 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___222 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___221 *mm;
	struct mm_struct___221 *active_mm;
	struct vmacache___221 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___222 *real_parent;
	struct task_struct___222 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___222 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___167 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___167 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___167 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___215 *ptracer_cred;
	const struct cred___215 *real_cred;
	const struct cred___215 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___185 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___222 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___58 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___221 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___222 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___120 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___222 *pgtable_t___221;

struct address_space___221;

struct page___222 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___221 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___222 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___221 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___221 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___214 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___221;

struct lruvec___221 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___221 *pgdat;
};

struct zone___221 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___221 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___221 {
	struct zone___221 *zone;
	int zone_idx;
};

struct zonelist___221 {
	struct zoneref___221 _zonerefs[25];
};

struct pglist_data___221 {
	struct zone___221 node_zones[3];
	struct zonelist___221 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___222 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___222 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___221 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___222 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___222 *owner;
};

struct secondary_data___222 {
	void *stack;
	struct task_struct___222 *task;
	long int status;
};

struct blocking_notifier_head___221 {
	struct rw_semaphore___222 rwsem;
	struct notifier_block *head;
};

struct vfsmount___53;

struct dentry___222;

struct path___221 {
	struct vfsmount___53 *mnt;
	struct dentry___222 *dentry;
};

struct file___222 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___221 f_path;
	struct inode___222 *f_inode;
	const struct file_operations___222 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___167 f_owner;
	const struct cred___215 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___221 *f_mapping;
	errseq_t f_wb_err;
};

struct key___215;

struct user_struct___215;

struct cred___215 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___215 *session_keyring;
	struct key___215 *process_keyring;
	struct key___215 *thread_keyring;
	struct key___215 *request_key_auth;
	void *security;
	struct user_struct___215 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___216;

struct kernfs_elem_dir___216 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___216 *root;
};

struct kernfs_node___216;

struct kernfs_syscall_ops___216;

struct kernfs_root___216 {
	struct kernfs_node___216 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___216 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___216 {
	struct kernfs_node___216 *target_kn;
};

struct kernfs_ops___216;

struct kernfs_elem_attr___216 {
	const struct kernfs_ops___216 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___216 *notify_next;
};

struct kernfs_node___216 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___216 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___216 dir;
		struct kernfs_elem_symlink___216 symlink;
		struct kernfs_elem_attr___216 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___216;

struct kernfs_ops___216 {
	int (*open)(struct kernfs_open_file___216 *);
	void (*release)(struct kernfs_open_file___216 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___216 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___216 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___216 *, struct vm_area_struct___222 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___216 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___216 {
	int (*remount_fs)(struct kernfs_root___216 *, int *, char *);
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___216 *);
	int (*mkdir)(struct kernfs_node___216 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___216 *);
	int (*rename)(struct kernfs_node___216 *, struct kernfs_node___216 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___216 *, struct kernfs_root___216 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___216 {
	struct kernfs_node___216 *kn;
	struct file___222 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___13 *vm_ops;
};

struct vm_area_struct___222 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___222 *vm_next;
	struct vm_area_struct___222 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___221 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___13 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___222 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___209;

struct kobj_type___209;

struct kobject___210 {
	const char *name;
	struct list_head entry;
	struct kobject___210 *parent;
	struct kset___209 *kset;
	struct kobj_type___209 *ktype;
	struct kernfs_node___216 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sysfs_ops___209 {
	ssize_t (*show)(struct kobject___210 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___210 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___209;

struct kset___209 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___210 kobj;
	const struct kset_uevent_ops___209 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___209 {
	void (*release)(struct kobject___210 *);
	const struct sysfs_ops___209 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___12 * (*child_ns_type)(struct kobject___210 *);
	const void * (*namespace)(struct kobject___210 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___209 {
	int (* const filter)(struct kset___209 *, struct kobject___210 *);
	const char * (* const name)(struct kset___209 *, struct kobject___210 *);
	int (* const uevent)(struct kset___209 *, struct kobject___210 *, struct kobj_uevent_env *);
};

struct kernel_param___176;

struct kernel_param_ops___176 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___176 *);
	int (*get)(char *, const struct kernel_param___176 *);
	void (*free)(void *);
};

struct kparam_array___176;

struct kernel_param___176 {
	const char *name;
	struct module___179 *mod;
	const struct kernel_param_ops___176 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___176 *arr;
	};
};

struct kparam_array___176 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___176 *ops;
	void *elem;
};

struct module_kobject___176 {
	struct kobject___210 kobj;
	struct module___179 *mod;
	struct kobject___210 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___176 {
	struct module___179 *mod;
	struct latch_tree_node node;
};

struct module_layout___176 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___176 mtn;
};

struct module_attribute___176;

struct module___179 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___176 mkobj;
	struct module_attribute___176 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___210 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___176 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___176 core_layout;
	struct module_layout___176 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___176 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___176 *, struct module_kobject___176 *, char *);
	ssize_t (*store)(struct module_attribute___176 *, struct module_kobject___176 *, const char *, size_t);
	void (*setup)(struct module___179 *, const char *);
	int (*test)(struct module___179 *);
	void (*free)(struct module___179 *);
};

struct dentry_operations___221;

struct super_block___221;

struct dentry___222 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___222 *d_parent;
	struct qstr d_name;
	struct inode___222 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___221 *d_op;
	struct super_block___221 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___221;

struct address_space___221 {
	struct inode___222 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___222 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___221 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___221;

struct block_device___222;

struct inode___222 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___221 *i_op;
	struct super_block___221 *i_sb;
	struct address_space___221 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___222 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___222 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___221 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___222 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___221 {
	int (*d_revalidate)(struct dentry___222 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___222 *, unsigned int);
	int (*d_hash)(const struct dentry___222 *, struct qstr *);
	int (*d_compare)(const struct dentry___222 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___222 *);
	int (*d_init)(struct dentry___222 *);
	void (*d_release)(struct dentry___222 *);
	void (*d_prune)(struct dentry___222 *);
	void (*d_iput)(struct dentry___222 *, struct inode___222 *);
	char * (*d_dname)(struct dentry___222 *, char *, int);
	struct vfsmount___53 * (*d_automount)(struct path___221 *);
	int (*d_manage)(const struct path___221 *, bool);
	struct dentry___222 * (*d_real)(struct dentry___222 *, const struct inode___222 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___221;

struct mem_dqinfo___221 {
	struct quota_format_type___221 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___221;

struct quota_info___221 {
	unsigned int flags;
	struct rw_semaphore___222 dqio_sem;
	struct inode___222 *files[3];
	struct mem_dqinfo___221 info[3];
	const struct quota_format_ops___221 *ops[3];
};

struct rcuwait___221 {
	struct task_struct___222 *task;
};

struct percpu_rw_semaphore___221 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___222 rw_sem;
	struct rcuwait___221 writer;
	int readers_block;
};

struct sb_writers___221 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___221 rw_sem[3];
};

struct file_system_type___221;

struct super_operations___221;

struct dquot_operations___221;

struct quotactl_ops___221;

struct super_block___221 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___221 *s_type;
	const struct super_operations___221 *s_op;
	const struct dquot_operations___221 *dq_op;
	const struct quotactl_ops___221 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___222 *s_root;
	struct rw_semaphore___222 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___222 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___221 s_dquot;
	struct sb_writers___221 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___221 *s_d_op;
	int cleancache_poolid;
	struct shrinker___95 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___53 {
	struct dentry___222 *mnt_root;
	struct super_block___221 *mnt_sb;
	int mnt_flags;
};

struct core_state___221;

struct mm_struct___221 {
	struct {
		struct vm_area_struct___222 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___222 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___222 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___221 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___222 *owner;
		struct user_namespace___3 *user_ns;
		struct file___222 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___221 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct core_thread___221 {
	struct task_struct___222 *task;
	struct core_thread___221 *next;
};

struct core_state___221 {
	atomic_t nr_threads;
	struct core_thread___221 dumper;
	struct completion startup;
};

struct user_struct___215 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___215 *uid_keyring;
	struct key___215 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct signal_struct___185 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___222 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___222 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___167 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___167 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___221 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___167 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

union thread_union___196 {
	struct task_struct___222 task;
	long unsigned int stack[8192];
};

struct kiocb___222 {
	struct file___222 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___222 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___221 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___222 *ia_file;
};

struct dquot___221 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___221 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___221 {
	int qf_fmt_id;
	const struct quota_format_ops___221 *qf_ops;
	struct module___179 *qf_owner;
	struct quota_format_type___221 *qf_next;
};

struct quota_format_ops___221 {
	int (*check_quota_file)(struct super_block___221 *, int);
	int (*read_file_info)(struct super_block___221 *, int);
	int (*write_file_info)(struct super_block___221 *, int);
	int (*free_file_info)(struct super_block___221 *, int);
	int (*read_dqblk)(struct dquot___221 *);
	int (*commit_dqblk)(struct dquot___221 *);
	int (*release_dqblk)(struct dquot___221 *);
	int (*get_next_id)(struct super_block___221 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___221 {
	int (*write_dquot)(struct dquot___221 *);
	struct dquot___221 * (*alloc_dquot)(struct super_block___221 *, int);
	void (*destroy_dquot)(struct dquot___221 *);
	int (*acquire_dquot)(struct dquot___221 *);
	int (*release_dquot)(struct dquot___221 *);
	int (*mark_dirty)(struct dquot___221 *);
	int (*write_info)(struct super_block___221 *, int);
	qsize_t * (*get_reserved_space)(struct inode___222 *);
	int (*get_projid)(struct inode___222 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___222 *, qsize_t *);
	int (*get_next_id)(struct super_block___221 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___221 {
	int (*quota_on)(struct super_block___221 *, int, int, const struct path___221 *);
	int (*quota_off)(struct super_block___221 *, int);
	int (*quota_enable)(struct super_block___221 *, unsigned int);
	int (*quota_disable)(struct super_block___221 *, unsigned int);
	int (*quota_sync)(struct super_block___221 *, int);
	int (*set_info)(struct super_block___221 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___221 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___221 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___221 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___221 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___221 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___221 {
	int (*writepage)(struct page___222 *, struct writeback_control___3 *);
	int (*readpage)(struct file___222 *, struct page___222 *);
	int (*writepages)(struct address_space___221 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___222 *);
	int (*readpages)(struct file___222 *, struct address_space___221 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___222 *, struct address_space___221 *, loff_t, unsigned int, unsigned int, struct page___222 **, void **);
	int (*write_end)(struct file___222 *, struct address_space___221 *, loff_t, unsigned int, unsigned int, struct page___222 *, void *);
	sector_t (*bmap)(struct address_space___221 *, sector_t);
	void (*invalidatepage)(struct page___222 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___222 *, gfp_t);
	void (*freepage)(struct page___222 *);
	ssize_t (*direct_IO)(struct kiocb___222 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___221 *, struct page___222 *, struct page___222 *, enum migrate_mode);
	bool (*isolate_page)(struct page___222 *, isolate_mode_t);
	void (*putback_page)(struct page___222 *);
	int (*launder_page)(struct page___222 *);
	int (*is_partially_uptodate)(struct page___222 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___222 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___221 *, struct page___222 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___222 *, sector_t *);
	void (*swap_deactivate)(struct file___222 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___222 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___222 *bd_inode;
	struct super_block___221 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___222 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___221 {
	struct dentry___222 * (*lookup)(struct inode___222 *, struct dentry___222 *, unsigned int);
	const char * (*get_link)(struct dentry___222 *, struct inode___222 *, struct delayed_call *);
	int (*permission)(struct inode___222 *, int);
	struct posix_acl * (*get_acl)(struct inode___222 *, int);
	int (*readlink)(struct dentry___222 *, char *, int);
	int (*create)(struct inode___222 *, struct dentry___222 *, umode_t, bool);
	int (*link)(struct dentry___222 *, struct inode___222 *, struct dentry___222 *);
	int (*unlink)(struct inode___222 *, struct dentry___222 *);
	int (*symlink)(struct inode___222 *, struct dentry___222 *, const char *);
	int (*mkdir)(struct inode___222 *, struct dentry___222 *, umode_t);
	int (*rmdir)(struct inode___222 *, struct dentry___222 *);
	int (*mknod)(struct inode___222 *, struct dentry___222 *, umode_t, dev_t);
	int (*rename)(struct inode___222 *, struct dentry___222 *, struct inode___222 *, struct dentry___222 *, unsigned int);
	int (*setattr)(struct dentry___222 *, struct iattr___221 *);
	int (*getattr)(const struct path___221 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___222 *, char *, size_t);
	int (*fiemap)(struct inode___222 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___222 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___222 *, struct dentry___222 *, struct file___222 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___222 *, struct dentry___222 *, umode_t);
	int (*set_acl)(struct inode___222 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___221 {
	void (*fl_copy_lock)(struct file_lock___222 *, struct file_lock___222 *);
	void (*fl_release_private)(struct file_lock___222 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___221;

struct lock_manager_operations___221;

struct file_lock___222 {
	struct file_lock___222 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___222 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___221 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___221 *fl_ops;
	const struct lock_manager_operations___221 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___221 {
	int (*lm_compare_owner)(struct file_lock___222 *, struct file_lock___222 *);
	long unsigned int (*lm_owner_key)(struct file_lock___222 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___222 *);
	int (*lm_grant)(struct file_lock___222 *, int);
	bool (*lm_break)(struct file_lock___222 *);
	int (*lm_change)(struct file_lock___222 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___222 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___221 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___221 *fa_next;
	struct file___222 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___221 {
	const char *name;
	int fs_flags;
	struct dentry___222 * (*mount)(struct file_system_type___221 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___221 *);
	struct module___179 *owner;
	struct file_system_type___221 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___221 {
	struct inode___222 * (*alloc_inode)(struct super_block___221 *);
	void (*destroy_inode)(struct inode___222 *);
	void (*dirty_inode)(struct inode___222 *, int);
	int (*write_inode)(struct inode___222 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___222 *);
	void (*evict_inode)(struct inode___222 *);
	void (*put_super)(struct super_block___221 *);
	int (*sync_fs)(struct super_block___221 *, int);
	int (*freeze_super)(struct super_block___221 *);
	int (*freeze_fs)(struct super_block___221 *);
	int (*thaw_super)(struct super_block___221 *);
	int (*unfreeze_fs)(struct super_block___221 *);
	int (*statfs)(struct dentry___222 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___221 *, int *, char *);
	void (*umount_begin)(struct super_block___221 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___222 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___222 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___222 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___222 *);
	ssize_t (*quota_read)(struct super_block___221 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___221 *, int, const char *, size_t, loff_t);
	struct dquot___221 ** (*get_dquots)(struct inode___222 *);
	int (*bdev_try_to_free_page)(struct super_block___221 *, struct page___222 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___221 *, struct shrink_control___95 *);
	long int (*free_cached_objects)(struct super_block___221 *, struct shrink_control___95 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*key_restrict_link_func_t___215)(struct key___215 *, const struct key_type *, const union key_payload *, struct key___215 *);

struct key_restriction___215;

struct key___215 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___222 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___215 *restrict_link;
};

struct key_restriction___215 {
	key_restrict_link_func_t___215 check;
	struct key___215 *key;
	struct key_type *keytype;
};

typedef unsigned int autofs_wqt_t;

struct autofs_sb_info;

struct autofs_info {
	struct dentry___161 *dentry;
	struct inode___162 *inode;
	int flags;
	struct completion expire_complete;
	struct list_head active;
	int active_count;
	struct list_head expiring;
	struct autofs_sb_info *sbi;
	long unsigned int last_used;
	atomic_t count;
	kuid_t uid;
	kgid_t gid;
};

struct autofs_wait_queue;

struct autofs_sb_info {
	u32 magic;
	int pipefd;
	struct file___162 *pipe;
	struct pid___127 *oz_pgrp;
	int version;
	int sub_version;
	int min_proto;
	int max_proto;
	unsigned int flags;
	long unsigned int exp_timeout;
	unsigned int type;
	struct super_block___161 *sb;
	struct mutex wq_mutex;
	struct mutex pipe_mutex;
	spinlock_t fs_lock;
	struct autofs_wait_queue *queues;
	spinlock_t lookup_lock;
	struct list_head active_list;
	struct list_head expiring_list;
	struct callback_head rcu;
};

struct autofs_wait_queue {
	wait_queue_head_t queue;
	struct autofs_wait_queue *next;
	autofs_wqt_t wait_queue_token;
	struct qstr name;
	u32 dev;
	u64 ino;
	kuid_t uid;
	kgid_t gid;
	pid_t pid;
	pid_t tgid;
	int status;
	unsigned int wait_ctr;
};

enum {
	Opt_err___5 = 0,
	Opt_fd = 1,
	Opt_uid___3 = 2,
	Opt_gid___4 = 3,
	Opt_pgrp = 4,
	Opt_minproto = 5,
	Opt_maxproto = 6,
	Opt_indirect = 7,
	Opt_direct = 8,
	Opt_offset = 9,
	Opt_strictexpire = 10,
};

enum {
	AUTOFS_IOC_READY_CMD = 96,
	AUTOFS_IOC_FAIL_CMD = 97,
	AUTOFS_IOC_CATATONIC_CMD = 98,
	AUTOFS_IOC_PROTOVER_CMD = 99,
	AUTOFS_IOC_SETTIMEOUT_CMD = 100,
	AUTOFS_IOC_EXPIRE_CMD = 101,
};

enum autofs_notify {
	NFY_NONE = 0,
	NFY_MOUNT = 1,
	NFY_EXPIRE = 2,
};

enum {
	AUTOFS_IOC_EXPIRE_MULTI_CMD = 102,
	AUTOFS_IOC_PROTOSUBVER_CMD = 103,
	AUTOFS_IOC_ASKUMOUNT_CMD = 112,
};

struct autofs_sb_info___2;

struct autofs_info___2 {
	struct dentry___188 *dentry;
	struct inode___189 *inode;
	int flags;
	struct completion expire_complete;
	struct list_head active;
	int active_count;
	struct list_head expiring;
	struct autofs_sb_info___2 *sbi;
	long unsigned int last_used;
	atomic_t count;
	kuid_t uid;
	kgid_t gid;
};

struct autofs_sb_info___2 {
	u32 magic;
	int pipefd;
	struct file___189 *pipe;
	struct pid___149 *oz_pgrp;
	int version;
	int sub_version;
	int min_proto;
	int max_proto;
	unsigned int flags;
	long unsigned int exp_timeout;
	unsigned int type;
	struct super_block___188 *sb;
	struct mutex wq_mutex;
	struct mutex pipe_mutex;
	spinlock_t fs_lock;
	struct autofs_wait_queue *queues;
	spinlock_t lookup_lock;
	struct list_head active_list;
	struct list_head expiring_list;
	struct callback_head rcu;
};

struct autofs_sb_info___3;

struct autofs_info___3 {
	struct dentry___220 *dentry;
	struct inode___220 *inode;
	int flags;
	struct completion expire_complete;
	struct list_head active;
	int active_count;
	struct list_head expiring;
	struct autofs_sb_info___3 *sbi;
	long unsigned int last_used;
	atomic_t count;
	kuid_t uid;
	kgid_t gid;
};

struct autofs_sb_info___3 {
	u32 magic;
	int pipefd;
	struct file___220 *pipe;
	struct pid___167 *oz_pgrp;
	int version;
	int sub_version;
	int min_proto;
	int max_proto;
	unsigned int flags;
	long unsigned int exp_timeout;
	unsigned int type;
	struct super_block___219 *sb;
	struct mutex wq_mutex;
	struct mutex pipe_mutex;
	spinlock_t fs_lock;
	struct autofs_wait_queue *queues;
	spinlock_t lookup_lock;
	struct list_head active_list;
	struct list_head expiring_list;
	struct callback_head rcu;
};

struct autofs_packet_hdr {
	int proto_version;
	int type;
};

struct autofs_packet_missing {
	struct autofs_packet_hdr hdr;
	autofs_wqt_t wait_queue_token;
	int len;
	char name[256];
};

struct autofs_packet_expire {
	struct autofs_packet_hdr hdr;
	int len;
	char name[256];
};

struct autofs_packet_expire_multi {
	struct autofs_packet_hdr hdr;
	autofs_wqt_t wait_queue_token;
	int len;
	char name[256];
};

union autofs_packet_union {
	struct autofs_packet_hdr hdr;
	struct autofs_packet_missing missing;
	struct autofs_packet_expire expire;
	struct autofs_packet_expire_multi expire_multi;
};

struct autofs_v5_packet {
	struct autofs_packet_hdr hdr;
	autofs_wqt_t wait_queue_token;
	__u32 dev;
	__u64 ino;
	__u32 uid;
	__u32 gid;
	__u32 pid;
	__u32 tgid;
	__u32 len;
	char name[256];
};

typedef struct autofs_v5_packet autofs_packet_missing_indirect_t;

typedef struct autofs_v5_packet autofs_packet_expire_indirect_t;

typedef struct autofs_v5_packet autofs_packet_missing_direct_t;

typedef struct autofs_v5_packet autofs_packet_expire_direct_t;

union autofs_v5_packet_union {
	struct autofs_packet_hdr hdr;
	struct autofs_v5_packet v5_packet;
	autofs_packet_missing_indirect_t missing_indirect;
	autofs_packet_expire_indirect_t expire_indirect;
	autofs_packet_missing_direct_t missing_direct;
	autofs_packet_expire_direct_t expire_direct;
};

struct module___180;

struct file___223;

struct kiocb___223;

struct poll_table_struct___140;

struct vm_area_struct___223;

struct inode___223;

struct file_lock___223;

struct page___223;

struct seq_file___201;

struct file_operations___223 {
	struct module___180 *owner;
	loff_t (*llseek)(struct file___223 *, loff_t, int);
	ssize_t (*read)(struct file___223 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___223 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___223 *, struct iov_iter___101 *);
	ssize_t (*write_iter)(struct kiocb___223 *, struct iov_iter___101 *);
	int (*iopoll)(struct kiocb___223 *, bool);
	int (*iterate)(struct file___223 *, struct dir_context *);
	int (*iterate_shared)(struct file___223 *, struct dir_context *);
	__poll_t (*poll)(struct file___223 *, struct poll_table_struct___140 *);
	long int (*unlocked_ioctl)(struct file___223 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___223 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___223 *, struct vm_area_struct___223 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___223 *, struct file___223 *);
	int (*flush)(struct file___223 *, fl_owner_t);
	int (*release)(struct inode___223 *, struct file___223 *);
	int (*fsync)(struct file___223 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___223 *, int);
	int (*lock)(struct file___223 *, int, struct file_lock___223 *);
	ssize_t (*sendpage)(struct file___223 *, struct page___223 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___223 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___223 *, int, struct file_lock___223 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___223 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___223 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___223 *, long int, struct file_lock___223 **, void **);
	long int (*fallocate)(struct file___223 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___201 *, struct file___223 *);
	ssize_t (*copy_file_range)(struct file___223 *, loff_t, struct file___223 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___223 *, loff_t, struct file___223 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___223 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct perf_event___121;

struct debug_info___121 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___121 *hbp_break[16];
	struct perf_event___121 *hbp_watch[16];
};

struct task_struct___223;

struct hw_perf_event___121 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___223 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___121)(struct perf_event___121 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___121;

struct perf_event_context___121;

struct fasync_struct___222;

struct pid_namespace___168;

struct trace_event_call___114;

struct perf_cgroup___121;

struct perf_event___121 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___121 *group_leader;
	struct pmu___121 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___121 hw;
	struct perf_event_context___121 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___121 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___223 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___222 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___121 *);
	struct callback_head callback_head;
	struct pid_namespace___168 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___121 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___121 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___114 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___121 *cgrp;
	struct list_head sb_list;
};

struct thread_struct___121 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___121 debug;
	long: 64;
};

struct vmacache___222 {
	u64 seqnum;
	struct vm_area_struct___223 *vmas[4];
};

struct page_frag___222 {
	struct page___223 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___222;

struct pid___168;

struct cred___216;

struct nsproxy___205;

struct signal_struct___186;

struct css_set___175;

struct task_struct___223 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___223 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___222 *mm;
	struct mm_struct___222 *active_mm;
	struct vmacache___222 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___223 *real_parent;
	struct task_struct___223 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___223 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___168 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___168 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___168 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___216 *ptracer_cred;
	const struct cred___216 *real_cred;
	const struct cred___216 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___205 *nsproxy;
	struct signal_struct___186 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___223 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___58 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___175 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___121 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___222 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___223 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___121 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___223 *pgtable_t___222;

struct address_space___222;

struct dev_pagemap___215;

struct page___223 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___222 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___223 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___222 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___222 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___215 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___222;

struct lruvec___222 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___222 *pgdat;
};

struct zone___222 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___222 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___222 {
	struct zone___222 *zone;
	int zone_idx;
};

struct zonelist___222 {
	struct zoneref___222 _zonerefs[25];
};

struct pglist_data___222 {
	struct zone___222 node_zones[3];
	struct zonelist___222 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___223 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___223 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___222 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___223 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___223 *owner;
};

struct secondary_data___223 {
	void *stack;
	struct task_struct___223 *task;
	long int status;
};

struct blocking_notifier_head___222 {
	struct rw_semaphore___223 rwsem;
	struct notifier_block *head;
};

struct key___216;

struct ucounts___187;

struct user_namespace___187 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___187 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___27 ns;
	long unsigned int flags;
	struct key___216 *persistent_keyring_register;
	struct rw_semaphore___223 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___187 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_root___217;

struct kernfs_elem_dir___217 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___217 *root;
};

struct kernfs_node___217;

struct kernfs_syscall_ops___217;

struct kernfs_root___217 {
	struct kernfs_node___217 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___217 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___217 {
	struct kernfs_node___217 *target_kn;
};

struct kernfs_ops___217;

struct kernfs_elem_attr___217 {
	const struct kernfs_ops___217 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___217 *notify_next;
};

struct kernfs_node___217 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___217 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___217 dir;
		struct kernfs_elem_symlink___217 symlink;
		struct kernfs_elem_attr___217 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___217;

struct kernfs_ops___217 {
	int (*open)(struct kernfs_open_file___217 *);
	void (*release)(struct kernfs_open_file___217 *);
	int (*seq_show)(struct seq_file___201 *, void *);
	void * (*seq_start)(struct seq_file___201 *, loff_t *);
	void * (*seq_next)(struct seq_file___201 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___201 *, void *);
	ssize_t (*read)(struct kernfs_open_file___217 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___217 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___217 *, struct vm_area_struct___223 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___217 *, struct poll_table_struct___140 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___217 {
	int (*remount_fs)(struct kernfs_root___217 *, int *, char *);
	int (*show_options)(struct seq_file___201 *, struct kernfs_root___217 *);
	int (*mkdir)(struct kernfs_node___217 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___217 *);
	int (*rename)(struct kernfs_node___217 *, struct kernfs_node___217 *, const char *);
	int (*show_path)(struct seq_file___201 *, struct kernfs_node___217 *, struct kernfs_root___217 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___199;

struct seq_file___201 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___199 *op;
	int poll_event;
	const struct file___223 *file;
	void *private;
};

struct vm_operations_struct___215;

struct kernfs_open_file___217 {
	struct kernfs_node___217 *kn;
	struct file___223 *file;
	struct seq_file___201 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___215 *vm_ops;
};

struct vfsmount___54;

struct dentry___223;

struct path___222 {
	struct vfsmount___54 *mnt;
	struct dentry___223 *dentry;
};

struct fown_struct___168 {
	rwlock_t lock;
	struct pid___168 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___223 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___222 f_path;
	struct inode___223 *f_inode;
	const struct file_operations___223 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___168 f_owner;
	const struct cred___216 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___222 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___215;

struct vm_operations_struct___215 {
	void (*open)(struct vm_area_struct___223 *);
	void (*close)(struct vm_area_struct___223 *);
	int (*split)(struct vm_area_struct___223 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___223 *);
	vm_fault_t (*fault)(struct vm_fault___215 *);
	vm_fault_t (*huge_fault)(struct vm_fault___215 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___215 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___223 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___215 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___215 *);
	int (*access)(struct vm_area_struct___223 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___223 *);
	int (*set_policy)(struct vm_area_struct___223 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___223 *, long unsigned int);
	struct page___223 * (*find_special_page)(struct vm_area_struct___223 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___142)(struct file___223 *, wait_queue_head_t *, struct poll_table_struct___140 *);

struct poll_table_struct___140 {
	poll_queue_proc___142 _qproc;
	__poll_t _key;
};

struct vm_area_struct___223 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___223 *vm_next;
	struct vm_area_struct___223 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___222 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___215 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___223 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___211;

struct bin_attribute___193;

struct attribute_group___194 {
	const char *name;
	umode_t (*is_visible)(struct kobject___211 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___211 *, struct bin_attribute___193 *, int);
	struct attribute **attrs;
	struct bin_attribute___193 **bin_attrs;
};

struct kset___210;

struct kobj_type___210;

struct kobject___211 {
	const char *name;
	struct list_head entry;
	struct kobject___211 *parent;
	struct kset___210 *kset;
	struct kobj_type___210 *ktype;
	struct kernfs_node___217 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___193 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___223 *, struct kobject___211 *, struct bin_attribute___193 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___223 *, struct kobject___211 *, struct bin_attribute___193 *, char *, loff_t, size_t);
	int (*mmap)(struct file___223 *, struct kobject___211 *, struct bin_attribute___193 *, struct vm_area_struct___223 *);
};

struct sysfs_ops___210 {
	ssize_t (*show)(struct kobject___211 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___211 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___210;

struct kset___210 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___211 kobj;
	const struct kset_uevent_ops___210 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___210 {
	void (*release)(struct kobject___211 *);
	const struct sysfs_ops___210 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___12 * (*child_ns_type)(struct kobject___211 *);
	const void * (*namespace)(struct kobject___211 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___210 {
	int (* const filter)(struct kset___210 *, struct kobject___211 *);
	const char * (* const name)(struct kset___210 *, struct kobject___211 *);
	int (* const uevent)(struct kset___210 *, struct kobject___211 *, struct kobj_uevent_env *);
};

struct kobj_attribute___206 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___211 *, struct kobj_attribute___206 *, char *);
	ssize_t (*store)(struct kobject___211 *, struct kobj_attribute___206 *, const char *, size_t);
};

struct device___192;

struct dev_pm_ops___192 {
	int (*prepare)(struct device___192 *);
	void (*complete)(struct device___192 *);
	int (*suspend)(struct device___192 *);
	int (*resume)(struct device___192 *);
	int (*freeze)(struct device___192 *);
	int (*thaw)(struct device___192 *);
	int (*poweroff)(struct device___192 *);
	int (*restore)(struct device___192 *);
	int (*suspend_late)(struct device___192 *);
	int (*resume_early)(struct device___192 *);
	int (*freeze_late)(struct device___192 *);
	int (*thaw_early)(struct device___192 *);
	int (*poweroff_late)(struct device___192 *);
	int (*restore_early)(struct device___192 *);
	int (*suspend_noirq)(struct device___192 *);
	int (*resume_noirq)(struct device___192 *);
	int (*freeze_noirq)(struct device___192 *);
	int (*thaw_noirq)(struct device___192 *);
	int (*poweroff_noirq)(struct device___192 *);
	int (*restore_noirq)(struct device___192 *);
	int (*runtime_suspend)(struct device___192 *);
	int (*runtime_resume)(struct device___192 *);
	int (*runtime_idle)(struct device___192 *);
};

struct dev_pm_info___192 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___192 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___192;

struct bus_type___192;

struct device_driver___192;

struct dev_pm_domain___192;

struct class___192;

struct device___192 {
	struct device___192 *parent;
	struct device_private *p;
	struct kobject___211 kobj;
	const char *init_name;
	const struct device_type___192 *type;
	struct mutex mutex;
	struct bus_type___192 *bus;
	struct device_driver___192 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___192 power;
	struct dev_pm_domain___192 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___192 *class;
	const struct attribute_group___194 **groups;
	void (*release)(struct device___192 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___192 {
	struct dev_pm_ops___192 ops;
	void (*detach)(struct device___192 *, bool);
	int (*activate)(struct device___192 *);
	void (*sync)(struct device___192 *);
	void (*dismiss)(struct device___192 *);
};

struct upid___168 {
	int nr;
	struct pid_namespace___168 *ns;
};

struct pid_namespace___168 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___223 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___168 *parent;
	struct vfsmount___54 *proc_mnt;
	struct dentry___223 *proc_self;
	struct dentry___223 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___187 *user_ns;
	struct ucounts___187 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___168 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___168 numbers[1];
};

struct user_struct___216 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___216 *uid_keyring;
	struct key___216 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___222;

struct mm_struct___222 {
	struct {
		struct vm_area_struct___223 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___223 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___223 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___222 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___223 *owner;
		struct user_namespace___187 *user_ns;
		struct file___223 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___222 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___216 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___216 *session_keyring;
	struct key___216 *process_keyring;
	struct key___216 *thread_keyring;
	struct key___216 *request_key_auth;
	void *security;
	struct user_struct___216 *user;
	struct user_namespace___187 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___175;

struct nsproxy___205 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___168 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___175 *cgroup_ns;
};

struct signal_struct___186 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___223 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___223 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___168 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___168 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___222 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___168 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___176;

struct cgroup___175;

struct css_set___175 {
	struct cgroup_subsys_state___176 *subsys[13];
	refcount_t refcount;
	struct css_set___175 *dom_cset;
	struct cgroup___175 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___175 *mg_src_cgrp;
	struct cgroup___175 *mg_dst_cgrp;
	struct css_set___175 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___121 {
	struct pmu___121 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___223 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___121 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

union thread_union___197 {
	struct task_struct___223 task;
	long unsigned int stack[8192];
};

struct bus_type___192 {
	const char *name;
	const char *dev_name;
	struct device___192 *dev_root;
	const struct attribute_group___194 **bus_groups;
	const struct attribute_group___194 **dev_groups;
	const struct attribute_group___194 **drv_groups;
	int (*match)(struct device___192 *, struct device_driver___192 *);
	int (*uevent)(struct device___192 *, struct kobj_uevent_env *);
	int (*probe)(struct device___192 *);
	int (*remove)(struct device___192 *);
	void (*shutdown)(struct device___192 *);
	int (*online)(struct device___192 *);
	int (*offline)(struct device___192 *);
	int (*suspend)(struct device___192 *, pm_message_t);
	int (*resume)(struct device___192 *);
	int (*num_vf)(struct device___192 *);
	int (*dma_configure)(struct device___192 *);
	const struct dev_pm_ops___192 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___192 {
	const char *name;
	struct bus_type___192 *bus;
	struct module___180 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___192 *);
	int (*remove)(struct device___192 *);
	void (*shutdown)(struct device___192 *);
	int (*suspend)(struct device___192 *, pm_message_t);
	int (*resume)(struct device___192 *);
	const struct attribute_group___194 **groups;
	const struct dev_pm_ops___192 *pm;
	void (*coredump)(struct device___192 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___192 {
	const char *name;
	const struct attribute_group___194 **groups;
	int (*uevent)(struct device___192 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___192 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___192 *);
	const struct dev_pm_ops___192 *pm;
};

struct module_kobject___177 {
	struct kobject___211 kobj;
	struct module___180 *mod;
	struct kobject___211 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___177 {
	struct module___180 *mod;
	struct latch_tree_node node;
};

struct module_layout___177 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___177 mtn;
};

struct module_attribute___177;

struct kernel_param___177;

struct module___180 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___177 mkobj;
	struct module_attribute___177 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___211 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___177 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___177 core_layout;
	struct module_layout___177 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___114 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct class___192 {
	const char *name;
	struct module___180 *owner;
	const struct attribute_group___194 **class_groups;
	const struct attribute_group___194 **dev_groups;
	struct kobject___211 *dev_kobj;
	int (*dev_uevent)(struct device___192 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___192 *, umode_t *);
	void (*class_release)(struct class___192 *);
	void (*dev_release)(struct device___192 *);
	int (*shutdown_pre)(struct device___192 *);
	const struct kobj_ns_type_operations___12 *ns_type;
	const void * (*namespace)(struct device___192 *);
	const struct dev_pm_ops___192 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct miscdevice___4 {
	int minor;
	const char *name;
	const struct file_operations___223 *fops;
	struct list_head list;
	struct device___192 *parent;
	struct device___192 *this_device;
	const struct attribute_group___194 **groups;
	const char *nodename;
	umode_t mode;
};

struct address_space_operations___222;

struct address_space___222 {
	struct inode___223 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___223 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___222 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___215)(struct vm_area_struct___223 *, long unsigned int, const struct page___223 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___215)(struct page___223 *, void *);

struct dev_pagemap___215 {
	dev_page_fault_t___215 page_fault;
	dev_page_free_t___215 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___192 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___222 {
	struct task_struct___223 *task;
	struct core_thread___222 *next;
};

struct core_state___222 {
	atomic_t nr_threads;
	struct core_thread___222 dumper;
	struct completion startup;
};

struct vm_fault___215 {
	struct vm_area_struct___223 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___223 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___223 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___222 prealloc_pte;
};

struct kiocb___223 {
	struct file___223 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___223 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dentry_operations___222;

struct super_block___222;

struct dentry___223 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___223 *d_parent;
	struct qstr d_name;
	struct inode___223 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___222 *d_op;
	struct super_block___222 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___222;

struct block_device___223;

struct inode___223 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___222 *i_op;
	struct super_block___222 *i_sb;
	struct address_space___222 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___223 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___223 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___222 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___223 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___222 {
	int (*d_revalidate)(struct dentry___223 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___223 *, unsigned int);
	int (*d_hash)(const struct dentry___223 *, struct qstr *);
	int (*d_compare)(const struct dentry___223 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___223 *);
	int (*d_init)(struct dentry___223 *);
	void (*d_release)(struct dentry___223 *);
	void (*d_prune)(struct dentry___223 *);
	void (*d_iput)(struct dentry___223 *, struct inode___223 *);
	char * (*d_dname)(struct dentry___223 *, char *, int);
	struct vfsmount___54 * (*d_automount)(struct path___222 *);
	int (*d_manage)(const struct path___222 *, bool);
	struct dentry___223 * (*d_real)(struct dentry___223 *, const struct inode___223 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___222;

struct mem_dqinfo___222 {
	struct quota_format_type___222 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___222;

struct quota_info___222 {
	unsigned int flags;
	struct rw_semaphore___223 dqio_sem;
	struct inode___223 *files[3];
	struct mem_dqinfo___222 info[3];
	const struct quota_format_ops___222 *ops[3];
};

struct rcuwait___222 {
	struct task_struct___223 *task;
};

struct percpu_rw_semaphore___222 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___223 rw_sem;
	struct rcuwait___222 writer;
	int readers_block;
};

struct sb_writers___222 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___222 rw_sem[3];
};

struct file_system_type___222;

struct super_operations___222;

struct dquot_operations___222;

struct quotactl_ops___222;

struct super_block___222 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___222 *s_type;
	const struct super_operations___222 *s_op;
	const struct dquot_operations___222 *dq_op;
	const struct quotactl_ops___222 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___223 *s_root;
	struct rw_semaphore___223 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___223 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___222 s_dquot;
	struct sb_writers___222 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___222 *s_d_op;
	int cleancache_poolid;
	struct shrinker___95 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___187 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___54 {
	struct dentry___223 *mnt_root;
	struct super_block___222 *mnt_sb;
	int mnt_flags;
};

struct iattr___222 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___223 *ia_file;
};

struct dquot___222 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___222 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___222 {
	int qf_fmt_id;
	const struct quota_format_ops___222 *qf_ops;
	struct module___180 *qf_owner;
	struct quota_format_type___222 *qf_next;
};

struct quota_format_ops___222 {
	int (*check_quota_file)(struct super_block___222 *, int);
	int (*read_file_info)(struct super_block___222 *, int);
	int (*write_file_info)(struct super_block___222 *, int);
	int (*free_file_info)(struct super_block___222 *, int);
	int (*read_dqblk)(struct dquot___222 *);
	int (*commit_dqblk)(struct dquot___222 *);
	int (*release_dqblk)(struct dquot___222 *);
	int (*get_next_id)(struct super_block___222 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___222 {
	int (*write_dquot)(struct dquot___222 *);
	struct dquot___222 * (*alloc_dquot)(struct super_block___222 *, int);
	void (*destroy_dquot)(struct dquot___222 *);
	int (*acquire_dquot)(struct dquot___222 *);
	int (*release_dquot)(struct dquot___222 *);
	int (*mark_dirty)(struct dquot___222 *);
	int (*write_info)(struct super_block___222 *, int);
	qsize_t * (*get_reserved_space)(struct inode___223 *);
	int (*get_projid)(struct inode___223 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___223 *, qsize_t *);
	int (*get_next_id)(struct super_block___222 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___222 {
	int (*quota_on)(struct super_block___222 *, int, int, const struct path___222 *);
	int (*quota_off)(struct super_block___222 *, int);
	int (*quota_enable)(struct super_block___222 *, unsigned int);
	int (*quota_disable)(struct super_block___222 *, unsigned int);
	int (*quota_sync)(struct super_block___222 *, int);
	int (*set_info)(struct super_block___222 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___222 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___222 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___222 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___222 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___222 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___222 {
	int (*writepage)(struct page___223 *, struct writeback_control___3 *);
	int (*readpage)(struct file___223 *, struct page___223 *);
	int (*writepages)(struct address_space___222 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___223 *);
	int (*readpages)(struct file___223 *, struct address_space___222 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___223 *, struct address_space___222 *, loff_t, unsigned int, unsigned int, struct page___223 **, void **);
	int (*write_end)(struct file___223 *, struct address_space___222 *, loff_t, unsigned int, unsigned int, struct page___223 *, void *);
	sector_t (*bmap)(struct address_space___222 *, sector_t);
	void (*invalidatepage)(struct page___223 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___223 *, gfp_t);
	void (*freepage)(struct page___223 *);
	ssize_t (*direct_IO)(struct kiocb___223 *, struct iov_iter___101 *);
	int (*migratepage)(struct address_space___222 *, struct page___223 *, struct page___223 *, enum migrate_mode);
	bool (*isolate_page)(struct page___223 *, isolate_mode_t);
	void (*putback_page)(struct page___223 *);
	int (*launder_page)(struct page___223 *);
	int (*is_partially_uptodate)(struct page___223 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___223 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___222 *, struct page___223 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___223 *, sector_t *);
	void (*swap_deactivate)(struct file___223 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___223 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___223 *bd_inode;
	struct super_block___222 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___223 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___222 {
	struct dentry___223 * (*lookup)(struct inode___223 *, struct dentry___223 *, unsigned int);
	const char * (*get_link)(struct dentry___223 *, struct inode___223 *, struct delayed_call *);
	int (*permission)(struct inode___223 *, int);
	struct posix_acl * (*get_acl)(struct inode___223 *, int);
	int (*readlink)(struct dentry___223 *, char *, int);
	int (*create)(struct inode___223 *, struct dentry___223 *, umode_t, bool);
	int (*link)(struct dentry___223 *, struct inode___223 *, struct dentry___223 *);
	int (*unlink)(struct inode___223 *, struct dentry___223 *);
	int (*symlink)(struct inode___223 *, struct dentry___223 *, const char *);
	int (*mkdir)(struct inode___223 *, struct dentry___223 *, umode_t);
	int (*rmdir)(struct inode___223 *, struct dentry___223 *);
	int (*mknod)(struct inode___223 *, struct dentry___223 *, umode_t, dev_t);
	int (*rename)(struct inode___223 *, struct dentry___223 *, struct inode___223 *, struct dentry___223 *, unsigned int);
	int (*setattr)(struct dentry___223 *, struct iattr___222 *);
	int (*getattr)(const struct path___222 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___223 *, char *, size_t);
	int (*fiemap)(struct inode___223 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___223 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___223 *, struct dentry___223 *, struct file___223 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___223 *, struct dentry___223 *, umode_t);
	int (*set_acl)(struct inode___223 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___222 {
	void (*fl_copy_lock)(struct file_lock___223 *, struct file_lock___223 *);
	void (*fl_release_private)(struct file_lock___223 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___222;

struct file_lock___223 {
	struct file_lock___223 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___223 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___222 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___222 *fl_ops;
	const struct lock_manager_operations___222 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___222 {
	int (*lm_compare_owner)(struct file_lock___223 *, struct file_lock___223 *);
	long unsigned int (*lm_owner_key)(struct file_lock___223 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___223 *);
	int (*lm_grant)(struct file_lock___223 *, int);
	bool (*lm_break)(struct file_lock___223 *);
	int (*lm_change)(struct file_lock___223 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___223 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___222 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___222 *fa_next;
	struct file___223 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___222 {
	const char *name;
	int fs_flags;
	struct dentry___223 * (*mount)(struct file_system_type___222 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___222 *);
	struct module___180 *owner;
	struct file_system_type___222 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___222 {
	struct inode___223 * (*alloc_inode)(struct super_block___222 *);
	void (*destroy_inode)(struct inode___223 *);
	void (*dirty_inode)(struct inode___223 *, int);
	int (*write_inode)(struct inode___223 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___223 *);
	void (*evict_inode)(struct inode___223 *);
	void (*put_super)(struct super_block___222 *);
	int (*sync_fs)(struct super_block___222 *, int);
	int (*freeze_super)(struct super_block___222 *);
	int (*freeze_fs)(struct super_block___222 *);
	int (*thaw_super)(struct super_block___222 *);
	int (*unfreeze_fs)(struct super_block___222 *);
	int (*statfs)(struct dentry___223 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___222 *, int *, char *);
	void (*umount_begin)(struct super_block___222 *);
	int (*show_options)(struct seq_file___201 *, struct dentry___223 *);
	int (*show_devname)(struct seq_file___201 *, struct dentry___223 *);
	int (*show_path)(struct seq_file___201 *, struct dentry___223 *);
	int (*show_stats)(struct seq_file___201 *, struct dentry___223 *);
	ssize_t (*quota_read)(struct super_block___222 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___222 *, int, const char *, size_t, loff_t);
	struct dquot___222 ** (*get_dquots)(struct inode___223 *);
	int (*bdev_try_to_free_page)(struct super_block___222 *, struct page___223 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___222 *, struct shrink_control___95 *);
	long int (*free_cached_objects)(struct super_block___222 *, struct shrink_control___95 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*key_restrict_link_func_t___216)(struct key___216 *, const struct key_type *, const union key_payload *, struct key___216 *);

struct key_restriction___216;

struct key___216 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___223 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___216 *restrict_link;
};

struct key_restriction___216 {
	key_restrict_link_func_t___216 check;
	struct key___216 *key;
	struct key_type *keytype;
};

typedef void compound_page_dtor___215(struct page___223 *);

struct seq_operations___199 {
	void * (*start)(struct seq_file___201 *, loff_t *);
	void (*stop)(struct seq_file___201 *, void *);
	void * (*next)(struct seq_file___201 *, void *, loff_t *);
	int (*show)(struct seq_file___201 *, void *);
};

struct cgroup_namespace___175 {
	refcount_t count;
	struct ns_common___27 ns;
	struct user_namespace___187 *user_ns;
	struct ucounts___187 *ucounts;
	struct css_set___175 *root_cset;
};

struct ucounts___187 {
	struct hlist_node node;
	struct user_namespace___187 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct kernel_param_ops___177 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___177 *);
	int (*get)(char *, const struct kernel_param___177 *);
	void (*free)(void *);
};

struct kparam_array___177;

struct kernel_param___177 {
	const char *name;
	struct module___180 *mod;
	const struct kernel_param_ops___177 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___177 *arr;
	};
};

struct kparam_array___177 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___177 *ops;
	void *elem;
};

struct module_attribute___177 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___177 *, struct module_kobject___177 *, char *);
	ssize_t (*store)(struct module_attribute___177 *, struct module_kobject___177 *, const char *, size_t);
	void (*setup)(struct module___180 *, const char *);
	int (*test)(struct module___180 *);
	void (*free)(struct module___180 *);
};

struct trace_event_class___114;

struct trace_event_call___114 {
	struct list_head list;
	struct trace_event_class___114 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___22 *prog_array;
	int (*perf_perm)(struct trace_event_call___114 *, struct perf_event___121 *);
};

struct node___160 {
	struct device___192 dev;
};

struct bpf_map___175;

struct bpf_map_ops___175 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___175 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___175 *, struct file___223 *);
	void (*map_free)(struct bpf_map___175 *);
	int (*map_get_next_key)(struct bpf_map___175 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___175 *);
	void * (*map_lookup_elem)(struct bpf_map___175 *, void *);
	int (*map_update_elem)(struct bpf_map___175 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___175 *, void *);
	int (*map_push_elem)(struct bpf_map___175 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___175 *, void *);
	int (*map_peek_elem)(struct bpf_map___175 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___175 *, struct file___223 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___175 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___175 *, void *, struct seq_file___201 *);
	int (*map_check_btf)(const struct bpf_map___175 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___175 {
	const struct bpf_map_ops___175 *ops;
	struct bpf_map___175 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___216 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___175;

typedef void (*kthread_work_func_t___175)(struct kthread_work___175 *);

struct kthread_worker___175;

struct kthread_work___175 {
	struct list_head node;
	kthread_work_func_t___175 func;
	struct kthread_worker___175 *worker;
	int canceling;
};

struct kthread_worker___175 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___223 *task;
	struct kthread_work___175 *current_work;
};

struct kthread_delayed_work___175 {
	struct kthread_work___175 work;
	struct timer_list timer;
};

struct psi_group___175 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___175 *poll_kworker;
	struct kthread_delayed_work___175 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___175 {
	struct kernfs_node___217 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___175;

struct cgroup_subsys_state___176 {
	struct cgroup___175 *cgroup;
	struct cgroup_subsys___175 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___176 *parent;
};

struct cgroup_root___175;

struct cgroup_rstat_cpu___175;

struct cgroup___175 {
	struct cgroup_subsys_state___176 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___217 *kn;
	struct cgroup_file___175 procs_file;
	struct cgroup_file___175 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___176 *subsys[13];
	struct cgroup_root___175 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___175 *dom_cgrp;
	struct cgroup_rstat_cpu___175 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___22 bpf;
	atomic_t congestion_count;
	struct cgroup___175 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___175 psi;
	int ancestor_ids[0];
};

struct cftype___175;

struct cgroup_subsys___175 {
	struct cgroup_subsys_state___176 * (*css_alloc)(struct cgroup_subsys_state___176 *);
	int (*css_online)(struct cgroup_subsys_state___176 *);
	void (*css_offline)(struct cgroup_subsys_state___176 *);
	void (*css_released)(struct cgroup_subsys_state___176 *);
	void (*css_free)(struct cgroup_subsys_state___176 *);
	void (*css_reset)(struct cgroup_subsys_state___176 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___176 *, int);
	int (*css_extra_stat_show)(struct seq_file___201 *, struct cgroup_subsys_state___176 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___223 *);
	void (*cancel_fork)(struct task_struct___223 *);
	void (*fork)(struct task_struct___223 *);
	void (*exit)(struct task_struct___223 *);
	void (*free)(struct task_struct___223 *);
	void (*bind)(struct cgroup_subsys_state___176 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___175 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___175 *dfl_cftypes;
	struct cftype___175 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___175 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___175 *updated_children;
	struct cgroup___175 *updated_next;
};

struct cgroup_root___175 {
	struct kernfs_root___217 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___175 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___175 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___175 *ss;
	struct list_head node;
	struct kernfs_ops___217 *kf_ops;
	int (*open)(struct kernfs_open_file___217 *);
	void (*release)(struct kernfs_open_file___217 *);
	u64 (*read_u64)(struct cgroup_subsys_state___176 *, struct cftype___175 *);
	s64 (*read_s64)(struct cgroup_subsys_state___176 *, struct cftype___175 *);
	int (*seq_show)(struct seq_file___201 *, void *);
	void * (*seq_start)(struct seq_file___201 *, loff_t *);
	void * (*seq_next)(struct seq_file___201 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___201 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___176 *, struct cftype___175 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___176 *, struct cftype___175 *, s64);
	ssize_t (*write)(struct kernfs_open_file___217 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___217 *, struct poll_table_struct___140 *);
};

struct perf_cpu_context___121;

struct pmu___121 {
	struct list_head entry;
	struct module___180 *module;
	struct device___192 *dev;
	const struct attribute_group___194 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___121 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___121 *);
	void (*pmu_disable)(struct pmu___121 *);
	int (*event_init)(struct perf_event___121 *);
	void (*event_mapped)(struct perf_event___121 *, struct mm_struct___222 *);
	void (*event_unmapped)(struct perf_event___121 *, struct mm_struct___222 *);
	int (*add)(struct perf_event___121 *, int);
	void (*del)(struct perf_event___121 *, int);
	void (*start)(struct perf_event___121 *, int);
	void (*stop)(struct perf_event___121 *, int);
	void (*read)(struct perf_event___121 *);
	void (*start_txn)(struct pmu___121 *, unsigned int);
	int (*commit_txn)(struct pmu___121 *);
	void (*cancel_txn)(struct pmu___121 *);
	int (*event_idx)(struct perf_event___121 *);
	void (*sched_task)(struct perf_event_context___121 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___121 *);
	int (*filter_match)(struct perf_event___121 *);
	int (*check_period)(struct perf_event___121 *, u64);
};

struct perf_cpu_context___121 {
	struct perf_event_context___121 ctx;
	struct perf_event_context___121 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___121 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___121 {
	struct cgroup_subsys_state___176 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___114 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___114 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___114 *);
	struct list_head * (*get_fields)(struct trace_event_call___114 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___114 *);
};

struct args_protover {
	__u32 version;
};

struct args_protosubver {
	__u32 sub_version;
};

struct args_openmount {
	__u32 devid;
};

struct args_ready {
	__u32 token;
};

struct args_fail {
	__u32 token;
	__s32 status;
};

struct args_setpipefd {
	__s32 pipefd;
};

struct args_timeout {
	__u64 timeout;
};

struct args_requester {
	__u32 uid;
	__u32 gid;
};

struct args_expire {
	__u32 how;
};

struct args_askumount {
	__u32 may_umount;
};

struct args_in {
	__u32 type;
};

struct args_out {
	__u32 devid;
	__u32 magic;
};

struct args_ismountpoint {
	union {
		struct args_in in;
		struct args_out out;
	};
};

struct autofs_dev_ioctl {
	__u32 ver_major;
	__u32 ver_minor;
	__u32 size;
	__s32 ioctlfd;
	union {
		struct args_protover protover;
		struct args_protosubver protosubver;
		struct args_openmount openmount;
		struct args_ready ready;
		struct args_fail fail;
		struct args_setpipefd setpipefd;
		struct args_timeout timeout;
		struct args_requester requester;
		struct args_expire expire;
		struct args_askumount askumount;
		struct args_ismountpoint ismountpoint;
	};
	char path[0];
};

enum {
	AUTOFS_DEV_IOCTL_VERSION_CMD = 113,
	AUTOFS_DEV_IOCTL_PROTOVER_CMD = 114,
	AUTOFS_DEV_IOCTL_PROTOSUBVER_CMD = 115,
	AUTOFS_DEV_IOCTL_OPENMOUNT_CMD = 116,
	AUTOFS_DEV_IOCTL_CLOSEMOUNT_CMD = 117,
	AUTOFS_DEV_IOCTL_READY_CMD = 118,
	AUTOFS_DEV_IOCTL_FAIL_CMD = 119,
	AUTOFS_DEV_IOCTL_SETPIPEFD_CMD = 120,
	AUTOFS_DEV_IOCTL_CATATONIC_CMD = 121,
	AUTOFS_DEV_IOCTL_TIMEOUT_CMD = 122,
	AUTOFS_DEV_IOCTL_REQUESTER_CMD = 123,
	AUTOFS_DEV_IOCTL_EXPIRE_CMD = 124,
	AUTOFS_DEV_IOCTL_ASKUMOUNT_CMD = 125,
	AUTOFS_DEV_IOCTL_ISMOUNTPOINT_CMD = 126,
};

struct autofs_sb_info___4;

struct autofs_info___4 {
	struct dentry___223 *dentry;
	struct inode___223 *inode;
	int flags;
	struct completion expire_complete;
	struct list_head active;
	int active_count;
	struct list_head expiring;
	struct autofs_sb_info___4 *sbi;
	long unsigned int last_used;
	atomic_t count;
	kuid_t uid;
	kgid_t gid;
};

struct autofs_sb_info___4 {
	u32 magic;
	int pipefd;
	struct file___223 *pipe;
	struct pid___168 *oz_pgrp;
	int version;
	int sub_version;
	int min_proto;
	int max_proto;
	unsigned int flags;
	long unsigned int exp_timeout;
	unsigned int type;
	struct super_block___222 *sb;
	struct mutex wq_mutex;
	struct mutex pipe_mutex;
	spinlock_t fs_lock;
	struct autofs_wait_queue *queues;
	spinlock_t lookup_lock;
	struct list_head active_list;
	struct list_head expiring_list;
	struct callback_head rcu;
};

typedef int (*ioctl_fn)(struct file___223 *, struct autofs_sb_info___4 *, struct autofs_dev_ioctl *);

struct module___181;

struct file___224;

struct kiocb___224;

struct vm_area_struct___224;

struct inode___224;

struct file_lock___224;

struct page___224;

struct seq_file___202;

struct file_operations___224 {
	struct module___181 *owner;
	loff_t (*llseek)(struct file___224 *, loff_t, int);
	ssize_t (*read)(struct file___224 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___224 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___224 *, struct iov_iter___101 *);
	ssize_t (*write_iter)(struct kiocb___224 *, struct iov_iter___101 *);
	int (*iopoll)(struct kiocb___224 *, bool);
	int (*iterate)(struct file___224 *, struct dir_context *);
	int (*iterate_shared)(struct file___224 *, struct dir_context *);
	__poll_t (*poll)(struct file___224 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___224 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___224 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___224 *, struct vm_area_struct___224 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___224 *, struct file___224 *);
	int (*flush)(struct file___224 *, fl_owner_t);
	int (*release)(struct inode___224 *, struct file___224 *);
	int (*fsync)(struct file___224 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___224 *, int);
	int (*lock)(struct file___224 *, int, struct file_lock___224 *);
	ssize_t (*sendpage)(struct file___224 *, struct page___224 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___224 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___224 *, int, struct file_lock___224 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___224 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___224 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___224 *, long int, struct file_lock___224 **, void **);
	long int (*fallocate)(struct file___224 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___202 *, struct file___224 *);
	ssize_t (*copy_file_range)(struct file___224 *, loff_t, struct file___224 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___224 *, loff_t, struct file___224 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___224 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___223 {
	u64 seqnum;
	struct vm_area_struct___224 *vmas[4];
};

struct page_frag___223 {
	struct page___224 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___223;

struct pid___169;

struct cred___217;

struct nsproxy___206;

struct signal_struct___187;

struct task_struct___224 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___224 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___223 *mm;
	struct mm_struct___223 *active_mm;
	struct vmacache___223 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___224 *real_parent;
	struct task_struct___224 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___224 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___169 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___169 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___169 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___217 *ptracer_cred;
	const struct cred___217 *real_cred;
	const struct cred___217 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___206 *nsproxy;
	struct signal_struct___187 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___224 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___58 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___223 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___224 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___121 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rw_semaphore___224 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___224 *owner;
};

struct key___217;

struct ucounts___188;

struct user_namespace___188 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___188 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___27 ns;
	long unsigned int flags;
	struct key___217 *persistent_keyring_register;
	struct rw_semaphore___224 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___188 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___224 *pgtable_t___223;

struct address_space___223;

struct dev_pagemap___216;

struct page___224 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___223 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___224 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___223 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___223 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___216 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___223;

struct lruvec___223 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___223 *pgdat;
};

struct zone___223 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___223 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___223 {
	struct zone___223 *zone;
	int zone_idx;
};

struct zonelist___223 {
	struct zoneref___223 _zonerefs[25];
};

struct pglist_data___223 {
	struct zone___223 node_zones[3];
	struct zonelist___223 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___224 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___224 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___223 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___224 {
	void *stack;
	struct task_struct___224 *task;
	long int status;
};

struct blocking_notifier_head___223 {
	struct rw_semaphore___224 rwsem;
	struct notifier_block *head;
};

struct vfsmount___55;

struct dentry___224;

struct path___223 {
	struct vfsmount___55 *mnt;
	struct dentry___224 *dentry;
};

struct fown_struct___169 {
	rwlock_t lock;
	struct pid___169 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___224 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___223 f_path;
	struct inode___224 *f_inode;
	const struct file_operations___224 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___169 f_owner;
	const struct cred___217 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___223 *f_mapping;
	errseq_t f_wb_err;
};

struct user_struct___217;

struct cred___217 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___217 *session_keyring;
	struct key___217 *process_keyring;
	struct key___217 *thread_keyring;
	struct key___217 *request_key_auth;
	void *security;
	struct user_struct___217 *user;
	struct user_namespace___188 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___218;

struct kernfs_elem_dir___218 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___218 *root;
};

struct kernfs_node___218;

struct kernfs_syscall_ops___218;

struct kernfs_root___218 {
	struct kernfs_node___218 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___218 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___218 {
	struct kernfs_node___218 *target_kn;
};

struct kernfs_ops___218;

struct kernfs_elem_attr___218 {
	const struct kernfs_ops___218 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___218 *notify_next;
};

struct kernfs_node___218 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___218 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___218 dir;
		struct kernfs_elem_symlink___218 symlink;
		struct kernfs_elem_attr___218 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___218;

struct kernfs_ops___218 {
	int (*open)(struct kernfs_open_file___218 *);
	void (*release)(struct kernfs_open_file___218 *);
	int (*seq_show)(struct seq_file___202 *, void *);
	void * (*seq_start)(struct seq_file___202 *, loff_t *);
	void * (*seq_next)(struct seq_file___202 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___202 *, void *);
	ssize_t (*read)(struct kernfs_open_file___218 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___218 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___218 *, struct vm_area_struct___224 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___218 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___218 {
	int (*remount_fs)(struct kernfs_root___218 *, int *, char *);
	int (*show_options)(struct seq_file___202 *, struct kernfs_root___218 *);
	int (*mkdir)(struct kernfs_node___218 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___218 *);
	int (*rename)(struct kernfs_node___218 *, struct kernfs_node___218 *, const char *);
	int (*show_path)(struct seq_file___202 *, struct kernfs_node___218 *, struct kernfs_root___218 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___200;

struct seq_file___202 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___200 *op;
	int poll_event;
	const struct file___224 *file;
	void *private;
};

struct vm_operations_struct___216;

struct kernfs_open_file___218 {
	struct kernfs_node___218 *kn;
	struct file___224 *file;
	struct seq_file___202 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___216 *vm_ops;
};

struct vm_fault___216;

struct vm_operations_struct___216 {
	void (*open)(struct vm_area_struct___224 *);
	void (*close)(struct vm_area_struct___224 *);
	int (*split)(struct vm_area_struct___224 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___224 *);
	vm_fault_t (*fault)(struct vm_fault___216 *);
	vm_fault_t (*huge_fault)(struct vm_fault___216 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___216 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___224 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___216 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___216 *);
	int (*access)(struct vm_area_struct___224 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___224 *);
	int (*set_policy)(struct vm_area_struct___224 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___224 *, long unsigned int);
	struct page___224 * (*find_special_page)(struct vm_area_struct___224 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_area_struct___224 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___224 *vm_next;
	struct vm_area_struct___224 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___223 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___216 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___224 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___211;

struct kobj_type___211;

struct kobject___212 {
	const char *name;
	struct list_head entry;
	struct kobject___212 *parent;
	struct kset___211 *kset;
	struct kobj_type___211 *ktype;
	struct kernfs_node___218 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sysfs_ops___211 {
	ssize_t (*show)(struct kobject___212 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___212 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___211;

struct kset___211 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___212 kobj;
	const struct kset_uevent_ops___211 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___211 {
	void (*release)(struct kobject___212 *);
	const struct sysfs_ops___211 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___12 * (*child_ns_type)(struct kobject___212 *);
	const void * (*namespace)(struct kobject___212 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___211 {
	int (* const filter)(struct kset___211 *, struct kobject___212 *);
	const char * (* const name)(struct kset___211 *, struct kobject___212 *);
	int (* const uevent)(struct kset___211 *, struct kobject___212 *, struct kobj_uevent_env *);
};

struct kobj_attribute___207 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___212 *, struct kobj_attribute___207 *, char *);
	ssize_t (*store)(struct kobject___212 *, struct kobj_attribute___207 *, const char *, size_t);
};

struct kernel_param___178;

struct kernel_param_ops___178 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___178 *);
	int (*get)(char *, const struct kernel_param___178 *);
	void (*free)(void *);
};

struct kparam_array___178;

struct kernel_param___178 {
	const char *name;
	struct module___181 *mod;
	const struct kernel_param_ops___178 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___178 *arr;
	};
};

struct kparam_array___178 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___178 *ops;
	void *elem;
};

struct module_kobject___178 {
	struct kobject___212 kobj;
	struct module___181 *mod;
	struct kobject___212 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___178 {
	struct module___181 *mod;
	struct latch_tree_node node;
};

struct module_layout___178 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___178 mtn;
};

struct module_attribute___178;

struct module___181 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___178 mkobj;
	struct module_attribute___178 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___212 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___178 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___178 core_layout;
	struct module_layout___178 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___178 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___178 *, struct module_kobject___178 *, char *);
	ssize_t (*store)(struct module_attribute___178 *, struct module_kobject___178 *, const char *, size_t);
	void (*setup)(struct module___181 *, const char *);
	int (*test)(struct module___181 *);
	void (*free)(struct module___181 *);
};

struct dentry_operations___223;

struct super_block___223;

struct dentry___224 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___224 *d_parent;
	struct qstr d_name;
	struct inode___224 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___223 *d_op;
	struct super_block___223 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___223;

struct address_space___223 {
	struct inode___224 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___224 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___223 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___223;

struct block_device___224;

struct inode___224 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___223 *i_op;
	struct super_block___223 *i_sb;
	struct address_space___223 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___224 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___224 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___223 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___224 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___223 {
	int (*d_revalidate)(struct dentry___224 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___224 *, unsigned int);
	int (*d_hash)(const struct dentry___224 *, struct qstr *);
	int (*d_compare)(const struct dentry___224 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___224 *);
	int (*d_init)(struct dentry___224 *);
	void (*d_release)(struct dentry___224 *);
	void (*d_prune)(struct dentry___224 *);
	void (*d_iput)(struct dentry___224 *, struct inode___224 *);
	char * (*d_dname)(struct dentry___224 *, char *, int);
	struct vfsmount___55 * (*d_automount)(struct path___223 *);
	int (*d_manage)(const struct path___223 *, bool);
	struct dentry___224 * (*d_real)(struct dentry___224 *, const struct inode___224 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___223;

struct mem_dqinfo___223 {
	struct quota_format_type___223 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___223;

struct quota_info___223 {
	unsigned int flags;
	struct rw_semaphore___224 dqio_sem;
	struct inode___224 *files[3];
	struct mem_dqinfo___223 info[3];
	const struct quota_format_ops___223 *ops[3];
};

struct rcuwait___223 {
	struct task_struct___224 *task;
};

struct percpu_rw_semaphore___223 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___224 rw_sem;
	struct rcuwait___223 writer;
	int readers_block;
};

struct sb_writers___223 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___223 rw_sem[3];
};

struct file_system_type___223;

struct super_operations___223;

struct dquot_operations___223;

struct quotactl_ops___223;

struct super_block___223 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___223 *s_type;
	const struct super_operations___223 *s_op;
	const struct dquot_operations___223 *dq_op;
	const struct quotactl_ops___223 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___224 *s_root;
	struct rw_semaphore___224 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___224 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___223 s_dquot;
	struct sb_writers___223 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___223 *s_d_op;
	int cleancache_poolid;
	struct shrinker___95 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___188 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___55 {
	struct dentry___224 *mnt_root;
	struct super_block___223 *mnt_sb;
	int mnt_flags;
};

struct pid_namespace___169;

struct upid___169 {
	int nr;
	struct pid_namespace___169 *ns;
};

struct pid_namespace___169 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___224 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___169 *parent;
	struct vfsmount___55 *proc_mnt;
	struct dentry___224 *proc_self;
	struct dentry___224 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___188 *user_ns;
	struct ucounts___188 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___169 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___169 numbers[1];
};

struct core_state___223;

struct mm_struct___223 {
	struct {
		struct vm_area_struct___224 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___224 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___224 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___223 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___224 *owner;
		struct user_namespace___188 *user_ns;
		struct file___224 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___223 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___216)(struct vm_area_struct___224 *, long unsigned int, const struct page___224 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___216)(struct page___224 *, void *);

struct dev_pagemap___216 {
	dev_page_fault_t___216 page_fault;
	dev_page_free_t___216 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___6 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___223 {
	struct task_struct___224 *task;
	struct core_thread___223 *next;
};

struct core_state___223 {
	atomic_t nr_threads;
	struct core_thread___223 dumper;
	struct completion startup;
};

struct vm_fault___216 {
	struct vm_area_struct___224 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___224 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___224 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___223 prealloc_pte;
};

struct user_struct___217 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___217 *uid_keyring;
	struct key___217 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct nsproxy___206 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___169 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct signal_struct___187 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___224 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___224 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___169 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___169 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___223 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___169 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

union thread_union___198 {
	struct task_struct___224 task;
	long unsigned int stack[8192];
};

struct kiocb___224 {
	struct file___224 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___224 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___223 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___224 *ia_file;
};

struct dquot___223 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___223 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___223 {
	int qf_fmt_id;
	const struct quota_format_ops___223 *qf_ops;
	struct module___181 *qf_owner;
	struct quota_format_type___223 *qf_next;
};

struct quota_format_ops___223 {
	int (*check_quota_file)(struct super_block___223 *, int);
	int (*read_file_info)(struct super_block___223 *, int);
	int (*write_file_info)(struct super_block___223 *, int);
	int (*free_file_info)(struct super_block___223 *, int);
	int (*read_dqblk)(struct dquot___223 *);
	int (*commit_dqblk)(struct dquot___223 *);
	int (*release_dqblk)(struct dquot___223 *);
	int (*get_next_id)(struct super_block___223 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___223 {
	int (*write_dquot)(struct dquot___223 *);
	struct dquot___223 * (*alloc_dquot)(struct super_block___223 *, int);
	void (*destroy_dquot)(struct dquot___223 *);
	int (*acquire_dquot)(struct dquot___223 *);
	int (*release_dquot)(struct dquot___223 *);
	int (*mark_dirty)(struct dquot___223 *);
	int (*write_info)(struct super_block___223 *, int);
	qsize_t * (*get_reserved_space)(struct inode___224 *);
	int (*get_projid)(struct inode___224 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___224 *, qsize_t *);
	int (*get_next_id)(struct super_block___223 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___223 {
	int (*quota_on)(struct super_block___223 *, int, int, const struct path___223 *);
	int (*quota_off)(struct super_block___223 *, int);
	int (*quota_enable)(struct super_block___223 *, unsigned int);
	int (*quota_disable)(struct super_block___223 *, unsigned int);
	int (*quota_sync)(struct super_block___223 *, int);
	int (*set_info)(struct super_block___223 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___223 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___223 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___223 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___223 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___223 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___223 {
	int (*writepage)(struct page___224 *, struct writeback_control___3 *);
	int (*readpage)(struct file___224 *, struct page___224 *);
	int (*writepages)(struct address_space___223 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___224 *);
	int (*readpages)(struct file___224 *, struct address_space___223 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___224 *, struct address_space___223 *, loff_t, unsigned int, unsigned int, struct page___224 **, void **);
	int (*write_end)(struct file___224 *, struct address_space___223 *, loff_t, unsigned int, unsigned int, struct page___224 *, void *);
	sector_t (*bmap)(struct address_space___223 *, sector_t);
	void (*invalidatepage)(struct page___224 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___224 *, gfp_t);
	void (*freepage)(struct page___224 *);
	ssize_t (*direct_IO)(struct kiocb___224 *, struct iov_iter___101 *);
	int (*migratepage)(struct address_space___223 *, struct page___224 *, struct page___224 *, enum migrate_mode);
	bool (*isolate_page)(struct page___224 *, isolate_mode_t);
	void (*putback_page)(struct page___224 *);
	int (*launder_page)(struct page___224 *);
	int (*is_partially_uptodate)(struct page___224 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___224 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___223 *, struct page___224 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___224 *, sector_t *);
	void (*swap_deactivate)(struct file___224 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___224 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___224 *bd_inode;
	struct super_block___223 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___224 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___223 {
	struct dentry___224 * (*lookup)(struct inode___224 *, struct dentry___224 *, unsigned int);
	const char * (*get_link)(struct dentry___224 *, struct inode___224 *, struct delayed_call *);
	int (*permission)(struct inode___224 *, int);
	struct posix_acl * (*get_acl)(struct inode___224 *, int);
	int (*readlink)(struct dentry___224 *, char *, int);
	int (*create)(struct inode___224 *, struct dentry___224 *, umode_t, bool);
	int (*link)(struct dentry___224 *, struct inode___224 *, struct dentry___224 *);
	int (*unlink)(struct inode___224 *, struct dentry___224 *);
	int (*symlink)(struct inode___224 *, struct dentry___224 *, const char *);
	int (*mkdir)(struct inode___224 *, struct dentry___224 *, umode_t);
	int (*rmdir)(struct inode___224 *, struct dentry___224 *);
	int (*mknod)(struct inode___224 *, struct dentry___224 *, umode_t, dev_t);
	int (*rename)(struct inode___224 *, struct dentry___224 *, struct inode___224 *, struct dentry___224 *, unsigned int);
	int (*setattr)(struct dentry___224 *, struct iattr___223 *);
	int (*getattr)(const struct path___223 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___224 *, char *, size_t);
	int (*fiemap)(struct inode___224 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___224 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___224 *, struct dentry___224 *, struct file___224 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___224 *, struct dentry___224 *, umode_t);
	int (*set_acl)(struct inode___224 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___223 {
	void (*fl_copy_lock)(struct file_lock___224 *, struct file_lock___224 *);
	void (*fl_release_private)(struct file_lock___224 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___223;

struct lock_manager_operations___223;

struct file_lock___224 {
	struct file_lock___224 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___224 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___223 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___223 *fl_ops;
	const struct lock_manager_operations___223 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___223 {
	int (*lm_compare_owner)(struct file_lock___224 *, struct file_lock___224 *);
	long unsigned int (*lm_owner_key)(struct file_lock___224 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___224 *);
	int (*lm_grant)(struct file_lock___224 *, int);
	bool (*lm_break)(struct file_lock___224 *);
	int (*lm_change)(struct file_lock___224 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___224 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___223 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___223 *fa_next;
	struct file___224 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___223 {
	const char *name;
	int fs_flags;
	struct dentry___224 * (*mount)(struct file_system_type___223 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___223 *);
	struct module___181 *owner;
	struct file_system_type___223 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___223 {
	struct inode___224 * (*alloc_inode)(struct super_block___223 *);
	void (*destroy_inode)(struct inode___224 *);
	void (*dirty_inode)(struct inode___224 *, int);
	int (*write_inode)(struct inode___224 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___224 *);
	void (*evict_inode)(struct inode___224 *);
	void (*put_super)(struct super_block___223 *);
	int (*sync_fs)(struct super_block___223 *, int);
	int (*freeze_super)(struct super_block___223 *);
	int (*freeze_fs)(struct super_block___223 *);
	int (*thaw_super)(struct super_block___223 *);
	int (*unfreeze_fs)(struct super_block___223 *);
	int (*statfs)(struct dentry___224 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___223 *, int *, char *);
	void (*umount_begin)(struct super_block___223 *);
	int (*show_options)(struct seq_file___202 *, struct dentry___224 *);
	int (*show_devname)(struct seq_file___202 *, struct dentry___224 *);
	int (*show_path)(struct seq_file___202 *, struct dentry___224 *);
	int (*show_stats)(struct seq_file___202 *, struct dentry___224 *);
	ssize_t (*quota_read)(struct super_block___223 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___223 *, int, const char *, size_t, loff_t);
	struct dquot___223 ** (*get_dquots)(struct inode___224 *);
	int (*bdev_try_to_free_page)(struct super_block___223 *, struct page___224 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___223 *, struct shrink_control___95 *);
	long int (*free_cached_objects)(struct super_block___223 *, struct shrink_control___95 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct tree_descr___3 {
	const char *name;
	const struct file_operations___224 *ops;
	int mode;
};

typedef void compound_page_dtor___216(struct page___224 *);

typedef int (*key_restrict_link_func_t___217)(struct key___217 *, const struct key_type *, const union key_payload *, struct key___217 *);

struct key_restriction___217;

struct key___217 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___224 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___217 *restrict_link;
};

struct key_restriction___217 {
	key_restrict_link_func_t___217 check;
	struct key___217 *key;
	struct key_type *keytype;
};

struct seq_operations___200 {
	void * (*start)(struct seq_file___202 *, loff_t *);
	void (*stop)(struct seq_file___202 *, void *);
	void * (*next)(struct seq_file___202 *, void *, loff_t *);
	int (*show)(struct seq_file___202 *, void *);
};

typedef struct vfsmount___55 * (*debugfs_automount_t)(struct dentry___224 *, void *);

struct ucounts___188 {
	struct hlist_node node;
	struct user_namespace___188 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct debugfs_fsdata {
	const struct file_operations___224 *real_fops;
	refcount_t active_users;
	struct completion active_users_drained;
};

struct debugfs_mount_opts {
	kuid_t uid;
	kgid_t gid;
	umode_t mode;
};

enum {
	Opt_uid___4 = 0,
	Opt_gid___5 = 1,
	Opt_mode___4 = 2,
	Opt_err___6 = 3,
};

struct debugfs_fs_info {
	struct debugfs_mount_opts mount_opts;
};

struct debugfs_blob_wrapper {
	void *data;
	long unsigned int size;
};

struct debugfs_reg32 {
	char *name;
	long unsigned int offset;
};

struct debugfs_regset32 {
	const struct debugfs_reg32 *regs;
	int nregs;
	void *base;
};

struct debugfs_fsdata___2 {
	const struct file_operations___36 *real_fops;
	refcount_t active_users;
	struct completion active_users_drained;
};

struct array_data {
	void *array;
	u32 elements;
};

struct debugfs_devm_entry {
	int (*read)(struct seq_file___33 *, void *);
	struct device___31 *dev;
};

struct tree_descr___4 {
	const char *name;
	const struct file_operations___219 *ops;
	int mode;
};

struct tracefs_dir_ops {
	int (*mkdir)(const char *);
	int (*rmdir)(const char *);
};

struct tracefs_mount_opts {
	kuid_t uid;
	kgid_t gid;
	umode_t mode;
};

struct tracefs_fs_info {
	struct tracefs_mount_opts mount_opts;
};

struct module___182;

struct file___225;

struct kiocb___225;

struct vm_area_struct___225;

struct inode___225;

struct file_lock___225;

struct page___225;

struct seq_file___203;

struct file_operations___225 {
	struct module___182 *owner;
	loff_t (*llseek)(struct file___225 *, loff_t, int);
	ssize_t (*read)(struct file___225 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___225 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___225 *, struct iov_iter___101 *);
	ssize_t (*write_iter)(struct kiocb___225 *, struct iov_iter___101 *);
	int (*iopoll)(struct kiocb___225 *, bool);
	int (*iterate)(struct file___225 *, struct dir_context *);
	int (*iterate_shared)(struct file___225 *, struct dir_context *);
	__poll_t (*poll)(struct file___225 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___225 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___225 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___225 *, struct vm_area_struct___225 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___225 *, struct file___225 *);
	int (*flush)(struct file___225 *, fl_owner_t);
	int (*release)(struct inode___225 *, struct file___225 *);
	int (*fsync)(struct file___225 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___225 *, int);
	int (*lock)(struct file___225 *, int, struct file_lock___225 *);
	ssize_t (*sendpage)(struct file___225 *, struct page___225 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___225 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___225 *, int, struct file_lock___225 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___225 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___225 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___225 *, long int, struct file_lock___225 **, void **);
	long int (*fallocate)(struct file___225 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___203 *, struct file___225 *);
	ssize_t (*copy_file_range)(struct file___225 *, loff_t, struct file___225 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___225 *, loff_t, struct file___225 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___225 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___224 {
	u64 seqnum;
	struct vm_area_struct___225 *vmas[4];
};

struct page_frag___224 {
	struct page___225 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___224;

struct pid___170;

struct cred___218;

struct nsproxy___207;

struct signal_struct___188;

struct task_struct___225 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___225 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___224 *mm;
	struct mm_struct___224 *active_mm;
	struct vmacache___224 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___225 *real_parent;
	struct task_struct___225 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___225 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___170 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___170 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___170 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___218 *ptracer_cred;
	const struct cred___218 *real_cred;
	const struct cred___218 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___207 *nsproxy;
	struct signal_struct___188 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___225 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___58 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___224 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___225 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___121 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rw_semaphore___225 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___225 *owner;
};

struct key___218;

struct ucounts___189;

struct user_namespace___189 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___189 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___27 ns;
	long unsigned int flags;
	struct key___218 *persistent_keyring_register;
	struct rw_semaphore___225 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___189 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___225 *pgtable_t___224;

struct address_space___224;

struct dev_pagemap___217;

struct page___225 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___224 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___225 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___224 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___224 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___217 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___224;

struct lruvec___224 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___224 *pgdat;
};

struct zone___224 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___224 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___224 {
	struct zone___224 *zone;
	int zone_idx;
};

struct zonelist___224 {
	struct zoneref___224 _zonerefs[25];
};

struct pglist_data___224 {
	struct zone___224 node_zones[3];
	struct zonelist___224 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___225 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___225 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___224 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___225 {
	void *stack;
	struct task_struct___225 *task;
	long int status;
};

struct blocking_notifier_head___224 {
	struct rw_semaphore___225 rwsem;
	struct notifier_block *head;
};

struct vfsmount___56;

struct dentry___225;

struct path___224 {
	struct vfsmount___56 *mnt;
	struct dentry___225 *dentry;
};

struct fown_struct___170 {
	rwlock_t lock;
	struct pid___170 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___225 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___224 f_path;
	struct inode___225 *f_inode;
	const struct file_operations___225 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___170 f_owner;
	const struct cred___218 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___224 *f_mapping;
	errseq_t f_wb_err;
};

struct user_struct___218;

struct cred___218 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___218 *session_keyring;
	struct key___218 *process_keyring;
	struct key___218 *thread_keyring;
	struct key___218 *request_key_auth;
	void *security;
	struct user_struct___218 *user;
	struct user_namespace___189 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___219;

struct kernfs_elem_dir___219 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___219 *root;
};

struct kernfs_node___219;

struct kernfs_syscall_ops___219;

struct kernfs_root___219 {
	struct kernfs_node___219 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___219 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___219 {
	struct kernfs_node___219 *target_kn;
};

struct kernfs_ops___219;

struct kernfs_elem_attr___219 {
	const struct kernfs_ops___219 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___219 *notify_next;
};

struct kernfs_node___219 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___219 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___219 dir;
		struct kernfs_elem_symlink___219 symlink;
		struct kernfs_elem_attr___219 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___219;

struct kernfs_ops___219 {
	int (*open)(struct kernfs_open_file___219 *);
	void (*release)(struct kernfs_open_file___219 *);
	int (*seq_show)(struct seq_file___203 *, void *);
	void * (*seq_start)(struct seq_file___203 *, loff_t *);
	void * (*seq_next)(struct seq_file___203 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___203 *, void *);
	ssize_t (*read)(struct kernfs_open_file___219 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___219 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___219 *, struct vm_area_struct___225 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___219 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___219 {
	int (*remount_fs)(struct kernfs_root___219 *, int *, char *);
	int (*show_options)(struct seq_file___203 *, struct kernfs_root___219 *);
	int (*mkdir)(struct kernfs_node___219 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___219 *);
	int (*rename)(struct kernfs_node___219 *, struct kernfs_node___219 *, const char *);
	int (*show_path)(struct seq_file___203 *, struct kernfs_node___219 *, struct kernfs_root___219 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___201;

struct seq_file___203 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___201 *op;
	int poll_event;
	const struct file___225 *file;
	void *private;
};

struct vm_operations_struct___217;

struct kernfs_open_file___219 {
	struct kernfs_node___219 *kn;
	struct file___225 *file;
	struct seq_file___203 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___217 *vm_ops;
};

struct vm_fault___217;

struct vm_operations_struct___217 {
	void (*open)(struct vm_area_struct___225 *);
	void (*close)(struct vm_area_struct___225 *);
	int (*split)(struct vm_area_struct___225 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___225 *);
	vm_fault_t (*fault)(struct vm_fault___217 *);
	vm_fault_t (*huge_fault)(struct vm_fault___217 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___217 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___225 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___217 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___217 *);
	int (*access)(struct vm_area_struct___225 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___225 *);
	int (*set_policy)(struct vm_area_struct___225 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___225 *, long unsigned int);
	struct page___225 * (*find_special_page)(struct vm_area_struct___225 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_area_struct___225 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___225 *vm_next;
	struct vm_area_struct___225 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___224 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___217 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___225 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___212;

struct kobj_type___212;

struct kobject___213 {
	const char *name;
	struct list_head entry;
	struct kobject___213 *parent;
	struct kset___212 *kset;
	struct kobj_type___212 *ktype;
	struct kernfs_node___219 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sysfs_ops___212 {
	ssize_t (*show)(struct kobject___213 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___213 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___212;

struct kset___212 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___213 kobj;
	const struct kset_uevent_ops___212 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___212 {
	void (*release)(struct kobject___213 *);
	const struct sysfs_ops___212 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___12 * (*child_ns_type)(struct kobject___213 *);
	const void * (*namespace)(struct kobject___213 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___212 {
	int (* const filter)(struct kset___212 *, struct kobject___213 *);
	const char * (* const name)(struct kset___212 *, struct kobject___213 *);
	int (* const uevent)(struct kset___212 *, struct kobject___213 *, struct kobj_uevent_env *);
};

struct kobj_attribute___208 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___213 *, struct kobj_attribute___208 *, char *);
	ssize_t (*store)(struct kobject___213 *, struct kobj_attribute___208 *, const char *, size_t);
};

struct kernel_param___179;

struct kernel_param_ops___179 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___179 *);
	int (*get)(char *, const struct kernel_param___179 *);
	void (*free)(void *);
};

struct kparam_array___179;

struct kernel_param___179 {
	const char *name;
	struct module___182 *mod;
	const struct kernel_param_ops___179 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___179 *arr;
	};
};

struct kparam_array___179 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___179 *ops;
	void *elem;
};

struct module_kobject___179 {
	struct kobject___213 kobj;
	struct module___182 *mod;
	struct kobject___213 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___179 {
	struct module___182 *mod;
	struct latch_tree_node node;
};

struct module_layout___179 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___179 mtn;
};

struct module_attribute___179;

struct module___182 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___179 mkobj;
	struct module_attribute___179 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___213 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___179 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___179 core_layout;
	struct module_layout___179 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___179 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___179 *, struct module_kobject___179 *, char *);
	ssize_t (*store)(struct module_attribute___179 *, struct module_kobject___179 *, const char *, size_t);
	void (*setup)(struct module___182 *, const char *);
	int (*test)(struct module___182 *);
	void (*free)(struct module___182 *);
};

struct dentry_operations___224;

struct super_block___224;

struct dentry___225 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___225 *d_parent;
	struct qstr d_name;
	struct inode___225 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___224 *d_op;
	struct super_block___224 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___224;

struct address_space___224 {
	struct inode___225 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___225 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___224 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___224;

struct block_device___225;

struct inode___225 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___224 *i_op;
	struct super_block___224 *i_sb;
	struct address_space___224 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___225 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___225 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___224 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___225 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___224 {
	int (*d_revalidate)(struct dentry___225 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___225 *, unsigned int);
	int (*d_hash)(const struct dentry___225 *, struct qstr *);
	int (*d_compare)(const struct dentry___225 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___225 *);
	int (*d_init)(struct dentry___225 *);
	void (*d_release)(struct dentry___225 *);
	void (*d_prune)(struct dentry___225 *);
	void (*d_iput)(struct dentry___225 *, struct inode___225 *);
	char * (*d_dname)(struct dentry___225 *, char *, int);
	struct vfsmount___56 * (*d_automount)(struct path___224 *);
	int (*d_manage)(const struct path___224 *, bool);
	struct dentry___225 * (*d_real)(struct dentry___225 *, const struct inode___225 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___224;

struct mem_dqinfo___224 {
	struct quota_format_type___224 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___224;

struct quota_info___224 {
	unsigned int flags;
	struct rw_semaphore___225 dqio_sem;
	struct inode___225 *files[3];
	struct mem_dqinfo___224 info[3];
	const struct quota_format_ops___224 *ops[3];
};

struct rcuwait___224 {
	struct task_struct___225 *task;
};

struct percpu_rw_semaphore___224 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___225 rw_sem;
	struct rcuwait___224 writer;
	int readers_block;
};

struct sb_writers___224 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___224 rw_sem[3];
};

struct file_system_type___224;

struct super_operations___224;

struct dquot_operations___224;

struct quotactl_ops___224;

struct super_block___224 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___224 *s_type;
	const struct super_operations___224 *s_op;
	const struct dquot_operations___224 *dq_op;
	const struct quotactl_ops___224 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___225 *s_root;
	struct rw_semaphore___225 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___225 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___224 s_dquot;
	struct sb_writers___224 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___224 *s_d_op;
	int cleancache_poolid;
	struct shrinker___95 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___189 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___56 {
	struct dentry___225 *mnt_root;
	struct super_block___224 *mnt_sb;
	int mnt_flags;
};

struct pid_namespace___170;

struct upid___170 {
	int nr;
	struct pid_namespace___170 *ns;
};

struct pid_namespace___170 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___225 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___170 *parent;
	struct vfsmount___56 *proc_mnt;
	struct dentry___225 *proc_self;
	struct dentry___225 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___189 *user_ns;
	struct ucounts___189 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___170 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___170 numbers[1];
};

struct core_state___224;

struct mm_struct___224 {
	struct {
		struct vm_area_struct___225 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___225 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___225 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___224 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___225 *owner;
		struct user_namespace___189 *user_ns;
		struct file___225 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___224 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___217)(struct vm_area_struct___225 *, long unsigned int, const struct page___225 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___217)(struct page___225 *, void *);

struct dev_pagemap___217 {
	dev_page_fault_t___217 page_fault;
	dev_page_free_t___217 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___6 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___224 {
	struct task_struct___225 *task;
	struct core_thread___224 *next;
};

struct core_state___224 {
	atomic_t nr_threads;
	struct core_thread___224 dumper;
	struct completion startup;
};

struct vm_fault___217 {
	struct vm_area_struct___225 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___225 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___225 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___224 prealloc_pte;
};

struct user_struct___218 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___218 *uid_keyring;
	struct key___218 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct nsproxy___207 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___170 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct signal_struct___188 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___225 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___225 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___170 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___170 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___224 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___170 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

union thread_union___199 {
	struct task_struct___225 task;
	long unsigned int stack[8192];
};

struct kiocb___225 {
	struct file___225 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___225 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___224 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___225 *ia_file;
};

struct dquot___224 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___224 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___224 {
	int qf_fmt_id;
	const struct quota_format_ops___224 *qf_ops;
	struct module___182 *qf_owner;
	struct quota_format_type___224 *qf_next;
};

struct quota_format_ops___224 {
	int (*check_quota_file)(struct super_block___224 *, int);
	int (*read_file_info)(struct super_block___224 *, int);
	int (*write_file_info)(struct super_block___224 *, int);
	int (*free_file_info)(struct super_block___224 *, int);
	int (*read_dqblk)(struct dquot___224 *);
	int (*commit_dqblk)(struct dquot___224 *);
	int (*release_dqblk)(struct dquot___224 *);
	int (*get_next_id)(struct super_block___224 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___224 {
	int (*write_dquot)(struct dquot___224 *);
	struct dquot___224 * (*alloc_dquot)(struct super_block___224 *, int);
	void (*destroy_dquot)(struct dquot___224 *);
	int (*acquire_dquot)(struct dquot___224 *);
	int (*release_dquot)(struct dquot___224 *);
	int (*mark_dirty)(struct dquot___224 *);
	int (*write_info)(struct super_block___224 *, int);
	qsize_t * (*get_reserved_space)(struct inode___225 *);
	int (*get_projid)(struct inode___225 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___225 *, qsize_t *);
	int (*get_next_id)(struct super_block___224 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___224 {
	int (*quota_on)(struct super_block___224 *, int, int, const struct path___224 *);
	int (*quota_off)(struct super_block___224 *, int);
	int (*quota_enable)(struct super_block___224 *, unsigned int);
	int (*quota_disable)(struct super_block___224 *, unsigned int);
	int (*quota_sync)(struct super_block___224 *, int);
	int (*set_info)(struct super_block___224 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___224 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___224 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___224 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___224 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___224 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___224 {
	int (*writepage)(struct page___225 *, struct writeback_control___3 *);
	int (*readpage)(struct file___225 *, struct page___225 *);
	int (*writepages)(struct address_space___224 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___225 *);
	int (*readpages)(struct file___225 *, struct address_space___224 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___225 *, struct address_space___224 *, loff_t, unsigned int, unsigned int, struct page___225 **, void **);
	int (*write_end)(struct file___225 *, struct address_space___224 *, loff_t, unsigned int, unsigned int, struct page___225 *, void *);
	sector_t (*bmap)(struct address_space___224 *, sector_t);
	void (*invalidatepage)(struct page___225 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___225 *, gfp_t);
	void (*freepage)(struct page___225 *);
	ssize_t (*direct_IO)(struct kiocb___225 *, struct iov_iter___101 *);
	int (*migratepage)(struct address_space___224 *, struct page___225 *, struct page___225 *, enum migrate_mode);
	bool (*isolate_page)(struct page___225 *, isolate_mode_t);
	void (*putback_page)(struct page___225 *);
	int (*launder_page)(struct page___225 *);
	int (*is_partially_uptodate)(struct page___225 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___225 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___224 *, struct page___225 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___225 *, sector_t *);
	void (*swap_deactivate)(struct file___225 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___225 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___225 *bd_inode;
	struct super_block___224 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___225 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___224 {
	struct dentry___225 * (*lookup)(struct inode___225 *, struct dentry___225 *, unsigned int);
	const char * (*get_link)(struct dentry___225 *, struct inode___225 *, struct delayed_call *);
	int (*permission)(struct inode___225 *, int);
	struct posix_acl * (*get_acl)(struct inode___225 *, int);
	int (*readlink)(struct dentry___225 *, char *, int);
	int (*create)(struct inode___225 *, struct dentry___225 *, umode_t, bool);
	int (*link)(struct dentry___225 *, struct inode___225 *, struct dentry___225 *);
	int (*unlink)(struct inode___225 *, struct dentry___225 *);
	int (*symlink)(struct inode___225 *, struct dentry___225 *, const char *);
	int (*mkdir)(struct inode___225 *, struct dentry___225 *, umode_t);
	int (*rmdir)(struct inode___225 *, struct dentry___225 *);
	int (*mknod)(struct inode___225 *, struct dentry___225 *, umode_t, dev_t);
	int (*rename)(struct inode___225 *, struct dentry___225 *, struct inode___225 *, struct dentry___225 *, unsigned int);
	int (*setattr)(struct dentry___225 *, struct iattr___224 *);
	int (*getattr)(const struct path___224 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___225 *, char *, size_t);
	int (*fiemap)(struct inode___225 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___225 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___225 *, struct dentry___225 *, struct file___225 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___225 *, struct dentry___225 *, umode_t);
	int (*set_acl)(struct inode___225 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___224 {
	void (*fl_copy_lock)(struct file_lock___225 *, struct file_lock___225 *);
	void (*fl_release_private)(struct file_lock___225 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___224;

struct lock_manager_operations___224;

struct file_lock___225 {
	struct file_lock___225 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___225 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___224 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___224 *fl_ops;
	const struct lock_manager_operations___224 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___224 {
	int (*lm_compare_owner)(struct file_lock___225 *, struct file_lock___225 *);
	long unsigned int (*lm_owner_key)(struct file_lock___225 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___225 *);
	int (*lm_grant)(struct file_lock___225 *, int);
	bool (*lm_break)(struct file_lock___225 *);
	int (*lm_change)(struct file_lock___225 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___225 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___224 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___224 *fa_next;
	struct file___225 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___224 {
	const char *name;
	int fs_flags;
	struct dentry___225 * (*mount)(struct file_system_type___224 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___224 *);
	struct module___182 *owner;
	struct file_system_type___224 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___224 {
	struct inode___225 * (*alloc_inode)(struct super_block___224 *);
	void (*destroy_inode)(struct inode___225 *);
	void (*dirty_inode)(struct inode___225 *, int);
	int (*write_inode)(struct inode___225 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___225 *);
	void (*evict_inode)(struct inode___225 *);
	void (*put_super)(struct super_block___224 *);
	int (*sync_fs)(struct super_block___224 *, int);
	int (*freeze_super)(struct super_block___224 *);
	int (*freeze_fs)(struct super_block___224 *);
	int (*thaw_super)(struct super_block___224 *);
	int (*unfreeze_fs)(struct super_block___224 *);
	int (*statfs)(struct dentry___225 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___224 *, int *, char *);
	void (*umount_begin)(struct super_block___224 *);
	int (*show_options)(struct seq_file___203 *, struct dentry___225 *);
	int (*show_devname)(struct seq_file___203 *, struct dentry___225 *);
	int (*show_path)(struct seq_file___203 *, struct dentry___225 *);
	int (*show_stats)(struct seq_file___203 *, struct dentry___225 *);
	ssize_t (*quota_read)(struct super_block___224 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___224 *, int, const char *, size_t, loff_t);
	struct dquot___224 ** (*get_dquots)(struct inode___225 *);
	int (*bdev_try_to_free_page)(struct super_block___224 *, struct page___225 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___224 *, struct shrink_control___95 *);
	long int (*free_cached_objects)(struct super_block___224 *, struct shrink_control___95 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct key_restriction___218;

struct key___218 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___225 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___218 *restrict_link;
};

struct ucounts___189 {
	struct hlist_node node;
	struct user_namespace___189 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct seq_operations___201 {
	void * (*start)(struct seq_file___203 *, loff_t *);
	void (*stop)(struct seq_file___203 *, void *);
	void * (*next)(struct seq_file___203 *, void *, loff_t *);
	int (*show)(struct seq_file___203 *, void *);
};

typedef int (*key_restrict_link_func_t___218)(struct key___218 *, const struct key_type *, const union key_payload *, struct key___218 *);

struct key_restriction___218 {
	key_restrict_link_func_t___218 check;
	struct key___218 *key;
	struct key_type *keytype;
};

typedef void compound_page_dtor___217(struct page___225 *);

enum pstore_type_id {
	PSTORE_TYPE_DMESG = 0,
	PSTORE_TYPE_MCE = 1,
	PSTORE_TYPE_CONSOLE = 2,
	PSTORE_TYPE_FTRACE = 3,
	PSTORE_TYPE_PPC_RTAS = 4,
	PSTORE_TYPE_PPC_OF = 5,
	PSTORE_TYPE_PPC_COMMON = 6,
	PSTORE_TYPE_PMSG = 7,
	PSTORE_TYPE_PPC_OPAL = 8,
	PSTORE_TYPE_UNKNOWN = 255,
};

struct pstore_info;

struct pstore_record {
	struct pstore_info *psi;
	enum pstore_type_id type;
	u64 id;
	struct timespec64 time;
	char *buf;
	ssize_t size;
	ssize_t ecc_notice_size;
	int count;
	enum kmsg_dump_reason reason;
	unsigned int part;
	bool compressed;
};

struct pstore_info {
	struct module___182 *owner;
	char *name;
	spinlock_t buf_lock;
	char *buf;
	size_t bufsize;
	struct mutex read_mutex;
	int flags;
	void *data;
	int (*open)(struct pstore_info *);
	int (*close)(struct pstore_info *);
	ssize_t (*read)(struct pstore_record *);
	int (*write)(struct pstore_record *);
	int (*write_user)(struct pstore_record *, const char *);
	int (*erase)(struct pstore_record *);
};

struct pstore_ftrace_record {
	long unsigned int ip;
	long unsigned int parent_ip;
	u64 ts;
};

struct pstore_private {
	struct list_head list;
	struct pstore_record *record;
	size_t total_size;
};

struct pstore_ftrace_seq_data {
	const void *ptr;
	size_t off;
	size_t size;
};

enum {
	Opt_kmsg_bytes = 0,
	Opt_err___7 = 1,
};

struct pstore_zbackend {
	int (*zbufsize)(size_t);
	const char *name;
};

struct efi_variable {
	efi_char16_t VariableName[512];
	efi_guid_t VendorGuid;
	long unsigned int DataSize;
	__u8 Data[1024];
	efi_status_t Status;
	__u32 Attributes;
} __attribute__((packed));

struct efivar_entry {
	struct efi_variable var;
	struct list_head list;
	struct kobject___7 kobj;
	bool scanning;
	bool deleting;
};

struct file___226;

struct kiocb___226;

struct poll_table_struct___141;

struct vm_area_struct___226;

struct inode___226;

struct file_lock___226;

struct page___226;

struct seq_file___204;

struct file_operations___226 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___226 *, loff_t, int);
	ssize_t (*read)(struct file___226 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___226 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___226 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___226 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___226 *, bool);
	int (*iterate)(struct file___226 *, struct dir_context *);
	int (*iterate_shared)(struct file___226 *, struct dir_context *);
	__poll_t (*poll)(struct file___226 *, struct poll_table_struct___141 *);
	long int (*unlocked_ioctl)(struct file___226 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___226 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___226 *, struct vm_area_struct___226 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___226 *, struct file___226 *);
	int (*flush)(struct file___226 *, fl_owner_t);
	int (*release)(struct inode___226 *, struct file___226 *);
	int (*fsync)(struct file___226 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___226 *, int);
	int (*lock)(struct file___226 *, int, struct file_lock___226 *);
	ssize_t (*sendpage)(struct file___226 *, struct page___226 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___226 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___226 *, int, struct file_lock___226 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___226 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___226 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___226 *, long int, struct file_lock___226 **, void **);
	long int (*fallocate)(struct file___226 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___204 *, struct file___226 *);
	ssize_t (*copy_file_range)(struct file___226 *, loff_t, struct file___226 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___226 *, loff_t, struct file___226 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___226 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___225 {
	u64 seqnum;
	struct vm_area_struct___226 *vmas[4];
};

struct page_frag___225 {
	struct page___226 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___225;

struct cred___219;

struct task_struct___226 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___226 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___225 *mm;
	struct mm_struct___225 *active_mm;
	struct vmacache___225 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___226 *real_parent;
	struct task_struct___226 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___226 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___170 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___170 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___170 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___219 *ptracer_cred;
	const struct cred___219 *real_cred;
	const struct cred___219 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___226 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___58 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___225 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___226 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___121 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___225;

struct super_block___225;

struct dentry___226 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___226 *d_parent;
	struct qstr d_name;
	struct inode___226 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___225 *d_op;
	struct super_block___225 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct rw_semaphore___226 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___226 *owner;
};

struct address_space_operations___225;

struct address_space___225 {
	struct inode___226 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___226 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___225 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___225;

struct block_device___226;

struct cdev___38;

struct inode___226 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___225 *i_op;
	struct super_block___225 *i_sb;
	struct address_space___225 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___226 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___226 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___225 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___226 *i_bdev;
		struct cdev___38 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vfsmount___57;

struct path___225;

struct dentry_operations___225 {
	int (*d_revalidate)(struct dentry___226 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___226 *, unsigned int);
	int (*d_hash)(const struct dentry___226 *, struct qstr *);
	int (*d_compare)(const struct dentry___226 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___226 *);
	int (*d_init)(struct dentry___226 *);
	void (*d_release)(struct dentry___226 *);
	void (*d_prune)(struct dentry___226 *);
	void (*d_iput)(struct dentry___226 *, struct inode___226 *);
	char * (*d_dname)(struct dentry___226 *, char *, int);
	struct vfsmount___57 * (*d_automount)(struct path___225 *);
	int (*d_manage)(const struct path___225 *, bool);
	struct dentry___226 * (*d_real)(struct dentry___226 *, const struct inode___226 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___225;

struct mem_dqinfo___225 {
	struct quota_format_type___225 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___225;

struct quota_info___225 {
	unsigned int flags;
	struct rw_semaphore___226 dqio_sem;
	struct inode___226 *files[3];
	struct mem_dqinfo___225 info[3];
	const struct quota_format_ops___225 *ops[3];
};

struct rcuwait___225 {
	struct task_struct___226 *task;
};

struct percpu_rw_semaphore___225 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___226 rw_sem;
	struct rcuwait___225 writer;
	int readers_block;
};

struct sb_writers___225 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___225 rw_sem[3];
};

struct file_system_type___225;

struct super_operations___225;

struct dquot_operations___225;

struct quotactl_ops___225;

struct super_block___225 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___225 *s_type;
	const struct super_operations___225 *s_op;
	const struct dquot_operations___225 *dq_op;
	const struct quotactl_ops___225 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___226 *s_root;
	struct rw_semaphore___226 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___226 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___225 s_dquot;
	struct sb_writers___225 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___225 *s_d_op;
	int cleancache_poolid;
	struct shrinker___95 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___57 {
	struct dentry___226 *mnt_root;
	struct super_block___225 *mnt_sb;
	int mnt_flags;
};

struct path___225 {
	struct vfsmount___57 *mnt;
	struct dentry___226 *dentry;
};

typedef struct page___226 *pgtable_t___225;

struct page___226 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___225 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___226 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___225 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___225 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___217 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___225;

struct lruvec___225 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___225 *pgdat;
};

struct zone___225 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___225 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___225 {
	struct zone___225 *zone;
	int zone_idx;
};

struct zonelist___225 {
	struct zoneref___225 _zonerefs[25];
};

struct pglist_data___225 {
	struct zone___225 node_zones[3];
	struct zonelist___225 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___226 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___226 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___225 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___226 {
	void *stack;
	struct task_struct___226 *task;
	long int status;
};

struct blocking_notifier_head___225 {
	struct rw_semaphore___226 rwsem;
	struct notifier_block *head;
};

struct vm_area_struct___226 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___226 *vm_next;
	struct vm_area_struct___226 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___225 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___13 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___226 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___225;

struct mm_struct___225 {
	struct {
		struct vm_area_struct___226 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___226 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___226 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___225 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___226 *owner;
		struct user_namespace___3 *user_ns;
		struct file___226 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___225 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct file___226 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___225 f_path;
	struct inode___226 *f_inode;
	const struct file_operations___226 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___170 f_owner;
	const struct cred___219 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___225 *f_mapping;
	errseq_t f_wb_err;
};

struct core_thread___225 {
	struct task_struct___226 *task;
	struct core_thread___225 *next;
};

struct core_state___225 {
	atomic_t nr_threads;
	struct core_thread___225 dumper;
	struct completion startup;
};

struct key___219;

struct user_struct___219 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___219 *uid_keyring;
	struct key___219 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___219 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___219 *session_keyring;
	struct key___219 *process_keyring;
	struct key___219 *thread_keyring;
	struct key___219 *request_key_auth;
	void *security;
	struct user_struct___219 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kiocb___226 {
	struct file___226 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___226 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___225 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___226 *ia_file;
};

struct dquot___225 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___225 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___225 {
	int qf_fmt_id;
	const struct quota_format_ops___225 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___225 *qf_next;
};

struct quota_format_ops___225 {
	int (*check_quota_file)(struct super_block___225 *, int);
	int (*read_file_info)(struct super_block___225 *, int);
	int (*write_file_info)(struct super_block___225 *, int);
	int (*free_file_info)(struct super_block___225 *, int);
	int (*read_dqblk)(struct dquot___225 *);
	int (*commit_dqblk)(struct dquot___225 *);
	int (*release_dqblk)(struct dquot___225 *);
	int (*get_next_id)(struct super_block___225 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___225 {
	int (*write_dquot)(struct dquot___225 *);
	struct dquot___225 * (*alloc_dquot)(struct super_block___225 *, int);
	void (*destroy_dquot)(struct dquot___225 *);
	int (*acquire_dquot)(struct dquot___225 *);
	int (*release_dquot)(struct dquot___225 *);
	int (*mark_dirty)(struct dquot___225 *);
	int (*write_info)(struct super_block___225 *, int);
	qsize_t * (*get_reserved_space)(struct inode___226 *);
	int (*get_projid)(struct inode___226 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___226 *, qsize_t *);
	int (*get_next_id)(struct super_block___225 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___225 {
	int (*quota_on)(struct super_block___225 *, int, int, const struct path___225 *);
	int (*quota_off)(struct super_block___225 *, int);
	int (*quota_enable)(struct super_block___225 *, unsigned int);
	int (*quota_disable)(struct super_block___225 *, unsigned int);
	int (*quota_sync)(struct super_block___225 *, int);
	int (*set_info)(struct super_block___225 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___225 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___225 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___225 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___225 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___225 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___225 {
	int (*writepage)(struct page___226 *, struct writeback_control___3 *);
	int (*readpage)(struct file___226 *, struct page___226 *);
	int (*writepages)(struct address_space___225 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___226 *);
	int (*readpages)(struct file___226 *, struct address_space___225 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___226 *, struct address_space___225 *, loff_t, unsigned int, unsigned int, struct page___226 **, void **);
	int (*write_end)(struct file___226 *, struct address_space___225 *, loff_t, unsigned int, unsigned int, struct page___226 *, void *);
	sector_t (*bmap)(struct address_space___225 *, sector_t);
	void (*invalidatepage)(struct page___226 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___226 *, gfp_t);
	void (*freepage)(struct page___226 *);
	ssize_t (*direct_IO)(struct kiocb___226 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___225 *, struct page___226 *, struct page___226 *, enum migrate_mode);
	bool (*isolate_page)(struct page___226 *, isolate_mode_t);
	void (*putback_page)(struct page___226 *);
	int (*launder_page)(struct page___226 *);
	int (*is_partially_uptodate)(struct page___226 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___226 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___225 *, struct page___226 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___226 *, sector_t *);
	void (*swap_deactivate)(struct file___226 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___226 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___226 *bd_inode;
	struct super_block___225 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___226 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___213;

struct kobj_type___213;

struct kernfs_node___220;

struct kobject___214 {
	const char *name;
	struct list_head entry;
	struct kobject___214 *parent;
	struct kset___213 *kset;
	struct kobj_type___213 *ktype;
	struct kernfs_node___220 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___38 {
	struct kobject___214 kobj;
	struct module___11 *owner;
	const struct file_operations___226 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___225 {
	struct dentry___226 * (*lookup)(struct inode___226 *, struct dentry___226 *, unsigned int);
	const char * (*get_link)(struct dentry___226 *, struct inode___226 *, struct delayed_call *);
	int (*permission)(struct inode___226 *, int);
	struct posix_acl * (*get_acl)(struct inode___226 *, int);
	int (*readlink)(struct dentry___226 *, char *, int);
	int (*create)(struct inode___226 *, struct dentry___226 *, umode_t, bool);
	int (*link)(struct dentry___226 *, struct inode___226 *, struct dentry___226 *);
	int (*unlink)(struct inode___226 *, struct dentry___226 *);
	int (*symlink)(struct inode___226 *, struct dentry___226 *, const char *);
	int (*mkdir)(struct inode___226 *, struct dentry___226 *, umode_t);
	int (*rmdir)(struct inode___226 *, struct dentry___226 *);
	int (*mknod)(struct inode___226 *, struct dentry___226 *, umode_t, dev_t);
	int (*rename)(struct inode___226 *, struct dentry___226 *, struct inode___226 *, struct dentry___226 *, unsigned int);
	int (*setattr)(struct dentry___226 *, struct iattr___225 *);
	int (*getattr)(const struct path___225 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___226 *, char *, size_t);
	int (*fiemap)(struct inode___226 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___226 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___226 *, struct dentry___226 *, struct file___226 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___226 *, struct dentry___226 *, umode_t);
	int (*set_acl)(struct inode___226 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___225 {
	void (*fl_copy_lock)(struct file_lock___226 *, struct file_lock___226 *);
	void (*fl_release_private)(struct file_lock___226 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___225;

struct lock_manager_operations___225;

struct file_lock___226 {
	struct file_lock___226 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___226 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___225 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___225 *fl_ops;
	const struct lock_manager_operations___225 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___225 {
	int (*lm_compare_owner)(struct file_lock___226 *, struct file_lock___226 *);
	long unsigned int (*lm_owner_key)(struct file_lock___226 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___226 *);
	int (*lm_grant)(struct file_lock___226 *, int);
	bool (*lm_break)(struct file_lock___226 *);
	int (*lm_change)(struct file_lock___226 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___226 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___225 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___225 *fa_next;
	struct file___226 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___225 {
	const char *name;
	int fs_flags;
	struct dentry___226 * (*mount)(struct file_system_type___225 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___225 *);
	struct module___11 *owner;
	struct file_system_type___225 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___225 {
	struct inode___226 * (*alloc_inode)(struct super_block___225 *);
	void (*destroy_inode)(struct inode___226 *);
	void (*dirty_inode)(struct inode___226 *, int);
	int (*write_inode)(struct inode___226 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___226 *);
	void (*evict_inode)(struct inode___226 *);
	void (*put_super)(struct super_block___225 *);
	int (*sync_fs)(struct super_block___225 *, int);
	int (*freeze_super)(struct super_block___225 *);
	int (*freeze_fs)(struct super_block___225 *);
	int (*thaw_super)(struct super_block___225 *);
	int (*unfreeze_fs)(struct super_block___225 *);
	int (*statfs)(struct dentry___226 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___225 *, int *, char *);
	void (*umount_begin)(struct super_block___225 *);
	int (*show_options)(struct seq_file___204 *, struct dentry___226 *);
	int (*show_devname)(struct seq_file___204 *, struct dentry___226 *);
	int (*show_path)(struct seq_file___204 *, struct dentry___226 *);
	int (*show_stats)(struct seq_file___204 *, struct dentry___226 *);
	ssize_t (*quota_read)(struct super_block___225 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___225 *, int, const char *, size_t, loff_t);
	struct dquot___225 ** (*get_dquots)(struct inode___226 *);
	int (*bdev_try_to_free_page)(struct super_block___225 *, struct page___226 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___225 *, struct shrink_control___95 *);
	long int (*free_cached_objects)(struct super_block___225 *, struct shrink_control___95 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___143)(struct file___226 *, wait_queue_head_t *, struct poll_table_struct___141 *);

struct poll_table_struct___141 {
	poll_queue_proc___143 _qproc;
	__poll_t _key;
};

struct seq_operations___202;

struct seq_file___204 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___202 *op;
	int poll_event;
	const struct file___226 *file;
	void *private;
};

struct device___193;

struct dev_pm_info___193 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___193 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___193;

struct bus_type___193;

struct device_driver___193;

struct dev_pm_domain___193;

struct class___193;

struct attribute_group___195;

struct device___193 {
	struct device___193 *parent;
	struct device_private *p;
	struct kobject___214 kobj;
	const char *init_name;
	const struct device_type___193 *type;
	struct mutex mutex;
	struct bus_type___193 *bus;
	struct device_driver___193 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___193 power;
	struct dev_pm_domain___193 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___193 *class;
	const struct attribute_group___195 **groups;
	void (*release)(struct device___193 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct kernfs_root___220;

struct kernfs_elem_dir___220 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___220 *root;
};

struct kernfs_syscall_ops___220;

struct kernfs_root___220 {
	struct kernfs_node___220 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___220 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___220 {
	struct kernfs_node___220 *target_kn;
};

struct kernfs_ops___220;

struct kernfs_elem_attr___220 {
	const struct kernfs_ops___220 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___220 *notify_next;
};

struct kernfs_node___220 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___220 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___220 dir;
		struct kernfs_elem_symlink___220 symlink;
		struct kernfs_elem_attr___220 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___220;

struct kernfs_ops___220 {
	int (*open)(struct kernfs_open_file___220 *);
	void (*release)(struct kernfs_open_file___220 *);
	int (*seq_show)(struct seq_file___204 *, void *);
	void * (*seq_start)(struct seq_file___204 *, loff_t *);
	void * (*seq_next)(struct seq_file___204 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___204 *, void *);
	ssize_t (*read)(struct kernfs_open_file___220 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___220 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___220 *, struct vm_area_struct___226 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___220 *, struct poll_table_struct___141 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___220 {
	int (*remount_fs)(struct kernfs_root___220 *, int *, char *);
	int (*show_options)(struct seq_file___204 *, struct kernfs_root___220 *);
	int (*mkdir)(struct kernfs_node___220 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___220 *);
	int (*rename)(struct kernfs_node___220 *, struct kernfs_node___220 *, const char *);
	int (*show_path)(struct seq_file___204 *, struct kernfs_node___220 *, struct kernfs_root___220 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___220 {
	struct kernfs_node___220 *kn;
	struct file___226 *file;
	struct seq_file___204 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___13 *vm_ops;
};

struct bin_attribute___194;

struct attribute_group___195 {
	const char *name;
	umode_t (*is_visible)(struct kobject___214 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___214 *, struct bin_attribute___194 *, int);
	struct attribute **attrs;
	struct bin_attribute___194 **bin_attrs;
};

struct bin_attribute___194 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___226 *, struct kobject___214 *, struct bin_attribute___194 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___226 *, struct kobject___214 *, struct bin_attribute___194 *, char *, loff_t, size_t);
	int (*mmap)(struct file___226 *, struct kobject___214 *, struct bin_attribute___194 *, struct vm_area_struct___226 *);
};

struct sysfs_ops___213 {
	ssize_t (*show)(struct kobject___214 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___214 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___213;

struct kset___213 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___214 kobj;
	const struct kset_uevent_ops___213 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___213 {
	void (*release)(struct kobject___214 *);
	const struct sysfs_ops___213 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___12 * (*child_ns_type)(struct kobject___214 *);
	const void * (*namespace)(struct kobject___214 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___213 {
	int (* const filter)(struct kset___213 *, struct kobject___214 *);
	const char * (* const name)(struct kset___213 *, struct kobject___214 *);
	int (* const uevent)(struct kset___213 *, struct kobject___214 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___193 {
	int (*prepare)(struct device___193 *);
	void (*complete)(struct device___193 *);
	int (*suspend)(struct device___193 *);
	int (*resume)(struct device___193 *);
	int (*freeze)(struct device___193 *);
	int (*thaw)(struct device___193 *);
	int (*poweroff)(struct device___193 *);
	int (*restore)(struct device___193 *);
	int (*suspend_late)(struct device___193 *);
	int (*resume_early)(struct device___193 *);
	int (*freeze_late)(struct device___193 *);
	int (*thaw_early)(struct device___193 *);
	int (*poweroff_late)(struct device___193 *);
	int (*restore_early)(struct device___193 *);
	int (*suspend_noirq)(struct device___193 *);
	int (*resume_noirq)(struct device___193 *);
	int (*freeze_noirq)(struct device___193 *);
	int (*thaw_noirq)(struct device___193 *);
	int (*poweroff_noirq)(struct device___193 *);
	int (*restore_noirq)(struct device___193 *);
	int (*runtime_suspend)(struct device___193 *);
	int (*runtime_resume)(struct device___193 *);
	int (*runtime_idle)(struct device___193 *);
};

struct dev_pm_domain___193 {
	struct dev_pm_ops___193 ops;
	void (*detach)(struct device___193 *, bool);
	int (*activate)(struct device___193 *);
	void (*sync)(struct device___193 *);
	void (*dismiss)(struct device___193 *);
};

struct bus_type___193 {
	const char *name;
	const char *dev_name;
	struct device___193 *dev_root;
	const struct attribute_group___195 **bus_groups;
	const struct attribute_group___195 **dev_groups;
	const struct attribute_group___195 **drv_groups;
	int (*match)(struct device___193 *, struct device_driver___193 *);
	int (*uevent)(struct device___193 *, struct kobj_uevent_env *);
	int (*probe)(struct device___193 *);
	int (*remove)(struct device___193 *);
	void (*shutdown)(struct device___193 *);
	int (*online)(struct device___193 *);
	int (*offline)(struct device___193 *);
	int (*suspend)(struct device___193 *, pm_message_t);
	int (*resume)(struct device___193 *);
	int (*num_vf)(struct device___193 *);
	int (*dma_configure)(struct device___193 *);
	const struct dev_pm_ops___193 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___193 {
	const char *name;
	struct bus_type___193 *bus;
	struct module___11 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___193 *);
	int (*remove)(struct device___193 *);
	void (*shutdown)(struct device___193 *);
	int (*suspend)(struct device___193 *, pm_message_t);
	int (*resume)(struct device___193 *);
	const struct attribute_group___195 **groups;
	const struct dev_pm_ops___193 *pm;
	void (*coredump)(struct device___193 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___193 {
	const char *name;
	const struct attribute_group___195 **groups;
	int (*uevent)(struct device___193 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___193 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___193 *);
	const struct dev_pm_ops___193 *pm;
};

struct class___193 {
	const char *name;
	struct module___11 *owner;
	const struct attribute_group___195 **class_groups;
	const struct attribute_group___195 **dev_groups;
	struct kobject___214 *dev_kobj;
	int (*dev_uevent)(struct device___193 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___193 *, umode_t *);
	void (*class_release)(struct class___193 *);
	void (*dev_release)(struct device___193 *);
	int (*shutdown_pre)(struct device___193 *);
	const struct kobj_ns_type_operations___12 *ns_type;
	const void * (*namespace)(struct device___193 *);
	const struct dev_pm_ops___193 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

typedef int (*key_restrict_link_func_t___219)(struct key___219 *, const struct key_type *, const union key_payload *, struct key___219 *);

struct key_restriction___219;

struct key___219 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___226 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___219 *restrict_link;
};

struct key_restriction___219 {
	key_restrict_link_func_t___219 check;
	struct key___219 *key;
	struct key_type *keytype;
};

struct seq_operations___202 {
	void * (*start)(struct seq_file___204 *, loff_t *);
	void (*stop)(struct seq_file___204 *, void *);
	void * (*next)(struct seq_file___204 *, void *, loff_t *);
	int (*show)(struct seq_file___204 *, void *);
};

struct efivar_entry___2 {
	struct efi_variable var;
	struct list_head list;
	struct kobject___214 kobj;
	bool scanning;
	bool deleting;
};

typedef unsigned int __kernel_mode_t;

struct file___227;

struct kiocb___227;

struct vm_area_struct___227;

struct inode___227;

struct file_lock___227;

struct page___227;

struct seq_file___205;

struct file_operations___227 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___227 *, loff_t, int);
	ssize_t (*read)(struct file___227 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___227 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___227 *, struct iov_iter___101 *);
	ssize_t (*write_iter)(struct kiocb___227 *, struct iov_iter___101 *);
	int (*iopoll)(struct kiocb___227 *, bool);
	int (*iterate)(struct file___227 *, struct dir_context *);
	int (*iterate_shared)(struct file___227 *, struct dir_context *);
	__poll_t (*poll)(struct file___227 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___227 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___227 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___227 *, struct vm_area_struct___227 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___227 *, struct file___227 *);
	int (*flush)(struct file___227 *, fl_owner_t);
	int (*release)(struct inode___227 *, struct file___227 *);
	int (*fsync)(struct file___227 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___227 *, int);
	int (*lock)(struct file___227 *, int, struct file_lock___227 *);
	ssize_t (*sendpage)(struct file___227 *, struct page___227 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___227 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___227 *, int, struct file_lock___227 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___227 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___227 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___227 *, long int, struct file_lock___227 **, void **);
	long int (*fallocate)(struct file___227 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___205 *, struct file___227 *);
	ssize_t (*copy_file_range)(struct file___227 *, loff_t, struct file___227 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___227 *, loff_t, struct file___227 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___227 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___226 {
	u64 seqnum;
	struct vm_area_struct___227 *vmas[4];
};

struct page_frag___226 {
	struct page___227 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___226;

struct pid___171;

struct cred___220;

struct nsproxy___208;

struct signal_struct___189;

struct vm_struct___150;

struct task_struct___227 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___227 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___226 *mm;
	struct mm_struct___226 *active_mm;
	struct vmacache___226 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___227 *real_parent;
	struct task_struct___227 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___227 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___171 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___171 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___171 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___220 *ptracer_cred;
	const struct cred___220 *real_cred;
	const struct cred___220 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___208 *nsproxy;
	struct signal_struct___189 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___227 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___58 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___226 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___227 *oom_reaper_list;
	struct vm_struct___150 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___121 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___227 *pgtable_t___226;

struct address_space___226;

struct dev_pagemap___218;

struct page___227 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___226 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___227 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___226 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___226 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___218 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___226;

struct lruvec___226 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___226 *pgdat;
};

struct zone___226 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___226 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___226 {
	struct zone___226 *zone;
	int zone_idx;
};

struct zonelist___226 {
	struct zoneref___226 _zonerefs[25];
};

struct pglist_data___226 {
	struct zone___226 node_zones[3];
	struct zonelist___226 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___227 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___227 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___226 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___227 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___227 *owner;
};

struct secondary_data___227 {
	void *stack;
	struct task_struct___227 *task;
	long int status;
};

struct blocking_notifier_head___226 {
	struct rw_semaphore___227 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___218;

struct vm_area_struct___227 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___227 *vm_next;
	struct vm_area_struct___227 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___226 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___218 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___227 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___226;

struct mm_struct___226 {
	struct {
		struct vm_area_struct___227 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___227 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___227 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___226 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___227 *owner;
		struct user_namespace___3 *user_ns;
		struct file___227 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___226 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___226;

struct address_space___226 {
	struct inode___227 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___227 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___226 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___218)(struct vm_area_struct___227 *, long unsigned int, const struct page___227 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___218)(struct page___227 *, void *);

struct device___194;

struct dev_pagemap___218 {
	dev_page_fault_t___218 page_fault;
	dev_page_free_t___218 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___194 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct dentry___227;

struct path___226 {
	struct vfsmount *mnt;
	struct dentry___227 *dentry;
};

struct fown_struct___171 {
	rwlock_t lock;
	struct pid___171 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___227 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___226 f_path;
	struct inode___227 *f_inode;
	const struct file_operations___227 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___171 f_owner;
	const struct cred___220 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___226 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___218;

struct vm_operations_struct___218 {
	void (*open)(struct vm_area_struct___227 *);
	void (*close)(struct vm_area_struct___227 *);
	int (*split)(struct vm_area_struct___227 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___227 *);
	vm_fault_t (*fault)(struct vm_fault___218 *);
	vm_fault_t (*huge_fault)(struct vm_fault___218 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___218 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___227 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___218 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___218 *);
	int (*access)(struct vm_area_struct___227 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___227 *);
	int (*set_policy)(struct vm_area_struct___227 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___227 *, long unsigned int);
	struct page___227 * (*find_special_page)(struct vm_area_struct___227 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___226 {
	struct task_struct___227 *task;
	struct core_thread___226 *next;
};

struct core_state___226 {
	atomic_t nr_threads;
	struct core_thread___226 dumper;
	struct completion startup;
};

struct vm_fault___218 {
	struct vm_area_struct___227 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___227 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___227 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___226 prealloc_pte;
};

struct pid_namespace___171;

struct upid___171 {
	int nr;
	struct pid_namespace___171 *ns;
};

struct pid_namespace___171 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___227 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___171 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___227 *proc_self;
	struct dentry___227 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___3 *user_ns;
	struct ucounts___2 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___171 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___171 numbers[1];
};

struct ipc_perm {
	__kernel_key_t key;
	__kernel_uid_t uid;
	__kernel_gid_t gid;
	__kernel_uid_t cuid;
	__kernel_gid_t cgid;
	__kernel_mode_t mode;
	short unsigned int seq;
};

struct ipc64_perm {
	__kernel_key_t key;
	__kernel_uid32_t uid;
	__kernel_gid32_t gid;
	__kernel_uid32_t cuid;
	__kernel_gid32_t cgid;
	__kernel_mode_t mode;
	unsigned char __pad1[0];
	short unsigned int seq;
	short unsigned int __pad2;
	__kernel_ulong_t __unused1;
	__kernel_ulong_t __unused2;
};

struct key___220;

struct user_struct___220 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___220 *uid_keyring;
	struct key___220 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___220 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___220 *session_keyring;
	struct key___220 *process_keyring;
	struct key___220 *thread_keyring;
	struct key___220 *request_key_auth;
	void *security;
	struct user_struct___220 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct ipc_namespace___3;

struct nsproxy___208 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace___3 *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___171 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct signal_struct___189 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___227 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___227 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___171 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___171 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___226 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___171 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_struct___150 {
	struct vm_struct___150 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___227 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___200 {
	struct task_struct___227 task;
	long unsigned int stack[8192];
};

struct kset___214;

struct kobj_type___214;

struct kernfs_node___221;

struct kobject___215 {
	const char *name;
	struct list_head entry;
	struct kobject___215 *parent;
	struct kset___214 *kset;
	struct kobj_type___214 *ktype;
	struct kernfs_node___221 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___194 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___194 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___194;

struct bus_type___194;

struct device_driver___194;

struct dev_pm_domain___194;

struct class___194;

struct attribute_group___196;

struct device___194 {
	struct device___194 *parent;
	struct device_private *p;
	struct kobject___215 kobj;
	const char *init_name;
	const struct device_type___194 *type;
	struct mutex mutex;
	struct bus_type___194 *bus;
	struct device_driver___194 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___194 power;
	struct dev_pm_domain___194 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___194 *class;
	const struct attribute_group___196 **groups;
	void (*release)(struct device___194 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___226;

struct super_block___226;

struct dentry___227 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___227 *d_parent;
	struct qstr d_name;
	struct inode___227 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___226 *d_op;
	struct super_block___226 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___226;

struct block_device___227;

struct inode___227 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___226 *i_op;
	struct super_block___226 *i_sb;
	struct address_space___226 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___227 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___227 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___226 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___227 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___226 {
	int (*d_revalidate)(struct dentry___227 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___227 *, unsigned int);
	int (*d_hash)(const struct dentry___227 *, struct qstr *);
	int (*d_compare)(const struct dentry___227 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___227 *);
	int (*d_init)(struct dentry___227 *);
	void (*d_release)(struct dentry___227 *);
	void (*d_prune)(struct dentry___227 *);
	void (*d_iput)(struct dentry___227 *, struct inode___227 *);
	char * (*d_dname)(struct dentry___227 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___226 *);
	int (*d_manage)(const struct path___226 *, bool);
	struct dentry___227 * (*d_real)(struct dentry___227 *, const struct inode___227 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___226;

struct mem_dqinfo___226 {
	struct quota_format_type___226 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___226;

struct quota_info___226 {
	unsigned int flags;
	struct rw_semaphore___227 dqio_sem;
	struct inode___227 *files[3];
	struct mem_dqinfo___226 info[3];
	const struct quota_format_ops___226 *ops[3];
};

struct rcuwait___226 {
	struct task_struct___227 *task;
};

struct percpu_rw_semaphore___226 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___227 rw_sem;
	struct rcuwait___226 writer;
	int readers_block;
};

struct sb_writers___226 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___226 rw_sem[3];
};

struct file_system_type___226;

struct super_operations___226;

struct dquot_operations___226;

struct quotactl_ops___226;

struct super_block___226 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___226 *s_type;
	const struct super_operations___226 *s_op;
	const struct dquot_operations___226 *dq_op;
	const struct quotactl_ops___226 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___227 *s_root;
	struct rw_semaphore___227 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___227 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___226 s_dquot;
	struct sb_writers___226 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___226 *s_d_op;
	int cleancache_poolid;
	struct shrinker___95 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___227 {
	struct file___227 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___227 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___226 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___227 *ia_file;
};

struct dquot___226 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___226 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___226 {
	int qf_fmt_id;
	const struct quota_format_ops___226 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___226 *qf_next;
};

struct quota_format_ops___226 {
	int (*check_quota_file)(struct super_block___226 *, int);
	int (*read_file_info)(struct super_block___226 *, int);
	int (*write_file_info)(struct super_block___226 *, int);
	int (*free_file_info)(struct super_block___226 *, int);
	int (*read_dqblk)(struct dquot___226 *);
	int (*commit_dqblk)(struct dquot___226 *);
	int (*release_dqblk)(struct dquot___226 *);
	int (*get_next_id)(struct super_block___226 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___226 {
	int (*write_dquot)(struct dquot___226 *);
	struct dquot___226 * (*alloc_dquot)(struct super_block___226 *, int);
	void (*destroy_dquot)(struct dquot___226 *);
	int (*acquire_dquot)(struct dquot___226 *);
	int (*release_dquot)(struct dquot___226 *);
	int (*mark_dirty)(struct dquot___226 *);
	int (*write_info)(struct super_block___226 *, int);
	qsize_t * (*get_reserved_space)(struct inode___227 *);
	int (*get_projid)(struct inode___227 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___227 *, qsize_t *);
	int (*get_next_id)(struct super_block___226 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___226 {
	int (*quota_on)(struct super_block___226 *, int, int, const struct path___226 *);
	int (*quota_off)(struct super_block___226 *, int);
	int (*quota_enable)(struct super_block___226 *, unsigned int);
	int (*quota_disable)(struct super_block___226 *, unsigned int);
	int (*quota_sync)(struct super_block___226 *, int);
	int (*set_info)(struct super_block___226 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___226 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___226 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___226 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___226 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___226 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___226 {
	int (*writepage)(struct page___227 *, struct writeback_control___3 *);
	int (*readpage)(struct file___227 *, struct page___227 *);
	int (*writepages)(struct address_space___226 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___227 *);
	int (*readpages)(struct file___227 *, struct address_space___226 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___227 *, struct address_space___226 *, loff_t, unsigned int, unsigned int, struct page___227 **, void **);
	int (*write_end)(struct file___227 *, struct address_space___226 *, loff_t, unsigned int, unsigned int, struct page___227 *, void *);
	sector_t (*bmap)(struct address_space___226 *, sector_t);
	void (*invalidatepage)(struct page___227 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___227 *, gfp_t);
	void (*freepage)(struct page___227 *);
	ssize_t (*direct_IO)(struct kiocb___227 *, struct iov_iter___101 *);
	int (*migratepage)(struct address_space___226 *, struct page___227 *, struct page___227 *, enum migrate_mode);
	bool (*isolate_page)(struct page___227 *, isolate_mode_t);
	void (*putback_page)(struct page___227 *);
	int (*launder_page)(struct page___227 *);
	int (*is_partially_uptodate)(struct page___227 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___227 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___226 *, struct page___227 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___227 *, sector_t *);
	void (*swap_deactivate)(struct file___227 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___227 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___227 *bd_inode;
	struct super_block___226 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___227 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___226 {
	struct dentry___227 * (*lookup)(struct inode___227 *, struct dentry___227 *, unsigned int);
	const char * (*get_link)(struct dentry___227 *, struct inode___227 *, struct delayed_call *);
	int (*permission)(struct inode___227 *, int);
	struct posix_acl * (*get_acl)(struct inode___227 *, int);
	int (*readlink)(struct dentry___227 *, char *, int);
	int (*create)(struct inode___227 *, struct dentry___227 *, umode_t, bool);
	int (*link)(struct dentry___227 *, struct inode___227 *, struct dentry___227 *);
	int (*unlink)(struct inode___227 *, struct dentry___227 *);
	int (*symlink)(struct inode___227 *, struct dentry___227 *, const char *);
	int (*mkdir)(struct inode___227 *, struct dentry___227 *, umode_t);
	int (*rmdir)(struct inode___227 *, struct dentry___227 *);
	int (*mknod)(struct inode___227 *, struct dentry___227 *, umode_t, dev_t);
	int (*rename)(struct inode___227 *, struct dentry___227 *, struct inode___227 *, struct dentry___227 *, unsigned int);
	int (*setattr)(struct dentry___227 *, struct iattr___226 *);
	int (*getattr)(const struct path___226 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___227 *, char *, size_t);
	int (*fiemap)(struct inode___227 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___227 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___227 *, struct dentry___227 *, struct file___227 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___227 *, struct dentry___227 *, umode_t);
	int (*set_acl)(struct inode___227 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___226 {
	void (*fl_copy_lock)(struct file_lock___227 *, struct file_lock___227 *);
	void (*fl_release_private)(struct file_lock___227 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___226;

struct lock_manager_operations___226;

struct file_lock___227 {
	struct file_lock___227 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___227 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___226 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___226 *fl_ops;
	const struct lock_manager_operations___226 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___226 {
	int (*lm_compare_owner)(struct file_lock___227 *, struct file_lock___227 *);
	long unsigned int (*lm_owner_key)(struct file_lock___227 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___227 *);
	int (*lm_grant)(struct file_lock___227 *, int);
	bool (*lm_break)(struct file_lock___227 *);
	int (*lm_change)(struct file_lock___227 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___227 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___226 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___226 *fa_next;
	struct file___227 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___226 {
	const char *name;
	int fs_flags;
	struct dentry___227 * (*mount)(struct file_system_type___226 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___226 *);
	struct module___11 *owner;
	struct file_system_type___226 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___226 {
	struct inode___227 * (*alloc_inode)(struct super_block___226 *);
	void (*destroy_inode)(struct inode___227 *);
	void (*dirty_inode)(struct inode___227 *, int);
	int (*write_inode)(struct inode___227 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___227 *);
	void (*evict_inode)(struct inode___227 *);
	void (*put_super)(struct super_block___226 *);
	int (*sync_fs)(struct super_block___226 *, int);
	int (*freeze_super)(struct super_block___226 *);
	int (*freeze_fs)(struct super_block___226 *);
	int (*thaw_super)(struct super_block___226 *);
	int (*unfreeze_fs)(struct super_block___226 *);
	int (*statfs)(struct dentry___227 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___226 *, int *, char *);
	void (*umount_begin)(struct super_block___226 *);
	int (*show_options)(struct seq_file___205 *, struct dentry___227 *);
	int (*show_devname)(struct seq_file___205 *, struct dentry___227 *);
	int (*show_path)(struct seq_file___205 *, struct dentry___227 *);
	int (*show_stats)(struct seq_file___205 *, struct dentry___227 *);
	ssize_t (*quota_read)(struct super_block___226 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___226 *, int, const char *, size_t, loff_t);
	struct dquot___226 ** (*get_dquots)(struct inode___227 *);
	int (*bdev_try_to_free_page)(struct super_block___226 *, struct page___227 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___226 *, struct shrink_control___95 *);
	long int (*free_cached_objects)(struct super_block___226 *, struct shrink_control___95 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___203;

struct seq_file___205 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___203 *op;
	int poll_event;
	const struct file___227 *file;
	void *private;
};

struct kobj_attribute___209 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___215 *, struct kobj_attribute___209 *, char *);
	ssize_t (*store)(struct kobject___215 *, struct kobj_attribute___209 *, const char *, size_t);
};

typedef void compound_page_dtor___218(struct page___227 *);

typedef int (*key_restrict_link_func_t___220)(struct key___220 *, const struct key_type *, const union key_payload *, struct key___220 *);

struct key_restriction___220;

struct key___220 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___227 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___220 *restrict_link;
};

struct key_restriction___220 {
	key_restrict_link_func_t___220 check;
	struct key___220 *key;
	struct key_type *keytype;
};

struct seq_operations___203 {
	void * (*start)(struct seq_file___205 *, loff_t *);
	void (*stop)(struct seq_file___205 *, void *);
	void * (*next)(struct seq_file___205 *, void *, loff_t *);
	int (*show)(struct seq_file___205 *, void *);
};

struct ipc_ids___3 {
	int in_use;
	short unsigned int seq;
	struct rw_semaphore___227 rwsem;
	struct idr ipcs_idr;
	int max_idx;
	int last_idx;
	int next_id;
	struct rhashtable key_ht;
};

struct ipc_namespace___3 {
	refcount_t count;
	struct ipc_ids___3 ids[3];
	int sem_ctls[4];
	int used_sems;
	unsigned int msg_ctlmax;
	unsigned int msg_ctlmnb;
	unsigned int msg_ctlmni;
	atomic_t msg_bytes;
	atomic_t msg_hdrs;
	size_t shm_ctlmax;
	size_t shm_ctlall;
	long unsigned int shm_tot;
	int shm_ctlmni;
	int shm_rmid_forced;
	struct notifier_block ipcns_nb;
	struct vfsmount *mq_mnt;
	unsigned int mq_queues_count;
	unsigned int mq_queues_max;
	unsigned int mq_msg_max;
	unsigned int mq_msgsize_max;
	unsigned int mq_msg_default;
	unsigned int mq_msgsize_default;
	struct user_namespace___3 *user_ns;
	struct ucounts___2 *ucounts;
	struct ns_common___27 ns;
};

struct kernfs_root___221;

struct kernfs_elem_dir___221 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___221 *root;
};

struct kernfs_syscall_ops___221;

struct kernfs_root___221 {
	struct kernfs_node___221 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___221 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___221 {
	struct kernfs_node___221 *target_kn;
};

struct kernfs_ops___221;

struct kernfs_elem_attr___221 {
	const struct kernfs_ops___221 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___221 *notify_next;
};

struct kernfs_node___221 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___221 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___221 dir;
		struct kernfs_elem_symlink___221 symlink;
		struct kernfs_elem_attr___221 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___221;

struct kernfs_ops___221 {
	int (*open)(struct kernfs_open_file___221 *);
	void (*release)(struct kernfs_open_file___221 *);
	int (*seq_show)(struct seq_file___205 *, void *);
	void * (*seq_start)(struct seq_file___205 *, loff_t *);
	void * (*seq_next)(struct seq_file___205 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___205 *, void *);
	ssize_t (*read)(struct kernfs_open_file___221 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___221 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___221 *, struct vm_area_struct___227 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___221 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___221 {
	int (*remount_fs)(struct kernfs_root___221 *, int *, char *);
	int (*show_options)(struct seq_file___205 *, struct kernfs_root___221 *);
	int (*mkdir)(struct kernfs_node___221 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___221 *);
	int (*rename)(struct kernfs_node___221 *, struct kernfs_node___221 *, const char *);
	int (*show_path)(struct seq_file___205 *, struct kernfs_node___221 *, struct kernfs_root___221 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___221 {
	struct kernfs_node___221 *kn;
	struct file___227 *file;
	struct seq_file___205 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___218 *vm_ops;
};

struct bin_attribute___195;

struct attribute_group___196 {
	const char *name;
	umode_t (*is_visible)(struct kobject___215 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___215 *, struct bin_attribute___195 *, int);
	struct attribute **attrs;
	struct bin_attribute___195 **bin_attrs;
};

struct bin_attribute___195 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___227 *, struct kobject___215 *, struct bin_attribute___195 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___227 *, struct kobject___215 *, struct bin_attribute___195 *, char *, loff_t, size_t);
	int (*mmap)(struct file___227 *, struct kobject___215 *, struct bin_attribute___195 *, struct vm_area_struct___227 *);
};

struct sysfs_ops___214 {
	ssize_t (*show)(struct kobject___215 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___215 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___214;

struct kset___214 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___215 kobj;
	const struct kset_uevent_ops___214 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___214 {
	void (*release)(struct kobject___215 *);
	const struct sysfs_ops___214 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___12 * (*child_ns_type)(struct kobject___215 *);
	const void * (*namespace)(struct kobject___215 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___214 {
	int (* const filter)(struct kset___214 *, struct kobject___215 *);
	const char * (* const name)(struct kset___214 *, struct kobject___215 *);
	int (* const uevent)(struct kset___214 *, struct kobject___215 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___194 {
	int (*prepare)(struct device___194 *);
	void (*complete)(struct device___194 *);
	int (*suspend)(struct device___194 *);
	int (*resume)(struct device___194 *);
	int (*freeze)(struct device___194 *);
	int (*thaw)(struct device___194 *);
	int (*poweroff)(struct device___194 *);
	int (*restore)(struct device___194 *);
	int (*suspend_late)(struct device___194 *);
	int (*resume_early)(struct device___194 *);
	int (*freeze_late)(struct device___194 *);
	int (*thaw_early)(struct device___194 *);
	int (*poweroff_late)(struct device___194 *);
	int (*restore_early)(struct device___194 *);
	int (*suspend_noirq)(struct device___194 *);
	int (*resume_noirq)(struct device___194 *);
	int (*freeze_noirq)(struct device___194 *);
	int (*thaw_noirq)(struct device___194 *);
	int (*poweroff_noirq)(struct device___194 *);
	int (*restore_noirq)(struct device___194 *);
	int (*runtime_suspend)(struct device___194 *);
	int (*runtime_resume)(struct device___194 *);
	int (*runtime_idle)(struct device___194 *);
};

struct dev_pm_domain___194 {
	struct dev_pm_ops___194 ops;
	void (*detach)(struct device___194 *, bool);
	int (*activate)(struct device___194 *);
	void (*sync)(struct device___194 *);
	void (*dismiss)(struct device___194 *);
};

struct bus_type___194 {
	const char *name;
	const char *dev_name;
	struct device___194 *dev_root;
	const struct attribute_group___196 **bus_groups;
	const struct attribute_group___196 **dev_groups;
	const struct attribute_group___196 **drv_groups;
	int (*match)(struct device___194 *, struct device_driver___194 *);
	int (*uevent)(struct device___194 *, struct kobj_uevent_env *);
	int (*probe)(struct device___194 *);
	int (*remove)(struct device___194 *);
	void (*shutdown)(struct device___194 *);
	int (*online)(struct device___194 *);
	int (*offline)(struct device___194 *);
	int (*suspend)(struct device___194 *, pm_message_t);
	int (*resume)(struct device___194 *);
	int (*num_vf)(struct device___194 *);
	int (*dma_configure)(struct device___194 *);
	const struct dev_pm_ops___194 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___194 {
	const char *name;
	struct bus_type___194 *bus;
	struct module___11 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___194 *);
	int (*remove)(struct device___194 *);
	void (*shutdown)(struct device___194 *);
	int (*suspend)(struct device___194 *, pm_message_t);
	int (*resume)(struct device___194 *);
	const struct attribute_group___196 **groups;
	const struct dev_pm_ops___194 *pm;
	void (*coredump)(struct device___194 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___194 {
	const char *name;
	const struct attribute_group___196 **groups;
	int (*uevent)(struct device___194 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___194 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___194 *);
	const struct dev_pm_ops___194 *pm;
};

struct class___194 {
	const char *name;
	struct module___11 *owner;
	const struct attribute_group___196 **class_groups;
	const struct attribute_group___196 **dev_groups;
	struct kobject___215 *dev_kobj;
	int (*dev_uevent)(struct device___194 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___194 *, umode_t *);
	void (*class_release)(struct class___194 *);
	void (*dev_release)(struct device___194 *);
	int (*shutdown_pre)(struct device___194 *);
	const struct kobj_ns_type_operations___12 *ns_type;
	const void * (*namespace)(struct device___194 *);
	const struct dev_pm_ops___194 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___161 {
	struct device___194 dev;
};

struct ipc_params {
	key_t key;
	int flg;
	union {
		size_t size;
		int nsems;
	} u;
};

struct ipc_ops {
	int (*getnew)(struct ipc_namespace___3 *, struct ipc_params *);
	int (*associate)(struct kern_ipc_perm *, int);
	int (*more_checks)(struct kern_ipc_perm *, struct ipc_params *);
};

struct ipc_proc_iface {
	const char *path;
	const char *header;
	int ids;
	int (*show)(struct seq_file___205 *, void *);
};

struct ipc_proc_iter {
	struct ipc_namespace___3 *ns;
	struct pid_namespace___171 *pid_ns;
	struct ipc_proc_iface *iface;
};

struct msg_msgseg;

struct msg_msg {
	struct list_head m_list;
	long int m_type;
	size_t m_ts;
	struct msg_msgseg *next;
	void *security;
};

struct msg_msgseg {
	struct msg_msgseg *next;
};

typedef int __kernel_ipc_pid_t;

struct module___183;

struct file___228;

struct kiocb___228;

struct poll_table_struct___142;

struct vm_area_struct___228;

struct inode___228;

struct file_lock___228;

struct page___228;

struct seq_file___206;

struct file_operations___228 {
	struct module___183 *owner;
	loff_t (*llseek)(struct file___228 *, loff_t, int);
	ssize_t (*read)(struct file___228 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___228 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___228 *, struct iov_iter___101 *);
	ssize_t (*write_iter)(struct kiocb___228 *, struct iov_iter___101 *);
	int (*iopoll)(struct kiocb___228 *, bool);
	int (*iterate)(struct file___228 *, struct dir_context *);
	int (*iterate_shared)(struct file___228 *, struct dir_context *);
	__poll_t (*poll)(struct file___228 *, struct poll_table_struct___142 *);
	long int (*unlocked_ioctl)(struct file___228 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___228 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___228 *, struct vm_area_struct___228 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___228 *, struct file___228 *);
	int (*flush)(struct file___228 *, fl_owner_t);
	int (*release)(struct inode___228 *, struct file___228 *);
	int (*fsync)(struct file___228 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___228 *, int);
	int (*lock)(struct file___228 *, int, struct file_lock___228 *);
	ssize_t (*sendpage)(struct file___228 *, struct page___228 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___228 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___228 *, int, struct file_lock___228 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___228 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___228 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___228 *, long int, struct file_lock___228 **, void **);
	long int (*fallocate)(struct file___228 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___206 *, struct file___228 *);
	ssize_t (*copy_file_range)(struct file___228 *, loff_t, struct file___228 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___228 *, loff_t, struct file___228 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___228 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___227 {
	u64 seqnum;
	struct vm_area_struct___228 *vmas[4];
};

struct page_frag___227 {
	struct page___228 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___122;

struct debug_info___122 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___122 *hbp_break[16];
	struct perf_event___122 *hbp_watch[16];
};

struct thread_struct___122 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___122 debug;
	long: 64;
};

struct mm_struct___227;

struct pid___172;

struct cred___221;

struct nsproxy___209;

struct signal_struct___190;

struct css_set___176;

struct perf_event_context___122;

struct task_struct___228 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___228 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___227 *mm;
	struct mm_struct___227 *active_mm;
	struct vmacache___227 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___228 *real_parent;
	struct task_struct___228 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___228 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___172 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___172 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___172 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___221 *ptracer_cred;
	const struct cred___221 *real_cred;
	const struct cred___221 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___209 *nsproxy;
	struct signal_struct___190 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___228 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___58 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___176 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___122 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___227 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___228 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___122 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___122 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___228 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___122)(struct perf_event___122 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___122;

struct fasync_struct___227;

struct pid_namespace___172;

struct trace_event_call___115;

struct perf_cgroup___122;

struct perf_event___122 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___122 *group_leader;
	struct pmu___122 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___122 hw;
	struct perf_event_context___122 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___122 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___228 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___227 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___122 *);
	struct callback_head callback_head;
	struct pid_namespace___172 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___122 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___122 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___115 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___122 *cgrp;
	struct list_head sb_list;
};

struct rw_semaphore___228 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___228 *owner;
};

struct key___221;

struct ucounts___190;

struct user_namespace___190 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___190 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___27 ns;
	long unsigned int flags;
	struct key___221 *persistent_keyring_register;
	struct rw_semaphore___228 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___190 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct secondary_data___228 {
	void *stack;
	struct task_struct___228 *task;
	long int status;
};

struct msgbuf {
	__kernel_long_t mtype;
	char mtext[1];
};

struct msg;

struct msqid_ds {
	struct ipc_perm msg_perm;
	struct msg *msg_first;
	struct msg *msg_last;
	__kernel_time_t msg_stime;
	__kernel_time_t msg_rtime;
	__kernel_time_t msg_ctime;
	long unsigned int msg_lcbytes;
	long unsigned int msg_lqbytes;
	short unsigned int msg_cbytes;
	short unsigned int msg_qnum;
	short unsigned int msg_qbytes;
	__kernel_ipc_pid_t msg_lspid;
	__kernel_ipc_pid_t msg_lrpid;
};

struct msqid64_ds {
	struct ipc64_perm msg_perm;
	__kernel_time_t msg_stime;
	__kernel_time_t msg_rtime;
	__kernel_time_t msg_ctime;
	long unsigned int msg_cbytes;
	long unsigned int msg_qnum;
	long unsigned int msg_qbytes;
	__kernel_pid_t msg_lspid;
	__kernel_pid_t msg_lrpid;
	long unsigned int __unused4;
	long unsigned int __unused5;
};

struct msginfo {
	int msgpool;
	int msgmap;
	int msgmax;
	int msgmnb;
	int msgmni;
	int msgssz;
	int msgtql;
	short unsigned int msgseg;
};

typedef struct page___228 *pgtable_t___227;

struct address_space___227;

struct dev_pagemap___219;

struct page___228 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___227 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___228 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___227 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___227 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___219 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___227;

struct lruvec___227 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___227 *pgdat;
};

struct zone___227 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___227 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___227 {
	struct zone___227 *zone;
	int zone_idx;
};

struct zonelist___227 {
	struct zoneref___227 _zonerefs[25];
};

struct pglist_data___227 {
	struct zone___227 node_zones[3];
	struct zonelist___227 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___228 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___228 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___227 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___227 {
	struct rw_semaphore___228 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___219;

struct vm_area_struct___228 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___228 *vm_next;
	struct vm_area_struct___228 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___227 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___219 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___228 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___227;

struct mm_struct___227 {
	struct {
		struct vm_area_struct___228 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___228 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___228 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___227 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___228 *owner;
		struct user_namespace___190 *user_ns;
		struct file___228 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___227 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___227;

struct address_space___227 {
	struct inode___228 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___228 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___227 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___219)(struct vm_area_struct___228 *, long unsigned int, const struct page___228 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___219)(struct page___228 *, void *);

struct device___195;

struct dev_pagemap___219 {
	dev_page_fault_t___219 page_fault;
	dev_page_free_t___219 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___195 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct dentry___228;

struct path___227 {
	struct vfsmount *mnt;
	struct dentry___228 *dentry;
};

struct fown_struct___172 {
	rwlock_t lock;
	struct pid___172 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___228 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___227 f_path;
	struct inode___228 *f_inode;
	const struct file_operations___228 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___172 f_owner;
	const struct cred___221 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___227 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___219;

struct vm_operations_struct___219 {
	void (*open)(struct vm_area_struct___228 *);
	void (*close)(struct vm_area_struct___228 *);
	int (*split)(struct vm_area_struct___228 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___228 *);
	vm_fault_t (*fault)(struct vm_fault___219 *);
	vm_fault_t (*huge_fault)(struct vm_fault___219 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___219 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___228 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___219 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___219 *);
	int (*access)(struct vm_area_struct___228 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___228 *);
	int (*set_policy)(struct vm_area_struct___228 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___228 *, long unsigned int);
	struct page___228 * (*find_special_page)(struct vm_area_struct___228 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___227 {
	struct task_struct___228 *task;
	struct core_thread___227 *next;
};

struct core_state___227 {
	atomic_t nr_threads;
	struct core_thread___227 dumper;
	struct completion startup;
};

struct vm_fault___219 {
	struct vm_area_struct___228 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___228 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___228 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___227 prealloc_pte;
};

struct upid___172 {
	int nr;
	struct pid_namespace___172 *ns;
};

struct pid_namespace___172 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___228 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___172 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___228 *proc_self;
	struct dentry___228 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___190 *user_ns;
	struct ucounts___190 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___172 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___172 numbers[1];
};

struct user_struct___221 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___221 *uid_keyring;
	struct key___221 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___221 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___221 *session_keyring;
	struct key___221 *process_keyring;
	struct key___221 *thread_keyring;
	struct key___221 *request_key_auth;
	void *security;
	struct user_struct___221 *user;
	struct user_namespace___190 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct ipc_namespace___4;

struct cgroup_namespace___176;

struct nsproxy___209 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace___4 *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___172 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___176 *cgroup_ns;
};

struct signal_struct___190 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___228 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___228 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___172 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___172 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___227 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___172 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___177;

struct cgroup___176;

struct css_set___176 {
	struct cgroup_subsys_state___177 *subsys[13];
	refcount_t refcount;
	struct css_set___176 *dom_cset;
	struct cgroup___176 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___176 *mg_src_cgrp;
	struct cgroup___176 *mg_dst_cgrp;
	struct css_set___176 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___122 {
	struct pmu___122 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___228 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___122 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

union thread_union___201 {
	struct task_struct___228 task;
	long unsigned int stack[8192];
};

struct kset___215;

struct kobj_type___215;

struct kernfs_node___222;

struct kobject___216 {
	const char *name;
	struct list_head entry;
	struct kobject___216 *parent;
	struct kset___215 *kset;
	struct kobj_type___215 *ktype;
	struct kernfs_node___222 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___195 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___195 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___195;

struct bus_type___195;

struct device_driver___195;

struct dev_pm_domain___195;

struct class___195;

struct attribute_group___197;

struct device___195 {
	struct device___195 *parent;
	struct device_private *p;
	struct kobject___216 kobj;
	const char *init_name;
	const struct device_type___195 *type;
	struct mutex mutex;
	struct bus_type___195 *bus;
	struct device_driver___195 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___195 power;
	struct dev_pm_domain___195 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___195 *class;
	const struct attribute_group___197 **groups;
	void (*release)(struct device___195 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___227;

struct super_block___227;

struct dentry___228 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___228 *d_parent;
	struct qstr d_name;
	struct inode___228 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___227 *d_op;
	struct super_block___227 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___227;

struct block_device___228;

struct inode___228 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___227 *i_op;
	struct super_block___227 *i_sb;
	struct address_space___227 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___228 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___228 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___227 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___228 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___227 {
	int (*d_revalidate)(struct dentry___228 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___228 *, unsigned int);
	int (*d_hash)(const struct dentry___228 *, struct qstr *);
	int (*d_compare)(const struct dentry___228 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___228 *);
	int (*d_init)(struct dentry___228 *);
	void (*d_release)(struct dentry___228 *);
	void (*d_prune)(struct dentry___228 *);
	void (*d_iput)(struct dentry___228 *, struct inode___228 *);
	char * (*d_dname)(struct dentry___228 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___227 *);
	int (*d_manage)(const struct path___227 *, bool);
	struct dentry___228 * (*d_real)(struct dentry___228 *, const struct inode___228 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___227;

struct mem_dqinfo___227 {
	struct quota_format_type___227 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___227;

struct quota_info___227 {
	unsigned int flags;
	struct rw_semaphore___228 dqio_sem;
	struct inode___228 *files[3];
	struct mem_dqinfo___227 info[3];
	const struct quota_format_ops___227 *ops[3];
};

struct rcuwait___227 {
	struct task_struct___228 *task;
};

struct percpu_rw_semaphore___227 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___228 rw_sem;
	struct rcuwait___227 writer;
	int readers_block;
};

struct sb_writers___227 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___227 rw_sem[3];
};

struct file_system_type___227;

struct super_operations___227;

struct dquot_operations___227;

struct quotactl_ops___227;

struct super_block___227 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___227 *s_type;
	const struct super_operations___227 *s_op;
	const struct dquot_operations___227 *dq_op;
	const struct quotactl_ops___227 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___228 *s_root;
	struct rw_semaphore___228 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___228 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___227 s_dquot;
	struct sb_writers___227 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___227 *s_d_op;
	int cleancache_poolid;
	struct shrinker___95 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___190 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___228 {
	struct file___228 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___228 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___227 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___228 *ia_file;
};

struct dquot___227 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___227 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___227 {
	int qf_fmt_id;
	const struct quota_format_ops___227 *qf_ops;
	struct module___183 *qf_owner;
	struct quota_format_type___227 *qf_next;
};

struct quota_format_ops___227 {
	int (*check_quota_file)(struct super_block___227 *, int);
	int (*read_file_info)(struct super_block___227 *, int);
	int (*write_file_info)(struct super_block___227 *, int);
	int (*free_file_info)(struct super_block___227 *, int);
	int (*read_dqblk)(struct dquot___227 *);
	int (*commit_dqblk)(struct dquot___227 *);
	int (*release_dqblk)(struct dquot___227 *);
	int (*get_next_id)(struct super_block___227 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___227 {
	int (*write_dquot)(struct dquot___227 *);
	struct dquot___227 * (*alloc_dquot)(struct super_block___227 *, int);
	void (*destroy_dquot)(struct dquot___227 *);
	int (*acquire_dquot)(struct dquot___227 *);
	int (*release_dquot)(struct dquot___227 *);
	int (*mark_dirty)(struct dquot___227 *);
	int (*write_info)(struct super_block___227 *, int);
	qsize_t * (*get_reserved_space)(struct inode___228 *);
	int (*get_projid)(struct inode___228 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___228 *, qsize_t *);
	int (*get_next_id)(struct super_block___227 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___227 {
	int (*quota_on)(struct super_block___227 *, int, int, const struct path___227 *);
	int (*quota_off)(struct super_block___227 *, int);
	int (*quota_enable)(struct super_block___227 *, unsigned int);
	int (*quota_disable)(struct super_block___227 *, unsigned int);
	int (*quota_sync)(struct super_block___227 *, int);
	int (*set_info)(struct super_block___227 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___227 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___227 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___227 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___227 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___227 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___180 {
	struct kobject___216 kobj;
	struct module___183 *mod;
	struct kobject___216 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___180 {
	struct module___183 *mod;
	struct latch_tree_node node;
};

struct module_layout___180 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___180 mtn;
};

struct module_attribute___180;

struct kernel_param___180;

struct module___183 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___180 mkobj;
	struct module_attribute___180 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___216 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___180 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___180 core_layout;
	struct module_layout___180 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___115 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___227 {
	int (*writepage)(struct page___228 *, struct writeback_control___3 *);
	int (*readpage)(struct file___228 *, struct page___228 *);
	int (*writepages)(struct address_space___227 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___228 *);
	int (*readpages)(struct file___228 *, struct address_space___227 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___228 *, struct address_space___227 *, loff_t, unsigned int, unsigned int, struct page___228 **, void **);
	int (*write_end)(struct file___228 *, struct address_space___227 *, loff_t, unsigned int, unsigned int, struct page___228 *, void *);
	sector_t (*bmap)(struct address_space___227 *, sector_t);
	void (*invalidatepage)(struct page___228 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___228 *, gfp_t);
	void (*freepage)(struct page___228 *);
	ssize_t (*direct_IO)(struct kiocb___228 *, struct iov_iter___101 *);
	int (*migratepage)(struct address_space___227 *, struct page___228 *, struct page___228 *, enum migrate_mode);
	bool (*isolate_page)(struct page___228 *, isolate_mode_t);
	void (*putback_page)(struct page___228 *);
	int (*launder_page)(struct page___228 *);
	int (*is_partially_uptodate)(struct page___228 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___228 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___227 *, struct page___228 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___228 *, sector_t *);
	void (*swap_deactivate)(struct file___228 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___228 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___228 *bd_inode;
	struct super_block___227 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___228 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___227 {
	struct dentry___228 * (*lookup)(struct inode___228 *, struct dentry___228 *, unsigned int);
	const char * (*get_link)(struct dentry___228 *, struct inode___228 *, struct delayed_call *);
	int (*permission)(struct inode___228 *, int);
	struct posix_acl * (*get_acl)(struct inode___228 *, int);
	int (*readlink)(struct dentry___228 *, char *, int);
	int (*create)(struct inode___228 *, struct dentry___228 *, umode_t, bool);
	int (*link)(struct dentry___228 *, struct inode___228 *, struct dentry___228 *);
	int (*unlink)(struct inode___228 *, struct dentry___228 *);
	int (*symlink)(struct inode___228 *, struct dentry___228 *, const char *);
	int (*mkdir)(struct inode___228 *, struct dentry___228 *, umode_t);
	int (*rmdir)(struct inode___228 *, struct dentry___228 *);
	int (*mknod)(struct inode___228 *, struct dentry___228 *, umode_t, dev_t);
	int (*rename)(struct inode___228 *, struct dentry___228 *, struct inode___228 *, struct dentry___228 *, unsigned int);
	int (*setattr)(struct dentry___228 *, struct iattr___227 *);
	int (*getattr)(const struct path___227 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___228 *, char *, size_t);
	int (*fiemap)(struct inode___228 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___228 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___228 *, struct dentry___228 *, struct file___228 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___228 *, struct dentry___228 *, umode_t);
	int (*set_acl)(struct inode___228 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___227 {
	void (*fl_copy_lock)(struct file_lock___228 *, struct file_lock___228 *);
	void (*fl_release_private)(struct file_lock___228 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___227;

struct file_lock___228 {
	struct file_lock___228 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___228 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___227 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___227 *fl_ops;
	const struct lock_manager_operations___227 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___227 {
	int (*lm_compare_owner)(struct file_lock___228 *, struct file_lock___228 *);
	long unsigned int (*lm_owner_key)(struct file_lock___228 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___228 *);
	int (*lm_grant)(struct file_lock___228 *, int);
	bool (*lm_break)(struct file_lock___228 *);
	int (*lm_change)(struct file_lock___228 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___228 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___227 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___227 *fa_next;
	struct file___228 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___227 {
	const char *name;
	int fs_flags;
	struct dentry___228 * (*mount)(struct file_system_type___227 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___227 *);
	struct module___183 *owner;
	struct file_system_type___227 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___227 {
	struct inode___228 * (*alloc_inode)(struct super_block___227 *);
	void (*destroy_inode)(struct inode___228 *);
	void (*dirty_inode)(struct inode___228 *, int);
	int (*write_inode)(struct inode___228 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___228 *);
	void (*evict_inode)(struct inode___228 *);
	void (*put_super)(struct super_block___227 *);
	int (*sync_fs)(struct super_block___227 *, int);
	int (*freeze_super)(struct super_block___227 *);
	int (*freeze_fs)(struct super_block___227 *);
	int (*thaw_super)(struct super_block___227 *);
	int (*unfreeze_fs)(struct super_block___227 *);
	int (*statfs)(struct dentry___228 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___227 *, int *, char *);
	void (*umount_begin)(struct super_block___227 *);
	int (*show_options)(struct seq_file___206 *, struct dentry___228 *);
	int (*show_devname)(struct seq_file___206 *, struct dentry___228 *);
	int (*show_path)(struct seq_file___206 *, struct dentry___228 *);
	int (*show_stats)(struct seq_file___206 *, struct dentry___228 *);
	ssize_t (*quota_read)(struct super_block___227 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___227 *, int, const char *, size_t, loff_t);
	struct dquot___227 ** (*get_dquots)(struct inode___228 *);
	int (*bdev_try_to_free_page)(struct super_block___227 *, struct page___228 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___227 *, struct shrink_control___95 *);
	long int (*free_cached_objects)(struct super_block___227 *, struct shrink_control___95 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___144)(struct file___228 *, wait_queue_head_t *, struct poll_table_struct___142 *);

struct poll_table_struct___142 {
	poll_queue_proc___144 _qproc;
	__poll_t _key;
};

struct seq_operations___204;

struct seq_file___206 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___204 *op;
	int poll_event;
	const struct file___228 *file;
	void *private;
};

struct kobj_attribute___210 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___216 *, struct kobj_attribute___210 *, char *);
	ssize_t (*store)(struct kobject___216 *, struct kobj_attribute___210 *, const char *, size_t);
};

typedef void compound_page_dtor___219(struct page___228 *);

typedef int (*key_restrict_link_func_t___221)(struct key___221 *, const struct key_type *, const union key_payload *, struct key___221 *);

struct key_restriction___221;

struct key___221 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___228 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___221 *restrict_link;
};

struct key_restriction___221 {
	key_restrict_link_func_t___221 check;
	struct key___221 *key;
	struct key_type *keytype;
};

struct seq_operations___204 {
	void * (*start)(struct seq_file___206 *, loff_t *);
	void (*stop)(struct seq_file___206 *, void *);
	void * (*next)(struct seq_file___206 *, void *, loff_t *);
	int (*show)(struct seq_file___206 *, void *);
};

struct ipc_ids___4 {
	int in_use;
	short unsigned int seq;
	struct rw_semaphore___228 rwsem;
	struct idr ipcs_idr;
	int max_idx;
	int last_idx;
	int next_id;
	struct rhashtable key_ht;
};

struct ipc_namespace___4 {
	refcount_t count;
	struct ipc_ids___4 ids[3];
	int sem_ctls[4];
	int used_sems;
	unsigned int msg_ctlmax;
	unsigned int msg_ctlmnb;
	unsigned int msg_ctlmni;
	atomic_t msg_bytes;
	atomic_t msg_hdrs;
	size_t shm_ctlmax;
	size_t shm_ctlall;
	long unsigned int shm_tot;
	int shm_ctlmni;
	int shm_rmid_forced;
	struct notifier_block ipcns_nb;
	struct vfsmount *mq_mnt;
	unsigned int mq_queues_count;
	unsigned int mq_queues_max;
	unsigned int mq_msg_max;
	unsigned int mq_msgsize_max;
	unsigned int mq_msg_default;
	unsigned int mq_msgsize_default;
	struct user_namespace___190 *user_ns;
	struct ucounts___190 *ucounts;
	struct ns_common___27 ns;
};

struct cgroup_namespace___176 {
	refcount_t count;
	struct ns_common___27 ns;
	struct user_namespace___190 *user_ns;
	struct ucounts___190 *ucounts;
	struct css_set___176 *root_cset;
};

struct ucounts___190 {
	struct hlist_node node;
	struct user_namespace___190 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct kernfs_root___222;

struct kernfs_elem_dir___222 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___222 *root;
};

struct kernfs_syscall_ops___222;

struct kernfs_root___222 {
	struct kernfs_node___222 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___222 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___222 {
	struct kernfs_node___222 *target_kn;
};

struct kernfs_ops___222;

struct kernfs_elem_attr___222 {
	const struct kernfs_ops___222 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___222 *notify_next;
};

struct kernfs_node___222 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___222 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___222 dir;
		struct kernfs_elem_symlink___222 symlink;
		struct kernfs_elem_attr___222 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___222;

struct kernfs_ops___222 {
	int (*open)(struct kernfs_open_file___222 *);
	void (*release)(struct kernfs_open_file___222 *);
	int (*seq_show)(struct seq_file___206 *, void *);
	void * (*seq_start)(struct seq_file___206 *, loff_t *);
	void * (*seq_next)(struct seq_file___206 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___206 *, void *);
	ssize_t (*read)(struct kernfs_open_file___222 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___222 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___222 *, struct vm_area_struct___228 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___222 *, struct poll_table_struct___142 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___222 {
	int (*remount_fs)(struct kernfs_root___222 *, int *, char *);
	int (*show_options)(struct seq_file___206 *, struct kernfs_root___222 *);
	int (*mkdir)(struct kernfs_node___222 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___222 *);
	int (*rename)(struct kernfs_node___222 *, struct kernfs_node___222 *, const char *);
	int (*show_path)(struct seq_file___206 *, struct kernfs_node___222 *, struct kernfs_root___222 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___222 {
	struct kernfs_node___222 *kn;
	struct file___228 *file;
	struct seq_file___206 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___219 *vm_ops;
};

struct bin_attribute___196;

struct attribute_group___197 {
	const char *name;
	umode_t (*is_visible)(struct kobject___216 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___216 *, struct bin_attribute___196 *, int);
	struct attribute **attrs;
	struct bin_attribute___196 **bin_attrs;
};

struct bin_attribute___196 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___228 *, struct kobject___216 *, struct bin_attribute___196 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___228 *, struct kobject___216 *, struct bin_attribute___196 *, char *, loff_t, size_t);
	int (*mmap)(struct file___228 *, struct kobject___216 *, struct bin_attribute___196 *, struct vm_area_struct___228 *);
};

struct sysfs_ops___215 {
	ssize_t (*show)(struct kobject___216 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___216 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___215;

struct kset___215 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___216 kobj;
	const struct kset_uevent_ops___215 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___215 {
	void (*release)(struct kobject___216 *);
	const struct sysfs_ops___215 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___12 * (*child_ns_type)(struct kobject___216 *);
	const void * (*namespace)(struct kobject___216 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___215 {
	int (* const filter)(struct kset___215 *, struct kobject___216 *);
	const char * (* const name)(struct kset___215 *, struct kobject___216 *);
	int (* const uevent)(struct kset___215 *, struct kobject___216 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___180 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___180 *);
	int (*get)(char *, const struct kernel_param___180 *);
	void (*free)(void *);
};

struct kparam_array___180;

struct kernel_param___180 {
	const char *name;
	struct module___183 *mod;
	const struct kernel_param_ops___180 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___180 *arr;
	};
};

struct kparam_array___180 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___180 *ops;
	void *elem;
};

struct module_attribute___180 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___180 *, struct module_kobject___180 *, char *);
	ssize_t (*store)(struct module_attribute___180 *, struct module_kobject___180 *, const char *, size_t);
	void (*setup)(struct module___183 *, const char *);
	int (*test)(struct module___183 *);
	void (*free)(struct module___183 *);
};

struct trace_event_class___115;

struct trace_event_call___115 {
	struct list_head list;
	struct trace_event_class___115 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___22 *prog_array;
	int (*perf_perm)(struct trace_event_call___115 *, struct perf_event___122 *);
};

struct dev_pm_ops___195 {
	int (*prepare)(struct device___195 *);
	void (*complete)(struct device___195 *);
	int (*suspend)(struct device___195 *);
	int (*resume)(struct device___195 *);
	int (*freeze)(struct device___195 *);
	int (*thaw)(struct device___195 *);
	int (*poweroff)(struct device___195 *);
	int (*restore)(struct device___195 *);
	int (*suspend_late)(struct device___195 *);
	int (*resume_early)(struct device___195 *);
	int (*freeze_late)(struct device___195 *);
	int (*thaw_early)(struct device___195 *);
	int (*poweroff_late)(struct device___195 *);
	int (*restore_early)(struct device___195 *);
	int (*suspend_noirq)(struct device___195 *);
	int (*resume_noirq)(struct device___195 *);
	int (*freeze_noirq)(struct device___195 *);
	int (*thaw_noirq)(struct device___195 *);
	int (*poweroff_noirq)(struct device___195 *);
	int (*restore_noirq)(struct device___195 *);
	int (*runtime_suspend)(struct device___195 *);
	int (*runtime_resume)(struct device___195 *);
	int (*runtime_idle)(struct device___195 *);
};

struct dev_pm_domain___195 {
	struct dev_pm_ops___195 ops;
	void (*detach)(struct device___195 *, bool);
	int (*activate)(struct device___195 *);
	void (*sync)(struct device___195 *);
	void (*dismiss)(struct device___195 *);
};

struct bus_type___195 {
	const char *name;
	const char *dev_name;
	struct device___195 *dev_root;
	const struct attribute_group___197 **bus_groups;
	const struct attribute_group___197 **dev_groups;
	const struct attribute_group___197 **drv_groups;
	int (*match)(struct device___195 *, struct device_driver___195 *);
	int (*uevent)(struct device___195 *, struct kobj_uevent_env *);
	int (*probe)(struct device___195 *);
	int (*remove)(struct device___195 *);
	void (*shutdown)(struct device___195 *);
	int (*online)(struct device___195 *);
	int (*offline)(struct device___195 *);
	int (*suspend)(struct device___195 *, pm_message_t);
	int (*resume)(struct device___195 *);
	int (*num_vf)(struct device___195 *);
	int (*dma_configure)(struct device___195 *);
	const struct dev_pm_ops___195 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___195 {
	const char *name;
	struct bus_type___195 *bus;
	struct module___183 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___195 *);
	int (*remove)(struct device___195 *);
	void (*shutdown)(struct device___195 *);
	int (*suspend)(struct device___195 *, pm_message_t);
	int (*resume)(struct device___195 *);
	const struct attribute_group___197 **groups;
	const struct dev_pm_ops___195 *pm;
	void (*coredump)(struct device___195 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___195 {
	const char *name;
	const struct attribute_group___197 **groups;
	int (*uevent)(struct device___195 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___195 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___195 *);
	const struct dev_pm_ops___195 *pm;
};

struct class___195 {
	const char *name;
	struct module___183 *owner;
	const struct attribute_group___197 **class_groups;
	const struct attribute_group___197 **dev_groups;
	struct kobject___216 *dev_kobj;
	int (*dev_uevent)(struct device___195 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___195 *, umode_t *);
	void (*class_release)(struct class___195 *);
	void (*dev_release)(struct device___195 *);
	int (*shutdown_pre)(struct device___195 *);
	const struct kobj_ns_type_operations___12 *ns_type;
	const void * (*namespace)(struct device___195 *);
	const struct dev_pm_ops___195 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___162 {
	struct device___195 dev;
};

struct bpf_map___176;

struct bpf_map_ops___176 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___176 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___176 *, struct file___228 *);
	void (*map_free)(struct bpf_map___176 *);
	int (*map_get_next_key)(struct bpf_map___176 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___176 *);
	void * (*map_lookup_elem)(struct bpf_map___176 *, void *);
	int (*map_update_elem)(struct bpf_map___176 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___176 *, void *);
	int (*map_push_elem)(struct bpf_map___176 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___176 *, void *);
	int (*map_peek_elem)(struct bpf_map___176 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___176 *, struct file___228 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___176 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___176 *, void *, struct seq_file___206 *);
	int (*map_check_btf)(const struct bpf_map___176 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___176 {
	const struct bpf_map_ops___176 *ops;
	struct bpf_map___176 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___221 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___176;

typedef void (*kthread_work_func_t___176)(struct kthread_work___176 *);

struct kthread_worker___176;

struct kthread_work___176 {
	struct list_head node;
	kthread_work_func_t___176 func;
	struct kthread_worker___176 *worker;
	int canceling;
};

struct kthread_worker___176 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___228 *task;
	struct kthread_work___176 *current_work;
};

struct kthread_delayed_work___176 {
	struct kthread_work___176 work;
	struct timer_list timer;
};

struct psi_group___176 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___176 *poll_kworker;
	struct kthread_delayed_work___176 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___176 {
	struct kernfs_node___222 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___176;

struct cgroup_subsys_state___177 {
	struct cgroup___176 *cgroup;
	struct cgroup_subsys___176 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___177 *parent;
};

struct cgroup_root___176;

struct cgroup_rstat_cpu___176;

struct cgroup___176 {
	struct cgroup_subsys_state___177 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___222 *kn;
	struct cgroup_file___176 procs_file;
	struct cgroup_file___176 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___177 *subsys[13];
	struct cgroup_root___176 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___176 *dom_cgrp;
	struct cgroup_rstat_cpu___176 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___22 bpf;
	atomic_t congestion_count;
	struct cgroup___176 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___176 psi;
	int ancestor_ids[0];
};

struct cftype___176;

struct cgroup_subsys___176 {
	struct cgroup_subsys_state___177 * (*css_alloc)(struct cgroup_subsys_state___177 *);
	int (*css_online)(struct cgroup_subsys_state___177 *);
	void (*css_offline)(struct cgroup_subsys_state___177 *);
	void (*css_released)(struct cgroup_subsys_state___177 *);
	void (*css_free)(struct cgroup_subsys_state___177 *);
	void (*css_reset)(struct cgroup_subsys_state___177 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___177 *, int);
	int (*css_extra_stat_show)(struct seq_file___206 *, struct cgroup_subsys_state___177 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___228 *);
	void (*cancel_fork)(struct task_struct___228 *);
	void (*fork)(struct task_struct___228 *);
	void (*exit)(struct task_struct___228 *);
	void (*free)(struct task_struct___228 *);
	void (*bind)(struct cgroup_subsys_state___177 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___176 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___176 *dfl_cftypes;
	struct cftype___176 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___176 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___176 *updated_children;
	struct cgroup___176 *updated_next;
};

struct cgroup_root___176 {
	struct kernfs_root___222 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___176 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___176 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___176 *ss;
	struct list_head node;
	struct kernfs_ops___222 *kf_ops;
	int (*open)(struct kernfs_open_file___222 *);
	void (*release)(struct kernfs_open_file___222 *);
	u64 (*read_u64)(struct cgroup_subsys_state___177 *, struct cftype___176 *);
	s64 (*read_s64)(struct cgroup_subsys_state___177 *, struct cftype___176 *);
	int (*seq_show)(struct seq_file___206 *, void *);
	void * (*seq_start)(struct seq_file___206 *, loff_t *);
	void * (*seq_next)(struct seq_file___206 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___206 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___177 *, struct cftype___176 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___177 *, struct cftype___176 *, s64);
	ssize_t (*write)(struct kernfs_open_file___222 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___222 *, struct poll_table_struct___142 *);
};

struct perf_cpu_context___122;

struct pmu___122 {
	struct list_head entry;
	struct module___183 *module;
	struct device___195 *dev;
	const struct attribute_group___197 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___122 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___122 *);
	void (*pmu_disable)(struct pmu___122 *);
	int (*event_init)(struct perf_event___122 *);
	void (*event_mapped)(struct perf_event___122 *, struct mm_struct___227 *);
	void (*event_unmapped)(struct perf_event___122 *, struct mm_struct___227 *);
	int (*add)(struct perf_event___122 *, int);
	void (*del)(struct perf_event___122 *, int);
	void (*start)(struct perf_event___122 *, int);
	void (*stop)(struct perf_event___122 *, int);
	void (*read)(struct perf_event___122 *);
	void (*start_txn)(struct pmu___122 *, unsigned int);
	int (*commit_txn)(struct pmu___122 *);
	void (*cancel_txn)(struct pmu___122 *);
	int (*event_idx)(struct perf_event___122 *);
	void (*sched_task)(struct perf_event_context___122 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___122 *);
	int (*filter_match)(struct perf_event___122 *);
	int (*check_period)(struct perf_event___122 *, u64);
};

struct perf_cpu_context___122 {
	struct perf_event_context___122 ctx;
	struct perf_event_context___122 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___122 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___122 {
	struct cgroup_subsys_state___177 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___115 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___115 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___115 *);
	struct list_head * (*get_fields)(struct trace_event_call___115 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___115 *);
};

struct syscall_metadata___58 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___115 *enter_event;
	struct trace_event_call___115 *exit_event;
};

struct ipc_ops___2 {
	int (*getnew)(struct ipc_namespace___4 *, struct ipc_params *);
	int (*associate)(struct kern_ipc_perm *, int);
	int (*more_checks)(struct kern_ipc_perm *, struct ipc_params *);
};

struct msg_queue {
	struct kern_ipc_perm q_perm;
	time64_t q_stime;
	time64_t q_rtime;
	time64_t q_ctime;
	long unsigned int q_cbytes;
	long unsigned int q_qnum;
	long unsigned int q_qbytes;
	struct pid___172 *q_lspid;
	struct pid___172 *q_lrpid;
	struct list_head q_messages;
	struct list_head q_receivers;
	struct list_head q_senders;
	long: 64;
	long: 64;
};

struct msg_receiver {
	struct list_head r_list;
	struct task_struct___228 *r_tsk;
	int r_mode;
	long int r_msgtype;
	long int r_maxsize;
	struct msg_msg *r_msg;
};

struct msg_sender {
	struct list_head list;
	struct task_struct___228 *tsk;
	size_t msgsz;
};

struct module___184;

struct file___229;

struct kiocb___229;

struct poll_table_struct___143;

struct vm_area_struct___229;

struct inode___229;

struct file_lock___229;

struct page___229;

struct seq_file___207;

struct file_operations___229 {
	struct module___184 *owner;
	loff_t (*llseek)(struct file___229 *, loff_t, int);
	ssize_t (*read)(struct file___229 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___229 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___229 *, struct iov_iter___101 *);
	ssize_t (*write_iter)(struct kiocb___229 *, struct iov_iter___101 *);
	int (*iopoll)(struct kiocb___229 *, bool);
	int (*iterate)(struct file___229 *, struct dir_context *);
	int (*iterate_shared)(struct file___229 *, struct dir_context *);
	__poll_t (*poll)(struct file___229 *, struct poll_table_struct___143 *);
	long int (*unlocked_ioctl)(struct file___229 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___229 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___229 *, struct vm_area_struct___229 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___229 *, struct file___229 *);
	int (*flush)(struct file___229 *, fl_owner_t);
	int (*release)(struct inode___229 *, struct file___229 *);
	int (*fsync)(struct file___229 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___229 *, int);
	int (*lock)(struct file___229 *, int, struct file_lock___229 *);
	ssize_t (*sendpage)(struct file___229 *, struct page___229 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___229 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___229 *, int, struct file_lock___229 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___229 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___229 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___229 *, long int, struct file_lock___229 **, void **);
	long int (*fallocate)(struct file___229 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___207 *, struct file___229 *);
	ssize_t (*copy_file_range)(struct file___229 *, loff_t, struct file___229 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___229 *, loff_t, struct file___229 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___229 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___228 {
	u64 seqnum;
	struct vm_area_struct___229 *vmas[4];
};

struct page_frag___228 {
	struct page___229 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___123;

struct debug_info___123 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___123 *hbp_break[16];
	struct perf_event___123 *hbp_watch[16];
};

struct thread_struct___123 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___123 debug;
	long: 64;
};

struct mm_struct___228;

struct pid___173;

struct cred___222;

struct nsproxy___210;

struct signal_struct___191;

struct css_set___177;

struct perf_event_context___123;

struct task_struct___229 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___229 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___228 *mm;
	struct mm_struct___228 *active_mm;
	struct vmacache___228 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___229 *real_parent;
	struct task_struct___229 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___229 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___173 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___173 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___173 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___222 *ptracer_cred;
	const struct cred___222 *real_cred;
	const struct cred___222 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___210 *nsproxy;
	struct signal_struct___191 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___229 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___58 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___177 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___123 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___228 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___229 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___123 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___123 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___229 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___123)(struct perf_event___123 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___123;

struct fasync_struct___228;

struct pid_namespace___173;

struct trace_event_call___116;

struct perf_cgroup___123;

struct perf_event___123 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___123 *group_leader;
	struct pmu___123 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___123 hw;
	struct perf_event_context___123 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___123 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___229 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___228 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___123 *);
	struct callback_head callback_head;
	struct pid_namespace___173 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___123 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___123 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___116 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___123 *cgrp;
	struct list_head sb_list;
};

struct rw_semaphore___229 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___229 *owner;
};

struct key___222;

struct ucounts___191;

struct user_namespace___191 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___191 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___27 ns;
	long unsigned int flags;
	struct key___222 *persistent_keyring_register;
	struct rw_semaphore___229 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___191 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct secondary_data___229 {
	void *stack;
	struct task_struct___229 *task;
	long int status;
};

struct sem;

struct sem_queue;

struct sem_undo;

struct semid_ds {
	struct ipc_perm sem_perm;
	__kernel_time_t sem_otime;
	__kernel_time_t sem_ctime;
	struct sem *sem_base;
	struct sem_queue *sem_pending;
	struct sem_queue **sem_pending_last;
	struct sem_undo *undo;
	short unsigned int sem_nsems;
};

struct sem {
	int semval;
	struct pid___173 *sempid;
	spinlock_t lock;
	struct list_head pending_alter;
	struct list_head pending_const;
	time64_t sem_otime;
};

struct sembuf;

struct sem_queue {
	struct list_head list;
	struct task_struct___229 *sleeper;
	struct sem_undo *undo;
	struct pid___173 *pid;
	int status;
	struct sembuf *sops;
	struct sembuf *blocking;
	int nsops;
	bool alter;
	bool dupsop;
};

struct sem_undo {
	struct list_head list_proc;
	struct callback_head rcu;
	struct sem_undo_list *ulp;
	struct list_head list_id;
	int semid;
	short int *semadj;
};

struct semid64_ds {
	struct ipc64_perm sem_perm;
	__kernel_time_t sem_otime;
	__kernel_time_t sem_ctime;
	long unsigned int sem_nsems;
	long unsigned int __unused3;
	long unsigned int __unused4;
};

struct sembuf {
	short unsigned int sem_num;
	short int sem_op;
	short int sem_flg;
};

struct seminfo {
	int semmap;
	int semmni;
	int semmns;
	int semmnu;
	int semmsl;
	int semopm;
	int semume;
	int semusz;
	int semvmx;
	int semaem;
};

struct sem_undo_list {
	refcount_t refcnt;
	spinlock_t lock;
	struct list_head list_proc;
};

typedef struct page___229 *pgtable_t___228;

struct address_space___228;

struct dev_pagemap___220;

struct page___229 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___228 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___229 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___228 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___228 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___220 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___228;

struct lruvec___228 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___228 *pgdat;
};

struct zone___228 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___228 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___228 {
	struct zone___228 *zone;
	int zone_idx;
};

struct zonelist___228 {
	struct zoneref___228 _zonerefs[25];
};

struct pglist_data___228 {
	struct zone___228 node_zones[3];
	struct zonelist___228 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___229 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___229 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___228 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___228 {
	struct rw_semaphore___229 rwsem;
	struct notifier_block *head;
};

struct upid___173 {
	int nr;
	struct pid_namespace___173 *ns;
};

struct dentry___229;

struct pid_namespace___173 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___229 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___173 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___229 *proc_self;
	struct dentry___229 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___191 *user_ns;
	struct ucounts___191 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___173 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___173 numbers[1];
};

struct user_struct___222 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___222 *uid_keyring;
	struct key___222 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___220;

struct vm_area_struct___229 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___229 *vm_next;
	struct vm_area_struct___229 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___228 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___220 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___229 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___228;

struct mm_struct___228 {
	struct {
		struct vm_area_struct___229 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___229 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___229 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___228 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___229 *owner;
		struct user_namespace___191 *user_ns;
		struct file___229 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___228 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___222 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___222 *session_keyring;
	struct key___222 *process_keyring;
	struct key___222 *thread_keyring;
	struct key___222 *request_key_auth;
	void *security;
	struct user_struct___222 *user;
	struct user_namespace___191 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct ipc_namespace___5;

struct cgroup_namespace___177;

struct nsproxy___210 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace___5 *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___173 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___177 *cgroup_ns;
};

struct signal_struct___191 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___229 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___229 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___173 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___173 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___228 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___173 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___178;

struct cgroup___177;

struct css_set___177 {
	struct cgroup_subsys_state___178 *subsys[13];
	refcount_t refcount;
	struct css_set___177 *dom_cset;
	struct cgroup___177 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___177 *mg_src_cgrp;
	struct cgroup___177 *mg_dst_cgrp;
	struct css_set___177 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___123 {
	struct pmu___123 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___229 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___123 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

union thread_union___202 {
	struct task_struct___229 task;
	long unsigned int stack[8192];
};

struct address_space_operations___228;

struct address_space___228 {
	struct inode___229 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___229 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___228 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___220)(struct vm_area_struct___229 *, long unsigned int, const struct page___229 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___220)(struct page___229 *, void *);

struct device___196;

struct dev_pagemap___220 {
	dev_page_fault_t___220 page_fault;
	dev_page_free_t___220 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___196 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___228 {
	struct vfsmount *mnt;
	struct dentry___229 *dentry;
};

struct fown_struct___173 {
	rwlock_t lock;
	struct pid___173 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___229 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___228 f_path;
	struct inode___229 *f_inode;
	const struct file_operations___229 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___173 f_owner;
	const struct cred___222 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___228 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___220;

struct vm_operations_struct___220 {
	void (*open)(struct vm_area_struct___229 *);
	void (*close)(struct vm_area_struct___229 *);
	int (*split)(struct vm_area_struct___229 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___229 *);
	vm_fault_t (*fault)(struct vm_fault___220 *);
	vm_fault_t (*huge_fault)(struct vm_fault___220 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___220 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___229 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___220 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___220 *);
	int (*access)(struct vm_area_struct___229 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___229 *);
	int (*set_policy)(struct vm_area_struct___229 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___229 *, long unsigned int);
	struct page___229 * (*find_special_page)(struct vm_area_struct___229 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___228 {
	struct task_struct___229 *task;
	struct core_thread___228 *next;
};

struct core_state___228 {
	atomic_t nr_threads;
	struct core_thread___228 dumper;
	struct completion startup;
};

struct vm_fault___220 {
	struct vm_area_struct___229 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___229 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___229 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___228 prealloc_pte;
};

struct kset___216;

struct kobj_type___216;

struct kernfs_node___223;

struct kobject___217 {
	const char *name;
	struct list_head entry;
	struct kobject___217 *parent;
	struct kset___216 *kset;
	struct kobj_type___216 *ktype;
	struct kernfs_node___223 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___181 {
	struct kobject___217 kobj;
	struct module___184 *mod;
	struct kobject___217 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___181 {
	struct module___184 *mod;
	struct latch_tree_node node;
};

struct module_layout___181 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___181 mtn;
};

struct module_attribute___181;

struct kernel_param___181;

struct module___184 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___181 mkobj;
	struct module_attribute___181 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___217 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___181 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___181 core_layout;
	struct module_layout___181 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___116 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kiocb___229 {
	struct file___229 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___229 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dentry_operations___228;

struct super_block___228;

struct dentry___229 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___229 *d_parent;
	struct qstr d_name;
	struct inode___229 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___228 *d_op;
	struct super_block___228 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___228;

struct block_device___229;

struct inode___229 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___228 *i_op;
	struct super_block___228 *i_sb;
	struct address_space___228 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___229 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___229 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___228 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___229 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___228 {
	int (*d_revalidate)(struct dentry___229 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___229 *, unsigned int);
	int (*d_hash)(const struct dentry___229 *, struct qstr *);
	int (*d_compare)(const struct dentry___229 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___229 *);
	int (*d_init)(struct dentry___229 *);
	void (*d_release)(struct dentry___229 *);
	void (*d_prune)(struct dentry___229 *);
	void (*d_iput)(struct dentry___229 *, struct inode___229 *);
	char * (*d_dname)(struct dentry___229 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___228 *);
	int (*d_manage)(const struct path___228 *, bool);
	struct dentry___229 * (*d_real)(struct dentry___229 *, const struct inode___229 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___228;

struct mem_dqinfo___228 {
	struct quota_format_type___228 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___228;

struct quota_info___228 {
	unsigned int flags;
	struct rw_semaphore___229 dqio_sem;
	struct inode___229 *files[3];
	struct mem_dqinfo___228 info[3];
	const struct quota_format_ops___228 *ops[3];
};

struct rcuwait___228 {
	struct task_struct___229 *task;
};

struct percpu_rw_semaphore___228 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___229 rw_sem;
	struct rcuwait___228 writer;
	int readers_block;
};

struct sb_writers___228 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___228 rw_sem[3];
};

struct file_system_type___228;

struct super_operations___228;

struct dquot_operations___228;

struct quotactl_ops___228;

struct super_block___228 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___228 *s_type;
	const struct super_operations___228 *s_op;
	const struct dquot_operations___228 *dq_op;
	const struct quotactl_ops___228 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___229 *s_root;
	struct rw_semaphore___229 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___229 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___228 s_dquot;
	struct sb_writers___228 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___228 *s_d_op;
	int cleancache_poolid;
	struct shrinker___95 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___191 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct iattr___228 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___229 *ia_file;
};

struct dquot___228 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___228 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___228 {
	int qf_fmt_id;
	const struct quota_format_ops___228 *qf_ops;
	struct module___184 *qf_owner;
	struct quota_format_type___228 *qf_next;
};

struct quota_format_ops___228 {
	int (*check_quota_file)(struct super_block___228 *, int);
	int (*read_file_info)(struct super_block___228 *, int);
	int (*write_file_info)(struct super_block___228 *, int);
	int (*free_file_info)(struct super_block___228 *, int);
	int (*read_dqblk)(struct dquot___228 *);
	int (*commit_dqblk)(struct dquot___228 *);
	int (*release_dqblk)(struct dquot___228 *);
	int (*get_next_id)(struct super_block___228 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___228 {
	int (*write_dquot)(struct dquot___228 *);
	struct dquot___228 * (*alloc_dquot)(struct super_block___228 *, int);
	void (*destroy_dquot)(struct dquot___228 *);
	int (*acquire_dquot)(struct dquot___228 *);
	int (*release_dquot)(struct dquot___228 *);
	int (*mark_dirty)(struct dquot___228 *);
	int (*write_info)(struct super_block___228 *, int);
	qsize_t * (*get_reserved_space)(struct inode___229 *);
	int (*get_projid)(struct inode___229 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___229 *, qsize_t *);
	int (*get_next_id)(struct super_block___228 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___228 {
	int (*quota_on)(struct super_block___228 *, int, int, const struct path___228 *);
	int (*quota_off)(struct super_block___228 *, int);
	int (*quota_enable)(struct super_block___228 *, unsigned int);
	int (*quota_disable)(struct super_block___228 *, unsigned int);
	int (*quota_sync)(struct super_block___228 *, int);
	int (*set_info)(struct super_block___228 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___228 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___228 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___228 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___228 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___228 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___228 {
	int (*writepage)(struct page___229 *, struct writeback_control___3 *);
	int (*readpage)(struct file___229 *, struct page___229 *);
	int (*writepages)(struct address_space___228 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___229 *);
	int (*readpages)(struct file___229 *, struct address_space___228 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___229 *, struct address_space___228 *, loff_t, unsigned int, unsigned int, struct page___229 **, void **);
	int (*write_end)(struct file___229 *, struct address_space___228 *, loff_t, unsigned int, unsigned int, struct page___229 *, void *);
	sector_t (*bmap)(struct address_space___228 *, sector_t);
	void (*invalidatepage)(struct page___229 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___229 *, gfp_t);
	void (*freepage)(struct page___229 *);
	ssize_t (*direct_IO)(struct kiocb___229 *, struct iov_iter___101 *);
	int (*migratepage)(struct address_space___228 *, struct page___229 *, struct page___229 *, enum migrate_mode);
	bool (*isolate_page)(struct page___229 *, isolate_mode_t);
	void (*putback_page)(struct page___229 *);
	int (*launder_page)(struct page___229 *);
	int (*is_partially_uptodate)(struct page___229 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___229 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___228 *, struct page___229 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___229 *, sector_t *);
	void (*swap_deactivate)(struct file___229 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___229 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___229 *bd_inode;
	struct super_block___228 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___229 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___228 {
	struct dentry___229 * (*lookup)(struct inode___229 *, struct dentry___229 *, unsigned int);
	const char * (*get_link)(struct dentry___229 *, struct inode___229 *, struct delayed_call *);
	int (*permission)(struct inode___229 *, int);
	struct posix_acl * (*get_acl)(struct inode___229 *, int);
	int (*readlink)(struct dentry___229 *, char *, int);
	int (*create)(struct inode___229 *, struct dentry___229 *, umode_t, bool);
	int (*link)(struct dentry___229 *, struct inode___229 *, struct dentry___229 *);
	int (*unlink)(struct inode___229 *, struct dentry___229 *);
	int (*symlink)(struct inode___229 *, struct dentry___229 *, const char *);
	int (*mkdir)(struct inode___229 *, struct dentry___229 *, umode_t);
	int (*rmdir)(struct inode___229 *, struct dentry___229 *);
	int (*mknod)(struct inode___229 *, struct dentry___229 *, umode_t, dev_t);
	int (*rename)(struct inode___229 *, struct dentry___229 *, struct inode___229 *, struct dentry___229 *, unsigned int);
	int (*setattr)(struct dentry___229 *, struct iattr___228 *);
	int (*getattr)(const struct path___228 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___229 *, char *, size_t);
	int (*fiemap)(struct inode___229 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___229 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___229 *, struct dentry___229 *, struct file___229 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___229 *, struct dentry___229 *, umode_t);
	int (*set_acl)(struct inode___229 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___228 {
	void (*fl_copy_lock)(struct file_lock___229 *, struct file_lock___229 *);
	void (*fl_release_private)(struct file_lock___229 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___228;

struct file_lock___229 {
	struct file_lock___229 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___229 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___228 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___228 *fl_ops;
	const struct lock_manager_operations___228 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___228 {
	int (*lm_compare_owner)(struct file_lock___229 *, struct file_lock___229 *);
	long unsigned int (*lm_owner_key)(struct file_lock___229 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___229 *);
	int (*lm_grant)(struct file_lock___229 *, int);
	bool (*lm_break)(struct file_lock___229 *);
	int (*lm_change)(struct file_lock___229 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___229 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___228 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___228 *fa_next;
	struct file___229 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___228 {
	const char *name;
	int fs_flags;
	struct dentry___229 * (*mount)(struct file_system_type___228 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___228 *);
	struct module___184 *owner;
	struct file_system_type___228 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___228 {
	struct inode___229 * (*alloc_inode)(struct super_block___228 *);
	void (*destroy_inode)(struct inode___229 *);
	void (*dirty_inode)(struct inode___229 *, int);
	int (*write_inode)(struct inode___229 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___229 *);
	void (*evict_inode)(struct inode___229 *);
	void (*put_super)(struct super_block___228 *);
	int (*sync_fs)(struct super_block___228 *, int);
	int (*freeze_super)(struct super_block___228 *);
	int (*freeze_fs)(struct super_block___228 *);
	int (*thaw_super)(struct super_block___228 *);
	int (*unfreeze_fs)(struct super_block___228 *);
	int (*statfs)(struct dentry___229 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___228 *, int *, char *);
	void (*umount_begin)(struct super_block___228 *);
	int (*show_options)(struct seq_file___207 *, struct dentry___229 *);
	int (*show_devname)(struct seq_file___207 *, struct dentry___229 *);
	int (*show_path)(struct seq_file___207 *, struct dentry___229 *);
	int (*show_stats)(struct seq_file___207 *, struct dentry___229 *);
	ssize_t (*quota_read)(struct super_block___228 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___228 *, int, const char *, size_t, loff_t);
	struct dquot___228 ** (*get_dquots)(struct inode___229 *);
	int (*bdev_try_to_free_page)(struct super_block___228 *, struct page___229 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___228 *, struct shrink_control___95 *);
	long int (*free_cached_objects)(struct super_block___228 *, struct shrink_control___95 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___145)(struct file___229 *, wait_queue_head_t *, struct poll_table_struct___143 *);

struct poll_table_struct___143 {
	poll_queue_proc___145 _qproc;
	__poll_t _key;
};

struct seq_operations___205;

struct seq_file___207 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___205 *op;
	int poll_event;
	const struct file___229 *file;
	void *private;
};

typedef int (*key_restrict_link_func_t___222)(struct key___222 *, const struct key_type *, const union key_payload *, struct key___222 *);

struct key_restriction___222;

struct key___222 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___229 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___222 *restrict_link;
};

struct key_restriction___222 {
	key_restrict_link_func_t___222 check;
	struct key___222 *key;
	struct key_type *keytype;
};

struct dev_pm_info___196 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___196 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___196;

struct bus_type___196;

struct device_driver___196;

struct dev_pm_domain___196;

struct class___196;

struct attribute_group___198;

struct device___196 {
	struct device___196 *parent;
	struct device_private *p;
	struct kobject___217 kobj;
	const char *init_name;
	const struct device_type___196 *type;
	struct mutex mutex;
	struct bus_type___196 *bus;
	struct device_driver___196 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___196 power;
	struct dev_pm_domain___196 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___196 *class;
	const struct attribute_group___198 **groups;
	void (*release)(struct device___196 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct kobj_attribute___211 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___217 *, struct kobj_attribute___211 *, char *);
	ssize_t (*store)(struct kobject___217 *, struct kobj_attribute___211 *, const char *, size_t);
};

typedef void compound_page_dtor___220(struct page___229 *);

struct seq_operations___205 {
	void * (*start)(struct seq_file___207 *, loff_t *);
	void (*stop)(struct seq_file___207 *, void *);
	void * (*next)(struct seq_file___207 *, void *, loff_t *);
	int (*show)(struct seq_file___207 *, void *);
};

struct ipc_ids___5 {
	int in_use;
	short unsigned int seq;
	struct rw_semaphore___229 rwsem;
	struct idr ipcs_idr;
	int max_idx;
	int last_idx;
	int next_id;
	struct rhashtable key_ht;
};

struct ipc_namespace___5 {
	refcount_t count;
	struct ipc_ids___5 ids[3];
	int sem_ctls[4];
	int used_sems;
	unsigned int msg_ctlmax;
	unsigned int msg_ctlmnb;
	unsigned int msg_ctlmni;
	atomic_t msg_bytes;
	atomic_t msg_hdrs;
	size_t shm_ctlmax;
	size_t shm_ctlall;
	long unsigned int shm_tot;
	int shm_ctlmni;
	int shm_rmid_forced;
	struct notifier_block ipcns_nb;
	struct vfsmount *mq_mnt;
	unsigned int mq_queues_count;
	unsigned int mq_queues_max;
	unsigned int mq_msg_max;
	unsigned int mq_msgsize_max;
	unsigned int mq_msg_default;
	unsigned int mq_msgsize_default;
	struct user_namespace___191 *user_ns;
	struct ucounts___191 *ucounts;
	struct ns_common___27 ns;
};

struct cgroup_namespace___177 {
	refcount_t count;
	struct ns_common___27 ns;
	struct user_namespace___191 *user_ns;
	struct ucounts___191 *ucounts;
	struct css_set___177 *root_cset;
};

struct ucounts___191 {
	struct hlist_node node;
	struct user_namespace___191 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct kernfs_root___223;

struct kernfs_elem_dir___223 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___223 *root;
};

struct kernfs_syscall_ops___223;

struct kernfs_root___223 {
	struct kernfs_node___223 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___223 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___223 {
	struct kernfs_node___223 *target_kn;
};

struct kernfs_ops___223;

struct kernfs_elem_attr___223 {
	const struct kernfs_ops___223 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___223 *notify_next;
};

struct kernfs_node___223 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___223 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___223 dir;
		struct kernfs_elem_symlink___223 symlink;
		struct kernfs_elem_attr___223 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___223;

struct kernfs_ops___223 {
	int (*open)(struct kernfs_open_file___223 *);
	void (*release)(struct kernfs_open_file___223 *);
	int (*seq_show)(struct seq_file___207 *, void *);
	void * (*seq_start)(struct seq_file___207 *, loff_t *);
	void * (*seq_next)(struct seq_file___207 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___207 *, void *);
	ssize_t (*read)(struct kernfs_open_file___223 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___223 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___223 *, struct vm_area_struct___229 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___223 *, struct poll_table_struct___143 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___223 {
	int (*remount_fs)(struct kernfs_root___223 *, int *, char *);
	int (*show_options)(struct seq_file___207 *, struct kernfs_root___223 *);
	int (*mkdir)(struct kernfs_node___223 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___223 *);
	int (*rename)(struct kernfs_node___223 *, struct kernfs_node___223 *, const char *);
	int (*show_path)(struct seq_file___207 *, struct kernfs_node___223 *, struct kernfs_root___223 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___223 {
	struct kernfs_node___223 *kn;
	struct file___229 *file;
	struct seq_file___207 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___220 *vm_ops;
};

struct bin_attribute___197;

struct attribute_group___198 {
	const char *name;
	umode_t (*is_visible)(struct kobject___217 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___217 *, struct bin_attribute___197 *, int);
	struct attribute **attrs;
	struct bin_attribute___197 **bin_attrs;
};

struct bin_attribute___197 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___229 *, struct kobject___217 *, struct bin_attribute___197 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___229 *, struct kobject___217 *, struct bin_attribute___197 *, char *, loff_t, size_t);
	int (*mmap)(struct file___229 *, struct kobject___217 *, struct bin_attribute___197 *, struct vm_area_struct___229 *);
};

struct sysfs_ops___216 {
	ssize_t (*show)(struct kobject___217 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___217 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___216;

struct kset___216 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___217 kobj;
	const struct kset_uevent_ops___216 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___216 {
	void (*release)(struct kobject___217 *);
	const struct sysfs_ops___216 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___12 * (*child_ns_type)(struct kobject___217 *);
	const void * (*namespace)(struct kobject___217 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___216 {
	int (* const filter)(struct kset___216 *, struct kobject___217 *);
	const char * (* const name)(struct kset___216 *, struct kobject___217 *);
	int (* const uevent)(struct kset___216 *, struct kobject___217 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___181 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___181 *);
	int (*get)(char *, const struct kernel_param___181 *);
	void (*free)(void *);
};

struct kparam_array___181;

struct kernel_param___181 {
	const char *name;
	struct module___184 *mod;
	const struct kernel_param_ops___181 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___181 *arr;
	};
};

struct kparam_array___181 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___181 *ops;
	void *elem;
};

struct module_attribute___181 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___181 *, struct module_kobject___181 *, char *);
	ssize_t (*store)(struct module_attribute___181 *, struct module_kobject___181 *, const char *, size_t);
	void (*setup)(struct module___184 *, const char *);
	int (*test)(struct module___184 *);
	void (*free)(struct module___184 *);
};

struct trace_event_class___116;

struct trace_event_call___116 {
	struct list_head list;
	struct trace_event_class___116 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___22 *prog_array;
	int (*perf_perm)(struct trace_event_call___116 *, struct perf_event___123 *);
};

struct dev_pm_ops___196 {
	int (*prepare)(struct device___196 *);
	void (*complete)(struct device___196 *);
	int (*suspend)(struct device___196 *);
	int (*resume)(struct device___196 *);
	int (*freeze)(struct device___196 *);
	int (*thaw)(struct device___196 *);
	int (*poweroff)(struct device___196 *);
	int (*restore)(struct device___196 *);
	int (*suspend_late)(struct device___196 *);
	int (*resume_early)(struct device___196 *);
	int (*freeze_late)(struct device___196 *);
	int (*thaw_early)(struct device___196 *);
	int (*poweroff_late)(struct device___196 *);
	int (*restore_early)(struct device___196 *);
	int (*suspend_noirq)(struct device___196 *);
	int (*resume_noirq)(struct device___196 *);
	int (*freeze_noirq)(struct device___196 *);
	int (*thaw_noirq)(struct device___196 *);
	int (*poweroff_noirq)(struct device___196 *);
	int (*restore_noirq)(struct device___196 *);
	int (*runtime_suspend)(struct device___196 *);
	int (*runtime_resume)(struct device___196 *);
	int (*runtime_idle)(struct device___196 *);
};

struct dev_pm_domain___196 {
	struct dev_pm_ops___196 ops;
	void (*detach)(struct device___196 *, bool);
	int (*activate)(struct device___196 *);
	void (*sync)(struct device___196 *);
	void (*dismiss)(struct device___196 *);
};

struct bus_type___196 {
	const char *name;
	const char *dev_name;
	struct device___196 *dev_root;
	const struct attribute_group___198 **bus_groups;
	const struct attribute_group___198 **dev_groups;
	const struct attribute_group___198 **drv_groups;
	int (*match)(struct device___196 *, struct device_driver___196 *);
	int (*uevent)(struct device___196 *, struct kobj_uevent_env *);
	int (*probe)(struct device___196 *);
	int (*remove)(struct device___196 *);
	void (*shutdown)(struct device___196 *);
	int (*online)(struct device___196 *);
	int (*offline)(struct device___196 *);
	int (*suspend)(struct device___196 *, pm_message_t);
	int (*resume)(struct device___196 *);
	int (*num_vf)(struct device___196 *);
	int (*dma_configure)(struct device___196 *);
	const struct dev_pm_ops___196 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___196 {
	const char *name;
	struct bus_type___196 *bus;
	struct module___184 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___196 *);
	int (*remove)(struct device___196 *);
	void (*shutdown)(struct device___196 *);
	int (*suspend)(struct device___196 *, pm_message_t);
	int (*resume)(struct device___196 *);
	const struct attribute_group___198 **groups;
	const struct dev_pm_ops___196 *pm;
	void (*coredump)(struct device___196 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___196 {
	const char *name;
	const struct attribute_group___198 **groups;
	int (*uevent)(struct device___196 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___196 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___196 *);
	const struct dev_pm_ops___196 *pm;
};

struct class___196 {
	const char *name;
	struct module___184 *owner;
	const struct attribute_group___198 **class_groups;
	const struct attribute_group___198 **dev_groups;
	struct kobject___217 *dev_kobj;
	int (*dev_uevent)(struct device___196 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___196 *, umode_t *);
	void (*class_release)(struct class___196 *);
	void (*dev_release)(struct device___196 *);
	int (*shutdown_pre)(struct device___196 *);
	const struct kobj_ns_type_operations___12 *ns_type;
	const void * (*namespace)(struct device___196 *);
	const struct dev_pm_ops___196 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___163 {
	struct device___196 dev;
};

struct bpf_map___177;

struct bpf_map_ops___177 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___177 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___177 *, struct file___229 *);
	void (*map_free)(struct bpf_map___177 *);
	int (*map_get_next_key)(struct bpf_map___177 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___177 *);
	void * (*map_lookup_elem)(struct bpf_map___177 *, void *);
	int (*map_update_elem)(struct bpf_map___177 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___177 *, void *);
	int (*map_push_elem)(struct bpf_map___177 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___177 *, void *);
	int (*map_peek_elem)(struct bpf_map___177 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___177 *, struct file___229 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___177 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___177 *, void *, struct seq_file___207 *);
	int (*map_check_btf)(const struct bpf_map___177 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___177 {
	const struct bpf_map_ops___177 *ops;
	struct bpf_map___177 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___222 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___177;

typedef void (*kthread_work_func_t___177)(struct kthread_work___177 *);

struct kthread_worker___177;

struct kthread_work___177 {
	struct list_head node;
	kthread_work_func_t___177 func;
	struct kthread_worker___177 *worker;
	int canceling;
};

struct kthread_worker___177 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___229 *task;
	struct kthread_work___177 *current_work;
};

struct kthread_delayed_work___177 {
	struct kthread_work___177 work;
	struct timer_list timer;
};

struct psi_group___177 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___177 *poll_kworker;
	struct kthread_delayed_work___177 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___177 {
	struct kernfs_node___223 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___177;

struct cgroup_subsys_state___178 {
	struct cgroup___177 *cgroup;
	struct cgroup_subsys___177 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___178 *parent;
};

struct cgroup_root___177;

struct cgroup_rstat_cpu___177;

struct cgroup___177 {
	struct cgroup_subsys_state___178 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___223 *kn;
	struct cgroup_file___177 procs_file;
	struct cgroup_file___177 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___178 *subsys[13];
	struct cgroup_root___177 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___177 *dom_cgrp;
	struct cgroup_rstat_cpu___177 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___22 bpf;
	atomic_t congestion_count;
	struct cgroup___177 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___177 psi;
	int ancestor_ids[0];
};

struct cftype___177;

struct cgroup_subsys___177 {
	struct cgroup_subsys_state___178 * (*css_alloc)(struct cgroup_subsys_state___178 *);
	int (*css_online)(struct cgroup_subsys_state___178 *);
	void (*css_offline)(struct cgroup_subsys_state___178 *);
	void (*css_released)(struct cgroup_subsys_state___178 *);
	void (*css_free)(struct cgroup_subsys_state___178 *);
	void (*css_reset)(struct cgroup_subsys_state___178 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___178 *, int);
	int (*css_extra_stat_show)(struct seq_file___207 *, struct cgroup_subsys_state___178 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___229 *);
	void (*cancel_fork)(struct task_struct___229 *);
	void (*fork)(struct task_struct___229 *);
	void (*exit)(struct task_struct___229 *);
	void (*free)(struct task_struct___229 *);
	void (*bind)(struct cgroup_subsys_state___178 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___177 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___177 *dfl_cftypes;
	struct cftype___177 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___177 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___177 *updated_children;
	struct cgroup___177 *updated_next;
};

struct cgroup_root___177 {
	struct kernfs_root___223 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___177 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___177 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___177 *ss;
	struct list_head node;
	struct kernfs_ops___223 *kf_ops;
	int (*open)(struct kernfs_open_file___223 *);
	void (*release)(struct kernfs_open_file___223 *);
	u64 (*read_u64)(struct cgroup_subsys_state___178 *, struct cftype___177 *);
	s64 (*read_s64)(struct cgroup_subsys_state___178 *, struct cftype___177 *);
	int (*seq_show)(struct seq_file___207 *, void *);
	void * (*seq_start)(struct seq_file___207 *, loff_t *);
	void * (*seq_next)(struct seq_file___207 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___207 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___178 *, struct cftype___177 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___178 *, struct cftype___177 *, s64);
	ssize_t (*write)(struct kernfs_open_file___223 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___223 *, struct poll_table_struct___143 *);
};

struct perf_cpu_context___123;

struct pmu___123 {
	struct list_head entry;
	struct module___184 *module;
	struct device___196 *dev;
	const struct attribute_group___198 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___123 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___123 *);
	void (*pmu_disable)(struct pmu___123 *);
	int (*event_init)(struct perf_event___123 *);
	void (*event_mapped)(struct perf_event___123 *, struct mm_struct___228 *);
	void (*event_unmapped)(struct perf_event___123 *, struct mm_struct___228 *);
	int (*add)(struct perf_event___123 *, int);
	void (*del)(struct perf_event___123 *, int);
	void (*start)(struct perf_event___123 *, int);
	void (*stop)(struct perf_event___123 *, int);
	void (*read)(struct perf_event___123 *);
	void (*start_txn)(struct pmu___123 *, unsigned int);
	int (*commit_txn)(struct pmu___123 *);
	void (*cancel_txn)(struct pmu___123 *);
	int (*event_idx)(struct perf_event___123 *);
	void (*sched_task)(struct perf_event_context___123 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___123 *);
	int (*filter_match)(struct perf_event___123 *);
	int (*check_period)(struct perf_event___123 *, u64);
};

struct perf_cpu_context___123 {
	struct perf_event_context___123 ctx;
	struct perf_event_context___123 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___123 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___123 {
	struct cgroup_subsys_state___178 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___116 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___116 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___116 *);
	struct list_head * (*get_fields)(struct trace_event_call___116 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___116 *);
};

struct syscall_metadata___59 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___116 *enter_event;
	struct trace_event_call___116 *exit_event;
};

struct ipc_ops___3 {
	int (*getnew)(struct ipc_namespace___5 *, struct ipc_params *);
	int (*associate)(struct kern_ipc_perm *, int);
	int (*more_checks)(struct kern_ipc_perm *, struct ipc_params *);
};

struct sem_array {
	struct kern_ipc_perm sem_perm;
	time64_t sem_ctime;
	struct list_head pending_alter;
	struct list_head pending_const;
	struct list_head list_id;
	int sem_nsems;
	int complex_count;
	unsigned int use_global_lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sem sems[0];
};

struct module___185;

struct file___230;

struct kiocb___230;

struct iov_iter___102;

struct poll_table_struct___144;

struct vm_area_struct___230;

struct inode___230;

struct file_lock___230;

struct page___230;

struct seq_file___208;

struct file_operations___230 {
	struct module___185 *owner;
	loff_t (*llseek)(struct file___230 *, loff_t, int);
	ssize_t (*read)(struct file___230 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___230 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___230 *, struct iov_iter___102 *);
	ssize_t (*write_iter)(struct kiocb___230 *, struct iov_iter___102 *);
	int (*iopoll)(struct kiocb___230 *, bool);
	int (*iterate)(struct file___230 *, struct dir_context *);
	int (*iterate_shared)(struct file___230 *, struct dir_context *);
	__poll_t (*poll)(struct file___230 *, struct poll_table_struct___144 *);
	long int (*unlocked_ioctl)(struct file___230 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___230 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___230 *, struct vm_area_struct___230 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___230 *, struct file___230 *);
	int (*flush)(struct file___230 *, fl_owner_t);
	int (*release)(struct inode___230 *, struct file___230 *);
	int (*fsync)(struct file___230 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___230 *, int);
	int (*lock)(struct file___230 *, int, struct file_lock___230 *);
	ssize_t (*sendpage)(struct file___230 *, struct page___230 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___230 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___230 *, int, struct file_lock___230 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___230 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___230 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___230 *, long int, struct file_lock___230 **, void **);
	long int (*fallocate)(struct file___230 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___208 *, struct file___230 *);
	ssize_t (*copy_file_range)(struct file___230 *, loff_t, struct file___230 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___230 *, loff_t, struct file___230 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___230 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___229 {
	u64 seqnum;
	struct vm_area_struct___230 *vmas[4];
};

struct page_frag___229 {
	struct page___230 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___124;

struct debug_info___124 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___124 *hbp_break[16];
	struct perf_event___124 *hbp_watch[16];
};

struct thread_struct___124 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___124 debug;
	long: 64;
};

struct mm_struct___229;

struct mem_cgroup___96;

struct pid___174;

struct cred___223;

struct nsproxy___211;

struct signal_struct___192;

struct bio_list___110;

struct backing_dev_info___110;

struct css_set___178;

struct perf_event_context___124;

struct task_struct___230 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___230 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___229 *mm;
	struct mm_struct___229 *active_mm;
	struct vmacache___229 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___230 *real_parent;
	struct task_struct___230 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___230 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___96 *active_memcg;
	long int rh_reserved2;
	struct pid___174 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___174 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___174 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___223 *ptracer_cred;
	const struct cred___223 *real_cred;
	const struct cred___223 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___211 *nsproxy;
	struct signal_struct___192 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___230 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___110 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___110 *backing_dev_info;
	struct io_context___58 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___178 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___124 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___229 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___96 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___230 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___124 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___124 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___230 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___124)(struct perf_event___124 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___124;

struct fasync_struct___229;

struct pid_namespace___174;

struct trace_event_call___117;

struct perf_cgroup___124;

struct perf_event___124 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___124 *group_leader;
	struct pmu___124 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___124 hw;
	struct perf_event_context___124 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___124 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___230 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___229 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___124 *);
	struct callback_head callback_head;
	struct pid_namespace___174 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___124 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___124 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___117 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___124 *cgrp;
	struct list_head sb_list;
};

typedef struct page___230 *pgtable_t___229;

struct address_space___229;

struct dev_pagemap___221;

struct page___230 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___229 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___230 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___229 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___229 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___221 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___96 *mem_cgroup;
};

struct pglist_data___229;

struct lruvec___229 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___229 *pgdat;
};

struct zone___229 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___229 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___229 {
	struct zone___229 *zone;
	int zone_idx;
};

struct zonelist___229 {
	struct zoneref___229 _zonerefs[25];
};

struct pglist_data___229 {
	struct zone___229 node_zones[3];
	struct zonelist___229 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___230 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___230 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___229 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___230 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___230 *owner;
};

struct secondary_data___230 {
	void *stack;
	struct task_struct___230 *task;
	long int status;
};

struct blocking_notifier_head___229 {
	struct rw_semaphore___230 rwsem;
	struct notifier_block *head;
};

struct cgroup___178;

struct cgroup_subsys___178;

struct cgroup_subsys_state___179 {
	struct cgroup___178 *cgroup;
	struct cgroup_subsys___178 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___179 *parent;
};

struct kernfs_node___224;

struct cgroup_file___178 {
	struct kernfs_node___224 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___96;

struct mem_cgroup___96 {
	struct cgroup_subsys_state___179 css;
	struct mem_cgroup_id___6 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___178 events_file;
	struct cgroup_file___178 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___230 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___96 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct vm_operations_struct___221;

struct vm_area_struct___230 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___230 *vm_next;
	struct vm_area_struct___230 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___229 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___221 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___230 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___229;

struct user_namespace___192;

struct mm_struct___229 {
	struct {
		struct vm_area_struct___230 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___230 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___230 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___229 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___230 *owner;
		struct user_namespace___192 *user_ns;
		struct file___230 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___229 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___229;

struct address_space___229 {
	struct inode___230 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___230 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___229 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___221)(struct vm_area_struct___230 *, long unsigned int, const struct page___230 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___221)(struct page___230 *, void *);

struct device___197;

struct dev_pagemap___221 {
	dev_page_fault_t___221 page_fault;
	dev_page_free_t___221 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___197 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct vfsmount___58;

struct dentry___230;

struct path___229 {
	struct vfsmount___58 *mnt;
	struct dentry___230 *dentry;
};

struct fown_struct___174 {
	rwlock_t lock;
	struct pid___174 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___230 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___229 f_path;
	struct inode___230 *f_inode;
	const struct file_operations___230 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___174 f_owner;
	const struct cred___223 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___229 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___221;

struct vm_operations_struct___221 {
	void (*open)(struct vm_area_struct___230 *);
	void (*close)(struct vm_area_struct___230 *);
	int (*split)(struct vm_area_struct___230 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___230 *);
	vm_fault_t (*fault)(struct vm_fault___221 *);
	vm_fault_t (*huge_fault)(struct vm_fault___221 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___221 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___230 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___221 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___221 *);
	int (*access)(struct vm_area_struct___230 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___230 *);
	int (*set_policy)(struct vm_area_struct___230 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___230 *, long unsigned int);
	struct page___230 * (*find_special_page)(struct vm_area_struct___230 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___229 {
	struct task_struct___230 *task;
	struct core_thread___229 *next;
};

struct core_state___229 {
	atomic_t nr_threads;
	struct core_thread___229 dumper;
	struct completion startup;
};

struct key___223;

struct ucounts___192;

struct user_namespace___192 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___192 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___27 ns;
	long unsigned int flags;
	struct key___223 *persistent_keyring_register;
	struct rw_semaphore___230 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___192 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___221 {
	struct vm_area_struct___230 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___230 *cow_page;
	struct mem_cgroup___96 *memcg;
	struct page___230 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___229 prealloc_pte;
};

struct shrink_control___96 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___96 *memcg;
};

struct shrinker___96 {
	long unsigned int (*count_objects)(struct shrinker___96 *, struct shrink_control___96 *);
	long unsigned int (*scan_objects)(struct shrinker___96 *, struct shrink_control___96 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct upid___174 {
	int nr;
	struct pid_namespace___174 *ns;
};

struct pid_namespace___174 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___230 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___174 *parent;
	struct vfsmount___58 *proc_mnt;
	struct dentry___230 *proc_self;
	struct dentry___230 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___192 *user_ns;
	struct ucounts___192 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___174 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___174 numbers[1];
};

struct shmid_ds {
	struct ipc_perm shm_perm;
	int shm_segsz;
	__kernel_time_t shm_atime;
	__kernel_time_t shm_dtime;
	__kernel_time_t shm_ctime;
	__kernel_ipc_pid_t shm_cpid;
	__kernel_ipc_pid_t shm_lpid;
	short unsigned int shm_nattch;
	short unsigned int shm_unused;
	void *shm_unused2;
	void *shm_unused3;
};

struct shmid64_ds {
	struct ipc64_perm shm_perm;
	size_t shm_segsz;
	__kernel_time_t shm_atime;
	__kernel_time_t shm_dtime;
	__kernel_time_t shm_ctime;
	__kernel_pid_t shm_cpid;
	__kernel_pid_t shm_lpid;
	long unsigned int shm_nattch;
	long unsigned int __unused4;
	long unsigned int __unused5;
};

struct shminfo64 {
	long unsigned int shmmax;
	long unsigned int shmmin;
	long unsigned int shmmni;
	long unsigned int shmseg;
	long unsigned int shmall;
	long unsigned int __unused1;
	long unsigned int __unused2;
	long unsigned int __unused3;
	long unsigned int __unused4;
};

struct shminfo {
	int shmmax;
	int shmmin;
	int shmmni;
	int shmseg;
	int shmall;
};

struct shm_info {
	int used_ids;
	__kernel_ulong_t shm_tot;
	__kernel_ulong_t shm_rss;
	__kernel_ulong_t shm_swp;
	__kernel_ulong_t swap_attempts;
	__kernel_ulong_t swap_successes;
};

struct user_struct___223 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___223 *uid_keyring;
	struct key___223 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___223 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___223 *session_keyring;
	struct key___223 *process_keyring;
	struct key___223 *thread_keyring;
	struct key___223 *request_key_auth;
	void *security;
	struct user_struct___223 *user;
	struct user_namespace___192 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct ipc_namespace___6;

struct cgroup_namespace___178;

struct nsproxy___211 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace___6 *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___174 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___178 *cgroup_ns;
};

struct signal_struct___192 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___230 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___230 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___174 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___174 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___229 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___174 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___110;

struct bio_list___110 {
	struct bio___110 *head;
	struct bio___110 *tail;
};

struct bdi_writeback_congested___110;

struct bdi_writeback___110 {
	struct backing_dev_info___110 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___110 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___179 *memcg_css;
	struct cgroup_subsys_state___179 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___110 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___110 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___197 *dev;
	struct device___197 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___230 *debug_dir;
	struct dentry___230 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___178 {
	struct cgroup_subsys_state___179 *subsys[13];
	refcount_t refcount;
	struct css_set___178 *dom_cset;
	struct cgroup___178 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___178 *mg_src_cgrp;
	struct cgroup___178 *mg_dst_cgrp;
	struct css_set___178 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___124 {
	struct pmu___124 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___230 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___124 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

union thread_union___203 {
	struct task_struct___230 task;
	long unsigned int stack[8192];
};

struct kset___217;

struct kobj_type___217;

struct kobject___218 {
	const char *name;
	struct list_head entry;
	struct kobject___218 *parent;
	struct kset___217 *kset;
	struct kobj_type___217 *ktype;
	struct kernfs_node___224 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___197 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___197 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___197;

struct bus_type___197;

struct device_driver___197;

struct dev_pm_domain___197;

struct class___197;

struct attribute_group___199;

struct device___197 {
	struct device___197 *parent;
	struct device_private *p;
	struct kobject___218 kobj;
	const char *init_name;
	const struct device_type___197 *type;
	struct mutex mutex;
	struct bus_type___197 *bus;
	struct device_driver___197 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___197 power;
	struct dev_pm_domain___197 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___197 *class;
	const struct attribute_group___199 **groups;
	void (*release)(struct device___197 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___229;

struct super_block___229;

struct dentry___230 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___230 *d_parent;
	struct qstr d_name;
	struct inode___230 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___229 *d_op;
	struct super_block___229 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___229;

struct block_device___230;

struct inode___230 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___229 *i_op;
	struct super_block___229 *i_sb;
	struct address_space___229 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___230 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___110 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___230 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___229 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___230 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___229 {
	int (*d_revalidate)(struct dentry___230 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___230 *, unsigned int);
	int (*d_hash)(const struct dentry___230 *, struct qstr *);
	int (*d_compare)(const struct dentry___230 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___230 *);
	int (*d_init)(struct dentry___230 *);
	void (*d_release)(struct dentry___230 *);
	void (*d_prune)(struct dentry___230 *);
	void (*d_iput)(struct dentry___230 *, struct inode___230 *);
	char * (*d_dname)(struct dentry___230 *, char *, int);
	struct vfsmount___58 * (*d_automount)(struct path___229 *);
	int (*d_manage)(const struct path___229 *, bool);
	struct dentry___230 * (*d_real)(struct dentry___230 *, const struct inode___230 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___229;

struct mem_dqinfo___229 {
	struct quota_format_type___229 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___229;

struct quota_info___229 {
	unsigned int flags;
	struct rw_semaphore___230 dqio_sem;
	struct inode___230 *files[3];
	struct mem_dqinfo___229 info[3];
	const struct quota_format_ops___229 *ops[3];
};

struct rcuwait___229 {
	struct task_struct___230 *task;
};

struct percpu_rw_semaphore___229 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___230 rw_sem;
	struct rcuwait___229 writer;
	int readers_block;
};

struct sb_writers___229 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___229 rw_sem[3];
};

struct file_system_type___229;

struct super_operations___229;

struct dquot_operations___229;

struct quotactl_ops___229;

struct xattr_handler___20;

struct super_block___229 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___229 *s_type;
	const struct super_operations___229 *s_op;
	const struct dquot_operations___229 *dq_op;
	const struct quotactl_ops___229 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___230 *s_root;
	struct rw_semaphore___230 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___20 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___230 *s_bdev;
	struct backing_dev_info___110 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___229 s_dquot;
	struct sb_writers___229 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___229 *s_d_op;
	int cleancache_poolid;
	struct shrinker___96 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___192 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___58 {
	struct dentry___230 *mnt_root;
	struct super_block___229 *mnt_sb;
	int mnt_flags;
};

struct kiocb___230 {
	struct file___230 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___230 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___229 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___230 *ia_file;
};

struct dquot___229 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___229 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___229 {
	int qf_fmt_id;
	const struct quota_format_ops___229 *qf_ops;
	struct module___185 *qf_owner;
	struct quota_format_type___229 *qf_next;
};

struct quota_format_ops___229 {
	int (*check_quota_file)(struct super_block___229 *, int);
	int (*read_file_info)(struct super_block___229 *, int);
	int (*write_file_info)(struct super_block___229 *, int);
	int (*free_file_info)(struct super_block___229 *, int);
	int (*read_dqblk)(struct dquot___229 *);
	int (*commit_dqblk)(struct dquot___229 *);
	int (*release_dqblk)(struct dquot___229 *);
	int (*get_next_id)(struct super_block___229 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___229 {
	int (*write_dquot)(struct dquot___229 *);
	struct dquot___229 * (*alloc_dquot)(struct super_block___229 *, int);
	void (*destroy_dquot)(struct dquot___229 *);
	int (*acquire_dquot)(struct dquot___229 *);
	int (*release_dquot)(struct dquot___229 *);
	int (*mark_dirty)(struct dquot___229 *);
	int (*write_info)(struct super_block___229 *, int);
	qsize_t * (*get_reserved_space)(struct inode___230 *);
	int (*get_projid)(struct inode___230 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___230 *, qsize_t *);
	int (*get_next_id)(struct super_block___229 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___229 {
	int (*quota_on)(struct super_block___229 *, int, int, const struct path___229 *);
	int (*quota_off)(struct super_block___229 *, int);
	int (*quota_enable)(struct super_block___229 *, unsigned int);
	int (*quota_disable)(struct super_block___229 *, unsigned int);
	int (*quota_sync)(struct super_block___229 *, int);
	int (*set_info)(struct super_block___229 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___229 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___229 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___229 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___229 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___229 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___182 {
	struct kobject___218 kobj;
	struct module___185 *mod;
	struct kobject___218 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___182 {
	struct module___185 *mod;
	struct latch_tree_node node;
};

struct module_layout___182 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___182 mtn;
};

struct module_attribute___182;

struct kernel_param___182;

struct module___185 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___182 mkobj;
	struct module_attribute___182 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___218 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___182 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___182 core_layout;
	struct module_layout___182 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___117 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___106;

struct swap_info_struct___68;

struct address_space_operations___229 {
	int (*writepage)(struct page___230 *, struct writeback_control___106 *);
	int (*readpage)(struct file___230 *, struct page___230 *);
	int (*writepages)(struct address_space___229 *, struct writeback_control___106 *);
	int (*set_page_dirty)(struct page___230 *);
	int (*readpages)(struct file___230 *, struct address_space___229 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___230 *, struct address_space___229 *, loff_t, unsigned int, unsigned int, struct page___230 **, void **);
	int (*write_end)(struct file___230 *, struct address_space___229 *, loff_t, unsigned int, unsigned int, struct page___230 *, void *);
	sector_t (*bmap)(struct address_space___229 *, sector_t);
	void (*invalidatepage)(struct page___230 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___230 *, gfp_t);
	void (*freepage)(struct page___230 *);
	ssize_t (*direct_IO)(struct kiocb___230 *, struct iov_iter___102 *);
	int (*migratepage)(struct address_space___229 *, struct page___230 *, struct page___230 *, enum migrate_mode);
	bool (*isolate_page)(struct page___230 *, isolate_mode_t);
	void (*putback_page)(struct page___230 *);
	int (*launder_page)(struct page___230 *);
	int (*is_partially_uptodate)(struct page___230 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___230 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___229 *, struct page___230 *);
	int (*swap_activate)(struct swap_info_struct___68 *, struct file___230 *, sector_t *);
	void (*swap_deactivate)(struct file___230 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___106 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___110 *wb;
	struct inode___230 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___110;

struct iov_iter___102 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___110 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct swap_info_struct___68 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___230 *bdev;
	struct file___230 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___230 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___230 *bd_inode;
	struct super_block___229 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___230 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___110 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___229 {
	struct dentry___230 * (*lookup)(struct inode___230 *, struct dentry___230 *, unsigned int);
	const char * (*get_link)(struct dentry___230 *, struct inode___230 *, struct delayed_call *);
	int (*permission)(struct inode___230 *, int);
	struct posix_acl * (*get_acl)(struct inode___230 *, int);
	int (*readlink)(struct dentry___230 *, char *, int);
	int (*create)(struct inode___230 *, struct dentry___230 *, umode_t, bool);
	int (*link)(struct dentry___230 *, struct inode___230 *, struct dentry___230 *);
	int (*unlink)(struct inode___230 *, struct dentry___230 *);
	int (*symlink)(struct inode___230 *, struct dentry___230 *, const char *);
	int (*mkdir)(struct inode___230 *, struct dentry___230 *, umode_t);
	int (*rmdir)(struct inode___230 *, struct dentry___230 *);
	int (*mknod)(struct inode___230 *, struct dentry___230 *, umode_t, dev_t);
	int (*rename)(struct inode___230 *, struct dentry___230 *, struct inode___230 *, struct dentry___230 *, unsigned int);
	int (*setattr)(struct dentry___230 *, struct iattr___229 *);
	int (*getattr)(const struct path___229 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___230 *, char *, size_t);
	int (*fiemap)(struct inode___230 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___230 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___230 *, struct dentry___230 *, struct file___230 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___230 *, struct dentry___230 *, umode_t);
	int (*set_acl)(struct inode___230 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___229 {
	void (*fl_copy_lock)(struct file_lock___230 *, struct file_lock___230 *);
	void (*fl_release_private)(struct file_lock___230 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___229;

struct file_lock___230 {
	struct file_lock___230 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___230 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___229 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___229 *fl_ops;
	const struct lock_manager_operations___229 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___229 {
	int (*lm_compare_owner)(struct file_lock___230 *, struct file_lock___230 *);
	long unsigned int (*lm_owner_key)(struct file_lock___230 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___230 *);
	int (*lm_grant)(struct file_lock___230 *, int);
	bool (*lm_break)(struct file_lock___230 *);
	int (*lm_change)(struct file_lock___230 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___230 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___229 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___229 *fa_next;
	struct file___230 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___229 {
	const char *name;
	int fs_flags;
	struct dentry___230 * (*mount)(struct file_system_type___229 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___229 *);
	struct module___185 *owner;
	struct file_system_type___229 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___229 {
	struct inode___230 * (*alloc_inode)(struct super_block___229 *);
	void (*destroy_inode)(struct inode___230 *);
	void (*dirty_inode)(struct inode___230 *, int);
	int (*write_inode)(struct inode___230 *, struct writeback_control___106 *);
	int (*drop_inode)(struct inode___230 *);
	void (*evict_inode)(struct inode___230 *);
	void (*put_super)(struct super_block___229 *);
	int (*sync_fs)(struct super_block___229 *, int);
	int (*freeze_super)(struct super_block___229 *);
	int (*freeze_fs)(struct super_block___229 *);
	int (*thaw_super)(struct super_block___229 *);
	int (*unfreeze_fs)(struct super_block___229 *);
	int (*statfs)(struct dentry___230 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___229 *, int *, char *);
	void (*umount_begin)(struct super_block___229 *);
	int (*show_options)(struct seq_file___208 *, struct dentry___230 *);
	int (*show_devname)(struct seq_file___208 *, struct dentry___230 *);
	int (*show_path)(struct seq_file___208 *, struct dentry___230 *);
	int (*show_stats)(struct seq_file___208 *, struct dentry___230 *);
	ssize_t (*quota_read)(struct super_block___229 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___229 *, int, const char *, size_t, loff_t);
	struct dquot___229 ** (*get_dquots)(struct inode___230 *);
	int (*bdev_try_to_free_page)(struct super_block___229 *, struct page___230 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___229 *, struct shrink_control___96 *);
	long int (*free_cached_objects)(struct super_block___229 *, struct shrink_control___96 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct xattr_handler___20 {
	const char *name;
	const char *prefix;
	int flags;
	bool (*list)(struct dentry___230 *);
	int (*get)(const struct xattr_handler___20 *, struct dentry___230 *, struct inode___230 *, const char *, void *, size_t);
	int (*set)(const struct xattr_handler___20 *, struct dentry___230 *, struct inode___230 *, const char *, const void *, size_t, int);
};

typedef void (*poll_queue_proc___146)(struct file___230 *, wait_queue_head_t *, struct poll_table_struct___144 *);

struct poll_table_struct___144 {
	poll_queue_proc___146 _qproc;
	__poll_t _key;
};

struct seq_operations___206;

struct seq_file___208 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___206 *op;
	int poll_event;
	const struct file___230 *file;
	void *private;
};

typedef void bio_end_io_t___110(struct bio___110 *);

struct bio_vec___110 {
	struct page___230 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___110;

struct bio_set___110;

struct bio___110 {
	struct bio___110 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___110 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___110 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___110 *bi_io_vec;
	struct bio_set___110 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___110 bi_inline_vecs[0];
};

struct kobj_attribute___212 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___218 *, struct kobj_attribute___212 *, char *);
	ssize_t (*store)(struct kobject___218 *, struct kobj_attribute___212 *, const char *, size_t);
};

typedef void compound_page_dtor___221(struct page___230 *);

typedef int (*key_restrict_link_func_t___223)(struct key___223 *, const struct key_type *, const union key_payload *, struct key___223 *);

struct key_restriction___223;

struct key___223 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___230 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___223 *restrict_link;
};

struct key_restriction___223 {
	key_restrict_link_func_t___223 check;
	struct key___223 *key;
	struct key_type *keytype;
};

struct seq_operations___206 {
	void * (*start)(struct seq_file___208 *, loff_t *);
	void (*stop)(struct seq_file___208 *, void *);
	void * (*next)(struct seq_file___208 *, void *, loff_t *);
	int (*show)(struct seq_file___208 *, void *);
};

struct kernfs_root___224;

struct kernfs_elem_dir___224 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___224 *root;
};

struct kernfs_syscall_ops___224;

struct kernfs_root___224 {
	struct kernfs_node___224 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___224 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___224 {
	struct kernfs_node___224 *target_kn;
};

struct kernfs_ops___224;

struct kernfs_elem_attr___224 {
	const struct kernfs_ops___224 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___224 *notify_next;
};

struct kernfs_node___224 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___224 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___224 dir;
		struct kernfs_elem_symlink___224 symlink;
		struct kernfs_elem_attr___224 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___224;

struct kernfs_ops___224 {
	int (*open)(struct kernfs_open_file___224 *);
	void (*release)(struct kernfs_open_file___224 *);
	int (*seq_show)(struct seq_file___208 *, void *);
	void * (*seq_start)(struct seq_file___208 *, loff_t *);
	void * (*seq_next)(struct seq_file___208 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___208 *, void *);
	ssize_t (*read)(struct kernfs_open_file___224 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___224 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___224 *, struct vm_area_struct___230 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___224 *, struct poll_table_struct___144 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___224 {
	int (*remount_fs)(struct kernfs_root___224 *, int *, char *);
	int (*show_options)(struct seq_file___208 *, struct kernfs_root___224 *);
	int (*mkdir)(struct kernfs_node___224 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___224 *);
	int (*rename)(struct kernfs_node___224 *, struct kernfs_node___224 *, const char *);
	int (*show_path)(struct seq_file___208 *, struct kernfs_node___224 *, struct kernfs_root___224 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___224 {
	struct kernfs_node___224 *kn;
	struct file___230 *file;
	struct seq_file___208 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___221 *vm_ops;
};

struct ipc_ids___6 {
	int in_use;
	short unsigned int seq;
	struct rw_semaphore___230 rwsem;
	struct idr ipcs_idr;
	int max_idx;
	int last_idx;
	int next_id;
	struct rhashtable key_ht;
};

struct ipc_namespace___6 {
	refcount_t count;
	struct ipc_ids___6 ids[3];
	int sem_ctls[4];
	int used_sems;
	unsigned int msg_ctlmax;
	unsigned int msg_ctlmnb;
	unsigned int msg_ctlmni;
	atomic_t msg_bytes;
	atomic_t msg_hdrs;
	size_t shm_ctlmax;
	size_t shm_ctlall;
	long unsigned int shm_tot;
	int shm_ctlmni;
	int shm_rmid_forced;
	struct notifier_block ipcns_nb;
	struct vfsmount___58 *mq_mnt;
	unsigned int mq_queues_count;
	unsigned int mq_queues_max;
	unsigned int mq_msg_max;
	unsigned int mq_msgsize_max;
	unsigned int mq_msg_default;
	unsigned int mq_msgsize_default;
	struct user_namespace___192 *user_ns;
	struct ucounts___192 *ucounts;
	struct ns_common___27 ns;
};

struct cgroup_namespace___178 {
	refcount_t count;
	struct ns_common___27 ns;
	struct user_namespace___192 *user_ns;
	struct ucounts___192 *ucounts;
	struct css_set___178 *root_cset;
};

struct ucounts___192 {
	struct hlist_node node;
	struct user_namespace___192 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___178;

struct bpf_map_ops___178 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___178 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___178 *, struct file___230 *);
	void (*map_free)(struct bpf_map___178 *);
	int (*map_get_next_key)(struct bpf_map___178 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___178 *);
	void * (*map_lookup_elem)(struct bpf_map___178 *, void *);
	int (*map_update_elem)(struct bpf_map___178 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___178 *, void *);
	int (*map_push_elem)(struct bpf_map___178 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___178 *, void *);
	int (*map_peek_elem)(struct bpf_map___178 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___178 *, struct file___230 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___178 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___178 *, void *, struct seq_file___208 *);
	int (*map_check_btf)(const struct bpf_map___178 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___178 {
	const struct bpf_map_ops___178 *ops;
	struct bpf_map___178 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___223 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___178;

typedef void (*kthread_work_func_t___178)(struct kthread_work___178 *);

struct kthread_worker___178;

struct kthread_work___178 {
	struct list_head node;
	kthread_work_func_t___178 func;
	struct kthread_worker___178 *worker;
	int canceling;
};

struct kthread_worker___178 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___230 *task;
	struct kthread_work___178 *current_work;
};

struct kthread_delayed_work___178 {
	struct kthread_work___178 work;
	struct timer_list timer;
};

struct psi_group___178 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___178 *poll_kworker;
	struct kthread_delayed_work___178 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___178;

struct cgroup_rstat_cpu___178;

struct cgroup___178 {
	struct cgroup_subsys_state___179 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___224 *kn;
	struct cgroup_file___178 procs_file;
	struct cgroup_file___178 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___179 *subsys[13];
	struct cgroup_root___178 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___178 *dom_cgrp;
	struct cgroup_rstat_cpu___178 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___22 bpf;
	atomic_t congestion_count;
	struct cgroup___178 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___178 psi;
	int ancestor_ids[0];
};

struct cftype___178;

struct cgroup_subsys___178 {
	struct cgroup_subsys_state___179 * (*css_alloc)(struct cgroup_subsys_state___179 *);
	int (*css_online)(struct cgroup_subsys_state___179 *);
	void (*css_offline)(struct cgroup_subsys_state___179 *);
	void (*css_released)(struct cgroup_subsys_state___179 *);
	void (*css_free)(struct cgroup_subsys_state___179 *);
	void (*css_reset)(struct cgroup_subsys_state___179 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___179 *, int);
	int (*css_extra_stat_show)(struct seq_file___208 *, struct cgroup_subsys_state___179 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___230 *);
	void (*cancel_fork)(struct task_struct___230 *);
	void (*fork)(struct task_struct___230 *);
	void (*exit)(struct task_struct___230 *);
	void (*free)(struct task_struct___230 *);
	void (*bind)(struct cgroup_subsys_state___179 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___178 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___178 *dfl_cftypes;
	struct cftype___178 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___178 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___178 *updated_children;
	struct cgroup___178 *updated_next;
};

struct cgroup_root___178 {
	struct kernfs_root___224 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___178 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___178 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___178 *ss;
	struct list_head node;
	struct kernfs_ops___224 *kf_ops;
	int (*open)(struct kernfs_open_file___224 *);
	void (*release)(struct kernfs_open_file___224 *);
	u64 (*read_u64)(struct cgroup_subsys_state___179 *, struct cftype___178 *);
	s64 (*read_s64)(struct cgroup_subsys_state___179 *, struct cftype___178 *);
	int (*seq_show)(struct seq_file___208 *, void *);
	void * (*seq_start)(struct seq_file___208 *, loff_t *);
	void * (*seq_next)(struct seq_file___208 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___208 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___179 *, struct cftype___178 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___179 *, struct cftype___178 *, s64);
	ssize_t (*write)(struct kernfs_open_file___224 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___224 *, struct poll_table_struct___144 *);
};

struct bin_attribute___198;

struct attribute_group___199 {
	const char *name;
	umode_t (*is_visible)(struct kobject___218 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___218 *, struct bin_attribute___198 *, int);
	struct attribute **attrs;
	struct bin_attribute___198 **bin_attrs;
};

struct hstate___42;

struct hugepage_subpool___10 {
	spinlock_t lock;
	long int count;
	long int max_hpages;
	long int used_hpages;
	struct hstate___42 *hstate;
	long int min_hpages;
	long int rsv_hpages;
};

struct hstate___42 {
	int next_nid_to_alloc;
	int next_nid_to_free;
	unsigned int order;
	long unsigned int mask;
	long unsigned int max_huge_pages;
	long unsigned int nr_huge_pages;
	long unsigned int free_huge_pages;
	long unsigned int resv_huge_pages;
	long unsigned int surplus_huge_pages;
	long unsigned int nr_overcommit_huge_pages;
	struct list_head hugepage_activelist;
	struct list_head hugepage_freelists[8];
	unsigned int nr_huge_pages_node[8];
	unsigned int free_huge_pages_node[8];
	unsigned int surplus_huge_pages_node[8];
	struct cftype___178 cgroup_files[5];
	char name[32];
};

struct hugetlbfs_sb_info___10 {
	long int max_inodes;
	long int free_inodes;
	spinlock_t stat_lock;
	struct hstate___42 *hstate;
	struct hugepage_subpool___10 *spool;
	kuid_t uid;
	kgid_t gid;
	umode_t mode;
};

struct bdi_writeback_congested___110 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___110 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___110 {
	struct bio___110 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___110 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___110 bip_inline_vecs[0];
};

struct bio_set___110 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___110 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___96 {
	struct mem_cgroup___96 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___96 {
	struct lruvec___229 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___96 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___96 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct bin_attribute___198 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___230 *, struct kobject___218 *, struct bin_attribute___198 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___230 *, struct kobject___218 *, struct bin_attribute___198 *, char *, loff_t, size_t);
	int (*mmap)(struct file___230 *, struct kobject___218 *, struct bin_attribute___198 *, struct vm_area_struct___230 *);
};

struct sysfs_ops___217 {
	ssize_t (*show)(struct kobject___218 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___218 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___217;

struct kset___217 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___218 kobj;
	const struct kset_uevent_ops___217 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___217 {
	void (*release)(struct kobject___218 *);
	const struct sysfs_ops___217 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___12 * (*child_ns_type)(struct kobject___218 *);
	const void * (*namespace)(struct kobject___218 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___217 {
	int (* const filter)(struct kset___217 *, struct kobject___218 *);
	const char * (* const name)(struct kset___217 *, struct kobject___218 *);
	int (* const uevent)(struct kset___217 *, struct kobject___218 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___197 {
	int (*prepare)(struct device___197 *);
	void (*complete)(struct device___197 *);
	int (*suspend)(struct device___197 *);
	int (*resume)(struct device___197 *);
	int (*freeze)(struct device___197 *);
	int (*thaw)(struct device___197 *);
	int (*poweroff)(struct device___197 *);
	int (*restore)(struct device___197 *);
	int (*suspend_late)(struct device___197 *);
	int (*resume_early)(struct device___197 *);
	int (*freeze_late)(struct device___197 *);
	int (*thaw_early)(struct device___197 *);
	int (*poweroff_late)(struct device___197 *);
	int (*restore_early)(struct device___197 *);
	int (*suspend_noirq)(struct device___197 *);
	int (*resume_noirq)(struct device___197 *);
	int (*freeze_noirq)(struct device___197 *);
	int (*thaw_noirq)(struct device___197 *);
	int (*poweroff_noirq)(struct device___197 *);
	int (*restore_noirq)(struct device___197 *);
	int (*runtime_suspend)(struct device___197 *);
	int (*runtime_resume)(struct device___197 *);
	int (*runtime_idle)(struct device___197 *);
};

struct dev_pm_domain___197 {
	struct dev_pm_ops___197 ops;
	void (*detach)(struct device___197 *, bool);
	int (*activate)(struct device___197 *);
	void (*sync)(struct device___197 *);
	void (*dismiss)(struct device___197 *);
};

struct bus_type___197 {
	const char *name;
	const char *dev_name;
	struct device___197 *dev_root;
	const struct attribute_group___199 **bus_groups;
	const struct attribute_group___199 **dev_groups;
	const struct attribute_group___199 **drv_groups;
	int (*match)(struct device___197 *, struct device_driver___197 *);
	int (*uevent)(struct device___197 *, struct kobj_uevent_env *);
	int (*probe)(struct device___197 *);
	int (*remove)(struct device___197 *);
	void (*shutdown)(struct device___197 *);
	int (*online)(struct device___197 *);
	int (*offline)(struct device___197 *);
	int (*suspend)(struct device___197 *, pm_message_t);
	int (*resume)(struct device___197 *);
	int (*num_vf)(struct device___197 *);
	int (*dma_configure)(struct device___197 *);
	const struct dev_pm_ops___197 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___197 {
	const char *name;
	struct bus_type___197 *bus;
	struct module___185 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___197 *);
	int (*remove)(struct device___197 *);
	void (*shutdown)(struct device___197 *);
	int (*suspend)(struct device___197 *, pm_message_t);
	int (*resume)(struct device___197 *);
	const struct attribute_group___199 **groups;
	const struct dev_pm_ops___197 *pm;
	void (*coredump)(struct device___197 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___197 {
	const char *name;
	const struct attribute_group___199 **groups;
	int (*uevent)(struct device___197 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___197 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___197 *);
	const struct dev_pm_ops___197 *pm;
};

struct class___197 {
	const char *name;
	struct module___185 *owner;
	const struct attribute_group___199 **class_groups;
	const struct attribute_group___199 **dev_groups;
	struct kobject___218 *dev_kobj;
	int (*dev_uevent)(struct device___197 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___197 *, umode_t *);
	void (*class_release)(struct class___197 *);
	void (*dev_release)(struct device___197 *);
	int (*shutdown_pre)(struct device___197 *);
	const struct kobj_ns_type_operations___12 *ns_type;
	const void * (*namespace)(struct device___197 *);
	const struct dev_pm_ops___197 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___164 {
	struct device___197 dev;
};

struct shmem_inode_info___3 {
	spinlock_t lock;
	unsigned int seals;
	long unsigned int flags;
	long unsigned int alloced;
	long unsigned int swapped;
	struct list_head shrinklist;
	struct list_head swaplist;
	struct shared_policy policy;
	struct simple_xattrs xattrs;
	struct inode___230 vfs_inode;
};

struct kernel_param_ops___182 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___182 *);
	int (*get)(char *, const struct kernel_param___182 *);
	void (*free)(void *);
};

struct kparam_array___182;

struct kernel_param___182 {
	const char *name;
	struct module___185 *mod;
	const struct kernel_param_ops___182 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___182 *arr;
	};
};

struct kparam_array___182 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___182 *ops;
	void *elem;
};

struct module_attribute___182 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___182 *, struct module_kobject___182 *, char *);
	ssize_t (*store)(struct module_attribute___182 *, struct module_kobject___182 *, const char *, size_t);
	void (*setup)(struct module___185 *, const char *);
	int (*test)(struct module___185 *);
	void (*free)(struct module___185 *);
};

struct trace_event_class___117;

struct trace_event_call___117 {
	struct list_head list;
	struct trace_event_class___117 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___22 *prog_array;
	int (*perf_perm)(struct trace_event_call___117 *, struct perf_event___124 *);
};

struct perf_cpu_context___124;

struct pmu___124 {
	struct list_head entry;
	struct module___185 *module;
	struct device___197 *dev;
	const struct attribute_group___199 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___124 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___124 *);
	void (*pmu_disable)(struct pmu___124 *);
	int (*event_init)(struct perf_event___124 *);
	void (*event_mapped)(struct perf_event___124 *, struct mm_struct___229 *);
	void (*event_unmapped)(struct perf_event___124 *, struct mm_struct___229 *);
	int (*add)(struct perf_event___124 *, int);
	void (*del)(struct perf_event___124 *, int);
	void (*start)(struct perf_event___124 *, int);
	void (*stop)(struct perf_event___124 *, int);
	void (*read)(struct perf_event___124 *);
	void (*start_txn)(struct pmu___124 *, unsigned int);
	int (*commit_txn)(struct pmu___124 *);
	void (*cancel_txn)(struct pmu___124 *);
	int (*event_idx)(struct perf_event___124 *);
	void (*sched_task)(struct perf_event_context___124 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___124 *);
	int (*filter_match)(struct perf_event___124 *);
	int (*check_period)(struct perf_event___124 *, u64);
};

struct perf_cpu_context___124 {
	struct perf_event_context___124 ctx;
	struct perf_event_context___124 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___124 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___124 {
	struct cgroup_subsys_state___179 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___117 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___117 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___117 *);
	struct list_head * (*get_fields)(struct trace_event_call___117 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___117 *);
};

struct syscall_metadata___60 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___117 *enter_event;
	struct trace_event_call___117 *exit_event;
};

struct ipc_ops___4 {
	int (*getnew)(struct ipc_namespace___6 *, struct ipc_params *);
	int (*associate)(struct kern_ipc_perm *, int);
	int (*more_checks)(struct kern_ipc_perm *, struct ipc_params *);
};

struct shmid_kernel {
	struct kern_ipc_perm shm_perm;
	struct file___230 *shm_file;
	long unsigned int shm_nattch;
	long unsigned int shm_segsz;
	time64_t shm_atim;
	time64_t shm_dtim;
	time64_t shm_ctim;
	struct pid___174 *shm_cprid;
	struct pid___174 *shm_lprid;
	struct user_struct___223 *mlock_user;
	struct task_struct___230 *shm_creator;
	struct list_head shm_clist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct shm_file_data {
	int id;
	struct ipc_namespace___6 *ns;
	struct file___230 *file;
	const struct vm_operations_struct___221 *vm_ops;
};

struct vm_area_struct___231;

struct vmacache___230 {
	u64 seqnum;
	struct vm_area_struct___231 *vmas[4];
};

struct page___231;

struct page_frag___230 {
	struct page___231 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___230;

struct nsproxy___212;

struct task_struct___231 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___231 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___230 *mm;
	struct mm_struct___230 *active_mm;
	struct vmacache___230 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___231 *real_parent;
	struct task_struct___231 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___231 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___174 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___174 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___174 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___2 *ptracer_cred;
	const struct cred___2 *real_cred;
	const struct cred___2 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___212 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___231 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___2 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___230 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___231 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___124 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___231 *pgtable_t___230;

struct page___231 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___229 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___231 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___230 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___230 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___221 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___230;

struct lruvec___230 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___230 *pgdat;
};

struct zone___230 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___230 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___230 {
	struct zone___230 *zone;
	int zone_idx;
};

struct zonelist___230 {
	struct zoneref___230 _zonerefs[25];
};

struct pglist_data___230 {
	struct zone___230 node_zones[3];
	struct zonelist___230 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___231 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___231 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___230 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___231 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___231 *owner;
};

struct secondary_data___231 {
	void *stack;
	struct task_struct___231 *task;
	long int status;
};

struct blocking_notifier_head___230 {
	struct rw_semaphore___231 rwsem;
	struct notifier_block *head;
};

struct kernfs_root___225;

struct kernfs_elem_dir___225 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___225 *root;
};

struct kernfs_node___225;

struct kernfs_syscall_ops___225;

struct kernfs_root___225 {
	struct kernfs_node___225 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___225 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___225 {
	struct kernfs_node___225 *target_kn;
};

struct kernfs_ops___225;

struct kernfs_elem_attr___225 {
	const struct kernfs_ops___225 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___225 *notify_next;
};

struct kernfs_node___225 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___225 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___225 dir;
		struct kernfs_elem_symlink___225 symlink;
		struct kernfs_elem_attr___225 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___225;

struct kernfs_ops___225 {
	int (*open)(struct kernfs_open_file___225 *);
	void (*release)(struct kernfs_open_file___225 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___225 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___225 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___225 *, struct vm_area_struct___231 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___225 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___225 {
	int (*remount_fs)(struct kernfs_root___225 *, int *, char *);
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___225 *);
	int (*mkdir)(struct kernfs_node___225 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___225 *);
	int (*rename)(struct kernfs_node___225 *, struct kernfs_node___225 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___225 *, struct kernfs_root___225 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___225 {
	struct kernfs_node___225 *kn;
	struct file___14 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___13 *vm_ops;
};

struct vm_area_struct___231 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___231 *vm_next;
	struct vm_area_struct___231 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___230 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___13 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___14 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___218;

struct kobj_type___218;

struct kobject___219 {
	const char *name;
	struct list_head entry;
	struct kobject___219 *parent;
	struct kset___218 *kset;
	struct kobj_type___218 *ktype;
	struct kernfs_node___225 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sysfs_ops___218 {
	ssize_t (*show)(struct kobject___219 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___219 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___218;

struct kset___218 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___219 kobj;
	const struct kset_uevent_ops___218 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___218 {
	void (*release)(struct kobject___219 *);
	const struct sysfs_ops___218 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___12 * (*child_ns_type)(struct kobject___219 *);
	const void * (*namespace)(struct kobject___219 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___218 {
	int (* const filter)(struct kset___218 *, struct kobject___219 *);
	const char * (* const name)(struct kset___218 *, struct kobject___219 *);
	int (* const uevent)(struct kset___218 *, struct kobject___219 *, struct kobj_uevent_env *);
};

struct kernel_param___183;

struct kernel_param_ops___183 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___183 *);
	int (*get)(char *, const struct kernel_param___183 *);
	void (*free)(void *);
};

struct module___186;

struct kparam_array___183;

struct kernel_param___183 {
	const char *name;
	struct module___186 *mod;
	const struct kernel_param_ops___183 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___183 *arr;
	};
};

struct kparam_array___183 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___183 *ops;
	void *elem;
};

struct module_kobject___183 {
	struct kobject___219 kobj;
	struct module___186 *mod;
	struct kobject___219 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___183 {
	struct module___186 *mod;
	struct latch_tree_node node;
};

struct module_layout___183 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___183 mtn;
};

struct module_attribute___183;

struct module___186 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___183 mkobj;
	struct module_attribute___183 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___219 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___183 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___183 core_layout;
	struct module_layout___183 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___183 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___183 *, struct module_kobject___183 *, char *);
	ssize_t (*store)(struct module_attribute___183 *, struct module_kobject___183 *, const char *, size_t);
	void (*setup)(struct module___186 *, const char *);
	int (*test)(struct module___186 *);
	void (*free)(struct module___186 *);
};

struct core_state___230;

struct mm_struct___230 {
	struct {
		struct vm_area_struct___231 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___14 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___231 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___230 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___231 *owner;
		struct user_namespace___3 *user_ns;
		struct file___14 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___230 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct ipc_namespace___7;

struct nsproxy___212 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace___7 *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct ipc_ids___7 {
	int in_use;
	short unsigned int seq;
	struct rw_semaphore___231 rwsem;
	struct idr ipcs_idr;
	int max_idx;
	int last_idx;
	int next_id;
	struct rhashtable key_ht;
};

struct ipc_namespace___7 {
	refcount_t count;
	struct ipc_ids___7 ids[3];
	int sem_ctls[4];
	int used_sems;
	unsigned int msg_ctlmax;
	unsigned int msg_ctlmnb;
	unsigned int msg_ctlmni;
	atomic_t msg_bytes;
	atomic_t msg_hdrs;
	size_t shm_ctlmax;
	size_t shm_ctlall;
	long unsigned int shm_tot;
	int shm_ctlmni;
	int shm_rmid_forced;
	struct notifier_block ipcns_nb;
	struct vfsmount *mq_mnt;
	unsigned int mq_queues_count;
	unsigned int mq_queues_max;
	unsigned int mq_msg_max;
	unsigned int mq_msgsize_max;
	unsigned int mq_msg_default;
	unsigned int mq_msgsize_default;
	struct user_namespace___3 *user_ns;
	struct ucounts___2 *ucounts;
	struct ns_common___27 ns;
};

struct core_thread___230 {
	struct task_struct___231 *task;
	struct core_thread___230 *next;
};

struct core_state___230 {
	atomic_t nr_threads;
	struct core_thread___230 dumper;
	struct completion startup;
};

struct module___187;

struct file___231;

struct kiocb___231;

struct iov_iter___103;

struct poll_table_struct___145;

struct vm_area_struct___232;

struct inode___231;

struct file_lock___231;

struct page___232;

struct pipe_inode_info___47;

struct seq_file___209;

struct file_operations___231 {
	struct module___187 *owner;
	loff_t (*llseek)(struct file___231 *, loff_t, int);
	ssize_t (*read)(struct file___231 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___231 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___231 *, struct iov_iter___103 *);
	ssize_t (*write_iter)(struct kiocb___231 *, struct iov_iter___103 *);
	int (*iopoll)(struct kiocb___231 *, bool);
	int (*iterate)(struct file___231 *, struct dir_context *);
	int (*iterate_shared)(struct file___231 *, struct dir_context *);
	__poll_t (*poll)(struct file___231 *, struct poll_table_struct___145 *);
	long int (*unlocked_ioctl)(struct file___231 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___231 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___231 *, struct vm_area_struct___232 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___231 *, struct file___231 *);
	int (*flush)(struct file___231 *, fl_owner_t);
	int (*release)(struct inode___231 *, struct file___231 *);
	int (*fsync)(struct file___231 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___231 *, int);
	int (*lock)(struct file___231 *, int, struct file_lock___231 *);
	ssize_t (*sendpage)(struct file___231 *, struct page___232 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___231 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___231 *, int, struct file_lock___231 *);
	ssize_t (*splice_write)(struct pipe_inode_info___47 *, struct file___231 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___231 *, loff_t *, struct pipe_inode_info___47 *, size_t, unsigned int);
	int (*setlease)(struct file___231 *, long int, struct file_lock___231 **, void **);
	long int (*fallocate)(struct file___231 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___209 *, struct file___231 *);
	ssize_t (*copy_file_range)(struct file___231 *, loff_t, struct file___231 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___231 *, loff_t, struct file___231 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___231 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___231 {
	u64 seqnum;
	struct vm_area_struct___232 *vmas[4];
};

struct page_frag___231 {
	struct page___232 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___125;

struct debug_info___125 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___125 *hbp_break[16];
	struct perf_event___125 *hbp_watch[16];
};

struct thread_struct___125 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___125 debug;
	long: 64;
};

struct mm_struct___231;

struct mem_cgroup___97;

struct pid___175;

struct cred___224;

struct nsproxy___213;

struct signal_struct___193;

struct bio_list___111;

struct backing_dev_info___111;

struct css_set___179;

struct perf_event_context___125;

struct vm_struct___151;

struct task_struct___232 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___232 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___231 *mm;
	struct mm_struct___231 *active_mm;
	struct vmacache___231 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___232 *real_parent;
	struct task_struct___232 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___232 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___97 *active_memcg;
	long int rh_reserved2;
	struct pid___175 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___175 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___175 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___224 *ptracer_cred;
	const struct cred___224 *real_cred;
	const struct cred___224 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___213 *nsproxy;
	struct signal_struct___193 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___232 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___111 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___111 *backing_dev_info;
	struct io_context___58 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___179 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___125 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___47 *splice_pipe;
	struct page_frag___231 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___97 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___232 *oom_reaper_list;
	struct vm_struct___151 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___125 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___125 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___232 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___125)(struct perf_event___125 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___125;

struct fasync_struct___230;

struct pid_namespace___175;

struct bpf_prog___23;

struct trace_event_call___118;

struct perf_cgroup___125;

struct perf_event___125 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___125 *group_leader;
	struct pmu___125 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___125 hw;
	struct perf_event_context___125 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___125 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___232 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___230 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___125 *);
	struct callback_head callback_head;
	struct pid_namespace___175 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___125 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___125 orig_overflow_handler;
	struct bpf_prog___23 *prog;
	struct trace_event_call___118 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___125 *cgrp;
	struct list_head sb_list;
};

typedef struct page___232 *pgtable_t___231;

struct address_space___230;

struct dev_pagemap___222;

struct page___232 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___230 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___232 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___231 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___231 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___222 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___97 *mem_cgroup;
};

struct pglist_data___231;

struct lruvec___231 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___231 *pgdat;
};

struct zone___231 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___231 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___231 {
	struct zone___231 *zone;
	int zone_idx;
};

struct zonelist___231 {
	struct zoneref___231 _zonerefs[25];
};

struct pglist_data___231 {
	struct zone___231 node_zones[3];
	struct zonelist___231 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___232 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___232 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___231 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___232 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___232 *owner;
};

struct secondary_data___232 {
	void *stack;
	struct task_struct___232 *task;
	long int status;
};

struct blocking_notifier_head___231 {
	struct rw_semaphore___232 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___222;

struct vm_area_struct___232 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___232 *vm_next;
	struct vm_area_struct___232 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___231 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___222 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___231 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___231;

struct user_namespace___193;

struct mm_struct___231 {
	struct {
		struct vm_area_struct___232 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___231 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___232 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___231 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___232 *owner;
		struct user_namespace___193 *user_ns;
		struct file___231 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___231 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___230;

struct address_space___230 {
	struct inode___231 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___232 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___230 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___222)(struct vm_area_struct___232 *, long unsigned int, const struct page___232 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___222)(struct page___232 *, void *);

struct device___198;

struct dev_pagemap___222 {
	dev_page_fault_t___222 page_fault;
	dev_page_free_t___222 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___198 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct cgroup___179;

struct cgroup_subsys___179;

struct cgroup_subsys_state___180 {
	struct cgroup___179 *cgroup;
	struct cgroup_subsys___179 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___180 *parent;
};

struct mem_cgroup_id___21 {
	int id;
	union {
		refcount_t ref;
		struct {
			atomic_t ref;
		} __UNIQUE_ID_rh_kabi_hide58;
		union {		};
	};
};

struct kernfs_node___226;

struct cgroup_file___179 {
	struct kernfs_node___226 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___97;

struct mem_cgroup___97 {
	struct cgroup_subsys_state___180 css;
	struct mem_cgroup_id___21 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___179 events_file;
	struct cgroup_file___179 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___232 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___97 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct vfsmount___59;

struct dentry___231;

struct path___230 {
	struct vfsmount___59 *mnt;
	struct dentry___231 *dentry;
};

struct fown_struct___175 {
	rwlock_t lock;
	struct pid___175 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___231 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___230 f_path;
	struct inode___231 *f_inode;
	const struct file_operations___231 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___175 f_owner;
	const struct cred___224 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___230 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___222;

struct vm_operations_struct___222 {
	void (*open)(struct vm_area_struct___232 *);
	void (*close)(struct vm_area_struct___232 *);
	int (*split)(struct vm_area_struct___232 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___232 *);
	vm_fault_t (*fault)(struct vm_fault___222 *);
	vm_fault_t (*huge_fault)(struct vm_fault___222 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___222 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___232 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___222 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___222 *);
	int (*access)(struct vm_area_struct___232 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___232 *);
	int (*set_policy)(struct vm_area_struct___232 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___232 *, long unsigned int);
	struct page___232 * (*find_special_page)(struct vm_area_struct___232 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___231 {
	struct task_struct___232 *task;
	struct core_thread___231 *next;
};

struct core_state___231 {
	atomic_t nr_threads;
	struct core_thread___231 dumper;
	struct completion startup;
};

struct key___224;

struct ucounts___193;

struct user_namespace___193 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___193 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___27 ns;
	long unsigned int flags;
	struct key___224 *persistent_keyring_register;
	struct rw_semaphore___232 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___193 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___222 {
	struct vm_area_struct___232 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___232 *cow_page;
	struct mem_cgroup___97 *memcg;
	struct page___232 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___231 prealloc_pte;
};

struct shrink_control___97 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___97 *memcg;
};

struct shrinker___97 {
	long unsigned int (*count_objects)(struct shrinker___97 *, struct shrink_control___97 *);
	long unsigned int (*scan_objects)(struct shrinker___97 *, struct shrink_control___97 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct upid___175 {
	int nr;
	struct pid_namespace___175 *ns;
};

struct pid_namespace___175 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___232 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___175 *parent;
	struct vfsmount___59 *proc_mnt;
	struct dentry___231 *proc_self;
	struct dentry___231 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___193 *user_ns;
	struct ucounts___193 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___175 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___175 numbers[1];
};

struct user_struct___224 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___224 *uid_keyring;
	struct key___224 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___224 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___224 *session_keyring;
	struct key___224 *process_keyring;
	struct key___224 *thread_keyring;
	struct key___224 *request_key_auth;
	void *security;
	struct user_struct___224 *user;
	struct user_namespace___193 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct ipc_namespace___8;

struct net___36;

struct cgroup_namespace___179;

struct nsproxy___213 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace___8 *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___175 *pid_ns_for_children;
	struct net___36 *net_ns;
	struct cgroup_namespace___179 *cgroup_ns;
};

struct signal_struct___193 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___232 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___232 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___175 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___175 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___231 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___175 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___111;

struct bio_list___111 {
	struct bio___111 *head;
	struct bio___111 *tail;
};

struct bdi_writeback_congested___111;

struct bdi_writeback___111 {
	struct backing_dev_info___111 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___111 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___180 *memcg_css;
	struct cgroup_subsys_state___180 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___111 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___111 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___198 *dev;
	struct device___198 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___231 *debug_dir;
	struct dentry___231 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___179 {
	struct cgroup_subsys_state___180 *subsys[13];
	refcount_t refcount;
	struct css_set___179 *dom_cset;
	struct cgroup___179 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___179 *mg_src_cgrp;
	struct cgroup___179 *mg_dst_cgrp;
	struct css_set___179 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___125 {
	struct pmu___125 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___232 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___125 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___47;

struct pipe_inode_info___47 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___232 *tmp_page;
	struct fasync_struct___230 *fasync_readers;
	struct fasync_struct___230 *fasync_writers;
	struct pipe_buffer___47 *bufs;
	struct user_struct___224 *user;
};

struct vm_struct___151 {
	struct vm_struct___151 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___232 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___204 {
	struct task_struct___232 task;
	long unsigned int stack[8192];
};

struct kset___219;

struct kobj_type___219;

struct kobject___220 {
	const char *name;
	struct list_head entry;
	struct kobject___220 *parent;
	struct kset___219 *kset;
	struct kobj_type___219 *ktype;
	struct kernfs_node___226 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___198 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___198 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___198;

struct bus_type___198;

struct device_driver___198;

struct dev_pm_domain___198;

struct dma_map_ops___44;

struct fwnode_handle___134;

struct class___198;

struct attribute_group___200;

struct device___198 {
	struct device___198 *parent;
	struct device_private *p;
	struct kobject___220 kobj;
	const char *init_name;
	const struct device_type___198 *type;
	struct mutex mutex;
	struct bus_type___198 *bus;
	struct device_driver___198 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___198 power;
	struct dev_pm_domain___198 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___44 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___134 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___198 *class;
	const struct attribute_group___200 **groups;
	void (*release)(struct device___198 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___230;

struct super_block___230;

struct dentry___231 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___231 *d_parent;
	struct qstr d_name;
	struct inode___231 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___230 *d_op;
	struct super_block___230 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___230;

struct block_device___231;

struct inode___231 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___230 *i_op;
	struct super_block___230 *i_sb;
	struct address_space___230 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___232 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___111 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___231 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___230 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___47 *i_pipe;
		struct block_device___231 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___230 {
	int (*d_revalidate)(struct dentry___231 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___231 *, unsigned int);
	int (*d_hash)(const struct dentry___231 *, struct qstr *);
	int (*d_compare)(const struct dentry___231 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___231 *);
	int (*d_init)(struct dentry___231 *);
	void (*d_release)(struct dentry___231 *);
	void (*d_prune)(struct dentry___231 *);
	void (*d_iput)(struct dentry___231 *, struct inode___231 *);
	char * (*d_dname)(struct dentry___231 *, char *, int);
	struct vfsmount___59 * (*d_automount)(struct path___230 *);
	int (*d_manage)(const struct path___230 *, bool);
	struct dentry___231 * (*d_real)(struct dentry___231 *, const struct inode___231 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___230;

struct mem_dqinfo___230 {
	struct quota_format_type___230 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___230;

struct quota_info___230 {
	unsigned int flags;
	struct rw_semaphore___232 dqio_sem;
	struct inode___231 *files[3];
	struct mem_dqinfo___230 info[3];
	const struct quota_format_ops___230 *ops[3];
};

struct rcuwait___230 {
	struct task_struct___232 *task;
};

struct percpu_rw_semaphore___230 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___232 rw_sem;
	struct rcuwait___230 writer;
	int readers_block;
};

struct sb_writers___230 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___230 rw_sem[3];
};

struct file_system_type___230;

struct super_operations___230;

struct dquot_operations___230;

struct quotactl_ops___230;

struct super_block___230 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___230 *s_type;
	const struct super_operations___230 *s_op;
	const struct dquot_operations___230 *dq_op;
	const struct quotactl_ops___230 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___231 *s_root;
	struct rw_semaphore___232 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___231 *s_bdev;
	struct backing_dev_info___111 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___230 s_dquot;
	struct sb_writers___230 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___230 *s_d_op;
	int cleancache_poolid;
	struct shrinker___97 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___193 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___59 {
	struct dentry___231 *mnt_root;
	struct super_block___230 *mnt_sb;
	int mnt_flags;
};

struct kiocb___231 {
	struct file___231 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___231 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___230 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___231 *ia_file;
};

struct dquot___230 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___230 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___230 {
	int qf_fmt_id;
	const struct quota_format_ops___230 *qf_ops;
	struct module___187 *qf_owner;
	struct quota_format_type___230 *qf_next;
};

struct quota_format_ops___230 {
	int (*check_quota_file)(struct super_block___230 *, int);
	int (*read_file_info)(struct super_block___230 *, int);
	int (*write_file_info)(struct super_block___230 *, int);
	int (*free_file_info)(struct super_block___230 *, int);
	int (*read_dqblk)(struct dquot___230 *);
	int (*commit_dqblk)(struct dquot___230 *);
	int (*release_dqblk)(struct dquot___230 *);
	int (*get_next_id)(struct super_block___230 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___230 {
	int (*write_dquot)(struct dquot___230 *);
	struct dquot___230 * (*alloc_dquot)(struct super_block___230 *, int);
	void (*destroy_dquot)(struct dquot___230 *);
	int (*acquire_dquot)(struct dquot___230 *);
	int (*release_dquot)(struct dquot___230 *);
	int (*mark_dirty)(struct dquot___230 *);
	int (*write_info)(struct super_block___230 *, int);
	qsize_t * (*get_reserved_space)(struct inode___231 *);
	int (*get_projid)(struct inode___231 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___231 *, qsize_t *);
	int (*get_next_id)(struct super_block___230 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___230 {
	int (*quota_on)(struct super_block___230 *, int, int, const struct path___230 *);
	int (*quota_off)(struct super_block___230 *, int);
	int (*quota_enable)(struct super_block___230 *, unsigned int);
	int (*quota_disable)(struct super_block___230 *, unsigned int);
	int (*quota_sync)(struct super_block___230 *, int);
	int (*set_info)(struct super_block___230 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___230 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___230 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___230 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___230 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___230 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___184 {
	struct kobject___220 kobj;
	struct module___187 *mod;
	struct kobject___220 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___184 {
	struct module___187 *mod;
	struct latch_tree_node node;
};

struct module_layout___184 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___184 mtn;
};

struct module_attribute___184;

struct kernel_param___184;

struct module___187 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___184 mkobj;
	struct module_attribute___184 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___220 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___184 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___184 core_layout;
	struct module_layout___184 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___118 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___107;

struct address_space_operations___230 {
	int (*writepage)(struct page___232 *, struct writeback_control___107 *);
	int (*readpage)(struct file___231 *, struct page___232 *);
	int (*writepages)(struct address_space___230 *, struct writeback_control___107 *);
	int (*set_page_dirty)(struct page___232 *);
	int (*readpages)(struct file___231 *, struct address_space___230 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___231 *, struct address_space___230 *, loff_t, unsigned int, unsigned int, struct page___232 **, void **);
	int (*write_end)(struct file___231 *, struct address_space___230 *, loff_t, unsigned int, unsigned int, struct page___232 *, void *);
	sector_t (*bmap)(struct address_space___230 *, sector_t);
	void (*invalidatepage)(struct page___232 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___232 *, gfp_t);
	void (*freepage)(struct page___232 *);
	ssize_t (*direct_IO)(struct kiocb___231 *, struct iov_iter___103 *);
	int (*migratepage)(struct address_space___230 *, struct page___232 *, struct page___232 *, enum migrate_mode);
	bool (*isolate_page)(struct page___232 *, isolate_mode_t);
	void (*putback_page)(struct page___232 *);
	int (*launder_page)(struct page___232 *);
	int (*is_partially_uptodate)(struct page___232 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___232 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___230 *, struct page___232 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___231 *, sector_t *);
	void (*swap_deactivate)(struct file___231 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___107 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___111 *wb;
	struct inode___231 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___111;

struct iov_iter___103 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___111 *bvec;
		struct pipe_inode_info___47 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___231 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___231 *bd_inode;
	struct super_block___230 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___231 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___111 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___230 {
	struct dentry___231 * (*lookup)(struct inode___231 *, struct dentry___231 *, unsigned int);
	const char * (*get_link)(struct dentry___231 *, struct inode___231 *, struct delayed_call *);
	int (*permission)(struct inode___231 *, int);
	struct posix_acl * (*get_acl)(struct inode___231 *, int);
	int (*readlink)(struct dentry___231 *, char *, int);
	int (*create)(struct inode___231 *, struct dentry___231 *, umode_t, bool);
	int (*link)(struct dentry___231 *, struct inode___231 *, struct dentry___231 *);
	int (*unlink)(struct inode___231 *, struct dentry___231 *);
	int (*symlink)(struct inode___231 *, struct dentry___231 *, const char *);
	int (*mkdir)(struct inode___231 *, struct dentry___231 *, umode_t);
	int (*rmdir)(struct inode___231 *, struct dentry___231 *);
	int (*mknod)(struct inode___231 *, struct dentry___231 *, umode_t, dev_t);
	int (*rename)(struct inode___231 *, struct dentry___231 *, struct inode___231 *, struct dentry___231 *, unsigned int);
	int (*setattr)(struct dentry___231 *, struct iattr___230 *);
	int (*getattr)(const struct path___230 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___231 *, char *, size_t);
	int (*fiemap)(struct inode___231 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___231 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___231 *, struct dentry___231 *, struct file___231 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___231 *, struct dentry___231 *, umode_t);
	int (*set_acl)(struct inode___231 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___230 {
	void (*fl_copy_lock)(struct file_lock___231 *, struct file_lock___231 *);
	void (*fl_release_private)(struct file_lock___231 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___230;

struct file_lock___231 {
	struct file_lock___231 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___231 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___230 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___230 *fl_ops;
	const struct lock_manager_operations___230 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___230 {
	int (*lm_compare_owner)(struct file_lock___231 *, struct file_lock___231 *);
	long unsigned int (*lm_owner_key)(struct file_lock___231 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___231 *);
	int (*lm_grant)(struct file_lock___231 *, int);
	bool (*lm_break)(struct file_lock___231 *);
	int (*lm_change)(struct file_lock___231 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___231 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___230 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___230 *fa_next;
	struct file___231 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___230 {
	const char *name;
	int fs_flags;
	struct dentry___231 * (*mount)(struct file_system_type___230 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___230 *);
	struct module___187 *owner;
	struct file_system_type___230 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___230 {
	struct inode___231 * (*alloc_inode)(struct super_block___230 *);
	void (*destroy_inode)(struct inode___231 *);
	void (*dirty_inode)(struct inode___231 *, int);
	int (*write_inode)(struct inode___231 *, struct writeback_control___107 *);
	int (*drop_inode)(struct inode___231 *);
	void (*evict_inode)(struct inode___231 *);
	void (*put_super)(struct super_block___230 *);
	int (*sync_fs)(struct super_block___230 *, int);
	int (*freeze_super)(struct super_block___230 *);
	int (*freeze_fs)(struct super_block___230 *);
	int (*thaw_super)(struct super_block___230 *);
	int (*unfreeze_fs)(struct super_block___230 *);
	int (*statfs)(struct dentry___231 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___230 *, int *, char *);
	void (*umount_begin)(struct super_block___230 *);
	int (*show_options)(struct seq_file___209 *, struct dentry___231 *);
	int (*show_devname)(struct seq_file___209 *, struct dentry___231 *);
	int (*show_path)(struct seq_file___209 *, struct dentry___231 *);
	int (*show_stats)(struct seq_file___209 *, struct dentry___231 *);
	ssize_t (*quota_read)(struct super_block___230 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___230 *, int, const char *, size_t, loff_t);
	struct dquot___230 ** (*get_dquots)(struct inode___231 *);
	int (*bdev_try_to_free_page)(struct super_block___230 *, struct page___232 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___230 *, struct shrink_control___97 *);
	long int (*free_cached_objects)(struct super_block___230 *, struct shrink_control___97 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___147)(struct file___231 *, wait_queue_head_t *, struct poll_table_struct___145 *);

struct poll_table_struct___145 {
	poll_queue_proc___147 _qproc;
	__poll_t _key;
};

struct seq_operations___207;

struct seq_file___209 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___207 *op;
	int poll_event;
	const struct file___231 *file;
	void *private;
};

typedef void bio_end_io_t___111(struct bio___111 *);

struct bio_vec___111 {
	struct page___232 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___111;

struct bio_set___111;

struct bio___111 {
	struct bio___111 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___111 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___111 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___111 *bi_io_vec;
	struct bio_set___111 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___111 bi_inline_vecs[0];
};

struct kobj_attribute___213 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___220 *, struct kobj_attribute___213 *, char *);
	ssize_t (*store)(struct kobject___220 *, struct kobj_attribute___213 *, const char *, size_t);
};

typedef void compound_page_dtor___222(struct page___232 *);

struct fd___28 {
	struct file___231 *file;
	unsigned int flags;
};

typedef struct poll_table_struct___145 poll_table___21;

struct msghdr___13 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___103 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___231 *msg_iocb;
};

struct socket_wq___13 {
	wait_queue_head_t wait;
	struct fasync_struct___230 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct sock___15;

struct proto_ops___13;

struct socket___13 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___13 *wq;
	struct file___231 *file;
	struct sock___15 *sk;
	const struct proto_ops___13 *ops;
};

typedef struct {
	struct net___36 *net;
} possible_net_t___25;

struct proto___13;

struct sock_common___13 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___13 *skc_prot;
	possible_net_t___25 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___15 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___27;

struct sk_buff_head___24 {
	struct sk_buff___27 *next;
	struct sk_buff___27 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___13;

struct dst_entry___14;

struct net_device___28;

struct sock___15 {
	struct sock_common___13 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___24 sk_error_queue;
	struct sk_buff_head___24 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___27 *head;
		struct sk_buff___27 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___13 *sk_filter;
	union {
		struct socket_wq___13 *sk_wq;
		struct socket_wq___13 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___14 *sk_rx_dst;
	struct dst_entry___14 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___27 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___24 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___231 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___13 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___175 *sk_peer_pid;
	const struct cred___224 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___13 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___97 *sk_memcg;
	void (*sk_state_change)(struct sock___15 *);
	void (*sk_data_ready)(struct sock___15 *);
	void (*sk_write_space)(struct sock___15 *);
	void (*sk_error_report)(struct sock___15 *);
	int (*sk_backlog_rcv)(struct sock___15 *, struct sk_buff___27 *);
	struct sk_buff___27 * (*sk_validate_xmit_skb)(struct sock___15 *, struct net_device___28 *, struct sk_buff___27 *);
	void (*sk_destruct)(struct sock___15 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

typedef int (*sk_read_actor_t___13)(read_descriptor_t *, struct sk_buff___27 *, unsigned int, size_t);

struct proto_ops___13 {
	int family;
	struct module___187 *owner;
	int (*release)(struct socket___13 *);
	int (*bind)(struct socket___13 *, struct sockaddr *, int);
	int (*connect)(struct socket___13 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___13 *, struct socket___13 *);
	int (*accept)(struct socket___13 *, struct socket___13 *, int, bool);
	int (*getname)(struct socket___13 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___231 *, struct socket___13 *, struct poll_table_struct___145 *);
	int (*ioctl)(struct socket___13 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___13 *, int);
	int (*shutdown)(struct socket___13 *, int);
	int (*setsockopt)(struct socket___13 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___13 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___13 *, struct msghdr___13 *, size_t);
	int (*recvmsg)(struct socket___13 *, struct msghdr___13 *, size_t, int);
	int (*mmap)(struct file___231 *, struct socket___13 *, struct vm_area_struct___232 *);
	ssize_t (*sendpage)(struct socket___13 *, struct page___232 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___13 *, loff_t *, struct pipe_inode_info___47 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___15 *, int);
	int (*peek_len)(struct socket___13 *);
	int (*read_sock)(struct sock___15 *, read_descriptor_t *, sk_read_actor_t___13);
	int (*sendpage_locked)(struct sock___15 *, struct page___232 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___15 *, struct msghdr___13 *, size_t);
	int (*set_rcvlowat)(struct sock___15 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct nf_bridge_info___24;

struct sk_buff___27 {
	union {
		struct {
			struct sk_buff___27 *next;
			struct sk_buff___27 *prev;
			union {
				struct net_device___28 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___15 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___27 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___24 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___24;

struct netns_frags___24 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___24 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_rules_ops___13;

struct fib_notifier_ops___13;

struct netns_ipv4___24 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___13 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___15 *fibnl;
	struct sock___15 **icmp_sk;
	struct sock___15 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___15 **tcp_sk;
	struct netns_frags___24 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___13 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___13 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___13 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___14;

struct dst_ops___34 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___34 *);
	struct dst_entry___14 * (*check)(struct dst_entry___14 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___14 *);
	unsigned int (*mtu)(const struct dst_entry___14 *);
	u32 * (*cow_metrics)(struct dst_entry___14 *, long unsigned int);
	void (*destroy)(struct dst_entry___14 *);
	void (*ifdown)(struct dst_entry___14 *, struct net_device___28 *, int);
	struct dst_entry___14 * (*negative_advice)(struct dst_entry___14 *);
	void (*link_failure)(struct sk_buff___27 *);
	void (*update_pmtu)(struct dst_entry___14 *, struct sock___15 *, struct sk_buff___27 *, u32);
	void (*redirect)(struct dst_entry___14 *, struct sock___15 *, struct sk_buff___27 *);
	int (*local_out)(struct net___36 *, struct sock___15 *, struct sk_buff___27 *);
	struct neighbour___14 * (*neigh_lookup)(const struct dst_entry___14 *, struct sk_buff___27 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___14 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___34 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___24 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___34 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___13 *fib6_rules_ops;
	struct sock___15 **icmp_sk;
	struct sock___15 *ndisc_sk;
	struct sock___15 *tcp_sk;
	struct sock___15 *igmp_sk;
	struct sock___15 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___13 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___13 *notifier_ops;
	struct fib_notifier_ops___13 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___14 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___15 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___24 {
	struct netns_frags___24 frags;
};

struct netns_xfrm___34 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___15 *nlsk;
	struct sock___15 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___34 xfrm4_dst_ops;
	struct dst_ops___34 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct net___36 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___193 *user_ns;
	struct ucounts___193 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___27 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___15 *rtnl;
	struct sock___15 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___28 *loopback_dev;
	struct netns_core core;
	struct netns_mib___2 mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___24 ipv4;
	struct netns_ipv6___34 ipv6;
	struct netns_sctp___14 sctp;
	struct netns_nf___2 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___24 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___15 *nfnl;
	struct sock___15 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___34 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can___2 can;
	struct sock___15 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___23 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kernfs_root___226;

struct kernfs_elem_dir___226 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___226 *root;
};

struct kernfs_syscall_ops___226;

struct kernfs_root___226 {
	struct kernfs_node___226 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___226 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___226 {
	struct kernfs_node___226 *target_kn;
};

struct kernfs_ops___226;

struct kernfs_elem_attr___226 {
	const struct kernfs_ops___226 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___226 *notify_next;
};

struct kernfs_node___226 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___226 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___226 dir;
		struct kernfs_elem_symlink___226 symlink;
		struct kernfs_elem_attr___226 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___226;

struct kernfs_ops___226 {
	int (*open)(struct kernfs_open_file___226 *);
	void (*release)(struct kernfs_open_file___226 *);
	int (*seq_show)(struct seq_file___209 *, void *);
	void * (*seq_start)(struct seq_file___209 *, loff_t *);
	void * (*seq_next)(struct seq_file___209 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___209 *, void *);
	ssize_t (*read)(struct kernfs_open_file___226 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___226 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___226 *, struct vm_area_struct___232 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___226 *, struct poll_table_struct___145 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___226 {
	int (*remount_fs)(struct kernfs_root___226 *, int *, char *);
	int (*show_options)(struct seq_file___209 *, struct kernfs_root___226 *);
	int (*mkdir)(struct kernfs_node___226 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___226 *);
	int (*rename)(struct kernfs_node___226 *, struct kernfs_node___226 *, const char *);
	int (*show_path)(struct seq_file___209 *, struct kernfs_node___226 *, struct kernfs_root___226 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___226 {
	struct kernfs_node___226 *kn;
	struct file___231 *file;
	struct seq_file___209 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___222 *vm_ops;
};

struct kobj_ns_type_operations___13 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___15 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___199;

struct attribute_group___200 {
	const char *name;
	umode_t (*is_visible)(struct kobject___220 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___220 *, struct bin_attribute___199 *, int);
	struct attribute **attrs;
	struct bin_attribute___199 **bin_attrs;
};

struct bin_attribute___199 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___231 *, struct kobject___220 *, struct bin_attribute___199 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___231 *, struct kobject___220 *, struct bin_attribute___199 *, char *, loff_t, size_t);
	int (*mmap)(struct file___231 *, struct kobject___220 *, struct bin_attribute___199 *, struct vm_area_struct___232 *);
};

struct sysfs_ops___219 {
	ssize_t (*show)(struct kobject___220 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___220 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___219;

struct kset___219 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___220 kobj;
	const struct kset_uevent_ops___219 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___219 {
	void (*release)(struct kobject___220 *);
	const struct sysfs_ops___219 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___13 * (*child_ns_type)(struct kobject___220 *);
	const void * (*namespace)(struct kobject___220 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___219 {
	int (* const filter)(struct kset___219 *, struct kobject___220 *);
	const char * (* const name)(struct kset___219 *, struct kobject___220 *);
	int (* const uevent)(struct kset___219 *, struct kobject___220 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___198 {
	int (*prepare)(struct device___198 *);
	void (*complete)(struct device___198 *);
	int (*suspend)(struct device___198 *);
	int (*resume)(struct device___198 *);
	int (*freeze)(struct device___198 *);
	int (*thaw)(struct device___198 *);
	int (*poweroff)(struct device___198 *);
	int (*restore)(struct device___198 *);
	int (*suspend_late)(struct device___198 *);
	int (*resume_early)(struct device___198 *);
	int (*freeze_late)(struct device___198 *);
	int (*thaw_early)(struct device___198 *);
	int (*poweroff_late)(struct device___198 *);
	int (*restore_early)(struct device___198 *);
	int (*suspend_noirq)(struct device___198 *);
	int (*resume_noirq)(struct device___198 *);
	int (*freeze_noirq)(struct device___198 *);
	int (*thaw_noirq)(struct device___198 *);
	int (*poweroff_noirq)(struct device___198 *);
	int (*restore_noirq)(struct device___198 *);
	int (*runtime_suspend)(struct device___198 *);
	int (*runtime_resume)(struct device___198 *);
	int (*runtime_idle)(struct device___198 *);
};

struct dev_pm_domain___198 {
	struct dev_pm_ops___198 ops;
	void (*detach)(struct device___198 *, bool);
	int (*activate)(struct device___198 *);
	void (*sync)(struct device___198 *);
	void (*dismiss)(struct device___198 *);
};

struct bus_type___198 {
	const char *name;
	const char *dev_name;
	struct device___198 *dev_root;
	const struct attribute_group___200 **bus_groups;
	const struct attribute_group___200 **dev_groups;
	const struct attribute_group___200 **drv_groups;
	int (*match)(struct device___198 *, struct device_driver___198 *);
	int (*uevent)(struct device___198 *, struct kobj_uevent_env *);
	int (*probe)(struct device___198 *);
	int (*remove)(struct device___198 *);
	void (*shutdown)(struct device___198 *);
	int (*online)(struct device___198 *);
	int (*offline)(struct device___198 *);
	int (*suspend)(struct device___198 *, pm_message_t);
	int (*resume)(struct device___198 *);
	int (*num_vf)(struct device___198 *);
	int (*dma_configure)(struct device___198 *);
	const struct dev_pm_ops___198 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___198 {
	const char *name;
	struct bus_type___198 *bus;
	struct module___187 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___198 *);
	int (*remove)(struct device___198 *);
	void (*shutdown)(struct device___198 *);
	int (*suspend)(struct device___198 *, pm_message_t);
	int (*resume)(struct device___198 *);
	const struct attribute_group___200 **groups;
	const struct dev_pm_ops___198 *pm;
	void (*coredump)(struct device___198 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___198 {
	const char *name;
	const struct attribute_group___200 **groups;
	int (*uevent)(struct device___198 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___198 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___198 *);
	const struct dev_pm_ops___198 *pm;
};

struct class___198 {
	const char *name;
	struct module___187 *owner;
	const struct attribute_group___200 **class_groups;
	const struct attribute_group___200 **dev_groups;
	struct kobject___220 *dev_kobj;
	int (*dev_uevent)(struct device___198 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___198 *, umode_t *);
	void (*class_release)(struct class___198 *);
	void (*dev_release)(struct device___198 *);
	int (*shutdown_pre)(struct device___198 *);
	const struct kobj_ns_type_operations___13 *ns_type;
	const void * (*namespace)(struct device___198 *);
	const struct dev_pm_ops___198 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___44 {
	void * (*alloc)(struct device___198 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___198 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___198 *, struct vm_area_struct___232 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___198 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___198 *, struct page___232 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___198 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___198 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___198 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___198 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___198 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___198 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___198 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___198 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___198 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___198 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___198 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___198 *, u64);
	u64 (*get_required_mask)(struct device___198 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___134;

struct fwnode_handle___134 {
	struct fwnode_handle___134 *secondary;
	const struct fwnode_operations___134 *ops;
};

struct fwnode_reference_args___134;

struct fwnode_endpoint___134;

struct fwnode_operations___134 {
	struct fwnode_handle___134 * (*get)(struct fwnode_handle___134 *);
	void (*put)(struct fwnode_handle___134 *);
	bool (*device_is_available)(const struct fwnode_handle___134 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___134 *, const struct device___198 *);
	bool (*property_present)(const struct fwnode_handle___134 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___134 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___134 *, const char *, const char **, size_t);
	struct fwnode_handle___134 * (*get_parent)(const struct fwnode_handle___134 *);
	struct fwnode_handle___134 * (*get_next_child_node)(const struct fwnode_handle___134 *, struct fwnode_handle___134 *);
	struct fwnode_handle___134 * (*get_named_child_node)(const struct fwnode_handle___134 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___134 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___134 *);
	struct fwnode_handle___134 * (*graph_get_next_endpoint)(const struct fwnode_handle___134 *, struct fwnode_handle___134 *);
	struct fwnode_handle___134 * (*graph_get_remote_endpoint)(const struct fwnode_handle___134 *);
	struct fwnode_handle___134 * (*graph_get_port_parent)(struct fwnode_handle___134 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___134 *, struct fwnode_endpoint___134 *);
};

struct fwnode_endpoint___134 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___134 *local_fwnode;
};

struct fwnode_reference_args___134 {
	struct fwnode_handle___134 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___47;

struct pipe_buffer___47 {
	struct page___232 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___47 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___47 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___47 *, struct pipe_buffer___47 *);
	void (*release)(struct pipe_inode_info___47 *, struct pipe_buffer___47 *);
	int (*steal)(struct pipe_inode_info___47 *, struct pipe_buffer___47 *);
	union {
		bool (*get)(struct pipe_inode_info___47 *, struct pipe_buffer___47 *);
		struct {
			void (*get)(struct pipe_inode_info___47 *, struct pipe_buffer___47 *);
		} __UNIQUE_ID_rh_kabi_hide21;
		union {		};
	};
};

struct nf_bridge_info___24 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___24 = 0,
		BRNF_PROTO_8021Q___24 = 1,
		BRNF_PROTO_PPPOE___24 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___28 *physindev;
	struct net_device___28 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___24(struct sk_buff___27 **);

struct net_device_ops___24;

struct ethtool_ops___24;

struct l3mdev_ops___14;

struct xfrmdev_ops___24;

struct tlsdev_ops___24;

struct header_ops___24;

struct netdev_rx_queue___24;

struct mini_Qdisc___23;

struct netdev_queue___24;

struct Qdisc___23;

struct rtnl_link_ops___23;

struct dcbnl_rtnl_ops___24;

struct net_device___28 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___24 *netdev_ops;
	const struct ethtool_ops___24 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___14 *l3mdev_ops;
	const struct ndisc_ops___2 *ndisc_ops;
	const struct xfrmdev_ops___24 *xfrmdev_ops;
	const struct tlsdev_ops___24 *tlsdev_ops;
	const struct header_ops___24 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___219 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___2 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___24 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___23 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___24 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___23 *miniq_ingress;
	struct netdev_queue___24 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___24 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___23 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___23 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___24 = 0,
		NETREG_REGISTERED___24 = 1,
		NETREG_UNREGISTERING___24 = 2,
		NETREG_UNREGISTERED___24 = 3,
		NETREG_RELEASED___24 = 4,
		NETREG_DUMMY___24 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___24 = 0,
		RTNL_LINK_INITIALIZING___24 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___28 *);
	struct netpoll_info *npinfo;
	possible_net_t___25 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___198 dev;
	const struct attribute_group___200 *sysfs_groups[4];
	const struct attribute_group___200 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___23 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___24 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide39;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

typedef int (*key_restrict_link_func_t___224)(struct key___224 *, const struct key_type *, const union key_payload *, struct key___224 *);

struct key_restriction___224;

struct key___224 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___232 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___224 *restrict_link;
};

struct key_restriction___224 {
	key_restrict_link_func_t___224 check;
	struct key___224 *key;
	struct key_type *keytype;
};

struct ipc_ids___8 {
	int in_use;
	short unsigned int seq;
	struct rw_semaphore___232 rwsem;
	struct idr ipcs_idr;
	int max_idx;
	int last_idx;
	int next_id;
	struct rhashtable key_ht;
};

struct ipc_namespace___8 {
	refcount_t count;
	struct ipc_ids___8 ids[3];
	int sem_ctls[4];
	int used_sems;
	unsigned int msg_ctlmax;
	unsigned int msg_ctlmnb;
	unsigned int msg_ctlmni;
	atomic_t msg_bytes;
	atomic_t msg_hdrs;
	size_t shm_ctlmax;
	size_t shm_ctlall;
	long unsigned int shm_tot;
	int shm_ctlmni;
	int shm_rmid_forced;
	struct notifier_block ipcns_nb;
	struct vfsmount___59 *mq_mnt;
	unsigned int mq_queues_count;
	unsigned int mq_queues_max;
	unsigned int mq_msg_max;
	unsigned int mq_msgsize_max;
	unsigned int mq_msg_default;
	unsigned int mq_msgsize_default;
	struct user_namespace___193 *user_ns;
	struct ucounts___193 *ucounts;
	struct ns_common___27 ns;
};

struct cgroup_namespace___179 {
	refcount_t count;
	struct ns_common___27 ns;
	struct user_namespace___193 *user_ns;
	struct ucounts___193 *ucounts;
	struct css_set___179 *root_cset;
};

struct netlink_callback___24 {
	struct sk_buff___27 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___24 *);
	int (*dump)(struct sk_buff___27 *, struct netlink_callback___24 *);
	int (*done)(struct netlink_callback___24 *);
	void *data;
	struct module___187 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct seq_operations___207 {
	void * (*start)(struct seq_file___209 *, loff_t *);
	void (*stop)(struct seq_file___209 *, void *);
	void * (*next)(struct seq_file___209 *, void *, loff_t *);
	int (*show)(struct seq_file___209 *, void *);
};

struct ucounts___193 {
	struct hlist_node node;
	struct user_namespace___193 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct kernel_param_ops___184 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___184 *);
	int (*get)(char *, const struct kernel_param___184 *);
	void (*free)(void *);
};

struct kparam_array___184;

struct kernel_param___184 {
	const char *name;
	struct module___187 *mod;
	const struct kernel_param_ops___184 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___184 *arr;
	};
};

struct kparam_array___184 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___184 *ops;
	void *elem;
};

struct module_attribute___184 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___184 *, struct module_kobject___184 *, char *);
	ssize_t (*store)(struct module_attribute___184 *, struct module_kobject___184 *, const char *, size_t);
	void (*setup)(struct module___187 *, const char *);
	int (*test)(struct module___187 *);
	void (*free)(struct module___187 *);
};

struct trace_event_class___118;

struct bpf_prog_array___23;

struct trace_event_call___118 {
	struct list_head list;
	struct trace_event_class___118 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___23 *prog_array;
	int (*perf_perm)(struct trace_event_call___118 *, struct perf_event___125 *);
};

struct node___165 {
	struct device___198 dev;
};

struct bpf_map___179;

struct bpf_map_ops___179 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___179 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___179 *, struct file___231 *);
	void (*map_free)(struct bpf_map___179 *);
	int (*map_get_next_key)(struct bpf_map___179 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___179 *);
	void * (*map_lookup_elem)(struct bpf_map___179 *, void *);
	int (*map_update_elem)(struct bpf_map___179 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___179 *, void *);
	int (*map_push_elem)(struct bpf_map___179 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___179 *, void *);
	int (*map_peek_elem)(struct bpf_map___179 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___179 *, struct file___231 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___179 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___179 *, void *, struct seq_file___209 *);
	int (*map_check_btf)(const struct bpf_map___179 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___179 {
	const struct bpf_map_ops___179 *ops;
	struct bpf_map___179 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___224 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___24;

struct bpf_map_dev_ops___24 {
	int (*map_get_next_key)(struct bpf_offloaded_map___24 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___24 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___24 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___24 *, void *);
};

struct bpf_offloaded_map___24 {
	struct bpf_map___179 map;
	struct net_device___28 *netdev;
	const struct bpf_map_dev_ops___24 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___23 {
	int (*test_run)(struct bpf_prog___23 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_aux___23;

struct bpf_prog___23 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___23 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

struct bpf_verifier_ops___23 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___23 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___23 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___23 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___23 *, u32 *);
};

struct bpf_prog_offload_ops___23 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___23 *);
	int (*translate)(struct bpf_prog___23 *);
	void (*destroy)(struct bpf_prog___23 *);
};

struct bpf_prog_offload___23 {
	struct bpf_prog___23 *prog;
	struct net_device___28 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___23 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___23 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___23 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___23 *ops;
	struct bpf_map___179 **used_maps;
	struct bpf_prog___23 *prog;
	struct user_struct___224 *user;
	u64 load_time;
	struct bpf_map___179 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___23 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___23 {
	struct bpf_prog___23 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___23 {
	struct callback_head rcu;
	struct bpf_prog_array_item___23 items[0];
};

struct cgroup_bpf___23 {
	struct bpf_prog_array___23 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___23 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___179;

typedef void (*kthread_work_func_t___179)(struct kthread_work___179 *);

struct kthread_worker___179;

struct kthread_work___179 {
	struct list_head node;
	kthread_work_func_t___179 func;
	struct kthread_worker___179 *worker;
	int canceling;
};

struct kthread_worker___179 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___232 *task;
	struct kthread_work___179 *current_work;
};

struct kthread_delayed_work___179 {
	struct kthread_work___179 work;
	struct timer_list timer;
};

struct psi_group___179 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___179 *poll_kworker;
	struct kthread_delayed_work___179 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___179;

struct cgroup_rstat_cpu___179;

struct cgroup___179 {
	struct cgroup_subsys_state___180 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___226 *kn;
	struct cgroup_file___179 procs_file;
	struct cgroup_file___179 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___180 *subsys[13];
	struct cgroup_root___179 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___179 *dom_cgrp;
	struct cgroup_rstat_cpu___179 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___23 bpf;
	atomic_t congestion_count;
	struct cgroup___179 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___179 psi;
	int ancestor_ids[0];
};

struct cftype___179;

struct cgroup_subsys___179 {
	struct cgroup_subsys_state___180 * (*css_alloc)(struct cgroup_subsys_state___180 *);
	int (*css_online)(struct cgroup_subsys_state___180 *);
	void (*css_offline)(struct cgroup_subsys_state___180 *);
	void (*css_released)(struct cgroup_subsys_state___180 *);
	void (*css_free)(struct cgroup_subsys_state___180 *);
	void (*css_reset)(struct cgroup_subsys_state___180 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___180 *, int);
	int (*css_extra_stat_show)(struct seq_file___209 *, struct cgroup_subsys_state___180 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___232 *);
	void (*cancel_fork)(struct task_struct___232 *);
	void (*fork)(struct task_struct___232 *);
	void (*exit)(struct task_struct___232 *);
	void (*free)(struct task_struct___232 *);
	void (*bind)(struct cgroup_subsys_state___180 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___179 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___179 *dfl_cftypes;
	struct cftype___179 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___179 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___179 *updated_children;
	struct cgroup___179 *updated_next;
};

struct cgroup_root___179 {
	struct kernfs_root___226 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___179 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___179 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___179 *ss;
	struct list_head node;
	struct kernfs_ops___226 *kf_ops;
	int (*open)(struct kernfs_open_file___226 *);
	void (*release)(struct kernfs_open_file___226 *);
	u64 (*read_u64)(struct cgroup_subsys_state___180 *, struct cftype___179 *);
	s64 (*read_s64)(struct cgroup_subsys_state___180 *, struct cftype___179 *);
	int (*seq_show)(struct seq_file___209 *, void *);
	void * (*seq_start)(struct seq_file___209 *, loff_t *);
	void * (*seq_next)(struct seq_file___209 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___209 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___180 *, struct cftype___179 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___180 *, struct cftype___179 *, s64);
	ssize_t (*write)(struct kernfs_open_file___226 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___226 *, struct poll_table_struct___145 *);
};

struct perf_cpu_context___125;

struct pmu___125 {
	struct list_head entry;
	struct module___187 *module;
	struct device___198 *dev;
	const struct attribute_group___200 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___125 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___125 *);
	void (*pmu_disable)(struct pmu___125 *);
	int (*event_init)(struct perf_event___125 *);
	void (*event_mapped)(struct perf_event___125 *, struct mm_struct___231 *);
	void (*event_unmapped)(struct perf_event___125 *, struct mm_struct___231 *);
	int (*add)(struct perf_event___125 *, int);
	void (*del)(struct perf_event___125 *, int);
	void (*start)(struct perf_event___125 *, int);
	void (*stop)(struct perf_event___125 *, int);
	void (*read)(struct perf_event___125 *);
	void (*start_txn)(struct pmu___125 *, unsigned int);
	int (*commit_txn)(struct pmu___125 *);
	void (*cancel_txn)(struct pmu___125 *);
	int (*event_idx)(struct perf_event___125 *);
	void (*sched_task)(struct perf_event_context___125 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___125 *);
	int (*filter_match)(struct perf_event___125 *);
	int (*check_period)(struct perf_event___125 *, u64);
};

struct perf_cpu_context___125 {
	struct perf_event_context___125 ctx;
	struct perf_event_context___125 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___125 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___125 {
	struct cgroup_subsys_state___180 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___118 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___118 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___118 *);
	struct list_head * (*get_fields)(struct trace_event_call___118 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___118 *);
};

struct syscall_metadata___61 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___118 *enter_event;
	struct trace_event_call___118 *exit_event;
};

struct ethtool_ops___24 {
	int (*get_settings)(struct net_device___28 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___28 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___28 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___28 *);
	void (*get_regs)(struct net_device___28 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___28 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___28 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___28 *);
	void (*set_msglevel)(struct net_device___28 *, u32);
	int (*nway_reset)(struct net_device___28 *);
	u32 (*get_link)(struct net_device___28 *);
	int (*get_eeprom_len)(struct net_device___28 *);
	int (*get_eeprom)(struct net_device___28 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___28 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___28 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___28 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___28 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___28 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___28 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___28 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___28 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___28 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___28 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___28 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___28 *);
	void (*complete)(struct net_device___28 *);
	u32 (*get_priv_flags)(struct net_device___28 *);
	int (*set_priv_flags)(struct net_device___28 *, u32);
	int (*get_sset_count)(struct net_device___28 *, int);
	int (*get_rxnfc)(struct net_device___28 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___28 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___28 *, struct ethtool_flash *);
	int (*reset)(struct net_device___28 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___28 *);
	u32 (*get_rxfh_indir_size)(struct net_device___28 *);
	int (*get_rxfh)(struct net_device___28 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___28 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___28 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___28 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___28 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___28 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___28 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___28 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___28 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___28 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___28 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___28 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___28 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___28 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___28 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___28 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___28 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___28 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___28 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___28 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___28 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___28 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	int (*get_fecparam)(struct net_device___28 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___28 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___28 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___28 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___28 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___24;

struct inet_frags___24 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___24 *, const void *);
	void (*destructor)(struct inet_frag_queue___24 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___24 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___27 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___27 *fragments_tail;
	struct sk_buff___27 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___24 *net;
	struct callback_head rcu;
};

struct fib_rule___13;

struct fib_lookup_arg___13;

struct fib_rules_ops___13 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___13 *, struct flowi *, int, struct fib_lookup_arg___13 *);
	bool (*suppress)(struct fib_rule___13 *, struct fib_lookup_arg___13 *);
	int (*match)(struct fib_rule___13 *, struct flowi *, int);
	int (*configure)(struct fib_rule___13 *, struct sk_buff___27 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___13 *);
	int (*compare)(struct fib_rule___13 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___13 *, struct sk_buff___27 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___13 *);
	void (*flush_cache)(struct fib_rules_ops___13 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___187 *owner;
	struct net___36 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___13 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___36 *);
	int (*fib_dump)(struct net___36 *, struct notifier_block *);
	struct module___187 *owner;
	struct callback_head rcu;
};

struct dst_entry___14 {
	struct net_device___28 *dev;
	struct dst_ops___34 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___27 *);
	int (*output)(struct net___36 *, struct sock___15 *, struct sk_buff___27 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___13;

struct neigh_parms___14;

struct neigh_ops___13;

struct neighbour___14 {
	struct neighbour___14 *next;
	struct neigh_table___13 *tbl;
	struct neigh_parms___14 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___24 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___14 *, struct sk_buff___27 *);
	const struct neigh_ops___13 *ops;
	struct callback_head rcu;
	struct net_device___28 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct pernet_operations___25 {
	struct list_head list;
	int (*init)(struct net___36 *);
	void (*exit)(struct net___36 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___24 {
	int (*ieee_getets)(struct net_device___28 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___28 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___28 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___28 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___28 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___28 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___28 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___28 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___28 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___28 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___28 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___28 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___28 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___28 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___28 *);
	u8 (*setstate)(struct net_device___28 *, u8);
	void (*getpermhwaddr)(struct net_device___28 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___28 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___28 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___28 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___28 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___28 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___28 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___28 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___28 *, int, u8 *);
	void (*setpfccfg)(struct net_device___28 *, int, u8);
	void (*getpfccfg)(struct net_device___28 *, int, u8 *);
	u8 (*setall)(struct net_device___28 *);
	u8 (*getcap)(struct net_device___28 *, int, u8 *);
	int (*getnumtcs)(struct net_device___28 *, int, u8 *);
	int (*setnumtcs)(struct net_device___28 *, int, u8);
	u8 (*getpfcstate)(struct net_device___28 *);
	void (*setpfcstate)(struct net_device___28 *, u8);
	void (*getbcncfg)(struct net_device___28 *, int, u32 *);
	void (*setbcncfg)(struct net_device___28 *, int, u32);
	void (*getbcnrp)(struct net_device___28 *, int, u8 *);
	void (*setbcnrp)(struct net_device___28 *, int, u8);
	int (*setapp)(struct net_device___28 *, u8, u16, u8);
	int (*getapp)(struct net_device___28 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___28 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___28 *, int, u8);
	u8 (*getdcbx)(struct net_device___28 *);
	u8 (*setdcbx)(struct net_device___28 *, u8);
	int (*peer_getappinfo)(struct net_device___28 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___28 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___28 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___28 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___28 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___28 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct xdp_rxq_info___24 {
	struct net_device___28 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___24 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___28 *dev_rx;
};

struct header_ops___24 {
	int (*create)(struct sk_buff___27 *, struct net_device___28 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___27 *, unsigned char *);
	int (*cache)(const struct neighbour___14 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___28 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___24 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___24 *, int);
	int poll_owner;
	struct net_device___28 *dev;
	struct sk_buff___27 *gro_list;
	struct sk_buff___27 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___24 {
	struct net_device___28 *dev;
	struct Qdisc___23 *qdisc;
	struct Qdisc___23 *qdisc_sleeping;
	struct kobject___220 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___28 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___23 {
	struct sk_buff___27 *head;
	struct sk_buff___27 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___23;

struct Qdisc___23 {
	int (*enqueue)(struct sk_buff___27 *, struct Qdisc___23 *, struct sk_buff___27 **);
	struct sk_buff___27 * (*dequeue)(struct Qdisc___23 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___23 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___24 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___24 gso_skb;
	struct qdisc_skb_head___23 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___23 *next_sched;
	struct sk_buff_head___24 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___24 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___220 kobj;
	struct net_device___28 *dev;
	long: 64;
	struct xdp_rxq_info___24 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___24)(struct net_device___28 *, struct sk_buff___27 *, struct net_device___28 *);

struct netdev_bpf___24 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___23 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___23 *prog;
			const struct bpf_prog_offload_ops___23 *ops;
		} verifier;
		struct {
			struct bpf_prog___23 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___24 *offmap;
		};
		struct {
			struct xdp_umem *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___24 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___27 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___24 {
	int (*tls_dev_add)(struct net_device___28 *, struct sock___15 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___28 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___28 *, struct sock___15 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide35;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___24 {
	int (*ndo_init)(struct net_device___28 *);
	void (*ndo_uninit)(struct net_device___28 *);
	int (*ndo_open)(struct net_device___28 *);
	int (*ndo_stop)(struct net_device___28 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___27 *, struct net_device___28 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___27 *, struct net_device___28 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___28 *, struct sk_buff___27 *, struct net_device___28 *, select_queue_fallback_t___24);
	void (*ndo_change_rx_flags)(struct net_device___28 *, int);
	void (*ndo_set_rx_mode)(struct net_device___28 *);
	int (*ndo_set_mac_address)(struct net_device___28 *, void *);
	int (*ndo_validate_addr)(struct net_device___28 *);
	int (*ndo_do_ioctl)(struct net_device___28 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___28 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___28 *, int);
	int (*ndo_neigh_setup)(struct net_device___28 *, struct neigh_parms___14 *);
	void (*ndo_tx_timeout)(struct net_device___28 *);
	void (*ndo_get_stats64)(struct net_device___28 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___28 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___28 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___28 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___28 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___28 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___28 *);
	int (*ndo_netpoll_setup)(struct net_device___28 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___28 *);
	int (*ndo_set_vf_mac)(struct net_device___28 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___28 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___28 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___28 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___28 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___28 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___28 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___28 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___28 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___28 *, int, struct sk_buff___27 *);
	int (*ndo_set_vf_guid)(struct net_device___28 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___28 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___28 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___28 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___28 *, const struct sk_buff___27 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___28 *, struct net_device___28 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___28 *, struct net_device___28 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___28 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___28 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___28 *, struct neighbour___14 *);
	void (*ndo_neigh_destroy)(struct net_device___28 *, struct neighbour___14 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___28 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___28 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide36;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___28 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___27 *, struct netlink_callback___24 *, struct net_device___28 *, struct net_device___28 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___28 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___28 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide37;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___27 *, u32, u32, struct net_device___28 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___28 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___28 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___28 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___28 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___28 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___28 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___28 *, struct net_device___28 *);
	void (*ndo_dfwd_del_station)(struct net_device___28 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___28 *);
	int (*ndo_set_tx_maxrate)(struct net_device___28 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___28 *);
	int (*ndo_change_proto_down)(struct net_device___28 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___28 *, struct sk_buff___27 *);
	void (*ndo_set_rx_headroom)(struct net_device___28 *, int);
	int (*ndo_bpf)(struct net_device___28 *, struct netdev_bpf___24 *);
	int (*ndo_xdp_xmit)(struct net_device___28 *, int, struct xdp_frame___24 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___28 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___28 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide38;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___14 {
	possible_net_t___25 net;
	struct net_device___28 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___14 *);
	void (*neigh_cleanup)(struct neighbour___14 *);
	struct neigh_table___13 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___14 {
	u32 (*l3mdev_fib_table)(const struct net_device___28 *);
	struct sk_buff___27 * (*l3mdev_l3_rcv)(struct net_device___28 *, struct sk_buff___27 *, u16);
	struct sk_buff___27 * (*l3mdev_l3_out)(struct net_device___28 *, struct sock___15 *, struct sk_buff___27 *, u16);
	struct dst_entry___14 * (*l3mdev_link_scope_lookup)(const struct net_device___28 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct tcf_proto___23;

struct mini_Qdisc___23 {
	struct tcf_proto___23 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___23 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___28 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___36 *, struct net_device___28 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___28 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___28 *, struct list_head *);
	size_t (*get_size)(const struct net_device___28 *);
	int (*fill_info)(struct sk_buff___27 *, const struct net_device___28 *);
	size_t (*get_xstats_size)(const struct net_device___28 *);
	int (*fill_xstats)(struct sk_buff___27 *, const struct net_device___28 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___28 *, struct net_device___28 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___28 *, const struct net_device___28 *);
	int (*fill_slave_info)(struct sk_buff___27 *, const struct net_device___28 *, const struct net_device___28 *);
	struct net___36 * (*get_link_net)(const struct net_device___28 *);
	size_t (*get_linkxstats_size)(const struct net_device___28 *, int);
	int (*fill_linkxstats)(struct sk_buff___27 *, const struct net_device___28 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___24 {
	struct list_head poll_list;
	struct sk_buff_head___24 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___24 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___23 *output_queue;
	struct Qdisc___23 **output_queue_tailp;
	struct sk_buff___27 *completion_queue;
	struct sk_buff_head___24 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___24 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___24 input_pkt_queue;
	struct napi_struct___24 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bdi_writeback_congested___111 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___111 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___111 {
	struct bio___111 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___111 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___111 bip_inline_vecs[0];
};

struct bio_set___111 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___111 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___97 {
	struct mem_cgroup___97 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___97 {
	struct lruvec___231 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___97 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___97 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct gnet_dump___23 {
	spinlock_t *lock;
	struct sk_buff___27 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___23;

struct Qdisc_ops___23 {
	struct Qdisc_ops___23 *next;
	const struct Qdisc_class_ops___23 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___27 *, struct Qdisc___23 *, struct sk_buff___27 **);
	struct sk_buff___27 * (*dequeue)(struct Qdisc___23 *);
	struct sk_buff___27 * (*peek)(struct Qdisc___23 *);
	int (*init)(struct Qdisc___23 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___23 *);
	void (*destroy)(struct Qdisc___23 *);
	int (*change)(struct Qdisc___23 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___23 *);
	int (*change_tx_queue_len)(struct Qdisc___23 *, unsigned int);
	int (*dump)(struct Qdisc___23 *, struct sk_buff___27 *);
	int (*dump_stats)(struct Qdisc___23 *, struct gnet_dump___23 *);
	void (*ingress_block_set)(struct Qdisc___23 *, u32);
	void (*egress_block_set)(struct Qdisc___23 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___23 *);
	u32 (*egress_block_get)(struct Qdisc___23 *);
	struct module___187 *owner;
};

struct tcf_block___23;

struct Qdisc_class_ops___23 {
	unsigned int flags;
	struct netdev_queue___24 * (*select_queue)(struct Qdisc___23 *, struct tcmsg *);
	int (*graft)(struct Qdisc___23 *, long unsigned int, struct Qdisc___23 *, struct Qdisc___23 **, struct netlink_ext_ack *);
	struct Qdisc___23 * (*leaf)(struct Qdisc___23 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___23 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___23 *, u32);
	int (*change)(struct Qdisc___23 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___23 *, long unsigned int);
	void (*walk)(struct Qdisc___23 *, struct qdisc_walker *);
	struct tcf_block___23 * (*tcf_block)(struct Qdisc___23 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___23 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___23 *, long unsigned int);
	int (*dump)(struct Qdisc___23 *, long unsigned int, struct sk_buff___27 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___23 *, long unsigned int, struct gnet_dump___23 *);
};

struct tcf_chain___23;

struct tcf_block___23 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___36 *net;
	struct Qdisc___23 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___23 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___23;

struct tcf_proto_ops___23;

struct tcf_proto___23 {
	struct tcf_proto___23 *next;
	void *root;
	int (*classify)(struct sk_buff___27 *, const struct tcf_proto___23 *, struct tcf_result___23 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___23 *ops;
	struct tcf_chain___23 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___23 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___23 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___23 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___27 *, const struct tcf_proto___23 *, struct tcf_result___23 *);
	int (*init)(struct tcf_proto___23 *);
	void (*destroy)(struct tcf_proto___23 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___23 *, u32);
	void (*put)(struct tcf_proto___23 *, void *);
	int (*change)(struct net___36 *, struct sk_buff___27 *, struct tcf_proto___23 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___23 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___23 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___23 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___36 *, struct tcf_chain___23 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___36 *, struct tcf_proto___23 *, void *, struct sk_buff___27 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___27 *, struct net___36 *, void *);
	struct module___187 *owner;
	int flags;
};

struct tcf_chain___23 {
	struct mutex filter_chain_lock;
	struct tcf_proto___23 *filter_chain;
	struct list_head list;
	struct tcf_block___23 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___23 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___13 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___23 *prog;
};

struct bpf_redirect_info___23 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___179 *map;
	struct bpf_map___179 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___13;

struct neigh_hash_table___13;

struct neigh_table___13 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___28 *, __u32 *);
	bool (*key_eq)(const struct neighbour___14 *, const void *);
	int (*constructor)(struct neighbour___14 *);
	int (*pconstructor)(struct pneigh_entry___13 *);
	void (*pdestructor)(struct pneigh_entry___13 *);
	void (*proxy_redo)(struct sk_buff___27 *);
	char *id;
	struct neigh_parms___14 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___24 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___13 *nht;
	struct pneigh_entry___13 **phash_buckets;
};

struct neigh_ops___13 {
	int family;
	void (*solicit)(struct neighbour___14 *, struct sk_buff___27 *);
	void (*error_report)(struct neighbour___14 *, struct sk_buff___27 *);
	int (*output)(struct neighbour___14 *, struct sk_buff___27 *);
	int (*connected_output)(struct neighbour___14 *, struct sk_buff___27 *);
};

struct pneigh_entry___13 {
	struct pneigh_entry___13 *next;
	possible_net_t___25 net;
	struct net_device___28 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___13 {
	struct neighbour___14 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___13 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___13 *ctarget;
	struct net___36 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___13 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___13 *rule;
	u32 table;
	int flags;
};

struct proto___13 {
	void (*close)(struct sock___15 *, long int);
	int (*pre_connect)(struct sock___15 *, struct sockaddr *, int);
	int (*connect)(struct sock___15 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___15 *, int);
	struct sock___15 * (*accept)(struct sock___15 *, int, int *, bool);
	int (*ioctl)(struct sock___15 *, int, long unsigned int);
	int (*init)(struct sock___15 *);
	void (*destroy)(struct sock___15 *);
	void (*shutdown)(struct sock___15 *, int);
	int (*setsockopt)(struct sock___15 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___15 *, int, int, char *, int *);
	void (*keepalive)(struct sock___15 *, int);
	int (*sendmsg)(struct sock___15 *, struct msghdr___13 *, size_t);
	int (*recvmsg)(struct sock___15 *, struct msghdr___13 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___15 *, struct page___232 *, int, size_t, int);
	int (*bind)(struct sock___15 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___15 *, struct sk_buff___27 *);
	void (*release_cb)(struct sock___15 *);
	int (*hash)(struct sock___15 *);
	void (*unhash)(struct sock___15 *);
	void (*rehash)(struct sock___15 *);
	int (*get_port)(struct sock___15 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___15 *);
	bool (*stream_memory_read)(const struct sock___15 *);
	void (*enter_memory_pressure)(struct sock___15 *);
	void (*leave_memory_pressure)(struct sock___15 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___3 *rsk_prot;
	struct timewait_sock_ops___3 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___187 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___15 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct posix_msg_tree_node {
	struct rb_node rb_node;
	struct list_head msg_list;
	int priority;
};

struct ext_wait_queue {
	struct task_struct___232 *task;
	struct list_head list;
	struct msg_msg *msg;
	int state;
};

struct mqueue_inode_info {
	spinlock_t lock;
	struct inode___231 vfs_inode;
	wait_queue_head_t wait_q;
	struct rb_root msg_tree;
	struct rb_node *msg_tree_rightmost;
	struct posix_msg_tree_node *node_cache;
	struct mq_attr attr;
	struct sigevent notify;
	struct pid___175 *notify_owner;
	struct user_namespace___193 *notify_user_ns;
	struct user_struct___224 *user;
	struct sock___15 *notify_sock;
	struct sk_buff___27 *notify_cookie;
	struct ext_wait_queue e_wait_q[2];
	long unsigned int qsize;
};

struct file___232;

struct kiocb___232;

struct vm_area_struct___233;

struct inode___232;

struct file_lock___232;

struct page___233;

struct file_operations___232 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___232 *, loff_t, int);
	ssize_t (*read)(struct file___232 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___232 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___232 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___232 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___232 *, bool);
	int (*iterate)(struct file___232 *, struct dir_context *);
	int (*iterate_shared)(struct file___232 *, struct dir_context *);
	__poll_t (*poll)(struct file___232 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___232 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___232 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___232 *, struct vm_area_struct___233 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___232 *, struct file___232 *);
	int (*flush)(struct file___232 *, fl_owner_t);
	int (*release)(struct inode___232 *, struct file___232 *);
	int (*fsync)(struct file___232 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___232 *, int);
	int (*lock)(struct file___232 *, int, struct file_lock___232 *);
	ssize_t (*sendpage)(struct file___232 *, struct page___233 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___232 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___232 *, int, struct file_lock___232 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___232 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___232 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___232 *, long int, struct file_lock___232 **, void **);
	long int (*fallocate)(struct file___232 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___232 *);
	ssize_t (*copy_file_range)(struct file___232 *, loff_t, struct file___232 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___232 *, loff_t, struct file___232 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___232 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___232 {
	u64 seqnum;
	struct vm_area_struct___233 *vmas[4];
};

struct page_frag___232 {
	struct page___233 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___232;

struct cred___225;

struct nsproxy___214;

struct task_struct___233 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___233 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___232 *mm;
	struct mm_struct___232 *active_mm;
	struct vmacache___232 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___233 *real_parent;
	struct task_struct___233 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___233 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___175 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___175 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___175 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___225 *ptracer_cred;
	const struct cred___225 *real_cred;
	const struct cred___225 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___214 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___233 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___58 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___232 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___233 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___125 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct proc_ns_operations___28;

struct ns_common___28 {
	atomic_long_t stashed;
	const struct proc_ns_operations___28 *ops;
	unsigned int inum;
};

struct rw_semaphore___233 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___233 *owner;
};

struct key___225;

struct ucounts___194;

struct user_namespace___194 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___194 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___28 ns;
	long unsigned int flags;
	struct key___225 *persistent_keyring_register;
	struct rw_semaphore___233 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___194 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct secondary_data___233 {
	void *stack;
	struct task_struct___233 *task;
	long int status;
};

typedef struct page___233 *pgtable_t___232;

struct address_space___231;

struct page___233 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___231 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___233 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___232 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___232 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___222 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___232;

struct lruvec___232 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___232 *pgdat;
};

struct zone___232 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___232 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___232 {
	struct zone___232 *zone;
	int zone_idx;
};

struct zonelist___232 {
	struct zoneref___232 _zonerefs[25];
};

struct pglist_data___232 {
	struct zone___232 node_zones[3];
	struct zonelist___232 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___233 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___233 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___232 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___232 {
	struct rw_semaphore___233 rwsem;
	struct notifier_block *head;
};

struct user_struct___225 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___225 *uid_keyring;
	struct key___225 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_area_struct___233 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___233 *vm_next;
	struct vm_area_struct___233 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___232 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___13 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___232 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___232;

struct mm_struct___232 {
	struct {
		struct vm_area_struct___233 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___232 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___233 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___232 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___233 *owner;
		struct user_namespace___194 *user_ns;
		struct file___232 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___232 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___225 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___225 *session_keyring;
	struct key___225 *process_keyring;
	struct key___225 *thread_keyring;
	struct key___225 *request_key_auth;
	void *security;
	struct user_struct___225 *user;
	struct user_namespace___194 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct ipc_namespace___9;

struct nsproxy___214 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace___9 *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___2 *cgroup_ns;
};

union thread_union___205 {
	struct task_struct___233 task;
	long unsigned int stack[8192];
};

struct ipc_ids___9 {
	int in_use;
	short unsigned int seq;
	struct rw_semaphore___233 rwsem;
	struct idr ipcs_idr;
	int max_idx;
	int last_idx;
	int next_id;
	struct rhashtable key_ht;
};

struct vfsmount___60;

struct ipc_namespace___9 {
	refcount_t count;
	struct ipc_ids___9 ids[3];
	int sem_ctls[4];
	int used_sems;
	unsigned int msg_ctlmax;
	unsigned int msg_ctlmnb;
	unsigned int msg_ctlmni;
	atomic_t msg_bytes;
	atomic_t msg_hdrs;
	size_t shm_ctlmax;
	size_t shm_ctlall;
	long unsigned int shm_tot;
	int shm_ctlmni;
	int shm_rmid_forced;
	struct notifier_block ipcns_nb;
	struct vfsmount___60 *mq_mnt;
	unsigned int mq_queues_count;
	unsigned int mq_queues_max;
	unsigned int mq_msg_max;
	unsigned int mq_msgsize_max;
	unsigned int mq_msg_default;
	unsigned int mq_msgsize_default;
	struct user_namespace___194 *user_ns;
	struct ucounts___194 *ucounts;
	struct ns_common___28 ns;
};

struct proc_ns_operations___28 {
	const char *name;
	const char *real_ns_name;
	int type;
	struct ns_common___28 * (*get)(struct task_struct___233 *);
	void (*put)(struct ns_common___28 *);
	int (*install)(struct nsproxy___214 *, struct ns_common___28 *);
	struct user_namespace___194 * (*owner)(struct ns_common___28 *);
	struct ns_common___28 * (*get_parent)(struct ns_common___28 *);
};

struct dentry___232;

struct super_block___231;

struct vfsmount___60 {
	struct dentry___232 *mnt_root;
	struct super_block___231 *mnt_sb;
	int mnt_flags;
};

struct ucounts___194 {
	struct hlist_node node;
	struct user_namespace___194 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

typedef int (*key_restrict_link_func_t___225)(struct key___225 *, const struct key_type *, const union key_payload *, struct key___225 *);

struct key_restriction___225;

struct key___225 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___233 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___225 *restrict_link;
};

struct key_restriction___225 {
	key_restrict_link_func_t___225 check;
	struct key___225 *key;
	struct key_type *keytype;
};

struct dentry_operations___231;

struct dentry___232 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___232 *d_parent;
	struct qstr d_name;
	struct inode___232 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___231 *d_op;
	struct super_block___231 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___231;

struct address_space___231 {
	struct inode___232 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___233 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___231 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___231;

struct block_device___232;

struct inode___232 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___231 *i_op;
	struct super_block___231 *i_sb;
	struct address_space___231 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___233 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___232 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___231 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___232 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___231;

struct dentry_operations___231 {
	int (*d_revalidate)(struct dentry___232 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___232 *, unsigned int);
	int (*d_hash)(const struct dentry___232 *, struct qstr *);
	int (*d_compare)(const struct dentry___232 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___232 *);
	int (*d_init)(struct dentry___232 *);
	void (*d_release)(struct dentry___232 *);
	void (*d_prune)(struct dentry___232 *);
	void (*d_iput)(struct dentry___232 *, struct inode___232 *);
	char * (*d_dname)(struct dentry___232 *, char *, int);
	struct vfsmount___60 * (*d_automount)(struct path___231 *);
	int (*d_manage)(const struct path___231 *, bool);
	struct dentry___232 * (*d_real)(struct dentry___232 *, const struct inode___232 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___231;

struct mem_dqinfo___231 {
	struct quota_format_type___231 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___231;

struct quota_info___231 {
	unsigned int flags;
	struct rw_semaphore___233 dqio_sem;
	struct inode___232 *files[3];
	struct mem_dqinfo___231 info[3];
	const struct quota_format_ops___231 *ops[3];
};

struct rcuwait___231 {
	struct task_struct___233 *task;
};

struct percpu_rw_semaphore___231 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___233 rw_sem;
	struct rcuwait___231 writer;
	int readers_block;
};

struct sb_writers___231 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___231 rw_sem[3];
};

struct file_system_type___231;

struct super_operations___231;

struct dquot_operations___231;

struct quotactl_ops___231;

struct super_block___231 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___231 *s_type;
	const struct super_operations___231 *s_op;
	const struct dquot_operations___231 *dq_op;
	const struct quotactl_ops___231 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___232 *s_root;
	struct rw_semaphore___233 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___232 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___231 s_dquot;
	struct sb_writers___231 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___231 *s_d_op;
	int cleancache_poolid;
	struct shrinker___97 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___194 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct path___231 {
	struct vfsmount___60 *mnt;
	struct dentry___232 *dentry;
};

struct file___232 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___231 f_path;
	struct inode___232 *f_inode;
	const struct file_operations___232 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___175 f_owner;
	const struct cred___225 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___231 *f_mapping;
	errseq_t f_wb_err;
};

struct core_thread___232 {
	struct task_struct___233 *task;
	struct core_thread___232 *next;
};

struct core_state___232 {
	atomic_t nr_threads;
	struct core_thread___232 dumper;
	struct completion startup;
};

struct kiocb___232 {
	struct file___232 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___232 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___231 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___232 *ia_file;
};

struct dquot___231 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___231 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___231 {
	int qf_fmt_id;
	const struct quota_format_ops___231 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___231 *qf_next;
};

struct quota_format_ops___231 {
	int (*check_quota_file)(struct super_block___231 *, int);
	int (*read_file_info)(struct super_block___231 *, int);
	int (*write_file_info)(struct super_block___231 *, int);
	int (*free_file_info)(struct super_block___231 *, int);
	int (*read_dqblk)(struct dquot___231 *);
	int (*commit_dqblk)(struct dquot___231 *);
	int (*release_dqblk)(struct dquot___231 *);
	int (*get_next_id)(struct super_block___231 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___231 {
	int (*write_dquot)(struct dquot___231 *);
	struct dquot___231 * (*alloc_dquot)(struct super_block___231 *, int);
	void (*destroy_dquot)(struct dquot___231 *);
	int (*acquire_dquot)(struct dquot___231 *);
	int (*release_dquot)(struct dquot___231 *);
	int (*mark_dirty)(struct dquot___231 *);
	int (*write_info)(struct super_block___231 *, int);
	qsize_t * (*get_reserved_space)(struct inode___232 *);
	int (*get_projid)(struct inode___232 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___232 *, qsize_t *);
	int (*get_next_id)(struct super_block___231 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___231 {
	int (*quota_on)(struct super_block___231 *, int, int, const struct path___231 *);
	int (*quota_off)(struct super_block___231 *, int);
	int (*quota_enable)(struct super_block___231 *, unsigned int);
	int (*quota_disable)(struct super_block___231 *, unsigned int);
	int (*quota_sync)(struct super_block___231 *, int);
	int (*set_info)(struct super_block___231 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___231 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___231 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___231 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___231 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___231 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___231 {
	int (*writepage)(struct page___233 *, struct writeback_control___3 *);
	int (*readpage)(struct file___232 *, struct page___233 *);
	int (*writepages)(struct address_space___231 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___233 *);
	int (*readpages)(struct file___232 *, struct address_space___231 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___232 *, struct address_space___231 *, loff_t, unsigned int, unsigned int, struct page___233 **, void **);
	int (*write_end)(struct file___232 *, struct address_space___231 *, loff_t, unsigned int, unsigned int, struct page___233 *, void *);
	sector_t (*bmap)(struct address_space___231 *, sector_t);
	void (*invalidatepage)(struct page___233 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___233 *, gfp_t);
	void (*freepage)(struct page___233 *);
	ssize_t (*direct_IO)(struct kiocb___232 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___231 *, struct page___233 *, struct page___233 *, enum migrate_mode);
	bool (*isolate_page)(struct page___233 *, isolate_mode_t);
	void (*putback_page)(struct page___233 *);
	int (*launder_page)(struct page___233 *);
	int (*is_partially_uptodate)(struct page___233 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___233 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___231 *, struct page___233 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___232 *, sector_t *);
	void (*swap_deactivate)(struct file___232 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___232 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___232 *bd_inode;
	struct super_block___231 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___232 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___231 {
	struct dentry___232 * (*lookup)(struct inode___232 *, struct dentry___232 *, unsigned int);
	const char * (*get_link)(struct dentry___232 *, struct inode___232 *, struct delayed_call *);
	int (*permission)(struct inode___232 *, int);
	struct posix_acl * (*get_acl)(struct inode___232 *, int);
	int (*readlink)(struct dentry___232 *, char *, int);
	int (*create)(struct inode___232 *, struct dentry___232 *, umode_t, bool);
	int (*link)(struct dentry___232 *, struct inode___232 *, struct dentry___232 *);
	int (*unlink)(struct inode___232 *, struct dentry___232 *);
	int (*symlink)(struct inode___232 *, struct dentry___232 *, const char *);
	int (*mkdir)(struct inode___232 *, struct dentry___232 *, umode_t);
	int (*rmdir)(struct inode___232 *, struct dentry___232 *);
	int (*mknod)(struct inode___232 *, struct dentry___232 *, umode_t, dev_t);
	int (*rename)(struct inode___232 *, struct dentry___232 *, struct inode___232 *, struct dentry___232 *, unsigned int);
	int (*setattr)(struct dentry___232 *, struct iattr___231 *);
	int (*getattr)(const struct path___231 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___232 *, char *, size_t);
	int (*fiemap)(struct inode___232 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___232 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___232 *, struct dentry___232 *, struct file___232 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___232 *, struct dentry___232 *, umode_t);
	int (*set_acl)(struct inode___232 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___231 {
	void (*fl_copy_lock)(struct file_lock___232 *, struct file_lock___232 *);
	void (*fl_release_private)(struct file_lock___232 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___231;

struct lock_manager_operations___231;

struct file_lock___232 {
	struct file_lock___232 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___232 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___231 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___231 *fl_ops;
	const struct lock_manager_operations___231 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___231 {
	int (*lm_compare_owner)(struct file_lock___232 *, struct file_lock___232 *);
	long unsigned int (*lm_owner_key)(struct file_lock___232 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___232 *);
	int (*lm_grant)(struct file_lock___232 *, int);
	bool (*lm_break)(struct file_lock___232 *);
	int (*lm_change)(struct file_lock___232 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___232 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___231 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___231 *fa_next;
	struct file___232 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___231 {
	const char *name;
	int fs_flags;
	struct dentry___232 * (*mount)(struct file_system_type___231 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___231 *);
	struct module___11 *owner;
	struct file_system_type___231 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___231 {
	struct inode___232 * (*alloc_inode)(struct super_block___231 *);
	void (*destroy_inode)(struct inode___232 *);
	void (*dirty_inode)(struct inode___232 *, int);
	int (*write_inode)(struct inode___232 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___232 *);
	void (*evict_inode)(struct inode___232 *);
	void (*put_super)(struct super_block___231 *);
	int (*sync_fs)(struct super_block___231 *, int);
	int (*freeze_super)(struct super_block___231 *);
	int (*freeze_fs)(struct super_block___231 *);
	int (*thaw_super)(struct super_block___231 *);
	int (*unfreeze_fs)(struct super_block___231 *);
	int (*statfs)(struct dentry___232 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___231 *, int *, char *);
	void (*umount_begin)(struct super_block___231 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___232 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___232 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___232 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___232 *);
	ssize_t (*quota_read)(struct super_block___231 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___231 *, int, const char *, size_t, loff_t);
	struct dquot___231 ** (*get_dquots)(struct inode___232 *);
	int (*bdev_try_to_free_page)(struct super_block___231 *, struct page___233 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___231 *, struct shrink_control___97 *);
	long int (*free_cached_objects)(struct super_block___231 *, struct shrink_control___97 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module___188;

struct file___233;

struct kiocb___233;

struct vm_area_struct___234;

struct inode___233;

struct file_lock___233;

struct page___234;

struct file_operations___233 {
	struct module___188 *owner;
	loff_t (*llseek)(struct file___233 *, loff_t, int);
	ssize_t (*read)(struct file___233 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___233 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___233 *, struct iov_iter___103 *);
	ssize_t (*write_iter)(struct kiocb___233 *, struct iov_iter___103 *);
	int (*iopoll)(struct kiocb___233 *, bool);
	int (*iterate)(struct file___233 *, struct dir_context *);
	int (*iterate_shared)(struct file___233 *, struct dir_context *);
	__poll_t (*poll)(struct file___233 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___233 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___233 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___233 *, struct vm_area_struct___234 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___233 *, struct file___233 *);
	int (*flush)(struct file___233 *, fl_owner_t);
	int (*release)(struct inode___233 *, struct file___233 *);
	int (*fsync)(struct file___233 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___233 *, int);
	int (*lock)(struct file___233 *, int, struct file_lock___233 *);
	ssize_t (*sendpage)(struct file___233 *, struct page___234 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___233 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___233 *, int, struct file_lock___233 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___233 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___233 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___233 *, long int, struct file_lock___233 **, void **);
	long int (*fallocate)(struct file___233 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___233 *);
	ssize_t (*copy_file_range)(struct file___233 *, loff_t, struct file___233 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___233 *, loff_t, struct file___233 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___233 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___233 {
	u64 seqnum;
	struct vm_area_struct___234 *vmas[4];
};

struct page_frag___233 {
	struct page___234 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___233;

struct cred___226;

struct task_struct___234 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___234 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___233 *mm;
	struct mm_struct___233 *active_mm;
	struct vmacache___233 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___234 *real_parent;
	struct task_struct___234 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___234 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___175 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___175 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___175 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___226 *ptracer_cred;
	const struct cred___226 *real_cred;
	const struct cred___226 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___234 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___58 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___233 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___234 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___125 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___234 *pgtable_t___233;

struct address_space___232;

struct dev_pagemap___223;

struct page___234 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___232 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___234 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___233 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___233 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___223 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___233;

struct lruvec___233 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___233 *pgdat;
};

struct zone___233 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___233 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___233 {
	struct zone___233 *zone;
	int zone_idx;
};

struct zonelist___233 {
	struct zoneref___233 _zonerefs[25];
};

struct pglist_data___233 {
	struct zone___233 node_zones[3];
	struct zonelist___233 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___234 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___234 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___233 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___234 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___234 *owner;
};

struct secondary_data___234 {
	void *stack;
	struct task_struct___234 *task;
	long int status;
};

struct blocking_notifier_head___233 {
	struct rw_semaphore___234 rwsem;
	struct notifier_block *head;
};

struct dentry___233;

struct path___232 {
	struct vfsmount *mnt;
	struct dentry___233 *dentry;
};

struct file___233 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___232 f_path;
	struct inode___233 *f_inode;
	const struct file_operations___233 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___175 f_owner;
	const struct cred___226 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___232 *f_mapping;
	errseq_t f_wb_err;
};

struct key___226;

struct user_struct___226;

struct cred___226 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___226 *session_keyring;
	struct key___226 *process_keyring;
	struct key___226 *thread_keyring;
	struct key___226 *request_key_auth;
	void *security;
	struct user_struct___226 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___227;

struct kernfs_elem_dir___227 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___227 *root;
};

struct kernfs_node___227;

struct kernfs_syscall_ops___227;

struct kernfs_root___227 {
	struct kernfs_node___227 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___227 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___227 {
	struct kernfs_node___227 *target_kn;
};

struct kernfs_ops___227;

struct kernfs_elem_attr___227 {
	const struct kernfs_ops___227 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___227 *notify_next;
};

struct kernfs_node___227 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___227 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___227 dir;
		struct kernfs_elem_symlink___227 symlink;
		struct kernfs_elem_attr___227 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___227;

struct kernfs_ops___227 {
	int (*open)(struct kernfs_open_file___227 *);
	void (*release)(struct kernfs_open_file___227 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___227 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___227 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___227 *, struct vm_area_struct___234 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___227 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___227 {
	int (*remount_fs)(struct kernfs_root___227 *, int *, char *);
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___227 *);
	int (*mkdir)(struct kernfs_node___227 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___227 *);
	int (*rename)(struct kernfs_node___227 *, struct kernfs_node___227 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___227 *, struct kernfs_root___227 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_operations_struct___223;

struct kernfs_open_file___227 {
	struct kernfs_node___227 *kn;
	struct file___233 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___223 *vm_ops;
};

struct vm_fault___223;

struct vm_operations_struct___223 {
	void (*open)(struct vm_area_struct___234 *);
	void (*close)(struct vm_area_struct___234 *);
	int (*split)(struct vm_area_struct___234 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___234 *);
	vm_fault_t (*fault)(struct vm_fault___223 *);
	vm_fault_t (*huge_fault)(struct vm_fault___223 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___223 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___234 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___223 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___223 *);
	int (*access)(struct vm_area_struct___234 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___234 *);
	int (*set_policy)(struct vm_area_struct___234 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___234 *, long unsigned int);
	struct page___234 * (*find_special_page)(struct vm_area_struct___234 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_area_struct___234 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___234 *vm_next;
	struct vm_area_struct___234 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___233 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___223 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___233 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___220;

struct kobj_type___220;

struct kobject___221 {
	const char *name;
	struct list_head entry;
	struct kobject___221 *parent;
	struct kset___220 *kset;
	struct kobj_type___220 *ktype;
	struct kernfs_node___227 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sysfs_ops___220 {
	ssize_t (*show)(struct kobject___221 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___221 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___220;

struct kset___220 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___221 kobj;
	const struct kset_uevent_ops___220 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___220 {
	void (*release)(struct kobject___221 *);
	const struct sysfs_ops___220 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___13 * (*child_ns_type)(struct kobject___221 *);
	const void * (*namespace)(struct kobject___221 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___220 {
	int (* const filter)(struct kset___220 *, struct kobject___221 *);
	const char * (* const name)(struct kset___220 *, struct kobject___221 *);
	int (* const uevent)(struct kset___220 *, struct kobject___221 *, struct kobj_uevent_env *);
};

struct kobj_attribute___214 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___221 *, struct kobj_attribute___214 *, char *);
	ssize_t (*store)(struct kobject___221 *, struct kobj_attribute___214 *, const char *, size_t);
};

struct kernel_param___185;

struct kernel_param_ops___185 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___185 *);
	int (*get)(char *, const struct kernel_param___185 *);
	void (*free)(void *);
};

struct kparam_array___185;

struct kernel_param___185 {
	const char *name;
	struct module___188 *mod;
	const struct kernel_param_ops___185 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___185 *arr;
	};
};

struct kparam_array___185 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___185 *ops;
	void *elem;
};

struct module_kobject___185 {
	struct kobject___221 kobj;
	struct module___188 *mod;
	struct kobject___221 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___185 {
	struct module___188 *mod;
	struct latch_tree_node node;
};

struct module_layout___185 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___185 mtn;
};

struct module_attribute___185;

struct module___188 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___185 mkobj;
	struct module_attribute___185 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___221 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___185 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___185 core_layout;
	struct module_layout___185 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___185 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___185 *, struct module_kobject___185 *, char *);
	ssize_t (*store)(struct module_attribute___185 *, struct module_kobject___185 *, const char *, size_t);
	void (*setup)(struct module___188 *, const char *);
	int (*test)(struct module___188 *);
	void (*free)(struct module___188 *);
};

struct key_type___2;

struct keyring_index_key___2 {
	struct key_type___2 *type;
	const char *description;
	size_t desc_len;
};

struct key_construction___2;

typedef int (*request_key_actor_t___2)(struct key_construction___2 *, const char *, void *);

struct key_match_data___2;

struct key_restriction___226;

struct key_type___2 {
	const char *name;
	size_t def_datalen;
	int (*vet_description)(const char *);
	int (*preparse)(struct key_preparsed_payload *);
	void (*free_preparse)(struct key_preparsed_payload *);
	int (*instantiate)(struct key___226 *, struct key_preparsed_payload *);
	int (*update)(struct key___226 *, struct key_preparsed_payload *);
	int (*match_preparse)(struct key_match_data___2 *);
	void (*match_free)(struct key_match_data___2 *);
	void (*revoke)(struct key___226 *);
	void (*destroy)(struct key___226 *);
	void (*describe)(const struct key___226 *, struct seq_file___9 *);
	long int (*read)(const struct key___226 *, char *, size_t);
	request_key_actor_t___2 request_key;
	struct key_restriction___226 * (*lookup_restriction)(const char *);
	struct list_head link;
	struct lock_class_key lock_class;
};

typedef int (*key_restrict_link_func_t___226)(struct key___226 *, const struct key_type___2 *, const union key_payload *, struct key___226 *);

struct key___226 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___234 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key___2 index_key;
		struct {
			struct key_type___2 *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___226 *restrict_link;
};

struct key_restriction___226 {
	key_restrict_link_func_t___226 check;
	struct key___226 *key;
	struct key_type___2 *keytype;
};

enum key_state {
	KEY_IS_UNINSTANTIATED = 0,
	KEY_IS_POSITIVE = 1,
};

struct key_user {
	struct rb_node node;
	struct mutex cons_lock;
	spinlock_t lock;
	refcount_t usage;
	atomic_t nkeys;
	atomic_t nikeys;
	kuid_t uid;
	int qnkeys;
	int qnbytes;
};

struct dentry_operations___232;

struct super_block___232;

struct dentry___233 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___233 *d_parent;
	struct qstr d_name;
	struct inode___233 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___232 *d_op;
	struct super_block___232 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___232;

struct address_space___232 {
	struct inode___233 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___234 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___232 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___232;

struct block_device___233;

struct inode___233 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___232 *i_op;
	struct super_block___232 *i_sb;
	struct address_space___232 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___234 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___233 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___232 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___233 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___232 {
	int (*d_revalidate)(struct dentry___233 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___233 *, unsigned int);
	int (*d_hash)(const struct dentry___233 *, struct qstr *);
	int (*d_compare)(const struct dentry___233 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___233 *);
	int (*d_init)(struct dentry___233 *);
	void (*d_release)(struct dentry___233 *);
	void (*d_prune)(struct dentry___233 *);
	void (*d_iput)(struct dentry___233 *, struct inode___233 *);
	char * (*d_dname)(struct dentry___233 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___232 *);
	int (*d_manage)(const struct path___232 *, bool);
	struct dentry___233 * (*d_real)(struct dentry___233 *, const struct inode___233 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___232;

struct mem_dqinfo___232 {
	struct quota_format_type___232 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___232;

struct quota_info___232 {
	unsigned int flags;
	struct rw_semaphore___234 dqio_sem;
	struct inode___233 *files[3];
	struct mem_dqinfo___232 info[3];
	const struct quota_format_ops___232 *ops[3];
};

struct rcuwait___232 {
	struct task_struct___234 *task;
};

struct percpu_rw_semaphore___232 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___234 rw_sem;
	struct rcuwait___232 writer;
	int readers_block;
};

struct sb_writers___232 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___232 rw_sem[3];
};

struct file_system_type___232;

struct super_operations___232;

struct dquot_operations___232;

struct quotactl_ops___232;

struct super_block___232 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___232 *s_type;
	const struct super_operations___232 *s_op;
	const struct dquot_operations___232 *dq_op;
	const struct quotactl_ops___232 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___233 *s_root;
	struct rw_semaphore___234 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___233 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___232 s_dquot;
	struct sb_writers___232 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___232 *s_d_op;
	int cleancache_poolid;
	struct shrinker___97 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct core_state___233;

struct mm_struct___233 {
	struct {
		struct vm_area_struct___234 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___233 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___234 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___233 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___234 *owner;
		struct user_namespace___3 *user_ns;
		struct file___233 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___233 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___223)(struct vm_area_struct___234 *, long unsigned int, const struct page___234 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___223)(struct page___234 *, void *);

struct dev_pagemap___223 {
	dev_page_fault_t___223 page_fault;
	dev_page_free_t___223 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___6 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___233 {
	struct task_struct___234 *task;
	struct core_thread___233 *next;
};

struct core_state___233 {
	atomic_t nr_threads;
	struct core_thread___233 dumper;
	struct completion startup;
};

struct vm_fault___223 {
	struct vm_area_struct___234 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___234 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___234 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___233 prealloc_pte;
};

struct user_struct___226 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___226 *uid_keyring;
	struct key___226 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct kiocb___233 {
	struct file___233 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___233 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___232 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___233 *ia_file;
};

struct dquot___232 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___232 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___232 {
	int qf_fmt_id;
	const struct quota_format_ops___232 *qf_ops;
	struct module___188 *qf_owner;
	struct quota_format_type___232 *qf_next;
};

struct quota_format_ops___232 {
	int (*check_quota_file)(struct super_block___232 *, int);
	int (*read_file_info)(struct super_block___232 *, int);
	int (*write_file_info)(struct super_block___232 *, int);
	int (*free_file_info)(struct super_block___232 *, int);
	int (*read_dqblk)(struct dquot___232 *);
	int (*commit_dqblk)(struct dquot___232 *);
	int (*release_dqblk)(struct dquot___232 *);
	int (*get_next_id)(struct super_block___232 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___232 {
	int (*write_dquot)(struct dquot___232 *);
	struct dquot___232 * (*alloc_dquot)(struct super_block___232 *, int);
	void (*destroy_dquot)(struct dquot___232 *);
	int (*acquire_dquot)(struct dquot___232 *);
	int (*release_dquot)(struct dquot___232 *);
	int (*mark_dirty)(struct dquot___232 *);
	int (*write_info)(struct super_block___232 *, int);
	qsize_t * (*get_reserved_space)(struct inode___233 *);
	int (*get_projid)(struct inode___233 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___233 *, qsize_t *);
	int (*get_next_id)(struct super_block___232 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___232 {
	int (*quota_on)(struct super_block___232 *, int, int, const struct path___232 *);
	int (*quota_off)(struct super_block___232 *, int);
	int (*quota_enable)(struct super_block___232 *, unsigned int);
	int (*quota_disable)(struct super_block___232 *, unsigned int);
	int (*quota_sync)(struct super_block___232 *, int);
	int (*set_info)(struct super_block___232 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___232 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___232 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___232 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___232 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___232 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___232 {
	int (*writepage)(struct page___234 *, struct writeback_control___3 *);
	int (*readpage)(struct file___233 *, struct page___234 *);
	int (*writepages)(struct address_space___232 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___234 *);
	int (*readpages)(struct file___233 *, struct address_space___232 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___233 *, struct address_space___232 *, loff_t, unsigned int, unsigned int, struct page___234 **, void **);
	int (*write_end)(struct file___233 *, struct address_space___232 *, loff_t, unsigned int, unsigned int, struct page___234 *, void *);
	sector_t (*bmap)(struct address_space___232 *, sector_t);
	void (*invalidatepage)(struct page___234 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___234 *, gfp_t);
	void (*freepage)(struct page___234 *);
	ssize_t (*direct_IO)(struct kiocb___233 *, struct iov_iter___103 *);
	int (*migratepage)(struct address_space___232 *, struct page___234 *, struct page___234 *, enum migrate_mode);
	bool (*isolate_page)(struct page___234 *, isolate_mode_t);
	void (*putback_page)(struct page___234 *);
	int (*launder_page)(struct page___234 *);
	int (*is_partially_uptodate)(struct page___234 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___234 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___232 *, struct page___234 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___233 *, sector_t *);
	void (*swap_deactivate)(struct file___233 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___233 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___233 *bd_inode;
	struct super_block___232 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___233 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___232 {
	struct dentry___233 * (*lookup)(struct inode___233 *, struct dentry___233 *, unsigned int);
	const char * (*get_link)(struct dentry___233 *, struct inode___233 *, struct delayed_call *);
	int (*permission)(struct inode___233 *, int);
	struct posix_acl * (*get_acl)(struct inode___233 *, int);
	int (*readlink)(struct dentry___233 *, char *, int);
	int (*create)(struct inode___233 *, struct dentry___233 *, umode_t, bool);
	int (*link)(struct dentry___233 *, struct inode___233 *, struct dentry___233 *);
	int (*unlink)(struct inode___233 *, struct dentry___233 *);
	int (*symlink)(struct inode___233 *, struct dentry___233 *, const char *);
	int (*mkdir)(struct inode___233 *, struct dentry___233 *, umode_t);
	int (*rmdir)(struct inode___233 *, struct dentry___233 *);
	int (*mknod)(struct inode___233 *, struct dentry___233 *, umode_t, dev_t);
	int (*rename)(struct inode___233 *, struct dentry___233 *, struct inode___233 *, struct dentry___233 *, unsigned int);
	int (*setattr)(struct dentry___233 *, struct iattr___232 *);
	int (*getattr)(const struct path___232 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___233 *, char *, size_t);
	int (*fiemap)(struct inode___233 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___233 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___233 *, struct dentry___233 *, struct file___233 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___233 *, struct dentry___233 *, umode_t);
	int (*set_acl)(struct inode___233 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___232 {
	void (*fl_copy_lock)(struct file_lock___233 *, struct file_lock___233 *);
	void (*fl_release_private)(struct file_lock___233 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___232;

struct lock_manager_operations___232;

struct file_lock___233 {
	struct file_lock___233 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___233 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___232 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___232 *fl_ops;
	const struct lock_manager_operations___232 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___232 {
	int (*lm_compare_owner)(struct file_lock___233 *, struct file_lock___233 *);
	long unsigned int (*lm_owner_key)(struct file_lock___233 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___233 *);
	int (*lm_grant)(struct file_lock___233 *, int);
	bool (*lm_break)(struct file_lock___233 *);
	int (*lm_change)(struct file_lock___233 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___233 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___232 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___232 *fa_next;
	struct file___233 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___232 {
	const char *name;
	int fs_flags;
	struct dentry___233 * (*mount)(struct file_system_type___232 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___232 *);
	struct module___188 *owner;
	struct file_system_type___232 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___232 {
	struct inode___233 * (*alloc_inode)(struct super_block___232 *);
	void (*destroy_inode)(struct inode___233 *);
	void (*dirty_inode)(struct inode___233 *, int);
	int (*write_inode)(struct inode___233 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___233 *);
	void (*evict_inode)(struct inode___233 *);
	void (*put_super)(struct super_block___232 *);
	int (*sync_fs)(struct super_block___232 *, int);
	int (*freeze_super)(struct super_block___232 *);
	int (*freeze_fs)(struct super_block___232 *);
	int (*thaw_super)(struct super_block___232 *);
	int (*unfreeze_fs)(struct super_block___232 *);
	int (*statfs)(struct dentry___233 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___232 *, int *, char *);
	void (*umount_begin)(struct super_block___232 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___233 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___233 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___233 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___233 *);
	ssize_t (*quota_read)(struct super_block___232 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___232 *, int, const char *, size_t, loff_t);
	struct dquot___232 ** (*get_dquots)(struct inode___233 *);
	int (*bdev_try_to_free_page)(struct super_block___232 *, struct page___234 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___232 *, struct shrink_control___97 *);
	long int (*free_cached_objects)(struct super_block___232 *, struct shrink_control___97 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___223(struct page___234 *);

struct key_construction___2 {
	struct key___226 *key;
	struct key___226 *authkey;
};

struct key_match_data___2 {
	bool (*cmp)(const struct key___226 *, const struct key_match_data___2 *);
	const void *raw_data;
	void *preparsed;
	unsigned int lookup_type;
};

struct assoc_array_edit;

struct module___189;

struct file___234;

struct kiocb___234;

struct vm_area_struct___235;

struct inode___234;

struct file_lock___234;

struct page___235;

struct seq_file___210;

struct file_operations___234 {
	struct module___189 *owner;
	loff_t (*llseek)(struct file___234 *, loff_t, int);
	ssize_t (*read)(struct file___234 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___234 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___234 *, struct iov_iter___103 *);
	ssize_t (*write_iter)(struct kiocb___234 *, struct iov_iter___103 *);
	int (*iopoll)(struct kiocb___234 *, bool);
	int (*iterate)(struct file___234 *, struct dir_context *);
	int (*iterate_shared)(struct file___234 *, struct dir_context *);
	__poll_t (*poll)(struct file___234 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___234 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___234 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___234 *, struct vm_area_struct___235 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___234 *, struct file___234 *);
	int (*flush)(struct file___234 *, fl_owner_t);
	int (*release)(struct inode___234 *, struct file___234 *);
	int (*fsync)(struct file___234 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___234 *, int);
	int (*lock)(struct file___234 *, int, struct file_lock___234 *);
	ssize_t (*sendpage)(struct file___234 *, struct page___235 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___234 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___234 *, int, struct file_lock___234 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___234 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___234 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___234 *, long int, struct file_lock___234 **, void **);
	long int (*fallocate)(struct file___234 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___210 *, struct file___234 *);
	ssize_t (*copy_file_range)(struct file___234 *, loff_t, struct file___234 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___234 *, loff_t, struct file___234 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___234 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___234 {
	u64 seqnum;
	struct vm_area_struct___235 *vmas[4];
};

struct page_frag___234 {
	struct page___235 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___234;

struct cred___227;

struct task_struct___235 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___235 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___234 *mm;
	struct mm_struct___234 *active_mm;
	struct vmacache___234 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___235 *real_parent;
	struct task_struct___235 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___235 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___175 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___175 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___175 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___227 *ptracer_cred;
	const struct cred___227 *real_cred;
	const struct cred___227 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___235 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___58 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___234 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___235 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___125 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___235 *pgtable_t___234;

struct address_space___233;

struct dev_pagemap___224;

struct page___235 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___233 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___235 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___234 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___234 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___224 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___234;

struct lruvec___234 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___234 *pgdat;
};

struct zone___234 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___234 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___234 {
	struct zone___234 *zone;
	int zone_idx;
};

struct zonelist___234 {
	struct zoneref___234 _zonerefs[25];
};

struct pglist_data___234 {
	struct zone___234 node_zones[3];
	struct zonelist___234 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___235 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___235 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___234 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___235 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___235 *owner;
};

struct secondary_data___235 {
	void *stack;
	struct task_struct___235 *task;
	long int status;
};

struct blocking_notifier_head___234 {
	struct rw_semaphore___235 rwsem;
	struct notifier_block *head;
};

struct dentry___234;

struct path___233 {
	struct vfsmount *mnt;
	struct dentry___234 *dentry;
};

struct file___234 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___233 f_path;
	struct inode___234 *f_inode;
	const struct file_operations___234 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___175 f_owner;
	const struct cred___227 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___233 *f_mapping;
	errseq_t f_wb_err;
};

struct key___227;

struct user_struct___227;

struct cred___227 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___227 *session_keyring;
	struct key___227 *process_keyring;
	struct key___227 *thread_keyring;
	struct key___227 *request_key_auth;
	void *security;
	struct user_struct___227 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___228;

struct kernfs_elem_dir___228 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___228 *root;
};

struct kernfs_node___228;

struct kernfs_syscall_ops___228;

struct kernfs_root___228 {
	struct kernfs_node___228 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___228 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___228 {
	struct kernfs_node___228 *target_kn;
};

struct kernfs_ops___228;

struct kernfs_elem_attr___228 {
	const struct kernfs_ops___228 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___228 *notify_next;
};

struct kernfs_node___228 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___228 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___228 dir;
		struct kernfs_elem_symlink___228 symlink;
		struct kernfs_elem_attr___228 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___228;

struct kernfs_ops___228 {
	int (*open)(struct kernfs_open_file___228 *);
	void (*release)(struct kernfs_open_file___228 *);
	int (*seq_show)(struct seq_file___210 *, void *);
	void * (*seq_start)(struct seq_file___210 *, loff_t *);
	void * (*seq_next)(struct seq_file___210 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___210 *, void *);
	ssize_t (*read)(struct kernfs_open_file___228 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___228 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___228 *, struct vm_area_struct___235 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___228 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___228 {
	int (*remount_fs)(struct kernfs_root___228 *, int *, char *);
	int (*show_options)(struct seq_file___210 *, struct kernfs_root___228 *);
	int (*mkdir)(struct kernfs_node___228 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___228 *);
	int (*rename)(struct kernfs_node___228 *, struct kernfs_node___228 *, const char *);
	int (*show_path)(struct seq_file___210 *, struct kernfs_node___228 *, struct kernfs_root___228 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___208;

struct seq_file___210 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___208 *op;
	int poll_event;
	const struct file___234 *file;
	void *private;
};

struct vm_operations_struct___224;

struct kernfs_open_file___228 {
	struct kernfs_node___228 *kn;
	struct file___234 *file;
	struct seq_file___210 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___224 *vm_ops;
};

struct vm_fault___224;

struct vm_operations_struct___224 {
	void (*open)(struct vm_area_struct___235 *);
	void (*close)(struct vm_area_struct___235 *);
	int (*split)(struct vm_area_struct___235 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___235 *);
	vm_fault_t (*fault)(struct vm_fault___224 *);
	vm_fault_t (*huge_fault)(struct vm_fault___224 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___224 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___235 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___224 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___224 *);
	int (*access)(struct vm_area_struct___235 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___235 *);
	int (*set_policy)(struct vm_area_struct___235 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___235 *, long unsigned int);
	struct page___235 * (*find_special_page)(struct vm_area_struct___235 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_area_struct___235 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___235 *vm_next;
	struct vm_area_struct___235 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___234 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___224 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___234 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___221;

struct kobj_type___221;

struct kobject___222 {
	const char *name;
	struct list_head entry;
	struct kobject___222 *parent;
	struct kset___221 *kset;
	struct kobj_type___221 *ktype;
	struct kernfs_node___228 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sysfs_ops___221 {
	ssize_t (*show)(struct kobject___222 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___222 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___221;

struct kset___221 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___222 kobj;
	const struct kset_uevent_ops___221 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___221 {
	void (*release)(struct kobject___222 *);
	const struct sysfs_ops___221 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___13 * (*child_ns_type)(struct kobject___222 *);
	const void * (*namespace)(struct kobject___222 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___221 {
	int (* const filter)(struct kset___221 *, struct kobject___222 *);
	const char * (* const name)(struct kset___221 *, struct kobject___222 *);
	int (* const uevent)(struct kset___221 *, struct kobject___222 *, struct kobj_uevent_env *);
};

struct kobj_attribute___215 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___222 *, struct kobj_attribute___215 *, char *);
	ssize_t (*store)(struct kobject___222 *, struct kobj_attribute___215 *, const char *, size_t);
};

struct kernel_param___186;

struct kernel_param_ops___186 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___186 *);
	int (*get)(char *, const struct kernel_param___186 *);
	void (*free)(void *);
};

struct kparam_array___186;

struct kernel_param___186 {
	const char *name;
	struct module___189 *mod;
	const struct kernel_param_ops___186 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___186 *arr;
	};
};

struct kparam_array___186 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___186 *ops;
	void *elem;
};

struct module_kobject___186 {
	struct kobject___222 kobj;
	struct module___189 *mod;
	struct kobject___222 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___186 {
	struct module___189 *mod;
	struct latch_tree_node node;
};

struct module_layout___186 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___186 mtn;
};

struct module_attribute___186;

struct module___189 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___186 mkobj;
	struct module_attribute___186 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___222 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___186 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___186 core_layout;
	struct module_layout___186 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___186 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___186 *, struct module_kobject___186 *, char *);
	ssize_t (*store)(struct module_attribute___186 *, struct module_kobject___186 *, const char *, size_t);
	void (*setup)(struct module___189 *, const char *);
	int (*test)(struct module___189 *);
	void (*free)(struct module___189 *);
};

struct user_struct___227 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___227 *uid_keyring;
	struct key___227 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___234;

struct mm_struct___234 {
	struct {
		struct vm_area_struct___235 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___234 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___235 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___234 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___235 *owner;
		struct user_namespace___3 *user_ns;
		struct file___234 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___234 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct assoc_array_ops {
	long unsigned int (*get_key_chunk)(const void *, int);
	long unsigned int (*get_object_key_chunk)(const void *, int);
	bool (*compare_object)(const void *, const void *);
	int (*diff_objects)(const void *, const void *);
	void (*free_object)(void *);
};

struct key_type___3;

struct keyring_index_key___3 {
	struct key_type___3 *type;
	const char *description;
	size_t desc_len;
};

struct key_construction___3;

typedef int (*request_key_actor_t___3)(struct key_construction___3 *, const char *, void *);

struct key_match_data___3;

struct key_restriction___227;

struct key_type___3 {
	const char *name;
	size_t def_datalen;
	int (*vet_description)(const char *);
	int (*preparse)(struct key_preparsed_payload *);
	void (*free_preparse)(struct key_preparsed_payload *);
	int (*instantiate)(struct key___227 *, struct key_preparsed_payload *);
	int (*update)(struct key___227 *, struct key_preparsed_payload *);
	int (*match_preparse)(struct key_match_data___3 *);
	void (*match_free)(struct key_match_data___3 *);
	void (*revoke)(struct key___227 *);
	void (*destroy)(struct key___227 *);
	void (*describe)(const struct key___227 *, struct seq_file___210 *);
	long int (*read)(const struct key___227 *, char *, size_t);
	request_key_actor_t___3 request_key;
	struct key_restriction___227 * (*lookup_restriction)(const char *);
	struct list_head link;
	struct lock_class_key lock_class;
};

typedef int (*key_restrict_link_func_t___227)(struct key___227 *, const struct key_type___3 *, const union key_payload *, struct key___227 *);

struct key___227 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___235 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key___3 index_key;
		struct {
			struct key_type___3 *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___227 *restrict_link;
};

struct key_restriction___227 {
	key_restrict_link_func_t___227 check;
	struct key___227 *key;
	struct key_type___3 *keytype;
};

struct dentry_operations___233;

struct super_block___233;

struct dentry___234 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___234 *d_parent;
	struct qstr d_name;
	struct inode___234 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___233 *d_op;
	struct super_block___233 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___233;

struct address_space___233 {
	struct inode___234 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___235 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___233 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___233;

struct block_device___234;

struct inode___234 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___233 *i_op;
	struct super_block___233 *i_sb;
	struct address_space___233 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___235 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___234 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___233 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___234 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___233 {
	int (*d_revalidate)(struct dentry___234 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___234 *, unsigned int);
	int (*d_hash)(const struct dentry___234 *, struct qstr *);
	int (*d_compare)(const struct dentry___234 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___234 *);
	int (*d_init)(struct dentry___234 *);
	void (*d_release)(struct dentry___234 *);
	void (*d_prune)(struct dentry___234 *);
	void (*d_iput)(struct dentry___234 *, struct inode___234 *);
	char * (*d_dname)(struct dentry___234 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___233 *);
	int (*d_manage)(const struct path___233 *, bool);
	struct dentry___234 * (*d_real)(struct dentry___234 *, const struct inode___234 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___233;

struct mem_dqinfo___233 {
	struct quota_format_type___233 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___233;

struct quota_info___233 {
	unsigned int flags;
	struct rw_semaphore___235 dqio_sem;
	struct inode___234 *files[3];
	struct mem_dqinfo___233 info[3];
	const struct quota_format_ops___233 *ops[3];
};

struct rcuwait___233 {
	struct task_struct___235 *task;
};

struct percpu_rw_semaphore___233 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___235 rw_sem;
	struct rcuwait___233 writer;
	int readers_block;
};

struct sb_writers___233 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___233 rw_sem[3];
};

struct file_system_type___233;

struct super_operations___233;

struct dquot_operations___233;

struct quotactl_ops___233;

struct super_block___233 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___233 *s_type;
	const struct super_operations___233 *s_op;
	const struct dquot_operations___233 *dq_op;
	const struct quotactl_ops___233 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___234 *s_root;
	struct rw_semaphore___235 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___234 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___233 s_dquot;
	struct sb_writers___233 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___233 *s_d_op;
	int cleancache_poolid;
	struct shrinker___97 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

typedef int (*dev_page_fault_t___224)(struct vm_area_struct___235 *, long unsigned int, const struct page___235 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___224)(struct page___235 *, void *);

struct dev_pagemap___224 {
	dev_page_fault_t___224 page_fault;
	dev_page_free_t___224 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___6 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___234 {
	struct task_struct___235 *task;
	struct core_thread___234 *next;
};

struct core_state___234 {
	atomic_t nr_threads;
	struct core_thread___234 dumper;
	struct completion startup;
};

struct vm_fault___224 {
	struct vm_area_struct___235 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___235 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___235 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___234 prealloc_pte;
};

struct kiocb___234 {
	struct file___234 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___234 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___233 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___234 *ia_file;
};

struct dquot___233 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___233 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___233 {
	int qf_fmt_id;
	const struct quota_format_ops___233 *qf_ops;
	struct module___189 *qf_owner;
	struct quota_format_type___233 *qf_next;
};

struct quota_format_ops___233 {
	int (*check_quota_file)(struct super_block___233 *, int);
	int (*read_file_info)(struct super_block___233 *, int);
	int (*write_file_info)(struct super_block___233 *, int);
	int (*free_file_info)(struct super_block___233 *, int);
	int (*read_dqblk)(struct dquot___233 *);
	int (*commit_dqblk)(struct dquot___233 *);
	int (*release_dqblk)(struct dquot___233 *);
	int (*get_next_id)(struct super_block___233 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___233 {
	int (*write_dquot)(struct dquot___233 *);
	struct dquot___233 * (*alloc_dquot)(struct super_block___233 *, int);
	void (*destroy_dquot)(struct dquot___233 *);
	int (*acquire_dquot)(struct dquot___233 *);
	int (*release_dquot)(struct dquot___233 *);
	int (*mark_dirty)(struct dquot___233 *);
	int (*write_info)(struct super_block___233 *, int);
	qsize_t * (*get_reserved_space)(struct inode___234 *);
	int (*get_projid)(struct inode___234 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___234 *, qsize_t *);
	int (*get_next_id)(struct super_block___233 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___233 {
	int (*quota_on)(struct super_block___233 *, int, int, const struct path___233 *);
	int (*quota_off)(struct super_block___233 *, int);
	int (*quota_enable)(struct super_block___233 *, unsigned int);
	int (*quota_disable)(struct super_block___233 *, unsigned int);
	int (*quota_sync)(struct super_block___233 *, int);
	int (*set_info)(struct super_block___233 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___233 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___233 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___233 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___233 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___233 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___233 {
	int (*writepage)(struct page___235 *, struct writeback_control___3 *);
	int (*readpage)(struct file___234 *, struct page___235 *);
	int (*writepages)(struct address_space___233 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___235 *);
	int (*readpages)(struct file___234 *, struct address_space___233 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___234 *, struct address_space___233 *, loff_t, unsigned int, unsigned int, struct page___235 **, void **);
	int (*write_end)(struct file___234 *, struct address_space___233 *, loff_t, unsigned int, unsigned int, struct page___235 *, void *);
	sector_t (*bmap)(struct address_space___233 *, sector_t);
	void (*invalidatepage)(struct page___235 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___235 *, gfp_t);
	void (*freepage)(struct page___235 *);
	ssize_t (*direct_IO)(struct kiocb___234 *, struct iov_iter___103 *);
	int (*migratepage)(struct address_space___233 *, struct page___235 *, struct page___235 *, enum migrate_mode);
	bool (*isolate_page)(struct page___235 *, isolate_mode_t);
	void (*putback_page)(struct page___235 *);
	int (*launder_page)(struct page___235 *);
	int (*is_partially_uptodate)(struct page___235 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___235 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___233 *, struct page___235 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___234 *, sector_t *);
	void (*swap_deactivate)(struct file___234 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___234 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___234 *bd_inode;
	struct super_block___233 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___234 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___233 {
	struct dentry___234 * (*lookup)(struct inode___234 *, struct dentry___234 *, unsigned int);
	const char * (*get_link)(struct dentry___234 *, struct inode___234 *, struct delayed_call *);
	int (*permission)(struct inode___234 *, int);
	struct posix_acl * (*get_acl)(struct inode___234 *, int);
	int (*readlink)(struct dentry___234 *, char *, int);
	int (*create)(struct inode___234 *, struct dentry___234 *, umode_t, bool);
	int (*link)(struct dentry___234 *, struct inode___234 *, struct dentry___234 *);
	int (*unlink)(struct inode___234 *, struct dentry___234 *);
	int (*symlink)(struct inode___234 *, struct dentry___234 *, const char *);
	int (*mkdir)(struct inode___234 *, struct dentry___234 *, umode_t);
	int (*rmdir)(struct inode___234 *, struct dentry___234 *);
	int (*mknod)(struct inode___234 *, struct dentry___234 *, umode_t, dev_t);
	int (*rename)(struct inode___234 *, struct dentry___234 *, struct inode___234 *, struct dentry___234 *, unsigned int);
	int (*setattr)(struct dentry___234 *, struct iattr___233 *);
	int (*getattr)(const struct path___233 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___234 *, char *, size_t);
	int (*fiemap)(struct inode___234 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___234 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___234 *, struct dentry___234 *, struct file___234 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___234 *, struct dentry___234 *, umode_t);
	int (*set_acl)(struct inode___234 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___233 {
	void (*fl_copy_lock)(struct file_lock___234 *, struct file_lock___234 *);
	void (*fl_release_private)(struct file_lock___234 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___233;

struct lock_manager_operations___233;

struct file_lock___234 {
	struct file_lock___234 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___234 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___233 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___233 *fl_ops;
	const struct lock_manager_operations___233 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___233 {
	int (*lm_compare_owner)(struct file_lock___234 *, struct file_lock___234 *);
	long unsigned int (*lm_owner_key)(struct file_lock___234 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___234 *);
	int (*lm_grant)(struct file_lock___234 *, int);
	bool (*lm_break)(struct file_lock___234 *);
	int (*lm_change)(struct file_lock___234 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___234 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___233 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___233 *fa_next;
	struct file___234 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___233 {
	const char *name;
	int fs_flags;
	struct dentry___234 * (*mount)(struct file_system_type___233 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___233 *);
	struct module___189 *owner;
	struct file_system_type___233 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___233 {
	struct inode___234 * (*alloc_inode)(struct super_block___233 *);
	void (*destroy_inode)(struct inode___234 *);
	void (*dirty_inode)(struct inode___234 *, int);
	int (*write_inode)(struct inode___234 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___234 *);
	void (*evict_inode)(struct inode___234 *);
	void (*put_super)(struct super_block___233 *);
	int (*sync_fs)(struct super_block___233 *, int);
	int (*freeze_super)(struct super_block___233 *);
	int (*freeze_fs)(struct super_block___233 *);
	int (*thaw_super)(struct super_block___233 *);
	int (*unfreeze_fs)(struct super_block___233 *);
	int (*statfs)(struct dentry___234 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___233 *, int *, char *);
	void (*umount_begin)(struct super_block___233 *);
	int (*show_options)(struct seq_file___210 *, struct dentry___234 *);
	int (*show_devname)(struct seq_file___210 *, struct dentry___234 *);
	int (*show_path)(struct seq_file___210 *, struct dentry___234 *);
	int (*show_stats)(struct seq_file___210 *, struct dentry___234 *);
	ssize_t (*quota_read)(struct super_block___233 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___233 *, int, const char *, size_t, loff_t);
	struct dquot___233 ** (*get_dquots)(struct inode___234 *);
	int (*bdev_try_to_free_page)(struct super_block___233 *, struct page___235 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___233 *, struct shrink_control___97 *);
	long int (*free_cached_objects)(struct super_block___233 *, struct shrink_control___97 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___224(struct page___235 *);

struct seq_operations___208 {
	void * (*start)(struct seq_file___210 *, loff_t *);
	void (*stop)(struct seq_file___210 *, void *);
	void * (*next)(struct seq_file___210 *, void *, loff_t *);
	int (*show)(struct seq_file___210 *, void *);
};

struct assoc_array_node {
	struct assoc_array_ptr *back_pointer;
	u8 parent_slot;
	struct assoc_array_ptr *slots[16];
	long unsigned int nr_leaves_on_branch;
};

struct assoc_array_shortcut {
	struct assoc_array_ptr *back_pointer;
	int parent_slot;
	int skip_to_level;
	struct assoc_array_ptr *next_node;
	long unsigned int index_key[0];
};

struct assoc_array_edit___2 {
	struct callback_head rcu;
	struct assoc_array *array;
	const struct assoc_array_ops *ops;
	const struct assoc_array_ops *ops_for_excised_subtree;
	struct assoc_array_ptr *leaf;
	struct assoc_array_ptr **leaf_p;
	struct assoc_array_ptr *dead_leaf;
	struct assoc_array_ptr *new_meta[3];
	struct assoc_array_ptr *excised_meta[1];
	struct assoc_array_ptr *excised_subtree;
	struct assoc_array_ptr **set_backpointers[16];
	struct assoc_array_ptr *set_backpointers_to;
	struct assoc_array_node *adjust_count_on;
	long int adjust_count_by;
	struct {
		struct assoc_array_ptr **ptr;
		struct assoc_array_ptr *to;
	} set[2];
	struct {
		u8 *p;
		u8 to;
	} set_parent_slot[1];
	u8 segment_cache[17];
};

struct key_construction___3 {
	struct key___227 *key;
	struct key___227 *authkey;
};

struct key_match_data___3 {
	bool (*cmp)(const struct key___227 *, const struct key_match_data___3 *);
	const void *raw_data;
	void *preparsed;
	unsigned int lookup_type;
};

struct keyring_search_context {
	struct keyring_index_key___3 index_key;
	const struct cred___227 *cred;
	struct key_match_data___3 match_data;
	unsigned int flags;
	int (*iterator)(const void *, void *);
	int skipped_ret;
	bool possessed;
	key_ref_t result;
	time64_t now;
};

struct keyring_read_iterator_context {
	size_t buflen;
	size_t count;
	key_serial_t *buffer;
};

struct module___190;

struct file___235;

struct kiocb___235;

struct poll_table_struct___146;

struct vm_area_struct___236;

struct inode___235;

struct file_lock___235;

struct page___236;

struct seq_file___211;

struct file_operations___235 {
	struct module___190 *owner;
	loff_t (*llseek)(struct file___235 *, loff_t, int);
	ssize_t (*read)(struct file___235 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___235 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___235 *, struct iov_iter___103 *);
	ssize_t (*write_iter)(struct kiocb___235 *, struct iov_iter___103 *);
	int (*iopoll)(struct kiocb___235 *, bool);
	int (*iterate)(struct file___235 *, struct dir_context *);
	int (*iterate_shared)(struct file___235 *, struct dir_context *);
	__poll_t (*poll)(struct file___235 *, struct poll_table_struct___146 *);
	long int (*unlocked_ioctl)(struct file___235 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___235 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___235 *, struct vm_area_struct___236 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___235 *, struct file___235 *);
	int (*flush)(struct file___235 *, fl_owner_t);
	int (*release)(struct inode___235 *, struct file___235 *);
	int (*fsync)(struct file___235 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___235 *, int);
	int (*lock)(struct file___235 *, int, struct file_lock___235 *);
	ssize_t (*sendpage)(struct file___235 *, struct page___236 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___235 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___235 *, int, struct file_lock___235 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___235 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___235 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___235 *, long int, struct file_lock___235 **, void **);
	long int (*fallocate)(struct file___235 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___211 *, struct file___235 *);
	ssize_t (*copy_file_range)(struct file___235 *, loff_t, struct file___235 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___235 *, loff_t, struct file___235 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___235 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___235 {
	u64 seqnum;
	struct vm_area_struct___236 *vmas[4];
};

struct page_frag___235 {
	struct page___236 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___126;

struct debug_info___126 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___126 *hbp_break[16];
	struct perf_event___126 *hbp_watch[16];
};

struct thread_struct___126 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___126 debug;
	long: 64;
};

struct mm_struct___235;

struct pid___176;

struct cred___228;

struct nsproxy___215;

struct signal_struct___194;

struct css_set___180;

struct perf_event_context___126;

struct vm_struct___152;

struct task_struct___236 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___236 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___235 *mm;
	struct mm_struct___235 *active_mm;
	struct vmacache___235 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___236 *real_parent;
	struct task_struct___236 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___236 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___176 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___176 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___176 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___228 *ptracer_cred;
	const struct cred___228 *real_cred;
	const struct cred___228 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___215 *nsproxy;
	struct signal_struct___194 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___236 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___58 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___180 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___126 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___235 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___236 *oom_reaper_list;
	struct vm_struct___152 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___126 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___126 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___236 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___126)(struct perf_event___126 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___126;

struct fasync_struct___234;

struct pid_namespace___176;

struct trace_event_call___119;

struct perf_cgroup___126;

struct perf_event___126 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___126 *group_leader;
	struct pmu___126 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___126 hw;
	struct perf_event_context___126 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___126 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___236 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___234 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___126 *);
	struct callback_head callback_head;
	struct pid_namespace___176 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___126 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___126 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___119 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___126 *cgrp;
	struct list_head sb_list;
};

struct rw_semaphore___236 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___236 *owner;
};

struct key___228;

struct ucounts___195;

struct user_namespace___195 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___195 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___28 ns;
	long unsigned int flags;
	struct key___228 *persistent_keyring_register;
	struct rw_semaphore___236 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___195 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___236 *pgtable_t___235;

struct address_space___234;

struct dev_pagemap___225;

struct page___236 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___234 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___236 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___235 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___235 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___225 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___235;

struct lruvec___235 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___235 *pgdat;
};

struct zone___235 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___235 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___235 {
	struct zone___235 *zone;
	int zone_idx;
};

struct zonelist___235 {
	struct zoneref___235 _zonerefs[25];
};

struct pglist_data___235 {
	struct zone___235 node_zones[3];
	struct zonelist___235 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___236 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___236 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___235 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___236 {
	void *stack;
	struct task_struct___236 *task;
	long int status;
};

struct blocking_notifier_head___235 {
	struct rw_semaphore___236 rwsem;
	struct notifier_block *head;
};

struct dentry___235;

struct path___234 {
	struct vfsmount *mnt;
	struct dentry___235 *dentry;
};

struct fown_struct___176 {
	rwlock_t lock;
	struct pid___176 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___235 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___234 f_path;
	struct inode___235 *f_inode;
	const struct file_operations___235 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___176 f_owner;
	const struct cred___228 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___234 *f_mapping;
	errseq_t f_wb_err;
};

struct user_struct___228;

struct cred___228 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___228 *session_keyring;
	struct key___228 *process_keyring;
	struct key___228 *thread_keyring;
	struct key___228 *request_key_auth;
	void *security;
	struct user_struct___228 *user;
	struct user_namespace___195 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___229;

struct kernfs_elem_dir___229 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___229 *root;
};

struct kernfs_node___229;

struct kernfs_syscall_ops___229;

struct kernfs_root___229 {
	struct kernfs_node___229 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___229 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___229 {
	struct kernfs_node___229 *target_kn;
};

struct kernfs_ops___229;

struct kernfs_elem_attr___229 {
	const struct kernfs_ops___229 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___229 *notify_next;
};

struct kernfs_node___229 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___229 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___229 dir;
		struct kernfs_elem_symlink___229 symlink;
		struct kernfs_elem_attr___229 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___229;

struct kernfs_ops___229 {
	int (*open)(struct kernfs_open_file___229 *);
	void (*release)(struct kernfs_open_file___229 *);
	int (*seq_show)(struct seq_file___211 *, void *);
	void * (*seq_start)(struct seq_file___211 *, loff_t *);
	void * (*seq_next)(struct seq_file___211 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___211 *, void *);
	ssize_t (*read)(struct kernfs_open_file___229 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___229 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___229 *, struct vm_area_struct___236 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___229 *, struct poll_table_struct___146 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___229 {
	int (*remount_fs)(struct kernfs_root___229 *, int *, char *);
	int (*show_options)(struct seq_file___211 *, struct kernfs_root___229 *);
	int (*mkdir)(struct kernfs_node___229 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___229 *);
	int (*rename)(struct kernfs_node___229 *, struct kernfs_node___229 *, const char *);
	int (*show_path)(struct seq_file___211 *, struct kernfs_node___229 *, struct kernfs_root___229 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___209;

struct seq_file___211 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___209 *op;
	int poll_event;
	const struct file___235 *file;
	void *private;
};

struct vm_operations_struct___225;

struct kernfs_open_file___229 {
	struct kernfs_node___229 *kn;
	struct file___235 *file;
	struct seq_file___211 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___225 *vm_ops;
};

struct vm_fault___225;

struct vm_operations_struct___225 {
	void (*open)(struct vm_area_struct___236 *);
	void (*close)(struct vm_area_struct___236 *);
	int (*split)(struct vm_area_struct___236 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___236 *);
	vm_fault_t (*fault)(struct vm_fault___225 *);
	vm_fault_t (*huge_fault)(struct vm_fault___225 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___225 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___236 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___225 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___225 *);
	int (*access)(struct vm_area_struct___236 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___236 *);
	int (*set_policy)(struct vm_area_struct___236 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___236 *, long unsigned int);
	struct page___236 * (*find_special_page)(struct vm_area_struct___236 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___148)(struct file___235 *, wait_queue_head_t *, struct poll_table_struct___146 *);

struct poll_table_struct___146 {
	poll_queue_proc___148 _qproc;
	__poll_t _key;
};

struct vm_area_struct___236 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___236 *vm_next;
	struct vm_area_struct___236 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___235 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___225 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___235 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___223;

struct bin_attribute___200;

struct attribute_group___201 {
	const char *name;
	umode_t (*is_visible)(struct kobject___223 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___223 *, struct bin_attribute___200 *, int);
	struct attribute **attrs;
	struct bin_attribute___200 **bin_attrs;
};

struct kset___222;

struct kobj_type___222;

struct kobject___223 {
	const char *name;
	struct list_head entry;
	struct kobject___223 *parent;
	struct kset___222 *kset;
	struct kobj_type___222 *ktype;
	struct kernfs_node___229 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___200 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___235 *, struct kobject___223 *, struct bin_attribute___200 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___235 *, struct kobject___223 *, struct bin_attribute___200 *, char *, loff_t, size_t);
	int (*mmap)(struct file___235 *, struct kobject___223 *, struct bin_attribute___200 *, struct vm_area_struct___236 *);
};

struct sysfs_ops___222 {
	ssize_t (*show)(struct kobject___223 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___223 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___222;

struct kset___222 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___223 kobj;
	const struct kset_uevent_ops___222 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___222 {
	void (*release)(struct kobject___223 *);
	const struct sysfs_ops___222 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___13 * (*child_ns_type)(struct kobject___223 *);
	const void * (*namespace)(struct kobject___223 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___222 {
	int (* const filter)(struct kset___222 *, struct kobject___223 *);
	const char * (* const name)(struct kset___222 *, struct kobject___223 *);
	int (* const uevent)(struct kset___222 *, struct kobject___223 *, struct kobj_uevent_env *);
};

struct kobj_attribute___216 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___223 *, struct kobj_attribute___216 *, char *);
	ssize_t (*store)(struct kobject___223 *, struct kobj_attribute___216 *, const char *, size_t);
};

struct kernel_param___187;

struct kernel_param_ops___187 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___187 *);
	int (*get)(char *, const struct kernel_param___187 *);
	void (*free)(void *);
};

struct kparam_array___187;

struct kernel_param___187 {
	const char *name;
	struct module___190 *mod;
	const struct kernel_param_ops___187 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___187 *arr;
	};
};

struct kparam_array___187 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___187 *ops;
	void *elem;
};

struct module_kobject___187 {
	struct kobject___223 kobj;
	struct module___190 *mod;
	struct kobject___223 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___187 {
	struct module___190 *mod;
	struct latch_tree_node node;
};

struct module_layout___187 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___187 mtn;
};

struct module_attribute___187;

struct module___190 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___187 mkobj;
	struct module_attribute___187 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___223 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___187 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___187 core_layout;
	struct module_layout___187 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___119 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___187 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___187 *, struct module_kobject___187 *, char *);
	ssize_t (*store)(struct module_attribute___187 *, struct module_kobject___187 *, const char *, size_t);
	void (*setup)(struct module___190 *, const char *);
	int (*test)(struct module___190 *);
	void (*free)(struct module___190 *);
};

struct trace_event_class___119;

struct trace_event_call___119 {
	struct list_head list;
	struct trace_event_class___119 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___23 *prog_array;
	int (*perf_perm)(struct trace_event_call___119 *, struct perf_event___126 *);
};

struct upid___176 {
	int nr;
	struct pid_namespace___176 *ns;
};

struct pid_namespace___176 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___236 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___176 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___235 *proc_self;
	struct dentry___235 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___195 *user_ns;
	struct ucounts___195 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___28 ns;
};

struct pid___176 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___176 numbers[1];
};

struct user_struct___228 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___228 *uid_keyring;
	struct key___228 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___235;

struct mm_struct___235 {
	struct {
		struct vm_area_struct___236 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___235 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___236 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___235 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___236 *owner;
		struct user_namespace___195 *user_ns;
		struct file___235 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___235 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___180;

struct nsproxy___215 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___176 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___180 *cgroup_ns;
};

struct signal_struct___194 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___236 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___236 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___176 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___176 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___235 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___176 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___181;

struct cgroup___180;

struct css_set___180 {
	struct cgroup_subsys_state___181 *subsys[13];
	refcount_t refcount;
	struct css_set___180 *dom_cset;
	struct cgroup___180 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___180 *mg_src_cgrp;
	struct cgroup___180 *mg_dst_cgrp;
	struct css_set___180 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___126 {
	struct pmu___126 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___236 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___126 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___152 {
	struct vm_struct___152 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___236 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___206 {
	struct task_struct___236 task;
	long unsigned int stack[8192];
};

struct dentry_operations___234;

struct super_block___234;

struct dentry___235 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___235 *d_parent;
	struct qstr d_name;
	struct inode___235 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___234 *d_op;
	struct super_block___234 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___234;

struct address_space___234 {
	struct inode___235 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___236 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___234 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___234;

struct block_device___235;

struct inode___235 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___234 *i_op;
	struct super_block___234 *i_sb;
	struct address_space___234 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___236 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___235 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___234 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___235 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___234 {
	int (*d_revalidate)(struct dentry___235 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___235 *, unsigned int);
	int (*d_hash)(const struct dentry___235 *, struct qstr *);
	int (*d_compare)(const struct dentry___235 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___235 *);
	int (*d_init)(struct dentry___235 *);
	void (*d_release)(struct dentry___235 *);
	void (*d_prune)(struct dentry___235 *);
	void (*d_iput)(struct dentry___235 *, struct inode___235 *);
	char * (*d_dname)(struct dentry___235 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___234 *);
	int (*d_manage)(const struct path___234 *, bool);
	struct dentry___235 * (*d_real)(struct dentry___235 *, const struct inode___235 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___234;

struct mem_dqinfo___234 {
	struct quota_format_type___234 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___234;

struct quota_info___234 {
	unsigned int flags;
	struct rw_semaphore___236 dqio_sem;
	struct inode___235 *files[3];
	struct mem_dqinfo___234 info[3];
	const struct quota_format_ops___234 *ops[3];
};

struct rcuwait___234 {
	struct task_struct___236 *task;
};

struct percpu_rw_semaphore___234 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___236 rw_sem;
	struct rcuwait___234 writer;
	int readers_block;
};

struct sb_writers___234 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___234 rw_sem[3];
};

struct file_system_type___234;

struct super_operations___234;

struct dquot_operations___234;

struct quotactl_ops___234;

struct super_block___234 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___234 *s_type;
	const struct super_operations___234 *s_op;
	const struct dquot_operations___234 *dq_op;
	const struct quotactl_ops___234 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___235 *s_root;
	struct rw_semaphore___236 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___235 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___234 s_dquot;
	struct sb_writers___234 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___234 *s_d_op;
	int cleancache_poolid;
	struct shrinker___97 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___195 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

typedef int (*dev_page_fault_t___225)(struct vm_area_struct___236 *, long unsigned int, const struct page___236 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___225)(struct page___236 *, void *);

struct device___199;

struct dev_pagemap___225 {
	dev_page_fault_t___225 page_fault;
	dev_page_free_t___225 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___199 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___235 {
	struct task_struct___236 *task;
	struct core_thread___235 *next;
};

struct core_state___235 {
	atomic_t nr_threads;
	struct core_thread___235 dumper;
	struct completion startup;
};

struct vm_fault___225 {
	struct vm_area_struct___236 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___236 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___236 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___235 prealloc_pte;
};

struct kiocb___235 {
	struct file___235 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___235 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___234 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___235 *ia_file;
};

struct dquot___234 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___234 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___234 {
	int qf_fmt_id;
	const struct quota_format_ops___234 *qf_ops;
	struct module___190 *qf_owner;
	struct quota_format_type___234 *qf_next;
};

struct quota_format_ops___234 {
	int (*check_quota_file)(struct super_block___234 *, int);
	int (*read_file_info)(struct super_block___234 *, int);
	int (*write_file_info)(struct super_block___234 *, int);
	int (*free_file_info)(struct super_block___234 *, int);
	int (*read_dqblk)(struct dquot___234 *);
	int (*commit_dqblk)(struct dquot___234 *);
	int (*release_dqblk)(struct dquot___234 *);
	int (*get_next_id)(struct super_block___234 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___234 {
	int (*write_dquot)(struct dquot___234 *);
	struct dquot___234 * (*alloc_dquot)(struct super_block___234 *, int);
	void (*destroy_dquot)(struct dquot___234 *);
	int (*acquire_dquot)(struct dquot___234 *);
	int (*release_dquot)(struct dquot___234 *);
	int (*mark_dirty)(struct dquot___234 *);
	int (*write_info)(struct super_block___234 *, int);
	qsize_t * (*get_reserved_space)(struct inode___235 *);
	int (*get_projid)(struct inode___235 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___235 *, qsize_t *);
	int (*get_next_id)(struct super_block___234 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___234 {
	int (*quota_on)(struct super_block___234 *, int, int, const struct path___234 *);
	int (*quota_off)(struct super_block___234 *, int);
	int (*quota_enable)(struct super_block___234 *, unsigned int);
	int (*quota_disable)(struct super_block___234 *, unsigned int);
	int (*quota_sync)(struct super_block___234 *, int);
	int (*set_info)(struct super_block___234 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___234 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___234 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___234 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___234 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___234 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___234 {
	int (*writepage)(struct page___236 *, struct writeback_control___3 *);
	int (*readpage)(struct file___235 *, struct page___236 *);
	int (*writepages)(struct address_space___234 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___236 *);
	int (*readpages)(struct file___235 *, struct address_space___234 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___235 *, struct address_space___234 *, loff_t, unsigned int, unsigned int, struct page___236 **, void **);
	int (*write_end)(struct file___235 *, struct address_space___234 *, loff_t, unsigned int, unsigned int, struct page___236 *, void *);
	sector_t (*bmap)(struct address_space___234 *, sector_t);
	void (*invalidatepage)(struct page___236 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___236 *, gfp_t);
	void (*freepage)(struct page___236 *);
	ssize_t (*direct_IO)(struct kiocb___235 *, struct iov_iter___103 *);
	int (*migratepage)(struct address_space___234 *, struct page___236 *, struct page___236 *, enum migrate_mode);
	bool (*isolate_page)(struct page___236 *, isolate_mode_t);
	void (*putback_page)(struct page___236 *);
	int (*launder_page)(struct page___236 *);
	int (*is_partially_uptodate)(struct page___236 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___236 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___234 *, struct page___236 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___235 *, sector_t *);
	void (*swap_deactivate)(struct file___235 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___235 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___235 *bd_inode;
	struct super_block___234 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___235 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___234 {
	struct dentry___235 * (*lookup)(struct inode___235 *, struct dentry___235 *, unsigned int);
	const char * (*get_link)(struct dentry___235 *, struct inode___235 *, struct delayed_call *);
	int (*permission)(struct inode___235 *, int);
	struct posix_acl * (*get_acl)(struct inode___235 *, int);
	int (*readlink)(struct dentry___235 *, char *, int);
	int (*create)(struct inode___235 *, struct dentry___235 *, umode_t, bool);
	int (*link)(struct dentry___235 *, struct inode___235 *, struct dentry___235 *);
	int (*unlink)(struct inode___235 *, struct dentry___235 *);
	int (*symlink)(struct inode___235 *, struct dentry___235 *, const char *);
	int (*mkdir)(struct inode___235 *, struct dentry___235 *, umode_t);
	int (*rmdir)(struct inode___235 *, struct dentry___235 *);
	int (*mknod)(struct inode___235 *, struct dentry___235 *, umode_t, dev_t);
	int (*rename)(struct inode___235 *, struct dentry___235 *, struct inode___235 *, struct dentry___235 *, unsigned int);
	int (*setattr)(struct dentry___235 *, struct iattr___234 *);
	int (*getattr)(const struct path___234 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___235 *, char *, size_t);
	int (*fiemap)(struct inode___235 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___235 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___235 *, struct dentry___235 *, struct file___235 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___235 *, struct dentry___235 *, umode_t);
	int (*set_acl)(struct inode___235 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___234 {
	void (*fl_copy_lock)(struct file_lock___235 *, struct file_lock___235 *);
	void (*fl_release_private)(struct file_lock___235 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___234;

struct file_lock___235 {
	struct file_lock___235 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___235 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___234 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___234 *fl_ops;
	const struct lock_manager_operations___234 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___234 {
	int (*lm_compare_owner)(struct file_lock___235 *, struct file_lock___235 *);
	long unsigned int (*lm_owner_key)(struct file_lock___235 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___235 *);
	int (*lm_grant)(struct file_lock___235 *, int);
	bool (*lm_break)(struct file_lock___235 *);
	int (*lm_change)(struct file_lock___235 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___235 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___234 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___234 *fa_next;
	struct file___235 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___234 {
	const char *name;
	int fs_flags;
	struct dentry___235 * (*mount)(struct file_system_type___234 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___234 *);
	struct module___190 *owner;
	struct file_system_type___234 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___234 {
	struct inode___235 * (*alloc_inode)(struct super_block___234 *);
	void (*destroy_inode)(struct inode___235 *);
	void (*dirty_inode)(struct inode___235 *, int);
	int (*write_inode)(struct inode___235 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___235 *);
	void (*evict_inode)(struct inode___235 *);
	void (*put_super)(struct super_block___234 *);
	int (*sync_fs)(struct super_block___234 *, int);
	int (*freeze_super)(struct super_block___234 *);
	int (*freeze_fs)(struct super_block___234 *);
	int (*thaw_super)(struct super_block___234 *);
	int (*unfreeze_fs)(struct super_block___234 *);
	int (*statfs)(struct dentry___235 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___234 *, int *, char *);
	void (*umount_begin)(struct super_block___234 *);
	int (*show_options)(struct seq_file___211 *, struct dentry___235 *);
	int (*show_devname)(struct seq_file___211 *, struct dentry___235 *);
	int (*show_path)(struct seq_file___211 *, struct dentry___235 *);
	int (*show_stats)(struct seq_file___211 *, struct dentry___235 *);
	ssize_t (*quota_read)(struct super_block___234 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___234 *, int, const char *, size_t, loff_t);
	struct dquot___234 ** (*get_dquots)(struct inode___235 *);
	int (*bdev_try_to_free_page)(struct super_block___234 *, struct page___236 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___234 *, struct shrink_control___97 *);
	long int (*free_cached_objects)(struct super_block___234 *, struct shrink_control___97 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct key_type___4;

struct keyring_index_key___4 {
	struct key_type___4 *type;
	const char *description;
	size_t desc_len;
};

struct key_construction___4;

typedef int (*request_key_actor_t___4)(struct key_construction___4 *, const char *, void *);

struct key_match_data___4;

struct key_restriction___228;

struct key_type___4 {
	const char *name;
	size_t def_datalen;
	int (*vet_description)(const char *);
	int (*preparse)(struct key_preparsed_payload *);
	void (*free_preparse)(struct key_preparsed_payload *);
	int (*instantiate)(struct key___228 *, struct key_preparsed_payload *);
	int (*update)(struct key___228 *, struct key_preparsed_payload *);
	int (*match_preparse)(struct key_match_data___4 *);
	void (*match_free)(struct key_match_data___4 *);
	void (*revoke)(struct key___228 *);
	void (*destroy)(struct key___228 *);
	void (*describe)(const struct key___228 *, struct seq_file___211 *);
	long int (*read)(const struct key___228 *, char *, size_t);
	request_key_actor_t___4 request_key;
	struct key_restriction___228 * (*lookup_restriction)(const char *);
	struct list_head link;
	struct lock_class_key lock_class;
};

typedef int (*key_restrict_link_func_t___228)(struct key___228 *, const struct key_type___4 *, const union key_payload *, struct key___228 *);

struct key___228 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___236 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key___4 index_key;
		struct {
			struct key_type___4 *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___228 *restrict_link;
};

struct key_restriction___228 {
	key_restrict_link_func_t___228 check;
	struct key___228 *key;
	struct key_type___4 *keytype;
};

struct dev_pm_info___199 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___199 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___199;

struct bus_type___199;

struct device_driver___199;

struct dev_pm_domain___199;

struct class___199;

struct device___199 {
	struct device___199 *parent;
	struct device_private *p;
	struct kobject___223 kobj;
	const char *init_name;
	const struct device_type___199 *type;
	struct mutex mutex;
	struct bus_type___199 *bus;
	struct device_driver___199 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___199 power;
	struct dev_pm_domain___199 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___199 *class;
	const struct attribute_group___201 **groups;
	void (*release)(struct device___199 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

typedef void compound_page_dtor___225(struct page___236 *);

struct seq_operations___209 {
	void * (*start)(struct seq_file___211 *, loff_t *);
	void (*stop)(struct seq_file___211 *, void *);
	void * (*next)(struct seq_file___211 *, void *, loff_t *);
	int (*show)(struct seq_file___211 *, void *);
};

struct cgroup_namespace___180 {
	refcount_t count;
	struct ns_common___28 ns;
	struct user_namespace___195 *user_ns;
	struct ucounts___195 *ucounts;
	struct css_set___180 *root_cset;
};

struct ucounts___195 {
	struct hlist_node node;
	struct user_namespace___195 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct dev_pm_ops___199 {
	int (*prepare)(struct device___199 *);
	void (*complete)(struct device___199 *);
	int (*suspend)(struct device___199 *);
	int (*resume)(struct device___199 *);
	int (*freeze)(struct device___199 *);
	int (*thaw)(struct device___199 *);
	int (*poweroff)(struct device___199 *);
	int (*restore)(struct device___199 *);
	int (*suspend_late)(struct device___199 *);
	int (*resume_early)(struct device___199 *);
	int (*freeze_late)(struct device___199 *);
	int (*thaw_early)(struct device___199 *);
	int (*poweroff_late)(struct device___199 *);
	int (*restore_early)(struct device___199 *);
	int (*suspend_noirq)(struct device___199 *);
	int (*resume_noirq)(struct device___199 *);
	int (*freeze_noirq)(struct device___199 *);
	int (*thaw_noirq)(struct device___199 *);
	int (*poweroff_noirq)(struct device___199 *);
	int (*restore_noirq)(struct device___199 *);
	int (*runtime_suspend)(struct device___199 *);
	int (*runtime_resume)(struct device___199 *);
	int (*runtime_idle)(struct device___199 *);
};

struct dev_pm_domain___199 {
	struct dev_pm_ops___199 ops;
	void (*detach)(struct device___199 *, bool);
	int (*activate)(struct device___199 *);
	void (*sync)(struct device___199 *);
	void (*dismiss)(struct device___199 *);
};

struct bus_type___199 {
	const char *name;
	const char *dev_name;
	struct device___199 *dev_root;
	const struct attribute_group___201 **bus_groups;
	const struct attribute_group___201 **dev_groups;
	const struct attribute_group___201 **drv_groups;
	int (*match)(struct device___199 *, struct device_driver___199 *);
	int (*uevent)(struct device___199 *, struct kobj_uevent_env *);
	int (*probe)(struct device___199 *);
	int (*remove)(struct device___199 *);
	void (*shutdown)(struct device___199 *);
	int (*online)(struct device___199 *);
	int (*offline)(struct device___199 *);
	int (*suspend)(struct device___199 *, pm_message_t);
	int (*resume)(struct device___199 *);
	int (*num_vf)(struct device___199 *);
	int (*dma_configure)(struct device___199 *);
	const struct dev_pm_ops___199 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___199 {
	const char *name;
	struct bus_type___199 *bus;
	struct module___190 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___199 *);
	int (*remove)(struct device___199 *);
	void (*shutdown)(struct device___199 *);
	int (*suspend)(struct device___199 *, pm_message_t);
	int (*resume)(struct device___199 *);
	const struct attribute_group___201 **groups;
	const struct dev_pm_ops___199 *pm;
	void (*coredump)(struct device___199 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___199 {
	const char *name;
	const struct attribute_group___201 **groups;
	int (*uevent)(struct device___199 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___199 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___199 *);
	const struct dev_pm_ops___199 *pm;
};

struct class___199 {
	const char *name;
	struct module___190 *owner;
	const struct attribute_group___201 **class_groups;
	const struct attribute_group___201 **dev_groups;
	struct kobject___223 *dev_kobj;
	int (*dev_uevent)(struct device___199 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___199 *, umode_t *);
	void (*class_release)(struct class___199 *);
	void (*dev_release)(struct device___199 *);
	int (*shutdown_pre)(struct device___199 *);
	const struct kobj_ns_type_operations___13 *ns_type;
	const void * (*namespace)(struct device___199 *);
	const struct dev_pm_ops___199 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___166 {
	struct device___199 dev;
};

struct bpf_map___180;

struct bpf_map_ops___180 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___180 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___180 *, struct file___235 *);
	void (*map_free)(struct bpf_map___180 *);
	int (*map_get_next_key)(struct bpf_map___180 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___180 *);
	void * (*map_lookup_elem)(struct bpf_map___180 *, void *);
	int (*map_update_elem)(struct bpf_map___180 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___180 *, void *);
	int (*map_push_elem)(struct bpf_map___180 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___180 *, void *);
	int (*map_peek_elem)(struct bpf_map___180 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___180 *, struct file___235 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___180 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___180 *, void *, struct seq_file___211 *);
	int (*map_check_btf)(const struct bpf_map___180 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___180 {
	const struct bpf_map_ops___180 *ops;
	struct bpf_map___180 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___228 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___180;

typedef void (*kthread_work_func_t___180)(struct kthread_work___180 *);

struct kthread_worker___180;

struct kthread_work___180 {
	struct list_head node;
	kthread_work_func_t___180 func;
	struct kthread_worker___180 *worker;
	int canceling;
};

struct kthread_worker___180 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___236 *task;
	struct kthread_work___180 *current_work;
};

struct kthread_delayed_work___180 {
	struct kthread_work___180 work;
	struct timer_list timer;
};

struct psi_group___180 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___180 *poll_kworker;
	struct kthread_delayed_work___180 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___180 {
	struct kernfs_node___229 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___180;

struct cgroup_subsys_state___181 {
	struct cgroup___180 *cgroup;
	struct cgroup_subsys___180 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___181 *parent;
};

struct cgroup_root___180;

struct cgroup_rstat_cpu___180;

struct cgroup___180 {
	struct cgroup_subsys_state___181 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___229 *kn;
	struct cgroup_file___180 procs_file;
	struct cgroup_file___180 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___181 *subsys[13];
	struct cgroup_root___180 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___180 *dom_cgrp;
	struct cgroup_rstat_cpu___180 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___23 bpf;
	atomic_t congestion_count;
	struct cgroup___180 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___180 psi;
	int ancestor_ids[0];
};

struct cftype___180;

struct cgroup_subsys___180 {
	struct cgroup_subsys_state___181 * (*css_alloc)(struct cgroup_subsys_state___181 *);
	int (*css_online)(struct cgroup_subsys_state___181 *);
	void (*css_offline)(struct cgroup_subsys_state___181 *);
	void (*css_released)(struct cgroup_subsys_state___181 *);
	void (*css_free)(struct cgroup_subsys_state___181 *);
	void (*css_reset)(struct cgroup_subsys_state___181 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___181 *, int);
	int (*css_extra_stat_show)(struct seq_file___211 *, struct cgroup_subsys_state___181 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___236 *);
	void (*cancel_fork)(struct task_struct___236 *);
	void (*fork)(struct task_struct___236 *);
	void (*exit)(struct task_struct___236 *);
	void (*free)(struct task_struct___236 *);
	void (*bind)(struct cgroup_subsys_state___181 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___180 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___180 *dfl_cftypes;
	struct cftype___180 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___180 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___180 *updated_children;
	struct cgroup___180 *updated_next;
};

struct cgroup_root___180 {
	struct kernfs_root___229 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___180 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___180 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___180 *ss;
	struct list_head node;
	struct kernfs_ops___229 *kf_ops;
	int (*open)(struct kernfs_open_file___229 *);
	void (*release)(struct kernfs_open_file___229 *);
	u64 (*read_u64)(struct cgroup_subsys_state___181 *, struct cftype___180 *);
	s64 (*read_s64)(struct cgroup_subsys_state___181 *, struct cftype___180 *);
	int (*seq_show)(struct seq_file___211 *, void *);
	void * (*seq_start)(struct seq_file___211 *, loff_t *);
	void * (*seq_next)(struct seq_file___211 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___211 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___181 *, struct cftype___180 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___181 *, struct cftype___180 *, s64);
	ssize_t (*write)(struct kernfs_open_file___229 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___229 *, struct poll_table_struct___146 *);
};

struct perf_cpu_context___126;

struct pmu___126 {
	struct list_head entry;
	struct module___190 *module;
	struct device___199 *dev;
	const struct attribute_group___201 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___126 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___126 *);
	void (*pmu_disable)(struct pmu___126 *);
	int (*event_init)(struct perf_event___126 *);
	void (*event_mapped)(struct perf_event___126 *, struct mm_struct___235 *);
	void (*event_unmapped)(struct perf_event___126 *, struct mm_struct___235 *);
	int (*add)(struct perf_event___126 *, int);
	void (*del)(struct perf_event___126 *, int);
	void (*start)(struct perf_event___126 *, int);
	void (*stop)(struct perf_event___126 *, int);
	void (*read)(struct perf_event___126 *);
	void (*start_txn)(struct pmu___126 *, unsigned int);
	int (*commit_txn)(struct pmu___126 *);
	void (*cancel_txn)(struct pmu___126 *);
	int (*event_idx)(struct perf_event___126 *);
	void (*sched_task)(struct perf_event_context___126 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___126 *);
	int (*filter_match)(struct perf_event___126 *);
	int (*check_period)(struct perf_event___126 *, u64);
};

struct perf_cpu_context___126 {
	struct perf_event_context___126 ctx;
	struct perf_event_context___126 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___126 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___126 {
	struct cgroup_subsys_state___181 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___119 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___119 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___119 *);
	struct list_head * (*get_fields)(struct trace_event_call___119 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___119 *);
};

struct syscall_metadata___62 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___119 *enter_event;
	struct trace_event_call___119 *exit_event;
};

struct keyctl_dh_params {
	__s32 private;
	__s32 prime;
	__s32 base;
};

struct keyctl_kdf_params {
	char *hashname;
	char *otherinfo;
	__u32 otherinfolen;
	__u32 __spare[8];
};

struct key_construction___4 {
	struct key___228 *key;
	struct key___228 *authkey;
};

struct key_match_data___4 {
	bool (*cmp)(const struct key___228 *, const struct key_match_data___4 *);
	const void *raw_data;
	void *preparsed;
	unsigned int lookup_type;
};

struct request_key_auth {
	struct key___228 *target_key;
	struct key___228 *dest_keyring;
	const struct cred___228 *cred;
	void *callout_info;
	size_t callout_len;
	pid_t pid;
};

struct keyring_search_context___2 {
	struct keyring_index_key___4 index_key;
	const struct cred___228 *cred;
	struct key_match_data___4 match_data;
	unsigned int flags;
	int (*iterator)(const void *, void *);
	int skipped_ret;
	bool possessed;
	key_ref_t result;
	time64_t now;
};

struct subprocess_info___4 {
	struct work_struct work;
	struct completion *complete;
	const char *path;
	char **argv;
	char **envp;
	struct file___235 *file;
	int wait;
	int retval;
	pid_t pid;
	int (*init)(struct subprocess_info___4 *, struct cred___228 *);
	void (*cleanup)(struct subprocess_info___4 *);
	void *data;
};

struct user_key_payload {
	struct callback_head rcu;
	short unsigned int datalen;
	char data[0];
};

struct file___236;

struct kiocb___236;

struct vm_area_struct___237;

struct inode___236;

struct file_lock___236;

struct page___237;

struct seq_file___212;

struct file_operations___236 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___236 *, loff_t, int);
	ssize_t (*read)(struct file___236 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___236 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___236 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___236 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___236 *, bool);
	int (*iterate)(struct file___236 *, struct dir_context *);
	int (*iterate_shared)(struct file___236 *, struct dir_context *);
	__poll_t (*poll)(struct file___236 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___236 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___236 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___236 *, struct vm_area_struct___237 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___236 *, struct file___236 *);
	int (*flush)(struct file___236 *, fl_owner_t);
	int (*release)(struct inode___236 *, struct file___236 *);
	int (*fsync)(struct file___236 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___236 *, int);
	int (*lock)(struct file___236 *, int, struct file_lock___236 *);
	ssize_t (*sendpage)(struct file___236 *, struct page___237 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___236 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___236 *, int, struct file_lock___236 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___236 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___236 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___236 *, long int, struct file_lock___236 **, void **);
	long int (*fallocate)(struct file___236 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___212 *, struct file___236 *);
	ssize_t (*copy_file_range)(struct file___236 *, loff_t, struct file___236 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___236 *, loff_t, struct file___236 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___236 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___236 {
	u64 seqnum;
	struct vm_area_struct___237 *vmas[4];
};

struct page_frag___236 {
	struct page___237 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___236;

struct mem_cgroup___98;

struct cred___229;

struct nsproxy___216;

struct bio_list___112;

struct backing_dev_info___112;

struct css_set___181;

struct vm_struct___153;

struct task_struct___237 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___237 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___236 *mm;
	struct mm_struct___236 *active_mm;
	struct vmacache___236 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___237 *real_parent;
	struct task_struct___237 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___237 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___98 *active_memcg;
	long int rh_reserved2;
	struct pid___176 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___176 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___176 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___229 *ptracer_cred;
	const struct cred___229 *real_cred;
	const struct cred___229 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___216 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___237 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___112 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___112 *backing_dev_info;
	struct io_context___58 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___181 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___236 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___98 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___237 *oom_reaper_list;
	struct vm_struct___153 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___126 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___235;

struct super_block___235;

struct dentry___236 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___236 *d_parent;
	struct qstr d_name;
	struct inode___236 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___235 *d_op;
	struct super_block___235 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct rw_semaphore___237 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___237 *owner;
};

struct address_space_operations___235;

struct address_space___235 {
	struct inode___236 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___237 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___235 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___235;

struct bdi_writeback___112;

struct block_device___236;

struct inode___236 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___235 *i_op;
	struct super_block___235 *i_sb;
	struct address_space___235 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___237 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___112 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___236 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___235 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___236 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___235;

struct dentry_operations___235 {
	int (*d_revalidate)(struct dentry___236 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___236 *, unsigned int);
	int (*d_hash)(const struct dentry___236 *, struct qstr *);
	int (*d_compare)(const struct dentry___236 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___236 *);
	int (*d_init)(struct dentry___236 *);
	void (*d_release)(struct dentry___236 *);
	void (*d_prune)(struct dentry___236 *);
	void (*d_iput)(struct dentry___236 *, struct inode___236 *);
	char * (*d_dname)(struct dentry___236 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___235 *);
	int (*d_manage)(const struct path___235 *, bool);
	struct dentry___236 * (*d_real)(struct dentry___236 *, const struct inode___236 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___235;

struct mem_dqinfo___235 {
	struct quota_format_type___235 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___235;

struct quota_info___235 {
	unsigned int flags;
	struct rw_semaphore___237 dqio_sem;
	struct inode___236 *files[3];
	struct mem_dqinfo___235 info[3];
	const struct quota_format_ops___235 *ops[3];
};

struct rcuwait___235 {
	struct task_struct___237 *task;
};

struct percpu_rw_semaphore___235 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___237 rw_sem;
	struct rcuwait___235 writer;
	int readers_block;
};

struct sb_writers___235 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___235 rw_sem[3];
};

struct shrink_control___98;

struct shrinker___98 {
	long unsigned int (*count_objects)(struct shrinker___98 *, struct shrink_control___98 *);
	long unsigned int (*scan_objects)(struct shrinker___98 *, struct shrink_control___98 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___235;

struct super_operations___235;

struct dquot_operations___235;

struct quotactl_ops___235;

struct xattr_handler___21;

struct user_namespace___196;

struct super_block___235 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___235 *s_type;
	const struct super_operations___235 *s_op;
	const struct dquot_operations___235 *dq_op;
	const struct quotactl_ops___235 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___236 *s_root;
	struct rw_semaphore___237 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___21 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___236 *s_bdev;
	struct backing_dev_info___112 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___235 s_dquot;
	struct sb_writers___235 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___235 *s_d_op;
	int cleancache_poolid;
	struct shrinker___98 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___196 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct path___235 {
	struct vfsmount *mnt;
	struct dentry___236 *dentry;
};

struct key___229;

struct ucounts___196;

struct user_namespace___196 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___196 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___28 ns;
	long unsigned int flags;
	struct key___229 *persistent_keyring_register;
	struct rw_semaphore___237 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___196 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct shrink_control___98 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___98 *memcg;
};

struct cgroup___181;

struct cgroup_subsys___181;

struct cgroup_subsys_state___182 {
	struct cgroup___181 *cgroup;
	struct cgroup_subsys___181 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___182 *parent;
};

struct kernfs_node___230;

struct cgroup_file___181 {
	struct kernfs_node___230 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___98;

struct mem_cgroup___98 {
	struct cgroup_subsys_state___182 css;
	struct mem_cgroup_id___6 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___181 events_file;
	struct cgroup_file___181 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___237 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___98 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___237 *pgtable_t___236;

struct dev_pagemap___226;

struct page___237 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___235 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___237 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___236 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___236 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___226 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___98 *mem_cgroup;
};

struct pglist_data___236;

struct lruvec___236 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___236 *pgdat;
};

struct zone___236 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___236 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___236 {
	struct zone___236 *zone;
	int zone_idx;
};

struct zonelist___236 {
	struct zoneref___236 _zonerefs[25];
};

struct pglist_data___236 {
	struct zone___236 node_zones[3];
	struct zonelist___236 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___237 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___237 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___236 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___237 {
	void *stack;
	struct task_struct___237 *task;
	long int status;
};

struct blocking_notifier_head___236 {
	struct rw_semaphore___237 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___226;

struct vm_area_struct___237 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___237 *vm_next;
	struct vm_area_struct___237 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___236 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___226 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___236 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___236;

struct mm_struct___236 {
	struct {
		struct vm_area_struct___237 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___236 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___237 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___236 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___237 *owner;
		struct user_namespace___196 *user_ns;
		struct file___236 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___236 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___226)(struct vm_area_struct___237 *, long unsigned int, const struct page___237 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___226)(struct page___237 *, void *);

struct device___200;

struct dev_pagemap___226 {
	dev_page_fault_t___226 page_fault;
	dev_page_free_t___226 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___200 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct file___236 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___235 f_path;
	struct inode___236 *f_inode;
	const struct file_operations___236 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___176 f_owner;
	const struct cred___229 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___235 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___226;

struct vm_operations_struct___226 {
	void (*open)(struct vm_area_struct___237 *);
	void (*close)(struct vm_area_struct___237 *);
	int (*split)(struct vm_area_struct___237 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___237 *);
	vm_fault_t (*fault)(struct vm_fault___226 *);
	vm_fault_t (*huge_fault)(struct vm_fault___226 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___226 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___237 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___226 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___226 *);
	int (*access)(struct vm_area_struct___237 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___237 *);
	int (*set_policy)(struct vm_area_struct___237 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___237 *, long unsigned int);
	struct page___237 * (*find_special_page)(struct vm_area_struct___237 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___236 {
	struct task_struct___237 *task;
	struct core_thread___236 *next;
};

struct core_state___236 {
	atomic_t nr_threads;
	struct core_thread___236 dumper;
	struct completion startup;
};

struct vm_fault___226 {
	struct vm_area_struct___237 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___237 *cow_page;
	struct mem_cgroup___98 *memcg;
	struct page___237 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___236 prealloc_pte;
};

struct user_struct___229 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___229 *uid_keyring;
	struct key___229 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___229 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___229 *session_keyring;
	struct key___229 *process_keyring;
	struct key___229 *thread_keyring;
	struct key___229 *request_key_auth;
	void *security;
	struct user_struct___229 *user;
	struct user_namespace___196 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___181;

struct nsproxy___216 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___181 *cgroup_ns;
};

struct bio___112;

struct bio_list___112 {
	struct bio___112 *head;
	struct bio___112 *tail;
};

struct bdi_writeback_congested___112;

struct bdi_writeback___112 {
	struct backing_dev_info___112 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___112 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___182 *memcg_css;
	struct cgroup_subsys_state___182 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___112 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___112 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___200 *dev;
	struct device___200 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___236 *debug_dir;
	struct dentry___236 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___181 {
	struct cgroup_subsys_state___182 *subsys[13];
	refcount_t refcount;
	struct css_set___181 *dom_cset;
	struct cgroup___181 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___181 *mg_src_cgrp;
	struct cgroup___181 *mg_dst_cgrp;
	struct css_set___181 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct vm_struct___153 {
	struct vm_struct___153 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___237 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct kiocb___236 {
	struct file___236 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___236 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___235 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___236 *ia_file;
};

struct dquot___235 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___235 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___235 {
	int qf_fmt_id;
	const struct quota_format_ops___235 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___235 *qf_next;
};

struct quota_format_ops___235 {
	int (*check_quota_file)(struct super_block___235 *, int);
	int (*read_file_info)(struct super_block___235 *, int);
	int (*write_file_info)(struct super_block___235 *, int);
	int (*free_file_info)(struct super_block___235 *, int);
	int (*read_dqblk)(struct dquot___235 *);
	int (*commit_dqblk)(struct dquot___235 *);
	int (*release_dqblk)(struct dquot___235 *);
	int (*get_next_id)(struct super_block___235 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___235 {
	int (*write_dquot)(struct dquot___235 *);
	struct dquot___235 * (*alloc_dquot)(struct super_block___235 *, int);
	void (*destroy_dquot)(struct dquot___235 *);
	int (*acquire_dquot)(struct dquot___235 *);
	int (*release_dquot)(struct dquot___235 *);
	int (*mark_dirty)(struct dquot___235 *);
	int (*write_info)(struct super_block___235 *, int);
	qsize_t * (*get_reserved_space)(struct inode___236 *);
	int (*get_projid)(struct inode___236 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___236 *, qsize_t *);
	int (*get_next_id)(struct super_block___235 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___235 {
	int (*quota_on)(struct super_block___235 *, int, int, const struct path___235 *);
	int (*quota_off)(struct super_block___235 *, int);
	int (*quota_enable)(struct super_block___235 *, unsigned int);
	int (*quota_disable)(struct super_block___235 *, unsigned int);
	int (*quota_sync)(struct super_block___235 *, int);
	int (*set_info)(struct super_block___235 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___235 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___235 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___235 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___235 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___235 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___108;

struct swap_info_struct___69;

struct address_space_operations___235 {
	int (*writepage)(struct page___237 *, struct writeback_control___108 *);
	int (*readpage)(struct file___236 *, struct page___237 *);
	int (*writepages)(struct address_space___235 *, struct writeback_control___108 *);
	int (*set_page_dirty)(struct page___237 *);
	int (*readpages)(struct file___236 *, struct address_space___235 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___236 *, struct address_space___235 *, loff_t, unsigned int, unsigned int, struct page___237 **, void **);
	int (*write_end)(struct file___236 *, struct address_space___235 *, loff_t, unsigned int, unsigned int, struct page___237 *, void *);
	sector_t (*bmap)(struct address_space___235 *, sector_t);
	void (*invalidatepage)(struct page___237 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___237 *, gfp_t);
	void (*freepage)(struct page___237 *);
	ssize_t (*direct_IO)(struct kiocb___236 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___235 *, struct page___237 *, struct page___237 *, enum migrate_mode);
	bool (*isolate_page)(struct page___237 *, isolate_mode_t);
	void (*putback_page)(struct page___237 *);
	int (*launder_page)(struct page___237 *);
	int (*is_partially_uptodate)(struct page___237 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___237 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___235 *, struct page___237 *);
	int (*swap_activate)(struct swap_info_struct___69 *, struct file___236 *, sector_t *);
	void (*swap_deactivate)(struct file___236 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___108 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___112 *wb;
	struct inode___236 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct swap_info_struct___69 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___236 *bdev;
	struct file___236 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___236 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___236 *bd_inode;
	struct super_block___235 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___236 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___112 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___235 {
	struct dentry___236 * (*lookup)(struct inode___236 *, struct dentry___236 *, unsigned int);
	const char * (*get_link)(struct dentry___236 *, struct inode___236 *, struct delayed_call *);
	int (*permission)(struct inode___236 *, int);
	struct posix_acl * (*get_acl)(struct inode___236 *, int);
	int (*readlink)(struct dentry___236 *, char *, int);
	int (*create)(struct inode___236 *, struct dentry___236 *, umode_t, bool);
	int (*link)(struct dentry___236 *, struct inode___236 *, struct dentry___236 *);
	int (*unlink)(struct inode___236 *, struct dentry___236 *);
	int (*symlink)(struct inode___236 *, struct dentry___236 *, const char *);
	int (*mkdir)(struct inode___236 *, struct dentry___236 *, umode_t);
	int (*rmdir)(struct inode___236 *, struct dentry___236 *);
	int (*mknod)(struct inode___236 *, struct dentry___236 *, umode_t, dev_t);
	int (*rename)(struct inode___236 *, struct dentry___236 *, struct inode___236 *, struct dentry___236 *, unsigned int);
	int (*setattr)(struct dentry___236 *, struct iattr___235 *);
	int (*getattr)(const struct path___235 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___236 *, char *, size_t);
	int (*fiemap)(struct inode___236 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___236 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___236 *, struct dentry___236 *, struct file___236 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___236 *, struct dentry___236 *, umode_t);
	int (*set_acl)(struct inode___236 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___235 {
	void (*fl_copy_lock)(struct file_lock___236 *, struct file_lock___236 *);
	void (*fl_release_private)(struct file_lock___236 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___235;

struct lock_manager_operations___235;

struct file_lock___236 {
	struct file_lock___236 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___236 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___235 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___235 *fl_ops;
	const struct lock_manager_operations___235 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___235 {
	int (*lm_compare_owner)(struct file_lock___236 *, struct file_lock___236 *);
	long unsigned int (*lm_owner_key)(struct file_lock___236 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___236 *);
	int (*lm_grant)(struct file_lock___236 *, int);
	bool (*lm_break)(struct file_lock___236 *);
	int (*lm_change)(struct file_lock___236 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___236 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___235 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___235 *fa_next;
	struct file___236 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___235 {
	const char *name;
	int fs_flags;
	struct dentry___236 * (*mount)(struct file_system_type___235 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___235 *);
	struct module___11 *owner;
	struct file_system_type___235 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___235 {
	struct inode___236 * (*alloc_inode)(struct super_block___235 *);
	void (*destroy_inode)(struct inode___236 *);
	void (*dirty_inode)(struct inode___236 *, int);
	int (*write_inode)(struct inode___236 *, struct writeback_control___108 *);
	int (*drop_inode)(struct inode___236 *);
	void (*evict_inode)(struct inode___236 *);
	void (*put_super)(struct super_block___235 *);
	int (*sync_fs)(struct super_block___235 *, int);
	int (*freeze_super)(struct super_block___235 *);
	int (*freeze_fs)(struct super_block___235 *);
	int (*thaw_super)(struct super_block___235 *);
	int (*unfreeze_fs)(struct super_block___235 *);
	int (*statfs)(struct dentry___236 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___235 *, int *, char *);
	void (*umount_begin)(struct super_block___235 *);
	int (*show_options)(struct seq_file___212 *, struct dentry___236 *);
	int (*show_devname)(struct seq_file___212 *, struct dentry___236 *);
	int (*show_path)(struct seq_file___212 *, struct dentry___236 *);
	int (*show_stats)(struct seq_file___212 *, struct dentry___236 *);
	ssize_t (*quota_read)(struct super_block___235 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___235 *, int, const char *, size_t, loff_t);
	struct dquot___235 ** (*get_dquots)(struct inode___236 *);
	int (*bdev_try_to_free_page)(struct super_block___235 *, struct page___237 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___235 *, struct shrink_control___98 *);
	long int (*free_cached_objects)(struct super_block___235 *, struct shrink_control___98 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct xattr_handler___21 {
	const char *name;
	const char *prefix;
	int flags;
	bool (*list)(struct dentry___236 *);
	int (*get)(const struct xattr_handler___21 *, struct dentry___236 *, struct inode___236 *, const char *, void *, size_t);
	int (*set)(const struct xattr_handler___21 *, struct dentry___236 *, struct inode___236 *, const char *, const void *, size_t, int);
};

struct seq_operations___210;

struct seq_file___212 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___210 *op;
	int poll_event;
	const struct file___236 *file;
	void *private;
};

struct kset___223;

struct kobj_type___223;

struct kobject___224 {
	const char *name;
	struct list_head entry;
	struct kobject___224 *parent;
	struct kset___223 *kset;
	struct kobj_type___223 *ktype;
	struct kernfs_node___230 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___112(struct bio___112 *);

struct bio_vec___112 {
	struct page___237 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___112;

struct bio_set___112;

struct bio___112 {
	struct bio___112 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___112 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___112 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___112 *bi_io_vec;
	struct bio_set___112 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___112 bi_inline_vecs[0];
};

struct key_type___5;

struct keyring_index_key___5 {
	struct key_type___5 *type;
	const char *description;
	size_t desc_len;
};

struct key_construction___5;

typedef int (*request_key_actor_t___5)(struct key_construction___5 *, const char *, void *);

struct key_match_data___5;

struct key_restriction___229;

struct key_type___5 {
	const char *name;
	size_t def_datalen;
	int (*vet_description)(const char *);
	int (*preparse)(struct key_preparsed_payload *);
	void (*free_preparse)(struct key_preparsed_payload *);
	int (*instantiate)(struct key___229 *, struct key_preparsed_payload *);
	int (*update)(struct key___229 *, struct key_preparsed_payload *);
	int (*match_preparse)(struct key_match_data___5 *);
	void (*match_free)(struct key_match_data___5 *);
	void (*revoke)(struct key___229 *);
	void (*destroy)(struct key___229 *);
	void (*describe)(const struct key___229 *, struct seq_file___212 *);
	long int (*read)(const struct key___229 *, char *, size_t);
	request_key_actor_t___5 request_key;
	struct key_restriction___229 * (*lookup_restriction)(const char *);
	struct list_head link;
	struct lock_class_key lock_class;
};

typedef int (*key_restrict_link_func_t___229)(struct key___229 *, const struct key_type___5 *, const union key_payload *, struct key___229 *);

struct key___229 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___237 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key___5 index_key;
		struct {
			struct key_type___5 *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___229 *restrict_link;
};

struct key_restriction___229 {
	key_restrict_link_func_t___229 check;
	struct key___229 *key;
	struct key_type___5 *keytype;
};

struct seq_operations___210 {
	void * (*start)(struct seq_file___212 *, loff_t *);
	void (*stop)(struct seq_file___212 *, void *);
	void * (*next)(struct seq_file___212 *, void *, loff_t *);
	int (*show)(struct seq_file___212 *, void *);
};

struct kernfs_root___230;

struct kernfs_elem_dir___230 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___230 *root;
};

struct kernfs_syscall_ops___230;

struct kernfs_root___230 {
	struct kernfs_node___230 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___230 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___230 {
	struct kernfs_node___230 *target_kn;
};

struct kernfs_ops___230;

struct kernfs_elem_attr___230 {
	const struct kernfs_ops___230 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___230 *notify_next;
};

struct kernfs_node___230 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___230 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___230 dir;
		struct kernfs_elem_symlink___230 symlink;
		struct kernfs_elem_attr___230 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___230;

struct kernfs_ops___230 {
	int (*open)(struct kernfs_open_file___230 *);
	void (*release)(struct kernfs_open_file___230 *);
	int (*seq_show)(struct seq_file___212 *, void *);
	void * (*seq_start)(struct seq_file___212 *, loff_t *);
	void * (*seq_next)(struct seq_file___212 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___212 *, void *);
	ssize_t (*read)(struct kernfs_open_file___230 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___230 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___230 *, struct vm_area_struct___237 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___230 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___230 {
	int (*remount_fs)(struct kernfs_root___230 *, int *, char *);
	int (*show_options)(struct seq_file___212 *, struct kernfs_root___230 *);
	int (*mkdir)(struct kernfs_node___230 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___230 *);
	int (*rename)(struct kernfs_node___230 *, struct kernfs_node___230 *, const char *);
	int (*show_path)(struct seq_file___212 *, struct kernfs_node___230 *, struct kernfs_root___230 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___230 {
	struct kernfs_node___230 *kn;
	struct file___236 *file;
	struct seq_file___212 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___226 *vm_ops;
};

struct cgroup_namespace___181 {
	refcount_t count;
	struct ns_common___28 ns;
	struct user_namespace___196 *user_ns;
	struct ucounts___196 *ucounts;
	struct css_set___181 *root_cset;
};

struct ucounts___196 {
	struct hlist_node node;
	struct user_namespace___196 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___181;

struct bpf_map_ops___181 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___181 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___181 *, struct file___236 *);
	void (*map_free)(struct bpf_map___181 *);
	int (*map_get_next_key)(struct bpf_map___181 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___181 *);
	void * (*map_lookup_elem)(struct bpf_map___181 *, void *);
	int (*map_update_elem)(struct bpf_map___181 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___181 *, void *);
	int (*map_push_elem)(struct bpf_map___181 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___181 *, void *);
	int (*map_peek_elem)(struct bpf_map___181 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___181 *, struct file___236 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___181 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___181 *, void *, struct seq_file___212 *);
	int (*map_check_btf)(const struct bpf_map___181 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___181 {
	const struct bpf_map_ops___181 *ops;
	struct bpf_map___181 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___229 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___181;

typedef void (*kthread_work_func_t___181)(struct kthread_work___181 *);

struct kthread_worker___181;

struct kthread_work___181 {
	struct list_head node;
	kthread_work_func_t___181 func;
	struct kthread_worker___181 *worker;
	int canceling;
};

struct kthread_worker___181 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___237 *task;
	struct kthread_work___181 *current_work;
};

struct kthread_delayed_work___181 {
	struct kthread_work___181 work;
	struct timer_list timer;
};

struct psi_group___181 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___181 *poll_kworker;
	struct kthread_delayed_work___181 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___181;

struct cgroup_rstat_cpu___181;

struct cgroup___181 {
	struct cgroup_subsys_state___182 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___230 *kn;
	struct cgroup_file___181 procs_file;
	struct cgroup_file___181 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___182 *subsys[13];
	struct cgroup_root___181 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___181 *dom_cgrp;
	struct cgroup_rstat_cpu___181 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___23 bpf;
	atomic_t congestion_count;
	struct cgroup___181 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___181 psi;
	int ancestor_ids[0];
};

struct cftype___181;

struct cgroup_subsys___181 {
	struct cgroup_subsys_state___182 * (*css_alloc)(struct cgroup_subsys_state___182 *);
	int (*css_online)(struct cgroup_subsys_state___182 *);
	void (*css_offline)(struct cgroup_subsys_state___182 *);
	void (*css_released)(struct cgroup_subsys_state___182 *);
	void (*css_free)(struct cgroup_subsys_state___182 *);
	void (*css_reset)(struct cgroup_subsys_state___182 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___182 *, int);
	int (*css_extra_stat_show)(struct seq_file___212 *, struct cgroup_subsys_state___182 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___237 *);
	void (*cancel_fork)(struct task_struct___237 *);
	void (*fork)(struct task_struct___237 *);
	void (*exit)(struct task_struct___237 *);
	void (*free)(struct task_struct___237 *);
	void (*bind)(struct cgroup_subsys_state___182 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___181 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___181 *dfl_cftypes;
	struct cftype___181 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___181 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___181 *updated_children;
	struct cgroup___181 *updated_next;
};

struct cgroup_root___181 {
	struct kernfs_root___230 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___181 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___181 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___181 *ss;
	struct list_head node;
	struct kernfs_ops___230 *kf_ops;
	int (*open)(struct kernfs_open_file___230 *);
	void (*release)(struct kernfs_open_file___230 *);
	u64 (*read_u64)(struct cgroup_subsys_state___182 *, struct cftype___181 *);
	s64 (*read_s64)(struct cgroup_subsys_state___182 *, struct cftype___181 *);
	int (*seq_show)(struct seq_file___212 *, void *);
	void * (*seq_start)(struct seq_file___212 *, loff_t *);
	void * (*seq_next)(struct seq_file___212 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___212 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___182 *, struct cftype___181 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___182 *, struct cftype___181 *, s64);
	ssize_t (*write)(struct kernfs_open_file___230 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___230 *, struct poll_table_struct___6 *);
};

struct dev_pm_info___200 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___200 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___200;

struct bus_type___200;

struct device_driver___200;

struct dev_pm_domain___200;

struct fwnode_handle___135;

struct class___200;

struct attribute_group___202;

struct device___200 {
	struct device___200 *parent;
	struct device_private *p;
	struct kobject___224 kobj;
	const char *init_name;
	const struct device_type___200 *type;
	struct mutex mutex;
	struct bus_type___200 *bus;
	struct device_driver___200 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___200 power;
	struct dev_pm_domain___200 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___135 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___200 *class;
	const struct attribute_group___202 **groups;
	void (*release)(struct device___200 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct kobj_attribute___217 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___224 *, struct kobj_attribute___217 *, char *);
	ssize_t (*store)(struct kobject___224 *, struct kobj_attribute___217 *, const char *, size_t);
};

typedef void compound_page_dtor___226(struct page___237 *);

struct bdi_writeback_congested___112 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___112 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___112 {
	struct bio___112 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___112 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___112 bip_inline_vecs[0];
};

struct bio_set___112 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___112 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___98 {
	struct mem_cgroup___98 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___98 {
	struct lruvec___236 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___98 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___98 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct bin_attribute___201;

struct attribute_group___202 {
	const char *name;
	umode_t (*is_visible)(struct kobject___224 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___224 *, struct bin_attribute___201 *, int);
	struct attribute **attrs;
	struct bin_attribute___201 **bin_attrs;
};

struct bin_attribute___201 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___236 *, struct kobject___224 *, struct bin_attribute___201 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___236 *, struct kobject___224 *, struct bin_attribute___201 *, char *, loff_t, size_t);
	int (*mmap)(struct file___236 *, struct kobject___224 *, struct bin_attribute___201 *, struct vm_area_struct___237 *);
};

struct sysfs_ops___223 {
	ssize_t (*show)(struct kobject___224 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___224 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___223;

struct kset___223 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___224 kobj;
	const struct kset_uevent_ops___223 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___223 {
	void (*release)(struct kobject___224 *);
	const struct sysfs_ops___223 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___13 * (*child_ns_type)(struct kobject___224 *);
	const void * (*namespace)(struct kobject___224 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___223 {
	int (* const filter)(struct kset___223 *, struct kobject___224 *);
	const char * (* const name)(struct kset___223 *, struct kobject___224 *);
	int (* const uevent)(struct kset___223 *, struct kobject___224 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___200 {
	int (*prepare)(struct device___200 *);
	void (*complete)(struct device___200 *);
	int (*suspend)(struct device___200 *);
	int (*resume)(struct device___200 *);
	int (*freeze)(struct device___200 *);
	int (*thaw)(struct device___200 *);
	int (*poweroff)(struct device___200 *);
	int (*restore)(struct device___200 *);
	int (*suspend_late)(struct device___200 *);
	int (*resume_early)(struct device___200 *);
	int (*freeze_late)(struct device___200 *);
	int (*thaw_early)(struct device___200 *);
	int (*poweroff_late)(struct device___200 *);
	int (*restore_early)(struct device___200 *);
	int (*suspend_noirq)(struct device___200 *);
	int (*resume_noirq)(struct device___200 *);
	int (*freeze_noirq)(struct device___200 *);
	int (*thaw_noirq)(struct device___200 *);
	int (*poweroff_noirq)(struct device___200 *);
	int (*restore_noirq)(struct device___200 *);
	int (*runtime_suspend)(struct device___200 *);
	int (*runtime_resume)(struct device___200 *);
	int (*runtime_idle)(struct device___200 *);
};

struct dev_pm_domain___200 {
	struct dev_pm_ops___200 ops;
	void (*detach)(struct device___200 *, bool);
	int (*activate)(struct device___200 *);
	void (*sync)(struct device___200 *);
	void (*dismiss)(struct device___200 *);
};

struct bus_type___200 {
	const char *name;
	const char *dev_name;
	struct device___200 *dev_root;
	const struct attribute_group___202 **bus_groups;
	const struct attribute_group___202 **dev_groups;
	const struct attribute_group___202 **drv_groups;
	int (*match)(struct device___200 *, struct device_driver___200 *);
	int (*uevent)(struct device___200 *, struct kobj_uevent_env *);
	int (*probe)(struct device___200 *);
	int (*remove)(struct device___200 *);
	void (*shutdown)(struct device___200 *);
	int (*online)(struct device___200 *);
	int (*offline)(struct device___200 *);
	int (*suspend)(struct device___200 *, pm_message_t);
	int (*resume)(struct device___200 *);
	int (*num_vf)(struct device___200 *);
	int (*dma_configure)(struct device___200 *);
	const struct dev_pm_ops___200 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___200 {
	const char *name;
	struct bus_type___200 *bus;
	struct module___11 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___200 *);
	int (*remove)(struct device___200 *);
	void (*shutdown)(struct device___200 *);
	int (*suspend)(struct device___200 *, pm_message_t);
	int (*resume)(struct device___200 *);
	const struct attribute_group___202 **groups;
	const struct dev_pm_ops___200 *pm;
	void (*coredump)(struct device___200 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___200 {
	const char *name;
	const struct attribute_group___202 **groups;
	int (*uevent)(struct device___200 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___200 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___200 *);
	const struct dev_pm_ops___200 *pm;
};

struct class___200 {
	const char *name;
	struct module___11 *owner;
	const struct attribute_group___202 **class_groups;
	const struct attribute_group___202 **dev_groups;
	struct kobject___224 *dev_kobj;
	int (*dev_uevent)(struct device___200 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___200 *, umode_t *);
	void (*class_release)(struct class___200 *);
	void (*dev_release)(struct device___200 *);
	int (*shutdown_pre)(struct device___200 *);
	const struct kobj_ns_type_operations___13 *ns_type;
	const void * (*namespace)(struct device___200 *);
	const struct dev_pm_ops___200 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct fwnode_operations___135;

struct fwnode_handle___135 {
	struct fwnode_handle___135 *secondary;
	const struct fwnode_operations___135 *ops;
};

struct node___167 {
	struct device___200 dev;
};

struct fwnode_reference_args___135;

struct fwnode_endpoint___135;

struct fwnode_operations___135 {
	struct fwnode_handle___135 * (*get)(struct fwnode_handle___135 *);
	void (*put)(struct fwnode_handle___135 *);
	bool (*device_is_available)(const struct fwnode_handle___135 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___135 *, const struct device___200 *);
	bool (*property_present)(const struct fwnode_handle___135 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___135 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___135 *, const char *, const char **, size_t);
	struct fwnode_handle___135 * (*get_parent)(const struct fwnode_handle___135 *);
	struct fwnode_handle___135 * (*get_next_child_node)(const struct fwnode_handle___135 *, struct fwnode_handle___135 *);
	struct fwnode_handle___135 * (*get_named_child_node)(const struct fwnode_handle___135 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___135 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___135 *);
	struct fwnode_handle___135 * (*graph_get_next_endpoint)(const struct fwnode_handle___135 *, struct fwnode_handle___135 *);
	struct fwnode_handle___135 * (*graph_get_remote_endpoint)(const struct fwnode_handle___135 *);
	struct fwnode_handle___135 * (*graph_get_port_parent)(struct fwnode_handle___135 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___135 *, struct fwnode_endpoint___135 *);
};

struct fwnode_endpoint___135 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___135 *local_fwnode;
};

struct fwnode_reference_args___135 {
	struct fwnode_handle___135 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct key_construction___5 {
	struct key___229 *key;
	struct key___229 *authkey;
};

struct key_match_data___5 {
	bool (*cmp)(const struct key___229 *, const struct key_match_data___5 *);
	const void *raw_data;
	void *preparsed;
	unsigned int lookup_type;
};

struct big_key_buf {
	unsigned int nr_pages;
	void *virt;
	struct scatterlist *sg;
	struct page___237 *pages[0];
};

enum {
	big_key_data = 0,
	big_key_path = 1,
	big_key_path_2nd_part = 2,
	big_key_len = 3,
};

enum big_key_op {
	BIG_KEY_ENC = 0,
	BIG_KEY_DEC = 1,
};

struct vfs_cap_data {
	__le32 magic_etc;
	struct {
		__le32 permitted;
		__le32 inheritable;
	} data[2];
};

struct vfs_ns_cap_data {
	__le32 magic_etc;
	struct {
		__le32 permitted;
		__le32 inheritable;
	} data[2];
	__le32 rootid;
};

struct module___191;

struct file___237;

struct kiocb___237;

struct iov_iter___104;

struct vm_area_struct___238;

struct inode___237;

struct file_lock___237;

struct page___238;

struct pipe_inode_info___48;

struct seq_file___213;

struct file_operations___237 {
	struct module___191 *owner;
	loff_t (*llseek)(struct file___237 *, loff_t, int);
	ssize_t (*read)(struct file___237 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___237 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___237 *, struct iov_iter___104 *);
	ssize_t (*write_iter)(struct kiocb___237 *, struct iov_iter___104 *);
	int (*iopoll)(struct kiocb___237 *, bool);
	int (*iterate)(struct file___237 *, struct dir_context *);
	int (*iterate_shared)(struct file___237 *, struct dir_context *);
	__poll_t (*poll)(struct file___237 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___237 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___237 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___237 *, struct vm_area_struct___238 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___237 *, struct file___237 *);
	int (*flush)(struct file___237 *, fl_owner_t);
	int (*release)(struct inode___237 *, struct file___237 *);
	int (*fsync)(struct file___237 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___237 *, int);
	int (*lock)(struct file___237 *, int, struct file_lock___237 *);
	ssize_t (*sendpage)(struct file___237 *, struct page___238 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___237 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___237 *, int, struct file_lock___237 *);
	ssize_t (*splice_write)(struct pipe_inode_info___48 *, struct file___237 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___237 *, loff_t *, struct pipe_inode_info___48 *, size_t, unsigned int);
	int (*setlease)(struct file___237 *, long int, struct file_lock___237 **, void **);
	long int (*fallocate)(struct file___237 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___213 *, struct file___237 *);
	ssize_t (*copy_file_range)(struct file___237 *, loff_t, struct file___237 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___237 *, loff_t, struct file___237 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___237 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___237 {
	u64 seqnum;
	struct vm_area_struct___238 *vmas[4];
};

struct page_frag___237 {
	struct page___238 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___237;

struct mem_cgroup___99;

struct pid___177;

struct cred___230;

struct nsproxy___217;

struct signal_struct___195;

struct bio_list___113;

struct backing_dev_info___113;

struct css_set___182;

struct vm_struct___154;

struct task_struct___238 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___238 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___237 *mm;
	struct mm_struct___237 *active_mm;
	struct vmacache___237 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___238 *real_parent;
	struct task_struct___238 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___238 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___99 *active_memcg;
	long int rh_reserved2;
	struct pid___177 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___177 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___177 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___230 *ptracer_cred;
	const struct cred___230 *real_cred;
	const struct cred___230 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___217 *nsproxy;
	struct signal_struct___195 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___238 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___113 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___113 *backing_dev_info;
	struct io_context___58 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___182 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___48 *splice_pipe;
	struct page_frag___237 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___99 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___238 *oom_reaper_list;
	struct vm_struct___154 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___126 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___177;

struct upid___177 {
	int nr;
	struct pid_namespace___177 *ns;
};

struct vfsmount___61;

struct dentry___237;

struct user_namespace___197;

struct ucounts___197;

struct pid_namespace___177 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___238 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___177 *parent;
	struct vfsmount___61 *proc_mnt;
	struct dentry___237 *proc_self;
	struct dentry___237 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___197 *user_ns;
	struct ucounts___197 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___28 ns;
};

struct pid___177 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___177 numbers[1];
};

struct rw_semaphore___238 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___238 *owner;
};

struct key___230;

struct user_namespace___197 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___197 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___28 ns;
	long unsigned int flags;
	struct key___230 *persistent_keyring_register;
	struct rw_semaphore___238 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___197 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct secondary_data___238 {
	void *stack;
	struct task_struct___238 *task;
	long int status;
};

typedef struct page___238 *pgtable_t___237;

struct address_space___236;

struct dev_pagemap___227;

struct page___238 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___236 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___238 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___237 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___237 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___227 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___99 *mem_cgroup;
};

struct user_struct___230 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___230 *uid_keyring;
	struct key___230 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___227;

struct vm_area_struct___238 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___238 *vm_next;
	struct vm_area_struct___238 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___237 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___227 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___237 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct linux_binfmt___37;

struct core_state___237;

struct mm_struct___237 {
	struct {
		struct vm_area_struct___238 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___237 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___238 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___37 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___237 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___238 *owner;
		struct user_namespace___197 *user_ns;
		struct file___237 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___237 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup___182;

struct cgroup_subsys___182;

struct cgroup_subsys_state___183 {
	struct cgroup___182 *cgroup;
	struct cgroup_subsys___182 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___183 *parent;
};

struct kernfs_node___231;

struct cgroup_file___182 {
	struct kernfs_node___231 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___99;

struct mem_cgroup___99 {
	struct cgroup_subsys_state___183 css;
	struct mem_cgroup_id___5 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___182 events_file;
	struct cgroup_file___182 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___238 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___99 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cred___230 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___230 *session_keyring;
	struct key___230 *process_keyring;
	struct key___230 *thread_keyring;
	struct key___230 *request_key_auth;
	void *security;
	struct user_struct___230 *user;
	struct user_namespace___197 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___182;

struct nsproxy___217 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___177 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___182 *cgroup_ns;
};

struct signal_struct___195 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___238 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___238 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___177 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___177 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___237 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___177 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___113;

struct bio_list___113 {
	struct bio___113 *head;
	struct bio___113 *tail;
};

struct bdi_writeback_congested___113;

struct bdi_writeback___113 {
	struct backing_dev_info___113 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___113 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___183 *memcg_css;
	struct cgroup_subsys_state___183 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___201;

struct backing_dev_info___113 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___113 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___201 *dev;
	struct device___201 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___237 *debug_dir;
	struct dentry___237 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___182 {
	struct cgroup_subsys_state___183 *subsys[13];
	refcount_t refcount;
	struct css_set___182 *dom_cset;
	struct cgroup___182 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___182 *mg_src_cgrp;
	struct cgroup___182 *mg_dst_cgrp;
	struct css_set___182 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___236;

struct pipe_buffer___48;

struct pipe_inode_info___48 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___238 *tmp_page;
	struct fasync_struct___236 *fasync_readers;
	struct fasync_struct___236 *fasync_writers;
	struct pipe_buffer___48 *bufs;
	struct user_struct___230 *user;
};

struct vm_struct___154 {
	struct vm_struct___154 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___238 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___207 {
	struct task_struct___238 task;
	long unsigned int stack[8192];
};

typedef int (*key_restrict_link_func_t___230)(struct key___230 *, const struct key_type *, const union key_payload *, struct key___230 *);

struct key_restriction___230;

struct key___230 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___238 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key___5 index_key;
		struct {
			struct key_type___5 *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___230 *restrict_link;
};

struct key_restriction___230 {
	key_restrict_link_func_t___230 check;
	struct key___230 *key;
	struct key_type *keytype;
};

struct pglist_data___237;

struct lruvec___237 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___237 *pgdat;
};

struct zone___237 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___237 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___237 {
	struct zone___237 *zone;
	int zone_idx;
};

struct zonelist___237 {
	struct zoneref___237 _zonerefs[25];
};

struct pglist_data___237 {
	struct zone___237 node_zones[3];
	struct zonelist___237 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___238 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___238 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___237 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___237 {
	struct rw_semaphore___238 rwsem;
	struct notifier_block *head;
};

struct address_space_operations___236;

struct address_space___236 {
	struct inode___237 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___238 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___236 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___227)(struct vm_area_struct___238 *, long unsigned int, const struct page___238 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___227)(struct page___238 *, void *);

struct dev_pagemap___227 {
	dev_page_fault_t___227 page_fault;
	dev_page_free_t___227 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___201 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___236 {
	struct vfsmount___61 *mnt;
	struct dentry___237 *dentry;
};

struct fown_struct___177 {
	rwlock_t lock;
	struct pid___177 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___237 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___236 f_path;
	struct inode___237 *f_inode;
	const struct file_operations___237 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___177 f_owner;
	const struct cred___230 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___236 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___227;

struct vm_operations_struct___227 {
	void (*open)(struct vm_area_struct___238 *);
	void (*close)(struct vm_area_struct___238 *);
	int (*split)(struct vm_area_struct___238 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___238 *);
	vm_fault_t (*fault)(struct vm_fault___227 *);
	vm_fault_t (*huge_fault)(struct vm_fault___227 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___227 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___238 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___227 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___227 *);
	int (*access)(struct vm_area_struct___238 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___238 *);
	int (*set_policy)(struct vm_area_struct___238 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___238 *, long unsigned int);
	struct page___238 * (*find_special_page)(struct vm_area_struct___238 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___237 {
	struct task_struct___238 *task;
	struct core_thread___237 *next;
};

struct core_state___237 {
	atomic_t nr_threads;
	struct core_thread___237 dumper;
	struct completion startup;
};

struct linux_binprm___38;

struct coredump_params___37;

struct linux_binfmt___37 {
	struct list_head lh;
	struct module___191 *module;
	int (*load_binary)(struct linux_binprm___38 *);
	int (*load_shlib)(struct file___237 *);
	int (*core_dump)(struct coredump_params___37 *);
	long unsigned int min_coredump;
};

struct vm_fault___227 {
	struct vm_area_struct___238 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___238 *cow_page;
	struct mem_cgroup___99 *memcg;
	struct page___238 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___237 prealloc_pte;
};

struct shrink_control___99 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___99 *memcg;
};

struct shrinker___99 {
	long unsigned int (*count_objects)(struct shrinker___99 *, struct shrink_control___99 *);
	long unsigned int (*scan_objects)(struct shrinker___99 *, struct shrink_control___99 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct kset___224;

struct kobj_type___224;

struct kobject___225 {
	const char *name;
	struct list_head entry;
	struct kobject___225 *parent;
	struct kset___224 *kset;
	struct kobj_type___224 *ktype;
	struct kernfs_node___231 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___201 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___201 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___201;

struct bus_type___201;

struct device_driver___201;

struct dev_pm_domain___201;

struct dma_map_ops___45;

struct fwnode_handle___136;

struct class___201;

struct attribute_group___203;

struct device___201 {
	struct device___201 *parent;
	struct device_private *p;
	struct kobject___225 kobj;
	const char *init_name;
	const struct device_type___201 *type;
	struct mutex mutex;
	struct bus_type___201 *bus;
	struct device_driver___201 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___201 power;
	struct dev_pm_domain___201 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___45 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___136 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___201 *class;
	const struct attribute_group___203 **groups;
	void (*release)(struct device___201 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___236;

struct super_block___236;

struct dentry___237 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___237 *d_parent;
	struct qstr d_name;
	struct inode___237 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___236 *d_op;
	struct super_block___236 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___236;

struct block_device___237;

struct inode___237 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___236 *i_op;
	struct super_block___236 *i_sb;
	struct address_space___236 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___238 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___113 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___237 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___236 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___48 *i_pipe;
		struct block_device___237 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___236 {
	int (*d_revalidate)(struct dentry___237 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___237 *, unsigned int);
	int (*d_hash)(const struct dentry___237 *, struct qstr *);
	int (*d_compare)(const struct dentry___237 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___237 *);
	int (*d_init)(struct dentry___237 *);
	void (*d_release)(struct dentry___237 *);
	void (*d_prune)(struct dentry___237 *);
	void (*d_iput)(struct dentry___237 *, struct inode___237 *);
	char * (*d_dname)(struct dentry___237 *, char *, int);
	struct vfsmount___61 * (*d_automount)(struct path___236 *);
	int (*d_manage)(const struct path___236 *, bool);
	struct dentry___237 * (*d_real)(struct dentry___237 *, const struct inode___237 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___236;

struct mem_dqinfo___236 {
	struct quota_format_type___236 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___236;

struct quota_info___236 {
	unsigned int flags;
	struct rw_semaphore___238 dqio_sem;
	struct inode___237 *files[3];
	struct mem_dqinfo___236 info[3];
	const struct quota_format_ops___236 *ops[3];
};

struct rcuwait___236 {
	struct task_struct___238 *task;
};

struct percpu_rw_semaphore___236 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___238 rw_sem;
	struct rcuwait___236 writer;
	int readers_block;
};

struct sb_writers___236 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___236 rw_sem[3];
};

struct file_system_type___236;

struct super_operations___236;

struct dquot_operations___236;

struct quotactl_ops___236;

struct xattr_handler___22;

struct super_block___236 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___236 *s_type;
	const struct super_operations___236 *s_op;
	const struct dquot_operations___236 *dq_op;
	const struct quotactl_ops___236 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___237 *s_root;
	struct rw_semaphore___238 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___22 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___237 *s_bdev;
	struct backing_dev_info___113 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___236 s_dquot;
	struct sb_writers___236 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___236 *s_d_op;
	int cleancache_poolid;
	struct shrinker___99 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___197 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___61 {
	struct dentry___237 *mnt_root;
	struct super_block___236 *mnt_sb;
	int mnt_flags;
};

struct kiocb___237 {
	struct file___237 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___237 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___236 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___237 *ia_file;
};

struct dquot___236 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___236 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___236 {
	int qf_fmt_id;
	const struct quota_format_ops___236 *qf_ops;
	struct module___191 *qf_owner;
	struct quota_format_type___236 *qf_next;
};

struct quota_format_ops___236 {
	int (*check_quota_file)(struct super_block___236 *, int);
	int (*read_file_info)(struct super_block___236 *, int);
	int (*write_file_info)(struct super_block___236 *, int);
	int (*free_file_info)(struct super_block___236 *, int);
	int (*read_dqblk)(struct dquot___236 *);
	int (*commit_dqblk)(struct dquot___236 *);
	int (*release_dqblk)(struct dquot___236 *);
	int (*get_next_id)(struct super_block___236 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___236 {
	int (*write_dquot)(struct dquot___236 *);
	struct dquot___236 * (*alloc_dquot)(struct super_block___236 *, int);
	void (*destroy_dquot)(struct dquot___236 *);
	int (*acquire_dquot)(struct dquot___236 *);
	int (*release_dquot)(struct dquot___236 *);
	int (*mark_dirty)(struct dquot___236 *);
	int (*write_info)(struct super_block___236 *, int);
	qsize_t * (*get_reserved_space)(struct inode___237 *);
	int (*get_projid)(struct inode___237 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___237 *, qsize_t *);
	int (*get_next_id)(struct super_block___236 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___236 {
	int (*quota_on)(struct super_block___236 *, int, int, const struct path___236 *);
	int (*quota_off)(struct super_block___236 *, int);
	int (*quota_enable)(struct super_block___236 *, unsigned int);
	int (*quota_disable)(struct super_block___236 *, unsigned int);
	int (*quota_sync)(struct super_block___236 *, int);
	int (*set_info)(struct super_block___236 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___236 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___236 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___236 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___236 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___236 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___188 {
	struct kobject___225 kobj;
	struct module___191 *mod;
	struct kobject___225 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___188 {
	struct module___191 *mod;
	struct latch_tree_node node;
};

struct module_layout___188 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___188 mtn;
};

struct module_attribute___188;

struct kernel_param___188;

struct module___191 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___188 mkobj;
	struct module_attribute___188 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___225 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___188 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___188 core_layout;
	struct module_layout___188 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___109;

struct swap_info_struct___70;

struct address_space_operations___236 {
	int (*writepage)(struct page___238 *, struct writeback_control___109 *);
	int (*readpage)(struct file___237 *, struct page___238 *);
	int (*writepages)(struct address_space___236 *, struct writeback_control___109 *);
	int (*set_page_dirty)(struct page___238 *);
	int (*readpages)(struct file___237 *, struct address_space___236 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___237 *, struct address_space___236 *, loff_t, unsigned int, unsigned int, struct page___238 **, void **);
	int (*write_end)(struct file___237 *, struct address_space___236 *, loff_t, unsigned int, unsigned int, struct page___238 *, void *);
	sector_t (*bmap)(struct address_space___236 *, sector_t);
	void (*invalidatepage)(struct page___238 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___238 *, gfp_t);
	void (*freepage)(struct page___238 *);
	ssize_t (*direct_IO)(struct kiocb___237 *, struct iov_iter___104 *);
	int (*migratepage)(struct address_space___236 *, struct page___238 *, struct page___238 *, enum migrate_mode);
	bool (*isolate_page)(struct page___238 *, isolate_mode_t);
	void (*putback_page)(struct page___238 *);
	int (*launder_page)(struct page___238 *);
	int (*is_partially_uptodate)(struct page___238 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___238 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___236 *, struct page___238 *);
	int (*swap_activate)(struct swap_info_struct___70 *, struct file___237 *, sector_t *);
	void (*swap_deactivate)(struct file___237 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___109 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___113 *wb;
	struct inode___237 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___113;

struct iov_iter___104 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___113 *bvec;
		struct pipe_inode_info___48 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct swap_info_struct___70 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___237 *bdev;
	struct file___237 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___237 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___237 *bd_inode;
	struct super_block___236 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___237 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___113 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___236 {
	struct dentry___237 * (*lookup)(struct inode___237 *, struct dentry___237 *, unsigned int);
	const char * (*get_link)(struct dentry___237 *, struct inode___237 *, struct delayed_call *);
	int (*permission)(struct inode___237 *, int);
	struct posix_acl * (*get_acl)(struct inode___237 *, int);
	int (*readlink)(struct dentry___237 *, char *, int);
	int (*create)(struct inode___237 *, struct dentry___237 *, umode_t, bool);
	int (*link)(struct dentry___237 *, struct inode___237 *, struct dentry___237 *);
	int (*unlink)(struct inode___237 *, struct dentry___237 *);
	int (*symlink)(struct inode___237 *, struct dentry___237 *, const char *);
	int (*mkdir)(struct inode___237 *, struct dentry___237 *, umode_t);
	int (*rmdir)(struct inode___237 *, struct dentry___237 *);
	int (*mknod)(struct inode___237 *, struct dentry___237 *, umode_t, dev_t);
	int (*rename)(struct inode___237 *, struct dentry___237 *, struct inode___237 *, struct dentry___237 *, unsigned int);
	int (*setattr)(struct dentry___237 *, struct iattr___236 *);
	int (*getattr)(const struct path___236 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___237 *, char *, size_t);
	int (*fiemap)(struct inode___237 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___237 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___237 *, struct dentry___237 *, struct file___237 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___237 *, struct dentry___237 *, umode_t);
	int (*set_acl)(struct inode___237 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___236 {
	void (*fl_copy_lock)(struct file_lock___237 *, struct file_lock___237 *);
	void (*fl_release_private)(struct file_lock___237 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___236;

struct file_lock___237 {
	struct file_lock___237 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___237 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___236 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___236 *fl_ops;
	const struct lock_manager_operations___236 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___236 {
	int (*lm_compare_owner)(struct file_lock___237 *, struct file_lock___237 *);
	long unsigned int (*lm_owner_key)(struct file_lock___237 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___237 *);
	int (*lm_grant)(struct file_lock___237 *, int);
	bool (*lm_break)(struct file_lock___237 *);
	int (*lm_change)(struct file_lock___237 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___237 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___236 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___236 *fa_next;
	struct file___237 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___236 {
	const char *name;
	int fs_flags;
	struct dentry___237 * (*mount)(struct file_system_type___236 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___236 *);
	struct module___191 *owner;
	struct file_system_type___236 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___236 {
	struct inode___237 * (*alloc_inode)(struct super_block___236 *);
	void (*destroy_inode)(struct inode___237 *);
	void (*dirty_inode)(struct inode___237 *, int);
	int (*write_inode)(struct inode___237 *, struct writeback_control___109 *);
	int (*drop_inode)(struct inode___237 *);
	void (*evict_inode)(struct inode___237 *);
	void (*put_super)(struct super_block___236 *);
	int (*sync_fs)(struct super_block___236 *, int);
	int (*freeze_super)(struct super_block___236 *);
	int (*freeze_fs)(struct super_block___236 *);
	int (*thaw_super)(struct super_block___236 *);
	int (*unfreeze_fs)(struct super_block___236 *);
	int (*statfs)(struct dentry___237 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___236 *, int *, char *);
	void (*umount_begin)(struct super_block___236 *);
	int (*show_options)(struct seq_file___213 *, struct dentry___237 *);
	int (*show_devname)(struct seq_file___213 *, struct dentry___237 *);
	int (*show_path)(struct seq_file___213 *, struct dentry___237 *);
	int (*show_stats)(struct seq_file___213 *, struct dentry___237 *);
	ssize_t (*quota_read)(struct super_block___236 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___236 *, int, const char *, size_t, loff_t);
	struct dquot___236 ** (*get_dquots)(struct inode___237 *);
	int (*bdev_try_to_free_page)(struct super_block___236 *, struct page___238 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___236 *, struct shrink_control___99 *);
	long int (*free_cached_objects)(struct super_block___236 *, struct shrink_control___99 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct xattr_handler___22 {
	const char *name;
	const char *prefix;
	int flags;
	bool (*list)(struct dentry___237 *);
	int (*get)(const struct xattr_handler___22 *, struct dentry___237 *, struct inode___237 *, const char *, void *, size_t);
	int (*set)(const struct xattr_handler___22 *, struct dentry___237 *, struct inode___237 *, const char *, const void *, size_t, int);
};

struct seq_operations___211;

struct seq_file___213 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___211 *op;
	int poll_event;
	const struct file___237 *file;
	void *private;
};

typedef void bio_end_io_t___113(struct bio___113 *);

struct bio_vec___113 {
	struct page___238 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___113;

struct bio_set___113;

struct bio___113 {
	struct bio___113 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___113 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___113 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___113 *bi_io_vec;
	struct bio_set___113 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___113 bi_inline_vecs[0];
};

struct kobj_attribute___218 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___225 *, struct kobj_attribute___218 *, char *);
	ssize_t (*store)(struct kobject___225 *, struct kobj_attribute___218 *, const char *, size_t);
};

typedef void compound_page_dtor___227(struct page___238 *);

struct cgroup_namespace___182 {
	refcount_t count;
	struct ns_common___28 ns;
	struct user_namespace___197 *user_ns;
	struct ucounts___197 *ucounts;
	struct css_set___182 *root_cset;
};

struct ucounts___197 {
	struct hlist_node node;
	struct user_namespace___197 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct msghdr___14 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___104 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___237 *msg_iocb;
};

struct kernfs_root___231;

struct kernfs_elem_dir___231 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___231 *root;
};

struct kernfs_syscall_ops___231;

struct kernfs_root___231 {
	struct kernfs_node___231 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___231 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___231 {
	struct kernfs_node___231 *target_kn;
};

struct kernfs_ops___231;

struct kernfs_elem_attr___231 {
	const struct kernfs_ops___231 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___231 *notify_next;
};

struct kernfs_node___231 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___231 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___231 dir;
		struct kernfs_elem_symlink___231 symlink;
		struct kernfs_elem_attr___231 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___231;

struct kernfs_ops___231 {
	int (*open)(struct kernfs_open_file___231 *);
	void (*release)(struct kernfs_open_file___231 *);
	int (*seq_show)(struct seq_file___213 *, void *);
	void * (*seq_start)(struct seq_file___213 *, loff_t *);
	void * (*seq_next)(struct seq_file___213 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___213 *, void *);
	ssize_t (*read)(struct kernfs_open_file___231 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___231 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___231 *, struct vm_area_struct___238 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___231 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___231 {
	int (*remount_fs)(struct kernfs_root___231 *, int *, char *);
	int (*show_options)(struct seq_file___213 *, struct kernfs_root___231 *);
	int (*mkdir)(struct kernfs_node___231 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___231 *);
	int (*rename)(struct kernfs_node___231 *, struct kernfs_node___231 *, const char *);
	int (*show_path)(struct seq_file___213 *, struct kernfs_node___231 *, struct kernfs_root___231 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___231 {
	struct kernfs_node___231 *kn;
	struct file___237 *file;
	struct seq_file___213 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___227 *vm_ops;
};

struct bin_attribute___202;

struct attribute_group___203 {
	const char *name;
	umode_t (*is_visible)(struct kobject___225 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___225 *, struct bin_attribute___202 *, int);
	struct attribute **attrs;
	struct bin_attribute___202 **bin_attrs;
};

struct bin_attribute___202 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___237 *, struct kobject___225 *, struct bin_attribute___202 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___237 *, struct kobject___225 *, struct bin_attribute___202 *, char *, loff_t, size_t);
	int (*mmap)(struct file___237 *, struct kobject___225 *, struct bin_attribute___202 *, struct vm_area_struct___238 *);
};

struct sysfs_ops___224 {
	ssize_t (*show)(struct kobject___225 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___225 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___224;

struct kset___224 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___225 kobj;
	const struct kset_uevent_ops___224 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___224 {
	void (*release)(struct kobject___225 *);
	const struct sysfs_ops___224 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___13 * (*child_ns_type)(struct kobject___225 *);
	const void * (*namespace)(struct kobject___225 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___224 {
	int (* const filter)(struct kset___224 *, struct kobject___225 *);
	const char * (* const name)(struct kset___224 *, struct kobject___225 *);
	int (* const uevent)(struct kset___224 *, struct kobject___225 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___188 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___188 *);
	int (*get)(char *, const struct kernel_param___188 *);
	void (*free)(void *);
};

struct kparam_array___188;

struct kernel_param___188 {
	const char *name;
	struct module___191 *mod;
	const struct kernel_param_ops___188 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___188 *arr;
	};
};

struct kparam_array___188 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___188 *ops;
	void *elem;
};

struct module_attribute___188 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___188 *, struct module_kobject___188 *, char *);
	ssize_t (*store)(struct module_attribute___188 *, struct module_kobject___188 *, const char *, size_t);
	void (*setup)(struct module___191 *, const char *);
	int (*test)(struct module___191 *);
	void (*free)(struct module___191 *);
};

struct security_mnt_opts {
	char **mnt_opts;
	int *mnt_opts_flags;
	int num_mnt_opts;
};

struct msg_msg___2;

struct request_sock___7;

struct sctp_endpoint;

struct xfrm_sec_ctx;

struct xfrm_user_sec_ctx;

struct socket___14;

struct bpf_map___182;

struct bpf_prog_aux___24;

union security_list_options {
	int (*binder_set_context_mgr)(struct task_struct___238 *);
	int (*binder_transaction)(struct task_struct___238 *, struct task_struct___238 *);
	int (*binder_transfer_binder)(struct task_struct___238 *, struct task_struct___238 *);
	int (*binder_transfer_file)(struct task_struct___238 *, struct task_struct___238 *, struct file___237 *);
	int (*ptrace_access_check)(struct task_struct___238 *, unsigned int);
	int (*ptrace_traceme)(struct task_struct___238 *);
	int (*capget)(struct task_struct___238 *, kernel_cap_t *, kernel_cap_t *, kernel_cap_t *);
	int (*capset)(struct cred___230 *, const struct cred___230 *, const kernel_cap_t *, const kernel_cap_t *, const kernel_cap_t *);
	int (*capable)(const struct cred___230 *, struct user_namespace___197 *, int, int);
	int (*quotactl)(int, int, int, struct super_block___236 *);
	int (*quota_on)(struct dentry___237 *);
	int (*syslog)(int);
	int (*settime)(const struct timespec64 *, const struct timezone *);
	int (*vm_enough_memory)(struct mm_struct___237 *, long int);
	int (*bprm_set_creds)(struct linux_binprm___38 *);
	int (*bprm_check_security)(struct linux_binprm___38 *);
	void (*bprm_committing_creds)(struct linux_binprm___38 *);
	void (*bprm_committed_creds)(struct linux_binprm___38 *);
	int (*sb_alloc_security)(struct super_block___236 *);
	void (*sb_free_security)(struct super_block___236 *);
	int (*sb_copy_data)(char *, char *);
	int (*sb_remount)(struct super_block___236 *, void *);
	int (*sb_kern_mount)(struct super_block___236 *, int, void *);
	int (*sb_show_options)(struct seq_file___213 *, struct super_block___236 *);
	int (*sb_statfs)(struct dentry___237 *);
	int (*sb_mount)(const char *, const struct path___236 *, const char *, long unsigned int, void *);
	int (*sb_umount)(struct vfsmount___61 *, int);
	int (*sb_pivotroot)(const struct path___236 *, const struct path___236 *);
	int (*sb_set_mnt_opts)(struct super_block___236 *, struct security_mnt_opts *, long unsigned int, long unsigned int *);
	int (*sb_clone_mnt_opts)(const struct super_block___236 *, struct super_block___236 *, long unsigned int, long unsigned int *);
	int (*sb_parse_opts_str)(char *, struct security_mnt_opts *);
	int (*dentry_init_security)(struct dentry___237 *, int, const struct qstr *, void **, u32 *);
	int (*dentry_create_files_as)(struct dentry___237 *, int, struct qstr *, const struct cred___230 *, struct cred___230 *);
	int (*inode_alloc_security)(struct inode___237 *);
	void (*inode_free_security)(struct inode___237 *);
	int (*inode_init_security)(struct inode___237 *, struct inode___237 *, const struct qstr *, const char **, void **, size_t *);
	int (*inode_create)(struct inode___237 *, struct dentry___237 *, umode_t);
	int (*inode_link)(struct dentry___237 *, struct inode___237 *, struct dentry___237 *);
	int (*inode_unlink)(struct inode___237 *, struct dentry___237 *);
	int (*inode_symlink)(struct inode___237 *, struct dentry___237 *, const char *);
	int (*inode_mkdir)(struct inode___237 *, struct dentry___237 *, umode_t);
	int (*inode_rmdir)(struct inode___237 *, struct dentry___237 *);
	int (*inode_mknod)(struct inode___237 *, struct dentry___237 *, umode_t, dev_t);
	int (*inode_rename)(struct inode___237 *, struct dentry___237 *, struct inode___237 *, struct dentry___237 *);
	int (*inode_readlink)(struct dentry___237 *);
	int (*inode_follow_link)(struct dentry___237 *, struct inode___237 *, bool);
	int (*inode_permission)(struct inode___237 *, int);
	int (*inode_setattr)(struct dentry___237 *, struct iattr___236 *);
	int (*inode_getattr)(const struct path___236 *);
	int (*inode_setxattr)(struct dentry___237 *, const char *, const void *, size_t, int);
	void (*inode_post_setxattr)(struct dentry___237 *, const char *, const void *, size_t, int);
	int (*inode_getxattr)(struct dentry___237 *, const char *);
	int (*inode_listxattr)(struct dentry___237 *);
	int (*inode_removexattr)(struct dentry___237 *, const char *);
	int (*inode_need_killpriv)(struct dentry___237 *);
	int (*inode_killpriv)(struct dentry___237 *);
	int (*inode_getsecurity)(struct inode___237 *, const char *, void **, bool);
	int (*inode_setsecurity)(struct inode___237 *, const char *, const void *, size_t, int);
	int (*inode_listsecurity)(struct inode___237 *, char *, size_t);
	void (*inode_getsecid)(struct inode___237 *, u32 *);
	int (*inode_copy_up)(struct dentry___237 *, struct cred___230 **);
	int (*inode_copy_up_xattr)(const char *);
	int (*kernfs_init_security)(struct kernfs_node___231 *, struct kernfs_node___231 *);
	int (*file_permission)(struct file___237 *, int);
	int (*file_alloc_security)(struct file___237 *);
	void (*file_free_security)(struct file___237 *);
	int (*file_ioctl)(struct file___237 *, unsigned int, long unsigned int);
	int (*mmap_addr)(long unsigned int);
	int (*mmap_file)(struct file___237 *, long unsigned int, long unsigned int, long unsigned int);
	int (*file_mprotect)(struct vm_area_struct___238 *, long unsigned int, long unsigned int);
	int (*file_lock)(struct file___237 *, unsigned int);
	int (*file_fcntl)(struct file___237 *, unsigned int, long unsigned int);
	void (*file_set_fowner)(struct file___237 *);
	int (*file_send_sigiotask)(struct task_struct___238 *, struct fown_struct___177 *, int);
	int (*file_receive)(struct file___237 *);
	int (*file_open)(struct file___237 *);
	int (*task_alloc)(struct task_struct___238 *, long unsigned int);
	void (*task_free)(struct task_struct___238 *);
	int (*cred_alloc_blank)(struct cred___230 *, gfp_t);
	void (*cred_free)(struct cred___230 *);
	int (*cred_prepare)(struct cred___230 *, const struct cred___230 *, gfp_t);
	void (*cred_transfer)(struct cred___230 *, const struct cred___230 *);
	void (*cred_getsecid)(const struct cred___230 *, u32 *);
	int (*kernel_act_as)(struct cred___230 *, u32);
	int (*kernel_create_files_as)(struct cred___230 *, struct inode___237 *);
	int (*kernel_module_request)(char *);
	int (*kernel_read_file)(struct file___237 *, enum kernel_read_file_id);
	int (*kernel_post_read_file)(struct file___237 *, char *, loff_t, enum kernel_read_file_id);
	int (*task_fix_setuid)(struct cred___230 *, const struct cred___230 *, int);
	int (*task_setpgid)(struct task_struct___238 *, pid_t);
	int (*task_getpgid)(struct task_struct___238 *);
	int (*task_getsid)(struct task_struct___238 *);
	void (*task_getsecid)(struct task_struct___238 *, u32 *);
	int (*task_setnice)(struct task_struct___238 *, int);
	int (*task_setioprio)(struct task_struct___238 *, int);
	int (*task_getioprio)(struct task_struct___238 *);
	int (*task_prlimit)(const struct cred___230 *, const struct cred___230 *, unsigned int);
	int (*task_setrlimit)(struct task_struct___238 *, unsigned int, struct rlimit *);
	int (*task_setscheduler)(struct task_struct___238 *);
	int (*task_getscheduler)(struct task_struct___238 *);
	int (*task_movememory)(struct task_struct___238 *);
	int (*task_kill)(struct task_struct___238 *, struct kernel_siginfo *, int, const struct cred___230 *);
	int (*task_prctl)(int, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*task_to_inode)(struct task_struct___238 *, struct inode___237 *);
	int (*ipc_permission)(struct kern_ipc_perm *, short int);
	void (*ipc_getsecid)(struct kern_ipc_perm *, u32 *);
	int (*msg_msg_alloc_security)(struct msg_msg___2 *);
	void (*msg_msg_free_security)(struct msg_msg___2 *);
	int (*msg_queue_alloc_security)(struct kern_ipc_perm *);
	void (*msg_queue_free_security)(struct kern_ipc_perm *);
	int (*msg_queue_associate)(struct kern_ipc_perm *, int);
	int (*msg_queue_msgctl)(struct kern_ipc_perm *, int);
	int (*msg_queue_msgsnd)(struct kern_ipc_perm *, struct msg_msg___2 *, int);
	int (*msg_queue_msgrcv)(struct kern_ipc_perm *, struct msg_msg___2 *, struct task_struct___238 *, long int, int);
	int (*shm_alloc_security)(struct kern_ipc_perm *);
	void (*shm_free_security)(struct kern_ipc_perm *);
	int (*shm_associate)(struct kern_ipc_perm *, int);
	int (*shm_shmctl)(struct kern_ipc_perm *, int);
	int (*shm_shmat)(struct kern_ipc_perm *, char *, int);
	int (*sem_alloc_security)(struct kern_ipc_perm *);
	void (*sem_free_security)(struct kern_ipc_perm *);
	int (*sem_associate)(struct kern_ipc_perm *, int);
	int (*sem_semctl)(struct kern_ipc_perm *, int);
	int (*sem_semop)(struct kern_ipc_perm *, struct sembuf *, unsigned int, int);
	int (*netlink_send)(struct sock *, struct sk_buff___27 *);
	void (*d_instantiate)(struct dentry___237 *, struct inode___237 *);
	int (*getprocattr)(struct task_struct___238 *, char *, char **);
	int (*setprocattr)(const char *, void *, size_t);
	int (*ismaclabel)(const char *);
	int (*secid_to_secctx)(u32, char **, u32 *);
	int (*secctx_to_secid)(const char *, u32, u32 *);
	void (*release_secctx)(char *, u32);
	void (*inode_invalidate_secctx)(struct inode___237 *);
	int (*inode_notifysecctx)(struct inode___237 *, void *, u32);
	int (*inode_setsecctx)(struct dentry___237 *, void *, u32);
	int (*inode_getsecctx)(struct inode___237 *, void **, u32 *);
	int (*unix_stream_connect)(struct sock *, struct sock *, struct sock *);
	int (*unix_may_send)(struct socket___14 *, struct socket___14 *);
	int (*socket_create)(int, int, int, int);
	int (*socket_post_create)(struct socket___14 *, int, int, int, int);
	int (*socket_socketpair)(struct socket___14 *, struct socket___14 *);
	int (*socket_bind)(struct socket___14 *, struct sockaddr *, int);
	int (*socket_connect)(struct socket___14 *, struct sockaddr *, int);
	int (*socket_listen)(struct socket___14 *, int);
	int (*socket_accept)(struct socket___14 *, struct socket___14 *);
	int (*socket_sendmsg)(struct socket___14 *, struct msghdr___14 *, int);
	int (*socket_recvmsg)(struct socket___14 *, struct msghdr___14 *, int, int);
	int (*socket_getsockname)(struct socket___14 *);
	int (*socket_getpeername)(struct socket___14 *);
	int (*socket_getsockopt)(struct socket___14 *, int, int);
	int (*socket_setsockopt)(struct socket___14 *, int, int);
	int (*socket_shutdown)(struct socket___14 *, int);
	int (*socket_sock_rcv_skb)(struct sock *, struct sk_buff___27 *);
	int (*socket_getpeersec_stream)(struct socket___14 *, char *, int *, unsigned int);
	int (*socket_getpeersec_dgram)(struct socket___14 *, struct sk_buff___27 *, u32 *);
	int (*sk_alloc_security)(struct sock *, int, gfp_t);
	void (*sk_free_security)(struct sock *);
	void (*sk_clone_security)(const struct sock *, struct sock *);
	void (*sk_getsecid)(struct sock *, u32 *);
	void (*sock_graft)(struct sock *, struct socket___14 *);
	int (*inet_conn_request)(struct sock *, struct sk_buff___27 *, struct request_sock___7 *);
	void (*inet_csk_clone)(struct sock *, const struct request_sock___7 *);
	void (*inet_conn_established)(struct sock *, struct sk_buff___27 *);
	int (*secmark_relabel_packet)(u32);
	void (*secmark_refcount_inc)();
	void (*secmark_refcount_dec)();
	void (*req_classify_flow)(const struct request_sock___7 *, struct flowi *);
	int (*tun_dev_alloc_security)(void **);
	void (*tun_dev_free_security)(void *);
	int (*tun_dev_create)();
	int (*tun_dev_attach_queue)(void *);
	int (*tun_dev_attach)(struct sock *, void *);
	int (*tun_dev_open)(void *);
	int (*sctp_assoc_request)(struct sctp_endpoint *, struct sk_buff___27 *);
	int (*sctp_bind_connect)(struct sock *, int, struct sockaddr *, int);
	void (*sctp_sk_clone)(struct sctp_endpoint *, struct sock *, struct sock *);
	int (*ib_pkey_access)(void *, u64, u16);
	int (*ib_endport_manage_subnet)(void *, const char *, u8);
	int (*ib_alloc_security)(void **);
	void (*ib_free_security)(void *);
	int (*xfrm_policy_alloc_security)(struct xfrm_sec_ctx **, struct xfrm_user_sec_ctx *, gfp_t);
	int (*xfrm_policy_clone_security)(struct xfrm_sec_ctx *, struct xfrm_sec_ctx **);
	void (*xfrm_policy_free_security)(struct xfrm_sec_ctx *);
	int (*xfrm_policy_delete_security)(struct xfrm_sec_ctx *);
	int (*xfrm_state_alloc)(struct xfrm_state *, struct xfrm_user_sec_ctx *);
	int (*xfrm_state_alloc_acquire)(struct xfrm_state *, struct xfrm_sec_ctx *, u32);
	void (*xfrm_state_free_security)(struct xfrm_state *);
	int (*xfrm_state_delete_security)(struct xfrm_state *);
	int (*xfrm_policy_lookup)(struct xfrm_sec_ctx *, u32, u8);
	int (*xfrm_state_pol_flow_match)(struct xfrm_state *, struct xfrm_policy *, const struct flowi *);
	int (*xfrm_decode_session)(struct sk_buff___27 *, u32 *, int);
	int (*key_alloc)(struct key___230 *, const struct cred___230 *, long unsigned int);
	void (*key_free)(struct key___230 *);
	int (*key_permission)(key_ref_t, const struct cred___230 *, unsigned int);
	int (*key_getsecurity)(struct key___230 *, char **);
	int (*audit_rule_init)(u32, u32, char *, void **);
	int (*audit_rule_known)(struct audit_krule *);
	int (*audit_rule_match)(u32, u32, u32, void *, struct audit_context *);
	void (*audit_rule_free)(void *);
	int (*bpf)(int, union bpf_attr *, unsigned int);
	int (*bpf_map)(struct bpf_map___182 *, fmode_t);
	int (*bpf_prog)(struct bpf_prog *);
	int (*bpf_map_alloc_security)(struct bpf_map___182 *);
	void (*bpf_map_free_security)(struct bpf_map___182 *);
	int (*bpf_prog_alloc_security)(struct bpf_prog_aux___24 *);
	void (*bpf_prog_free_security)(struct bpf_prog_aux___24 *);
};

struct linux_binprm___38 {
	char buf[256];
	struct vm_area_struct___238 *vma;
	long unsigned int vma_pages;
	struct mm_struct___237 *mm;
	long unsigned int p;
	unsigned int called_set_creds: 1;
	unsigned int cap_elevated: 1;
	unsigned int secureexec: 1;
	unsigned int recursion_depth;
	struct file___237 *file;
	struct cred___230 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
};

struct socket_wq___14;

struct proto_ops___14;

struct socket___14 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___14 *wq;
	struct file___237 *file;
	struct sock *sk;
	const struct proto_ops___14 *ops;
};

struct bpf_map_ops___182;

struct bpf_map___182 {
	const struct bpf_map_ops___182 *ops;
	struct bpf_map___182 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___230 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_aux___24 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___23 *ops;
	struct bpf_map___182 **used_maps;
	struct bpf_prog *prog;
	struct user_struct___230 *user;
	u64 load_time;
	struct bpf_map___182 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___23 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct security_hook_heads {
	struct hlist_head binder_set_context_mgr;
	struct hlist_head binder_transaction;
	struct hlist_head binder_transfer_binder;
	struct hlist_head binder_transfer_file;
	struct hlist_head ptrace_access_check;
	struct hlist_head ptrace_traceme;
	struct hlist_head capget;
	struct hlist_head capset;
	struct hlist_head capable;
	struct hlist_head quotactl;
	struct hlist_head quota_on;
	struct hlist_head syslog;
	struct hlist_head settime;
	struct hlist_head vm_enough_memory;
	struct hlist_head bprm_set_creds;
	struct hlist_head bprm_check_security;
	struct hlist_head bprm_committing_creds;
	struct hlist_head bprm_committed_creds;
	struct hlist_head sb_alloc_security;
	struct hlist_head sb_free_security;
	struct hlist_head sb_copy_data;
	struct hlist_head sb_remount;
	struct hlist_head sb_kern_mount;
	struct hlist_head sb_show_options;
	struct hlist_head sb_statfs;
	struct hlist_head sb_mount;
	struct hlist_head sb_umount;
	struct hlist_head sb_pivotroot;
	struct hlist_head sb_set_mnt_opts;
	struct hlist_head sb_clone_mnt_opts;
	struct hlist_head sb_parse_opts_str;
	struct hlist_head dentry_init_security;
	struct hlist_head dentry_create_files_as;
	struct hlist_head inode_alloc_security;
	struct hlist_head inode_free_security;
	struct hlist_head inode_init_security;
	struct hlist_head inode_create;
	struct hlist_head inode_link;
	struct hlist_head inode_unlink;
	struct hlist_head inode_symlink;
	struct hlist_head inode_mkdir;
	struct hlist_head inode_rmdir;
	struct hlist_head inode_mknod;
	struct hlist_head inode_rename;
	struct hlist_head inode_readlink;
	struct hlist_head inode_follow_link;
	struct hlist_head inode_permission;
	struct hlist_head inode_setattr;
	struct hlist_head inode_getattr;
	struct hlist_head inode_setxattr;
	struct hlist_head inode_post_setxattr;
	struct hlist_head inode_getxattr;
	struct hlist_head inode_listxattr;
	struct hlist_head inode_removexattr;
	struct hlist_head inode_need_killpriv;
	struct hlist_head inode_killpriv;
	struct hlist_head inode_getsecurity;
	struct hlist_head inode_setsecurity;
	struct hlist_head inode_listsecurity;
	struct hlist_head inode_getsecid;
	struct hlist_head inode_copy_up;
	struct hlist_head inode_copy_up_xattr;
	struct hlist_head kernfs_init_security;
	struct hlist_head file_permission;
	struct hlist_head file_alloc_security;
	struct hlist_head file_free_security;
	struct hlist_head file_ioctl;
	struct hlist_head mmap_addr;
	struct hlist_head mmap_file;
	struct hlist_head file_mprotect;
	struct hlist_head file_lock;
	struct hlist_head file_fcntl;
	struct hlist_head file_set_fowner;
	struct hlist_head file_send_sigiotask;
	struct hlist_head file_receive;
	struct hlist_head file_open;
	struct hlist_head task_alloc;
	struct hlist_head task_free;
	struct hlist_head cred_alloc_blank;
	struct hlist_head cred_free;
	struct hlist_head cred_prepare;
	struct hlist_head cred_transfer;
	struct hlist_head cred_getsecid;
	struct hlist_head kernel_act_as;
	struct hlist_head kernel_create_files_as;
	struct hlist_head kernel_read_file;
	struct hlist_head kernel_post_read_file;
	struct hlist_head kernel_module_request;
	struct hlist_head task_fix_setuid;
	struct hlist_head task_setpgid;
	struct hlist_head task_getpgid;
	struct hlist_head task_getsid;
	struct hlist_head task_getsecid;
	struct hlist_head task_setnice;
	struct hlist_head task_setioprio;
	struct hlist_head task_getioprio;
	struct hlist_head task_prlimit;
	struct hlist_head task_setrlimit;
	struct hlist_head task_setscheduler;
	struct hlist_head task_getscheduler;
	struct hlist_head task_movememory;
	struct hlist_head task_kill;
	struct hlist_head task_prctl;
	struct hlist_head task_to_inode;
	struct hlist_head ipc_permission;
	struct hlist_head ipc_getsecid;
	struct hlist_head msg_msg_alloc_security;
	struct hlist_head msg_msg_free_security;
	struct hlist_head msg_queue_alloc_security;
	struct hlist_head msg_queue_free_security;
	struct hlist_head msg_queue_associate;
	struct hlist_head msg_queue_msgctl;
	struct hlist_head msg_queue_msgsnd;
	struct hlist_head msg_queue_msgrcv;
	struct hlist_head shm_alloc_security;
	struct hlist_head shm_free_security;
	struct hlist_head shm_associate;
	struct hlist_head shm_shmctl;
	struct hlist_head shm_shmat;
	struct hlist_head sem_alloc_security;
	struct hlist_head sem_free_security;
	struct hlist_head sem_associate;
	struct hlist_head sem_semctl;
	struct hlist_head sem_semop;
	struct hlist_head netlink_send;
	struct hlist_head d_instantiate;
	struct hlist_head getprocattr;
	struct hlist_head setprocattr;
	struct hlist_head ismaclabel;
	struct hlist_head secid_to_secctx;
	struct hlist_head secctx_to_secid;
	struct hlist_head release_secctx;
	struct hlist_head inode_invalidate_secctx;
	struct hlist_head inode_notifysecctx;
	struct hlist_head inode_setsecctx;
	struct hlist_head inode_getsecctx;
	struct hlist_head unix_stream_connect;
	struct hlist_head unix_may_send;
	struct hlist_head socket_create;
	struct hlist_head socket_post_create;
	struct hlist_head socket_socketpair;
	struct hlist_head socket_bind;
	struct hlist_head socket_connect;
	struct hlist_head socket_listen;
	struct hlist_head socket_accept;
	struct hlist_head socket_sendmsg;
	struct hlist_head socket_recvmsg;
	struct hlist_head socket_getsockname;
	struct hlist_head socket_getpeername;
	struct hlist_head socket_getsockopt;
	struct hlist_head socket_setsockopt;
	struct hlist_head socket_shutdown;
	struct hlist_head socket_sock_rcv_skb;
	struct hlist_head socket_getpeersec_stream;
	struct hlist_head socket_getpeersec_dgram;
	struct hlist_head sk_alloc_security;
	struct hlist_head sk_free_security;
	struct hlist_head sk_clone_security;
	struct hlist_head sk_getsecid;
	struct hlist_head sock_graft;
	struct hlist_head inet_conn_request;
	struct hlist_head inet_csk_clone;
	struct hlist_head inet_conn_established;
	struct hlist_head secmark_relabel_packet;
	struct hlist_head secmark_refcount_inc;
	struct hlist_head secmark_refcount_dec;
	struct hlist_head req_classify_flow;
	struct hlist_head tun_dev_alloc_security;
	struct hlist_head tun_dev_free_security;
	struct hlist_head tun_dev_create;
	struct hlist_head tun_dev_attach_queue;
	struct hlist_head tun_dev_attach;
	struct hlist_head tun_dev_open;
	struct hlist_head sctp_assoc_request;
	struct hlist_head sctp_bind_connect;
	struct hlist_head sctp_sk_clone;
	struct hlist_head ib_pkey_access;
	struct hlist_head ib_endport_manage_subnet;
	struct hlist_head ib_alloc_security;
	struct hlist_head ib_free_security;
	struct hlist_head xfrm_policy_alloc_security;
	struct hlist_head xfrm_policy_clone_security;
	struct hlist_head xfrm_policy_free_security;
	struct hlist_head xfrm_policy_delete_security;
	struct hlist_head xfrm_state_alloc;
	struct hlist_head xfrm_state_alloc_acquire;
	struct hlist_head xfrm_state_free_security;
	struct hlist_head xfrm_state_delete_security;
	struct hlist_head xfrm_policy_lookup;
	struct hlist_head xfrm_state_pol_flow_match;
	struct hlist_head xfrm_decode_session;
	struct hlist_head key_alloc;
	struct hlist_head key_free;
	struct hlist_head key_permission;
	struct hlist_head key_getsecurity;
	struct hlist_head audit_rule_init;
	struct hlist_head audit_rule_known;
	struct hlist_head audit_rule_match;
	struct hlist_head audit_rule_free;
	struct hlist_head bpf;
	struct hlist_head bpf_map;
	struct hlist_head bpf_prog;
	struct hlist_head bpf_map_alloc_security;
	struct hlist_head bpf_map_free_security;
	struct hlist_head bpf_prog_alloc_security;
	struct hlist_head bpf_prog_free_security;
};

struct security_hook_list {
	struct hlist_node list;
	struct hlist_head *head;
	union security_list_options hook;
	char *lsm;
};

struct seq_operations___211 {
	void * (*start)(struct seq_file___213 *, loff_t *);
	void (*stop)(struct seq_file___213 *, void *);
	void * (*next)(struct seq_file___213 *, void *, loff_t *);
	int (*show)(struct seq_file___213 *, void *);
};

struct bpf_map_ops___182 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___182 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___182 *, struct file___237 *);
	void (*map_free)(struct bpf_map___182 *);
	int (*map_get_next_key)(struct bpf_map___182 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___182 *);
	void * (*map_lookup_elem)(struct bpf_map___182 *, void *);
	int (*map_update_elem)(struct bpf_map___182 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___182 *, void *);
	int (*map_push_elem)(struct bpf_map___182 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___182 *, void *);
	int (*map_peek_elem)(struct bpf_map___182 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___182 *, struct file___237 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___182 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___182 *, void *, struct seq_file___213 *);
	int (*map_check_btf)(const struct bpf_map___182 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct kthread_work___182;

typedef void (*kthread_work_func_t___182)(struct kthread_work___182 *);

struct kthread_worker___182;

struct kthread_work___182 {
	struct list_head node;
	kthread_work_func_t___182 func;
	struct kthread_worker___182 *worker;
	int canceling;
};

struct kthread_worker___182 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___238 *task;
	struct kthread_work___182 *current_work;
};

struct kthread_delayed_work___182 {
	struct kthread_work___182 work;
	struct timer_list timer;
};

struct psi_group___182 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___182 *poll_kworker;
	struct kthread_delayed_work___182 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___182;

struct cgroup_rstat_cpu___182;

struct cgroup___182 {
	struct cgroup_subsys_state___183 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___231 *kn;
	struct cgroup_file___182 procs_file;
	struct cgroup_file___182 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___183 *subsys[13];
	struct cgroup_root___182 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___182 *dom_cgrp;
	struct cgroup_rstat_cpu___182 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___23 bpf;
	atomic_t congestion_count;
	struct cgroup___182 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___182 psi;
	int ancestor_ids[0];
};

struct cftype___182;

struct cgroup_subsys___182 {
	struct cgroup_subsys_state___183 * (*css_alloc)(struct cgroup_subsys_state___183 *);
	int (*css_online)(struct cgroup_subsys_state___183 *);
	void (*css_offline)(struct cgroup_subsys_state___183 *);
	void (*css_released)(struct cgroup_subsys_state___183 *);
	void (*css_free)(struct cgroup_subsys_state___183 *);
	void (*css_reset)(struct cgroup_subsys_state___183 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___183 *, int);
	int (*css_extra_stat_show)(struct seq_file___213 *, struct cgroup_subsys_state___183 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___238 *);
	void (*cancel_fork)(struct task_struct___238 *);
	void (*fork)(struct task_struct___238 *);
	void (*exit)(struct task_struct___238 *);
	void (*free)(struct task_struct___238 *);
	void (*bind)(struct cgroup_subsys_state___183 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___182 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___182 *dfl_cftypes;
	struct cftype___182 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___182 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___182 *updated_children;
	struct cgroup___182 *updated_next;
};

struct cgroup_root___182 {
	struct kernfs_root___231 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___182 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___182 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___182 *ss;
	struct list_head node;
	struct kernfs_ops___231 *kf_ops;
	int (*open)(struct kernfs_open_file___231 *);
	void (*release)(struct kernfs_open_file___231 *);
	u64 (*read_u64)(struct cgroup_subsys_state___183 *, struct cftype___182 *);
	s64 (*read_s64)(struct cgroup_subsys_state___183 *, struct cftype___182 *);
	int (*seq_show)(struct seq_file___213 *, void *);
	void * (*seq_start)(struct seq_file___213 *, loff_t *);
	void * (*seq_next)(struct seq_file___213 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___213 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___183 *, struct cftype___182 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___183 *, struct cftype___182 *, s64);
	ssize_t (*write)(struct kernfs_open_file___231 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___231 *, struct poll_table_struct___6 *);
};

struct bdi_writeback_congested___113 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___113 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___113 {
	struct bio___113 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___113 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___113 bip_inline_vecs[0];
};

struct bio_set___113 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___113 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___99 {
	struct mem_cgroup___99 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___99 {
	struct lruvec___237 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___99 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___99 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct dev_pm_ops___201 {
	int (*prepare)(struct device___201 *);
	void (*complete)(struct device___201 *);
	int (*suspend)(struct device___201 *);
	int (*resume)(struct device___201 *);
	int (*freeze)(struct device___201 *);
	int (*thaw)(struct device___201 *);
	int (*poweroff)(struct device___201 *);
	int (*restore)(struct device___201 *);
	int (*suspend_late)(struct device___201 *);
	int (*resume_early)(struct device___201 *);
	int (*freeze_late)(struct device___201 *);
	int (*thaw_early)(struct device___201 *);
	int (*poweroff_late)(struct device___201 *);
	int (*restore_early)(struct device___201 *);
	int (*suspend_noirq)(struct device___201 *);
	int (*resume_noirq)(struct device___201 *);
	int (*freeze_noirq)(struct device___201 *);
	int (*thaw_noirq)(struct device___201 *);
	int (*poweroff_noirq)(struct device___201 *);
	int (*restore_noirq)(struct device___201 *);
	int (*runtime_suspend)(struct device___201 *);
	int (*runtime_resume)(struct device___201 *);
	int (*runtime_idle)(struct device___201 *);
};

struct dev_pm_domain___201 {
	struct dev_pm_ops___201 ops;
	void (*detach)(struct device___201 *, bool);
	int (*activate)(struct device___201 *);
	void (*sync)(struct device___201 *);
	void (*dismiss)(struct device___201 *);
};

struct bus_type___201 {
	const char *name;
	const char *dev_name;
	struct device___201 *dev_root;
	const struct attribute_group___203 **bus_groups;
	const struct attribute_group___203 **dev_groups;
	const struct attribute_group___203 **drv_groups;
	int (*match)(struct device___201 *, struct device_driver___201 *);
	int (*uevent)(struct device___201 *, struct kobj_uevent_env *);
	int (*probe)(struct device___201 *);
	int (*remove)(struct device___201 *);
	void (*shutdown)(struct device___201 *);
	int (*online)(struct device___201 *);
	int (*offline)(struct device___201 *);
	int (*suspend)(struct device___201 *, pm_message_t);
	int (*resume)(struct device___201 *);
	int (*num_vf)(struct device___201 *);
	int (*dma_configure)(struct device___201 *);
	const struct dev_pm_ops___201 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___201 {
	const char *name;
	struct bus_type___201 *bus;
	struct module___191 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___201 *);
	int (*remove)(struct device___201 *);
	void (*shutdown)(struct device___201 *);
	int (*suspend)(struct device___201 *, pm_message_t);
	int (*resume)(struct device___201 *);
	const struct attribute_group___203 **groups;
	const struct dev_pm_ops___201 *pm;
	void (*coredump)(struct device___201 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___201 {
	const char *name;
	const struct attribute_group___203 **groups;
	int (*uevent)(struct device___201 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___201 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___201 *);
	const struct dev_pm_ops___201 *pm;
};

struct class___201 {
	const char *name;
	struct module___191 *owner;
	const struct attribute_group___203 **class_groups;
	const struct attribute_group___203 **dev_groups;
	struct kobject___225 *dev_kobj;
	int (*dev_uevent)(struct device___201 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___201 *, umode_t *);
	void (*class_release)(struct class___201 *);
	void (*dev_release)(struct device___201 *);
	int (*shutdown_pre)(struct device___201 *);
	const struct kobj_ns_type_operations___13 *ns_type;
	const void * (*namespace)(struct device___201 *);
	const struct dev_pm_ops___201 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___45 {
	void * (*alloc)(struct device___201 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___201 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___201 *, struct vm_area_struct___238 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___201 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___201 *, struct page___238 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___201 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___201 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___201 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___201 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___201 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___201 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___201 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___201 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___201 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___201 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___201 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___201 *, u64);
	u64 (*get_required_mask)(struct device___201 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___136;

struct fwnode_handle___136 {
	struct fwnode_handle___136 *secondary;
	const struct fwnode_operations___136 *ops;
};

struct node___168 {
	struct device___201 dev;
};

struct socket_wq___14 {
	wait_queue_head_t wait;
	struct fasync_struct___236 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___14 {
	int family;
	struct module___191 *owner;
	int (*release)(struct socket___14 *);
	int (*bind)(struct socket___14 *, struct sockaddr *, int);
	int (*connect)(struct socket___14 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___14 *, struct socket___14 *);
	int (*accept)(struct socket___14 *, struct socket___14 *, int, bool);
	int (*getname)(struct socket___14 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___237 *, struct socket___14 *, struct poll_table_struct___6 *);
	int (*ioctl)(struct socket___14 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___14 *, int);
	int (*shutdown)(struct socket___14 *, int);
	int (*setsockopt)(struct socket___14 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___14 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___14 *, struct msghdr___14 *, size_t);
	int (*recvmsg)(struct socket___14 *, struct msghdr___14 *, size_t, int);
	int (*mmap)(struct file___237 *, struct socket___14 *, struct vm_area_struct___238 *);
	ssize_t (*sendpage)(struct socket___14 *, struct page___238 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___14 *, loff_t *, struct pipe_inode_info___48 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock *, int);
	int (*peek_len)(struct socket___14 *);
	int (*read_sock)(struct sock *, read_descriptor_t *, sk_read_actor_t___13);
	int (*sendpage_locked)(struct sock *, struct page___238 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock *, struct msghdr___14 *, size_t);
	int (*set_rcvlowat)(struct sock *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct fwnode_reference_args___136;

struct fwnode_endpoint___136;

struct fwnode_operations___136 {
	struct fwnode_handle___136 * (*get)(struct fwnode_handle___136 *);
	void (*put)(struct fwnode_handle___136 *);
	bool (*device_is_available)(const struct fwnode_handle___136 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___136 *, const struct device___201 *);
	bool (*property_present)(const struct fwnode_handle___136 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___136 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___136 *, const char *, const char **, size_t);
	struct fwnode_handle___136 * (*get_parent)(const struct fwnode_handle___136 *);
	struct fwnode_handle___136 * (*get_next_child_node)(const struct fwnode_handle___136 *, struct fwnode_handle___136 *);
	struct fwnode_handle___136 * (*get_named_child_node)(const struct fwnode_handle___136 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___136 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___136 *);
	struct fwnode_handle___136 * (*graph_get_next_endpoint)(const struct fwnode_handle___136 *, struct fwnode_handle___136 *);
	struct fwnode_handle___136 * (*graph_get_remote_endpoint)(const struct fwnode_handle___136 *);
	struct fwnode_handle___136 * (*graph_get_port_parent)(struct fwnode_handle___136 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___136 *, struct fwnode_endpoint___136 *);
};

struct fwnode_endpoint___136 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___136 *local_fwnode;
};

struct fwnode_reference_args___136 {
	struct fwnode_handle___136 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___48;

struct pipe_buffer___48 {
	struct page___238 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___48 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___48 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___48 *, struct pipe_buffer___48 *);
	void (*release)(struct pipe_inode_info___48 *, struct pipe_buffer___48 *);
	int (*steal)(struct pipe_inode_info___48 *, struct pipe_buffer___48 *);
	union {
		bool (*get)(struct pipe_inode_info___48 *, struct pipe_buffer___48 *);
		struct {
			void (*get)(struct pipe_inode_info___48 *, struct pipe_buffer___48 *);
		} __UNIQUE_ID_rh_kabi_hide37;
		union {		};
	};
};

struct hstate___43 {
	int next_nid_to_alloc;
	int next_nid_to_free;
	unsigned int order;
	long unsigned int mask;
	long unsigned int max_huge_pages;
	long unsigned int nr_huge_pages;
	long unsigned int free_huge_pages;
	long unsigned int resv_huge_pages;
	long unsigned int surplus_huge_pages;
	long unsigned int nr_overcommit_huge_pages;
	struct list_head hugepage_activelist;
	struct list_head hugepage_freelists[8];
	unsigned int nr_huge_pages_node[8];
	unsigned int free_huge_pages_node[8];
	unsigned int surplus_huge_pages_node[8];
	struct cftype___182 cgroup_files[5];
	char name[32];
};

struct coredump_params___37 {
	union {
		const kernel_siginfo_t *siginfo;
		struct {
			const siginfo_t *siginfo;
		} __UNIQUE_ID_rh_kabi_hide40;
		union {		};
	};
	struct pt_regs *regs;
	struct file___237 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
};

struct module___192;

struct file___238;

struct kiocb___238;

struct iov_iter___105;

struct vm_area_struct___239;

struct inode___238;

struct file_lock___238;

struct page___239;

struct seq_file___214;

struct file_operations___238 {
	struct module___192 *owner;
	loff_t (*llseek)(struct file___238 *, loff_t, int);
	ssize_t (*read)(struct file___238 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___238 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___238 *, struct iov_iter___105 *);
	ssize_t (*write_iter)(struct kiocb___238 *, struct iov_iter___105 *);
	int (*iopoll)(struct kiocb___238 *, bool);
	int (*iterate)(struct file___238 *, struct dir_context *);
	int (*iterate_shared)(struct file___238 *, struct dir_context *);
	__poll_t (*poll)(struct file___238 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___238 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___238 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___238 *, struct vm_area_struct___239 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___238 *, struct file___238 *);
	int (*flush)(struct file___238 *, fl_owner_t);
	int (*release)(struct inode___238 *, struct file___238 *);
	int (*fsync)(struct file___238 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___238 *, int);
	int (*lock)(struct file___238 *, int, struct file_lock___238 *);
	ssize_t (*sendpage)(struct file___238 *, struct page___239 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___238 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___238 *, int, struct file_lock___238 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___238 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___238 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___238 *, long int, struct file_lock___238 **, void **);
	long int (*fallocate)(struct file___238 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___214 *, struct file___238 *);
	ssize_t (*copy_file_range)(struct file___238 *, loff_t, struct file___238 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___238 *, loff_t, struct file___238 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___238 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___238 {
	u64 seqnum;
	struct vm_area_struct___239 *vmas[4];
};

struct page_frag___238 {
	struct page___239 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___238;

struct pid___178;

struct cred___231;

struct nsproxy___218;

struct signal_struct___196;

struct bio_list___114;

struct backing_dev_info___114;

struct io_context___59;

struct css_set___183;

struct request_queue___56;

struct vm_struct___155;

struct task_struct___239 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___239 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___238 *mm;
	struct mm_struct___238 *active_mm;
	struct vmacache___238 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___239 *real_parent;
	struct task_struct___239 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___239 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___178 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___178 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___178 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___231 *ptracer_cred;
	const struct cred___231 *real_cred;
	const struct cred___231 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___218 *nsproxy;
	struct signal_struct___196 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___239 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___114 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___114 *backing_dev_info;
	struct io_context___59 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___183 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___238 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___56 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___239 *oom_reaper_list;
	struct vm_struct___155 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___126 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct secondary_data___239 {
	void *stack;
	struct task_struct___239 *task;
	long int status;
};

struct vfsmount___62;

struct dentry___238;

struct path___237 {
	struct vfsmount___62 *mnt;
	struct dentry___238 *dentry;
};

struct fown_struct___178 {
	rwlock_t lock;
	struct pid___178 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct address_space___237;

struct file___238 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___237 f_path;
	struct inode___238 *f_inode;
	const struct file_operations___238 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___178 f_owner;
	const struct cred___231 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___237 *f_mapping;
	errseq_t f_wb_err;
};

struct bpf_map___183;

struct bpf_map_ops___183 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___183 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___183 *, struct file___238 *);
	void (*map_free)(struct bpf_map___183 *);
	int (*map_get_next_key)(struct bpf_map___183 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___183 *);
	void * (*map_lookup_elem)(struct bpf_map___183 *, void *);
	int (*map_update_elem)(struct bpf_map___183 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___183 *, void *);
	int (*map_push_elem)(struct bpf_map___183 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___183 *, void *);
	int (*map_peek_elem)(struct bpf_map___183 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___183 *, struct file___238 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___183 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___183 *, void *, struct seq_file___214 *);
	int (*map_check_btf)(const struct bpf_map___183 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct user_struct___231;

struct bpf_map___183 {
	const struct bpf_map_ops___183 *ops;
	struct bpf_map___183 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___231 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct seq_operations___212;

struct seq_file___214 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___212 *op;
	int poll_event;
	const struct file___238 *file;
	void *private;
};

struct key___231;

struct user_struct___231 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___231 *uid_keyring;
	struct key___231 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bpf_prog_aux___25 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___23 *ops;
	struct bpf_map___183 **used_maps;
	struct bpf_prog *prog;
	struct user_struct___231 *user;
	u64 load_time;
	struct bpf_map___183 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___23 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct dentry_operations___237;

struct super_block___237;

struct dentry___238 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___238 *d_parent;
	struct qstr d_name;
	struct inode___238 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___237 *d_op;
	struct super_block___237 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct rw_semaphore___239 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___239 *owner;
};

struct address_space_operations___237;

struct address_space___237 {
	struct inode___238 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___239 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___237 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___237;

struct bdi_writeback___114;

struct block_device___238;

struct inode___238 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___237 *i_op;
	struct super_block___237 *i_sb;
	struct address_space___237 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___239 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___114 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___238 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___237 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___238 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___237 {
	int (*d_revalidate)(struct dentry___238 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___238 *, unsigned int);
	int (*d_hash)(const struct dentry___238 *, struct qstr *);
	int (*d_compare)(const struct dentry___238 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___238 *);
	int (*d_init)(struct dentry___238 *);
	void (*d_release)(struct dentry___238 *);
	void (*d_prune)(struct dentry___238 *);
	void (*d_iput)(struct dentry___238 *, struct inode___238 *);
	char * (*d_dname)(struct dentry___238 *, char *, int);
	struct vfsmount___62 * (*d_automount)(struct path___237 *);
	int (*d_manage)(const struct path___237 *, bool);
	struct dentry___238 * (*d_real)(struct dentry___238 *, const struct inode___238 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___237;

struct mem_dqinfo___237 {
	struct quota_format_type___237 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___237;

struct quota_info___237 {
	unsigned int flags;
	struct rw_semaphore___239 dqio_sem;
	struct inode___238 *files[3];
	struct mem_dqinfo___237 info[3];
	const struct quota_format_ops___237 *ops[3];
};

struct rcuwait___237 {
	struct task_struct___239 *task;
};

struct percpu_rw_semaphore___237 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___239 rw_sem;
	struct rcuwait___237 writer;
	int readers_block;
};

struct sb_writers___237 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___237 rw_sem[3];
};

struct file_system_type___237;

struct super_operations___237;

struct dquot_operations___237;

struct quotactl_ops___237;

struct xattr_handler___23;

struct user_namespace___198;

struct super_block___237 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___237 *s_type;
	const struct super_operations___237 *s_op;
	const struct dquot_operations___237 *dq_op;
	const struct quotactl_ops___237 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___238 *s_root;
	struct rw_semaphore___239 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___23 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___238 *s_bdev;
	struct backing_dev_info___114 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___237 s_dquot;
	struct sb_writers___237 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___237 *s_d_op;
	int cleancache_poolid;
	struct shrinker___99 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___198 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___62 {
	struct dentry___238 *mnt_root;
	struct super_block___237 *mnt_sb;
	int mnt_flags;
};

struct ucounts___198;

struct user_namespace___198 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___198 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___28 ns;
	long unsigned int flags;
	struct key___231 *persistent_keyring_register;
	struct rw_semaphore___239 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___198 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___239 *pgtable_t___238;

struct dev_pagemap___228;

struct page___239 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___237 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___239 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___238 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___238 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___228 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___238;

struct lruvec___238 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___238 *pgdat;
};

struct zone___238 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___238 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___238 {
	struct zone___238 *zone;
	int zone_idx;
};

struct zonelist___238 {
	struct zoneref___238 _zonerefs[25];
};

struct pglist_data___238 {
	struct zone___238 node_zones[3];
	struct zonelist___238 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___239 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___239 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___238 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___238 {
	struct rw_semaphore___239 rwsem;
	struct notifier_block *head;
};

struct cred___231 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___231 *session_keyring;
	struct key___231 *process_keyring;
	struct key___231 *thread_keyring;
	struct key___231 *request_key_auth;
	void *security;
	struct user_struct___231 *user;
	struct user_namespace___198 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___232;

struct kernfs_elem_dir___232 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___232 *root;
};

struct kernfs_node___232;

struct kernfs_syscall_ops___232;

struct kernfs_root___232 {
	struct kernfs_node___232 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___232 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___232 {
	struct kernfs_node___232 *target_kn;
};

struct kernfs_ops___232;

struct kernfs_elem_attr___232 {
	const struct kernfs_ops___232 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___232 *notify_next;
};

struct kernfs_node___232 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___232 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___232 dir;
		struct kernfs_elem_symlink___232 symlink;
		struct kernfs_elem_attr___232 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___232;

struct kernfs_ops___232 {
	int (*open)(struct kernfs_open_file___232 *);
	void (*release)(struct kernfs_open_file___232 *);
	int (*seq_show)(struct seq_file___214 *, void *);
	void * (*seq_start)(struct seq_file___214 *, loff_t *);
	void * (*seq_next)(struct seq_file___214 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___214 *, void *);
	ssize_t (*read)(struct kernfs_open_file___232 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___232 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___232 *, struct vm_area_struct___239 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___232 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___232 {
	int (*remount_fs)(struct kernfs_root___232 *, int *, char *);
	int (*show_options)(struct seq_file___214 *, struct kernfs_root___232 *);
	int (*mkdir)(struct kernfs_node___232 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___232 *);
	int (*rename)(struct kernfs_node___232 *, struct kernfs_node___232 *, const char *);
	int (*show_path)(struct seq_file___214 *, struct kernfs_node___232 *, struct kernfs_root___232 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_operations_struct___228;

struct kernfs_open_file___232 {
	struct kernfs_node___232 *kn;
	struct file___238 *file;
	struct seq_file___214 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___228 *vm_ops;
};

struct vm_fault___228;

struct vm_operations_struct___228 {
	void (*open)(struct vm_area_struct___239 *);
	void (*close)(struct vm_area_struct___239 *);
	int (*split)(struct vm_area_struct___239 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___239 *);
	vm_fault_t (*fault)(struct vm_fault___228 *);
	vm_fault_t (*huge_fault)(struct vm_fault___228 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___228 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___239 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___228 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___228 *);
	int (*access)(struct vm_area_struct___239 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___239 *);
	int (*set_policy)(struct vm_area_struct___239 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___239 *, long unsigned int);
	struct page___239 * (*find_special_page)(struct vm_area_struct___239 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_area_struct___239 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___239 *vm_next;
	struct vm_area_struct___239 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___238 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___228 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___238 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___226;

struct bin_attribute___203;

struct attribute_group___204 {
	const char *name;
	umode_t (*is_visible)(struct kobject___226 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___226 *, struct bin_attribute___203 *, int);
	struct attribute **attrs;
	struct bin_attribute___203 **bin_attrs;
};

struct kset___225;

struct kobj_type___225;

struct kobject___226 {
	const char *name;
	struct list_head entry;
	struct kobject___226 *parent;
	struct kset___225 *kset;
	struct kobj_type___225 *ktype;
	struct kernfs_node___232 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___203 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___238 *, struct kobject___226 *, struct bin_attribute___203 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___238 *, struct kobject___226 *, struct bin_attribute___203 *, char *, loff_t, size_t);
	int (*mmap)(struct file___238 *, struct kobject___226 *, struct bin_attribute___203 *, struct vm_area_struct___239 *);
};

struct sysfs_ops___225 {
	ssize_t (*show)(struct kobject___226 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___226 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___225;

struct kset___225 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___226 kobj;
	const struct kset_uevent_ops___225 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___225 {
	void (*release)(struct kobject___226 *);
	const struct sysfs_ops___225 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___13 * (*child_ns_type)(struct kobject___226 *);
	const void * (*namespace)(struct kobject___226 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___225 {
	int (* const filter)(struct kset___225 *, struct kobject___226 *);
	const char * (* const name)(struct kset___225 *, struct kobject___226 *);
	int (* const uevent)(struct kset___225 *, struct kobject___226 *, struct kobj_uevent_env *);
};

struct kobj_attribute___219 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___226 *, struct kobj_attribute___219 *, char *);
	ssize_t (*store)(struct kobject___226 *, struct kobj_attribute___219 *, const char *, size_t);
};

struct kernel_param___189;

struct kernel_param_ops___189 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___189 *);
	int (*get)(char *, const struct kernel_param___189 *);
	void (*free)(void *);
};

struct kparam_array___189;

struct kernel_param___189 {
	const char *name;
	struct module___192 *mod;
	const struct kernel_param_ops___189 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___189 *arr;
	};
};

struct kparam_array___189 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___189 *ops;
	void *elem;
};

struct module_kobject___189 {
	struct kobject___226 kobj;
	struct module___192 *mod;
	struct kobject___226 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___189 {
	struct module___192 *mod;
	struct latch_tree_node node;
};

struct module_layout___189 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___189 mtn;
};

struct module_attribute___189;

struct module___192 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___189 mkobj;
	struct module_attribute___189 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___226 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___189 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___189 core_layout;
	struct module_layout___189 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___189 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___189 *, struct module_kobject___189 *, char *);
	ssize_t (*store)(struct module_attribute___189 *, struct module_kobject___189 *, const char *, size_t);
	void (*setup)(struct module___192 *, const char *);
	int (*test)(struct module___192 *);
	void (*free)(struct module___192 *);
};

typedef int (*key_restrict_link_func_t___231)(struct key___231 *, const struct key_type *, const union key_payload *, struct key___231 *);

struct key_restriction___231;

struct key___231 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___239 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key___5 index_key;
		struct {
			struct key_type___5 *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___231 *restrict_link;
};

struct key_restriction___231 {
	key_restrict_link_func_t___231 check;
	struct key___231 *key;
	struct key_type *keytype;
};

struct pid_namespace___178;

struct upid___178 {
	int nr;
	struct pid_namespace___178 *ns;
};

struct pid_namespace___178 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___239 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___178 *parent;
	struct vfsmount___62 *proc_mnt;
	struct dentry___238 *proc_self;
	struct dentry___238 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___198 *user_ns;
	struct ucounts___198 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___28 ns;
};

struct pid___178 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___178 numbers[1];
};

struct core_state___238;

struct mm_struct___238 {
	struct {
		struct vm_area_struct___239 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___238 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___239 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___238 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___239 *owner;
		struct user_namespace___198 *user_ns;
		struct file___238 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___238 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___228)(struct vm_area_struct___239 *, long unsigned int, const struct page___239 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___228)(struct page___239 *, void *);

struct device___202;

struct dev_pagemap___228 {
	dev_page_fault_t___228 page_fault;
	dev_page_free_t___228 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___202 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___238 {
	struct task_struct___239 *task;
	struct core_thread___238 *next;
};

struct core_state___238 {
	atomic_t nr_threads;
	struct core_thread___238 dumper;
	struct completion startup;
};

struct vm_fault___228 {
	struct vm_area_struct___239 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___239 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___239 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___238 prealloc_pte;
};

struct cgroup_namespace___183;

struct nsproxy___218 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___178 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___183 *cgroup_ns;
};

struct signal_struct___196 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___239 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___239 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___178 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___178 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___238 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___178 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___114;

struct bio_list___114 {
	struct bio___114 *head;
	struct bio___114 *tail;
};

struct bdi_writeback_congested___114;

struct cgroup_subsys_state___184;

struct bdi_writeback___114 {
	struct backing_dev_info___114 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___114 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___184 *memcg_css;
	struct cgroup_subsys_state___184 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___114 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___114 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___202 *dev;
	struct device___202 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___238 *debug_dir;
	struct dentry___238 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___59;

struct io_context___59 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___59 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___183;

struct css_set___183 {
	struct cgroup_subsys_state___184 *subsys[13];
	refcount_t refcount;
	struct css_set___183 *dom_cset;
	struct cgroup___183 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___183 *mg_src_cgrp;
	struct cgroup___183 *mg_dst_cgrp;
	struct css_set___183 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

typedef blk_qc_t make_request_fn___55(struct request_queue___56 *, struct bio___114 *);

struct request___56;

typedef int dma_drain_needed_fn___55(struct request___56 *);

struct bsg_ops___55;

struct bsg_class_device___55 {
	struct device___202 *class_dev;
	int minor;
	struct request_queue___56 *queue;
	const struct bsg_ops___55 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___114 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___114 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___55;

struct blkcg_gq___44;

struct request_queue___56 {
	struct list_head queue_head;
	struct request___56 *last_merge;
	struct elevator_queue___55 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___55 *make_request_fn;
	dma_drain_needed_fn___55 *dma_drain_needed;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___114 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___226 kobj;
	struct kobject___226 *mq_kobj;
	struct blk_integrity integrity;
	struct device___202 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___44 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	struct bsg_class_device___55 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___114 bio_split;
	struct dentry___238 *debugfs_dir;
	struct dentry___238 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___155 {
	struct vm_struct___155 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___239 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___208 {
	struct task_struct___239 task;
	long unsigned int stack[8192];
};

struct io_cq___59 {
	struct request_queue___56 *q;
	struct io_context___59 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___6 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___238 {
	struct file___238 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___238 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___237 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___238 *ia_file;
};

struct dquot___237 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___237 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___237 {
	int qf_fmt_id;
	const struct quota_format_ops___237 *qf_ops;
	struct module___192 *qf_owner;
	struct quota_format_type___237 *qf_next;
};

struct quota_format_ops___237 {
	int (*check_quota_file)(struct super_block___237 *, int);
	int (*read_file_info)(struct super_block___237 *, int);
	int (*write_file_info)(struct super_block___237 *, int);
	int (*free_file_info)(struct super_block___237 *, int);
	int (*read_dqblk)(struct dquot___237 *);
	int (*commit_dqblk)(struct dquot___237 *);
	int (*release_dqblk)(struct dquot___237 *);
	int (*get_next_id)(struct super_block___237 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___237 {
	int (*write_dquot)(struct dquot___237 *);
	struct dquot___237 * (*alloc_dquot)(struct super_block___237 *, int);
	void (*destroy_dquot)(struct dquot___237 *);
	int (*acquire_dquot)(struct dquot___237 *);
	int (*release_dquot)(struct dquot___237 *);
	int (*mark_dirty)(struct dquot___237 *);
	int (*write_info)(struct super_block___237 *, int);
	qsize_t * (*get_reserved_space)(struct inode___238 *);
	int (*get_projid)(struct inode___238 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___238 *, qsize_t *);
	int (*get_next_id)(struct super_block___237 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___237 {
	int (*quota_on)(struct super_block___237 *, int, int, const struct path___237 *);
	int (*quota_off)(struct super_block___237 *, int);
	int (*quota_enable)(struct super_block___237 *, unsigned int);
	int (*quota_disable)(struct super_block___237 *, unsigned int);
	int (*quota_sync)(struct super_block___237 *, int);
	int (*set_info)(struct super_block___237 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___237 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___237 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___237 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___237 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___237 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___110;

struct address_space_operations___237 {
	int (*writepage)(struct page___239 *, struct writeback_control___110 *);
	int (*readpage)(struct file___238 *, struct page___239 *);
	int (*writepages)(struct address_space___237 *, struct writeback_control___110 *);
	int (*set_page_dirty)(struct page___239 *);
	int (*readpages)(struct file___238 *, struct address_space___237 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___238 *, struct address_space___237 *, loff_t, unsigned int, unsigned int, struct page___239 **, void **);
	int (*write_end)(struct file___238 *, struct address_space___237 *, loff_t, unsigned int, unsigned int, struct page___239 *, void *);
	sector_t (*bmap)(struct address_space___237 *, sector_t);
	void (*invalidatepage)(struct page___239 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___239 *, gfp_t);
	void (*freepage)(struct page___239 *);
	ssize_t (*direct_IO)(struct kiocb___238 *, struct iov_iter___105 *);
	int (*migratepage)(struct address_space___237 *, struct page___239 *, struct page___239 *, enum migrate_mode);
	bool (*isolate_page)(struct page___239 *, isolate_mode_t);
	void (*putback_page)(struct page___239 *);
	int (*launder_page)(struct page___239 *);
	int (*is_partially_uptodate)(struct page___239 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___239 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___237 *, struct page___239 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___238 *, sector_t *);
	void (*swap_deactivate)(struct file___238 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___110 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___114 *wb;
	struct inode___238 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___114;

struct iov_iter___105 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___114 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct hd_struct___56;

struct gendisk___56;

struct block_device___238 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___238 *bd_inode;
	struct super_block___237 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___238 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___56 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___56 *bd_disk;
	struct request_queue___56 *bd_queue;
	struct backing_dev_info___114 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___202 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___202 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___202;

struct bus_type___202;

struct device_driver___202;

struct dev_pm_domain___202;

struct fwnode_handle___137;

struct class___202;

struct device___202 {
	struct device___202 *parent;
	struct device_private *p;
	struct kobject___226 kobj;
	const char *init_name;
	const struct device_type___202 *type;
	struct mutex mutex;
	struct bus_type___202 *bus;
	struct device_driver___202 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___202 power;
	struct dev_pm_domain___202 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___137 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___202 *class;
	const struct attribute_group___204 **groups;
	void (*release)(struct device___202 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___56 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___202 __dev;
	struct kobject___226 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___56;

struct block_device_operations___56;

struct gendisk___56 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___56 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___56 *part_tbl;
	struct hd_struct___56 part0;
	const struct block_device_operations___56 *fops;
	struct request_queue___56 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___239 lookup_sem;
	struct kobject___226 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___226 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___237 {
	struct dentry___238 * (*lookup)(struct inode___238 *, struct dentry___238 *, unsigned int);
	const char * (*get_link)(struct dentry___238 *, struct inode___238 *, struct delayed_call *);
	int (*permission)(struct inode___238 *, int);
	struct posix_acl * (*get_acl)(struct inode___238 *, int);
	int (*readlink)(struct dentry___238 *, char *, int);
	int (*create)(struct inode___238 *, struct dentry___238 *, umode_t, bool);
	int (*link)(struct dentry___238 *, struct inode___238 *, struct dentry___238 *);
	int (*unlink)(struct inode___238 *, struct dentry___238 *);
	int (*symlink)(struct inode___238 *, struct dentry___238 *, const char *);
	int (*mkdir)(struct inode___238 *, struct dentry___238 *, umode_t);
	int (*rmdir)(struct inode___238 *, struct dentry___238 *);
	int (*mknod)(struct inode___238 *, struct dentry___238 *, umode_t, dev_t);
	int (*rename)(struct inode___238 *, struct dentry___238 *, struct inode___238 *, struct dentry___238 *, unsigned int);
	int (*setattr)(struct dentry___238 *, struct iattr___237 *);
	int (*getattr)(const struct path___237 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___238 *, char *, size_t);
	int (*fiemap)(struct inode___238 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___238 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___238 *, struct dentry___238 *, struct file___238 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___238 *, struct dentry___238 *, umode_t);
	int (*set_acl)(struct inode___238 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___237 {
	void (*fl_copy_lock)(struct file_lock___238 *, struct file_lock___238 *);
	void (*fl_release_private)(struct file_lock___238 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___237;

struct lock_manager_operations___237;

struct file_lock___238 {
	struct file_lock___238 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___238 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___237 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___237 *fl_ops;
	const struct lock_manager_operations___237 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___237 {
	int (*lm_compare_owner)(struct file_lock___238 *, struct file_lock___238 *);
	long unsigned int (*lm_owner_key)(struct file_lock___238 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___238 *);
	int (*lm_grant)(struct file_lock___238 *, int);
	bool (*lm_break)(struct file_lock___238 *);
	int (*lm_change)(struct file_lock___238 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___238 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___237 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___237 *fa_next;
	struct file___238 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___237 {
	const char *name;
	int fs_flags;
	struct dentry___238 * (*mount)(struct file_system_type___237 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___237 *);
	struct module___192 *owner;
	struct file_system_type___237 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___237 {
	struct inode___238 * (*alloc_inode)(struct super_block___237 *);
	void (*destroy_inode)(struct inode___238 *);
	void (*dirty_inode)(struct inode___238 *, int);
	int (*write_inode)(struct inode___238 *, struct writeback_control___110 *);
	int (*drop_inode)(struct inode___238 *);
	void (*evict_inode)(struct inode___238 *);
	void (*put_super)(struct super_block___237 *);
	int (*sync_fs)(struct super_block___237 *, int);
	int (*freeze_super)(struct super_block___237 *);
	int (*freeze_fs)(struct super_block___237 *);
	int (*thaw_super)(struct super_block___237 *);
	int (*unfreeze_fs)(struct super_block___237 *);
	int (*statfs)(struct dentry___238 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___237 *, int *, char *);
	void (*umount_begin)(struct super_block___237 *);
	int (*show_options)(struct seq_file___214 *, struct dentry___238 *);
	int (*show_devname)(struct seq_file___214 *, struct dentry___238 *);
	int (*show_path)(struct seq_file___214 *, struct dentry___238 *);
	int (*show_stats)(struct seq_file___214 *, struct dentry___238 *);
	ssize_t (*quota_read)(struct super_block___237 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___237 *, int, const char *, size_t, loff_t);
	struct dquot___237 ** (*get_dquots)(struct inode___238 *);
	int (*bdev_try_to_free_page)(struct super_block___237 *, struct page___239 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___237 *, struct shrink_control___99 *);
	long int (*free_cached_objects)(struct super_block___237 *, struct shrink_control___99 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct xattr_handler___23 {
	const char *name;
	const char *prefix;
	int flags;
	bool (*list)(struct dentry___238 *);
	int (*get)(const struct xattr_handler___23 *, struct dentry___238 *, struct inode___238 *, const char *, void *, size_t);
	int (*set)(const struct xattr_handler___23 *, struct dentry___238 *, struct inode___238 *, const char *, const void *, size_t, int);
};

typedef void bio_end_io_t___114(struct bio___114 *);

struct bio_vec___114 {
	struct page___239 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___114;

struct bio___114 {
	struct bio___114 *bi_next;
	struct gendisk___56 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___114 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___44 *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___114 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___114 *bi_io_vec;
	struct bio_set___114 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___114 bi_inline_vecs[0];
};

typedef void compound_page_dtor___228(struct page___239 *);

enum lsm_event {
	LSM_POLICY_CHANGE = 0,
};

typedef int (*initxattrs)(struct inode___238 *, const struct xattr *, void *);

struct sk_buff___28;

struct socket___15;

struct msghdr___15;

union security_list_options___2 {
	int (*binder_set_context_mgr)(struct task_struct___239 *);
	int (*binder_transaction)(struct task_struct___239 *, struct task_struct___239 *);
	int (*binder_transfer_binder)(struct task_struct___239 *, struct task_struct___239 *);
	int (*binder_transfer_file)(struct task_struct___239 *, struct task_struct___239 *, struct file___238 *);
	int (*ptrace_access_check)(struct task_struct___239 *, unsigned int);
	int (*ptrace_traceme)(struct task_struct___239 *);
	int (*capget)(struct task_struct___239 *, kernel_cap_t *, kernel_cap_t *, kernel_cap_t *);
	int (*capset)(struct cred___231 *, const struct cred___231 *, const kernel_cap_t *, const kernel_cap_t *, const kernel_cap_t *);
	int (*capable)(const struct cred___231 *, struct user_namespace___198 *, int, int);
	int (*quotactl)(int, int, int, struct super_block___237 *);
	int (*quota_on)(struct dentry___238 *);
	int (*syslog)(int);
	int (*settime)(const struct timespec64 *, const struct timezone *);
	int (*vm_enough_memory)(struct mm_struct___238 *, long int);
	int (*bprm_set_creds)(struct linux_binprm___2 *);
	int (*bprm_check_security)(struct linux_binprm___2 *);
	void (*bprm_committing_creds)(struct linux_binprm___2 *);
	void (*bprm_committed_creds)(struct linux_binprm___2 *);
	int (*sb_alloc_security)(struct super_block___237 *);
	void (*sb_free_security)(struct super_block___237 *);
	int (*sb_copy_data)(char *, char *);
	int (*sb_remount)(struct super_block___237 *, void *);
	int (*sb_kern_mount)(struct super_block___237 *, int, void *);
	int (*sb_show_options)(struct seq_file___214 *, struct super_block___237 *);
	int (*sb_statfs)(struct dentry___238 *);
	int (*sb_mount)(const char *, const struct path___237 *, const char *, long unsigned int, void *);
	int (*sb_umount)(struct vfsmount___62 *, int);
	int (*sb_pivotroot)(const struct path___237 *, const struct path___237 *);
	int (*sb_set_mnt_opts)(struct super_block___237 *, struct security_mnt_opts *, long unsigned int, long unsigned int *);
	int (*sb_clone_mnt_opts)(const struct super_block___237 *, struct super_block___237 *, long unsigned int, long unsigned int *);
	int (*sb_parse_opts_str)(char *, struct security_mnt_opts *);
	int (*dentry_init_security)(struct dentry___238 *, int, const struct qstr *, void **, u32 *);
	int (*dentry_create_files_as)(struct dentry___238 *, int, struct qstr *, const struct cred___231 *, struct cred___231 *);
	int (*inode_alloc_security)(struct inode___238 *);
	void (*inode_free_security)(struct inode___238 *);
	int (*inode_init_security)(struct inode___238 *, struct inode___238 *, const struct qstr *, const char **, void **, size_t *);
	int (*inode_create)(struct inode___238 *, struct dentry___238 *, umode_t);
	int (*inode_link)(struct dentry___238 *, struct inode___238 *, struct dentry___238 *);
	int (*inode_unlink)(struct inode___238 *, struct dentry___238 *);
	int (*inode_symlink)(struct inode___238 *, struct dentry___238 *, const char *);
	int (*inode_mkdir)(struct inode___238 *, struct dentry___238 *, umode_t);
	int (*inode_rmdir)(struct inode___238 *, struct dentry___238 *);
	int (*inode_mknod)(struct inode___238 *, struct dentry___238 *, umode_t, dev_t);
	int (*inode_rename)(struct inode___238 *, struct dentry___238 *, struct inode___238 *, struct dentry___238 *);
	int (*inode_readlink)(struct dentry___238 *);
	int (*inode_follow_link)(struct dentry___238 *, struct inode___238 *, bool);
	int (*inode_permission)(struct inode___238 *, int);
	int (*inode_setattr)(struct dentry___238 *, struct iattr___237 *);
	int (*inode_getattr)(const struct path___237 *);
	int (*inode_setxattr)(struct dentry___238 *, const char *, const void *, size_t, int);
	void (*inode_post_setxattr)(struct dentry___238 *, const char *, const void *, size_t, int);
	int (*inode_getxattr)(struct dentry___238 *, const char *);
	int (*inode_listxattr)(struct dentry___238 *);
	int (*inode_removexattr)(struct dentry___238 *, const char *);
	int (*inode_need_killpriv)(struct dentry___238 *);
	int (*inode_killpriv)(struct dentry___238 *);
	int (*inode_getsecurity)(struct inode___238 *, const char *, void **, bool);
	int (*inode_setsecurity)(struct inode___238 *, const char *, const void *, size_t, int);
	int (*inode_listsecurity)(struct inode___238 *, char *, size_t);
	void (*inode_getsecid)(struct inode___238 *, u32 *);
	int (*inode_copy_up)(struct dentry___238 *, struct cred___231 **);
	int (*inode_copy_up_xattr)(const char *);
	int (*kernfs_init_security)(struct kernfs_node___232 *, struct kernfs_node___232 *);
	int (*file_permission)(struct file___238 *, int);
	int (*file_alloc_security)(struct file___238 *);
	void (*file_free_security)(struct file___238 *);
	int (*file_ioctl)(struct file___238 *, unsigned int, long unsigned int);
	int (*mmap_addr)(long unsigned int);
	int (*mmap_file)(struct file___238 *, long unsigned int, long unsigned int, long unsigned int);
	int (*file_mprotect)(struct vm_area_struct___239 *, long unsigned int, long unsigned int);
	int (*file_lock)(struct file___238 *, unsigned int);
	int (*file_fcntl)(struct file___238 *, unsigned int, long unsigned int);
	void (*file_set_fowner)(struct file___238 *);
	int (*file_send_sigiotask)(struct task_struct___239 *, struct fown_struct___178 *, int);
	int (*file_receive)(struct file___238 *);
	int (*file_open)(struct file___238 *);
	int (*task_alloc)(struct task_struct___239 *, long unsigned int);
	void (*task_free)(struct task_struct___239 *);
	int (*cred_alloc_blank)(struct cred___231 *, gfp_t);
	void (*cred_free)(struct cred___231 *);
	int (*cred_prepare)(struct cred___231 *, const struct cred___231 *, gfp_t);
	void (*cred_transfer)(struct cred___231 *, const struct cred___231 *);
	void (*cred_getsecid)(const struct cred___231 *, u32 *);
	int (*kernel_act_as)(struct cred___231 *, u32);
	int (*kernel_create_files_as)(struct cred___231 *, struct inode___238 *);
	int (*kernel_module_request)(char *);
	int (*kernel_read_file)(struct file___238 *, enum kernel_read_file_id);
	int (*kernel_post_read_file)(struct file___238 *, char *, loff_t, enum kernel_read_file_id);
	int (*task_fix_setuid)(struct cred___231 *, const struct cred___231 *, int);
	int (*task_setpgid)(struct task_struct___239 *, pid_t);
	int (*task_getpgid)(struct task_struct___239 *);
	int (*task_getsid)(struct task_struct___239 *);
	void (*task_getsecid)(struct task_struct___239 *, u32 *);
	int (*task_setnice)(struct task_struct___239 *, int);
	int (*task_setioprio)(struct task_struct___239 *, int);
	int (*task_getioprio)(struct task_struct___239 *);
	int (*task_prlimit)(const struct cred___231 *, const struct cred___231 *, unsigned int);
	int (*task_setrlimit)(struct task_struct___239 *, unsigned int, struct rlimit *);
	int (*task_setscheduler)(struct task_struct___239 *);
	int (*task_getscheduler)(struct task_struct___239 *);
	int (*task_movememory)(struct task_struct___239 *);
	int (*task_kill)(struct task_struct___239 *, struct kernel_siginfo *, int, const struct cred___231 *);
	int (*task_prctl)(int, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*task_to_inode)(struct task_struct___239 *, struct inode___238 *);
	int (*ipc_permission)(struct kern_ipc_perm *, short int);
	void (*ipc_getsecid)(struct kern_ipc_perm *, u32 *);
	int (*msg_msg_alloc_security)(struct msg_msg___2 *);
	void (*msg_msg_free_security)(struct msg_msg___2 *);
	int (*msg_queue_alloc_security)(struct kern_ipc_perm *);
	void (*msg_queue_free_security)(struct kern_ipc_perm *);
	int (*msg_queue_associate)(struct kern_ipc_perm *, int);
	int (*msg_queue_msgctl)(struct kern_ipc_perm *, int);
	int (*msg_queue_msgsnd)(struct kern_ipc_perm *, struct msg_msg___2 *, int);
	int (*msg_queue_msgrcv)(struct kern_ipc_perm *, struct msg_msg___2 *, struct task_struct___239 *, long int, int);
	int (*shm_alloc_security)(struct kern_ipc_perm *);
	void (*shm_free_security)(struct kern_ipc_perm *);
	int (*shm_associate)(struct kern_ipc_perm *, int);
	int (*shm_shmctl)(struct kern_ipc_perm *, int);
	int (*shm_shmat)(struct kern_ipc_perm *, char *, int);
	int (*sem_alloc_security)(struct kern_ipc_perm *);
	void (*sem_free_security)(struct kern_ipc_perm *);
	int (*sem_associate)(struct kern_ipc_perm *, int);
	int (*sem_semctl)(struct kern_ipc_perm *, int);
	int (*sem_semop)(struct kern_ipc_perm *, struct sembuf *, unsigned int, int);
	int (*netlink_send)(struct sock *, struct sk_buff___28 *);
	void (*d_instantiate)(struct dentry___238 *, struct inode___238 *);
	int (*getprocattr)(struct task_struct___239 *, char *, char **);
	int (*setprocattr)(const char *, void *, size_t);
	int (*ismaclabel)(const char *);
	int (*secid_to_secctx)(u32, char **, u32 *);
	int (*secctx_to_secid)(const char *, u32, u32 *);
	void (*release_secctx)(char *, u32);
	void (*inode_invalidate_secctx)(struct inode___238 *);
	int (*inode_notifysecctx)(struct inode___238 *, void *, u32);
	int (*inode_setsecctx)(struct dentry___238 *, void *, u32);
	int (*inode_getsecctx)(struct inode___238 *, void **, u32 *);
	int (*unix_stream_connect)(struct sock *, struct sock *, struct sock *);
	int (*unix_may_send)(struct socket___15 *, struct socket___15 *);
	int (*socket_create)(int, int, int, int);
	int (*socket_post_create)(struct socket___15 *, int, int, int, int);
	int (*socket_socketpair)(struct socket___15 *, struct socket___15 *);
	int (*socket_bind)(struct socket___15 *, struct sockaddr *, int);
	int (*socket_connect)(struct socket___15 *, struct sockaddr *, int);
	int (*socket_listen)(struct socket___15 *, int);
	int (*socket_accept)(struct socket___15 *, struct socket___15 *);
	int (*socket_sendmsg)(struct socket___15 *, struct msghdr___15 *, int);
	int (*socket_recvmsg)(struct socket___15 *, struct msghdr___15 *, int, int);
	int (*socket_getsockname)(struct socket___15 *);
	int (*socket_getpeername)(struct socket___15 *);
	int (*socket_getsockopt)(struct socket___15 *, int, int);
	int (*socket_setsockopt)(struct socket___15 *, int, int);
	int (*socket_shutdown)(struct socket___15 *, int);
	int (*socket_sock_rcv_skb)(struct sock *, struct sk_buff___28 *);
	int (*socket_getpeersec_stream)(struct socket___15 *, char *, int *, unsigned int);
	int (*socket_getpeersec_dgram)(struct socket___15 *, struct sk_buff___28 *, u32 *);
	int (*sk_alloc_security)(struct sock *, int, gfp_t);
	void (*sk_free_security)(struct sock *);
	void (*sk_clone_security)(const struct sock *, struct sock *);
	void (*sk_getsecid)(struct sock *, u32 *);
	void (*sock_graft)(struct sock *, struct socket___15 *);
	int (*inet_conn_request)(struct sock *, struct sk_buff___28 *, struct request_sock___7 *);
	void (*inet_csk_clone)(struct sock *, const struct request_sock___7 *);
	void (*inet_conn_established)(struct sock *, struct sk_buff___28 *);
	int (*secmark_relabel_packet)(u32);
	void (*secmark_refcount_inc)();
	void (*secmark_refcount_dec)();
	void (*req_classify_flow)(const struct request_sock___7 *, struct flowi *);
	int (*tun_dev_alloc_security)(void **);
	void (*tun_dev_free_security)(void *);
	int (*tun_dev_create)();
	int (*tun_dev_attach_queue)(void *);
	int (*tun_dev_attach)(struct sock *, void *);
	int (*tun_dev_open)(void *);
	int (*sctp_assoc_request)(struct sctp_endpoint *, struct sk_buff___28 *);
	int (*sctp_bind_connect)(struct sock *, int, struct sockaddr *, int);
	void (*sctp_sk_clone)(struct sctp_endpoint *, struct sock *, struct sock *);
	int (*ib_pkey_access)(void *, u64, u16);
	int (*ib_endport_manage_subnet)(void *, const char *, u8);
	int (*ib_alloc_security)(void **);
	void (*ib_free_security)(void *);
	int (*xfrm_policy_alloc_security)(struct xfrm_sec_ctx **, struct xfrm_user_sec_ctx *, gfp_t);
	int (*xfrm_policy_clone_security)(struct xfrm_sec_ctx *, struct xfrm_sec_ctx **);
	void (*xfrm_policy_free_security)(struct xfrm_sec_ctx *);
	int (*xfrm_policy_delete_security)(struct xfrm_sec_ctx *);
	int (*xfrm_state_alloc)(struct xfrm_state *, struct xfrm_user_sec_ctx *);
	int (*xfrm_state_alloc_acquire)(struct xfrm_state *, struct xfrm_sec_ctx *, u32);
	void (*xfrm_state_free_security)(struct xfrm_state *);
	int (*xfrm_state_delete_security)(struct xfrm_state *);
	int (*xfrm_policy_lookup)(struct xfrm_sec_ctx *, u32, u8);
	int (*xfrm_state_pol_flow_match)(struct xfrm_state *, struct xfrm_policy *, const struct flowi *);
	int (*xfrm_decode_session)(struct sk_buff___28 *, u32 *, int);
	int (*key_alloc)(struct key___231 *, const struct cred___231 *, long unsigned int);
	void (*key_free)(struct key___231 *);
	int (*key_permission)(key_ref_t, const struct cred___231 *, unsigned int);
	int (*key_getsecurity)(struct key___231 *, char **);
	int (*audit_rule_init)(u32, u32, char *, void **);
	int (*audit_rule_known)(struct audit_krule *);
	int (*audit_rule_match)(u32, u32, u32, void *, struct audit_context *);
	void (*audit_rule_free)(void *);
	int (*bpf)(int, union bpf_attr *, unsigned int);
	int (*bpf_map)(struct bpf_map___183 *, fmode_t);
	int (*bpf_prog)(struct bpf_prog *);
	int (*bpf_map_alloc_security)(struct bpf_map___183 *);
	void (*bpf_map_free_security)(struct bpf_map___183 *);
	int (*bpf_prog_alloc_security)(struct bpf_prog_aux___25 *);
	void (*bpf_prog_free_security)(struct bpf_prog_aux___25 *);
};

struct msghdr___15 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___105 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___238 *msg_iocb;
};

struct security_hook_list___2 {
	struct hlist_node list;
	struct hlist_head *head;
	union security_list_options___2 hook;
	char *lsm;
};

struct cgroup_namespace___183 {
	refcount_t count;
	struct ns_common___28 ns;
	struct user_namespace___198 *user_ns;
	struct ucounts___198 *ucounts;
	struct css_set___183 *root_cset;
};

struct ucounts___198 {
	struct hlist_node node;
	struct user_namespace___198 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct fwnode_operations___137;

struct fwnode_handle___137 {
	struct fwnode_handle___137 *secondary;
	const struct fwnode_operations___137 *ops;
};

struct fwnode_reference_args___137;

struct fwnode_endpoint___137;

struct fwnode_operations___137 {
	struct fwnode_handle___137 * (*get)(struct fwnode_handle___137 *);
	void (*put)(struct fwnode_handle___137 *);
	bool (*device_is_available)(const struct fwnode_handle___137 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___137 *, const struct device___202 *);
	bool (*property_present)(const struct fwnode_handle___137 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___137 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___137 *, const char *, const char **, size_t);
	struct fwnode_handle___137 * (*get_parent)(const struct fwnode_handle___137 *);
	struct fwnode_handle___137 * (*get_next_child_node)(const struct fwnode_handle___137 *, struct fwnode_handle___137 *);
	struct fwnode_handle___137 * (*get_named_child_node)(const struct fwnode_handle___137 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___137 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___137 *);
	struct fwnode_handle___137 * (*graph_get_next_endpoint)(const struct fwnode_handle___137 *, struct fwnode_handle___137 *);
	struct fwnode_handle___137 * (*graph_get_remote_endpoint)(const struct fwnode_handle___137 *);
	struct fwnode_handle___137 * (*graph_get_port_parent)(struct fwnode_handle___137 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___137 *, struct fwnode_endpoint___137 *);
};

struct fwnode_endpoint___137 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___137 *local_fwnode;
};

struct fwnode_reference_args___137 {
	struct fwnode_handle___137 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct kimage___18;

typedef void *kexec_load_t___18(struct kimage___18 *, char *, long unsigned int, char *, long unsigned int, char *, long unsigned int);

struct kexec_file_ops___19 {
	kexec_probe_t *probe;
	kexec_load_t___18 *load;
	kexec_cleanup_t *cleanup;
};

struct kimage___18 {
	kimage_entry_t head;
	kimage_entry_t *entry;
	kimage_entry_t *last_entry;
	long unsigned int start;
	struct page___239 *control_code_page;
	struct page___239 *swap_page;
	void *vmcoreinfo_data_copy;
	long unsigned int nr_segments;
	struct kexec_segment segment[16];
	struct list_head control_pages;
	struct list_head dest_pages;
	struct list_head unusable_pages;
	long unsigned int control_page;
	unsigned int type: 1;
	unsigned int preserve_context: 1;
	unsigned int file_mode: 1;
	struct kimage_arch arch;
	void *kernel_buf;
	long unsigned int kernel_buf_len;
	void *initrd_buf;
	long unsigned int initrd_buf_len;
	char *cmdline_buf;
	long unsigned int cmdline_buf_len;
	const struct kexec_file_ops___19 *fops;
	void *image_loader_data;
	struct purgatory_info purgatory_info;
};

struct seq_operations___212 {
	void * (*start)(struct seq_file___214 *, loff_t *);
	void (*stop)(struct seq_file___214 *, void *);
	void * (*next)(struct seq_file___214 *, void *, loff_t *);
	int (*show)(struct seq_file___214 *, void *);
};

struct bio_integrity_payload___114 {
	struct bio___114 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___114 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___114 bip_inline_vecs[0];
};

struct blkcg___44;

struct blkg_policy_data___44;

struct blkcg_gq___44 {
	struct request_queue___56 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___44 *blkcg;
	struct bdi_writeback_congested___114 *wb_congested;
	struct blkcg_gq___44 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_rwstat stat_bytes;
	struct blkg_rwstat stat_ios;
	struct blkg_policy_data___44 *pd[5];
	struct callback_head callback_head;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
};

struct dev_pm_ops___202;

struct device_type___202 {
	const char *name;
	const struct attribute_group___204 **groups;
	int (*uevent)(struct device___202 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___202 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___202 *);
	const struct dev_pm_ops___202 *pm;
};

struct class___202 {
	const char *name;
	struct module___192 *owner;
	const struct attribute_group___204 **class_groups;
	const struct attribute_group___204 **dev_groups;
	struct kobject___226 *dev_kobj;
	int (*dev_uevent)(struct device___202 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___202 *, umode_t *);
	void (*class_release)(struct class___202 *);
	void (*dev_release)(struct device___202 *);
	int (*shutdown_pre)(struct device___202 *);
	const struct kobj_ns_type_operations___13 *ns_type;
	const void * (*namespace)(struct device___202 *);
	const struct dev_pm_ops___202 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dev_pm_ops___202 {
	int (*prepare)(struct device___202 *);
	void (*complete)(struct device___202 *);
	int (*suspend)(struct device___202 *);
	int (*resume)(struct device___202 *);
	int (*freeze)(struct device___202 *);
	int (*thaw)(struct device___202 *);
	int (*poweroff)(struct device___202 *);
	int (*restore)(struct device___202 *);
	int (*suspend_late)(struct device___202 *);
	int (*resume_early)(struct device___202 *);
	int (*freeze_late)(struct device___202 *);
	int (*thaw_early)(struct device___202 *);
	int (*poweroff_late)(struct device___202 *);
	int (*restore_early)(struct device___202 *);
	int (*suspend_noirq)(struct device___202 *);
	int (*resume_noirq)(struct device___202 *);
	int (*freeze_noirq)(struct device___202 *);
	int (*thaw_noirq)(struct device___202 *);
	int (*poweroff_noirq)(struct device___202 *);
	int (*restore_noirq)(struct device___202 *);
	int (*runtime_suspend)(struct device___202 *);
	int (*runtime_resume)(struct device___202 *);
	int (*runtime_idle)(struct device___202 *);
};

struct dev_pm_domain___202 {
	struct dev_pm_ops___202 ops;
	void (*detach)(struct device___202 *, bool);
	int (*activate)(struct device___202 *);
	void (*sync)(struct device___202 *);
	void (*dismiss)(struct device___202 *);
};

struct bus_type___202 {
	const char *name;
	const char *dev_name;
	struct device___202 *dev_root;
	const struct attribute_group___204 **bus_groups;
	const struct attribute_group___204 **dev_groups;
	const struct attribute_group___204 **drv_groups;
	int (*match)(struct device___202 *, struct device_driver___202 *);
	int (*uevent)(struct device___202 *, struct kobj_uevent_env *);
	int (*probe)(struct device___202 *);
	int (*remove)(struct device___202 *);
	void (*shutdown)(struct device___202 *);
	int (*online)(struct device___202 *);
	int (*offline)(struct device___202 *);
	int (*suspend)(struct device___202 *, pm_message_t);
	int (*resume)(struct device___202 *);
	int (*num_vf)(struct device___202 *);
	int (*dma_configure)(struct device___202 *);
	const struct dev_pm_ops___202 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___202 {
	const char *name;
	struct bus_type___202 *bus;
	struct module___192 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___202 *);
	int (*remove)(struct device___202 *);
	void (*shutdown)(struct device___202 *);
	int (*suspend)(struct device___202 *, pm_message_t);
	int (*resume)(struct device___202 *);
	const struct attribute_group___204 **groups;
	const struct dev_pm_ops___202 *pm;
	void (*coredump)(struct device___202 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct disk_part_tbl___56 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___56 *last_lookup;
	struct hd_struct___56 *part[0];
};

struct block_device_operations___56 {
	int (*open)(struct block_device___238 *, fmode_t);
	void (*release)(struct gendisk___56 *, fmode_t);
	int (*rw_page)(struct block_device___238 *, sector_t, struct page___239 *, unsigned int);
	int (*ioctl)(struct block_device___238 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___238 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___56 *, unsigned int);
	int (*media_changed)(struct gendisk___56 *);
	void (*unlock_native_capacity)(struct gendisk___56 *);
	int (*revalidate_disk)(struct gendisk___56 *);
	int (*getgeo)(struct block_device___238 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___238 *, long unsigned int);
	int (*report_zones)(struct gendisk___56 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___192 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bdi_writeback_congested___114 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___114 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct cgroup_subsys___183;

struct cgroup_subsys_state___184 {
	struct cgroup___183 *cgroup;
	struct cgroup_subsys___183 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___184 *parent;
};

struct bsg_ops___55 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___56 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___56 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___56 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___55(struct request___56 *, blk_status_t);

struct request___56 {
	struct request_queue___56 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___114 *bio;
	struct bio___114 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___114 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___59 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___55 *saved_end_io;
		} flush;
	};
	struct gendisk___56 *rq_disk;
	struct hd_struct___56 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___55 *end_io;
	void *end_io_data;
	struct request___56 *next_rq;
};

struct elevator_type___55;

struct elevator_mq_ops___55 {
	int (*init_sched)(struct request_queue___56 *, struct elevator_type___55 *);
	void (*exit_sched)(struct elevator_queue___55 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	bool (*allow_merge)(struct request_queue___56 *, struct request___56 *, struct bio___114 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx *, struct bio___114 *);
	int (*request_merge)(struct request_queue___56 *, struct request___56 **, struct bio___114 *);
	void (*request_merged)(struct request_queue___56 *, struct request___56 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___56 *, struct request___56 *, struct request___56 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___56 *, struct bio___114 *);
	void (*finish_request)(struct request___56 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___56 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___56 *, u64);
	void (*started_request)(struct request___56 *);
	void (*requeue_request)(struct request___56 *);
	struct request___56 * (*former_request)(struct request_queue___56 *, struct request___56 *);
	struct request___56 * (*next_request)(struct request_queue___56 *, struct request___56 *);
	void (*init_icq)(struct io_cq___59 *);
	void (*exit_icq)(struct io_cq___59 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___55;

struct elevator_type___55 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___55 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___55 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___192 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___55 {
	struct elevator_type___55 *type;
	void *elevator_data;
	struct kobject___226 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___55 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___55 *, char *);
	ssize_t (*store)(struct elevator_queue___55 *, const char *, size_t);
};

struct kthread_work___183;

typedef void (*kthread_work_func_t___183)(struct kthread_work___183 *);

struct kthread_worker___183;

struct kthread_work___183 {
	struct list_head node;
	kthread_work_func_t___183 func;
	struct kthread_worker___183 *worker;
	int canceling;
};

struct kthread_worker___183 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___239 *task;
	struct kthread_work___183 *current_work;
};

struct kthread_delayed_work___183 {
	struct kthread_work___183 work;
	struct timer_list timer;
};

struct psi_group___183 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___183 *poll_kworker;
	struct kthread_delayed_work___183 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___183 {
	struct kernfs_node___232 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_root___183;

struct cgroup_rstat_cpu___183;

struct cgroup___183 {
	struct cgroup_subsys_state___184 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___232 *kn;
	struct cgroup_file___183 procs_file;
	struct cgroup_file___183 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___184 *subsys[13];
	struct cgroup_root___183 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___183 *dom_cgrp;
	struct cgroup_rstat_cpu___183 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___23 bpf;
	atomic_t congestion_count;
	struct cgroup___183 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___183 psi;
	int ancestor_ids[0];
};

struct cftype___183;

struct cgroup_subsys___183 {
	struct cgroup_subsys_state___184 * (*css_alloc)(struct cgroup_subsys_state___184 *);
	int (*css_online)(struct cgroup_subsys_state___184 *);
	void (*css_offline)(struct cgroup_subsys_state___184 *);
	void (*css_released)(struct cgroup_subsys_state___184 *);
	void (*css_free)(struct cgroup_subsys_state___184 *);
	void (*css_reset)(struct cgroup_subsys_state___184 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___184 *, int);
	int (*css_extra_stat_show)(struct seq_file___214 *, struct cgroup_subsys_state___184 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___239 *);
	void (*cancel_fork)(struct task_struct___239 *);
	void (*fork)(struct task_struct___239 *);
	void (*exit)(struct task_struct___239 *);
	void (*free)(struct task_struct___239 *);
	void (*bind)(struct cgroup_subsys_state___184 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___183 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___183 *dfl_cftypes;
	struct cftype___183 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___183 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___183 *updated_children;
	struct cgroup___183 *updated_next;
};

struct cgroup_root___183 {
	struct kernfs_root___232 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___183 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___183 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___183 *ss;
	struct list_head node;
	struct kernfs_ops___232 *kf_ops;
	int (*open)(struct kernfs_open_file___232 *);
	void (*release)(struct kernfs_open_file___232 *);
	u64 (*read_u64)(struct cgroup_subsys_state___184 *, struct cftype___183 *);
	s64 (*read_s64)(struct cgroup_subsys_state___184 *, struct cftype___183 *);
	int (*seq_show)(struct seq_file___214 *, void *);
	void * (*seq_start)(struct seq_file___214 *, loff_t *);
	void * (*seq_next)(struct seq_file___214 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___214 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___184 *, struct cftype___183 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___184 *, struct cftype___183 *, s64);
	ssize_t (*write)(struct kernfs_open_file___232 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___232 *, struct poll_table_struct___6 *);
};

struct blkcg_policy_data___44;

struct blkcg___44 {
	struct cgroup_subsys_state___184 css;
	spinlock_t lock;
	struct xarray blkg_tree;
	struct blkcg_gq___44 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___44 *cpd[5];
	struct list_head all_blkcgs_node;
	struct list_head cgwb_list;
	refcount_t cgwb_refcnt;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct blkcg_policy_data___44 {
	struct blkcg___44 *blkcg;
	int plid;
};

struct blkg_policy_data___44 {
	struct blkcg_gq___44 *blkg;
	int plid;
};

struct module___193;

struct file___239;

struct kiocb___239;

struct iov_iter___106;

struct poll_table_struct___147;

struct vm_area_struct___240;

struct inode___239;

struct file_lock___239;

struct page___240;

struct pipe_inode_info___49;

struct seq_file___215;

struct file_operations___239 {
	struct module___193 *owner;
	loff_t (*llseek)(struct file___239 *, loff_t, int);
	ssize_t (*read)(struct file___239 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___239 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___239 *, struct iov_iter___106 *);
	ssize_t (*write_iter)(struct kiocb___239 *, struct iov_iter___106 *);
	int (*iopoll)(struct kiocb___239 *, bool);
	int (*iterate)(struct file___239 *, struct dir_context *);
	int (*iterate_shared)(struct file___239 *, struct dir_context *);
	__poll_t (*poll)(struct file___239 *, struct poll_table_struct___147 *);
	long int (*unlocked_ioctl)(struct file___239 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___239 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___239 *, struct vm_area_struct___240 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___239 *, struct file___239 *);
	int (*flush)(struct file___239 *, fl_owner_t);
	int (*release)(struct inode___239 *, struct file___239 *);
	int (*fsync)(struct file___239 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___239 *, int);
	int (*lock)(struct file___239 *, int, struct file_lock___239 *);
	ssize_t (*sendpage)(struct file___239 *, struct page___240 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___239 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___239 *, int, struct file_lock___239 *);
	ssize_t (*splice_write)(struct pipe_inode_info___49 *, struct file___239 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___239 *, loff_t *, struct pipe_inode_info___49 *, size_t, unsigned int);
	int (*setlease)(struct file___239 *, long int, struct file_lock___239 **, void **);
	long int (*fallocate)(struct file___239 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___215 *, struct file___239 *);
	ssize_t (*copy_file_range)(struct file___239 *, loff_t, struct file___239 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___239 *, loff_t, struct file___239 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___239 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___239 {
	u64 seqnum;
	struct vm_area_struct___240 *vmas[4];
};

struct page_frag___239 {
	struct page___240 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___239;

struct mem_cgroup___100;

struct pid___179;

struct cred___232;

struct nsproxy___219;

struct signal_struct___197;

struct bio_list___115;

struct backing_dev_info___115;

struct css_set___184;

struct vm_struct___156;

struct task_struct___240 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___240 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___239 *mm;
	struct mm_struct___239 *active_mm;
	struct vmacache___239 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___240 *real_parent;
	struct task_struct___240 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___240 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___100 *active_memcg;
	long int rh_reserved2;
	struct pid___179 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___179 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___179 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___232 *ptracer_cred;
	const struct cred___232 *real_cred;
	const struct cred___232 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___219 *nsproxy;
	struct signal_struct___197 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___240 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___115 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___115 *backing_dev_info;
	struct io_context___59 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___184 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___49 *splice_pipe;
	struct page_frag___239 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___100 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___240 *oom_reaper_list;
	struct vm_struct___156 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___126 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___240 *pgtable_t___239;

struct address_space___238;

struct dev_pagemap___229;

struct page___240 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___238 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___240 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___239 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___239 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___229 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___100 *mem_cgroup;
};

struct pglist_data___239;

struct lruvec___239 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___239 *pgdat;
};

struct zone___239 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___239 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___239 {
	struct zone___239 *zone;
	int zone_idx;
};

struct zonelist___239 {
	struct zoneref___239 _zonerefs[25];
};

struct pglist_data___239 {
	struct zone___239 node_zones[3];
	struct zonelist___239 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___240 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___240 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___239 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___240 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___240 *owner;
};

struct secondary_data___240 {
	void *stack;
	struct task_struct___240 *task;
	long int status;
};

struct blocking_notifier_head___239 {
	struct rw_semaphore___240 rwsem;
	struct notifier_block *head;
};

struct cgroup___184;

struct cgroup_subsys___184;

struct cgroup_subsys_state___185 {
	struct cgroup___184 *cgroup;
	struct cgroup_subsys___184 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___185 *parent;
};

struct kernfs_node___233;

struct cgroup_file___184 {
	struct kernfs_node___233 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___100;

struct mem_cgroup___100 {
	struct cgroup_subsys_state___185 css;
	struct mem_cgroup_id___16 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___184 events_file;
	struct cgroup_file___184 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___240 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___100 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___238;

struct super_block___238;

struct dentry___239 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___239 *d_parent;
	struct qstr d_name;
	struct inode___239 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___238 *d_op;
	struct super_block___238 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___238;

struct address_space___238 {
	struct inode___239 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___240 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___238 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___238;

struct bdi_writeback___115;

struct block_device___239;

struct inode___239 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___238 *i_op;
	struct super_block___238 *i_sb;
	struct address_space___238 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___240 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___115 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___239 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___238 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___49 *i_pipe;
		struct block_device___239 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___238;

struct dentry_operations___238 {
	int (*d_revalidate)(struct dentry___239 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___239 *, unsigned int);
	int (*d_hash)(const struct dentry___239 *, struct qstr *);
	int (*d_compare)(const struct dentry___239 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___239 *);
	int (*d_init)(struct dentry___239 *);
	void (*d_release)(struct dentry___239 *);
	void (*d_prune)(struct dentry___239 *);
	void (*d_iput)(struct dentry___239 *, struct inode___239 *);
	char * (*d_dname)(struct dentry___239 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___238 *);
	int (*d_manage)(const struct path___238 *, bool);
	struct dentry___239 * (*d_real)(struct dentry___239 *, const struct inode___239 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___238;

struct mem_dqinfo___238 {
	struct quota_format_type___238 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___238;

struct quota_info___238 {
	unsigned int flags;
	struct rw_semaphore___240 dqio_sem;
	struct inode___239 *files[3];
	struct mem_dqinfo___238 info[3];
	const struct quota_format_ops___238 *ops[3];
};

struct rcuwait___238 {
	struct task_struct___240 *task;
};

struct percpu_rw_semaphore___238 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___240 rw_sem;
	struct rcuwait___238 writer;
	int readers_block;
};

struct sb_writers___238 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___238 rw_sem[3];
};

struct shrink_control___100;

struct shrinker___100 {
	long unsigned int (*count_objects)(struct shrinker___100 *, struct shrink_control___100 *);
	long unsigned int (*scan_objects)(struct shrinker___100 *, struct shrink_control___100 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___238;

struct super_operations___238;

struct dquot_operations___238;

struct quotactl_ops___238;

struct user_namespace___199;

struct super_block___238 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___238 *s_type;
	const struct super_operations___238 *s_op;
	const struct dquot_operations___238 *dq_op;
	const struct quotactl_ops___238 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___239 *s_root;
	struct rw_semaphore___240 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___239 *s_bdev;
	struct backing_dev_info___115 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___238 s_dquot;
	struct sb_writers___238 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___238 *s_d_op;
	int cleancache_poolid;
	struct shrinker___100 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___199 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct path___238 {
	struct vfsmount *mnt;
	struct dentry___239 *dentry;
};

struct key___232;

struct ucounts___199;

struct user_namespace___199 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___199 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___28 ns;
	long unsigned int flags;
	struct key___232 *persistent_keyring_register;
	struct rw_semaphore___240 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___199 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct shrink_control___100 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___100 *memcg;
};

struct pid_namespace___179;

struct upid___179 {
	int nr;
	struct pid_namespace___179 *ns;
};

struct pid_namespace___179 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___240 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___179 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___239 *proc_self;
	struct dentry___239 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___199 *user_ns;
	struct ucounts___199 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___28 ns;
};

struct pid___179 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___179 numbers[1];
};

struct vm_operations_struct___229;

struct vm_area_struct___240 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___240 *vm_next;
	struct vm_area_struct___240 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___239 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___229 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___239 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___239;

struct mm_struct___239 {
	struct {
		struct vm_area_struct___240 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___239 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___240 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___239 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___240 *owner;
		struct user_namespace___199 *user_ns;
		struct file___239 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___239 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___229)(struct vm_area_struct___240 *, long unsigned int, const struct page___240 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___229)(struct page___240 *, void *);

struct device___203;

struct dev_pagemap___229 {
	dev_page_fault_t___229 page_fault;
	dev_page_free_t___229 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___203 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct fown_struct___179 {
	rwlock_t lock;
	struct pid___179 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___239 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___238 f_path;
	struct inode___239 *f_inode;
	const struct file_operations___239 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___179 f_owner;
	const struct cred___232 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___238 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___229;

struct vm_operations_struct___229 {
	void (*open)(struct vm_area_struct___240 *);
	void (*close)(struct vm_area_struct___240 *);
	int (*split)(struct vm_area_struct___240 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___240 *);
	vm_fault_t (*fault)(struct vm_fault___229 *);
	vm_fault_t (*huge_fault)(struct vm_fault___229 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___229 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___240 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___229 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___229 *);
	int (*access)(struct vm_area_struct___240 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___240 *);
	int (*set_policy)(struct vm_area_struct___240 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___240 *, long unsigned int);
	struct page___240 * (*find_special_page)(struct vm_area_struct___240 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___239 {
	struct task_struct___240 *task;
	struct core_thread___239 *next;
};

struct core_state___239 {
	atomic_t nr_threads;
	struct core_thread___239 dumper;
	struct completion startup;
};

struct vm_fault___229 {
	struct vm_area_struct___240 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___240 *cow_page;
	struct mem_cgroup___100 *memcg;
	struct page___240 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___239 prealloc_pte;
};

struct user_struct___232 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___232 *uid_keyring;
	struct key___232 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___232 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___232 *session_keyring;
	struct key___232 *process_keyring;
	struct key___232 *thread_keyring;
	struct key___232 *request_key_auth;
	void *security;
	struct user_struct___232 *user;
	struct user_namespace___199 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___37;

struct cgroup_namespace___184;

struct nsproxy___219 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___179 *pid_ns_for_children;
	struct net___37 *net_ns;
	struct cgroup_namespace___184 *cgroup_ns;
};

struct signal_struct___197 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___240 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___240 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___179 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___179 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___239 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___179 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___115;

struct bio_list___115 {
	struct bio___115 *head;
	struct bio___115 *tail;
};

struct bdi_writeback_congested___115;

struct bdi_writeback___115 {
	struct backing_dev_info___115 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___115 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___185 *memcg_css;
	struct cgroup_subsys_state___185 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___115 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___115 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___203 *dev;
	struct device___203 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___239 *debug_dir;
	struct dentry___239 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___184 {
	struct cgroup_subsys_state___185 *subsys[13];
	refcount_t refcount;
	struct css_set___184 *dom_cset;
	struct cgroup___184 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___184 *mg_src_cgrp;
	struct cgroup___184 *mg_dst_cgrp;
	struct css_set___184 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___238;

struct pipe_buffer___49;

struct pipe_inode_info___49 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___240 *tmp_page;
	struct fasync_struct___238 *fasync_readers;
	struct fasync_struct___238 *fasync_writers;
	struct pipe_buffer___49 *bufs;
	struct user_struct___232 *user;
};

struct vm_struct___156 {
	struct vm_struct___156 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___240 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___209 {
	struct task_struct___240 task;
	long unsigned int stack[8192];
};

struct kiocb___239 {
	struct file___239 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___239 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___238 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___239 *ia_file;
};

struct dquot___238 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___238 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___238 {
	int qf_fmt_id;
	const struct quota_format_ops___238 *qf_ops;
	struct module___193 *qf_owner;
	struct quota_format_type___238 *qf_next;
};

struct quota_format_ops___238 {
	int (*check_quota_file)(struct super_block___238 *, int);
	int (*read_file_info)(struct super_block___238 *, int);
	int (*write_file_info)(struct super_block___238 *, int);
	int (*free_file_info)(struct super_block___238 *, int);
	int (*read_dqblk)(struct dquot___238 *);
	int (*commit_dqblk)(struct dquot___238 *);
	int (*release_dqblk)(struct dquot___238 *);
	int (*get_next_id)(struct super_block___238 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___238 {
	int (*write_dquot)(struct dquot___238 *);
	struct dquot___238 * (*alloc_dquot)(struct super_block___238 *, int);
	void (*destroy_dquot)(struct dquot___238 *);
	int (*acquire_dquot)(struct dquot___238 *);
	int (*release_dquot)(struct dquot___238 *);
	int (*mark_dirty)(struct dquot___238 *);
	int (*write_info)(struct super_block___238 *, int);
	qsize_t * (*get_reserved_space)(struct inode___239 *);
	int (*get_projid)(struct inode___239 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___239 *, qsize_t *);
	int (*get_next_id)(struct super_block___238 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___238 {
	int (*quota_on)(struct super_block___238 *, int, int, const struct path___238 *);
	int (*quota_off)(struct super_block___238 *, int);
	int (*quota_enable)(struct super_block___238 *, unsigned int);
	int (*quota_disable)(struct super_block___238 *, unsigned int);
	int (*quota_sync)(struct super_block___238 *, int);
	int (*set_info)(struct super_block___238 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___238 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___238 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___238 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___238 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___238 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___226;

struct kobj_type___226;

struct kobject___227 {
	const char *name;
	struct list_head entry;
	struct kobject___227 *parent;
	struct kset___226 *kset;
	struct kobj_type___226 *ktype;
	struct kernfs_node___233 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___190 {
	struct kobject___227 kobj;
	struct module___193 *mod;
	struct kobject___227 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___190 {
	struct module___193 *mod;
	struct latch_tree_node node;
};

struct module_layout___190 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___190 mtn;
};

struct module_attribute___190;

struct kernel_param___190;

struct module___193 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___190 mkobj;
	struct module_attribute___190 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___227 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___190 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___190 core_layout;
	struct module_layout___190 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide53;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide54;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___111;

struct address_space_operations___238 {
	int (*writepage)(struct page___240 *, struct writeback_control___111 *);
	int (*readpage)(struct file___239 *, struct page___240 *);
	int (*writepages)(struct address_space___238 *, struct writeback_control___111 *);
	int (*set_page_dirty)(struct page___240 *);
	int (*readpages)(struct file___239 *, struct address_space___238 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___239 *, struct address_space___238 *, loff_t, unsigned int, unsigned int, struct page___240 **, void **);
	int (*write_end)(struct file___239 *, struct address_space___238 *, loff_t, unsigned int, unsigned int, struct page___240 *, void *);
	sector_t (*bmap)(struct address_space___238 *, sector_t);
	void (*invalidatepage)(struct page___240 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___240 *, gfp_t);
	void (*freepage)(struct page___240 *);
	ssize_t (*direct_IO)(struct kiocb___239 *, struct iov_iter___106 *);
	int (*migratepage)(struct address_space___238 *, struct page___240 *, struct page___240 *, enum migrate_mode);
	bool (*isolate_page)(struct page___240 *, isolate_mode_t);
	void (*putback_page)(struct page___240 *);
	int (*launder_page)(struct page___240 *);
	int (*is_partially_uptodate)(struct page___240 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___240 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___238 *, struct page___240 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___239 *, sector_t *);
	void (*swap_deactivate)(struct file___239 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___111 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___115 *wb;
	struct inode___239 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___115;

struct iov_iter___106 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___115 *bvec;
		struct pipe_inode_info___49 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___239 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___239 *bd_inode;
	struct super_block___238 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___239 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___115 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___238 {
	struct dentry___239 * (*lookup)(struct inode___239 *, struct dentry___239 *, unsigned int);
	const char * (*get_link)(struct dentry___239 *, struct inode___239 *, struct delayed_call *);
	int (*permission)(struct inode___239 *, int);
	struct posix_acl * (*get_acl)(struct inode___239 *, int);
	int (*readlink)(struct dentry___239 *, char *, int);
	int (*create)(struct inode___239 *, struct dentry___239 *, umode_t, bool);
	int (*link)(struct dentry___239 *, struct inode___239 *, struct dentry___239 *);
	int (*unlink)(struct inode___239 *, struct dentry___239 *);
	int (*symlink)(struct inode___239 *, struct dentry___239 *, const char *);
	int (*mkdir)(struct inode___239 *, struct dentry___239 *, umode_t);
	int (*rmdir)(struct inode___239 *, struct dentry___239 *);
	int (*mknod)(struct inode___239 *, struct dentry___239 *, umode_t, dev_t);
	int (*rename)(struct inode___239 *, struct dentry___239 *, struct inode___239 *, struct dentry___239 *, unsigned int);
	int (*setattr)(struct dentry___239 *, struct iattr___238 *);
	int (*getattr)(const struct path___238 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___239 *, char *, size_t);
	int (*fiemap)(struct inode___239 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___239 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___239 *, struct dentry___239 *, struct file___239 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___239 *, struct dentry___239 *, umode_t);
	int (*set_acl)(struct inode___239 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___238 {
	void (*fl_copy_lock)(struct file_lock___239 *, struct file_lock___239 *);
	void (*fl_release_private)(struct file_lock___239 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___238;

struct file_lock___239 {
	struct file_lock___239 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___239 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___238 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___238 *fl_ops;
	const struct lock_manager_operations___238 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___238 {
	int (*lm_compare_owner)(struct file_lock___239 *, struct file_lock___239 *);
	long unsigned int (*lm_owner_key)(struct file_lock___239 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___239 *);
	int (*lm_grant)(struct file_lock___239 *, int);
	bool (*lm_break)(struct file_lock___239 *);
	int (*lm_change)(struct file_lock___239 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___239 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___238 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___238 *fa_next;
	struct file___239 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___238 {
	const char *name;
	int fs_flags;
	struct dentry___239 * (*mount)(struct file_system_type___238 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___238 *);
	struct module___193 *owner;
	struct file_system_type___238 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___238 {
	struct inode___239 * (*alloc_inode)(struct super_block___238 *);
	void (*destroy_inode)(struct inode___239 *);
	void (*dirty_inode)(struct inode___239 *, int);
	int (*write_inode)(struct inode___239 *, struct writeback_control___111 *);
	int (*drop_inode)(struct inode___239 *);
	void (*evict_inode)(struct inode___239 *);
	void (*put_super)(struct super_block___238 *);
	int (*sync_fs)(struct super_block___238 *, int);
	int (*freeze_super)(struct super_block___238 *);
	int (*freeze_fs)(struct super_block___238 *);
	int (*thaw_super)(struct super_block___238 *);
	int (*unfreeze_fs)(struct super_block___238 *);
	int (*statfs)(struct dentry___239 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___238 *, int *, char *);
	void (*umount_begin)(struct super_block___238 *);
	int (*show_options)(struct seq_file___215 *, struct dentry___239 *);
	int (*show_devname)(struct seq_file___215 *, struct dentry___239 *);
	int (*show_path)(struct seq_file___215 *, struct dentry___239 *);
	int (*show_stats)(struct seq_file___215 *, struct dentry___239 *);
	ssize_t (*quota_read)(struct super_block___238 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___238 *, int, const char *, size_t, loff_t);
	struct dquot___238 ** (*get_dquots)(struct inode___239 *);
	int (*bdev_try_to_free_page)(struct super_block___238 *, struct page___240 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___238 *, struct shrink_control___100 *);
	long int (*free_cached_objects)(struct super_block___238 *, struct shrink_control___100 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___149)(struct file___239 *, wait_queue_head_t *, struct poll_table_struct___147 *);

struct poll_table_struct___147 {
	poll_queue_proc___149 _qproc;
	__poll_t _key;
};

struct seq_operations___213;

struct seq_file___215 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___213 *op;
	int poll_event;
	const struct file___239 *file;
	void *private;
};

typedef void bio_end_io_t___115(struct bio___115 *);

struct bio_vec___115 {
	struct page___240 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___115;

struct bio_set___115;

struct bio___115 {
	struct bio___115 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___115 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___115 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___115 *bi_io_vec;
	struct bio_set___115 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___115 bi_inline_vecs[0];
};

struct msghdr___16 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___106 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___239 *msg_iocb;
};

struct socket_wq___15 {
	wait_queue_head_t wait;
	struct fasync_struct___238 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct sock___16;

struct proto_ops___15;

struct socket___16 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___15 *wq;
	struct file___239 *file;
	struct sock___16 *sk;
	const struct proto_ops___15 *ops;
};

typedef struct {
	struct net___37 *net;
} possible_net_t___26;

struct proto___14;

struct sock_common___14 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___14 *skc_prot;
	possible_net_t___26 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___16 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___29;

struct sk_buff_head___25 {
	struct sk_buff___29 *next;
	struct sk_buff___29 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___14;

struct dst_entry___15;

struct net_device___29;

struct sock___16 {
	struct sock_common___14 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___25 sk_error_queue;
	struct sk_buff_head___25 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___29 *head;
		struct sk_buff___29 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___14 *sk_filter;
	union {
		struct socket_wq___15 *sk_wq;
		struct socket_wq___15 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___15 *sk_rx_dst;
	struct dst_entry___15 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___29 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___25 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___239 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___14 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___179 *sk_peer_pid;
	const struct cred___232 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___16 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___100 *sk_memcg;
	void (*sk_state_change)(struct sock___16 *);
	void (*sk_data_ready)(struct sock___16 *);
	void (*sk_write_space)(struct sock___16 *);
	void (*sk_error_report)(struct sock___16 *);
	int (*sk_backlog_rcv)(struct sock___16 *, struct sk_buff___29 *);
	struct sk_buff___29 * (*sk_validate_xmit_skb)(struct sock___16 *, struct net_device___29 *, struct sk_buff___29 *);
	void (*sk_destruct)(struct sock___16 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

typedef int (*sk_read_actor_t___14)(read_descriptor_t *, struct sk_buff___29 *, unsigned int, size_t);

struct proto_ops___15 {
	int family;
	struct module___193 *owner;
	int (*release)(struct socket___16 *);
	int (*bind)(struct socket___16 *, struct sockaddr *, int);
	int (*connect)(struct socket___16 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___16 *, struct socket___16 *);
	int (*accept)(struct socket___16 *, struct socket___16 *, int, bool);
	int (*getname)(struct socket___16 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___239 *, struct socket___16 *, struct poll_table_struct___147 *);
	int (*ioctl)(struct socket___16 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___16 *, int);
	int (*shutdown)(struct socket___16 *, int);
	int (*setsockopt)(struct socket___16 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___16 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___16 *, struct msghdr___16 *, size_t);
	int (*recvmsg)(struct socket___16 *, struct msghdr___16 *, size_t, int);
	int (*mmap)(struct file___239 *, struct socket___16 *, struct vm_area_struct___240 *);
	ssize_t (*sendpage)(struct socket___16 *, struct page___240 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___16 *, loff_t *, struct pipe_inode_info___49 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___16 *, int);
	int (*peek_len)(struct socket___16 *);
	int (*read_sock)(struct sock___16 *, read_descriptor_t *, sk_read_actor_t___14);
	int (*sendpage_locked)(struct sock___16 *, struct page___240 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___16 *, struct msghdr___16 *, size_t);
	int (*set_rcvlowat)(struct sock___16 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct nf_bridge_info___25;

struct sk_buff___29 {
	union {
		struct {
			struct sk_buff___29 *next;
			struct sk_buff___29 *prev;
			union {
				struct net_device___29 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___16 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___29 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___25 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___25;

struct netns_frags___25 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___25 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ip_ra_chain___4;

struct fib_rules_ops___14;

struct fib_notifier_ops___14;

struct netns_ipv4___25 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___4 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___14 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___16 *fibnl;
	struct sock___16 **icmp_sk;
	struct sock___16 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___16 **tcp_sk;
	struct netns_frags___25 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___14 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___14 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___14 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___15;

struct dst_ops___35 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___35 *);
	struct dst_entry___15 * (*check)(struct dst_entry___15 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___15 *);
	unsigned int (*mtu)(const struct dst_entry___15 *);
	u32 * (*cow_metrics)(struct dst_entry___15 *, long unsigned int);
	void (*destroy)(struct dst_entry___15 *);
	void (*ifdown)(struct dst_entry___15 *, struct net_device___29 *, int);
	struct dst_entry___15 * (*negative_advice)(struct dst_entry___15 *);
	void (*link_failure)(struct sk_buff___29 *);
	void (*update_pmtu)(struct dst_entry___15 *, struct sock___16 *, struct sk_buff___29 *, u32);
	void (*redirect)(struct dst_entry___15 *, struct sock___16 *, struct sk_buff___29 *);
	int (*local_out)(struct net___37 *, struct sock___16 *, struct sk_buff___29 *);
	struct neighbour___15 * (*neigh_lookup)(const struct dst_entry___15 *, struct sk_buff___29 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___15 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___35 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___25 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___35 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___14 *fib6_rules_ops;
	struct sock___16 **icmp_sk;
	struct sock___16 *ndisc_sk;
	struct sock___16 *tcp_sk;
	struct sock___16 *igmp_sk;
	struct sock___16 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___14 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___14 *notifier_ops;
	struct fib_notifier_ops___14 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___15 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___16 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___25 {
	struct netns_frags___25 frags;
};

struct netns_xfrm___35 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___16 *nlsk;
	struct sock___16 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___35 xfrm4_dst_ops;
	struct dst_ops___35 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___24;

struct net___37 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___199 *user_ns;
	struct ucounts___199 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___28 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___16 *rtnl;
	struct sock___16 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___29 *loopback_dev;
	struct netns_core core;
	struct netns_mib___2 mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___25 ipv4;
	struct netns_ipv6___35 ipv6;
	struct netns_sctp___15 sctp;
	struct netns_nf___2 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___25 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___16 *nfnl;
	struct sock___16 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___35 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can___2 can;
	struct sock___16 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___24 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kernfs_root___233;

struct kernfs_elem_dir___233 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___233 *root;
};

struct kernfs_syscall_ops___233;

struct kernfs_root___233 {
	struct kernfs_node___233 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___233 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___233 {
	struct kernfs_node___233 *target_kn;
};

struct kernfs_ops___233;

struct kernfs_elem_attr___233 {
	const struct kernfs_ops___233 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___233 *notify_next;
};

struct kernfs_node___233 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___233 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___233 dir;
		struct kernfs_elem_symlink___233 symlink;
		struct kernfs_elem_attr___233 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___233;

struct kernfs_ops___233 {
	int (*open)(struct kernfs_open_file___233 *);
	void (*release)(struct kernfs_open_file___233 *);
	int (*seq_show)(struct seq_file___215 *, void *);
	void * (*seq_start)(struct seq_file___215 *, loff_t *);
	void * (*seq_next)(struct seq_file___215 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___215 *, void *);
	ssize_t (*read)(struct kernfs_open_file___233 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___233 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___233 *, struct vm_area_struct___240 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___233 *, struct poll_table_struct___147 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___233 {
	int (*remount_fs)(struct kernfs_root___233 *, int *, char *);
	int (*show_options)(struct seq_file___215 *, struct kernfs_root___233 *);
	int (*mkdir)(struct kernfs_node___233 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___233 *);
	int (*rename)(struct kernfs_node___233 *, struct kernfs_node___233 *, const char *);
	int (*show_path)(struct seq_file___215 *, struct kernfs_node___233 *, struct kernfs_root___233 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___233 {
	struct kernfs_node___233 *kn;
	struct file___239 *file;
	struct seq_file___215 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___229 *vm_ops;
};

struct kobj_ns_type_operations___14 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___16 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___204;

struct attribute_group___205 {
	const char *name;
	umode_t (*is_visible)(struct kobject___227 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___227 *, struct bin_attribute___204 *, int);
	struct attribute **attrs;
	struct bin_attribute___204 **bin_attrs;
};

struct bin_attribute___204 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___239 *, struct kobject___227 *, struct bin_attribute___204 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___239 *, struct kobject___227 *, struct bin_attribute___204 *, char *, loff_t, size_t);
	int (*mmap)(struct file___239 *, struct kobject___227 *, struct bin_attribute___204 *, struct vm_area_struct___240 *);
};

struct sysfs_ops___226 {
	ssize_t (*show)(struct kobject___227 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___227 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___226;

struct kset___226 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___227 kobj;
	const struct kset_uevent_ops___226 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___226 {
	void (*release)(struct kobject___227 *);
	const struct sysfs_ops___226 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___14 * (*child_ns_type)(struct kobject___227 *);
	const void * (*namespace)(struct kobject___227 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___226 {
	int (* const filter)(struct kset___226 *, struct kobject___227 *);
	const char * (* const name)(struct kset___226 *, struct kobject___227 *);
	int (* const uevent)(struct kset___226 *, struct kobject___227 *, struct kobj_uevent_env *);
};

struct kobj_attribute___220 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___227 *, struct kobj_attribute___220 *, char *);
	ssize_t (*store)(struct kobject___227 *, struct kobj_attribute___220 *, const char *, size_t);
};

struct dev_pm_ops___203 {
	int (*prepare)(struct device___203 *);
	void (*complete)(struct device___203 *);
	int (*suspend)(struct device___203 *);
	int (*resume)(struct device___203 *);
	int (*freeze)(struct device___203 *);
	int (*thaw)(struct device___203 *);
	int (*poweroff)(struct device___203 *);
	int (*restore)(struct device___203 *);
	int (*suspend_late)(struct device___203 *);
	int (*resume_early)(struct device___203 *);
	int (*freeze_late)(struct device___203 *);
	int (*thaw_early)(struct device___203 *);
	int (*poweroff_late)(struct device___203 *);
	int (*restore_early)(struct device___203 *);
	int (*suspend_noirq)(struct device___203 *);
	int (*resume_noirq)(struct device___203 *);
	int (*freeze_noirq)(struct device___203 *);
	int (*thaw_noirq)(struct device___203 *);
	int (*poweroff_noirq)(struct device___203 *);
	int (*restore_noirq)(struct device___203 *);
	int (*runtime_suspend)(struct device___203 *);
	int (*runtime_resume)(struct device___203 *);
	int (*runtime_idle)(struct device___203 *);
};

struct dev_pm_info___203 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___203 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___203;

struct bus_type___203;

struct device_driver___203;

struct dev_pm_domain___203;

struct dma_map_ops___46;

struct fwnode_handle___138;

struct class___203;

struct device___203 {
	struct device___203 *parent;
	struct device_private *p;
	struct kobject___227 kobj;
	const char *init_name;
	const struct device_type___203 *type;
	struct mutex mutex;
	struct bus_type___203 *bus;
	struct device_driver___203 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___203 power;
	struct dev_pm_domain___203 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___46 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___138 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___203 *class;
	const struct attribute_group___205 **groups;
	void (*release)(struct device___203 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___203 {
	struct dev_pm_ops___203 ops;
	void (*detach)(struct device___203 *, bool);
	int (*activate)(struct device___203 *);
	void (*sync)(struct device___203 *);
	void (*dismiss)(struct device___203 *);
};

struct bus_type___203 {
	const char *name;
	const char *dev_name;
	struct device___203 *dev_root;
	const struct attribute_group___205 **bus_groups;
	const struct attribute_group___205 **dev_groups;
	const struct attribute_group___205 **drv_groups;
	int (*match)(struct device___203 *, struct device_driver___203 *);
	int (*uevent)(struct device___203 *, struct kobj_uevent_env *);
	int (*probe)(struct device___203 *);
	int (*remove)(struct device___203 *);
	void (*shutdown)(struct device___203 *);
	int (*online)(struct device___203 *);
	int (*offline)(struct device___203 *);
	int (*suspend)(struct device___203 *, pm_message_t);
	int (*resume)(struct device___203 *);
	int (*num_vf)(struct device___203 *);
	int (*dma_configure)(struct device___203 *);
	const struct dev_pm_ops___203 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___203 {
	const char *name;
	struct bus_type___203 *bus;
	struct module___193 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___203 *);
	int (*remove)(struct device___203 *);
	void (*shutdown)(struct device___203 *);
	int (*suspend)(struct device___203 *, pm_message_t);
	int (*resume)(struct device___203 *);
	const struct attribute_group___205 **groups;
	const struct dev_pm_ops___203 *pm;
	void (*coredump)(struct device___203 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___203 {
	const char *name;
	const struct attribute_group___205 **groups;
	int (*uevent)(struct device___203 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___203 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___203 *);
	const struct dev_pm_ops___203 *pm;
};

struct class___203 {
	const char *name;
	struct module___193 *owner;
	const struct attribute_group___205 **class_groups;
	const struct attribute_group___205 **dev_groups;
	struct kobject___227 *dev_kobj;
	int (*dev_uevent)(struct device___203 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___203 *, umode_t *);
	void (*class_release)(struct class___203 *);
	void (*dev_release)(struct device___203 *);
	int (*shutdown_pre)(struct device___203 *);
	const struct kobj_ns_type_operations___14 *ns_type;
	const void * (*namespace)(struct device___203 *);
	const struct dev_pm_ops___203 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___46 {
	void * (*alloc)(struct device___203 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___203 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___203 *, struct vm_area_struct___240 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___203 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___203 *, struct page___240 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___203 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___203 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___203 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___203 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___203 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___203 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___203 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___203 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___203 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___203 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___203 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___203 *, u64);
	u64 (*get_required_mask)(struct device___203 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___138;

struct fwnode_handle___138 {
	struct fwnode_handle___138 *secondary;
	const struct fwnode_operations___138 *ops;
};

typedef void compound_page_dtor___229(struct page___240 *);

struct fwnode_reference_args___138;

struct fwnode_endpoint___138;

struct fwnode_operations___138 {
	struct fwnode_handle___138 * (*get)(struct fwnode_handle___138 *);
	void (*put)(struct fwnode_handle___138 *);
	bool (*device_is_available)(const struct fwnode_handle___138 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___138 *, const struct device___203 *);
	bool (*property_present)(const struct fwnode_handle___138 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___138 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___138 *, const char *, const char **, size_t);
	struct fwnode_handle___138 * (*get_parent)(const struct fwnode_handle___138 *);
	struct fwnode_handle___138 * (*get_next_child_node)(const struct fwnode_handle___138 *, struct fwnode_handle___138 *);
	struct fwnode_handle___138 * (*get_named_child_node)(const struct fwnode_handle___138 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___138 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___138 *);
	struct fwnode_handle___138 * (*graph_get_next_endpoint)(const struct fwnode_handle___138 *, struct fwnode_handle___138 *);
	struct fwnode_handle___138 * (*graph_get_remote_endpoint)(const struct fwnode_handle___138 *);
	struct fwnode_handle___138 * (*graph_get_port_parent)(struct fwnode_handle___138 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___138 *, struct fwnode_endpoint___138 *);
};

struct fwnode_endpoint___138 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___138 *local_fwnode;
};

struct fwnode_reference_args___138 {
	struct fwnode_handle___138 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___49;

struct pipe_buffer___49 {
	struct page___240 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___49 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___49 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___49 *, struct pipe_buffer___49 *);
	void (*release)(struct pipe_inode_info___49 *, struct pipe_buffer___49 *);
	int (*steal)(struct pipe_inode_info___49 *, struct pipe_buffer___49 *);
	union {
		bool (*get)(struct pipe_inode_info___49 *, struct pipe_buffer___49 *);
		struct {
			void (*get)(struct pipe_inode_info___49 *, struct pipe_buffer___49 *);
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
};

struct nf_bridge_info___25 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___25 = 0,
		BRNF_PROTO_8021Q___25 = 1,
		BRNF_PROTO_PPPOE___25 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___29 *physindev;
	struct net_device___29 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___25(struct sk_buff___29 **);

struct net_device_ops___25;

struct ethtool_ops___25;

struct l3mdev_ops___15;

struct ndisc_ops___8;

struct xfrmdev_ops___25;

struct tlsdev_ops___25;

struct header_ops___25;

struct inet6_dev___8;

struct netdev_rx_queue___25;

struct mini_Qdisc___24;

struct netdev_queue___25;

struct Qdisc___24;

struct rtnl_link_ops___24;

struct dcbnl_rtnl_ops___25;

struct net_device___29 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___25 *netdev_ops;
	const struct ethtool_ops___25 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___15 *l3mdev_ops;
	const struct ndisc_ops___8 *ndisc_ops;
	const struct xfrmdev_ops___25 *xfrmdev_ops;
	const struct tlsdev_ops___25 *tlsdev_ops;
	const struct header_ops___25 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___226 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___8 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___25 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___24 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___25 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___24 *miniq_ingress;
	struct netdev_queue___25 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___25 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___24 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___24 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___25 = 0,
		NETREG_REGISTERED___25 = 1,
		NETREG_UNREGISTERING___25 = 2,
		NETREG_UNREGISTERED___25 = 3,
		NETREG_RELEASED___25 = 4,
		NETREG_DUMMY___25 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___25 = 0,
		RTNL_LINK_INITIALIZING___25 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___29 *);
	struct netpoll_info *npinfo;
	possible_net_t___26 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___203 dev;
	const struct attribute_group___205 *sysfs_groups[4];
	const struct attribute_group___205 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___24 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___25 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct ethtool_ops___25 {
	int (*get_settings)(struct net_device___29 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___29 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___29 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___29 *);
	void (*get_regs)(struct net_device___29 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___29 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___29 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___29 *);
	void (*set_msglevel)(struct net_device___29 *, u32);
	int (*nway_reset)(struct net_device___29 *);
	u32 (*get_link)(struct net_device___29 *);
	int (*get_eeprom_len)(struct net_device___29 *);
	int (*get_eeprom)(struct net_device___29 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___29 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___29 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___29 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___29 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___29 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___29 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___29 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___29 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___29 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___29 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___29 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___29 *);
	void (*complete)(struct net_device___29 *);
	u32 (*get_priv_flags)(struct net_device___29 *);
	int (*set_priv_flags)(struct net_device___29 *, u32);
	int (*get_sset_count)(struct net_device___29 *, int);
	int (*get_rxnfc)(struct net_device___29 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___29 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___29 *, struct ethtool_flash *);
	int (*reset)(struct net_device___29 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___29 *);
	u32 (*get_rxfh_indir_size)(struct net_device___29 *);
	int (*get_rxfh)(struct net_device___29 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___29 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___29 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___29 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___29 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___29 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___29 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___29 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___29 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___29 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___29 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___29 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___29 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___29 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___29 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___29 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___29 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___29 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___29 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___29 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___29 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___29 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	int (*get_fecparam)(struct net_device___29 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___29 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___29 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___29 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___29 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___25;

struct inet_frags___25 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___25 *, const void *);
	void (*destructor)(struct inet_frag_queue___25 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___25 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___29 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___29 *fragments_tail;
	struct sk_buff___29 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___25 *net;
	struct callback_head rcu;
};

struct ip_ra_chain___4 {
	struct ip_ra_chain___4 *next;
	struct sock___16 *sk;
	union {
		void (*destructor)(struct sock___16 *);
		struct sock___16 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___14;

struct fib_lookup_arg___14;

struct fib_rules_ops___14 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___14 *, struct flowi *, int, struct fib_lookup_arg___14 *);
	bool (*suppress)(struct fib_rule___14 *, struct fib_lookup_arg___14 *);
	int (*match)(struct fib_rule___14 *, struct flowi *, int);
	int (*configure)(struct fib_rule___14 *, struct sk_buff___29 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___14 *);
	int (*compare)(struct fib_rule___14 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___14 *, struct sk_buff___29 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___14 *);
	void (*flush_cache)(struct fib_rules_ops___14 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___193 *owner;
	struct net___37 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___14 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___37 *);
	int (*fib_dump)(struct net___37 *, struct notifier_block *);
	struct module___193 *owner;
	struct callback_head rcu;
};

struct dst_entry___15 {
	struct net_device___29 *dev;
	struct dst_ops___35 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___29 *);
	int (*output)(struct net___37 *, struct sock___16 *, struct sk_buff___29 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___14;

struct neigh_parms___15;

struct neigh_ops___14;

struct neighbour___15 {
	struct neighbour___15 *next;
	struct neigh_table___14 *tbl;
	struct neigh_parms___15 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___25 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___15 *, struct sk_buff___29 *);
	const struct neigh_ops___14 *ops;
	struct callback_head rcu;
	struct net_device___29 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct ucounts___199 {
	struct hlist_node node;
	struct user_namespace___199 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_prog_aux___26;

struct bpf_prog___24 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___26 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

typedef int (*key_restrict_link_func_t___232)(struct key___232 *, const struct key_type *, const union key_payload *, struct key___232 *);

struct key_restriction___232;

struct key___232 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___240 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key___5 index_key;
		struct {
			struct key_type___5 *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___232 *restrict_link;
};

struct key_restriction___232 {
	key_restrict_link_func_t___232 check;
	struct key___232 *key;
	struct key_type *keytype;
};

struct seq_operations___213 {
	void * (*start)(struct seq_file___215 *, loff_t *);
	void (*stop)(struct seq_file___215 *, void *);
	void * (*next)(struct seq_file___215 *, void *, loff_t *);
	int (*show)(struct seq_file___215 *, void *);
};

struct pernet_operations___26 {
	struct list_head list;
	int (*init)(struct net___37 *);
	void (*exit)(struct net___37 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___25 {
	int (*ieee_getets)(struct net_device___29 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___29 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___29 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___29 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___29 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___29 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___29 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___29 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___29 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___29 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___29 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___29 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___29 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___29 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___29 *);
	u8 (*setstate)(struct net_device___29 *, u8);
	void (*getpermhwaddr)(struct net_device___29 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___29 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___29 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___29 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___29 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___29 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___29 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___29 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___29 *, int, u8 *);
	void (*setpfccfg)(struct net_device___29 *, int, u8);
	void (*getpfccfg)(struct net_device___29 *, int, u8 *);
	u8 (*setall)(struct net_device___29 *);
	u8 (*getcap)(struct net_device___29 *, int, u8 *);
	int (*getnumtcs)(struct net_device___29 *, int, u8 *);
	int (*setnumtcs)(struct net_device___29 *, int, u8);
	u8 (*getpfcstate)(struct net_device___29 *);
	void (*setpfcstate)(struct net_device___29 *, u8);
	void (*getbcncfg)(struct net_device___29 *, int, u32 *);
	void (*setbcncfg)(struct net_device___29 *, int, u32);
	void (*getbcnrp)(struct net_device___29 *, int, u8 *);
	void (*setbcnrp)(struct net_device___29 *, int, u8);
	int (*setapp)(struct net_device___29 *, u8, u16, u8);
	int (*getapp)(struct net_device___29 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___29 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___29 *, int, u8);
	u8 (*getdcbx)(struct net_device___29 *);
	u8 (*setdcbx)(struct net_device___29 *, u8);
	int (*peer_getappinfo)(struct net_device___29 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___29 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___29 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___29 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___29 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___29 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___184 {
	refcount_t count;
	struct ns_common___28 ns;
	struct user_namespace___199 *user_ns;
	struct ucounts___199 *ucounts;
	struct css_set___184 *root_cset;
};

struct bpf_map___184;

struct bpf_map_ops___184 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___184 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___184 *, struct file___239 *);
	void (*map_free)(struct bpf_map___184 *);
	int (*map_get_next_key)(struct bpf_map___184 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___184 *);
	void * (*map_lookup_elem)(struct bpf_map___184 *, void *);
	int (*map_update_elem)(struct bpf_map___184 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___184 *, void *);
	int (*map_push_elem)(struct bpf_map___184 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___184 *, void *);
	int (*map_peek_elem)(struct bpf_map___184 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___184 *, struct file___239 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___184 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___184 *, void *, struct seq_file___215 *);
	int (*map_check_btf)(const struct bpf_map___184 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___184 {
	const struct bpf_map_ops___184 *ops;
	struct bpf_map___184 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___232 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___25;

struct bpf_map_dev_ops___25 {
	int (*map_get_next_key)(struct bpf_offloaded_map___25 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___25 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___25 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___25 *, void *);
};

struct bpf_offloaded_map___25 {
	struct bpf_map___184 map;
	struct net_device___29 *netdev;
	const struct bpf_map_dev_ops___25 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___24 {
	int (*test_run)(struct bpf_prog___24 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___24 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___24 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___24 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___24 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___24 *, u32 *);
};

struct bpf_prog_offload_ops___24 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___24 *);
	int (*translate)(struct bpf_prog___24 *);
	void (*destroy)(struct bpf_prog___24 *);
};

struct bpf_prog_offload___24 {
	struct bpf_prog___24 *prog;
	struct net_device___29 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___24 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___26 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___24 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___24 *ops;
	struct bpf_map___184 **used_maps;
	struct bpf_prog___24 *prog;
	struct user_struct___232 *user;
	u64 load_time;
	struct bpf_map___184 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___24 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___24 {
	struct bpf_prog___24 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___24 {
	struct callback_head rcu;
	struct bpf_prog_array_item___24 items[0];
};

struct cgroup_bpf___24 {
	struct bpf_prog_array___24 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___24 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___184;

typedef void (*kthread_work_func_t___184)(struct kthread_work___184 *);

struct kthread_worker___184;

struct kthread_work___184 {
	struct list_head node;
	kthread_work_func_t___184 func;
	struct kthread_worker___184 *worker;
	int canceling;
};

struct kthread_worker___184 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___240 *task;
	struct kthread_work___184 *current_work;
};

struct kthread_delayed_work___184 {
	struct kthread_work___184 work;
	struct timer_list timer;
};

struct psi_group___184 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___184 *poll_kworker;
	struct kthread_delayed_work___184 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___184;

struct cgroup_rstat_cpu___184;

struct cgroup___184 {
	struct cgroup_subsys_state___185 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___233 *kn;
	struct cgroup_file___184 procs_file;
	struct cgroup_file___184 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___185 *subsys[13];
	struct cgroup_root___184 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___184 *dom_cgrp;
	struct cgroup_rstat_cpu___184 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___24 bpf;
	atomic_t congestion_count;
	struct cgroup___184 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___184 psi;
	int ancestor_ids[0];
};

struct cftype___184;

struct cgroup_subsys___184 {
	struct cgroup_subsys_state___185 * (*css_alloc)(struct cgroup_subsys_state___185 *);
	int (*css_online)(struct cgroup_subsys_state___185 *);
	void (*css_offline)(struct cgroup_subsys_state___185 *);
	void (*css_released)(struct cgroup_subsys_state___185 *);
	void (*css_free)(struct cgroup_subsys_state___185 *);
	void (*css_reset)(struct cgroup_subsys_state___185 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___185 *, int);
	int (*css_extra_stat_show)(struct seq_file___215 *, struct cgroup_subsys_state___185 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___240 *);
	void (*cancel_fork)(struct task_struct___240 *);
	void (*fork)(struct task_struct___240 *);
	void (*exit)(struct task_struct___240 *);
	void (*free)(struct task_struct___240 *);
	void (*bind)(struct cgroup_subsys_state___185 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___184 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___184 *dfl_cftypes;
	struct cftype___184 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___184 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___184 *updated_children;
	struct cgroup___184 *updated_next;
};

struct cgroup_root___184 {
	struct kernfs_root___233 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___184 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___184 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___184 *ss;
	struct list_head node;
	struct kernfs_ops___233 *kf_ops;
	int (*open)(struct kernfs_open_file___233 *);
	void (*release)(struct kernfs_open_file___233 *);
	u64 (*read_u64)(struct cgroup_subsys_state___185 *, struct cftype___184 *);
	s64 (*read_s64)(struct cgroup_subsys_state___185 *, struct cftype___184 *);
	int (*seq_show)(struct seq_file___215 *, void *);
	void * (*seq_start)(struct seq_file___215 *, loff_t *);
	void * (*seq_next)(struct seq_file___215 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___215 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___185 *, struct cftype___184 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___185 *, struct cftype___184 *, s64);
	ssize_t (*write)(struct kernfs_open_file___233 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___233 *, struct poll_table_struct___147 *);
};

struct xdp_rxq_info___25 {
	struct net_device___29 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___25 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___29 *dev_rx;
};

struct netlink_callback___25 {
	struct sk_buff___29 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___25 *);
	int (*dump)(struct sk_buff___29 *, struct netlink_callback___25 *);
	int (*done)(struct netlink_callback___25 *);
	void *data;
	struct module___193 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___25 {
	int (*create)(struct sk_buff___29 *, struct net_device___29 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___29 *, unsigned char *);
	int (*cache)(const struct neighbour___15 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___29 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___25 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___25 *, int);
	int poll_owner;
	struct net_device___29 *dev;
	struct sk_buff___29 *gro_list;
	struct sk_buff___29 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___25 {
	struct net_device___29 *dev;
	struct Qdisc___24 *qdisc;
	struct Qdisc___24 *qdisc_sleeping;
	struct kobject___227 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___29 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___24 {
	struct sk_buff___29 *head;
	struct sk_buff___29 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___24;

struct Qdisc___24 {
	int (*enqueue)(struct sk_buff___29 *, struct Qdisc___24 *, struct sk_buff___29 **);
	struct sk_buff___29 * (*dequeue)(struct Qdisc___24 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___24 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___25 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___25 gso_skb;
	struct qdisc_skb_head___24 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___24 *next_sched;
	struct sk_buff_head___25 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___25 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___227 kobj;
	struct net_device___29 *dev;
	long: 64;
	struct xdp_rxq_info___25 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___25)(struct net_device___29 *, struct sk_buff___29 *, struct net_device___29 *);

struct netdev_bpf___25 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___24 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___24 *prog;
			const struct bpf_prog_offload_ops___24 *ops;
		} verifier;
		struct {
			struct bpf_prog___24 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___25 *offmap;
		};
		struct {
			struct xdp_umem *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___25 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___29 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___25 {
	int (*tls_dev_add)(struct net_device___29 *, struct sock___16 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___29 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___29 *, struct sock___16 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___25 {
	int (*ndo_init)(struct net_device___29 *);
	void (*ndo_uninit)(struct net_device___29 *);
	int (*ndo_open)(struct net_device___29 *);
	int (*ndo_stop)(struct net_device___29 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___29 *, struct net_device___29 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___29 *, struct net_device___29 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___29 *, struct sk_buff___29 *, struct net_device___29 *, select_queue_fallback_t___25);
	void (*ndo_change_rx_flags)(struct net_device___29 *, int);
	void (*ndo_set_rx_mode)(struct net_device___29 *);
	int (*ndo_set_mac_address)(struct net_device___29 *, void *);
	int (*ndo_validate_addr)(struct net_device___29 *);
	int (*ndo_do_ioctl)(struct net_device___29 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___29 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___29 *, int);
	int (*ndo_neigh_setup)(struct net_device___29 *, struct neigh_parms___15 *);
	void (*ndo_tx_timeout)(struct net_device___29 *);
	void (*ndo_get_stats64)(struct net_device___29 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___29 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___29 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___29 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___29 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___29 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___29 *);
	int (*ndo_netpoll_setup)(struct net_device___29 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___29 *);
	int (*ndo_set_vf_mac)(struct net_device___29 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___29 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___29 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___29 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___29 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___29 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___29 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___29 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___29 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___29 *, int, struct sk_buff___29 *);
	int (*ndo_set_vf_guid)(struct net_device___29 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___29 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___29 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___29 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___29 *, const struct sk_buff___29 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___29 *, struct net_device___29 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___29 *, struct net_device___29 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___29 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___29 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___29 *, struct neighbour___15 *);
	void (*ndo_neigh_destroy)(struct net_device___29 *, struct neighbour___15 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___29 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___29 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___29 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___29 *, struct netlink_callback___25 *, struct net_device___29 *, struct net_device___29 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___29 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___29 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___29 *, u32, u32, struct net_device___29 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___29 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___29 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___29 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___29 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___29 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___29 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___29 *, struct net_device___29 *);
	void (*ndo_dfwd_del_station)(struct net_device___29 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___29 *);
	int (*ndo_set_tx_maxrate)(struct net_device___29 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___29 *);
	int (*ndo_change_proto_down)(struct net_device___29 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___29 *, struct sk_buff___29 *);
	void (*ndo_set_rx_headroom)(struct net_device___29 *, int);
	int (*ndo_bpf)(struct net_device___29 *, struct netdev_bpf___25 *);
	int (*ndo_xdp_xmit)(struct net_device___29 *, int, struct xdp_frame___25 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___29 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___29 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___15 {
	possible_net_t___26 net;
	struct net_device___29 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___15 *);
	void (*neigh_cleanup)(struct neighbour___15 *);
	struct neigh_table___14 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___15 {
	u32 (*l3mdev_fib_table)(const struct net_device___29 *);
	struct sk_buff___29 * (*l3mdev_l3_rcv)(struct net_device___29 *, struct sk_buff___29 *, u16);
	struct sk_buff___29 * (*l3mdev_l3_out)(struct net_device___29 *, struct sock___16 *, struct sk_buff___29 *, u16);
	struct dst_entry___15 * (*l3mdev_link_scope_lookup)(const struct net_device___29 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct ndisc_ops___8 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___29 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___29 *, struct neighbour___15 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___29 *, u8, struct neighbour___15 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___29 *, struct sk_buff___29 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___37 *, struct net_device___29 *, const struct prefix_info *, struct inet6_dev___8 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___7;

struct inet6_dev___8 {
	struct net_device___29 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___7 *mc_list;
	struct ifmcaddr6___7 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	u8 rndid[8];
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___15 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
};

struct tcf_proto___24;

struct mini_Qdisc___24 {
	struct tcf_proto___24 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___24 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___29 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___37 *, struct net_device___29 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___29 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___29 *, struct list_head *);
	size_t (*get_size)(const struct net_device___29 *);
	int (*fill_info)(struct sk_buff___29 *, const struct net_device___29 *);
	size_t (*get_xstats_size)(const struct net_device___29 *);
	int (*fill_xstats)(struct sk_buff___29 *, const struct net_device___29 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___29 *, struct net_device___29 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___29 *, const struct net_device___29 *);
	int (*fill_slave_info)(struct sk_buff___29 *, const struct net_device___29 *, const struct net_device___29 *);
	struct net___37 * (*get_link_net)(const struct net_device___29 *);
	size_t (*get_linkxstats_size)(const struct net_device___29 *, int);
	int (*fill_linkxstats)(struct sk_buff___29 *, const struct net_device___29 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___25 {
	struct list_head poll_list;
	struct sk_buff_head___25 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___25 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___24 *output_queue;
	struct Qdisc___24 **output_queue_tailp;
	struct sk_buff___29 *completion_queue;
	struct sk_buff_head___25 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___25 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___25 input_pkt_queue;
	struct napi_struct___25 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bdi_writeback_congested___115 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___115 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___115 {
	struct bio___115 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___115 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___115 bip_inline_vecs[0];
};

struct bio_set___115 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___115 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___100 {
	struct mem_cgroup___100 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___100 {
	struct lruvec___239 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___100 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___100 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct kernel_param_ops___190 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___190 *);
	int (*get)(char *, const struct kernel_param___190 *);
	void (*free)(void *);
};

struct kparam_array___190;

struct kernel_param___190 {
	const char *name;
	struct module___193 *mod;
	const struct kernel_param_ops___190 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___190 *arr;
	};
};

struct kparam_array___190 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___190 *ops;
	void *elem;
};

struct module_attribute___190 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___190 *, struct module_kobject___190 *, char *);
	ssize_t (*store)(struct module_attribute___190 *, struct module_kobject___190 *, const char *, size_t);
	void (*setup)(struct module___193 *, const char *);
	int (*test)(struct module___193 *);
	void (*free)(struct module___193 *);
};

struct gnet_dump___24 {
	spinlock_t *lock;
	struct sk_buff___29 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___24;

struct Qdisc_ops___24 {
	struct Qdisc_ops___24 *next;
	const struct Qdisc_class_ops___24 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___29 *, struct Qdisc___24 *, struct sk_buff___29 **);
	struct sk_buff___29 * (*dequeue)(struct Qdisc___24 *);
	struct sk_buff___29 * (*peek)(struct Qdisc___24 *);
	int (*init)(struct Qdisc___24 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___24 *);
	void (*destroy)(struct Qdisc___24 *);
	int (*change)(struct Qdisc___24 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___24 *);
	int (*change_tx_queue_len)(struct Qdisc___24 *, unsigned int);
	int (*dump)(struct Qdisc___24 *, struct sk_buff___29 *);
	int (*dump_stats)(struct Qdisc___24 *, struct gnet_dump___24 *);
	void (*ingress_block_set)(struct Qdisc___24 *, u32);
	void (*egress_block_set)(struct Qdisc___24 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___24 *);
	u32 (*egress_block_get)(struct Qdisc___24 *);
	struct module___193 *owner;
};

struct tcf_block___24;

struct Qdisc_class_ops___24 {
	unsigned int flags;
	struct netdev_queue___25 * (*select_queue)(struct Qdisc___24 *, struct tcmsg *);
	int (*graft)(struct Qdisc___24 *, long unsigned int, struct Qdisc___24 *, struct Qdisc___24 **, struct netlink_ext_ack *);
	struct Qdisc___24 * (*leaf)(struct Qdisc___24 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___24 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___24 *, u32);
	int (*change)(struct Qdisc___24 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___24 *, long unsigned int);
	void (*walk)(struct Qdisc___24 *, struct qdisc_walker *);
	struct tcf_block___24 * (*tcf_block)(struct Qdisc___24 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___24 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___24 *, long unsigned int);
	int (*dump)(struct Qdisc___24 *, long unsigned int, struct sk_buff___29 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___24 *, long unsigned int, struct gnet_dump___24 *);
};

struct tcf_chain___24;

struct tcf_block___24 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___37 *net;
	struct Qdisc___24 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___24 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___24;

struct tcf_proto_ops___24;

struct tcf_proto___24 {
	struct tcf_proto___24 *next;
	void *root;
	int (*classify)(struct sk_buff___29 *, const struct tcf_proto___24 *, struct tcf_result___24 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___24 *ops;
	struct tcf_chain___24 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___24 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___24 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___24 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___29 *, const struct tcf_proto___24 *, struct tcf_result___24 *);
	int (*init)(struct tcf_proto___24 *);
	void (*destroy)(struct tcf_proto___24 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___24 *, u32);
	void (*put)(struct tcf_proto___24 *, void *);
	int (*change)(struct net___37 *, struct sk_buff___29 *, struct tcf_proto___24 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___24 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___24 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___24 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___37 *, struct tcf_chain___24 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___37 *, struct tcf_proto___24 *, void *, struct sk_buff___29 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___29 *, struct net___37 *, void *);
	struct module___193 *owner;
	int flags;
};

struct tcf_chain___24 {
	struct mutex filter_chain_lock;
	struct tcf_proto___24 *filter_chain;
	struct list_head list;
	struct tcf_block___24 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___24 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___14 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___24 *prog;
};

struct bpf_redirect_info___24 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___184 *map;
	struct bpf_map___184 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___14;

struct neigh_hash_table___14;

struct neigh_table___14 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___29 *, __u32 *);
	bool (*key_eq)(const struct neighbour___15 *, const void *);
	int (*constructor)(struct neighbour___15 *);
	int (*pconstructor)(struct pneigh_entry___14 *);
	void (*pdestructor)(struct pneigh_entry___14 *);
	void (*proxy_redo)(struct sk_buff___29 *);
	char *id;
	struct neigh_parms___15 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___25 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___14 *nht;
	struct pneigh_entry___14 **phash_buckets;
};

struct neigh_ops___14 {
	int family;
	void (*solicit)(struct neighbour___15 *, struct sk_buff___29 *);
	void (*error_report)(struct neighbour___15 *, struct sk_buff___29 *);
	int (*output)(struct neighbour___15 *, struct sk_buff___29 *);
	int (*connected_output)(struct neighbour___15 *, struct sk_buff___29 *);
};

struct pneigh_entry___14 {
	struct pneigh_entry___14 *next;
	possible_net_t___26 net;
	struct net_device___29 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___14 {
	struct neighbour___15 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___14 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___14 *ctarget;
	struct net___37 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___14 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___14 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___8;

struct timewait_sock_ops___8;

struct proto___14 {
	void (*close)(struct sock___16 *, long int);
	int (*pre_connect)(struct sock___16 *, struct sockaddr *, int);
	int (*connect)(struct sock___16 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___16 *, int);
	struct sock___16 * (*accept)(struct sock___16 *, int, int *, bool);
	int (*ioctl)(struct sock___16 *, int, long unsigned int);
	int (*init)(struct sock___16 *);
	void (*destroy)(struct sock___16 *);
	void (*shutdown)(struct sock___16 *, int);
	int (*setsockopt)(struct sock___16 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___16 *, int, int, char *, int *);
	void (*keepalive)(struct sock___16 *, int);
	int (*sendmsg)(struct sock___16 *, struct msghdr___16 *, size_t);
	int (*recvmsg)(struct sock___16 *, struct msghdr___16 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___16 *, struct page___240 *, int, size_t, int);
	int (*bind)(struct sock___16 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___16 *, struct sk_buff___29 *);
	void (*release_cb)(struct sock___16 *);
	int (*hash)(struct sock___16 *);
	void (*unhash)(struct sock___16 *);
	void (*rehash)(struct sock___16 *);
	int (*get_port)(struct sock___16 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___16 *);
	bool (*stream_memory_read)(const struct sock___16 *);
	void (*enter_memory_pressure)(struct sock___16 *);
	void (*leave_memory_pressure)(struct sock___16 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___8 *rsk_prot;
	struct timewait_sock_ops___8 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___193 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___16 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct request_sock___8;

struct request_sock_ops___8 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___16 *, struct request_sock___8 *);
	void (*send_ack)(const struct sock___16 *, struct sk_buff___29 *, struct request_sock___8 *);
	void (*send_reset)(const struct sock___16 *, struct sk_buff___29 *);
	void (*destructor)(struct request_sock___8 *);
	void (*syn_ack_timeout)(const struct request_sock___8 *);
};

struct timewait_sock_ops___8 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___16 *, struct sock___16 *, void *);
	void (*twsk_destructor)(struct sock___16 *);
};

struct request_sock___8 {
	struct sock_common___14 __req_common;
	struct request_sock___8 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___8 *rsk_ops;
	struct sock___16 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___7 {
	struct in6_addr mca_addr;
	struct inet6_dev___8 *idev;
	struct ifmcaddr6___7 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ip6_ra_chain___7 {
	struct ip6_ra_chain___7 *next;
	struct sock___16 *sk;
	int sel;
	void (*destructor)(struct sock___16 *);
};

enum ib_uverbs_write_cmds {
	IB_USER_VERBS_CMD_GET_CONTEXT = 0,
	IB_USER_VERBS_CMD_QUERY_DEVICE = 1,
	IB_USER_VERBS_CMD_QUERY_PORT = 2,
	IB_USER_VERBS_CMD_ALLOC_PD = 3,
	IB_USER_VERBS_CMD_DEALLOC_PD = 4,
	IB_USER_VERBS_CMD_CREATE_AH = 5,
	IB_USER_VERBS_CMD_MODIFY_AH = 6,
	IB_USER_VERBS_CMD_QUERY_AH = 7,
	IB_USER_VERBS_CMD_DESTROY_AH = 8,
	IB_USER_VERBS_CMD_REG_MR = 9,
	IB_USER_VERBS_CMD_REG_SMR = 10,
	IB_USER_VERBS_CMD_REREG_MR = 11,
	IB_USER_VERBS_CMD_QUERY_MR = 12,
	IB_USER_VERBS_CMD_DEREG_MR = 13,
	IB_USER_VERBS_CMD_ALLOC_MW = 14,
	IB_USER_VERBS_CMD_BIND_MW = 15,
	IB_USER_VERBS_CMD_DEALLOC_MW = 16,
	IB_USER_VERBS_CMD_CREATE_COMP_CHANNEL = 17,
	IB_USER_VERBS_CMD_CREATE_CQ = 18,
	IB_USER_VERBS_CMD_RESIZE_CQ = 19,
	IB_USER_VERBS_CMD_DESTROY_CQ = 20,
	IB_USER_VERBS_CMD_POLL_CQ = 21,
	IB_USER_VERBS_CMD_PEEK_CQ = 22,
	IB_USER_VERBS_CMD_REQ_NOTIFY_CQ = 23,
	IB_USER_VERBS_CMD_CREATE_QP = 24,
	IB_USER_VERBS_CMD_QUERY_QP = 25,
	IB_USER_VERBS_CMD_MODIFY_QP = 26,
	IB_USER_VERBS_CMD_DESTROY_QP = 27,
	IB_USER_VERBS_CMD_POST_SEND = 28,
	IB_USER_VERBS_CMD_POST_RECV = 29,
	IB_USER_VERBS_CMD_ATTACH_MCAST = 30,
	IB_USER_VERBS_CMD_DETACH_MCAST = 31,
	IB_USER_VERBS_CMD_CREATE_SRQ = 32,
	IB_USER_VERBS_CMD_MODIFY_SRQ = 33,
	IB_USER_VERBS_CMD_QUERY_SRQ = 34,
	IB_USER_VERBS_CMD_DESTROY_SRQ = 35,
	IB_USER_VERBS_CMD_POST_SRQ_RECV = 36,
	IB_USER_VERBS_CMD_OPEN_XRCD = 37,
	IB_USER_VERBS_CMD_CLOSE_XRCD = 38,
	IB_USER_VERBS_CMD_CREATE_XSRQ = 39,
	IB_USER_VERBS_CMD_OPEN_QP = 40,
};

enum ib_uverbs_create_qp_mask {
	IB_UVERBS_CREATE_QP_MASK_IND_TABLE = 1,
};

enum ib_uverbs_wr_opcode {
	IB_UVERBS_WR_RDMA_WRITE = 0,
	IB_UVERBS_WR_RDMA_WRITE_WITH_IMM = 1,
	IB_UVERBS_WR_SEND = 2,
	IB_UVERBS_WR_SEND_WITH_IMM = 3,
	IB_UVERBS_WR_RDMA_READ = 4,
	IB_UVERBS_WR_ATOMIC_CMP_AND_SWP = 5,
	IB_UVERBS_WR_ATOMIC_FETCH_AND_ADD = 6,
	IB_UVERBS_WR_LOCAL_INV = 7,
	IB_UVERBS_WR_BIND_MW = 8,
	IB_UVERBS_WR_SEND_WITH_INV = 9,
	IB_UVERBS_WR_TSO = 10,
	IB_UVERBS_WR_RDMA_READ_WITH_INV = 11,
	IB_UVERBS_WR_MASKED_ATOMIC_CMP_AND_SWP = 12,
	IB_UVERBS_WR_MASKED_ATOMIC_FETCH_AND_ADD = 13,
};

enum ib_uverbs_access_flags {
	IB_UVERBS_ACCESS_LOCAL_WRITE = 1,
	IB_UVERBS_ACCESS_REMOTE_WRITE = 2,
	IB_UVERBS_ACCESS_REMOTE_READ = 4,
	IB_UVERBS_ACCESS_REMOTE_ATOMIC = 8,
	IB_UVERBS_ACCESS_MW_BIND = 16,
	IB_UVERBS_ACCESS_ZERO_BASED = 32,
	IB_UVERBS_ACCESS_ON_DEMAND = 64,
	IB_UVERBS_ACCESS_HUGETLB = 128,
};

union ib_gid {
	u8 raw[16];
	struct {
		__be64 subnet_prefix;
		__be64 interface_id;
	} global;
};

struct lsm_network_audit {
	int netif;
	struct sock___16 *sk;
	u16 family;
	__be16 dport;
	__be16 sport;
	union {
		struct {
			__be32 daddr;
			__be32 saddr;
		} v4;
		struct {
			struct in6_addr daddr;
			struct in6_addr saddr;
		} v6;
	} fam;
};

struct lsm_ioctlop_audit {
	struct path___238 path;
	u16 cmd;
};

struct lsm_ibpkey_audit {
	u64 subnet_prefix;
	u16 pkey;
};

struct lsm_ibendport_audit {
	char dev_name[64];
	u8 port;
};

struct selinux_state;

struct selinux_audit_data {
	u32 ssid;
	u32 tsid;
	u16 tclass;
	u32 requested;
	u32 audited;
	u32 denied;
	int result;
	struct selinux_state *state;
};

struct common_audit_data {
	char type;
	union {
		struct path___238 path;
		struct dentry___239 *dentry;
		struct inode___239 *inode;
		struct lsm_network_audit *net;
		int cap;
		int ipc_id;
		struct task_struct___240 *tsk;
		struct {
			key_serial_t key;
			char *key_desc;
		} key_struct;
		char *kmod_name;
		struct lsm_ioctlop_audit *op;
		struct file___239 *file;
		struct lsm_ibpkey_audit *ibpkey;
		struct lsm_ibendport_audit *ibendport;
	} u;
	union {
		struct selinux_audit_data *selinux_audit_data;
	};
};

enum {
	POLICYDB_CAPABILITY_NETPEER = 0,
	POLICYDB_CAPABILITY_OPENPERM = 1,
	POLICYDB_CAPABILITY_EXTSOCKCLASS = 2,
	POLICYDB_CAPABILITY_ALWAYSNETWORK = 3,
	POLICYDB_CAPABILITY_CGROUPSECLABEL = 4,
	POLICYDB_CAPABILITY_NNP_NOSUID_TRANSITION = 5,
	__POLICYDB_CAPABILITY_MAX = 6,
};

struct selinux_avc;

struct selinux_ss;

struct selinux_state {
	bool disabled;
	bool enforcing;
	bool checkreqprot;
	bool initialized;
	bool policycap[6];
	struct selinux_avc *avc;
	struct selinux_ss *ss;
};

struct avc_cache {
	struct hlist_head slots[512];
	spinlock_t slots_lock[512];
	atomic_t lru_hint;
	atomic_t active_nodes;
	u32 latest_notif;
};

struct selinux_avc {
	unsigned int avc_cache_threshold;
	struct avc_cache avc_cache;
};

struct av_decision {
	u32 allowed;
	u32 auditallow;
	u32 auditdeny;
	u32 seqno;
	u32 flags;
};

struct extended_perms_data {
	u32 p[8];
};

struct extended_perms_decision {
	u8 used;
	u8 driver;
	struct extended_perms_data *allowed;
	struct extended_perms_data *auditallow;
	struct extended_perms_data *dontaudit;
};

struct extended_perms {
	u16 len;
	struct extended_perms_data drivers;
};

struct avc_cache_stats {
	unsigned int lookups;
	unsigned int misses;
	unsigned int allocations;
	unsigned int reclaims;
	unsigned int frees;
};

struct security_class_mapping {
	const char *name;
	const char *perms[33];
};

struct avc_xperms_node;

struct avc_entry {
	u32 ssid;
	u32 tsid;
	u16 tclass;
	struct av_decision avd;
	struct avc_xperms_node *xp_node;
};

struct avc_xperms_node {
	struct extended_perms xp;
	struct list_head xpd_head;
};

struct avc_node {
	struct avc_entry ae;
	struct hlist_node list;
	struct callback_head rhead;
};

struct avc_xperms_decision_node {
	struct extended_perms_decision xpd;
	struct list_head xpd_list;
};

struct avc_callback_node {
	int (*callback)(u32);
	u32 events;
	struct avc_callback_node *next;
};

typedef __u16 __sum16;

typedef u16 u_int16_t;

typedef u8 uint8_t;

struct module___194;

struct file___240;

struct kiocb___240;

struct iov_iter___107;

struct poll_table_struct___148;

struct vm_area_struct___241;

struct inode___240;

struct file_lock___240;

struct page___241;

struct pipe_inode_info___50;

struct seq_file___216;

struct file_operations___240 {
	struct module___194 *owner;
	loff_t (*llseek)(struct file___240 *, loff_t, int);
	ssize_t (*read)(struct file___240 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___240 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___240 *, struct iov_iter___107 *);
	ssize_t (*write_iter)(struct kiocb___240 *, struct iov_iter___107 *);
	int (*iopoll)(struct kiocb___240 *, bool);
	int (*iterate)(struct file___240 *, struct dir_context *);
	int (*iterate_shared)(struct file___240 *, struct dir_context *);
	__poll_t (*poll)(struct file___240 *, struct poll_table_struct___148 *);
	long int (*unlocked_ioctl)(struct file___240 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___240 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___240 *, struct vm_area_struct___241 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___240 *, struct file___240 *);
	int (*flush)(struct file___240 *, fl_owner_t);
	int (*release)(struct inode___240 *, struct file___240 *);
	int (*fsync)(struct file___240 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___240 *, int);
	int (*lock)(struct file___240 *, int, struct file_lock___240 *);
	ssize_t (*sendpage)(struct file___240 *, struct page___241 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___240 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___240 *, int, struct file_lock___240 *);
	ssize_t (*splice_write)(struct pipe_inode_info___50 *, struct file___240 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___240 *, loff_t *, struct pipe_inode_info___50 *, size_t, unsigned int);
	int (*setlease)(struct file___240 *, long int, struct file_lock___240 **, void **);
	long int (*fallocate)(struct file___240 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___216 *, struct file___240 *);
	ssize_t (*copy_file_range)(struct file___240 *, loff_t, struct file___240 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___240 *, loff_t, struct file___240 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___240 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___240 {
	u64 seqnum;
	struct vm_area_struct___241 *vmas[4];
};

struct page_frag___240 {
	struct page___241 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___127;

struct debug_info___127 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___127 *hbp_break[16];
	struct perf_event___127 *hbp_watch[16];
};

struct thread_struct___127 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___127 debug;
	long: 64;
};

struct mm_struct___240;

struct mem_cgroup___101;

struct pid___180;

struct cred___233;

struct files_struct___16;

struct nsproxy___220;

struct signal_struct___198;

struct bio_list___116;

struct backing_dev_info___116;

struct io_context___60;

struct css_set___185;

struct perf_event_context___127;

struct request_queue___57;

struct vm_struct___157;

struct task_struct___241 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___241 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___240 *mm;
	struct mm_struct___240 *active_mm;
	struct vmacache___240 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___241 *real_parent;
	struct task_struct___241 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___241 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___101 *active_memcg;
	long int rh_reserved2;
	struct pid___180 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___180 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___180 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___233 *ptracer_cred;
	const struct cred___233 *real_cred;
	const struct cred___233 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct___16 *files;
	struct nsproxy___220 *nsproxy;
	struct signal_struct___198 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___241 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___116 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___116 *backing_dev_info;
	struct io_context___60 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___185 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___127 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___50 *splice_pipe;
	struct page_frag___240 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___101 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___57 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___241 *oom_reaper_list;
	struct vm_struct___157 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___127 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___127 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___241 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___127)(struct perf_event___127 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___127;

struct fasync_struct___239;

struct pid_namespace___180;

struct bpf_prog___25;

struct trace_event_call___120;

struct perf_cgroup___127;

struct perf_event___127 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___127 *group_leader;
	struct pmu___127 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___127 hw;
	struct perf_event_context___127 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___127 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___241 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___239 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___127 *);
	struct callback_head callback_head;
	struct pid_namespace___180 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___127 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___127 orig_overflow_handler;
	struct bpf_prog___25 *prog;
	struct trace_event_call___120 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___127 *cgrp;
	struct list_head sb_list;
};

struct upid___180 {
	int nr;
	struct pid_namespace___180 *ns;
};

struct vfsmount___63;

struct dentry___240;

struct user_namespace___200;

struct ucounts___200;

struct pid_namespace___180 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___241 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___180 *parent;
	struct vfsmount___63 *proc_mnt;
	struct dentry___240 *proc_self;
	struct dentry___240 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___200 *user_ns;
	struct ucounts___200 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___28 ns;
};

struct pid___180 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___180 numbers[1];
};

struct rw_semaphore___241 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___241 *owner;
};

struct key___233;

struct user_namespace___200 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___200 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___28 ns;
	long unsigned int flags;
	struct key___233 *persistent_keyring_register;
	struct rw_semaphore___241 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___200 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct secondary_data___241 {
	void *stack;
	struct task_struct___241 *task;
	long int status;
};

struct rhltable {
	struct rhashtable ht;
};

typedef struct page___241 *pgtable_t___240;

struct address_space___239;

struct dev_pagemap___230;

struct page___241 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___239 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___241 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___240 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___240 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___230 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___101 *mem_cgroup;
};

struct user_struct___233 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___233 *uid_keyring;
	struct key___233 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___230;

struct vm_area_struct___241 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___241 *vm_next;
	struct vm_area_struct___241 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___240 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___230 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___240 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct linux_binfmt___38;

struct core_state___240;

struct mm_struct___240 {
	struct {
		struct vm_area_struct___241 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___240 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___241 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___38 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___240 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___241 *owner;
		struct user_namespace___200 *user_ns;
		struct file___240 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___240 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup___185;

struct cgroup_subsys___185;

struct cgroup_subsys_state___186 {
	struct cgroup___185 *cgroup;
	struct cgroup_subsys___185 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___186 *parent;
};

struct kernfs_node___234;

struct cgroup_file___185 {
	struct kernfs_node___234 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___101;

struct mem_cgroup___101 {
	struct cgroup_subsys_state___186 css;
	struct mem_cgroup_id___8 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___185 events_file;
	struct cgroup_file___185 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___241 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___101 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cred___233 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___233 *session_keyring;
	struct key___233 *process_keyring;
	struct key___233 *thread_keyring;
	struct key___233 *request_key_auth;
	void *security;
	struct user_struct___233 *user;
	struct user_namespace___200 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct fdtable___16 {
	unsigned int max_fds;
	struct file___240 **fd;
	long unsigned int *close_on_exec;
	long unsigned int *open_fds;
	long unsigned int *full_fds_bits;
	struct callback_head rcu;
};

struct files_struct___16 {
	atomic_t count;
	bool resize_in_progress;
	wait_queue_head_t resize_wait;
	struct fdtable___16 *fdt;
	struct fdtable___16 fdtab;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t file_lock;
	unsigned int next_fd;
	long unsigned int close_on_exec_init[1];
	long unsigned int open_fds_init[1];
	long unsigned int full_fds_bits_init[1];
	struct file___240 *fd_array[64];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net___38;

struct cgroup_namespace___185;

struct nsproxy___220 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___180 *pid_ns_for_children;
	struct net___38 *net_ns;
	struct cgroup_namespace___185 *cgroup_ns;
};

struct tty_struct___20;

struct signal_struct___198 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___241 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___241 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___180 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___180 *tty_old_pgrp;
	int leader;
	struct tty_struct___20 *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___240 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___180 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___116;

struct bio_list___116 {
	struct bio___116 *head;
	struct bio___116 *tail;
};

struct bdi_writeback_congested___116;

struct bdi_writeback___116 {
	struct backing_dev_info___116 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___116 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___186 *memcg_css;
	struct cgroup_subsys_state___186 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___204;

struct backing_dev_info___116 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___116 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___204 *dev;
	struct device___204 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___240 *debug_dir;
	struct dentry___240 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___60;

struct io_context___60 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___60 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___185 {
	struct cgroup_subsys_state___186 *subsys[13];
	refcount_t refcount;
	struct css_set___185 *dom_cset;
	struct cgroup___185 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___185 *mg_src_cgrp;
	struct cgroup___185 *mg_dst_cgrp;
	struct css_set___185 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___127 {
	struct pmu___127 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___241 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___127 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___50;

struct pipe_inode_info___50 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___241 *tmp_page;
	struct fasync_struct___239 *fasync_readers;
	struct fasync_struct___239 *fasync_writers;
	struct pipe_buffer___50 *bufs;
	struct user_struct___233 *user;
};

typedef blk_qc_t make_request_fn___56(struct request_queue___57 *, struct bio___116 *);

struct request___57;

typedef int dma_drain_needed_fn___56(struct request___57 *);

struct kset___227;

struct kobj_type___227;

struct kobject___228 {
	const char *name;
	struct list_head entry;
	struct kobject___228 *parent;
	struct kset___227 *kset;
	struct kobj_type___227 *ktype;
	struct kernfs_node___234 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___56;

struct bsg_class_device___56 {
	struct device___204 *class_dev;
	int minor;
	struct request_queue___57 *queue;
	const struct bsg_ops___56 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___116 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___116 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___56;

struct blkcg_gq___45;

struct request_queue___57 {
	struct list_head queue_head;
	struct request___57 *last_merge;
	struct elevator_queue___56 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___56 *make_request_fn;
	dma_drain_needed_fn___56 *dma_drain_needed;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___116 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___228 kobj;
	struct kobject___228 *mq_kobj;
	struct blk_integrity integrity;
	struct device___204 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___45 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	struct bsg_class_device___56 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___116 bio_split;
	struct dentry___240 *debugfs_dir;
	struct dentry___240 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___157 {
	struct vm_struct___157 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___241 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___210 {
	struct task_struct___241 task;
	long unsigned int stack[8192];
};

typedef int (*key_restrict_link_func_t___233)(struct key___233 *, const struct key_type *, const union key_payload *, struct key___233 *);

struct key_restriction___233;

struct key___233 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___241 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key___5 index_key;
		struct {
			struct key_type___5 *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___233 *restrict_link;
};

struct key_restriction___233 {
	key_restrict_link_func_t___233 check;
	struct key___233 *key;
	struct key_type *keytype;
};

struct tty_driver___20;

struct tty_operations___20;

struct tty_ldisc___20;

struct tty_port___20;

struct tty_struct___20 {
	int magic;
	struct kref kref;
	struct device___204 *dev;
	struct tty_driver___20 *driver;
	const struct tty_operations___20 *ops;
	int index;
	struct ld_semaphore ldisc_sem;
	struct tty_ldisc___20 *ldisc;
	struct mutex atomic_write_lock;
	struct mutex legacy_mutex;
	struct mutex throttle_mutex;
	struct rw_semaphore___241 termios_rwsem;
	struct mutex winsize_mutex;
	spinlock_t ctrl_lock;
	spinlock_t flow_lock;
	struct ktermios termios;
	struct ktermios termios_locked;
	struct termiox *termiox;
	char name[64];
	struct pid___180 *pgrp;
	struct pid___180 *session;
	long unsigned int flags;
	int count;
	struct winsize winsize;
	long unsigned int stopped: 1;
	long unsigned int flow_stopped: 1;
	int: 30;
	long unsigned int unused: 62;
	int hw_stopped;
	long unsigned int ctrl_status: 8;
	long unsigned int packet: 1;
	int: 23;
	long unsigned int unused_ctrl: 55;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___20 *link;
	struct fasync_struct___239 *fasync;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	spinlock_t files_lock;
	struct list_head tty_files;
	int closing;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___20 *port;
};

struct pglist_data___240;

struct lruvec___240 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___240 *pgdat;
};

struct zone___240 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___240 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___240 {
	struct zone___240 *zone;
	int zone_idx;
};

struct zonelist___240 {
	struct zoneref___240 _zonerefs[25];
};

struct pglist_data___240 {
	struct zone___240 node_zones[3];
	struct zonelist___240 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___241 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___241 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___240 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___240 {
	struct rw_semaphore___241 rwsem;
	struct notifier_block *head;
};

struct address_space_operations___239;

struct address_space___239 {
	struct inode___240 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___241 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___239 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___230)(struct vm_area_struct___241 *, long unsigned int, const struct page___241 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___230)(struct page___241 *, void *);

struct dev_pagemap___230 {
	dev_page_fault_t___230 page_fault;
	dev_page_free_t___230 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___204 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___239 {
	struct vfsmount___63 *mnt;
	struct dentry___240 *dentry;
};

struct fown_struct___180 {
	rwlock_t lock;
	struct pid___180 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___240 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___239 f_path;
	struct inode___240 *f_inode;
	const struct file_operations___240 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___180 f_owner;
	const struct cred___233 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___239 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___230;

struct vm_operations_struct___230 {
	void (*open)(struct vm_area_struct___241 *);
	void (*close)(struct vm_area_struct___241 *);
	int (*split)(struct vm_area_struct___241 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___241 *);
	vm_fault_t (*fault)(struct vm_fault___230 *);
	vm_fault_t (*huge_fault)(struct vm_fault___230 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___230 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___241 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___230 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___230 *);
	int (*access)(struct vm_area_struct___241 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___241 *);
	int (*set_policy)(struct vm_area_struct___241 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___241 *, long unsigned int);
	struct page___241 * (*find_special_page)(struct vm_area_struct___241 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___240 {
	struct task_struct___241 *task;
	struct core_thread___240 *next;
};

struct core_state___240 {
	atomic_t nr_threads;
	struct core_thread___240 dumper;
	struct completion startup;
};

struct linux_binprm___39;

struct coredump_params___38;

struct linux_binfmt___38 {
	struct list_head lh;
	struct module___194 *module;
	int (*load_binary)(struct linux_binprm___39 *);
	int (*load_shlib)(struct file___240 *);
	int (*core_dump)(struct coredump_params___38 *);
	long unsigned int min_coredump;
};

struct vm_fault___230 {
	struct vm_area_struct___241 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___241 *cow_page;
	struct mem_cgroup___101 *memcg;
	struct page___241 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___240 prealloc_pte;
};

struct shrink_control___101 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___101 *memcg;
};

struct shrinker___101 {
	long unsigned int (*count_objects)(struct shrinker___101 *, struct shrink_control___101 *);
	long unsigned int (*scan_objects)(struct shrinker___101 *, struct shrink_control___101 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct dev_pm_info___204 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___204 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___204;

struct bus_type___204;

struct device_driver___204;

struct dev_pm_domain___204;

struct dma_map_ops___47;

struct fwnode_handle___139;

struct class___204;

struct attribute_group___206;

struct device___204 {
	struct device___204 *parent;
	struct device_private *p;
	struct kobject___228 kobj;
	const char *init_name;
	const struct device_type___204 *type;
	struct mutex mutex;
	struct bus_type___204 *bus;
	struct device_driver___204 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___204 power;
	struct dev_pm_domain___204 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___47 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___139 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___204 *class;
	const struct attribute_group___206 **groups;
	void (*release)(struct device___204 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___239;

struct super_block___239;

struct dentry___240 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___240 *d_parent;
	struct qstr d_name;
	struct inode___240 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___239 *d_op;
	struct super_block___239 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___239;

struct block_device___240;

struct cdev___39;

struct inode___240 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___239 *i_op;
	struct super_block___239 *i_sb;
	struct address_space___239 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___241 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___116 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___240 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___239 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___50 *i_pipe;
		struct block_device___240 *i_bdev;
		struct cdev___39 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___239 {
	int (*d_revalidate)(struct dentry___240 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___240 *, unsigned int);
	int (*d_hash)(const struct dentry___240 *, struct qstr *);
	int (*d_compare)(const struct dentry___240 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___240 *);
	int (*d_init)(struct dentry___240 *);
	void (*d_release)(struct dentry___240 *);
	void (*d_prune)(struct dentry___240 *);
	void (*d_iput)(struct dentry___240 *, struct inode___240 *);
	char * (*d_dname)(struct dentry___240 *, char *, int);
	struct vfsmount___63 * (*d_automount)(struct path___239 *);
	int (*d_manage)(const struct path___239 *, bool);
	struct dentry___240 * (*d_real)(struct dentry___240 *, const struct inode___240 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___239;

struct mem_dqinfo___239 {
	struct quota_format_type___239 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___239;

struct quota_info___239 {
	unsigned int flags;
	struct rw_semaphore___241 dqio_sem;
	struct inode___240 *files[3];
	struct mem_dqinfo___239 info[3];
	const struct quota_format_ops___239 *ops[3];
};

struct rcuwait___239 {
	struct task_struct___241 *task;
};

struct percpu_rw_semaphore___239 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___241 rw_sem;
	struct rcuwait___239 writer;
	int readers_block;
};

struct sb_writers___239 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___239 rw_sem[3];
};

struct file_system_type___239;

struct super_operations___239;

struct dquot_operations___239;

struct quotactl_ops___239;

struct xattr_handler___24;

struct super_block___239 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___239 *s_type;
	const struct super_operations___239 *s_op;
	const struct dquot_operations___239 *dq_op;
	const struct quotactl_ops___239 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___240 *s_root;
	struct rw_semaphore___241 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___24 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___240 *s_bdev;
	struct backing_dev_info___116 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___239 s_dquot;
	struct sb_writers___239 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___239 *s_d_op;
	int cleancache_poolid;
	struct shrinker___101 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___200 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___63 {
	struct dentry___240 *mnt_root;
	struct super_block___239 *mnt_sb;
	int mnt_flags;
};

struct io_cq___60 {
	struct request_queue___57 *q;
	struct io_context___60 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___6 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___240 {
	struct file___240 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___240 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___239 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___240 *ia_file;
};

struct dquot___239 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___239 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___239 {
	int qf_fmt_id;
	const struct quota_format_ops___239 *qf_ops;
	struct module___194 *qf_owner;
	struct quota_format_type___239 *qf_next;
};

struct quota_format_ops___239 {
	int (*check_quota_file)(struct super_block___239 *, int);
	int (*read_file_info)(struct super_block___239 *, int);
	int (*write_file_info)(struct super_block___239 *, int);
	int (*free_file_info)(struct super_block___239 *, int);
	int (*read_dqblk)(struct dquot___239 *);
	int (*commit_dqblk)(struct dquot___239 *);
	int (*release_dqblk)(struct dquot___239 *);
	int (*get_next_id)(struct super_block___239 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___239 {
	int (*write_dquot)(struct dquot___239 *);
	struct dquot___239 * (*alloc_dquot)(struct super_block___239 *, int);
	void (*destroy_dquot)(struct dquot___239 *);
	int (*acquire_dquot)(struct dquot___239 *);
	int (*release_dquot)(struct dquot___239 *);
	int (*mark_dirty)(struct dquot___239 *);
	int (*write_info)(struct super_block___239 *, int);
	qsize_t * (*get_reserved_space)(struct inode___240 *);
	int (*get_projid)(struct inode___240 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___240 *, qsize_t *);
	int (*get_next_id)(struct super_block___239 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___239 {
	int (*quota_on)(struct super_block___239 *, int, int, const struct path___239 *);
	int (*quota_off)(struct super_block___239 *, int);
	int (*quota_enable)(struct super_block___239 *, unsigned int);
	int (*quota_disable)(struct super_block___239 *, unsigned int);
	int (*quota_sync)(struct super_block___239 *, int);
	int (*set_info)(struct super_block___239 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___239 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___239 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___239 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___239 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___239 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___191 {
	struct kobject___228 kobj;
	struct module___194 *mod;
	struct kobject___228 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___191 {
	struct module___194 *mod;
	struct latch_tree_node node;
};

struct module_layout___191 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___191 mtn;
};

struct module_attribute___191;

struct kernel_param___191;

struct module___194 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___191 mkobj;
	struct module_attribute___191 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___228 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___191 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___191 core_layout;
	struct module_layout___191 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___120 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide44;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide45;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___112;

struct swap_info_struct___71;

struct address_space_operations___239 {
	int (*writepage)(struct page___241 *, struct writeback_control___112 *);
	int (*readpage)(struct file___240 *, struct page___241 *);
	int (*writepages)(struct address_space___239 *, struct writeback_control___112 *);
	int (*set_page_dirty)(struct page___241 *);
	int (*readpages)(struct file___240 *, struct address_space___239 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___240 *, struct address_space___239 *, loff_t, unsigned int, unsigned int, struct page___241 **, void **);
	int (*write_end)(struct file___240 *, struct address_space___239 *, loff_t, unsigned int, unsigned int, struct page___241 *, void *);
	sector_t (*bmap)(struct address_space___239 *, sector_t);
	void (*invalidatepage)(struct page___241 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___241 *, gfp_t);
	void (*freepage)(struct page___241 *);
	ssize_t (*direct_IO)(struct kiocb___240 *, struct iov_iter___107 *);
	int (*migratepage)(struct address_space___239 *, struct page___241 *, struct page___241 *, enum migrate_mode);
	bool (*isolate_page)(struct page___241 *, isolate_mode_t);
	void (*putback_page)(struct page___241 *);
	int (*launder_page)(struct page___241 *);
	int (*is_partially_uptodate)(struct page___241 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___241 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___239 *, struct page___241 *);
	int (*swap_activate)(struct swap_info_struct___71 *, struct file___240 *, sector_t *);
	void (*swap_deactivate)(struct file___240 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___112 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___116 *wb;
	struct inode___240 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___116;

struct iov_iter___107 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___116 *bvec;
		struct pipe_inode_info___50 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct swap_info_struct___71 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___240 *bdev;
	struct file___240 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct hd_struct___57;

struct gendisk___57;

struct block_device___240 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___240 *bd_inode;
	struct super_block___239 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___240 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___57 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___57 *bd_disk;
	struct request_queue___57 *bd_queue;
	struct backing_dev_info___116 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct hd_struct___57 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___204 __dev;
	struct kobject___228 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___57;

struct block_device_operations___57;

struct gendisk___57 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___57 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___57 *part_tbl;
	struct hd_struct___57 part0;
	const struct block_device_operations___57 *fops;
	struct request_queue___57 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___241 lookup_sem;
	struct kobject___228 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___228 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___39 {
	struct kobject___228 kobj;
	struct module___194 *owner;
	const struct file_operations___240 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___239 {
	struct dentry___240 * (*lookup)(struct inode___240 *, struct dentry___240 *, unsigned int);
	const char * (*get_link)(struct dentry___240 *, struct inode___240 *, struct delayed_call *);
	int (*permission)(struct inode___240 *, int);
	struct posix_acl * (*get_acl)(struct inode___240 *, int);
	int (*readlink)(struct dentry___240 *, char *, int);
	int (*create)(struct inode___240 *, struct dentry___240 *, umode_t, bool);
	int (*link)(struct dentry___240 *, struct inode___240 *, struct dentry___240 *);
	int (*unlink)(struct inode___240 *, struct dentry___240 *);
	int (*symlink)(struct inode___240 *, struct dentry___240 *, const char *);
	int (*mkdir)(struct inode___240 *, struct dentry___240 *, umode_t);
	int (*rmdir)(struct inode___240 *, struct dentry___240 *);
	int (*mknod)(struct inode___240 *, struct dentry___240 *, umode_t, dev_t);
	int (*rename)(struct inode___240 *, struct dentry___240 *, struct inode___240 *, struct dentry___240 *, unsigned int);
	int (*setattr)(struct dentry___240 *, struct iattr___239 *);
	int (*getattr)(const struct path___239 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___240 *, char *, size_t);
	int (*fiemap)(struct inode___240 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___240 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___240 *, struct dentry___240 *, struct file___240 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___240 *, struct dentry___240 *, umode_t);
	int (*set_acl)(struct inode___240 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___239 {
	void (*fl_copy_lock)(struct file_lock___240 *, struct file_lock___240 *);
	void (*fl_release_private)(struct file_lock___240 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___239;

struct file_lock___240 {
	struct file_lock___240 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___240 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___239 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___239 *fl_ops;
	const struct lock_manager_operations___239 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___239 {
	int (*lm_compare_owner)(struct file_lock___240 *, struct file_lock___240 *);
	long unsigned int (*lm_owner_key)(struct file_lock___240 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___240 *);
	int (*lm_grant)(struct file_lock___240 *, int);
	bool (*lm_break)(struct file_lock___240 *);
	int (*lm_change)(struct file_lock___240 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___240 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___239 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___239 *fa_next;
	struct file___240 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___239 {
	const char *name;
	int fs_flags;
	struct dentry___240 * (*mount)(struct file_system_type___239 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___239 *);
	struct module___194 *owner;
	struct file_system_type___239 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___239 {
	struct inode___240 * (*alloc_inode)(struct super_block___239 *);
	void (*destroy_inode)(struct inode___240 *);
	void (*dirty_inode)(struct inode___240 *, int);
	int (*write_inode)(struct inode___240 *, struct writeback_control___112 *);
	int (*drop_inode)(struct inode___240 *);
	void (*evict_inode)(struct inode___240 *);
	void (*put_super)(struct super_block___239 *);
	int (*sync_fs)(struct super_block___239 *, int);
	int (*freeze_super)(struct super_block___239 *);
	int (*freeze_fs)(struct super_block___239 *);
	int (*thaw_super)(struct super_block___239 *);
	int (*unfreeze_fs)(struct super_block___239 *);
	int (*statfs)(struct dentry___240 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___239 *, int *, char *);
	void (*umount_begin)(struct super_block___239 *);
	int (*show_options)(struct seq_file___216 *, struct dentry___240 *);
	int (*show_devname)(struct seq_file___216 *, struct dentry___240 *);
	int (*show_path)(struct seq_file___216 *, struct dentry___240 *);
	int (*show_stats)(struct seq_file___216 *, struct dentry___240 *);
	ssize_t (*quota_read)(struct super_block___239 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___239 *, int, const char *, size_t, loff_t);
	struct dquot___239 ** (*get_dquots)(struct inode___240 *);
	int (*bdev_try_to_free_page)(struct super_block___239 *, struct page___241 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___239 *, struct shrink_control___101 *);
	long int (*free_cached_objects)(struct super_block___239 *, struct shrink_control___101 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct xattr_handler___24 {
	const char *name;
	const char *prefix;
	int flags;
	bool (*list)(struct dentry___240 *);
	int (*get)(const struct xattr_handler___24 *, struct dentry___240 *, struct inode___240 *, const char *, void *, size_t);
	int (*set)(const struct xattr_handler___24 *, struct dentry___240 *, struct inode___240 *, const char *, const void *, size_t, int);
};

typedef void (*poll_queue_proc___150)(struct file___240 *, wait_queue_head_t *, struct poll_table_struct___148 *);

struct poll_table_struct___148 {
	poll_queue_proc___150 _qproc;
	__poll_t _key;
};

struct seq_operations___214;

struct seq_file___216 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___214 *op;
	int poll_event;
	const struct file___240 *file;
	void *private;
};

typedef void bio_end_io_t___116(struct bio___116 *);

struct bio_vec___116 {
	struct page___241 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___116;

struct bio___116 {
	struct bio___116 *bi_next;
	struct gendisk___57 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___116 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___45 *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___116 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___116 *bi_io_vec;
	struct bio_set___116 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___116 bi_inline_vecs[0];
};

struct kobj_attribute___221 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___228 *, struct kobj_attribute___221 *, char *);
	ssize_t (*store)(struct kobject___228 *, struct kobj_attribute___221 *, const char *, size_t);
};

typedef void compound_page_dtor___230(struct page___241 *);

struct inet_frags___26;

struct netns_frags___26 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___26 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ip_ra_chain___5;

struct fib_rules_ops___15;

struct sock___17;

struct tcp_congestion_ops___2;

struct tcp_fastopen_context___2;

struct fib_notifier_ops___15;

struct netns_ipv4___26 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___5 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___15 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___17 *fibnl;
	struct sock___17 **icmp_sk;
	struct sock___17 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___17 **tcp_sk;
	struct netns_frags___26 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops___2 *tcp_congestion_control;
	struct tcp_fastopen_context___2 *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___15 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___15 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___15 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct dst_entry___16;

struct net_device___30;

struct sk_buff___30;

struct neighbour___16;

struct dst_ops___36 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___36 *);
	struct dst_entry___16 * (*check)(struct dst_entry___16 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___16 *);
	unsigned int (*mtu)(const struct dst_entry___16 *);
	u32 * (*cow_metrics)(struct dst_entry___16 *, long unsigned int);
	void (*destroy)(struct dst_entry___16 *);
	void (*ifdown)(struct dst_entry___16 *, struct net_device___30 *, int);
	struct dst_entry___16 * (*negative_advice)(struct dst_entry___16 *);
	void (*link_failure)(struct sk_buff___30 *);
	void (*update_pmtu)(struct dst_entry___16 *, struct sock___17 *, struct sk_buff___30 *, u32);
	void (*redirect)(struct dst_entry___16 *, struct sock___17 *, struct sk_buff___30 *);
	int (*local_out)(struct net___38 *, struct sock___17 *, struct sk_buff___30 *);
	struct neighbour___16 * (*neigh_lookup)(const struct dst_entry___16 *, struct sk_buff___30 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___16 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___36 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___26 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___36 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___15 *fib6_rules_ops;
	struct sock___17 **icmp_sk;
	struct sock___17 *ndisc_sk;
	struct sock___17 *tcp_sk;
	struct sock___17 *igmp_sk;
	struct sock___17 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___15 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___15 *notifier_ops;
	struct fib_notifier_ops___15 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___16 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___17 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___26 {
	struct netns_frags___26 frags;
};

struct netns_xfrm___36 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___17 *nlsk;
	struct sock___17 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___36 xfrm4_dst_ops;
	struct dst_ops___36 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct net___38 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___200 *user_ns;
	struct ucounts___200 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___28 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___17 *rtnl;
	struct sock___17 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___30 *loopback_dev;
	struct netns_core core;
	struct netns_mib___2 mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___26 ipv4;
	struct netns_ipv6___36 ipv6;
	struct netns_sctp___16 sctp;
	struct netns_nf___2 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___26 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___17 *nfnl;
	struct sock___17 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___36 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can___2 can;
	struct sock___17 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___25 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cgroup_namespace___185 {
	refcount_t count;
	struct ns_common___28 ns;
	struct user_namespace___200 *user_ns;
	struct ucounts___200 *ucounts;
	struct css_set___185 *root_cset;
};

struct ucounts___200 {
	struct hlist_node node;
	struct user_namespace___200 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct seq_operations___214 {
	void * (*start)(struct seq_file___216 *, loff_t *);
	void (*stop)(struct seq_file___216 *, void *);
	void * (*next)(struct seq_file___216 *, void *, loff_t *);
	int (*show)(struct seq_file___216 *, void *);
};

struct kernfs_root___234;

struct kernfs_elem_dir___234 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___234 *root;
};

struct kernfs_syscall_ops___234;

struct kernfs_root___234 {
	struct kernfs_node___234 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___234 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___234 {
	struct kernfs_node___234 *target_kn;
};

struct kernfs_ops___234;

struct kernfs_elem_attr___234 {
	const struct kernfs_ops___234 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___234 *notify_next;
};

struct kernfs_node___234 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___234 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___234 dir;
		struct kernfs_elem_symlink___234 symlink;
		struct kernfs_elem_attr___234 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___234;

struct kernfs_ops___234 {
	int (*open)(struct kernfs_open_file___234 *);
	void (*release)(struct kernfs_open_file___234 *);
	int (*seq_show)(struct seq_file___216 *, void *);
	void * (*seq_start)(struct seq_file___216 *, loff_t *);
	void * (*seq_next)(struct seq_file___216 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___216 *, void *);
	ssize_t (*read)(struct kernfs_open_file___234 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___234 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___234 *, struct vm_area_struct___241 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___234 *, struct poll_table_struct___148 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___234 {
	int (*remount_fs)(struct kernfs_root___234 *, int *, char *);
	int (*show_options)(struct seq_file___216 *, struct kernfs_root___234 *);
	int (*mkdir)(struct kernfs_node___234 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___234 *);
	int (*rename)(struct kernfs_node___234 *, struct kernfs_node___234 *, const char *);
	int (*show_path)(struct seq_file___216 *, struct kernfs_node___234 *, struct kernfs_root___234 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___234 {
	struct kernfs_node___234 *kn;
	struct file___240 *file;
	struct seq_file___216 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___230 *vm_ops;
};

struct bpf_map___185;

struct bpf_map_ops___185 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___185 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___185 *, struct file___240 *);
	void (*map_free)(struct bpf_map___185 *);
	int (*map_get_next_key)(struct bpf_map___185 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___185 *);
	void * (*map_lookup_elem)(struct bpf_map___185 *, void *);
	int (*map_update_elem)(struct bpf_map___185 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___185 *, void *);
	int (*map_push_elem)(struct bpf_map___185 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___185 *, void *);
	int (*map_peek_elem)(struct bpf_map___185 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___185 *, struct file___240 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___185 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___185 *, void *, struct seq_file___216 *);
	int (*map_check_btf)(const struct bpf_map___185 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___185 {
	const struct bpf_map_ops___185 *ops;
	struct bpf_map___185 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___233 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___26;

struct bpf_map_dev_ops___26 {
	int (*map_get_next_key)(struct bpf_offloaded_map___26 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___26 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___26 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___26 *, void *);
};

struct bpf_offloaded_map___26 {
	struct bpf_map___185 map;
	struct net_device___30 *netdev;
	const struct bpf_map_dev_ops___26 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

typedef rx_handler_result_t rx_handler_func_t___26(struct sk_buff___30 **);

typedef struct {
	struct net___38 *net;
} possible_net_t___27;

struct net_device_ops___26;

struct ethtool_ops___26;

struct l3mdev_ops___16;

struct ndisc_ops___9;

struct xfrmdev_ops___26;

struct tlsdev_ops___26;

struct header_ops___26;

struct inet6_dev___9;

struct netdev_rx_queue___26;

struct mini_Qdisc___25;

struct netdev_queue___26;

struct Qdisc___25;

struct rtnl_link_ops___25;

struct dcbnl_rtnl_ops___26;

struct net_device___30 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___26 *netdev_ops;
	const struct ethtool_ops___26 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___16 *l3mdev_ops;
	const struct ndisc_ops___9 *ndisc_ops;
	const struct xfrmdev_ops___26 *xfrmdev_ops;
	const struct tlsdev_ops___26 *tlsdev_ops;
	const struct header_ops___26 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___227 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___9 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___26 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___25 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___26 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___25 *miniq_ingress;
	struct netdev_queue___26 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___26 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___25 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___25 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___26 = 0,
		NETREG_REGISTERED___26 = 1,
		NETREG_UNREGISTERING___26 = 2,
		NETREG_UNREGISTERED___26 = 3,
		NETREG_RELEASED___26 = 4,
		NETREG_DUMMY___26 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___26 = 0,
		RTNL_LINK_INITIALIZING___26 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___30 *);
	struct netpoll_info *npinfo;
	possible_net_t___27 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___204 dev;
	const struct attribute_group___206 *sysfs_groups[4];
	const struct attribute_group___206 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___25 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___26 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide66;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct bpf_prog_ops___25 {
	int (*test_run)(struct bpf_prog___25 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_aux___27;

struct bpf_prog___25 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___27 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

struct bpf_verifier_ops___25 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___25 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___25 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___25 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___25 *, u32 *);
};

struct bpf_prog_offload_ops___25 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___25 *);
	int (*translate)(struct bpf_prog___25 *);
	void (*destroy)(struct bpf_prog___25 *);
};

struct bpf_prog_offload___25 {
	struct bpf_prog___25 *prog;
	struct net_device___30 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___25 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___27 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___25 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___25 *ops;
	struct bpf_map___185 **used_maps;
	struct bpf_prog___25 *prog;
	struct user_struct___233 *user;
	u64 load_time;
	struct bpf_map___185 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___25 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___25 {
	struct bpf_prog___25 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___25 {
	struct callback_head rcu;
	struct bpf_prog_array_item___25 items[0];
};

struct cgroup_bpf___25 {
	struct bpf_prog_array___25 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___25 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___185;

typedef void (*kthread_work_func_t___185)(struct kthread_work___185 *);

struct kthread_worker___185;

struct kthread_work___185 {
	struct list_head node;
	kthread_work_func_t___185 func;
	struct kthread_worker___185 *worker;
	int canceling;
};

struct kthread_worker___185 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___241 *task;
	struct kthread_work___185 *current_work;
};

struct kthread_delayed_work___185 {
	struct kthread_work___185 work;
	struct timer_list timer;
};

struct psi_group___185 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___185 *poll_kworker;
	struct kthread_delayed_work___185 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___185;

struct cgroup_rstat_cpu___185;

struct cgroup___185 {
	struct cgroup_subsys_state___186 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___234 *kn;
	struct cgroup_file___185 procs_file;
	struct cgroup_file___185 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___186 *subsys[13];
	struct cgroup_root___185 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___185 *dom_cgrp;
	struct cgroup_rstat_cpu___185 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___25 bpf;
	atomic_t congestion_count;
	struct cgroup___185 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___185 psi;
	int ancestor_ids[0];
};

struct cftype___185;

struct cgroup_subsys___185 {
	struct cgroup_subsys_state___186 * (*css_alloc)(struct cgroup_subsys_state___186 *);
	int (*css_online)(struct cgroup_subsys_state___186 *);
	void (*css_offline)(struct cgroup_subsys_state___186 *);
	void (*css_released)(struct cgroup_subsys_state___186 *);
	void (*css_free)(struct cgroup_subsys_state___186 *);
	void (*css_reset)(struct cgroup_subsys_state___186 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___186 *, int);
	int (*css_extra_stat_show)(struct seq_file___216 *, struct cgroup_subsys_state___186 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___241 *);
	void (*cancel_fork)(struct task_struct___241 *);
	void (*fork)(struct task_struct___241 *);
	void (*exit)(struct task_struct___241 *);
	void (*free)(struct task_struct___241 *);
	void (*bind)(struct cgroup_subsys_state___186 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___185 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___185 *dfl_cftypes;
	struct cftype___185 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___185 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___185 *updated_children;
	struct cgroup___185 *updated_next;
};

struct cgroup_root___185 {
	struct kernfs_root___234 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___185 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___185 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___185 *ss;
	struct list_head node;
	struct kernfs_ops___234 *kf_ops;
	int (*open)(struct kernfs_open_file___234 *);
	void (*release)(struct kernfs_open_file___234 *);
	u64 (*read_u64)(struct cgroup_subsys_state___186 *, struct cftype___185 *);
	s64 (*read_s64)(struct cgroup_subsys_state___186 *, struct cftype___185 *);
	int (*seq_show)(struct seq_file___216 *, void *);
	void * (*seq_start)(struct seq_file___216 *, loff_t *);
	void * (*seq_next)(struct seq_file___216 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___216 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___186 *, struct cftype___185 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___186 *, struct cftype___185 *, s64);
	ssize_t (*write)(struct kernfs_open_file___234 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___234 *, struct poll_table_struct___148 *);
};

struct bdi_writeback_congested___116 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___116 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___116 {
	struct bio___116 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___116 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___116 bip_inline_vecs[0];
};

struct blkcg___45;

struct blkg_policy_data___45;

struct blkcg_gq___45 {
	struct request_queue___57 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___45 *blkcg;
	struct bdi_writeback_congested___116 *wb_congested;
	struct blkcg_gq___45 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_rwstat stat_bytes;
	struct blkg_rwstat stat_ios;
	struct blkg_policy_data___45 *pd[5];
	struct callback_head callback_head;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
};

struct mem_cgroup_reclaim_iter___101 {
	struct mem_cgroup___101 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___101 {
	struct lruvec___240 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___101 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___101 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct dev_pm_ops___204;

struct device_type___204 {
	const char *name;
	const struct attribute_group___206 **groups;
	int (*uevent)(struct device___204 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___204 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___204 *);
	const struct dev_pm_ops___204 *pm;
};

struct kobj_ns_type_operations___15;

struct class___204 {
	const char *name;
	struct module___194 *owner;
	const struct attribute_group___206 **class_groups;
	const struct attribute_group___206 **dev_groups;
	struct kobject___228 *dev_kobj;
	int (*dev_uevent)(struct device___204 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___204 *, umode_t *);
	void (*class_release)(struct class___204 *);
	void (*dev_release)(struct device___204 *);
	int (*shutdown_pre)(struct device___204 *);
	const struct kobj_ns_type_operations___15 *ns_type;
	const void * (*namespace)(struct device___204 *);
	const struct dev_pm_ops___204 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct kobj_ns_type_operations___15 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___17 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct proto___15;

struct sock_common___15 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___15 *skc_prot;
	possible_net_t___27 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___17 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff_head___26 {
	struct sk_buff___30 *next;
	struct sk_buff___30 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___15;

struct socket_wq___16;

struct socket___17;

struct sock___17 {
	struct sock_common___15 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___26 sk_error_queue;
	struct sk_buff_head___26 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___30 *head;
		struct sk_buff___30 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___15 *sk_filter;
	union {
		struct socket_wq___16 *sk_wq;
		struct socket_wq___16 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___16 *sk_rx_dst;
	struct dst_entry___16 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___30 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___26 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___240 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___15 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___180 *sk_peer_pid;
	const struct cred___233 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___17 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___101 *sk_memcg;
	void (*sk_state_change)(struct sock___17 *);
	void (*sk_data_ready)(struct sock___17 *);
	void (*sk_write_space)(struct sock___17 *);
	void (*sk_error_report)(struct sock___17 *);
	int (*sk_backlog_rcv)(struct sock___17 *, struct sk_buff___30 *);
	struct sk_buff___30 * (*sk_validate_xmit_skb)(struct sock___17 *, struct net_device___30 *, struct sk_buff___30 *);
	void (*sk_destruct)(struct sock___17 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct bin_attribute___205;

struct attribute_group___206 {
	const char *name;
	umode_t (*is_visible)(struct kobject___228 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___228 *, struct bin_attribute___205 *, int);
	struct attribute **attrs;
	struct bin_attribute___205 **bin_attrs;
};

struct bin_attribute___205 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___240 *, struct kobject___228 *, struct bin_attribute___205 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___240 *, struct kobject___228 *, struct bin_attribute___205 *, char *, loff_t, size_t);
	int (*mmap)(struct file___240 *, struct kobject___228 *, struct bin_attribute___205 *, struct vm_area_struct___241 *);
};

struct sysfs_ops___227 {
	ssize_t (*show)(struct kobject___228 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___228 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___227;

struct kset___227 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___228 kobj;
	const struct kset_uevent_ops___227 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___227 {
	void (*release)(struct kobject___228 *);
	const struct sysfs_ops___227 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___15 * (*child_ns_type)(struct kobject___228 *);
	const void * (*namespace)(struct kobject___228 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___227 {
	int (* const filter)(struct kset___227 *, struct kobject___228 *);
	const char * (* const name)(struct kset___227 *, struct kobject___228 *);
	int (* const uevent)(struct kset___227 *, struct kobject___228 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___204 {
	int (*prepare)(struct device___204 *);
	void (*complete)(struct device___204 *);
	int (*suspend)(struct device___204 *);
	int (*resume)(struct device___204 *);
	int (*freeze)(struct device___204 *);
	int (*thaw)(struct device___204 *);
	int (*poweroff)(struct device___204 *);
	int (*restore)(struct device___204 *);
	int (*suspend_late)(struct device___204 *);
	int (*resume_early)(struct device___204 *);
	int (*freeze_late)(struct device___204 *);
	int (*thaw_early)(struct device___204 *);
	int (*poweroff_late)(struct device___204 *);
	int (*restore_early)(struct device___204 *);
	int (*suspend_noirq)(struct device___204 *);
	int (*resume_noirq)(struct device___204 *);
	int (*freeze_noirq)(struct device___204 *);
	int (*thaw_noirq)(struct device___204 *);
	int (*poweroff_noirq)(struct device___204 *);
	int (*restore_noirq)(struct device___204 *);
	int (*runtime_suspend)(struct device___204 *);
	int (*runtime_resume)(struct device___204 *);
	int (*runtime_idle)(struct device___204 *);
};

struct dev_pm_domain___204 {
	struct dev_pm_ops___204 ops;
	void (*detach)(struct device___204 *, bool);
	int (*activate)(struct device___204 *);
	void (*sync)(struct device___204 *);
	void (*dismiss)(struct device___204 *);
};

struct bus_type___204 {
	const char *name;
	const char *dev_name;
	struct device___204 *dev_root;
	const struct attribute_group___206 **bus_groups;
	const struct attribute_group___206 **dev_groups;
	const struct attribute_group___206 **drv_groups;
	int (*match)(struct device___204 *, struct device_driver___204 *);
	int (*uevent)(struct device___204 *, struct kobj_uevent_env *);
	int (*probe)(struct device___204 *);
	int (*remove)(struct device___204 *);
	void (*shutdown)(struct device___204 *);
	int (*online)(struct device___204 *);
	int (*offline)(struct device___204 *);
	int (*suspend)(struct device___204 *, pm_message_t);
	int (*resume)(struct device___204 *);
	int (*num_vf)(struct device___204 *);
	int (*dma_configure)(struct device___204 *);
	const struct dev_pm_ops___204 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___204 {
	const char *name;
	struct bus_type___204 *bus;
	struct module___194 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___204 *);
	int (*remove)(struct device___204 *);
	void (*shutdown)(struct device___204 *);
	int (*suspend)(struct device___204 *, pm_message_t);
	int (*resume)(struct device___204 *);
	const struct attribute_group___206 **groups;
	const struct dev_pm_ops___204 *pm;
	void (*coredump)(struct device___204 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct dma_map_ops___47 {
	void * (*alloc)(struct device___204 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___204 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___204 *, struct vm_area_struct___241 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___204 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___204 *, struct page___241 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___204 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___204 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___204 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___204 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___204 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___204 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide50;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___204 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___204 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___204 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___204 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___204 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___204 *, u64);
	u64 (*get_required_mask)(struct device___204 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___139;

struct fwnode_handle___139 {
	struct fwnode_handle___139 *secondary;
	const struct fwnode_operations___139 *ops;
};

struct disk_part_tbl___57 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___57 *last_lookup;
	struct hd_struct___57 *part[0];
};

struct block_device_operations___57 {
	int (*open)(struct block_device___240 *, fmode_t);
	void (*release)(struct gendisk___57 *, fmode_t);
	int (*rw_page)(struct block_device___240 *, sector_t, struct page___241 *, unsigned int);
	int (*ioctl)(struct block_device___240 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___240 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___57 *, unsigned int);
	int (*media_changed)(struct gendisk___57 *);
	void (*unlock_native_capacity)(struct gendisk___57 *);
	int (*revalidate_disk)(struct gendisk___57 *);
	int (*getgeo)(struct block_device___240 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___240 *, long unsigned int);
	int (*report_zones)(struct gendisk___57 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___194 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___56 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___57 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___57 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___57 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___56(struct request___57 *, blk_status_t);

struct request___57 {
	struct request_queue___57 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___116 *bio;
	struct bio___116 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___116 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___60 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___56 *saved_end_io;
		} flush;
	};
	struct gendisk___57 *rq_disk;
	struct hd_struct___57 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___56 *end_io;
	void *end_io_data;
	struct request___57 *next_rq;
};

struct fwnode_reference_args___139;

struct fwnode_endpoint___139;

struct fwnode_operations___139 {
	struct fwnode_handle___139 * (*get)(struct fwnode_handle___139 *);
	void (*put)(struct fwnode_handle___139 *);
	bool (*device_is_available)(const struct fwnode_handle___139 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___139 *, const struct device___204 *);
	bool (*property_present)(const struct fwnode_handle___139 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___139 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___139 *, const char *, const char **, size_t);
	struct fwnode_handle___139 * (*get_parent)(const struct fwnode_handle___139 *);
	struct fwnode_handle___139 * (*get_next_child_node)(const struct fwnode_handle___139 *, struct fwnode_handle___139 *);
	struct fwnode_handle___139 * (*get_named_child_node)(const struct fwnode_handle___139 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___139 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___139 *);
	struct fwnode_handle___139 * (*graph_get_next_endpoint)(const struct fwnode_handle___139 *, struct fwnode_handle___139 *);
	struct fwnode_handle___139 * (*graph_get_remote_endpoint)(const struct fwnode_handle___139 *);
	struct fwnode_handle___139 * (*graph_get_port_parent)(struct fwnode_handle___139 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___139 *, struct fwnode_endpoint___139 *);
};

struct fwnode_endpoint___139 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___139 *local_fwnode;
};

struct fwnode_reference_args___139 {
	struct fwnode_handle___139 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct elevator_type___56;

struct elevator_mq_ops___56 {
	int (*init_sched)(struct request_queue___57 *, struct elevator_type___56 *);
	void (*exit_sched)(struct elevator_queue___56 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	bool (*allow_merge)(struct request_queue___57 *, struct request___57 *, struct bio___116 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx *, struct bio___116 *);
	int (*request_merge)(struct request_queue___57 *, struct request___57 **, struct bio___116 *);
	void (*request_merged)(struct request_queue___57 *, struct request___57 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___57 *, struct request___57 *, struct request___57 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___57 *, struct bio___116 *);
	void (*finish_request)(struct request___57 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___57 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___57 *, u64);
	void (*started_request)(struct request___57 *);
	void (*requeue_request)(struct request___57 *);
	struct request___57 * (*former_request)(struct request_queue___57 *, struct request___57 *);
	struct request___57 * (*next_request)(struct request_queue___57 *, struct request___57 *);
	void (*init_icq)(struct io_cq___60 *);
	void (*exit_icq)(struct io_cq___60 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___56;

struct elevator_type___56 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___56 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___56 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___194 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___56 {
	struct elevator_type___56 *type;
	void *elevator_data;
	struct kobject___228 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___56 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___56 *, char *);
	ssize_t (*store)(struct elevator_queue___56 *, const char *, size_t);
};

struct blkcg_policy_data___45;

struct blkcg___45 {
	struct cgroup_subsys_state___186 css;
	spinlock_t lock;
	struct xarray blkg_tree;
	struct blkcg_gq___45 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___45 *cpd[5];
	struct list_head all_blkcgs_node;
	struct list_head cgwb_list;
	refcount_t cgwb_refcnt;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct blkcg_policy_data___45 {
	struct blkcg___45 *blkcg;
	int plid;
};

struct blkg_policy_data___45 {
	struct blkcg_gq___45 *blkg;
	int plid;
};

struct msghdr___17;

struct request_sock___9;

struct sctp_endpoint___2;

struct xfrm_sec_ctx___2;

struct xfrm_user_sec_ctx___2;

union security_list_options___3 {
	int (*binder_set_context_mgr)(struct task_struct___241 *);
	int (*binder_transaction)(struct task_struct___241 *, struct task_struct___241 *);
	int (*binder_transfer_binder)(struct task_struct___241 *, struct task_struct___241 *);
	int (*binder_transfer_file)(struct task_struct___241 *, struct task_struct___241 *, struct file___240 *);
	int (*ptrace_access_check)(struct task_struct___241 *, unsigned int);
	int (*ptrace_traceme)(struct task_struct___241 *);
	int (*capget)(struct task_struct___241 *, kernel_cap_t *, kernel_cap_t *, kernel_cap_t *);
	int (*capset)(struct cred___233 *, const struct cred___233 *, const kernel_cap_t *, const kernel_cap_t *, const kernel_cap_t *);
	int (*capable)(const struct cred___233 *, struct user_namespace___200 *, int, int);
	int (*quotactl)(int, int, int, struct super_block___239 *);
	int (*quota_on)(struct dentry___240 *);
	int (*syslog)(int);
	int (*settime)(const struct timespec64 *, const struct timezone *);
	int (*vm_enough_memory)(struct mm_struct___240 *, long int);
	int (*bprm_set_creds)(struct linux_binprm___39 *);
	int (*bprm_check_security)(struct linux_binprm___39 *);
	void (*bprm_committing_creds)(struct linux_binprm___39 *);
	void (*bprm_committed_creds)(struct linux_binprm___39 *);
	int (*sb_alloc_security)(struct super_block___239 *);
	void (*sb_free_security)(struct super_block___239 *);
	int (*sb_copy_data)(char *, char *);
	int (*sb_remount)(struct super_block___239 *, void *);
	int (*sb_kern_mount)(struct super_block___239 *, int, void *);
	int (*sb_show_options)(struct seq_file___216 *, struct super_block___239 *);
	int (*sb_statfs)(struct dentry___240 *);
	int (*sb_mount)(const char *, const struct path___239 *, const char *, long unsigned int, void *);
	int (*sb_umount)(struct vfsmount___63 *, int);
	int (*sb_pivotroot)(const struct path___239 *, const struct path___239 *);
	int (*sb_set_mnt_opts)(struct super_block___239 *, struct security_mnt_opts *, long unsigned int, long unsigned int *);
	int (*sb_clone_mnt_opts)(const struct super_block___239 *, struct super_block___239 *, long unsigned int, long unsigned int *);
	int (*sb_parse_opts_str)(char *, struct security_mnt_opts *);
	int (*dentry_init_security)(struct dentry___240 *, int, const struct qstr *, void **, u32 *);
	int (*dentry_create_files_as)(struct dentry___240 *, int, struct qstr *, const struct cred___233 *, struct cred___233 *);
	int (*inode_alloc_security)(struct inode___240 *);
	void (*inode_free_security)(struct inode___240 *);
	int (*inode_init_security)(struct inode___240 *, struct inode___240 *, const struct qstr *, const char **, void **, size_t *);
	int (*inode_create)(struct inode___240 *, struct dentry___240 *, umode_t);
	int (*inode_link)(struct dentry___240 *, struct inode___240 *, struct dentry___240 *);
	int (*inode_unlink)(struct inode___240 *, struct dentry___240 *);
	int (*inode_symlink)(struct inode___240 *, struct dentry___240 *, const char *);
	int (*inode_mkdir)(struct inode___240 *, struct dentry___240 *, umode_t);
	int (*inode_rmdir)(struct inode___240 *, struct dentry___240 *);
	int (*inode_mknod)(struct inode___240 *, struct dentry___240 *, umode_t, dev_t);
	int (*inode_rename)(struct inode___240 *, struct dentry___240 *, struct inode___240 *, struct dentry___240 *);
	int (*inode_readlink)(struct dentry___240 *);
	int (*inode_follow_link)(struct dentry___240 *, struct inode___240 *, bool);
	int (*inode_permission)(struct inode___240 *, int);
	int (*inode_setattr)(struct dentry___240 *, struct iattr___239 *);
	int (*inode_getattr)(const struct path___239 *);
	int (*inode_setxattr)(struct dentry___240 *, const char *, const void *, size_t, int);
	void (*inode_post_setxattr)(struct dentry___240 *, const char *, const void *, size_t, int);
	int (*inode_getxattr)(struct dentry___240 *, const char *);
	int (*inode_listxattr)(struct dentry___240 *);
	int (*inode_removexattr)(struct dentry___240 *, const char *);
	int (*inode_need_killpriv)(struct dentry___240 *);
	int (*inode_killpriv)(struct dentry___240 *);
	int (*inode_getsecurity)(struct inode___240 *, const char *, void **, bool);
	int (*inode_setsecurity)(struct inode___240 *, const char *, const void *, size_t, int);
	int (*inode_listsecurity)(struct inode___240 *, char *, size_t);
	void (*inode_getsecid)(struct inode___240 *, u32 *);
	int (*inode_copy_up)(struct dentry___240 *, struct cred___233 **);
	int (*inode_copy_up_xattr)(const char *);
	int (*kernfs_init_security)(struct kernfs_node___234 *, struct kernfs_node___234 *);
	int (*file_permission)(struct file___240 *, int);
	int (*file_alloc_security)(struct file___240 *);
	void (*file_free_security)(struct file___240 *);
	int (*file_ioctl)(struct file___240 *, unsigned int, long unsigned int);
	int (*mmap_addr)(long unsigned int);
	int (*mmap_file)(struct file___240 *, long unsigned int, long unsigned int, long unsigned int);
	int (*file_mprotect)(struct vm_area_struct___241 *, long unsigned int, long unsigned int);
	int (*file_lock)(struct file___240 *, unsigned int);
	int (*file_fcntl)(struct file___240 *, unsigned int, long unsigned int);
	void (*file_set_fowner)(struct file___240 *);
	int (*file_send_sigiotask)(struct task_struct___241 *, struct fown_struct___180 *, int);
	int (*file_receive)(struct file___240 *);
	int (*file_open)(struct file___240 *);
	int (*task_alloc)(struct task_struct___241 *, long unsigned int);
	void (*task_free)(struct task_struct___241 *);
	int (*cred_alloc_blank)(struct cred___233 *, gfp_t);
	void (*cred_free)(struct cred___233 *);
	int (*cred_prepare)(struct cred___233 *, const struct cred___233 *, gfp_t);
	void (*cred_transfer)(struct cred___233 *, const struct cred___233 *);
	void (*cred_getsecid)(const struct cred___233 *, u32 *);
	int (*kernel_act_as)(struct cred___233 *, u32);
	int (*kernel_create_files_as)(struct cred___233 *, struct inode___240 *);
	int (*kernel_module_request)(char *);
	int (*kernel_read_file)(struct file___240 *, enum kernel_read_file_id);
	int (*kernel_post_read_file)(struct file___240 *, char *, loff_t, enum kernel_read_file_id);
	int (*task_fix_setuid)(struct cred___233 *, const struct cred___233 *, int);
	int (*task_setpgid)(struct task_struct___241 *, pid_t);
	int (*task_getpgid)(struct task_struct___241 *);
	int (*task_getsid)(struct task_struct___241 *);
	void (*task_getsecid)(struct task_struct___241 *, u32 *);
	int (*task_setnice)(struct task_struct___241 *, int);
	int (*task_setioprio)(struct task_struct___241 *, int);
	int (*task_getioprio)(struct task_struct___241 *);
	int (*task_prlimit)(const struct cred___233 *, const struct cred___233 *, unsigned int);
	int (*task_setrlimit)(struct task_struct___241 *, unsigned int, struct rlimit *);
	int (*task_setscheduler)(struct task_struct___241 *);
	int (*task_getscheduler)(struct task_struct___241 *);
	int (*task_movememory)(struct task_struct___241 *);
	int (*task_kill)(struct task_struct___241 *, struct kernel_siginfo *, int, const struct cred___233 *);
	int (*task_prctl)(int, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*task_to_inode)(struct task_struct___241 *, struct inode___240 *);
	int (*ipc_permission)(struct kern_ipc_perm *, short int);
	void (*ipc_getsecid)(struct kern_ipc_perm *, u32 *);
	int (*msg_msg_alloc_security)(struct msg_msg *);
	void (*msg_msg_free_security)(struct msg_msg *);
	int (*msg_queue_alloc_security)(struct kern_ipc_perm *);
	void (*msg_queue_free_security)(struct kern_ipc_perm *);
	int (*msg_queue_associate)(struct kern_ipc_perm *, int);
	int (*msg_queue_msgctl)(struct kern_ipc_perm *, int);
	int (*msg_queue_msgsnd)(struct kern_ipc_perm *, struct msg_msg *, int);
	int (*msg_queue_msgrcv)(struct kern_ipc_perm *, struct msg_msg *, struct task_struct___241 *, long int, int);
	int (*shm_alloc_security)(struct kern_ipc_perm *);
	void (*shm_free_security)(struct kern_ipc_perm *);
	int (*shm_associate)(struct kern_ipc_perm *, int);
	int (*shm_shmctl)(struct kern_ipc_perm *, int);
	int (*shm_shmat)(struct kern_ipc_perm *, char *, int);
	int (*sem_alloc_security)(struct kern_ipc_perm *);
	void (*sem_free_security)(struct kern_ipc_perm *);
	int (*sem_associate)(struct kern_ipc_perm *, int);
	int (*sem_semctl)(struct kern_ipc_perm *, int);
	int (*sem_semop)(struct kern_ipc_perm *, struct sembuf *, unsigned int, int);
	int (*netlink_send)(struct sock___17 *, struct sk_buff___30 *);
	void (*d_instantiate)(struct dentry___240 *, struct inode___240 *);
	int (*getprocattr)(struct task_struct___241 *, char *, char **);
	int (*setprocattr)(const char *, void *, size_t);
	int (*ismaclabel)(const char *);
	int (*secid_to_secctx)(u32, char **, u32 *);
	int (*secctx_to_secid)(const char *, u32, u32 *);
	void (*release_secctx)(char *, u32);
	void (*inode_invalidate_secctx)(struct inode___240 *);
	int (*inode_notifysecctx)(struct inode___240 *, void *, u32);
	int (*inode_setsecctx)(struct dentry___240 *, void *, u32);
	int (*inode_getsecctx)(struct inode___240 *, void **, u32 *);
	int (*unix_stream_connect)(struct sock___17 *, struct sock___17 *, struct sock___17 *);
	int (*unix_may_send)(struct socket___17 *, struct socket___17 *);
	int (*socket_create)(int, int, int, int);
	int (*socket_post_create)(struct socket___17 *, int, int, int, int);
	int (*socket_socketpair)(struct socket___17 *, struct socket___17 *);
	int (*socket_bind)(struct socket___17 *, struct sockaddr *, int);
	int (*socket_connect)(struct socket___17 *, struct sockaddr *, int);
	int (*socket_listen)(struct socket___17 *, int);
	int (*socket_accept)(struct socket___17 *, struct socket___17 *);
	int (*socket_sendmsg)(struct socket___17 *, struct msghdr___17 *, int);
	int (*socket_recvmsg)(struct socket___17 *, struct msghdr___17 *, int, int);
	int (*socket_getsockname)(struct socket___17 *);
	int (*socket_getpeername)(struct socket___17 *);
	int (*socket_getsockopt)(struct socket___17 *, int, int);
	int (*socket_setsockopt)(struct socket___17 *, int, int);
	int (*socket_shutdown)(struct socket___17 *, int);
	int (*socket_sock_rcv_skb)(struct sock___17 *, struct sk_buff___30 *);
	int (*socket_getpeersec_stream)(struct socket___17 *, char *, int *, unsigned int);
	int (*socket_getpeersec_dgram)(struct socket___17 *, struct sk_buff___30 *, u32 *);
	int (*sk_alloc_security)(struct sock___17 *, int, gfp_t);
	void (*sk_free_security)(struct sock___17 *);
	void (*sk_clone_security)(const struct sock___17 *, struct sock___17 *);
	void (*sk_getsecid)(struct sock___17 *, u32 *);
	void (*sock_graft)(struct sock___17 *, struct socket___17 *);
	int (*inet_conn_request)(struct sock___17 *, struct sk_buff___30 *, struct request_sock___9 *);
	void (*inet_csk_clone)(struct sock___17 *, const struct request_sock___9 *);
	void (*inet_conn_established)(struct sock___17 *, struct sk_buff___30 *);
	int (*secmark_relabel_packet)(u32);
	void (*secmark_refcount_inc)();
	void (*secmark_refcount_dec)();
	void (*req_classify_flow)(const struct request_sock___9 *, struct flowi *);
	int (*tun_dev_alloc_security)(void **);
	void (*tun_dev_free_security)(void *);
	int (*tun_dev_create)();
	int (*tun_dev_attach_queue)(void *);
	int (*tun_dev_attach)(struct sock___17 *, void *);
	int (*tun_dev_open)(void *);
	int (*sctp_assoc_request)(struct sctp_endpoint___2 *, struct sk_buff___30 *);
	int (*sctp_bind_connect)(struct sock___17 *, int, struct sockaddr *, int);
	void (*sctp_sk_clone)(struct sctp_endpoint___2 *, struct sock___17 *, struct sock___17 *);
	int (*ib_pkey_access)(void *, u64, u16);
	int (*ib_endport_manage_subnet)(void *, const char *, u8);
	int (*ib_alloc_security)(void **);
	void (*ib_free_security)(void *);
	int (*xfrm_policy_alloc_security)(struct xfrm_sec_ctx___2 **, struct xfrm_user_sec_ctx___2 *, gfp_t);
	int (*xfrm_policy_clone_security)(struct xfrm_sec_ctx___2 *, struct xfrm_sec_ctx___2 **);
	void (*xfrm_policy_free_security)(struct xfrm_sec_ctx___2 *);
	int (*xfrm_policy_delete_security)(struct xfrm_sec_ctx___2 *);
	int (*xfrm_state_alloc)(struct xfrm_state *, struct xfrm_user_sec_ctx___2 *);
	int (*xfrm_state_alloc_acquire)(struct xfrm_state *, struct xfrm_sec_ctx___2 *, u32);
	void (*xfrm_state_free_security)(struct xfrm_state *);
	int (*xfrm_state_delete_security)(struct xfrm_state *);
	int (*xfrm_policy_lookup)(struct xfrm_sec_ctx___2 *, u32, u8);
	int (*xfrm_state_pol_flow_match)(struct xfrm_state *, struct xfrm_policy *, const struct flowi *);
	int (*xfrm_decode_session)(struct sk_buff___30 *, u32 *, int);
	int (*key_alloc)(struct key___233 *, const struct cred___233 *, long unsigned int);
	void (*key_free)(struct key___233 *);
	int (*key_permission)(key_ref_t, const struct cred___233 *, unsigned int);
	int (*key_getsecurity)(struct key___233 *, char **);
	int (*audit_rule_init)(u32, u32, char *, void **);
	int (*audit_rule_known)(struct audit_krule *);
	int (*audit_rule_match)(u32, u32, u32, void *, struct audit_context *);
	void (*audit_rule_free)(void *);
	int (*bpf)(int, union bpf_attr *, unsigned int);
	int (*bpf_map)(struct bpf_map___185 *, fmode_t);
	int (*bpf_prog)(struct bpf_prog___25 *);
	int (*bpf_map_alloc_security)(struct bpf_map___185 *);
	void (*bpf_map_free_security)(struct bpf_map___185 *);
	int (*bpf_prog_alloc_security)(struct bpf_prog_aux___27 *);
	void (*bpf_prog_free_security)(struct bpf_prog_aux___27 *);
};

struct linux_binprm___39 {
	char buf[256];
	struct vm_area_struct___241 *vma;
	long unsigned int vma_pages;
	struct mm_struct___240 *mm;
	long unsigned int p;
	unsigned int called_set_creds: 1;
	unsigned int cap_elevated: 1;
	unsigned int secureexec: 1;
	unsigned int recursion_depth;
	struct file___240 *file;
	struct cred___233 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
};

struct nf_bridge_info___26;

struct sk_buff___30 {
	union {
		struct {
			struct sk_buff___30 *next;
			struct sk_buff___30 *prev;
			union {
				struct net_device___30 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___17 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___30 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___26 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct proto_ops___16;

struct socket___17 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___16 *wq;
	struct file___240 *file;
	struct sock___17 *sk;
	const struct proto_ops___16 *ops;
};

struct msghdr___17 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___107 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___240 *msg_iocb;
};

struct request_sock_ops___9;

struct request_sock___9 {
	struct sock_common___15 __req_common;
	struct request_sock___9 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___9 *rsk_ops;
	struct sock___17 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

enum sctp_endpoint_type {
	SCTP_EP_TYPE_SOCKET = 0,
	SCTP_EP_TYPE_ASSOCIATION = 1,
};

struct sctp_chunk;

struct sctp_inq {
	struct list_head in_chunk_list;
	struct sctp_chunk *in_progress;
	struct work_struct immediate;
};

struct sctp_bind_addr {
	__u16 port;
	struct list_head address_list;
};

struct sctp_ep_common {
	struct hlist_node node;
	int hashent;
	enum sctp_endpoint_type type;
	refcount_t refcnt;
	bool dead;
	struct sock___17 *sk;
	struct sctp_inq inqueue;
	struct sctp_bind_addr bind_addr;
};

struct crypto_shash___3;

struct sctp_hmac_algo_param;

struct sctp_chunks_param;

struct sctp_endpoint___2 {
	struct sctp_ep_common base;
	struct list_head asocs;
	__u8 secret_key[32];
	__u8 *digest;
	__u32 sndbuf_policy;
	__u32 rcvbuf_policy;
	struct crypto_shash___3 **auth_hmacs;
	struct sctp_hmac_algo_param *auth_hmacs_list;
	struct sctp_chunks_param *auth_chunk_list;
	struct list_head endpoint_shared_keys;
	__u16 active_key_id;
	__u8 auth_enable: 1;
	__u8 intl_enable: 1;
	__u8 prsctp_enable: 1;
	__u8 reconf_enable: 1;
	__u8 strreset_enable;
	u32 secid;
	u32 peer_secid;
};

struct xfrm_sec_ctx___2 {
	__u8 ctx_doi;
	__u8 ctx_alg;
	__u16 ctx_len;
	__u32 ctx_sid;
	char ctx_str[0];
};

struct xfrm_user_sec_ctx___2 {
	__u16 len;
	__u16 exttype;
	__u8 ctx_alg;
	__u8 ctx_doi;
	__u16 ctx_len;
};

struct security_hook_list___3 {
	struct hlist_node list;
	struct hlist_head *head;
	union security_list_options___3 hook;
	char *lsm;
};

struct node___169 {
	struct device___204 dev;
};

struct kernel_param_ops___191 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___191 *);
	int (*get)(char *, const struct kernel_param___191 *);
	void (*free)(void *);
};

struct kparam_array___191;

struct kernel_param___191 {
	const char *name;
	struct module___194 *mod;
	const struct kernel_param_ops___191 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___191 *arr;
	};
};

struct kparam_array___191 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___191 *ops;
	void *elem;
};

struct module_attribute___191 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___191 *, struct module_kobject___191 *, char *);
	ssize_t (*store)(struct module_attribute___191 *, struct module_kobject___191 *, const char *, size_t);
	void (*setup)(struct module___194 *, const char *);
	int (*test)(struct module___194 *);
	void (*free)(struct module___194 *);
};

struct trace_event_class___120;

struct trace_event_call___120 {
	struct list_head list;
	struct trace_event_class___120 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___25 *prog_array;
	int (*perf_perm)(struct trace_event_call___120 *, struct perf_event___127 *);
};

struct crypto_async_request___5;

typedef void (*crypto_completion_t___5)(struct crypto_async_request___5 *, int);

struct crypto_tfm___5;

struct crypto_async_request___5 {
	struct list_head list;
	crypto_completion_t___5 complete;
	void *data;
	struct crypto_tfm___5 *tfm;
	u32 flags;
};

struct crypto_ablkcipher___5;

struct ablkcipher_request___5;

struct ablkcipher_tfm___5 {
	int (*setkey)(struct crypto_ablkcipher___5 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___5 *);
	int (*decrypt)(struct ablkcipher_request___5 *);
	struct crypto_ablkcipher___5 *base;
	unsigned int ivsize;
	unsigned int reqsize;
};

struct blkcipher_desc___5;

struct blkcipher_tfm___5 {
	void *iv;
	int (*setkey)(struct crypto_tfm___5 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___5 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___5 *, struct scatterlist *, struct scatterlist *, unsigned int);
};

struct cipher_tfm___5 {
	int (*cit_setkey)(struct crypto_tfm___5 *, const u8 *, unsigned int);
	void (*cit_encrypt_one)(struct crypto_tfm___5 *, u8 *, const u8 *);
	void (*cit_decrypt_one)(struct crypto_tfm___5 *, u8 *, const u8 *);
};

struct compress_tfm___5 {
	int (*cot_compress)(struct crypto_tfm___5 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*cot_decompress)(struct crypto_tfm___5 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___5;

struct crypto_tfm___5 {
	u32 crt_flags;
	union {
		struct ablkcipher_tfm___5 ablkcipher;
		struct blkcipher_tfm___5 blkcipher;
		struct cipher_tfm___5 cipher;
		struct compress_tfm___5 compress;
	} crt_u;
	void (*exit)(struct crypto_tfm___5 *);
	struct crypto_alg___5 *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct ablkcipher_request___5 {
	struct crypto_async_request___5 base;
	unsigned int nbytes;
	void *info;
	struct scatterlist *src;
	struct scatterlist *dst;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_blkcipher___5;

struct blkcipher_desc___5 {
	struct crypto_blkcipher___5 *tfm;
	void *info;
	u32 flags;
};

struct crypto_blkcipher___5 {
	struct crypto_tfm___5 base;
};

struct ablkcipher_alg___5 {
	int (*setkey)(struct crypto_ablkcipher___5 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___5 *);
	int (*decrypt)(struct ablkcipher_request___5 *);
	int (*givencrypt)(struct skcipher_givcrypt_request *);
	int (*givdecrypt)(struct skcipher_givcrypt_request *);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct crypto_ablkcipher___5 {
	struct crypto_tfm___5 base;
};

struct blkcipher_alg___5 {
	int (*setkey)(struct crypto_tfm___5 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___5 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___5 *, struct scatterlist *, struct scatterlist *, unsigned int);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct cipher_alg___5 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___5 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___5 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___5 *, u8 *, const u8 *);
};

struct compress_alg___5 {
	int (*coa_compress)(struct crypto_tfm___5 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___5 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___5 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type *cra_type;
	union {
		struct ablkcipher_alg___5 ablkcipher;
		struct blkcipher_alg___5 blkcipher;
		struct cipher_alg___5 cipher;
		struct compress_alg___5 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___5 *);
	void (*cra_exit)(struct crypto_tfm___5 *);
	void (*cra_destroy)(struct crypto_alg___5 *);
	struct module___194 *cra_module;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct crypto_cipher {
	struct crypto_tfm___5 base;
};

struct crypto_shash___3 {
	unsigned int descsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_tfm___5 base;
};

struct perf_cpu_context___127;

struct pmu___127 {
	struct list_head entry;
	struct module___194 *module;
	struct device___204 *dev;
	const struct attribute_group___206 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___127 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___127 *);
	void (*pmu_disable)(struct pmu___127 *);
	int (*event_init)(struct perf_event___127 *);
	void (*event_mapped)(struct perf_event___127 *, struct mm_struct___240 *);
	void (*event_unmapped)(struct perf_event___127 *, struct mm_struct___240 *);
	int (*add)(struct perf_event___127 *, int);
	void (*del)(struct perf_event___127 *, int);
	void (*start)(struct perf_event___127 *, int);
	void (*stop)(struct perf_event___127 *, int);
	void (*read)(struct perf_event___127 *);
	void (*start_txn)(struct pmu___127 *, unsigned int);
	int (*commit_txn)(struct pmu___127 *);
	void (*cancel_txn)(struct pmu___127 *);
	int (*event_idx)(struct perf_event___127 *);
	void (*sched_task)(struct perf_event_context___127 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___127 *);
	int (*filter_match)(struct perf_event___127 *);
	int (*check_period)(struct perf_event___127 *, u64);
};

struct perf_cpu_context___127 {
	struct perf_event_context___127 ctx;
	struct perf_event_context___127 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___127 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___127 {
	struct cgroup_subsys_state___186 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___120 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___120 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___120 *);
	struct list_head * (*get_fields)(struct trace_event_call___120 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___120 *);
};

struct socket_wq___16 {
	wait_queue_head_t wait;
	struct fasync_struct___239 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

typedef int (*sk_read_actor_t___15)(read_descriptor_t *, struct sk_buff___30 *, unsigned int, size_t);

struct proto_ops___16 {
	int family;
	struct module___194 *owner;
	int (*release)(struct socket___17 *);
	int (*bind)(struct socket___17 *, struct sockaddr *, int);
	int (*connect)(struct socket___17 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___17 *, struct socket___17 *);
	int (*accept)(struct socket___17 *, struct socket___17 *, int, bool);
	int (*getname)(struct socket___17 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___240 *, struct socket___17 *, struct poll_table_struct___148 *);
	int (*ioctl)(struct socket___17 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___17 *, int);
	int (*shutdown)(struct socket___17 *, int);
	int (*setsockopt)(struct socket___17 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___17 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___17 *, struct msghdr___17 *, size_t);
	int (*recvmsg)(struct socket___17 *, struct msghdr___17 *, size_t, int);
	int (*mmap)(struct file___240 *, struct socket___17 *, struct vm_area_struct___241 *);
	ssize_t (*sendpage)(struct socket___17 *, struct page___241 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___17 *, loff_t *, struct pipe_inode_info___50 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___17 *, int);
	int (*peek_len)(struct socket___17 *);
	int (*read_sock)(struct sock___17 *, read_descriptor_t *, sk_read_actor_t___15);
	int (*sendpage_locked)(struct sock___17 *, struct page___241 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___17 *, struct msghdr___17 *, size_t);
	int (*set_rcvlowat)(struct sock___17 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct sockaddr_in6 {
	short unsigned int sin6_family;
	__be16 sin6_port;
	__be32 sin6_flowinfo;
	struct in6_addr sin6_addr;
	__u32 sin6_scope_id;
};

struct pipe_buf_operations___50;

struct pipe_buffer___50 {
	struct page___241 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___50 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___50 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___50 *, struct pipe_buffer___50 *);
	void (*release)(struct pipe_inode_info___50 *, struct pipe_buffer___50 *);
	int (*steal)(struct pipe_inode_info___50 *, struct pipe_buffer___50 *);
	union {
		bool (*get)(struct pipe_inode_info___50 *, struct pipe_buffer___50 *);
		struct {
			void (*get)(struct pipe_inode_info___50 *, struct pipe_buffer___50 *);
		} __UNIQUE_ID_rh_kabi_hide53;
		union {		};
	};
};

struct nf_conntrack {
	atomic_t use;
};

struct nf_bridge_info___26 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___26 = 0,
		BRNF_PROTO_8021Q___26 = 1,
		BRNF_PROTO_PPPOE___26 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___30 *physindev;
	struct net_device___30 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

struct in_addr {
	__be32 s_addr;
};

struct sockaddr_in {
	__kernel_sa_family_t sin_family;
	__be16 sin_port;
	struct in_addr sin_addr;
	unsigned char __pad[8];
};

struct ethtool_ops___26 {
	int (*get_settings)(struct net_device___30 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___30 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___30 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___30 *);
	void (*get_regs)(struct net_device___30 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___30 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___30 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___30 *);
	void (*set_msglevel)(struct net_device___30 *, u32);
	int (*nway_reset)(struct net_device___30 *);
	u32 (*get_link)(struct net_device___30 *);
	int (*get_eeprom_len)(struct net_device___30 *);
	int (*get_eeprom)(struct net_device___30 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___30 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___30 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___30 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___30 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___30 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___30 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___30 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___30 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___30 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___30 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___30 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___30 *);
	void (*complete)(struct net_device___30 *);
	u32 (*get_priv_flags)(struct net_device___30 *);
	int (*set_priv_flags)(struct net_device___30 *, u32);
	int (*get_sset_count)(struct net_device___30 *, int);
	int (*get_rxnfc)(struct net_device___30 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___30 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___30 *, struct ethtool_flash *);
	int (*reset)(struct net_device___30 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___30 *);
	u32 (*get_rxfh_indir_size)(struct net_device___30 *);
	int (*get_rxfh)(struct net_device___30 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___30 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___30 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___30 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___30 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___30 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___30 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___30 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___30 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___30 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___30 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___30 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___30 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___30 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___30 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___30 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___30 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___30 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___30 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___30 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide56;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___30 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___30 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide57;
		union {		};
	};
	int (*get_fecparam)(struct net_device___30 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___30 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___30 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___30 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide58;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___30 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide59;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___26;

struct inet_frags___26 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___26 *, const void *);
	void (*destructor)(struct inet_frag_queue___26 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___26 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___30 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___30 *fragments_tail;
	struct sk_buff___30 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___26 *net;
	struct callback_head rcu;
};

struct inet_listen_hashbucket {
	spinlock_t lock;
	unsigned int count;
	struct hlist_head head;
};

struct inet_ehash_bucket;

struct inet_bind_hashbucket;

struct inet_hashinfo {
	struct inet_ehash_bucket *ehash;
	spinlock_t *ehash_locks;
	unsigned int ehash_mask;
	unsigned int ehash_locks_mask;
	struct kmem_cache *bind_bucket_cachep;
	struct inet_bind_hashbucket *bhash;
	unsigned int bhash_size;
	unsigned int lhash2_mask;
	struct inet_listen_hashbucket *lhash2;
	long: 64;
	struct inet_listen_hashbucket listening_hash[32];
};

struct ip_ra_chain___5 {
	struct ip_ra_chain___5 *next;
	struct sock___17 *sk;
	union {
		void (*destructor)(struct sock___17 *);
		struct sock___17 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___15;

struct fib_lookup_arg___15;

struct fib_rules_ops___15 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___15 *, struct flowi *, int, struct fib_lookup_arg___15 *);
	bool (*suppress)(struct fib_rule___15 *, struct fib_lookup_arg___15 *);
	int (*match)(struct fib_rule___15 *, struct flowi *, int);
	int (*configure)(struct fib_rule___15 *, struct sk_buff___30 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___15 *);
	int (*compare)(struct fib_rule___15 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___15 *, struct sk_buff___30 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___15 *);
	void (*flush_cache)(struct fib_rules_ops___15 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___194 *owner;
	struct net___38 *fro_net;
	struct callback_head rcu;
};

struct tcp_congestion_ops___2 {
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___17 *);
	void (*release)(struct sock___17 *);
	u32 (*ssthresh)(struct sock___17 *);
	void (*cong_avoid)(struct sock___17 *, u32, u32);
	void (*set_state)(struct sock___17 *, u8);
	void (*cwnd_event)(struct sock___17 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___17 *, u32);
	u32 (*undo_cwnd)(struct sock___17 *);
	void (*pkts_acked)(struct sock___17 *, const struct ack_sample *);
	u32 (*min_tso_segs)(struct sock___17 *);
	u32 (*sndbuf_expand)(struct sock___17 *);
	void (*cong_control)(struct sock___17 *, const struct rate_sample *);
	size_t (*get_info)(struct sock___17 *, u32, int *, union tcp_cc_info *);
	char name[16];
	struct module___194 *owner;
};

struct tcp_fastopen_context___2 {
	struct crypto_cipher *tfm;
	__u8 key[16];
	struct callback_head rcu;
};

struct fib_notifier_ops___15 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___38 *);
	int (*fib_dump)(struct net___38 *, struct notifier_block *);
	struct module___194 *owner;
	struct callback_head rcu;
};

struct dst_entry___16 {
	struct net_device___30 *dev;
	struct dst_ops___36 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___30 *);
	int (*output)(struct net___38 *, struct sock___17 *, struct sk_buff___30 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___15;

struct neigh_parms___16;

struct neigh_ops___15;

struct neighbour___16 {
	struct neighbour___16 *next;
	struct neigh_table___15 *tbl;
	struct neigh_parms___16 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___26 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___16 *, struct sk_buff___30 *);
	const struct neigh_ops___15 *ops;
	struct callback_head rcu;
	struct net_device___30 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct nf_hook_state;

typedef unsigned int nf_hookfn(void *, struct sk_buff___30 *, const struct nf_hook_state *);

struct nf_hook_entry {
	nf_hookfn *hook;
	void *priv;
};

struct nf_hook_entries {
	u16 num_hook_entries;
	struct nf_hook_entry hooks[0];
};

enum ip_conntrack_info {
	IP_CT_ESTABLISHED = 0,
	IP_CT_RELATED = 1,
	IP_CT_NEW = 2,
	IP_CT_IS_REPLY = 3,
	IP_CT_ESTABLISHED_REPLY = 3,
	IP_CT_RELATED_REPLY = 4,
	IP_CT_NUMBER = 5,
	IP_CT_UNTRACKED = 7,
};

struct pernet_operations___27 {
	struct list_head list;
	int (*init)(struct net___38 *);
	void (*exit)(struct net___38 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___26 {
	int (*ieee_getets)(struct net_device___30 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___30 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___30 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___30 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___30 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___30 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___30 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___30 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___30 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___30 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___30 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___30 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___30 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___30 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___30 *);
	u8 (*setstate)(struct net_device___30 *, u8);
	void (*getpermhwaddr)(struct net_device___30 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___30 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___30 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___30 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___30 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___30 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___30 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___30 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___30 *, int, u8 *);
	void (*setpfccfg)(struct net_device___30 *, int, u8);
	void (*getpfccfg)(struct net_device___30 *, int, u8 *);
	u8 (*setall)(struct net_device___30 *);
	u8 (*getcap)(struct net_device___30 *, int, u8 *);
	int (*getnumtcs)(struct net_device___30 *, int, u8 *);
	int (*setnumtcs)(struct net_device___30 *, int, u8);
	u8 (*getpfcstate)(struct net_device___30 *);
	void (*setpfcstate)(struct net_device___30 *, u8);
	void (*getbcncfg)(struct net_device___30 *, int, u32 *);
	void (*setbcncfg)(struct net_device___30 *, int, u32);
	void (*getbcnrp)(struct net_device___30 *, int, u8 *);
	void (*setbcnrp)(struct net_device___30 *, int, u8);
	int (*setapp)(struct net_device___30 *, u8, u16, u8);
	int (*getapp)(struct net_device___30 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___30 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___30 *, int, u8);
	u8 (*getdcbx)(struct net_device___30 *);
	u8 (*setdcbx)(struct net_device___30 *, u8);
	int (*peer_getappinfo)(struct net_device___30 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___30 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___30 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___30 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___30 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___30 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct xdp_rxq_info___26 {
	struct net_device___30 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___26 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___30 *dev_rx;
};

struct netlink_callback___26 {
	struct sk_buff___30 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___26 *);
	int (*dump)(struct sk_buff___30 *, struct netlink_callback___26 *);
	int (*done)(struct netlink_callback___26 *);
	void *data;
	struct module___194 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___26 {
	int (*create)(struct sk_buff___30 *, struct net_device___30 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___30 *, unsigned char *);
	int (*cache)(const struct neighbour___16 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___30 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___26 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___26 *, int);
	int poll_owner;
	struct net_device___30 *dev;
	struct sk_buff___30 *gro_list;
	struct sk_buff___30 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___26 {
	struct net_device___30 *dev;
	struct Qdisc___25 *qdisc;
	struct Qdisc___25 *qdisc_sleeping;
	struct kobject___228 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___30 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide60;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___25 {
	struct sk_buff___30 *head;
	struct sk_buff___30 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___25;

struct Qdisc___25 {
	int (*enqueue)(struct sk_buff___30 *, struct Qdisc___25 *, struct sk_buff___30 **);
	struct sk_buff___30 * (*dequeue)(struct Qdisc___25 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___25 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___26 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___26 gso_skb;
	struct qdisc_skb_head___25 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___25 *next_sched;
	struct sk_buff_head___26 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___26 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___228 kobj;
	struct net_device___30 *dev;
	long: 64;
	struct xdp_rxq_info___26 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide61;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___26)(struct net_device___30 *, struct sk_buff___30 *, struct net_device___30 *);

struct netdev_bpf___26 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___25 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___25 *prog;
			const struct bpf_prog_offload_ops___25 *ops;
		} verifier;
		struct {
			struct bpf_prog___25 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___26 *offmap;
		};
		struct {
			struct xdp_umem *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___26 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___30 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___26 {
	int (*tls_dev_add)(struct net_device___30 *, struct sock___17 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___30 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___30 *, struct sock___17 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide62;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___26 {
	int (*ndo_init)(struct net_device___30 *);
	void (*ndo_uninit)(struct net_device___30 *);
	int (*ndo_open)(struct net_device___30 *);
	int (*ndo_stop)(struct net_device___30 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___30 *, struct net_device___30 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___30 *, struct net_device___30 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___30 *, struct sk_buff___30 *, struct net_device___30 *, select_queue_fallback_t___26);
	void (*ndo_change_rx_flags)(struct net_device___30 *, int);
	void (*ndo_set_rx_mode)(struct net_device___30 *);
	int (*ndo_set_mac_address)(struct net_device___30 *, void *);
	int (*ndo_validate_addr)(struct net_device___30 *);
	int (*ndo_do_ioctl)(struct net_device___30 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___30 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___30 *, int);
	int (*ndo_neigh_setup)(struct net_device___30 *, struct neigh_parms___16 *);
	void (*ndo_tx_timeout)(struct net_device___30 *);
	void (*ndo_get_stats64)(struct net_device___30 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___30 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___30 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___30 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___30 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___30 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___30 *);
	int (*ndo_netpoll_setup)(struct net_device___30 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___30 *);
	int (*ndo_set_vf_mac)(struct net_device___30 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___30 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___30 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___30 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___30 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___30 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___30 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___30 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___30 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___30 *, int, struct sk_buff___30 *);
	int (*ndo_set_vf_guid)(struct net_device___30 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___30 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___30 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___30 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___30 *, const struct sk_buff___30 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___30 *, struct net_device___30 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___30 *, struct net_device___30 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___30 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___30 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___30 *, struct neighbour___16 *);
	void (*ndo_neigh_destroy)(struct net_device___30 *, struct neighbour___16 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___30 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___30 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide63;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___30 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___30 *, struct netlink_callback___26 *, struct net_device___30 *, struct net_device___30 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___30 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___30 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide64;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___30 *, u32, u32, struct net_device___30 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___30 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___30 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___30 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___30 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___30 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___30 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___30 *, struct net_device___30 *);
	void (*ndo_dfwd_del_station)(struct net_device___30 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___30 *);
	int (*ndo_set_tx_maxrate)(struct net_device___30 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___30 *);
	int (*ndo_change_proto_down)(struct net_device___30 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___30 *, struct sk_buff___30 *);
	void (*ndo_set_rx_headroom)(struct net_device___30 *, int);
	int (*ndo_bpf)(struct net_device___30 *, struct netdev_bpf___26 *);
	int (*ndo_xdp_xmit)(struct net_device___30 *, int, struct xdp_frame___26 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___30 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___30 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide65;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___16 {
	possible_net_t___27 net;
	struct net_device___30 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___16 *);
	void (*neigh_cleanup)(struct neighbour___16 *);
	struct neigh_table___15 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___16 {
	u32 (*l3mdev_fib_table)(const struct net_device___30 *);
	struct sk_buff___30 * (*l3mdev_l3_rcv)(struct net_device___30 *, struct sk_buff___30 *, u16);
	struct sk_buff___30 * (*l3mdev_l3_out)(struct net_device___30 *, struct sock___17 *, struct sk_buff___30 *, u16);
	struct dst_entry___16 * (*l3mdev_link_scope_lookup)(const struct net_device___30 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct ndisc_ops___9 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___30 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___30 *, struct neighbour___16 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___30 *, u8, struct neighbour___16 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___30 *, struct sk_buff___30 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___38 *, struct net_device___30 *, const struct prefix_info *, struct inet6_dev___9 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___8;

struct inet6_dev___9 {
	struct net_device___30 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___8 *mc_list;
	struct ifmcaddr6___8 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	u8 rndid[8];
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___16 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
};

struct tcf_proto___25;

struct mini_Qdisc___25 {
	struct tcf_proto___25 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___25 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___30 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___38 *, struct net_device___30 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___30 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___30 *, struct list_head *);
	size_t (*get_size)(const struct net_device___30 *);
	int (*fill_info)(struct sk_buff___30 *, const struct net_device___30 *);
	size_t (*get_xstats_size)(const struct net_device___30 *);
	int (*fill_xstats)(struct sk_buff___30 *, const struct net_device___30 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___30 *, struct net_device___30 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___30 *, const struct net_device___30 *);
	int (*fill_slave_info)(struct sk_buff___30 *, const struct net_device___30 *, const struct net_device___30 *);
	struct net___38 * (*get_link_net)(const struct net_device___30 *);
	size_t (*get_linkxstats_size)(const struct net_device___30 *, int);
	int (*fill_linkxstats)(struct sk_buff___30 *, const struct net_device___30 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___26 {
	struct list_head poll_list;
	struct sk_buff_head___26 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___26 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___25 *output_queue;
	struct Qdisc___25 **output_queue_tailp;
	struct sk_buff___30 *completion_queue;
	struct sk_buff_head___26 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___26 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___26 input_pkt_queue;
	struct napi_struct___26 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct nf_hook_state {
	unsigned int hook;
	u_int8_t pf;
	struct net_device___30 *in;
	struct net_device___30 *out;
	struct sock___17 *sk;
	struct net___38 *net;
	int (*okfn)(struct net___38 *, struct sock___17 *, struct sk_buff___30 *);
};

struct nf_hook_ops {
	nf_hookfn *hook;
	struct net_device___30 *dev;
	void *priv;
	u_int8_t pf;
	unsigned int hooknum;
	int priority;
};

struct nf_conn;

enum nf_nat_manip_type;

struct nf_nat_hook {
	int (*parse_nat_setup)(struct nf_conn *, enum nf_nat_manip_type, const struct nlattr *);
	void (*decode_session)(struct sk_buff___30 *, struct flowi *);
	unsigned int (*manip_pkt)(struct sk_buff___30 *, struct nf_conn *, enum nf_nat_manip_type, enum ip_conntrack_dir);
};

struct nf_conntrack_zone {
	u16 id;
	u8 flags;
	u8 dir;
};

struct nf_conntrack_tuple;

struct nf_ct_hook {
	int (*update)(struct net___38 *, struct sk_buff___30 *);
	void (*destroy)(struct nf_conntrack *);
	bool (*get_tuple_skb)(struct nf_conntrack_tuple *, const struct sk_buff___30 *);
};

struct nfnl_ct_hook {
	struct nf_conn * (*get_ct)(const struct sk_buff___30 *, enum ip_conntrack_info *);
	size_t (*build_size)(const struct nf_conn *);
	int (*build)(struct sk_buff___30 *, struct nf_conn *, enum ip_conntrack_info, u_int16_t, u_int16_t);
	int (*parse)(const struct nlattr *, struct nf_conn *);
	int (*attach_expect)(const struct nlattr *, struct nf_conn *, u32, u32);
	void (*seq_adjust)(struct sk_buff___30 *, struct nf_conn *, enum ip_conntrack_info, s32);
};

enum nf_ip_hook_priorities {
	NF_IP_PRI_FIRST = 2147483648,
	NF_IP_PRI_RAW_BEFORE_DEFRAG = 4294966846,
	NF_IP_PRI_CONNTRACK_DEFRAG = 4294966896,
	NF_IP_PRI_RAW = 4294966996,
	NF_IP_PRI_SELINUX_FIRST = 4294967071,
	NF_IP_PRI_CONNTRACK = 4294967096,
	NF_IP_PRI_MANGLE = 4294967146,
	NF_IP_PRI_NAT_DST = 4294967196,
	NF_IP_PRI_FILTER = 0,
	NF_IP_PRI_SECURITY = 50,
	NF_IP_PRI_NAT_SRC = 100,
	NF_IP_PRI_SELINUX_LAST = 225,
	NF_IP_PRI_CONNTRACK_HELPER = 300,
	NF_IP_PRI_CONNTRACK_CONFIRM = 2147483647,
	NF_IP_PRI_LAST = 2147483647,
};

enum nf_ip6_hook_priorities {
	NF_IP6_PRI_FIRST = 2147483648,
	NF_IP6_PRI_RAW_BEFORE_DEFRAG = 4294966846,
	NF_IP6_PRI_CONNTRACK_DEFRAG = 4294966896,
	NF_IP6_PRI_RAW = 4294966996,
	NF_IP6_PRI_SELINUX_FIRST = 4294967071,
	NF_IP6_PRI_CONNTRACK = 4294967096,
	NF_IP6_PRI_MANGLE = 4294967146,
	NF_IP6_PRI_NAT_DST = 4294967196,
	NF_IP6_PRI_FILTER = 0,
	NF_IP6_PRI_SECURITY = 50,
	NF_IP6_PRI_NAT_SRC = 100,
	NF_IP6_PRI_SELINUX_LAST = 225,
	NF_IP6_PRI_CONNTRACK_HELPER = 300,
	NF_IP6_PRI_LAST = 2147483647,
};

struct nf_queue_entry___2;

struct nf_ipv6_ops {
	int (*chk_addr)(struct net___38 *, const struct in6_addr *, const struct net_device___30 *, int);
	void (*route_input)(struct sk_buff___30 *);
	int (*fragment)(struct net___38 *, struct sock___17 *, struct sk_buff___30 *, int (*)(struct net___38 *, struct sock___17 *, struct sk_buff___30 *));
	__sum16 (*checksum)(struct sk_buff___30 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___30 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___38 *, struct dst_entry___16 **, struct flowi *, bool);
	int (*reroute)(struct sk_buff___30 *, const struct nf_queue_entry___2 *);
};

struct tty_operations___20 {
	struct tty_struct___20 * (*lookup)(struct tty_driver___20 *, struct file___240 *, int);
	int (*install)(struct tty_driver___20 *, struct tty_struct___20 *);
	void (*remove)(struct tty_driver___20 *, struct tty_struct___20 *);
	int (*open)(struct tty_struct___20 *, struct file___240 *);
	void (*close)(struct tty_struct___20 *, struct file___240 *);
	void (*shutdown)(struct tty_struct___20 *);
	void (*cleanup)(struct tty_struct___20 *);
	int (*write)(struct tty_struct___20 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___20 *, unsigned char);
	void (*flush_chars)(struct tty_struct___20 *);
	int (*write_room)(struct tty_struct___20 *);
	int (*chars_in_buffer)(struct tty_struct___20 *);
	int (*ioctl)(struct tty_struct___20 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___20 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___20 *, struct ktermios *);
	void (*throttle)(struct tty_struct___20 *);
	void (*unthrottle)(struct tty_struct___20 *);
	void (*stop)(struct tty_struct___20 *);
	void (*start)(struct tty_struct___20 *);
	void (*hangup)(struct tty_struct___20 *);
	int (*break_ctl)(struct tty_struct___20 *, int);
	void (*flush_buffer)(struct tty_struct___20 *);
	void (*set_ldisc)(struct tty_struct___20 *);
	void (*wait_until_sent)(struct tty_struct___20 *, int);
	void (*send_xchar)(struct tty_struct___20 *, char);
	int (*tiocmget)(struct tty_struct___20 *);
	int (*tiocmset)(struct tty_struct___20 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___20 *, struct winsize *);
	int (*set_termiox)(struct tty_struct___20 *, struct termiox *);
	int (*get_icount)(struct tty_struct___20 *, struct serial_icounter_struct *);
	void (*show_fdinfo)(struct tty_struct___20 *, struct seq_file___216 *);
	int (*poll_init)(struct tty_driver___20 *, int, char *);
	int (*poll_get_char)(struct tty_driver___20 *, int);
	void (*poll_put_char)(struct tty_driver___20 *, int, char);
	int (*proc_show)(struct seq_file___216 *, void *);
};

struct tty_driver___20 {
	int magic;
	struct kref kref;
	struct cdev___39 **cdevs;
	struct module___194 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___20 *other;
	struct tty_struct___20 **ttys;
	struct tty_port___20 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___20 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___20;

struct tty_port_client_operations___20;

struct tty_port___20 {
	struct tty_bufhead buf;
	struct tty_struct___20 *tty;
	struct tty_struct___20 *itty;
	const struct tty_port_operations___20 *ops;
	const struct tty_port_client_operations___20 *client_ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	unsigned char low_latency: 1;
	struct mutex mutex;
	struct mutex buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
	void *client_data;
};

struct tty_ldisc_ops___20 {
	int magic;
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___20 *);
	void (*close)(struct tty_struct___20 *);
	void (*flush_buffer)(struct tty_struct___20 *);
	ssize_t (*read)(struct tty_struct___20 *, struct file___240 *, unsigned char *, size_t);
	ssize_t (*write)(struct tty_struct___20 *, struct file___240 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___20 *, struct file___240 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___20 *, struct file___240 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___20 *, struct ktermios *);
	__poll_t (*poll)(struct tty_struct___20 *, struct file___240 *, struct poll_table_struct___148 *);
	int (*hangup)(struct tty_struct___20 *);
	void (*receive_buf)(struct tty_struct___20 *, const unsigned char *, char *, int);
	void (*write_wakeup)(struct tty_struct___20 *);
	void (*dcd_change)(struct tty_struct___20 *, unsigned int);
	int (*receive_buf2)(struct tty_struct___20 *, const unsigned char *, char *, int);
	struct module___194 *owner;
	int refcount;
};

struct tty_ldisc___20 {
	struct tty_ldisc_ops___20 *ops;
	struct tty_struct___20 *tty;
};

struct tty_port_operations___20 {
	int (*carrier_raised)(struct tty_port___20 *);
	void (*dtr_rts)(struct tty_port___20 *, int);
	void (*shutdown)(struct tty_port___20 *);
	int (*activate)(struct tty_port___20 *, struct tty_struct___20 *);
	void (*destruct)(struct tty_port___20 *);
};

struct tty_port_client_operations___20 {
	int (*receive_buf)(struct tty_port___20 *, const unsigned char *, const unsigned char *, size_t);
	void (*write_wakeup)(struct tty_port___20 *);
};

struct tty_file_private {
	struct tty_struct___20 *tty;
	struct file___240 *file;
	struct list_head list;
};

struct gnet_dump___25 {
	spinlock_t *lock;
	struct sk_buff___30 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___25;

struct Qdisc_ops___25 {
	struct Qdisc_ops___25 *next;
	const struct Qdisc_class_ops___25 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___30 *, struct Qdisc___25 *, struct sk_buff___30 **);
	struct sk_buff___30 * (*dequeue)(struct Qdisc___25 *);
	struct sk_buff___30 * (*peek)(struct Qdisc___25 *);
	int (*init)(struct Qdisc___25 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___25 *);
	void (*destroy)(struct Qdisc___25 *);
	int (*change)(struct Qdisc___25 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___25 *);
	int (*change_tx_queue_len)(struct Qdisc___25 *, unsigned int);
	int (*dump)(struct Qdisc___25 *, struct sk_buff___30 *);
	int (*dump_stats)(struct Qdisc___25 *, struct gnet_dump___25 *);
	void (*ingress_block_set)(struct Qdisc___25 *, u32);
	void (*egress_block_set)(struct Qdisc___25 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___25 *);
	u32 (*egress_block_get)(struct Qdisc___25 *);
	struct module___194 *owner;
};

struct tcf_block___25;

struct Qdisc_class_ops___25 {
	unsigned int flags;
	struct netdev_queue___26 * (*select_queue)(struct Qdisc___25 *, struct tcmsg *);
	int (*graft)(struct Qdisc___25 *, long unsigned int, struct Qdisc___25 *, struct Qdisc___25 **, struct netlink_ext_ack *);
	struct Qdisc___25 * (*leaf)(struct Qdisc___25 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___25 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___25 *, u32);
	int (*change)(struct Qdisc___25 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___25 *, long unsigned int);
	void (*walk)(struct Qdisc___25 *, struct qdisc_walker *);
	struct tcf_block___25 * (*tcf_block)(struct Qdisc___25 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___25 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___25 *, long unsigned int);
	int (*dump)(struct Qdisc___25 *, long unsigned int, struct sk_buff___30 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___25 *, long unsigned int, struct gnet_dump___25 *);
};

struct tcf_chain___25;

struct tcf_block___25 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___38 *net;
	struct Qdisc___25 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___25 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___25;

struct tcf_proto_ops___25;

struct tcf_proto___25 {
	struct tcf_proto___25 *next;
	void *root;
	int (*classify)(struct sk_buff___30 *, const struct tcf_proto___25 *, struct tcf_result___25 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___25 *ops;
	struct tcf_chain___25 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___25 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___25 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___25 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___30 *, const struct tcf_proto___25 *, struct tcf_result___25 *);
	int (*init)(struct tcf_proto___25 *);
	void (*destroy)(struct tcf_proto___25 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___25 *, u32);
	void (*put)(struct tcf_proto___25 *, void *);
	int (*change)(struct net___38 *, struct sk_buff___30 *, struct tcf_proto___25 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___25 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___25 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___25 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___38 *, struct tcf_chain___25 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___38 *, struct tcf_proto___25 *, void *, struct sk_buff___30 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___30 *, struct net___38 *, void *);
	struct module___194 *owner;
	int flags;
};

struct tcf_chain___25 {
	struct mutex filter_chain_lock;
	struct tcf_proto___25 *filter_chain;
	struct list_head list;
	struct tcf_block___25 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___25 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___15 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___25 *prog;
};

struct bpf_redirect_info___25 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___185 *map;
	struct bpf_map___185 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___15;

struct neigh_hash_table___15;

struct neigh_table___15 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___30 *, __u32 *);
	bool (*key_eq)(const struct neighbour___16 *, const void *);
	int (*constructor)(struct neighbour___16 *);
	int (*pconstructor)(struct pneigh_entry___15 *);
	void (*pdestructor)(struct pneigh_entry___15 *);
	void (*proxy_redo)(struct sk_buff___30 *);
	char *id;
	struct neigh_parms___16 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___26 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___15 *nht;
	struct pneigh_entry___15 **phash_buckets;
};

struct neigh_ops___15 {
	int family;
	void (*solicit)(struct neighbour___16 *, struct sk_buff___30 *);
	void (*error_report)(struct neighbour___16 *, struct sk_buff___30 *);
	int (*output)(struct neighbour___16 *, struct sk_buff___30 *);
	int (*connected_output)(struct neighbour___16 *, struct sk_buff___30 *);
};

struct pneigh_entry___15 {
	struct pneigh_entry___15 *next;
	possible_net_t___27 net;
	struct net_device___30 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___15 {
	struct neighbour___16 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___15 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___15 *ctarget;
	struct net___38 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___15 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___15 *rule;
	u32 table;
	int flags;
};

struct timewait_sock_ops___9;

struct proto___15 {
	void (*close)(struct sock___17 *, long int);
	int (*pre_connect)(struct sock___17 *, struct sockaddr *, int);
	int (*connect)(struct sock___17 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___17 *, int);
	struct sock___17 * (*accept)(struct sock___17 *, int, int *, bool);
	int (*ioctl)(struct sock___17 *, int, long unsigned int);
	int (*init)(struct sock___17 *);
	void (*destroy)(struct sock___17 *);
	void (*shutdown)(struct sock___17 *, int);
	int (*setsockopt)(struct sock___17 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___17 *, int, int, char *, int *);
	void (*keepalive)(struct sock___17 *, int);
	int (*sendmsg)(struct sock___17 *, struct msghdr___17 *, size_t);
	int (*recvmsg)(struct sock___17 *, struct msghdr___17 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___17 *, struct page___241 *, int, size_t, int);
	int (*bind)(struct sock___17 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___17 *, struct sk_buff___30 *);
	void (*release_cb)(struct sock___17 *);
	int (*hash)(struct sock___17 *);
	void (*unhash)(struct sock___17 *);
	void (*rehash)(struct sock___17 *);
	int (*get_port)(struct sock___17 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___17 *);
	bool (*stream_memory_read)(const struct sock___17 *);
	void (*enter_memory_pressure)(struct sock___17 *);
	void (*leave_memory_pressure)(struct sock___17 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___9 *rsk_prot;
	struct timewait_sock_ops___9 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___194 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___17 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct request_sock_ops___9 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___17 *, struct request_sock___9 *);
	void (*send_ack)(const struct sock___17 *, struct sk_buff___30 *, struct request_sock___9 *);
	void (*send_reset)(const struct sock___17 *, struct sk_buff___30 *);
	void (*destructor)(struct request_sock___9 *);
	void (*syn_ack_timeout)(const struct request_sock___9 *);
};

struct timewait_sock_ops___9 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___17 *, struct sock___17 *, void *);
	void (*twsk_destructor)(struct sock___17 *);
};

struct socket_alloc {
	struct socket___17 socket;
	struct inode___240 vfs_inode;
};

struct ip_options {
	__be32 faddr;
	__be32 nexthop;
	unsigned char optlen;
	unsigned char srr;
	unsigned char rr;
	unsigned char ts;
	unsigned char is_strictroute: 1;
	unsigned char srr_is_hit: 1;
	unsigned char is_changed: 1;
	unsigned char rr_needaddr: 1;
	unsigned char ts_needtime: 1;
	unsigned char ts_needaddr: 1;
	unsigned char router_alert;
	unsigned char cipso;
	unsigned char __pad2;
	unsigned char __data[0];
};

struct ip_options_rcu {
	struct callback_head rcu;
	struct ip_options opt;
};

struct ipv6_opt_hdr;

struct ipv6_rt_hdr;

struct ipv6_txoptions {
	refcount_t refcnt;
	int tot_len;
	__u16 opt_flen;
	__u16 opt_nflen;
	struct ipv6_opt_hdr *hopopt;
	struct ipv6_opt_hdr *dst0opt;
	struct ipv6_rt_hdr *srcrt;
	struct ipv6_opt_hdr *dst1opt;
	struct callback_head rcu;
};

struct inet_cork {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___16 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
	__u16 gso_size;
	u64 transmit_time;
};

struct inet_cork_full {
	struct inet_cork base;
	struct flowi fl;
};

struct ipv6_pinfo;

struct ip_mc_socklist;

struct inet_sock {
	struct sock___17 sk;
	struct ipv6_pinfo *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	__be16 inet_sport;
	__u16 inet_id;
	struct ip_options_rcu *inet_opt;
	int rx_dst_ifindex;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 bind_address_no_port: 1;
	__u8 defer_connect: 1;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full cork;
};

struct in6_pktinfo {
	struct in6_addr ipi6_addr;
	int ipi6_ifindex;
};

struct inet6_cork {
	struct ipv6_txoptions *opt;
	u8 hop_limit;
	u8 tclass;
};

struct ipv6_mc_socklist;

struct ipv6_ac_socklist;

struct ipv6_fl_socklist;

struct ipv6_pinfo {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
			__u16 recvfragsize: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 repflow: 1;
	__u16 pmtudisc: 3;
	__u16 padding: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u16 autoflowlabel: 1;
	__u16 autoflowlabel_set: 1;
	__u8 min_hopcount;
	__u8 tclass;
	__be32 rcv_flowinfo;
	__u32 dst_cookie;
	__u32 rx_dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___30 *pktoptions;
	struct sk_buff___30 *rxpmtu;
	struct inet6_cork cork;
};

struct icmp_err {
	int errno;
	unsigned int fatal: 1;
};

struct iphdr {
	__u8 ihl: 4;
	__u8 version: 4;
	__u8 tos;
	__be16 tot_len;
	__be16 id;
	__be16 frag_off;
	__u8 ttl;
	__u8 protocol;
	__sum16 check;
	__be32 saddr;
	__be32 daddr;
};

struct ipv6_rt_hdr {
	__u8 nexthdr;
	__u8 hdrlen;
	__u8 type;
	__u8 segments_left;
};

struct ipv6_opt_hdr {
	__u8 nexthdr;
	__u8 hdrlen;
};

struct ipv6hdr {
	__u8 priority: 4;
	__u8 version: 4;
	__u8 flow_lbl[3];
	__be16 payload_len;
	__u8 nexthdr;
	__u8 hop_limit;
	struct in6_addr saddr;
	struct in6_addr daddr;
};

struct tcphdr {
	__be16 source;
	__be16 dest;
	__be32 seq;
	__be32 ack_seq;
	__u16 res1: 4;
	__u16 doff: 4;
	__u16 fin: 1;
	__u16 syn: 1;
	__u16 rst: 1;
	__u16 psh: 1;
	__u16 ack: 1;
	__u16 urg: 1;
	__u16 ece: 1;
	__u16 cwr: 1;
	__be16 window;
	__sum16 check;
	__be16 urg_ptr;
};

struct udphdr {
	__be16 source;
	__be16 dest;
	__be16 len;
	__sum16 check;
};

struct inet6_skb_parm {
	int iif;
	__be16 ra;
	__u16 dst0;
	__u16 srcrt;
	__u16 dst1;
	__u16 lastopt;
	__u16 nhoff;
	__u16 flags;
	__u16 dsthao;
	__u16 frag_max_size;
};

struct ip6_sf_socklist;

struct ipv6_mc_socklist {
	struct in6_addr addr;
	int ifindex;
	struct ipv6_mc_socklist *next;
	rwlock_t sflock;
	unsigned int sfmode;
	struct ip6_sf_socklist *sflist;
	struct callback_head rcu;
};

struct ipv6_ac_socklist {
	struct in6_addr acl_addr;
	int acl_ifindex;
	struct ipv6_ac_socklist *acl_next;
};

struct ip6_flowlabel;

struct ipv6_fl_socklist {
	struct ipv6_fl_socklist *next;
	struct ip6_flowlabel *fl;
	struct callback_head rcu;
};

struct ip6_sf_socklist {
	unsigned int sl_max;
	unsigned int sl_count;
	struct in6_addr sl_addr[0];
};

struct ifmcaddr6___8 {
	struct in6_addr mca_addr;
	struct inet6_dev___9 *idev;
	struct ifmcaddr6___8 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ip6_ra_chain___8 {
	struct ip6_ra_chain___8 *next;
	struct sock___17 *sk;
	int sel;
	void (*destructor)(struct sock___17 *);
};

struct ip6_flowlabel {
	struct ip6_flowlabel *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___180 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___38 *fl_net;
};

struct inet_skb_parm {
	int iif;
	struct ip_options opt;
	u16 flags;
	u16 frag_max_size;
};

struct inet_ehash_bucket {
	struct hlist_nulls_head chain;
};

struct inet_bind_hashbucket {
	spinlock_t lock;
	struct hlist_head chain;
};

struct ack_sample {
	u32 pkts_acked;
	s32 rtt_us;
	u32 in_flight;
};

struct rate_sample {
	u64 prior_mstamp;
	u32 prior_delivered;
	s32 delivered;
	long int interval_us;
	long int rtt_us;
	int losses;
	u32 acked_sacked;
	u32 prior_in_flight;
	bool is_app_limited;
	bool is_retrans;
	bool is_ack_delayed;
};

struct netlbl_lsm_cache {
	refcount_t refcount;
	void (*free)(const void *);
	void *data;
};

struct netlbl_lsm_catmap {
	u32 startbit;
	u64 bitmap[4];
	struct netlbl_lsm_catmap *next;
};

struct netlbl_lsm_secattr {
	u32 flags;
	u32 type;
	char *domain;
	struct netlbl_lsm_cache *cache;
	struct {
		struct {
			struct netlbl_lsm_catmap *cat;
			u32 lvl;
		} mls;
		u32 secid;
	} attr;
};

struct dccp_hdr {
	__be16 dccph_sport;
	__be16 dccph_dport;
	__u8 dccph_doff;
	__u8 dccph_cscov: 4;
	__u8 dccph_ccval: 4;
	__sum16 dccph_checksum;
	__u8 dccph_x: 1;
	__u8 dccph_type: 4;
	__u8 dccph_reserved: 3;
	__u8 dccph_seq2;
	__be16 dccph_seq;
};

enum dccp_state {
	DCCP_OPEN = 1,
	DCCP_REQUESTING = 2,
	DCCP_LISTEN = 10,
	DCCP_RESPOND = 3,
	DCCP_ACTIVE_CLOSEREQ = 4,
	DCCP_PASSIVE_CLOSE = 8,
	DCCP_CLOSING = 11,
	DCCP_TIME_WAIT = 6,
	DCCP_CLOSED = 7,
	DCCP_NEW_SYN_RECV = 12,
	DCCP_PARTOPEN = 13,
	DCCP_PASSIVE_CLOSEREQ = 14,
	DCCP_MAX_STATES = 15,
};

typedef __s32 sctp_assoc_t;

enum sctp_msg_flags {
	MSG_NOTIFICATION = 32768,
};

struct sctp_initmsg {
	__u16 sinit_num_ostreams;
	__u16 sinit_max_instreams;
	__u16 sinit_max_attempts;
	__u16 sinit_max_init_timeo;
};

struct sctp_sndrcvinfo {
	__u16 sinfo_stream;
	__u16 sinfo_ssn;
	__u16 sinfo_flags;
	__u32 sinfo_ppid;
	__u32 sinfo_context;
	__u32 sinfo_timetolive;
	__u32 sinfo_tsn;
	__u32 sinfo_cumtsn;
	sctp_assoc_t sinfo_assoc_id;
};

struct sctp_rtoinfo {
	sctp_assoc_t srto_assoc_id;
	__u32 srto_initial;
	__u32 srto_max;
	__u32 srto_min;
};

struct sctp_assocparams {
	sctp_assoc_t sasoc_assoc_id;
	__u16 sasoc_asocmaxrxt;
	__u16 sasoc_number_peer_destinations;
	__u32 sasoc_peer_rwnd;
	__u32 sasoc_local_rwnd;
	__u32 sasoc_cookie_life;
};

struct sctp_paddrparams {
	sctp_assoc_t spp_assoc_id;
	struct __kernel_sockaddr_storage spp_address;
	__u32 spp_hbinterval;
	__u16 spp_pathmaxrxt;
	__u32 spp_pathmtu;
	__u32 spp_sackdelay;
	__u32 spp_flags;
	__u32 spp_ipv6_flowlabel;
	__u8 spp_dscp;
	char: 8;
} __attribute__((packed));

struct sctphdr {
	__be16 source;
	__be16 dest;
	__be32 vtag;
	__le32 checksum;
};

struct sctp_chunkhdr {
	__u8 type;
	__u8 flags;
	__be16 length;
};

enum sctp_cid {
	SCTP_CID_DATA = 0,
	SCTP_CID_INIT = 1,
	SCTP_CID_INIT_ACK = 2,
	SCTP_CID_SACK = 3,
	SCTP_CID_HEARTBEAT = 4,
	SCTP_CID_HEARTBEAT_ACK = 5,
	SCTP_CID_ABORT = 6,
	SCTP_CID_SHUTDOWN = 7,
	SCTP_CID_SHUTDOWN_ACK = 8,
	SCTP_CID_ERROR = 9,
	SCTP_CID_COOKIE_ECHO = 10,
	SCTP_CID_COOKIE_ACK = 11,
	SCTP_CID_ECN_ECNE = 12,
	SCTP_CID_ECN_CWR = 13,
	SCTP_CID_SHUTDOWN_COMPLETE = 14,
	SCTP_CID_AUTH = 15,
	SCTP_CID_I_DATA = 64,
	SCTP_CID_FWD_TSN = 192,
	SCTP_CID_ASCONF = 193,
	SCTP_CID_I_FWD_TSN = 194,
	SCTP_CID_ASCONF_ACK = 128,
	SCTP_CID_RECONF = 130,
};

struct sctp_paramhdr {
	__be16 type;
	__be16 length;
};

enum sctp_param {
	SCTP_PARAM_HEARTBEAT_INFO = 256,
	SCTP_PARAM_IPV4_ADDRESS = 1280,
	SCTP_PARAM_IPV6_ADDRESS = 1536,
	SCTP_PARAM_STATE_COOKIE = 1792,
	SCTP_PARAM_UNRECOGNIZED_PARAMETERS = 2048,
	SCTP_PARAM_COOKIE_PRESERVATIVE = 2304,
	SCTP_PARAM_HOST_NAME_ADDRESS = 2816,
	SCTP_PARAM_SUPPORTED_ADDRESS_TYPES = 3072,
	SCTP_PARAM_ECN_CAPABLE = 128,
	SCTP_PARAM_RANDOM = 640,
	SCTP_PARAM_CHUNKS = 896,
	SCTP_PARAM_HMAC_ALGO = 1152,
	SCTP_PARAM_SUPPORTED_EXT = 2176,
	SCTP_PARAM_FWD_TSN_SUPPORT = 192,
	SCTP_PARAM_ADD_IP = 448,
	SCTP_PARAM_DEL_IP = 704,
	SCTP_PARAM_ERR_CAUSE = 960,
	SCTP_PARAM_SET_PRIMARY = 1216,
	SCTP_PARAM_SUCCESS_REPORT = 1472,
	SCTP_PARAM_ADAPTATION_LAYER_IND = 1728,
	SCTP_PARAM_RESET_OUT_REQUEST = 3328,
	SCTP_PARAM_RESET_IN_REQUEST = 3584,
	SCTP_PARAM_RESET_TSN_REQUEST = 3840,
	SCTP_PARAM_RESET_RESPONSE = 4096,
	SCTP_PARAM_RESET_ADD_OUT_STREAMS = 4352,
	SCTP_PARAM_RESET_ADD_IN_STREAMS = 4608,
};

struct sctp_datahdr {
	__be32 tsn;
	__be16 stream;
	__be16 ssn;
	__u32 ppid;
	__u8 payload[0];
};

struct sctp_idatahdr {
	__be32 tsn;
	__be16 stream;
	__be16 reserved;
	__be32 mid;
	union {
		__u32 ppid;
		__be32 fsn;
	};
	__u8 payload[0];
};

struct sctp_inithdr {
	__be32 init_tag;
	__be32 a_rwnd;
	__be16 num_outbound_streams;
	__be16 num_inbound_streams;
	__be32 initial_tsn;
	__u8 params[0];
};

struct sctp_init_chunk {
	struct sctp_chunkhdr chunk_hdr;
	struct sctp_inithdr init_hdr;
};

struct sctp_ipv4addr_param {
	struct sctp_paramhdr param_hdr;
	struct in_addr addr;
};

struct sctp_ipv6addr_param {
	struct sctp_paramhdr param_hdr;
	struct in6_addr addr;
};

struct sctp_cookie_preserve_param {
	struct sctp_paramhdr param_hdr;
	__be32 lifespan_increment;
};

struct sctp_hostname_param {
	struct sctp_paramhdr param_hdr;
	uint8_t hostname[0];
};

struct sctp_supported_addrs_param {
	struct sctp_paramhdr param_hdr;
	__be16 types[0];
};

struct sctp_adaptation_ind_param {
	struct sctp_paramhdr param_hdr;
	__be32 adaptation_ind;
};

struct sctp_supported_ext_param {
	struct sctp_paramhdr param_hdr;
	__u8 chunks[0];
};

struct sctp_random_param {
	struct sctp_paramhdr param_hdr;
	__u8 random_val[0];
};

struct sctp_chunks_param {
	struct sctp_paramhdr param_hdr;
	__u8 chunks[0];
};

struct sctp_hmac_algo_param {
	struct sctp_paramhdr param_hdr;
	__be16 hmac_ids[0];
};

struct sctp_cookie_param {
	struct sctp_paramhdr p;
	__u8 body[0];
};

struct sctp_gap_ack_block {
	__be16 start;
	__be16 end;
};

union sctp_sack_variable {
	struct sctp_gap_ack_block gab;
	__be32 dup;
};

struct sctp_sackhdr {
	__be32 cum_tsn_ack;
	__be32 a_rwnd;
	__be16 num_gap_ack_blocks;
	__be16 num_dup_tsns;
	union sctp_sack_variable variable[0];
};

struct sctp_heartbeathdr {
	struct sctp_paramhdr info;
};

struct sctp_shutdownhdr {
	__be32 cum_tsn_ack;
};

struct sctp_errhdr {
	__be16 cause;
	__be16 length;
	__u8 variable[0];
};

struct sctp_ecnehdr {
	__be32 lowest_tsn;
};

struct sctp_cwrhdr {
	__be32 lowest_tsn;
};

struct sctp_fwdtsn_skip {
	__be16 stream;
	__be16 ssn;
};

struct sctp_fwdtsn_hdr {
	__be32 new_cum_tsn;
	struct sctp_fwdtsn_skip skip[0];
};

struct sctp_ifwdtsn_skip {
	__be16 stream;
	__u8 reserved;
	__u8 flags;
	__be32 mid;
};

struct sctp_ifwdtsn_hdr {
	__be32 new_cum_tsn;
	struct sctp_ifwdtsn_skip skip[0];
};

struct sctp_addip_param {
	struct sctp_paramhdr param_hdr;
	__be32 crr_id;
};

struct sctp_addiphdr {
	__be32 serial;
	__u8 params[0];
};

struct sctp_authhdr {
	__be16 shkey_id;
	__be16 hmac_id;
	__u8 hmac[0];
};

union sctp_addr {
	struct sockaddr_in v4;
	struct sockaddr_in6 v6;
	struct sockaddr sa;
};

struct sctp_cookie {
	__u32 my_vtag;
	__u32 peer_vtag;
	__u32 my_ttag;
	__u32 peer_ttag;
	ktime_t expiration;
	__u16 sinit_num_ostreams;
	__u16 sinit_max_instreams;
	__u32 initial_tsn;
	union sctp_addr peer_addr;
	__u16 my_port;
	__u8 prsctp_capable;
	__u8 padding;
	__u32 adaptation_ind;
	__u8 auth_random[36];
	__u8 auth_hmacs[10];
	__u8 auth_chunks[20];
	__u32 raw_addr_list_len;
	struct sctp_init_chunk peer_init[0];
};

struct sctp_tsnmap {
	long unsigned int *tsn_map;
	__u32 base_tsn;
	__u32 cumulative_tsn_ack_point;
	__u32 max_tsn_seen;
	__u16 len;
	__u16 pending_data;
	__u16 num_dup_tsns;
	__be32 dup_tsns[16];
};

struct sctp_inithdr_host {
	__u32 init_tag;
	__u32 a_rwnd;
	__u16 num_outbound_streams;
	__u16 num_inbound_streams;
	__u32 initial_tsn;
};

enum sctp_state {
	SCTP_STATE_CLOSED = 0,
	SCTP_STATE_COOKIE_WAIT = 1,
	SCTP_STATE_COOKIE_ECHOED = 2,
	SCTP_STATE_ESTABLISHED = 3,
	SCTP_STATE_SHUTDOWN_PENDING = 4,
	SCTP_STATE_SHUTDOWN_SENT = 5,
	SCTP_STATE_SHUTDOWN_RECEIVED = 6,
	SCTP_STATE_SHUTDOWN_ACK_SENT = 7,
};

struct sctp_stream_out;

struct sctp_stream_in;

struct sctp_stream_out_ext;

struct sctp_stream_interleave;

struct sctp_stream {
	struct sctp_stream_out *out;
	struct sctp_stream_in *in;
	__u16 outcnt;
	__u16 incnt;
	struct sctp_stream_out *out_curr;
	union {
		struct {
			struct list_head prio_list;
		};
		struct {
			struct list_head rr_list;
			struct sctp_stream_out_ext *rr_next;
		};
	};
	struct sctp_stream_interleave *si;
};

struct sctp_sched_ops;

struct sctp_association;

struct sctp_outq {
	struct sctp_association *asoc;
	struct list_head out_chunk_list;
	struct sctp_sched_ops *sched;
	unsigned int out_qlen;
	unsigned int error;
	struct list_head control_chunk_list;
	struct list_head sacked;
	struct list_head retransmit;
	struct list_head abandoned;
	__u32 outstanding_bytes;
	char fast_rtx;
	char cork;
};

struct sctp_ulpq {
	char pd_mode;
	struct sctp_association *asoc;
	struct sk_buff_head___26 reasm;
	struct sk_buff_head___26 reasm_uo;
	struct sk_buff_head___26 lobby;
};

struct sctp_priv_assoc_stats {
	struct __kernel_sockaddr_storage obs_rto_ipaddr;
	__u64 max_obs_rto;
	__u64 isacks;
	__u64 osacks;
	__u64 opackets;
	__u64 ipackets;
	__u64 rtxchunks;
	__u64 outofseqtsns;
	__u64 idupchunks;
	__u64 gapcnt;
	__u64 ouodchunks;
	__u64 iuodchunks;
	__u64 oodchunks;
	__u64 iodchunks;
	__u64 octrlchunks;
	__u64 ictrlchunks;
};

struct sctp_transport;

struct sctp_auth_bytes;

struct sctp_shared_key;

struct sctp_association {
	struct sctp_ep_common base;
	struct list_head asocs;
	sctp_assoc_t assoc_id;
	struct sctp_endpoint___2 *ep;
	struct sctp_cookie c;
	struct {
		struct list_head transport_addr_list;
		__u32 rwnd;
		__u16 transport_count;
		__u16 port;
		struct sctp_transport *primary_path;
		union sctp_addr primary_addr;
		struct sctp_transport *active_path;
		struct sctp_transport *retran_path;
		struct sctp_transport *last_sent_to;
		struct sctp_transport *last_data_from;
		struct sctp_tsnmap tsn_map;
		__be16 addip_disabled_mask;
		__u16 ecn_capable: 1;
		__u16 ipv4_address: 1;
		__u16 ipv6_address: 1;
		__u16 hostname_address: 1;
		__u16 asconf_capable: 1;
		__u16 prsctp_capable: 1;
		__u16 reconf_capable: 1;
		__u16 intl_capable: 1;
		__u16 auth_capable: 1;
		__u16 sack_needed: 1;
		__u16 sack_generation: 1;
		__u16 zero_window_announced: 1;
		__u32 sack_cnt;
		__u32 adaptation_ind;
		struct sctp_inithdr_host i;
		void *cookie;
		int cookie_len;
		__u32 addip_serial;
		struct sctp_random_param *peer_random;
		struct sctp_chunks_param *peer_chunks;
		struct sctp_hmac_algo_param *peer_hmacs;
	} peer;
	enum sctp_state state;
	int overall_error_count;
	ktime_t cookie_life;
	long unsigned int rto_initial;
	long unsigned int rto_max;
	long unsigned int rto_min;
	int max_burst;
	int max_retrans;
	int pf_retrans;
	__u16 max_init_attempts;
	__u16 init_retries;
	long unsigned int max_init_timeo;
	long unsigned int hbinterval;
	__u16 pathmaxrxt;
	__u32 flowlabel;
	__u8 dscp;
	__u8 pmtu_pending;
	__u32 pathmtu;
	__u32 param_flags;
	__u32 sackfreq;
	long unsigned int sackdelay;
	long unsigned int timeouts[11];
	struct timer_list timers[11];
	struct sctp_transport *shutdown_last_sent_to;
	struct sctp_transport *init_last_sent_to;
	int shutdown_retries;
	__u32 next_tsn;
	__u32 ctsn_ack_point;
	__u32 adv_peer_ack_point;
	__u32 highest_sacked;
	__u32 fast_recovery_exit;
	__u8 fast_recovery;
	__u16 unack_data;
	__u32 rtx_data_chunks;
	__u32 rwnd;
	__u32 a_rwnd;
	__u32 rwnd_over;
	__u32 rwnd_press;
	int sndbuf_used;
	atomic_t rmem_alloc;
	wait_queue_head_t wait;
	__u32 frag_point;
	__u32 user_frag;
	int init_err_counter;
	int init_cycle;
	__u16 default_stream;
	__u16 default_flags;
	__u32 default_ppid;
	__u32 default_context;
	__u32 default_timetolive;
	__u32 default_rcv_context;
	struct sctp_stream stream;
	struct sctp_outq outqueue;
	struct sctp_ulpq ulpq;
	__u32 last_ecne_tsn;
	__u32 last_cwr_tsn;
	int numduptsns;
	struct sctp_chunk *addip_last_asconf;
	struct list_head asconf_ack_list;
	struct list_head addip_chunk_list;
	__u32 addip_serial;
	int src_out_of_asoc_ok;
	union sctp_addr *asconf_addr_del_pending;
	struct sctp_transport *new_transport;
	struct list_head endpoint_shared_keys;
	struct sctp_auth_bytes *asoc_shared_key;
	struct sctp_shared_key *shkey;
	__u16 default_hmac_id;
	__u16 active_key_id;
	__u8 need_ecne: 1;
	__u8 temp: 1;
	__u8 force_delay: 1;
	__u8 strreset_enable;
	__u8 strreset_outstanding;
	__u32 strreset_outseq;
	__u32 strreset_inseq;
	__u32 strreset_result[2];
	struct sctp_chunk *strreset_chunk;
	struct sctp_priv_assoc_stats stats;
	int sent_cnt_removable;
	__u16 subscribe;
	__u64 abandoned_unsent[3];
	__u64 abandoned_sent[3];
	struct callback_head rcu;
};

struct sctp_auth_bytes {
	refcount_t refcnt;
	__u32 len;
	__u8 data[0];
};

struct sctp_shared_key {
	struct list_head key_list;
	struct sctp_auth_bytes *key;
	refcount_t refcnt;
	__u16 key_id;
	__u8 deactivated;
};

enum {
	SCTP_MAX_STREAM = 65535,
};

enum sctp_event_timeout {
	SCTP_EVENT_TIMEOUT_NONE = 0,
	SCTP_EVENT_TIMEOUT_T1_COOKIE = 1,
	SCTP_EVENT_TIMEOUT_T1_INIT = 2,
	SCTP_EVENT_TIMEOUT_T2_SHUTDOWN = 3,
	SCTP_EVENT_TIMEOUT_T3_RTX = 4,
	SCTP_EVENT_TIMEOUT_T4_RTO = 5,
	SCTP_EVENT_TIMEOUT_T5_SHUTDOWN_GUARD = 6,
	SCTP_EVENT_TIMEOUT_HEARTBEAT = 7,
	SCTP_EVENT_TIMEOUT_RECONF = 8,
	SCTP_EVENT_TIMEOUT_SACK = 9,
	SCTP_EVENT_TIMEOUT_AUTOCLOSE = 10,
};

enum {
	SCTP_MAX_DUP_TSNS = 16,
};

enum sctp_scope {
	SCTP_SCOPE_GLOBAL = 0,
	SCTP_SCOPE_PRIVATE = 1,
	SCTP_SCOPE_LINK = 2,
	SCTP_SCOPE_LOOPBACK = 3,
	SCTP_SCOPE_UNUSABLE = 4,
};

enum {
	SCTP_AUTH_HMAC_ID_RESERVED_0 = 0,
	SCTP_AUTH_HMAC_ID_SHA1 = 1,
	SCTP_AUTH_HMAC_ID_RESERVED_2 = 2,
	SCTP_AUTH_HMAC_ID_SHA256 = 3,
	__SCTP_AUTH_HMAC_MAX = 4,
};

struct sctp_ulpevent {
	struct sctp_association *asoc;
	struct sctp_chunk *chunk;
	unsigned int rmem_len;
	union {
		__u32 mid;
		__u16 ssn;
	};
	union {
		__u32 ppid;
		__u32 fsn;
	};
	__u32 tsn;
	__u32 cumtsn;
	__u16 stream;
	__u16 flags;
	__u16 msg_flags;
} __attribute__((packed));

union sctp_addr_param;

union sctp_params {
	void *v;
	struct sctp_paramhdr *p;
	struct sctp_cookie_preserve_param *life;
	struct sctp_hostname_param *dns;
	struct sctp_cookie_param *cookie;
	struct sctp_supported_addrs_param *sat;
	struct sctp_ipv4addr_param *v4;
	struct sctp_ipv6addr_param *v6;
	union sctp_addr_param *addr;
	struct sctp_adaptation_ind_param *aind;
	struct sctp_supported_ext_param *ext;
	struct sctp_random_param *random;
	struct sctp_chunks_param *chunks;
	struct sctp_hmac_algo_param *hmac_algo;
	struct sctp_addip_param *addip;
};

struct sctp_sender_hb_info;

struct sctp_signed_cookie;

struct sctp_datamsg;

struct sctp_chunk {
	struct list_head list;
	refcount_t refcnt;
	int sent_count;
	union {
		struct list_head transmitted_list;
		struct list_head stream_list;
	};
	struct list_head frag_list;
	struct sk_buff___30 *skb;
	union {
		struct sk_buff___30 *head_skb;
		struct sctp_shared_key *shkey;
	};
	union sctp_params param_hdr;
	union {
		__u8 *v;
		struct sctp_datahdr *data_hdr;
		struct sctp_inithdr *init_hdr;
		struct sctp_sackhdr *sack_hdr;
		struct sctp_heartbeathdr *hb_hdr;
		struct sctp_sender_hb_info *hbs_hdr;
		struct sctp_shutdownhdr *shutdown_hdr;
		struct sctp_signed_cookie *cookie_hdr;
		struct sctp_ecnehdr *ecne_hdr;
		struct sctp_cwrhdr *ecn_cwr_hdr;
		struct sctp_errhdr *err_hdr;
		struct sctp_addiphdr *addip_hdr;
		struct sctp_fwdtsn_hdr *fwdtsn_hdr;
		struct sctp_authhdr *auth_hdr;
		struct sctp_idatahdr *idata_hdr;
		struct sctp_ifwdtsn_hdr *ifwdtsn_hdr;
	} subh;
	__u8 *chunk_end;
	struct sctp_chunkhdr *chunk_hdr;
	struct sctphdr *sctp_hdr;
	struct sctp_sndrcvinfo sinfo;
	struct sctp_association *asoc;
	struct sctp_ep_common *rcvr;
	long unsigned int sent_at;
	union sctp_addr source;
	union sctp_addr dest;
	struct sctp_datamsg *msg;
	struct sctp_transport *transport;
	struct sk_buff___30 *auth_chunk;
	__u16 rtt_in_progress: 1;
	__u16 has_tsn: 1;
	__u16 has_ssn: 1;
	__u16 singleton: 1;
	__u16 end_of_packet: 1;
	__u16 ecn_ce_done: 1;
	__u16 pdiscard: 1;
	__u16 tsn_gap_acked: 1;
	__u16 data_accepted: 1;
	__u16 auth: 1;
	__u16 has_asconf: 1;
	__u16 tsn_missing_report: 2;
	__u16 fast_retransmit: 2;
};

struct sctp_stream_interleave {
	__u16 data_chunk_len;
	__u16 ftsn_chunk_len;
	struct sctp_chunk * (*make_datafrag)(const struct sctp_association *, const struct sctp_sndrcvinfo *, int, __u8, gfp_t);
	void (*assign_number)(struct sctp_chunk *);
	bool (*validate_data)(struct sctp_chunk *);
	int (*ulpevent_data)(struct sctp_ulpq *, struct sctp_chunk *, gfp_t);
	int (*enqueue_event)(struct sctp_ulpq *, struct sctp_ulpevent *);
	void (*renege_events)(struct sctp_ulpq *, struct sctp_chunk *, gfp_t);
	void (*start_pd)(struct sctp_ulpq *, gfp_t);
	void (*abort_pd)(struct sctp_ulpq *, gfp_t);
	void (*generate_ftsn)(struct sctp_outq *, __u32);
	bool (*validate_ftsn)(struct sctp_chunk *);
	void (*report_ftsn)(struct sctp_ulpq *, __u32);
	void (*handle_ftsn)(struct sctp_ulpq *, struct sctp_chunk *);
};

struct sctp_bind_bucket {
	short unsigned int port;
	signed char fastreuse;
	signed char fastreuseport;
	kuid_t fastuid;
	struct hlist_node node;
	struct hlist_head owner;
	struct net___38 *net;
};

struct sctp_bind_hashbucket {
	spinlock_t lock;
	struct hlist_head chain;
};

struct sctp_hashbucket {
	rwlock_t lock;
	struct hlist_head chain;
};

struct sctp_globals {
	struct list_head address_families;
	struct sctp_hashbucket *ep_hashtable;
	struct sctp_bind_hashbucket *port_hashtable;
	struct rhltable transport_hashtable;
	int ep_hashsize;
	int port_hashsize;
	__u16 max_instreams;
	__u16 max_outstreams;
	bool checksum_disable;
};

enum sctp_socket_type {
	SCTP_SOCKET_UDP = 0,
	SCTP_SOCKET_UDP_HIGH_BANDWIDTH = 1,
	SCTP_SOCKET_TCP = 2,
};

struct sctp_pf;

struct sctp_sock {
	struct inet_sock inet;
	enum sctp_socket_type type;
	struct sctp_pf *pf;
	struct crypto_shash___3 *hmac;
	char *sctp_hmac_alg;
	struct sctp_endpoint___2 *ep;
	struct sctp_bind_bucket *bind_hash;
	__u16 default_stream;
	__u32 default_ppid;
	__u16 default_flags;
	__u32 default_context;
	__u32 default_timetolive;
	__u32 default_rcv_context;
	int max_burst;
	__u32 hbinterval;
	__u16 pathmaxrxt;
	__u32 flowlabel;
	__u8 dscp;
	int pf_retrans;
	__u32 pathmtu;
	__u32 sackdelay;
	__u32 sackfreq;
	__u32 param_flags;
	__u32 default_ss;
	struct sctp_rtoinfo rtoinfo;
	struct sctp_paddrparams paddrparam;
	struct sctp_assocparams assocparams;
	__u16 subscribe;
	struct sctp_initmsg initmsg;
	int user_frag;
	__u32 autoclose;
	__u32 adaptation_ind;
	__u32 pd_point;
	__u16 nodelay: 1;
	__u16 reuse: 1;
	__u16 disable_fragments: 1;
	__u16 v4mapped: 1;
	__u16 frag_interleave: 1;
	__u16 recvrcvinfo: 1;
	__u16 recvnxtinfo: 1;
	__u16 data_ready_signalled: 1;
	atomic_t pd_mode;
	struct sk_buff_head___26 pd_lobby;
	struct list_head auto_asconf_list;
	int do_auto_asconf;
};

struct sctp_af;

struct sctp_pf {
	void (*event_msgname)(struct sctp_ulpevent *, char *, int *);
	void (*skb_msgname)(struct sk_buff___30 *, char *, int *);
	int (*af_supported)(sa_family_t, struct sctp_sock *);
	int (*cmp_addr)(const union sctp_addr *, const union sctp_addr *, struct sctp_sock *);
	int (*bind_verify)(struct sctp_sock *, union sctp_addr *);
	int (*send_verify)(struct sctp_sock *, union sctp_addr *);
	int (*supported_addrs)(const struct sctp_sock *, __be16 *);
	struct sock___17 * (*create_accept_sk)(struct sock___17 *, struct sctp_association *, bool);
	int (*addr_to_user)(struct sctp_sock *, union sctp_addr *);
	void (*to_sk_saddr)(union sctp_addr *, struct sock___17 *);
	void (*to_sk_daddr)(union sctp_addr *, struct sock___17 *);
	void (*copy_ip_options)(struct sock___17 *, struct sock___17 *);
	struct sctp_af *af;
};

struct sctp_signed_cookie {
	__u8 signature[32];
	__u32 __pad;
	struct sctp_cookie c;
} __attribute__((packed));

union sctp_addr_param {
	struct sctp_paramhdr p;
	struct sctp_ipv4addr_param v4;
	struct sctp_ipv6addr_param v6;
};

struct sctp_sender_hb_info {
	struct sctp_paramhdr param_hdr;
	union sctp_addr daddr;
	long unsigned int sent_at;
	__u64 hb_nonce;
};

struct sctp_af {
	int (*sctp_xmit)(struct sk_buff___30 *, struct sctp_transport *);
	int (*setsockopt)(struct sock___17 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___17 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___17 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___17 *, int, int, char *, int *);
	void (*get_dst)(struct sctp_transport *, union sctp_addr *, struct flowi *, struct sock___17 *);
	void (*get_saddr)(struct sctp_sock *, struct sctp_transport *, struct flowi *);
	void (*copy_addrlist)(struct list_head *, struct net_device___30 *);
	int (*cmp_addr)(const union sctp_addr *, const union sctp_addr *);
	void (*addr_copy)(union sctp_addr *, union sctp_addr *);
	void (*from_skb)(union sctp_addr *, struct sk_buff___30 *, int);
	void (*from_sk)(union sctp_addr *, struct sock___17 *);
	void (*from_addr_param)(union sctp_addr *, union sctp_addr_param *, __be16, int);
	int (*to_addr_param)(const union sctp_addr *, union sctp_addr_param *);
	int (*addr_valid)(union sctp_addr *, struct sctp_sock *, const struct sk_buff___30 *);
	enum sctp_scope (*scope)(union sctp_addr *);
	void (*inaddr_any)(union sctp_addr *, __be16);
	int (*is_any)(const union sctp_addr *);
	int (*available)(union sctp_addr *, struct sctp_sock *);
	int (*skb_iif)(const struct sk_buff___30 *);
	int (*is_ce)(const struct sk_buff___30 *);
	void (*seq_dump_addr)(struct seq_file___216 *, union sctp_addr *);
	void (*ecn_capable)(struct sock___17 *);
	__u16 net_header_len;
	int sockaddr_len;
	int (*ip_options_len)(struct sock___17 *);
	sa_family_t sa_family;
	struct list_head list;
};

struct sctp_packet {
	__u16 source_port;
	__u16 destination_port;
	__u32 vtag;
	struct list_head chunk_list;
	size_t overhead;
	size_t size;
	size_t max_size;
	struct sctp_transport *transport;
	struct sctp_chunk *auth;
	u8 has_cookie_echo: 1;
	u8 has_sack: 1;
	u8 has_auth: 1;
	u8 has_data: 1;
	u8 ipfragok: 1;
};

struct sctp_transport {
	struct list_head transports;
	struct rhlist_head node;
	refcount_t refcnt;
	__u32 rto_pending: 1;
	__u32 hb_sent: 1;
	__u32 pmtu_pending: 1;
	__u32 dst_pending_confirm: 1;
	__u32 sack_generation: 1;
	u32 dst_cookie;
	struct flowi fl;
	union sctp_addr ipaddr;
	struct sctp_af *af_specific;
	struct sctp_association *asoc;
	long unsigned int rto;
	__u32 rtt;
	__u32 rttvar;
	__u32 srtt;
	__u32 cwnd;
	__u32 ssthresh;
	__u32 partial_bytes_acked;
	__u32 flight_size;
	__u32 burst_limited;
	struct dst_entry___16 *dst;
	union sctp_addr saddr;
	long unsigned int hbinterval;
	long unsigned int sackdelay;
	__u32 sackfreq;
	atomic_t mtu_info;
	ktime_t last_time_heard;
	long unsigned int last_time_sent;
	long unsigned int last_time_ecne_reduced;
	__u16 pathmaxrxt;
	__u32 flowlabel;
	__u8 dscp;
	int pf_retrans;
	__u32 pathmtu;
	__u32 param_flags;
	int init_sent_count;
	int state;
	short unsigned int error_count;
	struct timer_list T3_rtx_timer;
	struct timer_list hb_timer;
	struct timer_list proto_unreach_timer;
	struct timer_list reconf_timer;
	struct list_head transmitted;
	struct sctp_packet packet;
	struct list_head send_ready;
	struct {
		__u32 next_tsn_at_change;
		char changeover_active;
		char cycling_changeover;
		char cacc_saw_newack;
	} cacc;
	__u64 hb_nonce;
	struct callback_head rcu;
};

struct sctp_datamsg {
	struct list_head chunks;
	refcount_t refcnt;
	long unsigned int expires_at;
	int send_error;
	u8 send_failed: 1;
	u8 can_delay: 1;
	u8 abandoned: 1;
};

struct sctp_stream_priorities {
	struct list_head prio_sched;
	struct list_head active;
	struct sctp_stream_out_ext *next;
	__u16 prio;
};

struct sctp_stream_out_ext {
	__u64 abandoned_unsent[3];
	__u64 abandoned_sent[3];
	struct list_head outq;
	union {
		struct {
			struct list_head prio_list;
			struct sctp_stream_priorities *prio_head;
		};
		struct {
			struct list_head rr_list;
		};
	};
};

struct sctp_stream_out {
	union {
		__u32 mid;
		__u16 ssn;
	};
	__u32 mid_uo;
	struct sctp_stream_out_ext *ext;
	__u8 state;
};

struct sctp_stream_in {
	union {
		__u32 mid;
		__u16 ssn;
	};
	__u32 mid_uo;
	__u32 fsn;
	__u32 fsn_uo;
	char pd_mode;
	char pd_mode_uo;
};

struct hstate___44 {
	int next_nid_to_alloc;
	int next_nid_to_free;
	unsigned int order;
	long unsigned int mask;
	long unsigned int max_huge_pages;
	long unsigned int nr_huge_pages;
	long unsigned int free_huge_pages;
	long unsigned int resv_huge_pages;
	long unsigned int surplus_huge_pages;
	long unsigned int nr_overcommit_huge_pages;
	struct list_head hugepage_activelist;
	struct list_head hugepage_freelists[8];
	unsigned int nr_huge_pages_node[8];
	unsigned int free_huge_pages_node[8];
	unsigned int surplus_huge_pages_node[8];
	struct cftype___185 cgroup_files[5];
	char name[32];
};

struct lsm_network_audit___2 {
	int netif;
	struct sock___17 *sk;
	u16 family;
	__be16 dport;
	__be16 sport;
	union {
		struct {
			__be32 daddr;
			__be32 saddr;
		} v4;
		struct {
			struct in6_addr daddr;
			struct in6_addr saddr;
		} v6;
	} fam;
};

struct lsm_ioctlop_audit___2 {
	struct path___239 path;
	u16 cmd;
};

struct common_audit_data___2 {
	char type;
	union {
		struct path___239 path;
		struct dentry___240 *dentry;
		struct inode___240 *inode;
		struct lsm_network_audit___2 *net;
		int cap;
		int ipc_id;
		struct task_struct___241 *tsk;
		struct {
			key_serial_t key;
			char *key_desc;
		} key_struct;
		char *kmod_name;
		struct lsm_ioctlop_audit___2 *op;
		struct file___240 *file;
		struct lsm_ibpkey_audit *ibpkey;
		struct lsm_ibendport_audit *ibendport;
	} u;
	union {
		struct selinux_audit_data *selinux_audit_data;
	};
};

struct coredump_params___38 {
	union {
		const kernel_siginfo_t *siginfo;
		struct {
			const siginfo_t *siginfo;
		} __UNIQUE_ID_rh_kabi_hide107;
		union {		};
	};
	struct pt_regs *regs;
	struct file___240 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
};

struct task_security_struct {
	u32 osid;
	u32 sid;
	u32 exec_sid;
	u32 create_sid;
	u32 keycreate_sid;
	u32 sockcreate_sid;
};

enum label_initialized {
	LABEL_INVALID = 0,
	LABEL_INITIALIZED = 1,
	LABEL_PENDING = 2,
};

struct inode_security_struct {
	struct inode___240 *inode;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
	u32 task_sid;
	u32 sid;
	u16 sclass;
	unsigned char initialized;
	spinlock_t lock;
};

struct file_security_struct {
	u32 sid;
	u32 fown_sid;
	u32 isid;
	u32 pseqno;
};

struct superblock_security_struct {
	struct super_block___239 *sb;
	u32 sid;
	u32 def_sid;
	u32 mntpoint_sid;
	short unsigned int behavior;
	short unsigned int flags;
	struct mutex lock;
	struct list_head isec_head;
	spinlock_t isec_lock;
};

struct msg_security_struct {
	u32 sid;
};

struct ipc_security_struct {
	u16 sclass;
	u32 sid;
};

struct sk_security_struct {
	enum {
		NLBL_UNSET = 0,
		NLBL_REQUIRE = 1,
		NLBL_LABELED = 2,
		NLBL_REQSKB = 3,
		NLBL_CONNLABELED = 4,
	} nlbl_state;
	struct netlbl_lsm_secattr *nlbl_secattr;
	u32 sid;
	u32 peer_sid;
	u16 sclass;
	enum {
		SCTP_ASSOC_UNSET = 0,
		SCTP_ASSOC_SET = 1,
	} sctp_assoc_state;
};

struct tun_security_struct {
	u32 sid;
};

struct key_security_struct {
	u32 sid;
};

struct ib_security_struct {
	u32 sid;
};

struct bpf_security_struct {
	u32 sid;
};

enum {
	Opt_error = 4294967295,
	Opt_context = 1,
	Opt_fscontext = 2,
	Opt_defcontext = 3,
	Opt_rootcontext = 4,
	Opt_labelsupport = 5,
	Opt_nextmntopt = 6,
};

struct module___195;

struct file___241;

struct kiocb___241;

struct iov_iter___108;

struct poll_table_struct___149;

struct vm_area_struct___242;

struct inode___241;

struct file_lock___241;

struct page___242;

struct pipe_inode_info___51;

struct seq_file___217;

struct file_operations___241 {
	struct module___195 *owner;
	loff_t (*llseek)(struct file___241 *, loff_t, int);
	ssize_t (*read)(struct file___241 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___241 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___241 *, struct iov_iter___108 *);
	ssize_t (*write_iter)(struct kiocb___241 *, struct iov_iter___108 *);
	int (*iopoll)(struct kiocb___241 *, bool);
	int (*iterate)(struct file___241 *, struct dir_context *);
	int (*iterate_shared)(struct file___241 *, struct dir_context *);
	__poll_t (*poll)(struct file___241 *, struct poll_table_struct___149 *);
	long int (*unlocked_ioctl)(struct file___241 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___241 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___241 *, struct vm_area_struct___242 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___241 *, struct file___241 *);
	int (*flush)(struct file___241 *, fl_owner_t);
	int (*release)(struct inode___241 *, struct file___241 *);
	int (*fsync)(struct file___241 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___241 *, int);
	int (*lock)(struct file___241 *, int, struct file_lock___241 *);
	ssize_t (*sendpage)(struct file___241 *, struct page___242 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___241 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___241 *, int, struct file_lock___241 *);
	ssize_t (*splice_write)(struct pipe_inode_info___51 *, struct file___241 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___241 *, loff_t *, struct pipe_inode_info___51 *, size_t, unsigned int);
	int (*setlease)(struct file___241 *, long int, struct file_lock___241 **, void **);
	long int (*fallocate)(struct file___241 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___217 *, struct file___241 *);
	ssize_t (*copy_file_range)(struct file___241 *, loff_t, struct file___241 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___241 *, loff_t, struct file___241 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___241 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___241 {
	u64 seqnum;
	struct vm_area_struct___242 *vmas[4];
};

struct page_frag___241 {
	struct page___242 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___241;

struct mem_cgroup___102;

struct pid___181;

struct cred___234;

struct nsproxy___221;

struct signal_struct___199;

struct bio_list___117;

struct backing_dev_info___117;

struct css_set___186;

struct vm_struct___158;

struct task_struct___242 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___242 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___241 *mm;
	struct mm_struct___241 *active_mm;
	struct vmacache___241 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___242 *real_parent;
	struct task_struct___242 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___242 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___102 *active_memcg;
	long int rh_reserved2;
	struct pid___181 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___181 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___181 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___234 *ptracer_cred;
	const struct cred___234 *real_cred;
	const struct cred___234 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___221 *nsproxy;
	struct signal_struct___199 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___242 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___117 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___117 *backing_dev_info;
	struct io_context___60 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___186 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___51 *splice_pipe;
	struct page_frag___241 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___102 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___242 *oom_reaper_list;
	struct vm_struct___158 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___127 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___242 *pgtable_t___241;

struct address_space___240;

struct dev_pagemap___231;

struct page___242 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___240 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___242 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___241 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___241 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___231 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___102 *mem_cgroup;
};

struct pglist_data___241;

struct lruvec___241 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___241 *pgdat;
};

struct zone___241 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___241 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___241 {
	struct zone___241 *zone;
	int zone_idx;
};

struct zonelist___241 {
	struct zoneref___241 _zonerefs[25];
};

struct pglist_data___241 {
	struct zone___241 node_zones[3];
	struct zonelist___241 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___242 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___242 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___241 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___242 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___242 *owner;
};

struct secondary_data___242 {
	void *stack;
	struct task_struct___242 *task;
	long int status;
};

struct blocking_notifier_head___241 {
	struct rw_semaphore___242 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___231;

struct vm_area_struct___242 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___242 *vm_next;
	struct vm_area_struct___242 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___241 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___231 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___241 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct linux_binfmt___39;

struct core_state___241;

struct user_namespace___201;

struct mm_struct___241 {
	struct {
		struct vm_area_struct___242 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___241 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___242 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___39 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___241 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___242 *owner;
		struct user_namespace___201 *user_ns;
		struct file___241 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___241 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___240;

struct address_space___240 {
	struct inode___241 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___242 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___240 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___231)(struct vm_area_struct___242 *, long unsigned int, const struct page___242 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___231)(struct page___242 *, void *);

struct device___205;

struct dev_pagemap___231 {
	dev_page_fault_t___231 page_fault;
	dev_page_free_t___231 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___205 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct cgroup___186;

struct cgroup_subsys___186;

struct cgroup_subsys_state___187 {
	struct cgroup___186 *cgroup;
	struct cgroup_subsys___186 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___187 *parent;
};

struct kernfs_node___235;

struct cgroup_file___186 {
	struct kernfs_node___235 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___102;

struct mem_cgroup___102 {
	struct cgroup_subsys_state___187 css;
	struct mem_cgroup_id___16 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___186 events_file;
	struct cgroup_file___186 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___242 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___102 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct vfsmount___64;

struct dentry___241;

struct path___240 {
	struct vfsmount___64 *mnt;
	struct dentry___241 *dentry;
};

struct fown_struct___181 {
	rwlock_t lock;
	struct pid___181 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___241 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___240 f_path;
	struct inode___241 *f_inode;
	const struct file_operations___241 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___181 f_owner;
	const struct cred___234 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___240 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___231;

struct vm_operations_struct___231 {
	void (*open)(struct vm_area_struct___242 *);
	void (*close)(struct vm_area_struct___242 *);
	int (*split)(struct vm_area_struct___242 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___242 *);
	vm_fault_t (*fault)(struct vm_fault___231 *);
	vm_fault_t (*huge_fault)(struct vm_fault___231 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___231 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___242 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___231 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___231 *);
	int (*access)(struct vm_area_struct___242 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___242 *);
	int (*set_policy)(struct vm_area_struct___242 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___242 *, long unsigned int);
	struct page___242 * (*find_special_page)(struct vm_area_struct___242 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___241 {
	struct task_struct___242 *task;
	struct core_thread___241 *next;
};

struct core_state___241 {
	atomic_t nr_threads;
	struct core_thread___241 dumper;
	struct completion startup;
};

struct linux_binprm___40;

struct coredump_params___39;

struct linux_binfmt___39 {
	struct list_head lh;
	struct module___195 *module;
	int (*load_binary)(struct linux_binprm___40 *);
	int (*load_shlib)(struct file___241 *);
	int (*core_dump)(struct coredump_params___39 *);
	long unsigned int min_coredump;
};

struct key___234;

struct ucounts___201;

struct user_namespace___201 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___201 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___28 ns;
	long unsigned int flags;
	struct key___234 *persistent_keyring_register;
	struct rw_semaphore___242 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___201 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___231 {
	struct vm_area_struct___242 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___242 *cow_page;
	struct mem_cgroup___102 *memcg;
	struct page___242 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___241 prealloc_pte;
};

struct shrink_control___102 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___102 *memcg;
};

struct shrinker___102 {
	long unsigned int (*count_objects)(struct shrinker___102 *, struct shrink_control___102 *);
	long unsigned int (*scan_objects)(struct shrinker___102 *, struct shrink_control___102 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct pid_namespace___181;

struct upid___181 {
	int nr;
	struct pid_namespace___181 *ns;
};

struct pid_namespace___181 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___242 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___181 *parent;
	struct vfsmount___64 *proc_mnt;
	struct dentry___241 *proc_self;
	struct dentry___241 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___201 *user_ns;
	struct ucounts___201 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___28 ns;
};

struct pid___181 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___181 numbers[1];
};

struct user_struct___234 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___234 *uid_keyring;
	struct key___234 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___234 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___234 *session_keyring;
	struct key___234 *process_keyring;
	struct key___234 *thread_keyring;
	struct key___234 *request_key_auth;
	void *security;
	struct user_struct___234 *user;
	struct user_namespace___201 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___39;

struct cgroup_namespace___186;

struct nsproxy___221 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___181 *pid_ns_for_children;
	struct net___39 *net_ns;
	struct cgroup_namespace___186 *cgroup_ns;
};

struct signal_struct___199 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___242 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___242 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___181 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___181 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___241 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___181 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___117;

struct bio_list___117 {
	struct bio___117 *head;
	struct bio___117 *tail;
};

struct bdi_writeback_congested___117;

struct bdi_writeback___117 {
	struct backing_dev_info___117 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___117 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___187 *memcg_css;
	struct cgroup_subsys_state___187 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___117 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___117 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___205 *dev;
	struct device___205 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___241 *debug_dir;
	struct dentry___241 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___186 {
	struct cgroup_subsys_state___187 *subsys[13];
	refcount_t refcount;
	struct css_set___186 *dom_cset;
	struct cgroup___186 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___186 *mg_src_cgrp;
	struct cgroup___186 *mg_dst_cgrp;
	struct css_set___186 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___240;

struct pipe_buffer___51;

struct pipe_inode_info___51 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___242 *tmp_page;
	struct fasync_struct___240 *fasync_readers;
	struct fasync_struct___240 *fasync_writers;
	struct pipe_buffer___51 *bufs;
	struct user_struct___234 *user;
};

struct vm_struct___158 {
	struct vm_struct___158 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___242 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___211 {
	struct task_struct___242 task;
	long unsigned int stack[8192];
};

struct kset___228;

struct kobj_type___228;

struct kobject___229 {
	const char *name;
	struct list_head entry;
	struct kobject___229 *parent;
	struct kset___228 *kset;
	struct kobj_type___228 *ktype;
	struct kernfs_node___235 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___205 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___205 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___205;

struct bus_type___205;

struct device_driver___205;

struct dev_pm_domain___205;

struct dma_map_ops___48;

struct fwnode_handle___140;

struct class___205;

struct attribute_group___207;

struct device___205 {
	struct device___205 *parent;
	struct device_private *p;
	struct kobject___229 kobj;
	const char *init_name;
	const struct device_type___205 *type;
	struct mutex mutex;
	struct bus_type___205 *bus;
	struct device_driver___205 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___205 power;
	struct dev_pm_domain___205 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___48 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___140 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___205 *class;
	const struct attribute_group___207 **groups;
	void (*release)(struct device___205 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___240;

struct super_block___240;

struct dentry___241 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___241 *d_parent;
	struct qstr d_name;
	struct inode___241 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___240 *d_op;
	struct super_block___240 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___240;

struct block_device___241;

struct inode___241 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___240 *i_op;
	struct super_block___240 *i_sb;
	struct address_space___240 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___242 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___117 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___241 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___240 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___51 *i_pipe;
		struct block_device___241 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___240 {
	int (*d_revalidate)(struct dentry___241 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___241 *, unsigned int);
	int (*d_hash)(const struct dentry___241 *, struct qstr *);
	int (*d_compare)(const struct dentry___241 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___241 *);
	int (*d_init)(struct dentry___241 *);
	void (*d_release)(struct dentry___241 *);
	void (*d_prune)(struct dentry___241 *);
	void (*d_iput)(struct dentry___241 *, struct inode___241 *);
	char * (*d_dname)(struct dentry___241 *, char *, int);
	struct vfsmount___64 * (*d_automount)(struct path___240 *);
	int (*d_manage)(const struct path___240 *, bool);
	struct dentry___241 * (*d_real)(struct dentry___241 *, const struct inode___241 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___240;

struct mem_dqinfo___240 {
	struct quota_format_type___240 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___240;

struct quota_info___240 {
	unsigned int flags;
	struct rw_semaphore___242 dqio_sem;
	struct inode___241 *files[3];
	struct mem_dqinfo___240 info[3];
	const struct quota_format_ops___240 *ops[3];
};

struct rcuwait___240 {
	struct task_struct___242 *task;
};

struct percpu_rw_semaphore___240 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___242 rw_sem;
	struct rcuwait___240 writer;
	int readers_block;
};

struct sb_writers___240 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___240 rw_sem[3];
};

struct file_system_type___240;

struct super_operations___240;

struct dquot_operations___240;

struct quotactl_ops___240;

struct super_block___240 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___240 *s_type;
	const struct super_operations___240 *s_op;
	const struct dquot_operations___240 *dq_op;
	const struct quotactl_ops___240 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___241 *s_root;
	struct rw_semaphore___242 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___241 *s_bdev;
	struct backing_dev_info___117 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___240 s_dquot;
	struct sb_writers___240 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___240 *s_d_op;
	int cleancache_poolid;
	struct shrinker___102 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___201 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___64 {
	struct dentry___241 *mnt_root;
	struct super_block___240 *mnt_sb;
	int mnt_flags;
};

struct kiocb___241 {
	struct file___241 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___241 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___240 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___241 *ia_file;
};

struct dquot___240 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___240 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___240 {
	int qf_fmt_id;
	const struct quota_format_ops___240 *qf_ops;
	struct module___195 *qf_owner;
	struct quota_format_type___240 *qf_next;
};

struct quota_format_ops___240 {
	int (*check_quota_file)(struct super_block___240 *, int);
	int (*read_file_info)(struct super_block___240 *, int);
	int (*write_file_info)(struct super_block___240 *, int);
	int (*free_file_info)(struct super_block___240 *, int);
	int (*read_dqblk)(struct dquot___240 *);
	int (*commit_dqblk)(struct dquot___240 *);
	int (*release_dqblk)(struct dquot___240 *);
	int (*get_next_id)(struct super_block___240 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___240 {
	int (*write_dquot)(struct dquot___240 *);
	struct dquot___240 * (*alloc_dquot)(struct super_block___240 *, int);
	void (*destroy_dquot)(struct dquot___240 *);
	int (*acquire_dquot)(struct dquot___240 *);
	int (*release_dquot)(struct dquot___240 *);
	int (*mark_dirty)(struct dquot___240 *);
	int (*write_info)(struct super_block___240 *, int);
	qsize_t * (*get_reserved_space)(struct inode___241 *);
	int (*get_projid)(struct inode___241 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___241 *, qsize_t *);
	int (*get_next_id)(struct super_block___240 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___240 {
	int (*quota_on)(struct super_block___240 *, int, int, const struct path___240 *);
	int (*quota_off)(struct super_block___240 *, int);
	int (*quota_enable)(struct super_block___240 *, unsigned int);
	int (*quota_disable)(struct super_block___240 *, unsigned int);
	int (*quota_sync)(struct super_block___240 *, int);
	int (*set_info)(struct super_block___240 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___240 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___240 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___240 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___240 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___240 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___192 {
	struct kobject___229 kobj;
	struct module___195 *mod;
	struct kobject___229 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___192 {
	struct module___195 *mod;
	struct latch_tree_node node;
};

struct module_layout___192 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___192 mtn;
};

struct module_attribute___192;

struct kernel_param___192;

struct module___195 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___192 mkobj;
	struct module_attribute___192 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___229 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___192 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___192 core_layout;
	struct module_layout___192 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide53;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide54;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___113;

struct address_space_operations___240 {
	int (*writepage)(struct page___242 *, struct writeback_control___113 *);
	int (*readpage)(struct file___241 *, struct page___242 *);
	int (*writepages)(struct address_space___240 *, struct writeback_control___113 *);
	int (*set_page_dirty)(struct page___242 *);
	int (*readpages)(struct file___241 *, struct address_space___240 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___241 *, struct address_space___240 *, loff_t, unsigned int, unsigned int, struct page___242 **, void **);
	int (*write_end)(struct file___241 *, struct address_space___240 *, loff_t, unsigned int, unsigned int, struct page___242 *, void *);
	sector_t (*bmap)(struct address_space___240 *, sector_t);
	void (*invalidatepage)(struct page___242 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___242 *, gfp_t);
	void (*freepage)(struct page___242 *);
	ssize_t (*direct_IO)(struct kiocb___241 *, struct iov_iter___108 *);
	int (*migratepage)(struct address_space___240 *, struct page___242 *, struct page___242 *, enum migrate_mode);
	bool (*isolate_page)(struct page___242 *, isolate_mode_t);
	void (*putback_page)(struct page___242 *);
	int (*launder_page)(struct page___242 *);
	int (*is_partially_uptodate)(struct page___242 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___242 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___240 *, struct page___242 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___241 *, sector_t *);
	void (*swap_deactivate)(struct file___241 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___113 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___117 *wb;
	struct inode___241 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___117;

struct iov_iter___108 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___117 *bvec;
		struct pipe_inode_info___51 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___241 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___241 *bd_inode;
	struct super_block___240 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___241 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___117 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___240 {
	struct dentry___241 * (*lookup)(struct inode___241 *, struct dentry___241 *, unsigned int);
	const char * (*get_link)(struct dentry___241 *, struct inode___241 *, struct delayed_call *);
	int (*permission)(struct inode___241 *, int);
	struct posix_acl * (*get_acl)(struct inode___241 *, int);
	int (*readlink)(struct dentry___241 *, char *, int);
	int (*create)(struct inode___241 *, struct dentry___241 *, umode_t, bool);
	int (*link)(struct dentry___241 *, struct inode___241 *, struct dentry___241 *);
	int (*unlink)(struct inode___241 *, struct dentry___241 *);
	int (*symlink)(struct inode___241 *, struct dentry___241 *, const char *);
	int (*mkdir)(struct inode___241 *, struct dentry___241 *, umode_t);
	int (*rmdir)(struct inode___241 *, struct dentry___241 *);
	int (*mknod)(struct inode___241 *, struct dentry___241 *, umode_t, dev_t);
	int (*rename)(struct inode___241 *, struct dentry___241 *, struct inode___241 *, struct dentry___241 *, unsigned int);
	int (*setattr)(struct dentry___241 *, struct iattr___240 *);
	int (*getattr)(const struct path___240 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___241 *, char *, size_t);
	int (*fiemap)(struct inode___241 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___241 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___241 *, struct dentry___241 *, struct file___241 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___241 *, struct dentry___241 *, umode_t);
	int (*set_acl)(struct inode___241 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___240 {
	void (*fl_copy_lock)(struct file_lock___241 *, struct file_lock___241 *);
	void (*fl_release_private)(struct file_lock___241 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___240;

struct file_lock___241 {
	struct file_lock___241 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___241 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___240 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___240 *fl_ops;
	const struct lock_manager_operations___240 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___240 {
	int (*lm_compare_owner)(struct file_lock___241 *, struct file_lock___241 *);
	long unsigned int (*lm_owner_key)(struct file_lock___241 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___241 *);
	int (*lm_grant)(struct file_lock___241 *, int);
	bool (*lm_break)(struct file_lock___241 *);
	int (*lm_change)(struct file_lock___241 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___241 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___240 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___240 *fa_next;
	struct file___241 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___240 {
	const char *name;
	int fs_flags;
	struct dentry___241 * (*mount)(struct file_system_type___240 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___240 *);
	struct module___195 *owner;
	struct file_system_type___240 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___240 {
	struct inode___241 * (*alloc_inode)(struct super_block___240 *);
	void (*destroy_inode)(struct inode___241 *);
	void (*dirty_inode)(struct inode___241 *, int);
	int (*write_inode)(struct inode___241 *, struct writeback_control___113 *);
	int (*drop_inode)(struct inode___241 *);
	void (*evict_inode)(struct inode___241 *);
	void (*put_super)(struct super_block___240 *);
	int (*sync_fs)(struct super_block___240 *, int);
	int (*freeze_super)(struct super_block___240 *);
	int (*freeze_fs)(struct super_block___240 *);
	int (*thaw_super)(struct super_block___240 *);
	int (*unfreeze_fs)(struct super_block___240 *);
	int (*statfs)(struct dentry___241 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___240 *, int *, char *);
	void (*umount_begin)(struct super_block___240 *);
	int (*show_options)(struct seq_file___217 *, struct dentry___241 *);
	int (*show_devname)(struct seq_file___217 *, struct dentry___241 *);
	int (*show_path)(struct seq_file___217 *, struct dentry___241 *);
	int (*show_stats)(struct seq_file___217 *, struct dentry___241 *);
	ssize_t (*quota_read)(struct super_block___240 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___240 *, int, const char *, size_t, loff_t);
	struct dquot___240 ** (*get_dquots)(struct inode___241 *);
	int (*bdev_try_to_free_page)(struct super_block___240 *, struct page___242 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___240 *, struct shrink_control___102 *);
	long int (*free_cached_objects)(struct super_block___240 *, struct shrink_control___102 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___151)(struct file___241 *, wait_queue_head_t *, struct poll_table_struct___149 *);

struct poll_table_struct___149 {
	poll_queue_proc___151 _qproc;
	__poll_t _key;
};

struct seq_operations___215;

struct seq_file___217 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___215 *op;
	int poll_event;
	const struct file___241 *file;
	void *private;
};

typedef void bio_end_io_t___117(struct bio___117 *);

struct bio_vec___117 {
	struct page___242 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___117;

struct bio_set___117;

struct bio___117 {
	struct bio___117 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___117 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___117 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___117 *bi_io_vec;
	struct bio_set___117 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___117 bi_inline_vecs[0];
};

struct tree_descr___5 {
	const char *name;
	const struct file_operations___241 *ops;
	int mode;
};

struct kobj_attribute___222 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___229 *, struct kobj_attribute___222 *, char *);
	ssize_t (*store)(struct kobject___229 *, struct kobj_attribute___222 *, const char *, size_t);
};

typedef void compound_page_dtor___231(struct page___242 *);

typedef int (*key_restrict_link_func_t___234)(struct key___234 *, const struct key_type *, const union key_payload *, struct key___234 *);

struct key_restriction___234;

struct key___234 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___242 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key___5 index_key;
		struct {
			struct key_type___5 *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___234 *restrict_link;
};

struct key_restriction___234 {
	key_restrict_link_func_t___234 check;
	struct key___234 *key;
	struct key_type *keytype;
};

struct seq_operations___215 {
	void * (*start)(struct seq_file___217 *, loff_t *);
	void (*stop)(struct seq_file___217 *, void *);
	void * (*next)(struct seq_file___217 *, void *, loff_t *);
	int (*show)(struct seq_file___217 *, void *);
};

struct inet_frags___27;

struct netns_frags___27 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___27 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ip_ra_chain___6;

struct fib_rules_ops___16;

struct sock___18;

struct fib_notifier_ops___16;

struct netns_ipv4___27 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___6 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___16 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___18 *fibnl;
	struct sock___18 **icmp_sk;
	struct sock___18 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___18 **tcp_sk;
	struct netns_frags___27 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___16 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___16 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___16 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct dst_entry___17;

struct net_device___31;

struct sk_buff___31;

struct neighbour___17;

struct dst_ops___37 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___37 *);
	struct dst_entry___17 * (*check)(struct dst_entry___17 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___17 *);
	unsigned int (*mtu)(const struct dst_entry___17 *);
	u32 * (*cow_metrics)(struct dst_entry___17 *, long unsigned int);
	void (*destroy)(struct dst_entry___17 *);
	void (*ifdown)(struct dst_entry___17 *, struct net_device___31 *, int);
	struct dst_entry___17 * (*negative_advice)(struct dst_entry___17 *);
	void (*link_failure)(struct sk_buff___31 *);
	void (*update_pmtu)(struct dst_entry___17 *, struct sock___18 *, struct sk_buff___31 *, u32);
	void (*redirect)(struct dst_entry___17 *, struct sock___18 *, struct sk_buff___31 *);
	int (*local_out)(struct net___39 *, struct sock___18 *, struct sk_buff___31 *);
	struct neighbour___17 * (*neigh_lookup)(const struct dst_entry___17 *, struct sk_buff___31 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___17 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___37 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___27 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___37 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___16 *fib6_rules_ops;
	struct sock___18 **icmp_sk;
	struct sock___18 *ndisc_sk;
	struct sock___18 *tcp_sk;
	struct sock___18 *igmp_sk;
	struct sock___18 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___16 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___16 *notifier_ops;
	struct fib_notifier_ops___16 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___17 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___18 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___27 {
	struct netns_frags___27 frags;
};

struct netns_xfrm___37 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___18 *nlsk;
	struct sock___18 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___37 xfrm4_dst_ops;
	struct dst_ops___37 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___26;

struct net___39 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___201 *user_ns;
	struct ucounts___201 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___28 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___18 *rtnl;
	struct sock___18 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___31 *loopback_dev;
	struct netns_core core;
	struct netns_mib___2 mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___27 ipv4;
	struct netns_ipv6___37 ipv6;
	struct netns_sctp___17 sctp;
	struct netns_nf___2 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___27 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___18 *nfnl;
	struct sock___18 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___37 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can___2 can;
	struct sock___18 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___26 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cgroup_namespace___186 {
	refcount_t count;
	struct ns_common___28 ns;
	struct user_namespace___201 *user_ns;
	struct ucounts___201 *ucounts;
	struct css_set___186 *root_cset;
};

struct ucounts___201 {
	struct hlist_node node;
	struct user_namespace___201 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct msghdr___18 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___108 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___241 *msg_iocb;
};

struct kernfs_root___235;

struct kernfs_elem_dir___235 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___235 *root;
};

struct kernfs_syscall_ops___235;

struct kernfs_root___235 {
	struct kernfs_node___235 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___235 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___235 {
	struct kernfs_node___235 *target_kn;
};

struct kernfs_ops___235;

struct kernfs_elem_attr___235 {
	const struct kernfs_ops___235 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___235 *notify_next;
};

struct kernfs_node___235 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___235 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___235 dir;
		struct kernfs_elem_symlink___235 symlink;
		struct kernfs_elem_attr___235 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___235;

struct kernfs_ops___235 {
	int (*open)(struct kernfs_open_file___235 *);
	void (*release)(struct kernfs_open_file___235 *);
	int (*seq_show)(struct seq_file___217 *, void *);
	void * (*seq_start)(struct seq_file___217 *, loff_t *);
	void * (*seq_next)(struct seq_file___217 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___217 *, void *);
	ssize_t (*read)(struct kernfs_open_file___235 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___235 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___235 *, struct vm_area_struct___242 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___235 *, struct poll_table_struct___149 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___235 {
	int (*remount_fs)(struct kernfs_root___235 *, int *, char *);
	int (*show_options)(struct seq_file___217 *, struct kernfs_root___235 *);
	int (*mkdir)(struct kernfs_node___235 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___235 *);
	int (*rename)(struct kernfs_node___235 *, struct kernfs_node___235 *, const char *);
	int (*show_path)(struct seq_file___217 *, struct kernfs_node___235 *, struct kernfs_root___235 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___235 {
	struct kernfs_node___235 *kn;
	struct file___241 *file;
	struct seq_file___217 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___231 *vm_ops;
};

struct kobj_ns_type_operations___16 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___18 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___39 *net;
} possible_net_t___28;

struct proto___16;

struct sock_common___16 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___16 *skc_prot;
	possible_net_t___28 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___18 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff_head___27 {
	struct sk_buff___31 *next;
	struct sk_buff___31 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___16;

struct socket_wq___17;

struct socket___18;

struct sock___18 {
	struct sock_common___16 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___27 sk_error_queue;
	struct sk_buff_head___27 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___31 *head;
		struct sk_buff___31 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___16 *sk_filter;
	union {
		struct socket_wq___17 *sk_wq;
		struct socket_wq___17 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___17 *sk_rx_dst;
	struct dst_entry___17 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___31 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___27 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___241 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___16 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___181 *sk_peer_pid;
	const struct cred___234 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___18 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___102 *sk_memcg;
	void (*sk_state_change)(struct sock___18 *);
	void (*sk_data_ready)(struct sock___18 *);
	void (*sk_write_space)(struct sock___18 *);
	void (*sk_error_report)(struct sock___18 *);
	int (*sk_backlog_rcv)(struct sock___18 *, struct sk_buff___31 *);
	struct sk_buff___31 * (*sk_validate_xmit_skb)(struct sock___18 *, struct net_device___31 *, struct sk_buff___31 *);
	void (*sk_destruct)(struct sock___18 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct bin_attribute___206;

struct attribute_group___207 {
	const char *name;
	umode_t (*is_visible)(struct kobject___229 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___229 *, struct bin_attribute___206 *, int);
	struct attribute **attrs;
	struct bin_attribute___206 **bin_attrs;
};

struct bin_attribute___206 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___241 *, struct kobject___229 *, struct bin_attribute___206 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___241 *, struct kobject___229 *, struct bin_attribute___206 *, char *, loff_t, size_t);
	int (*mmap)(struct file___241 *, struct kobject___229 *, struct bin_attribute___206 *, struct vm_area_struct___242 *);
};

struct sysfs_ops___228 {
	ssize_t (*show)(struct kobject___229 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___229 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___228;

struct kset___228 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___229 kobj;
	const struct kset_uevent_ops___228 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___228 {
	void (*release)(struct kobject___229 *);
	const struct sysfs_ops___228 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___16 * (*child_ns_type)(struct kobject___229 *);
	const void * (*namespace)(struct kobject___229 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___228 {
	int (* const filter)(struct kset___228 *, struct kobject___229 *);
	const char * (* const name)(struct kset___228 *, struct kobject___229 *);
	int (* const uevent)(struct kset___228 *, struct kobject___229 *, struct kobj_uevent_env *);
};

struct socket_wq___17 {
	wait_queue_head_t wait;
	struct fasync_struct___240 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___17;

struct socket___18 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___17 *wq;
	struct file___241 *file;
	struct sock___18 *sk;
	const struct proto_ops___17 *ops;
};

typedef int (*sk_read_actor_t___16)(read_descriptor_t *, struct sk_buff___31 *, unsigned int, size_t);

struct proto_ops___17 {
	int family;
	struct module___195 *owner;
	int (*release)(struct socket___18 *);
	int (*bind)(struct socket___18 *, struct sockaddr *, int);
	int (*connect)(struct socket___18 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___18 *, struct socket___18 *);
	int (*accept)(struct socket___18 *, struct socket___18 *, int, bool);
	int (*getname)(struct socket___18 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___241 *, struct socket___18 *, struct poll_table_struct___149 *);
	int (*ioctl)(struct socket___18 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___18 *, int);
	int (*shutdown)(struct socket___18 *, int);
	int (*setsockopt)(struct socket___18 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___18 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___18 *, struct msghdr___18 *, size_t);
	int (*recvmsg)(struct socket___18 *, struct msghdr___18 *, size_t, int);
	int (*mmap)(struct file___241 *, struct socket___18 *, struct vm_area_struct___242 *);
	ssize_t (*sendpage)(struct socket___18 *, struct page___242 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___18 *, loff_t *, struct pipe_inode_info___51 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___18 *, int);
	int (*peek_len)(struct socket___18 *);
	int (*read_sock)(struct sock___18 *, read_descriptor_t *, sk_read_actor_t___16);
	int (*sendpage_locked)(struct sock___18 *, struct page___242 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___18 *, struct msghdr___18 *, size_t);
	int (*set_rcvlowat)(struct sock___18 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct nf_bridge_info___27;

struct sk_buff___31 {
	union {
		struct {
			struct sk_buff___31 *next;
			struct sk_buff___31 *prev;
			union {
				struct net_device___31 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___18 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___31 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___27 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct dev_pm_ops___205 {
	int (*prepare)(struct device___205 *);
	void (*complete)(struct device___205 *);
	int (*suspend)(struct device___205 *);
	int (*resume)(struct device___205 *);
	int (*freeze)(struct device___205 *);
	int (*thaw)(struct device___205 *);
	int (*poweroff)(struct device___205 *);
	int (*restore)(struct device___205 *);
	int (*suspend_late)(struct device___205 *);
	int (*resume_early)(struct device___205 *);
	int (*freeze_late)(struct device___205 *);
	int (*thaw_early)(struct device___205 *);
	int (*poweroff_late)(struct device___205 *);
	int (*restore_early)(struct device___205 *);
	int (*suspend_noirq)(struct device___205 *);
	int (*resume_noirq)(struct device___205 *);
	int (*freeze_noirq)(struct device___205 *);
	int (*thaw_noirq)(struct device___205 *);
	int (*poweroff_noirq)(struct device___205 *);
	int (*restore_noirq)(struct device___205 *);
	int (*runtime_suspend)(struct device___205 *);
	int (*runtime_resume)(struct device___205 *);
	int (*runtime_idle)(struct device___205 *);
};

struct dev_pm_domain___205 {
	struct dev_pm_ops___205 ops;
	void (*detach)(struct device___205 *, bool);
	int (*activate)(struct device___205 *);
	void (*sync)(struct device___205 *);
	void (*dismiss)(struct device___205 *);
};

struct bus_type___205 {
	const char *name;
	const char *dev_name;
	struct device___205 *dev_root;
	const struct attribute_group___207 **bus_groups;
	const struct attribute_group___207 **dev_groups;
	const struct attribute_group___207 **drv_groups;
	int (*match)(struct device___205 *, struct device_driver___205 *);
	int (*uevent)(struct device___205 *, struct kobj_uevent_env *);
	int (*probe)(struct device___205 *);
	int (*remove)(struct device___205 *);
	void (*shutdown)(struct device___205 *);
	int (*online)(struct device___205 *);
	int (*offline)(struct device___205 *);
	int (*suspend)(struct device___205 *, pm_message_t);
	int (*resume)(struct device___205 *);
	int (*num_vf)(struct device___205 *);
	int (*dma_configure)(struct device___205 *);
	const struct dev_pm_ops___205 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___205 {
	const char *name;
	struct bus_type___205 *bus;
	struct module___195 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___205 *);
	int (*remove)(struct device___205 *);
	void (*shutdown)(struct device___205 *);
	int (*suspend)(struct device___205 *, pm_message_t);
	int (*resume)(struct device___205 *);
	const struct attribute_group___207 **groups;
	const struct dev_pm_ops___205 *pm;
	void (*coredump)(struct device___205 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___205 {
	const char *name;
	const struct attribute_group___207 **groups;
	int (*uevent)(struct device___205 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___205 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___205 *);
	const struct dev_pm_ops___205 *pm;
};

struct class___205 {
	const char *name;
	struct module___195 *owner;
	const struct attribute_group___207 **class_groups;
	const struct attribute_group___207 **dev_groups;
	struct kobject___229 *dev_kobj;
	int (*dev_uevent)(struct device___205 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___205 *, umode_t *);
	void (*class_release)(struct class___205 *);
	void (*dev_release)(struct device___205 *);
	int (*shutdown_pre)(struct device___205 *);
	const struct kobj_ns_type_operations___16 *ns_type;
	const void * (*namespace)(struct device___205 *);
	const struct dev_pm_ops___205 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___48 {
	void * (*alloc)(struct device___205 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___205 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___205 *, struct vm_area_struct___242 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___205 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___205 *, struct page___242 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___205 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___205 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___205 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___205 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___205 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___205 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___205 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___205 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___205 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___205 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___205 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___205 *, u64);
	u64 (*get_required_mask)(struct device___205 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___140;

struct fwnode_handle___140 {
	struct fwnode_handle___140 *secondary;
	const struct fwnode_operations___140 *ops;
};

struct fwnode_reference_args___140;

struct fwnode_endpoint___140;

struct fwnode_operations___140 {
	struct fwnode_handle___140 * (*get)(struct fwnode_handle___140 *);
	void (*put)(struct fwnode_handle___140 *);
	bool (*device_is_available)(const struct fwnode_handle___140 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___140 *, const struct device___205 *);
	bool (*property_present)(const struct fwnode_handle___140 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___140 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___140 *, const char *, const char **, size_t);
	struct fwnode_handle___140 * (*get_parent)(const struct fwnode_handle___140 *);
	struct fwnode_handle___140 * (*get_next_child_node)(const struct fwnode_handle___140 *, struct fwnode_handle___140 *);
	struct fwnode_handle___140 * (*get_named_child_node)(const struct fwnode_handle___140 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___140 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___140 *);
	struct fwnode_handle___140 * (*graph_get_next_endpoint)(const struct fwnode_handle___140 *, struct fwnode_handle___140 *);
	struct fwnode_handle___140 * (*graph_get_remote_endpoint)(const struct fwnode_handle___140 *);
	struct fwnode_handle___140 * (*graph_get_port_parent)(struct fwnode_handle___140 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___140 *, struct fwnode_endpoint___140 *);
};

struct fwnode_endpoint___140 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___140 *local_fwnode;
};

struct fwnode_reference_args___140 {
	struct fwnode_handle___140 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___51;

struct pipe_buffer___51 {
	struct page___242 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___51 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___51 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___51 *, struct pipe_buffer___51 *);
	void (*release)(struct pipe_inode_info___51 *, struct pipe_buffer___51 *);
	int (*steal)(struct pipe_inode_info___51 *, struct pipe_buffer___51 *);
	union {
		bool (*get)(struct pipe_inode_info___51 *, struct pipe_buffer___51 *);
		struct {
			void (*get)(struct pipe_inode_info___51 *, struct pipe_buffer___51 *);
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
};

struct nf_bridge_info___27 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___27 = 0,
		BRNF_PROTO_8021Q___27 = 1,
		BRNF_PROTO_PPPOE___27 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___31 *physindev;
	struct net_device___31 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___27(struct sk_buff___31 **);

struct net_device_ops___27;

struct ethtool_ops___27;

struct l3mdev_ops___17;

struct ndisc_ops___10;

struct xfrmdev_ops___27;

struct tlsdev_ops___27;

struct header_ops___27;

struct inet6_dev___10;

struct netdev_rx_queue___27;

struct mini_Qdisc___26;

struct netdev_queue___27;

struct Qdisc___26;

struct rtnl_link_ops___26;

struct dcbnl_rtnl_ops___27;

struct net_device___31 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___27 *netdev_ops;
	const struct ethtool_ops___27 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___17 *l3mdev_ops;
	const struct ndisc_ops___10 *ndisc_ops;
	const struct xfrmdev_ops___27 *xfrmdev_ops;
	const struct tlsdev_ops___27 *tlsdev_ops;
	const struct header_ops___27 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___228 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___10 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___27 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___26 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___27 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___26 *miniq_ingress;
	struct netdev_queue___27 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___27 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___26 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___26 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___27 = 0,
		NETREG_REGISTERED___27 = 1,
		NETREG_UNREGISTERING___27 = 2,
		NETREG_UNREGISTERED___27 = 3,
		NETREG_RELEASED___27 = 4,
		NETREG_DUMMY___27 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___27 = 0,
		RTNL_LINK_INITIALIZING___27 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___31 *);
	struct netpoll_info *npinfo;
	possible_net_t___28 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___205 dev;
	const struct attribute_group___207 *sysfs_groups[4];
	const struct attribute_group___207 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___26 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___27 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct ethtool_ops___27 {
	int (*get_settings)(struct net_device___31 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___31 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___31 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___31 *);
	void (*get_regs)(struct net_device___31 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___31 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___31 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___31 *);
	void (*set_msglevel)(struct net_device___31 *, u32);
	int (*nway_reset)(struct net_device___31 *);
	u32 (*get_link)(struct net_device___31 *);
	int (*get_eeprom_len)(struct net_device___31 *);
	int (*get_eeprom)(struct net_device___31 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___31 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___31 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___31 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___31 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___31 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___31 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___31 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___31 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___31 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___31 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___31 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___31 *);
	void (*complete)(struct net_device___31 *);
	u32 (*get_priv_flags)(struct net_device___31 *);
	int (*set_priv_flags)(struct net_device___31 *, u32);
	int (*get_sset_count)(struct net_device___31 *, int);
	int (*get_rxnfc)(struct net_device___31 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___31 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___31 *, struct ethtool_flash *);
	int (*reset)(struct net_device___31 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___31 *);
	u32 (*get_rxfh_indir_size)(struct net_device___31 *);
	int (*get_rxfh)(struct net_device___31 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___31 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___31 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___31 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___31 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___31 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___31 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___31 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___31 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___31 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___31 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___31 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___31 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___31 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___31 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___31 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___31 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___31 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___31 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___31 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___31 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___31 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	int (*get_fecparam)(struct net_device___31 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___31 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___31 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___31 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___31 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___27;

struct inet_frags___27 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___27 *, const void *);
	void (*destructor)(struct inet_frag_queue___27 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___27 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___31 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___31 *fragments_tail;
	struct sk_buff___31 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___27 *net;
	struct callback_head rcu;
};

struct ip_ra_chain___6 {
	struct ip_ra_chain___6 *next;
	struct sock___18 *sk;
	union {
		void (*destructor)(struct sock___18 *);
		struct sock___18 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___16;

struct fib_lookup_arg___16;

struct fib_rules_ops___16 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___16 *, struct flowi *, int, struct fib_lookup_arg___16 *);
	bool (*suppress)(struct fib_rule___16 *, struct fib_lookup_arg___16 *);
	int (*match)(struct fib_rule___16 *, struct flowi *, int);
	int (*configure)(struct fib_rule___16 *, struct sk_buff___31 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___16 *);
	int (*compare)(struct fib_rule___16 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___16 *, struct sk_buff___31 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___16 *);
	void (*flush_cache)(struct fib_rules_ops___16 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___195 *owner;
	struct net___39 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___16 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___39 *);
	int (*fib_dump)(struct net___39 *, struct notifier_block *);
	struct module___195 *owner;
	struct callback_head rcu;
};

struct dst_entry___17 {
	struct net_device___31 *dev;
	struct dst_ops___37 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___31 *);
	int (*output)(struct net___39 *, struct sock___18 *, struct sk_buff___31 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___16;

struct neigh_parms___17;

struct neigh_ops___16;

struct neighbour___17 {
	struct neighbour___17 *next;
	struct neigh_table___16 *tbl;
	struct neigh_parms___17 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___27 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___17 *, struct sk_buff___31 *);
	const struct neigh_ops___16 *ops;
	struct callback_head rcu;
	struct net_device___31 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct bpf_prog_aux___28;

struct bpf_prog___26 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___28 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

struct pernet_operations___28 {
	struct list_head list;
	int (*init)(struct net___39 *);
	void (*exit)(struct net___39 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___27 {
	int (*ieee_getets)(struct net_device___31 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___31 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___31 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___31 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___31 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___31 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___31 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___31 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___31 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___31 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___31 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___31 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___31 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___31 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___31 *);
	u8 (*setstate)(struct net_device___31 *, u8);
	void (*getpermhwaddr)(struct net_device___31 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___31 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___31 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___31 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___31 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___31 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___31 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___31 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___31 *, int, u8 *);
	void (*setpfccfg)(struct net_device___31 *, int, u8);
	void (*getpfccfg)(struct net_device___31 *, int, u8 *);
	u8 (*setall)(struct net_device___31 *);
	u8 (*getcap)(struct net_device___31 *, int, u8 *);
	int (*getnumtcs)(struct net_device___31 *, int, u8 *);
	int (*setnumtcs)(struct net_device___31 *, int, u8);
	u8 (*getpfcstate)(struct net_device___31 *);
	void (*setpfcstate)(struct net_device___31 *, u8);
	void (*getbcncfg)(struct net_device___31 *, int, u32 *);
	void (*setbcncfg)(struct net_device___31 *, int, u32);
	void (*getbcnrp)(struct net_device___31 *, int, u8 *);
	void (*setbcnrp)(struct net_device___31 *, int, u8);
	int (*setapp)(struct net_device___31 *, u8, u16, u8);
	int (*getapp)(struct net_device___31 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___31 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___31 *, int, u8);
	u8 (*getdcbx)(struct net_device___31 *);
	u8 (*setdcbx)(struct net_device___31 *, u8);
	int (*peer_getappinfo)(struct net_device___31 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___31 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___31 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___31 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___31 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___31 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct bpf_map___186;

struct bpf_map_ops___186 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___186 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___186 *, struct file___241 *);
	void (*map_free)(struct bpf_map___186 *);
	int (*map_get_next_key)(struct bpf_map___186 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___186 *);
	void * (*map_lookup_elem)(struct bpf_map___186 *, void *);
	int (*map_update_elem)(struct bpf_map___186 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___186 *, void *);
	int (*map_push_elem)(struct bpf_map___186 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___186 *, void *);
	int (*map_peek_elem)(struct bpf_map___186 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___186 *, struct file___241 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___186 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___186 *, void *, struct seq_file___217 *);
	int (*map_check_btf)(const struct bpf_map___186 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___186 {
	const struct bpf_map_ops___186 *ops;
	struct bpf_map___186 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___234 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___27;

struct bpf_map_dev_ops___27 {
	int (*map_get_next_key)(struct bpf_offloaded_map___27 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___27 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___27 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___27 *, void *);
};

struct bpf_offloaded_map___27 {
	struct bpf_map___186 map;
	struct net_device___31 *netdev;
	const struct bpf_map_dev_ops___27 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___26 {
	int (*test_run)(struct bpf_prog___26 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___26 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___26 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___26 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___26 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___26 *, u32 *);
};

struct bpf_prog_offload_ops___26 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___26 *);
	int (*translate)(struct bpf_prog___26 *);
	void (*destroy)(struct bpf_prog___26 *);
};

struct bpf_prog_offload___26 {
	struct bpf_prog___26 *prog;
	struct net_device___31 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___26 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___28 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___26 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___26 *ops;
	struct bpf_map___186 **used_maps;
	struct bpf_prog___26 *prog;
	struct user_struct___234 *user;
	u64 load_time;
	struct bpf_map___186 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___26 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___26 {
	struct bpf_prog___26 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___26 {
	struct callback_head rcu;
	struct bpf_prog_array_item___26 items[0];
};

struct cgroup_bpf___26 {
	struct bpf_prog_array___26 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___26 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___186;

typedef void (*kthread_work_func_t___186)(struct kthread_work___186 *);

struct kthread_worker___186;

struct kthread_work___186 {
	struct list_head node;
	kthread_work_func_t___186 func;
	struct kthread_worker___186 *worker;
	int canceling;
};

struct kthread_worker___186 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___242 *task;
	struct kthread_work___186 *current_work;
};

struct kthread_delayed_work___186 {
	struct kthread_work___186 work;
	struct timer_list timer;
};

struct psi_group___186 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___186 *poll_kworker;
	struct kthread_delayed_work___186 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___186;

struct cgroup_rstat_cpu___186;

struct cgroup___186 {
	struct cgroup_subsys_state___187 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___235 *kn;
	struct cgroup_file___186 procs_file;
	struct cgroup_file___186 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___187 *subsys[13];
	struct cgroup_root___186 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___186 *dom_cgrp;
	struct cgroup_rstat_cpu___186 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___26 bpf;
	atomic_t congestion_count;
	struct cgroup___186 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___186 psi;
	int ancestor_ids[0];
};

struct cftype___186;

struct cgroup_subsys___186 {
	struct cgroup_subsys_state___187 * (*css_alloc)(struct cgroup_subsys_state___187 *);
	int (*css_online)(struct cgroup_subsys_state___187 *);
	void (*css_offline)(struct cgroup_subsys_state___187 *);
	void (*css_released)(struct cgroup_subsys_state___187 *);
	void (*css_free)(struct cgroup_subsys_state___187 *);
	void (*css_reset)(struct cgroup_subsys_state___187 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___187 *, int);
	int (*css_extra_stat_show)(struct seq_file___217 *, struct cgroup_subsys_state___187 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___242 *);
	void (*cancel_fork)(struct task_struct___242 *);
	void (*fork)(struct task_struct___242 *);
	void (*exit)(struct task_struct___242 *);
	void (*free)(struct task_struct___242 *);
	void (*bind)(struct cgroup_subsys_state___187 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___186 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___186 *dfl_cftypes;
	struct cftype___186 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___186 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___186 *updated_children;
	struct cgroup___186 *updated_next;
};

struct cgroup_root___186 {
	struct kernfs_root___235 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___186 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___186 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___186 *ss;
	struct list_head node;
	struct kernfs_ops___235 *kf_ops;
	int (*open)(struct kernfs_open_file___235 *);
	void (*release)(struct kernfs_open_file___235 *);
	u64 (*read_u64)(struct cgroup_subsys_state___187 *, struct cftype___186 *);
	s64 (*read_s64)(struct cgroup_subsys_state___187 *, struct cftype___186 *);
	int (*seq_show)(struct seq_file___217 *, void *);
	void * (*seq_start)(struct seq_file___217 *, loff_t *);
	void * (*seq_next)(struct seq_file___217 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___217 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___187 *, struct cftype___186 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___187 *, struct cftype___186 *, s64);
	ssize_t (*write)(struct kernfs_open_file___235 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___235 *, struct poll_table_struct___149 *);
};

struct xdp_rxq_info___27 {
	struct net_device___31 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___27 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___31 *dev_rx;
};

struct netlink_callback___27 {
	struct sk_buff___31 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___27 *);
	int (*dump)(struct sk_buff___31 *, struct netlink_callback___27 *);
	int (*done)(struct netlink_callback___27 *);
	void *data;
	struct module___195 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___27 {
	int (*create)(struct sk_buff___31 *, struct net_device___31 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___31 *, unsigned char *);
	int (*cache)(const struct neighbour___17 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___31 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___27 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___27 *, int);
	int poll_owner;
	struct net_device___31 *dev;
	struct sk_buff___31 *gro_list;
	struct sk_buff___31 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___27 {
	struct net_device___31 *dev;
	struct Qdisc___26 *qdisc;
	struct Qdisc___26 *qdisc_sleeping;
	struct kobject___229 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___31 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___26 {
	struct sk_buff___31 *head;
	struct sk_buff___31 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___26;

struct Qdisc___26 {
	int (*enqueue)(struct sk_buff___31 *, struct Qdisc___26 *, struct sk_buff___31 **);
	struct sk_buff___31 * (*dequeue)(struct Qdisc___26 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___26 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___27 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___27 gso_skb;
	struct qdisc_skb_head___26 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___26 *next_sched;
	struct sk_buff_head___27 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___27 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___229 kobj;
	struct net_device___31 *dev;
	long: 64;
	struct xdp_rxq_info___27 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___27)(struct net_device___31 *, struct sk_buff___31 *, struct net_device___31 *);

struct netdev_bpf___27 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___26 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___26 *prog;
			const struct bpf_prog_offload_ops___26 *ops;
		} verifier;
		struct {
			struct bpf_prog___26 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___27 *offmap;
		};
		struct {
			struct xdp_umem *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___27 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___31 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___27 {
	int (*tls_dev_add)(struct net_device___31 *, struct sock___18 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___31 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___31 *, struct sock___18 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___27 {
	int (*ndo_init)(struct net_device___31 *);
	void (*ndo_uninit)(struct net_device___31 *);
	int (*ndo_open)(struct net_device___31 *);
	int (*ndo_stop)(struct net_device___31 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___31 *, struct net_device___31 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___31 *, struct net_device___31 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___31 *, struct sk_buff___31 *, struct net_device___31 *, select_queue_fallback_t___27);
	void (*ndo_change_rx_flags)(struct net_device___31 *, int);
	void (*ndo_set_rx_mode)(struct net_device___31 *);
	int (*ndo_set_mac_address)(struct net_device___31 *, void *);
	int (*ndo_validate_addr)(struct net_device___31 *);
	int (*ndo_do_ioctl)(struct net_device___31 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___31 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___31 *, int);
	int (*ndo_neigh_setup)(struct net_device___31 *, struct neigh_parms___17 *);
	void (*ndo_tx_timeout)(struct net_device___31 *);
	void (*ndo_get_stats64)(struct net_device___31 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___31 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___31 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___31 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___31 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___31 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___31 *);
	int (*ndo_netpoll_setup)(struct net_device___31 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___31 *);
	int (*ndo_set_vf_mac)(struct net_device___31 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___31 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___31 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___31 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___31 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___31 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___31 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___31 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___31 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___31 *, int, struct sk_buff___31 *);
	int (*ndo_set_vf_guid)(struct net_device___31 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___31 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___31 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___31 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___31 *, const struct sk_buff___31 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___31 *, struct net_device___31 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___31 *, struct net_device___31 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___31 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___31 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___31 *, struct neighbour___17 *);
	void (*ndo_neigh_destroy)(struct net_device___31 *, struct neighbour___17 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___31 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___31 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___31 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___31 *, struct netlink_callback___27 *, struct net_device___31 *, struct net_device___31 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___31 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___31 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___31 *, u32, u32, struct net_device___31 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___31 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___31 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___31 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___31 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___31 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___31 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___31 *, struct net_device___31 *);
	void (*ndo_dfwd_del_station)(struct net_device___31 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___31 *);
	int (*ndo_set_tx_maxrate)(struct net_device___31 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___31 *);
	int (*ndo_change_proto_down)(struct net_device___31 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___31 *, struct sk_buff___31 *);
	void (*ndo_set_rx_headroom)(struct net_device___31 *, int);
	int (*ndo_bpf)(struct net_device___31 *, struct netdev_bpf___27 *);
	int (*ndo_xdp_xmit)(struct net_device___31 *, int, struct xdp_frame___27 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___31 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___31 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___17 {
	possible_net_t___28 net;
	struct net_device___31 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___17 *);
	void (*neigh_cleanup)(struct neighbour___17 *);
	struct neigh_table___16 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___17 {
	u32 (*l3mdev_fib_table)(const struct net_device___31 *);
	struct sk_buff___31 * (*l3mdev_l3_rcv)(struct net_device___31 *, struct sk_buff___31 *, u16);
	struct sk_buff___31 * (*l3mdev_l3_out)(struct net_device___31 *, struct sock___18 *, struct sk_buff___31 *, u16);
	struct dst_entry___17 * (*l3mdev_link_scope_lookup)(const struct net_device___31 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct ndisc_ops___10 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___31 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___31 *, struct neighbour___17 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___31 *, u8, struct neighbour___17 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___31 *, struct sk_buff___31 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___39 *, struct net_device___31 *, const struct prefix_info *, struct inet6_dev___10 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___9;

struct inet6_dev___10 {
	struct net_device___31 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___9 *mc_list;
	struct ifmcaddr6___9 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	u8 rndid[8];
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___17 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
};

struct tcf_proto___26;

struct mini_Qdisc___26 {
	struct tcf_proto___26 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___26 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___31 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___39 *, struct net_device___31 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___31 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___31 *, struct list_head *);
	size_t (*get_size)(const struct net_device___31 *);
	int (*fill_info)(struct sk_buff___31 *, const struct net_device___31 *);
	size_t (*get_xstats_size)(const struct net_device___31 *);
	int (*fill_xstats)(struct sk_buff___31 *, const struct net_device___31 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___31 *, struct net_device___31 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___31 *, const struct net_device___31 *);
	int (*fill_slave_info)(struct sk_buff___31 *, const struct net_device___31 *, const struct net_device___31 *);
	struct net___39 * (*get_link_net)(const struct net_device___31 *);
	size_t (*get_linkxstats_size)(const struct net_device___31 *, int);
	int (*fill_linkxstats)(struct sk_buff___31 *, const struct net_device___31 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___27 {
	struct list_head poll_list;
	struct sk_buff_head___27 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___27 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___26 *output_queue;
	struct Qdisc___26 **output_queue_tailp;
	struct sk_buff___31 *completion_queue;
	struct sk_buff_head___27 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___27 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___27 input_pkt_queue;
	struct napi_struct___27 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bdi_writeback_congested___117 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___117 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___117 {
	struct bio___117 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___117 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___117 bip_inline_vecs[0];
};

struct bio_set___117 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___117 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___102 {
	struct mem_cgroup___102 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___102 {
	struct lruvec___241 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___102 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___102 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct kernel_param_ops___192 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___192 *);
	int (*get)(char *, const struct kernel_param___192 *);
	void (*free)(void *);
};

struct kparam_array___192;

struct kernel_param___192 {
	const char *name;
	struct module___195 *mod;
	const struct kernel_param_ops___192 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___192 *arr;
	};
};

struct kparam_array___192 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___192 *ops;
	void *elem;
};

struct module_attribute___192 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___192 *, struct module_kobject___192 *, char *);
	ssize_t (*store)(struct module_attribute___192 *, struct module_kobject___192 *, const char *, size_t);
	void (*setup)(struct module___195 *, const char *);
	int (*test)(struct module___195 *);
	void (*free)(struct module___195 *);
};

struct gnet_dump___26 {
	spinlock_t *lock;
	struct sk_buff___31 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___26;

struct Qdisc_ops___26 {
	struct Qdisc_ops___26 *next;
	const struct Qdisc_class_ops___26 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___31 *, struct Qdisc___26 *, struct sk_buff___31 **);
	struct sk_buff___31 * (*dequeue)(struct Qdisc___26 *);
	struct sk_buff___31 * (*peek)(struct Qdisc___26 *);
	int (*init)(struct Qdisc___26 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___26 *);
	void (*destroy)(struct Qdisc___26 *);
	int (*change)(struct Qdisc___26 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___26 *);
	int (*change_tx_queue_len)(struct Qdisc___26 *, unsigned int);
	int (*dump)(struct Qdisc___26 *, struct sk_buff___31 *);
	int (*dump_stats)(struct Qdisc___26 *, struct gnet_dump___26 *);
	void (*ingress_block_set)(struct Qdisc___26 *, u32);
	void (*egress_block_set)(struct Qdisc___26 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___26 *);
	u32 (*egress_block_get)(struct Qdisc___26 *);
	struct module___195 *owner;
};

struct tcf_block___26;

struct Qdisc_class_ops___26 {
	unsigned int flags;
	struct netdev_queue___27 * (*select_queue)(struct Qdisc___26 *, struct tcmsg *);
	int (*graft)(struct Qdisc___26 *, long unsigned int, struct Qdisc___26 *, struct Qdisc___26 **, struct netlink_ext_ack *);
	struct Qdisc___26 * (*leaf)(struct Qdisc___26 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___26 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___26 *, u32);
	int (*change)(struct Qdisc___26 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___26 *, long unsigned int);
	void (*walk)(struct Qdisc___26 *, struct qdisc_walker *);
	struct tcf_block___26 * (*tcf_block)(struct Qdisc___26 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___26 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___26 *, long unsigned int);
	int (*dump)(struct Qdisc___26 *, long unsigned int, struct sk_buff___31 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___26 *, long unsigned int, struct gnet_dump___26 *);
};

struct tcf_chain___26;

struct tcf_block___26 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___39 *net;
	struct Qdisc___26 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___26 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___26;

struct tcf_proto_ops___26;

struct tcf_proto___26 {
	struct tcf_proto___26 *next;
	void *root;
	int (*classify)(struct sk_buff___31 *, const struct tcf_proto___26 *, struct tcf_result___26 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___26 *ops;
	struct tcf_chain___26 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___26 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___26 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___26 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___31 *, const struct tcf_proto___26 *, struct tcf_result___26 *);
	int (*init)(struct tcf_proto___26 *);
	void (*destroy)(struct tcf_proto___26 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___26 *, u32);
	void (*put)(struct tcf_proto___26 *, void *);
	int (*change)(struct net___39 *, struct sk_buff___31 *, struct tcf_proto___26 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___26 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___26 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___26 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___39 *, struct tcf_chain___26 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___39 *, struct tcf_proto___26 *, void *, struct sk_buff___31 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___31 *, struct net___39 *, void *);
	struct module___195 *owner;
	int flags;
};

struct tcf_chain___26 {
	struct mutex filter_chain_lock;
	struct tcf_proto___26 *filter_chain;
	struct list_head list;
	struct tcf_block___26 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___26 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___16 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___26 *prog;
};

struct bpf_redirect_info___26 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___186 *map;
	struct bpf_map___186 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___16;

struct neigh_hash_table___16;

struct neigh_table___16 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___31 *, __u32 *);
	bool (*key_eq)(const struct neighbour___17 *, const void *);
	int (*constructor)(struct neighbour___17 *);
	int (*pconstructor)(struct pneigh_entry___16 *);
	void (*pdestructor)(struct pneigh_entry___16 *);
	void (*proxy_redo)(struct sk_buff___31 *);
	char *id;
	struct neigh_parms___17 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___27 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___16 *nht;
	struct pneigh_entry___16 **phash_buckets;
};

struct neigh_ops___16 {
	int family;
	void (*solicit)(struct neighbour___17 *, struct sk_buff___31 *);
	void (*error_report)(struct neighbour___17 *, struct sk_buff___31 *);
	int (*output)(struct neighbour___17 *, struct sk_buff___31 *);
	int (*connected_output)(struct neighbour___17 *, struct sk_buff___31 *);
};

struct pneigh_entry___16 {
	struct pneigh_entry___16 *next;
	possible_net_t___28 net;
	struct net_device___31 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___16 {
	struct neighbour___17 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___16 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___16 *ctarget;
	struct net___39 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___16 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___16 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___10;

struct timewait_sock_ops___10;

struct proto___16 {
	void (*close)(struct sock___18 *, long int);
	int (*pre_connect)(struct sock___18 *, struct sockaddr *, int);
	int (*connect)(struct sock___18 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___18 *, int);
	struct sock___18 * (*accept)(struct sock___18 *, int, int *, bool);
	int (*ioctl)(struct sock___18 *, int, long unsigned int);
	int (*init)(struct sock___18 *);
	void (*destroy)(struct sock___18 *);
	void (*shutdown)(struct sock___18 *, int);
	int (*setsockopt)(struct sock___18 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___18 *, int, int, char *, int *);
	void (*keepalive)(struct sock___18 *, int);
	int (*sendmsg)(struct sock___18 *, struct msghdr___18 *, size_t);
	int (*recvmsg)(struct sock___18 *, struct msghdr___18 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___18 *, struct page___242 *, int, size_t, int);
	int (*bind)(struct sock___18 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___18 *, struct sk_buff___31 *);
	void (*release_cb)(struct sock___18 *);
	int (*hash)(struct sock___18 *);
	void (*unhash)(struct sock___18 *);
	void (*rehash)(struct sock___18 *);
	int (*get_port)(struct sock___18 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___18 *);
	bool (*stream_memory_read)(const struct sock___18 *);
	void (*enter_memory_pressure)(struct sock___18 *);
	void (*leave_memory_pressure)(struct sock___18 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___10 *rsk_prot;
	struct timewait_sock_ops___10 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___195 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___18 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct request_sock___10;

struct request_sock_ops___10 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___18 *, struct request_sock___10 *);
	void (*send_ack)(const struct sock___18 *, struct sk_buff___31 *, struct request_sock___10 *);
	void (*send_reset)(const struct sock___18 *, struct sk_buff___31 *);
	void (*destructor)(struct request_sock___10 *);
	void (*syn_ack_timeout)(const struct request_sock___10 *);
};

struct timewait_sock_ops___10 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___18 *, struct sock___18 *, void *);
	void (*twsk_destructor)(struct sock___18 *);
};

struct request_sock___10 {
	struct sock_common___16 __req_common;
	struct request_sock___10 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___10 *rsk_ops;
	struct sock___18 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___9 {
	struct in6_addr mca_addr;
	struct inet6_dev___10 *idev;
	struct ifmcaddr6___9 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ip6_ra_chain___9 {
	struct ip6_ra_chain___9 *next;
	struct sock___18 *sk;
	int sel;
	void (*destructor)(struct sock___18 *);
};

struct linux_binprm___40 {
	char buf[256];
	struct vm_area_struct___242 *vma;
	long unsigned int vma_pages;
	struct mm_struct___241 *mm;
	long unsigned int p;
	unsigned int called_set_creds: 1;
	unsigned int cap_elevated: 1;
	unsigned int secureexec: 1;
	unsigned int recursion_depth;
	struct file___241 *file;
	struct cred___234 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
};

struct coredump_params___39 {
	union {
		const kernel_siginfo_t *siginfo;
		struct {
			const siginfo_t *siginfo;
		} __UNIQUE_ID_rh_kabi_hide77;
		union {		};
	};
	struct pt_regs *regs;
	struct file___241 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
};

struct inode_security_struct___2 {
	struct inode___241 *inode;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
	u32 task_sid;
	u32 sid;
	u16 sclass;
	unsigned char initialized;
	spinlock_t lock;
};

enum sel_inos {
	SEL_ROOT_INO = 2,
	SEL_LOAD = 3,
	SEL_ENFORCE = 4,
	SEL_CONTEXT = 5,
	SEL_ACCESS = 6,
	SEL_CREATE = 7,
	SEL_RELABEL = 8,
	SEL_USER = 9,
	SEL_POLICYVERS = 10,
	SEL_COMMIT_BOOLS = 11,
	SEL_MLS = 12,
	SEL_DISABLE = 13,
	SEL_MEMBER = 14,
	SEL_CHECKREQPROT = 15,
	SEL_COMPAT_NET = 16,
	SEL_REJECT_UNKNOWN = 17,
	SEL_DENY_UNKNOWN = 18,
	SEL_STATUS = 19,
	SEL_POLICY = 20,
	SEL_VALIDATE_TRANS = 21,
	SEL_INO_NEXT = 22,
};

struct selinux_fs_info {
	struct dentry___241 *bool_dir;
	unsigned int bool_num;
	char **bool_pending_names;
	unsigned int *bool_pending_values;
	struct dentry___241 *class_dir;
	long unsigned int last_class_ino;
	bool policy_opened;
	struct dentry___241 *policycap_dir;
	struct mutex mutex;
	long unsigned int last_ino;
	struct selinux_state *state;
	struct super_block___240 *sb;
};

struct policy_load_memory {
	size_t len;
	void *data;
};

enum {
	SELNL_MSG_SETENFORCE = 16,
	SELNL_MSG_POLICYLOAD = 17,
	SELNL_MSG_MAX = 18,
};

enum selinux_nlgroups {
	SELNLGRP_NONE = 0,
	SELNLGRP_AVC = 1,
	__SELNLGRP_MAX = 2,
};

struct selnl_msg_setenforce {
	__s32 val;
};

struct selnl_msg_policyload {
	__u32 seqno;
};

struct module___196;

struct file___242;

struct kiocb___242;

struct iov_iter___109;

struct poll_table_struct___150;

struct vm_area_struct___243;

struct inode___242;

struct file_lock___242;

struct page___243;

struct pipe_inode_info___52;

struct seq_file___218;

struct file_operations___242 {
	struct module___196 *owner;
	loff_t (*llseek)(struct file___242 *, loff_t, int);
	ssize_t (*read)(struct file___242 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___242 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___242 *, struct iov_iter___109 *);
	ssize_t (*write_iter)(struct kiocb___242 *, struct iov_iter___109 *);
	int (*iopoll)(struct kiocb___242 *, bool);
	int (*iterate)(struct file___242 *, struct dir_context *);
	int (*iterate_shared)(struct file___242 *, struct dir_context *);
	__poll_t (*poll)(struct file___242 *, struct poll_table_struct___150 *);
	long int (*unlocked_ioctl)(struct file___242 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___242 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___242 *, struct vm_area_struct___243 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___242 *, struct file___242 *);
	int (*flush)(struct file___242 *, fl_owner_t);
	int (*release)(struct inode___242 *, struct file___242 *);
	int (*fsync)(struct file___242 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___242 *, int);
	int (*lock)(struct file___242 *, int, struct file_lock___242 *);
	ssize_t (*sendpage)(struct file___242 *, struct page___243 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___242 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___242 *, int, struct file_lock___242 *);
	ssize_t (*splice_write)(struct pipe_inode_info___52 *, struct file___242 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___242 *, loff_t *, struct pipe_inode_info___52 *, size_t, unsigned int);
	int (*setlease)(struct file___242 *, long int, struct file_lock___242 **, void **);
	long int (*fallocate)(struct file___242 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___218 *, struct file___242 *);
	ssize_t (*copy_file_range)(struct file___242 *, loff_t, struct file___242 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___242 *, loff_t, struct file___242 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___242 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___242 {
	u64 seqnum;
	struct vm_area_struct___243 *vmas[4];
};

struct page_frag___242 {
	struct page___243 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___242;

struct mem_cgroup___103;

struct pid___182;

struct cred___235;

struct nsproxy___222;

struct signal_struct___200;

struct bio_list___118;

struct backing_dev_info___118;

struct css_set___187;

struct vm_struct___159;

struct task_struct___243 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___243 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___242 *mm;
	struct mm_struct___242 *active_mm;
	struct vmacache___242 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___243 *real_parent;
	struct task_struct___243 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___243 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___103 *active_memcg;
	long int rh_reserved2;
	struct pid___182 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___182 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___182 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___235 *ptracer_cred;
	const struct cred___235 *real_cred;
	const struct cred___235 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___222 *nsproxy;
	struct signal_struct___200 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___243 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___118 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___118 *backing_dev_info;
	struct io_context___60 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___187 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___52 *splice_pipe;
	struct page_frag___242 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___103 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___243 *oom_reaper_list;
	struct vm_struct___159 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___127 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___243 *pgtable_t___242;

struct address_space___241;

struct dev_pagemap___232;

struct page___243 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___241 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___243 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___242 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___242 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___232 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___103 *mem_cgroup;
};

struct pglist_data___242;

struct lruvec___242 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___242 *pgdat;
};

struct zone___242 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___242 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___242 {
	struct zone___242 *zone;
	int zone_idx;
};

struct zonelist___242 {
	struct zoneref___242 _zonerefs[25];
};

struct pglist_data___242 {
	struct zone___242 node_zones[3];
	struct zonelist___242 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___243 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___243 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___242 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___243 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___243 *owner;
};

struct secondary_data___243 {
	void *stack;
	struct task_struct___243 *task;
	long int status;
};

struct blocking_notifier_head___242 {
	struct rw_semaphore___243 rwsem;
	struct notifier_block *head;
};

struct cgroup___187;

struct cgroup_subsys___187;

struct cgroup_subsys_state___188 {
	struct cgroup___187 *cgroup;
	struct cgroup_subsys___187 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___188 *parent;
};

struct kernfs_node___236;

struct cgroup_file___187 {
	struct kernfs_node___236 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___103;

struct mem_cgroup___103 {
	struct cgroup_subsys_state___188 css;
	struct mem_cgroup_id___16 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___187 events_file;
	struct cgroup_file___187 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___243 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___103 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___182;

struct upid___182 {
	int nr;
	struct pid_namespace___182 *ns;
};

struct dentry___242;

struct user_namespace___202;

struct ucounts___202;

struct pid_namespace___182 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___243 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___182 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___242 *proc_self;
	struct dentry___242 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___202 *user_ns;
	struct ucounts___202 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___28 ns;
};

struct pid___182 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___182 numbers[1];
};

struct key___235;

struct user_namespace___202 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___202 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___28 ns;
	long unsigned int flags;
	struct key___235 *persistent_keyring_register;
	struct rw_semaphore___243 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___202 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct user_struct___235 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___235 *uid_keyring;
	struct key___235 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___232;

struct vm_area_struct___243 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___243 *vm_next;
	struct vm_area_struct___243 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___242 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___232 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___242 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___242;

struct mm_struct___242 {
	struct {
		struct vm_area_struct___243 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___242 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___243 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___242 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___243 *owner;
		struct user_namespace___202 *user_ns;
		struct file___242 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___242 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___235 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___235 *session_keyring;
	struct key___235 *process_keyring;
	struct key___235 *thread_keyring;
	struct key___235 *request_key_auth;
	void *security;
	struct user_struct___235 *user;
	struct user_namespace___202 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___40;

struct cgroup_namespace___187;

struct nsproxy___222 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___182 *pid_ns_for_children;
	struct net___40 *net_ns;
	struct cgroup_namespace___187 *cgroup_ns;
};

struct signal_struct___200 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___243 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___243 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___182 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___182 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___242 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___182 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___118;

struct bio_list___118 {
	struct bio___118 *head;
	struct bio___118 *tail;
};

struct bdi_writeback_congested___118;

struct bdi_writeback___118 {
	struct backing_dev_info___118 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___118 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___188 *memcg_css;
	struct cgroup_subsys_state___188 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___206;

struct backing_dev_info___118 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___118 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___206 *dev;
	struct device___206 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___242 *debug_dir;
	struct dentry___242 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___187 {
	struct cgroup_subsys_state___188 *subsys[13];
	refcount_t refcount;
	struct css_set___187 *dom_cset;
	struct cgroup___187 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___187 *mg_src_cgrp;
	struct cgroup___187 *mg_dst_cgrp;
	struct css_set___187 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___241;

struct pipe_buffer___52;

struct pipe_inode_info___52 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___243 *tmp_page;
	struct fasync_struct___241 *fasync_readers;
	struct fasync_struct___241 *fasync_writers;
	struct pipe_buffer___52 *bufs;
	struct user_struct___235 *user;
};

struct vm_struct___159 {
	struct vm_struct___159 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___243 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___212 {
	struct task_struct___243 task;
	long unsigned int stack[8192];
};

struct address_space_operations___241;

struct address_space___241 {
	struct inode___242 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___243 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___241 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___232)(struct vm_area_struct___243 *, long unsigned int, const struct page___243 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___232)(struct page___243 *, void *);

struct dev_pagemap___232 {
	dev_page_fault_t___232 page_fault;
	dev_page_free_t___232 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___206 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___241 {
	struct vfsmount *mnt;
	struct dentry___242 *dentry;
};

struct fown_struct___182 {
	rwlock_t lock;
	struct pid___182 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___242 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___241 f_path;
	struct inode___242 *f_inode;
	const struct file_operations___242 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___182 f_owner;
	const struct cred___235 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___241 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___232;

struct vm_operations_struct___232 {
	void (*open)(struct vm_area_struct___243 *);
	void (*close)(struct vm_area_struct___243 *);
	int (*split)(struct vm_area_struct___243 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___243 *);
	vm_fault_t (*fault)(struct vm_fault___232 *);
	vm_fault_t (*huge_fault)(struct vm_fault___232 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___232 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___243 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___232 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___232 *);
	int (*access)(struct vm_area_struct___243 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___243 *);
	int (*set_policy)(struct vm_area_struct___243 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___243 *, long unsigned int);
	struct page___243 * (*find_special_page)(struct vm_area_struct___243 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___242 {
	struct task_struct___243 *task;
	struct core_thread___242 *next;
};

struct core_state___242 {
	atomic_t nr_threads;
	struct core_thread___242 dumper;
	struct completion startup;
};

struct vm_fault___232 {
	struct vm_area_struct___243 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___243 *cow_page;
	struct mem_cgroup___103 *memcg;
	struct page___243 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___242 prealloc_pte;
};

struct kset___229;

struct kobj_type___229;

struct kobject___230 {
	const char *name;
	struct list_head entry;
	struct kobject___230 *parent;
	struct kset___229 *kset;
	struct kobj_type___229 *ktype;
	struct kernfs_node___236 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___193 {
	struct kobject___230 kobj;
	struct module___196 *mod;
	struct kobject___230 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___193 {
	struct module___196 *mod;
	struct latch_tree_node node;
};

struct module_layout___193 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___193 mtn;
};

struct module_attribute___193;

struct kernel_param___193;

struct module___196 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___193 mkobj;
	struct module_attribute___193 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___230 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___193 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___193 core_layout;
	struct module_layout___193 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide53;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide54;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bio_vec___118 {
	struct page___243 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___109 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___118 *bvec;
		struct pipe_inode_info___52 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct msghdr___19 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___109 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___242 *msg_iocb;
};

struct kiocb___242 {
	struct file___242 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___242 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dentry_operations___241;

struct super_block___241;

struct dentry___242 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___242 *d_parent;
	struct qstr d_name;
	struct inode___242 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___241 *d_op;
	struct super_block___241 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___241;

struct block_device___242;

struct inode___242 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___241 *i_op;
	struct super_block___241 *i_sb;
	struct address_space___241 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___243 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___118 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___242 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___241 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___52 *i_pipe;
		struct block_device___242 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___241 {
	int (*d_revalidate)(struct dentry___242 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___242 *, unsigned int);
	int (*d_hash)(const struct dentry___242 *, struct qstr *);
	int (*d_compare)(const struct dentry___242 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___242 *);
	int (*d_init)(struct dentry___242 *);
	void (*d_release)(struct dentry___242 *);
	void (*d_prune)(struct dentry___242 *);
	void (*d_iput)(struct dentry___242 *, struct inode___242 *);
	char * (*d_dname)(struct dentry___242 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___241 *);
	int (*d_manage)(const struct path___241 *, bool);
	struct dentry___242 * (*d_real)(struct dentry___242 *, const struct inode___242 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___241;

struct mem_dqinfo___241 {
	struct quota_format_type___241 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___241;

struct quota_info___241 {
	unsigned int flags;
	struct rw_semaphore___243 dqio_sem;
	struct inode___242 *files[3];
	struct mem_dqinfo___241 info[3];
	const struct quota_format_ops___241 *ops[3];
};

struct rcuwait___241 {
	struct task_struct___243 *task;
};

struct percpu_rw_semaphore___241 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___243 rw_sem;
	struct rcuwait___241 writer;
	int readers_block;
};

struct sb_writers___241 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___241 rw_sem[3];
};

struct shrink_control___103;

struct shrinker___103 {
	long unsigned int (*count_objects)(struct shrinker___103 *, struct shrink_control___103 *);
	long unsigned int (*scan_objects)(struct shrinker___103 *, struct shrink_control___103 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___241;

struct super_operations___241;

struct dquot_operations___241;

struct quotactl_ops___241;

struct super_block___241 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___241 *s_type;
	const struct super_operations___241 *s_op;
	const struct dquot_operations___241 *dq_op;
	const struct quotactl_ops___241 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___242 *s_root;
	struct rw_semaphore___243 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___242 *s_bdev;
	struct backing_dev_info___118 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___241 s_dquot;
	struct sb_writers___241 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___241 *s_d_op;
	int cleancache_poolid;
	struct shrinker___103 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___202 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___103 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___103 *memcg;
};

struct iattr___241 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___242 *ia_file;
};

struct dquot___241 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___241 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___241 {
	int qf_fmt_id;
	const struct quota_format_ops___241 *qf_ops;
	struct module___196 *qf_owner;
	struct quota_format_type___241 *qf_next;
};

struct quota_format_ops___241 {
	int (*check_quota_file)(struct super_block___241 *, int);
	int (*read_file_info)(struct super_block___241 *, int);
	int (*write_file_info)(struct super_block___241 *, int);
	int (*free_file_info)(struct super_block___241 *, int);
	int (*read_dqblk)(struct dquot___241 *);
	int (*commit_dqblk)(struct dquot___241 *);
	int (*release_dqblk)(struct dquot___241 *);
	int (*get_next_id)(struct super_block___241 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___241 {
	int (*write_dquot)(struct dquot___241 *);
	struct dquot___241 * (*alloc_dquot)(struct super_block___241 *, int);
	void (*destroy_dquot)(struct dquot___241 *);
	int (*acquire_dquot)(struct dquot___241 *);
	int (*release_dquot)(struct dquot___241 *);
	int (*mark_dirty)(struct dquot___241 *);
	int (*write_info)(struct super_block___241 *, int);
	qsize_t * (*get_reserved_space)(struct inode___242 *);
	int (*get_projid)(struct inode___242 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___242 *, qsize_t *);
	int (*get_next_id)(struct super_block___241 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___241 {
	int (*quota_on)(struct super_block___241 *, int, int, const struct path___241 *);
	int (*quota_off)(struct super_block___241 *, int);
	int (*quota_enable)(struct super_block___241 *, unsigned int);
	int (*quota_disable)(struct super_block___241 *, unsigned int);
	int (*quota_sync)(struct super_block___241 *, int);
	int (*set_info)(struct super_block___241 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___241 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___241 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___241 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___241 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___241 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___114;

struct address_space_operations___241 {
	int (*writepage)(struct page___243 *, struct writeback_control___114 *);
	int (*readpage)(struct file___242 *, struct page___243 *);
	int (*writepages)(struct address_space___241 *, struct writeback_control___114 *);
	int (*set_page_dirty)(struct page___243 *);
	int (*readpages)(struct file___242 *, struct address_space___241 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___242 *, struct address_space___241 *, loff_t, unsigned int, unsigned int, struct page___243 **, void **);
	int (*write_end)(struct file___242 *, struct address_space___241 *, loff_t, unsigned int, unsigned int, struct page___243 *, void *);
	sector_t (*bmap)(struct address_space___241 *, sector_t);
	void (*invalidatepage)(struct page___243 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___243 *, gfp_t);
	void (*freepage)(struct page___243 *);
	ssize_t (*direct_IO)(struct kiocb___242 *, struct iov_iter___109 *);
	int (*migratepage)(struct address_space___241 *, struct page___243 *, struct page___243 *, enum migrate_mode);
	bool (*isolate_page)(struct page___243 *, isolate_mode_t);
	void (*putback_page)(struct page___243 *);
	int (*launder_page)(struct page___243 *);
	int (*is_partially_uptodate)(struct page___243 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___243 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___241 *, struct page___243 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___242 *, sector_t *);
	void (*swap_deactivate)(struct file___242 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___114 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___118 *wb;
	struct inode___242 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___242 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___242 *bd_inode;
	struct super_block___241 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___242 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___118 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___241 {
	struct dentry___242 * (*lookup)(struct inode___242 *, struct dentry___242 *, unsigned int);
	const char * (*get_link)(struct dentry___242 *, struct inode___242 *, struct delayed_call *);
	int (*permission)(struct inode___242 *, int);
	struct posix_acl * (*get_acl)(struct inode___242 *, int);
	int (*readlink)(struct dentry___242 *, char *, int);
	int (*create)(struct inode___242 *, struct dentry___242 *, umode_t, bool);
	int (*link)(struct dentry___242 *, struct inode___242 *, struct dentry___242 *);
	int (*unlink)(struct inode___242 *, struct dentry___242 *);
	int (*symlink)(struct inode___242 *, struct dentry___242 *, const char *);
	int (*mkdir)(struct inode___242 *, struct dentry___242 *, umode_t);
	int (*rmdir)(struct inode___242 *, struct dentry___242 *);
	int (*mknod)(struct inode___242 *, struct dentry___242 *, umode_t, dev_t);
	int (*rename)(struct inode___242 *, struct dentry___242 *, struct inode___242 *, struct dentry___242 *, unsigned int);
	int (*setattr)(struct dentry___242 *, struct iattr___241 *);
	int (*getattr)(const struct path___241 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___242 *, char *, size_t);
	int (*fiemap)(struct inode___242 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___242 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___242 *, struct dentry___242 *, struct file___242 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___242 *, struct dentry___242 *, umode_t);
	int (*set_acl)(struct inode___242 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___241 {
	void (*fl_copy_lock)(struct file_lock___242 *, struct file_lock___242 *);
	void (*fl_release_private)(struct file_lock___242 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___241;

struct file_lock___242 {
	struct file_lock___242 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___242 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___241 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___241 *fl_ops;
	const struct lock_manager_operations___241 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___241 {
	int (*lm_compare_owner)(struct file_lock___242 *, struct file_lock___242 *);
	long unsigned int (*lm_owner_key)(struct file_lock___242 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___242 *);
	int (*lm_grant)(struct file_lock___242 *, int);
	bool (*lm_break)(struct file_lock___242 *);
	int (*lm_change)(struct file_lock___242 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___242 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___241 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___241 *fa_next;
	struct file___242 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___241 {
	const char *name;
	int fs_flags;
	struct dentry___242 * (*mount)(struct file_system_type___241 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___241 *);
	struct module___196 *owner;
	struct file_system_type___241 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___241 {
	struct inode___242 * (*alloc_inode)(struct super_block___241 *);
	void (*destroy_inode)(struct inode___242 *);
	void (*dirty_inode)(struct inode___242 *, int);
	int (*write_inode)(struct inode___242 *, struct writeback_control___114 *);
	int (*drop_inode)(struct inode___242 *);
	void (*evict_inode)(struct inode___242 *);
	void (*put_super)(struct super_block___241 *);
	int (*sync_fs)(struct super_block___241 *, int);
	int (*freeze_super)(struct super_block___241 *);
	int (*freeze_fs)(struct super_block___241 *);
	int (*thaw_super)(struct super_block___241 *);
	int (*unfreeze_fs)(struct super_block___241 *);
	int (*statfs)(struct dentry___242 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___241 *, int *, char *);
	void (*umount_begin)(struct super_block___241 *);
	int (*show_options)(struct seq_file___218 *, struct dentry___242 *);
	int (*show_devname)(struct seq_file___218 *, struct dentry___242 *);
	int (*show_path)(struct seq_file___218 *, struct dentry___242 *);
	int (*show_stats)(struct seq_file___218 *, struct dentry___242 *);
	ssize_t (*quota_read)(struct super_block___241 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___241 *, int, const char *, size_t, loff_t);
	struct dquot___241 ** (*get_dquots)(struct inode___242 *);
	int (*bdev_try_to_free_page)(struct super_block___241 *, struct page___243 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___241 *, struct shrink_control___103 *);
	long int (*free_cached_objects)(struct super_block___241 *, struct shrink_control___103 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___152)(struct file___242 *, wait_queue_head_t *, struct poll_table_struct___150 *);

struct poll_table_struct___150 {
	poll_queue_proc___152 _qproc;
	__poll_t _key;
};

struct seq_operations___216;

struct seq_file___218 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___216 *op;
	int poll_event;
	const struct file___242 *file;
	void *private;
};

typedef void bio_end_io_t___118(struct bio___118 *);

struct bio_integrity_payload___118;

struct bio_set___118;

struct bio___118 {
	struct bio___118 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___118 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___118 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___118 *bi_io_vec;
	struct bio_set___118 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___118 bi_inline_vecs[0];
};

struct socket_wq___18 {
	wait_queue_head_t wait;
	struct fasync_struct___241 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct sock___19;

struct proto_ops___18;

struct socket___19 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___18 *wq;
	struct file___242 *file;
	struct sock___19 *sk;
	const struct proto_ops___18 *ops;
};

typedef struct {
	struct net___40 *net;
} possible_net_t___29;

struct proto___17;

struct sock_common___17 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___17 *skc_prot;
	possible_net_t___29 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___19 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___32;

struct sk_buff_head___28 {
	struct sk_buff___32 *next;
	struct sk_buff___32 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___17;

struct dst_entry___18;

struct net_device___32;

struct sock___19 {
	struct sock_common___17 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___28 sk_error_queue;
	struct sk_buff_head___28 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___32 *head;
		struct sk_buff___32 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___17 *sk_filter;
	union {
		struct socket_wq___18 *sk_wq;
		struct socket_wq___18 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___18 *sk_rx_dst;
	struct dst_entry___18 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___32 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___28 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___242 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___17 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___182 *sk_peer_pid;
	const struct cred___235 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___19 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___103 *sk_memcg;
	void (*sk_state_change)(struct sock___19 *);
	void (*sk_data_ready)(struct sock___19 *);
	void (*sk_write_space)(struct sock___19 *);
	void (*sk_error_report)(struct sock___19 *);
	int (*sk_backlog_rcv)(struct sock___19 *, struct sk_buff___32 *);
	struct sk_buff___32 * (*sk_validate_xmit_skb)(struct sock___19 *, struct net_device___32 *, struct sk_buff___32 *);
	void (*sk_destruct)(struct sock___19 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

typedef int (*sk_read_actor_t___17)(read_descriptor_t *, struct sk_buff___32 *, unsigned int, size_t);

struct proto_ops___18 {
	int family;
	struct module___196 *owner;
	int (*release)(struct socket___19 *);
	int (*bind)(struct socket___19 *, struct sockaddr *, int);
	int (*connect)(struct socket___19 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___19 *, struct socket___19 *);
	int (*accept)(struct socket___19 *, struct socket___19 *, int, bool);
	int (*getname)(struct socket___19 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___242 *, struct socket___19 *, struct poll_table_struct___150 *);
	int (*ioctl)(struct socket___19 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___19 *, int);
	int (*shutdown)(struct socket___19 *, int);
	int (*setsockopt)(struct socket___19 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___19 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___19 *, struct msghdr___19 *, size_t);
	int (*recvmsg)(struct socket___19 *, struct msghdr___19 *, size_t, int);
	int (*mmap)(struct file___242 *, struct socket___19 *, struct vm_area_struct___243 *);
	ssize_t (*sendpage)(struct socket___19 *, struct page___243 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___19 *, loff_t *, struct pipe_inode_info___52 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___19 *, int);
	int (*peek_len)(struct socket___19 *);
	int (*read_sock)(struct sock___19 *, read_descriptor_t *, sk_read_actor_t___17);
	int (*sendpage_locked)(struct sock___19 *, struct page___243 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___19 *, struct msghdr___19 *, size_t);
	int (*set_rcvlowat)(struct sock___19 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct nf_bridge_info___28;

struct sk_buff___32 {
	union {
		struct {
			struct sk_buff___32 *next;
			struct sk_buff___32 *prev;
			union {
				struct net_device___32 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___19 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___32 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___28 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___28;

struct netns_frags___28 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___28 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_rules_ops___17;

struct fib_notifier_ops___17;

struct netns_ipv4___28 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___17 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___19 *fibnl;
	struct sock___19 **icmp_sk;
	struct sock___19 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___19 **tcp_sk;
	struct netns_frags___28 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___17 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___17 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___17 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___18;

struct dst_ops___38 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___38 *);
	struct dst_entry___18 * (*check)(struct dst_entry___18 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___18 *);
	unsigned int (*mtu)(const struct dst_entry___18 *);
	u32 * (*cow_metrics)(struct dst_entry___18 *, long unsigned int);
	void (*destroy)(struct dst_entry___18 *);
	void (*ifdown)(struct dst_entry___18 *, struct net_device___32 *, int);
	struct dst_entry___18 * (*negative_advice)(struct dst_entry___18 *);
	void (*link_failure)(struct sk_buff___32 *);
	void (*update_pmtu)(struct dst_entry___18 *, struct sock___19 *, struct sk_buff___32 *, u32);
	void (*redirect)(struct dst_entry___18 *, struct sock___19 *, struct sk_buff___32 *);
	int (*local_out)(struct net___40 *, struct sock___19 *, struct sk_buff___32 *);
	struct neighbour___18 * (*neigh_lookup)(const struct dst_entry___18 *, struct sk_buff___32 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___18 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___38 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___28 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___38 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___17 *fib6_rules_ops;
	struct sock___19 **icmp_sk;
	struct sock___19 *ndisc_sk;
	struct sock___19 *tcp_sk;
	struct sock___19 *igmp_sk;
	struct sock___19 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___17 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___17 *notifier_ops;
	struct fib_notifier_ops___17 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___18 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___19 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___28 {
	struct netns_frags___28 frags;
};

struct netns_xfrm___38 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___19 *nlsk;
	struct sock___19 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___38 xfrm4_dst_ops;
	struct dst_ops___38 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___27;

struct net___40 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___202 *user_ns;
	struct ucounts___202 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___28 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___19 *rtnl;
	struct sock___19 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___32 *loopback_dev;
	struct netns_core core;
	struct netns_mib___2 mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___28 ipv4;
	struct netns_ipv6___38 ipv6;
	struct netns_sctp___18 sctp;
	struct netns_nf___2 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___28 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___19 *nfnl;
	struct sock___19 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___38 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can___2 can;
	struct sock___19 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___27 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kernfs_root___236;

struct kernfs_elem_dir___236 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___236 *root;
};

struct kernfs_syscall_ops___236;

struct kernfs_root___236 {
	struct kernfs_node___236 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___236 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___236 {
	struct kernfs_node___236 *target_kn;
};

struct kernfs_ops___236;

struct kernfs_elem_attr___236 {
	const struct kernfs_ops___236 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___236 *notify_next;
};

struct kernfs_node___236 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___236 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___236 dir;
		struct kernfs_elem_symlink___236 symlink;
		struct kernfs_elem_attr___236 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___236;

struct kernfs_ops___236 {
	int (*open)(struct kernfs_open_file___236 *);
	void (*release)(struct kernfs_open_file___236 *);
	int (*seq_show)(struct seq_file___218 *, void *);
	void * (*seq_start)(struct seq_file___218 *, loff_t *);
	void * (*seq_next)(struct seq_file___218 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___218 *, void *);
	ssize_t (*read)(struct kernfs_open_file___236 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___236 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___236 *, struct vm_area_struct___243 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___236 *, struct poll_table_struct___150 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___236 {
	int (*remount_fs)(struct kernfs_root___236 *, int *, char *);
	int (*show_options)(struct seq_file___218 *, struct kernfs_root___236 *);
	int (*mkdir)(struct kernfs_node___236 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___236 *);
	int (*rename)(struct kernfs_node___236 *, struct kernfs_node___236 *, const char *);
	int (*show_path)(struct seq_file___218 *, struct kernfs_node___236 *, struct kernfs_root___236 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___236 {
	struct kernfs_node___236 *kn;
	struct file___242 *file;
	struct seq_file___218 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___232 *vm_ops;
};

struct kobj_ns_type_operations___17 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___19 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___207;

struct attribute_group___208 {
	const char *name;
	umode_t (*is_visible)(struct kobject___230 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___230 *, struct bin_attribute___207 *, int);
	struct attribute **attrs;
	struct bin_attribute___207 **bin_attrs;
};

struct bin_attribute___207 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___242 *, struct kobject___230 *, struct bin_attribute___207 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___242 *, struct kobject___230 *, struct bin_attribute___207 *, char *, loff_t, size_t);
	int (*mmap)(struct file___242 *, struct kobject___230 *, struct bin_attribute___207 *, struct vm_area_struct___243 *);
};

struct sysfs_ops___229 {
	ssize_t (*show)(struct kobject___230 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___230 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___229;

struct kset___229 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___230 kobj;
	const struct kset_uevent_ops___229 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___229 {
	void (*release)(struct kobject___230 *);
	const struct sysfs_ops___229 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___17 * (*child_ns_type)(struct kobject___230 *);
	const void * (*namespace)(struct kobject___230 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___229 {
	int (* const filter)(struct kset___229 *, struct kobject___230 *);
	const char * (* const name)(struct kset___229 *, struct kobject___230 *);
	int (* const uevent)(struct kset___229 *, struct kobject___230 *, struct kobj_uevent_env *);
};

struct kobj_attribute___223 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___230 *, struct kobj_attribute___223 *, char *);
	ssize_t (*store)(struct kobject___230 *, struct kobj_attribute___223 *, const char *, size_t);
};

struct dev_pm_ops___206 {
	int (*prepare)(struct device___206 *);
	void (*complete)(struct device___206 *);
	int (*suspend)(struct device___206 *);
	int (*resume)(struct device___206 *);
	int (*freeze)(struct device___206 *);
	int (*thaw)(struct device___206 *);
	int (*poweroff)(struct device___206 *);
	int (*restore)(struct device___206 *);
	int (*suspend_late)(struct device___206 *);
	int (*resume_early)(struct device___206 *);
	int (*freeze_late)(struct device___206 *);
	int (*thaw_early)(struct device___206 *);
	int (*poweroff_late)(struct device___206 *);
	int (*restore_early)(struct device___206 *);
	int (*suspend_noirq)(struct device___206 *);
	int (*resume_noirq)(struct device___206 *);
	int (*freeze_noirq)(struct device___206 *);
	int (*thaw_noirq)(struct device___206 *);
	int (*poweroff_noirq)(struct device___206 *);
	int (*restore_noirq)(struct device___206 *);
	int (*runtime_suspend)(struct device___206 *);
	int (*runtime_resume)(struct device___206 *);
	int (*runtime_idle)(struct device___206 *);
};

struct dev_pm_info___206 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___206 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___206;

struct bus_type___206;

struct device_driver___206;

struct dev_pm_domain___206;

struct dma_map_ops___49;

struct fwnode_handle___141;

struct class___206;

struct device___206 {
	struct device___206 *parent;
	struct device_private *p;
	struct kobject___230 kobj;
	const char *init_name;
	const struct device_type___206 *type;
	struct mutex mutex;
	struct bus_type___206 *bus;
	struct device_driver___206 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___206 power;
	struct dev_pm_domain___206 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___49 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___141 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___206 *class;
	const struct attribute_group___208 **groups;
	void (*release)(struct device___206 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___206 {
	struct dev_pm_ops___206 ops;
	void (*detach)(struct device___206 *, bool);
	int (*activate)(struct device___206 *);
	void (*sync)(struct device___206 *);
	void (*dismiss)(struct device___206 *);
};

struct bus_type___206 {
	const char *name;
	const char *dev_name;
	struct device___206 *dev_root;
	const struct attribute_group___208 **bus_groups;
	const struct attribute_group___208 **dev_groups;
	const struct attribute_group___208 **drv_groups;
	int (*match)(struct device___206 *, struct device_driver___206 *);
	int (*uevent)(struct device___206 *, struct kobj_uevent_env *);
	int (*probe)(struct device___206 *);
	int (*remove)(struct device___206 *);
	void (*shutdown)(struct device___206 *);
	int (*online)(struct device___206 *);
	int (*offline)(struct device___206 *);
	int (*suspend)(struct device___206 *, pm_message_t);
	int (*resume)(struct device___206 *);
	int (*num_vf)(struct device___206 *);
	int (*dma_configure)(struct device___206 *);
	const struct dev_pm_ops___206 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___206 {
	const char *name;
	struct bus_type___206 *bus;
	struct module___196 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___206 *);
	int (*remove)(struct device___206 *);
	void (*shutdown)(struct device___206 *);
	int (*suspend)(struct device___206 *, pm_message_t);
	int (*resume)(struct device___206 *);
	const struct attribute_group___208 **groups;
	const struct dev_pm_ops___206 *pm;
	void (*coredump)(struct device___206 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___206 {
	const char *name;
	const struct attribute_group___208 **groups;
	int (*uevent)(struct device___206 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___206 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___206 *);
	const struct dev_pm_ops___206 *pm;
};

struct class___206 {
	const char *name;
	struct module___196 *owner;
	const struct attribute_group___208 **class_groups;
	const struct attribute_group___208 **dev_groups;
	struct kobject___230 *dev_kobj;
	int (*dev_uevent)(struct device___206 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___206 *, umode_t *);
	void (*class_release)(struct class___206 *);
	void (*dev_release)(struct device___206 *);
	int (*shutdown_pre)(struct device___206 *);
	const struct kobj_ns_type_operations___17 *ns_type;
	const void * (*namespace)(struct device___206 *);
	const struct dev_pm_ops___206 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___49 {
	void * (*alloc)(struct device___206 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___206 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___206 *, struct vm_area_struct___243 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___206 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___206 *, struct page___243 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___206 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___206 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___206 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___206 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___206 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___206 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___206 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___206 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___206 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___206 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___206 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___206 *, u64);
	u64 (*get_required_mask)(struct device___206 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___141;

struct fwnode_handle___141 {
	struct fwnode_handle___141 *secondary;
	const struct fwnode_operations___141 *ops;
};

typedef void compound_page_dtor___232(struct page___243 *);

struct fwnode_reference_args___141;

struct fwnode_endpoint___141;

struct fwnode_operations___141 {
	struct fwnode_handle___141 * (*get)(struct fwnode_handle___141 *);
	void (*put)(struct fwnode_handle___141 *);
	bool (*device_is_available)(const struct fwnode_handle___141 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___141 *, const struct device___206 *);
	bool (*property_present)(const struct fwnode_handle___141 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___141 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___141 *, const char *, const char **, size_t);
	struct fwnode_handle___141 * (*get_parent)(const struct fwnode_handle___141 *);
	struct fwnode_handle___141 * (*get_next_child_node)(const struct fwnode_handle___141 *, struct fwnode_handle___141 *);
	struct fwnode_handle___141 * (*get_named_child_node)(const struct fwnode_handle___141 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___141 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___141 *);
	struct fwnode_handle___141 * (*graph_get_next_endpoint)(const struct fwnode_handle___141 *, struct fwnode_handle___141 *);
	struct fwnode_handle___141 * (*graph_get_remote_endpoint)(const struct fwnode_handle___141 *);
	struct fwnode_handle___141 * (*graph_get_port_parent)(struct fwnode_handle___141 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___141 *, struct fwnode_endpoint___141 *);
};

struct fwnode_endpoint___141 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___141 *local_fwnode;
};

struct fwnode_reference_args___141 {
	struct fwnode_handle___141 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___52;

struct pipe_buffer___52 {
	struct page___243 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___52 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___52 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___52 *, struct pipe_buffer___52 *);
	void (*release)(struct pipe_inode_info___52 *, struct pipe_buffer___52 *);
	int (*steal)(struct pipe_inode_info___52 *, struct pipe_buffer___52 *);
	union {
		bool (*get)(struct pipe_inode_info___52 *, struct pipe_buffer___52 *);
		struct {
			void (*get)(struct pipe_inode_info___52 *, struct pipe_buffer___52 *);
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
};

struct nf_bridge_info___28 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___28 = 0,
		BRNF_PROTO_8021Q___28 = 1,
		BRNF_PROTO_PPPOE___28 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___32 *physindev;
	struct net_device___32 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___28(struct sk_buff___32 **);

struct net_device_ops___28;

struct ethtool_ops___28;

struct l3mdev_ops___18;

struct xfrmdev_ops___28;

struct tlsdev_ops___28;

struct header_ops___28;

struct netdev_rx_queue___28;

struct mini_Qdisc___27;

struct netdev_queue___28;

struct Qdisc___27;

struct rtnl_link_ops___27;

struct dcbnl_rtnl_ops___28;

struct net_device___32 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___28 *netdev_ops;
	const struct ethtool_ops___28 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___18 *l3mdev_ops;
	const struct ndisc_ops___2 *ndisc_ops;
	const struct xfrmdev_ops___28 *xfrmdev_ops;
	const struct tlsdev_ops___28 *tlsdev_ops;
	const struct header_ops___28 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___229 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___2 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___28 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___27 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___28 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___27 *miniq_ingress;
	struct netdev_queue___28 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___28 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___27 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___27 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___28 = 0,
		NETREG_REGISTERED___28 = 1,
		NETREG_UNREGISTERING___28 = 2,
		NETREG_UNREGISTERED___28 = 3,
		NETREG_RELEASED___28 = 4,
		NETREG_DUMMY___28 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___28 = 0,
		RTNL_LINK_INITIALIZING___28 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___32 *);
	struct netpoll_info *npinfo;
	possible_net_t___29 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___206 dev;
	const struct attribute_group___208 *sysfs_groups[4];
	const struct attribute_group___208 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___27 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___28 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

typedef int (*key_restrict_link_func_t___235)(struct key___235 *, const struct key_type *, const union key_payload *, struct key___235 *);

struct key_restriction___235;

struct key___235 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___243 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key___5 index_key;
		struct {
			struct key_type___5 *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___235 *restrict_link;
};

struct key_restriction___235 {
	key_restrict_link_func_t___235 check;
	struct key___235 *key;
	struct key_type *keytype;
};

struct cgroup_namespace___187 {
	refcount_t count;
	struct ns_common___28 ns;
	struct user_namespace___202 *user_ns;
	struct ucounts___202 *ucounts;
	struct css_set___187 *root_cset;
};

struct netlink_callback___28 {
	struct sk_buff___32 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___28 *);
	int (*dump)(struct sk_buff___32 *, struct netlink_callback___28 *);
	int (*done)(struct netlink_callback___28 *);
	void *data;
	struct module___196 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct ethtool_ops___28 {
	int (*get_settings)(struct net_device___32 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___32 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___32 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___32 *);
	void (*get_regs)(struct net_device___32 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___32 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___32 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___32 *);
	void (*set_msglevel)(struct net_device___32 *, u32);
	int (*nway_reset)(struct net_device___32 *);
	u32 (*get_link)(struct net_device___32 *);
	int (*get_eeprom_len)(struct net_device___32 *);
	int (*get_eeprom)(struct net_device___32 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___32 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___32 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___32 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___32 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___32 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___32 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___32 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___32 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___32 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___32 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___32 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___32 *);
	void (*complete)(struct net_device___32 *);
	u32 (*get_priv_flags)(struct net_device___32 *);
	int (*set_priv_flags)(struct net_device___32 *, u32);
	int (*get_sset_count)(struct net_device___32 *, int);
	int (*get_rxnfc)(struct net_device___32 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___32 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___32 *, struct ethtool_flash *);
	int (*reset)(struct net_device___32 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___32 *);
	int (*get_rxfh)(struct net_device___32 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___32 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___32 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___32 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___32 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___32 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___32 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___32 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___32 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___32 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___32 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___32 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___32 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___32 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___32 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___32 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___32 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___32 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___32 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___32 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___32 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___32 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	int (*get_fecparam)(struct net_device___32 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___32 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___32 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___32 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___32 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___28;

struct inet_frags___28 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___28 *, const void *);
	void (*destructor)(struct inet_frag_queue___28 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___28 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___32 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___32 *fragments_tail;
	struct sk_buff___32 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___28 *net;
	struct callback_head rcu;
};

struct fib_rule___17;

struct fib_lookup_arg___17;

struct fib_rules_ops___17 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___17 *, struct flowi *, int, struct fib_lookup_arg___17 *);
	bool (*suppress)(struct fib_rule___17 *, struct fib_lookup_arg___17 *);
	int (*match)(struct fib_rule___17 *, struct flowi *, int);
	int (*configure)(struct fib_rule___17 *, struct sk_buff___32 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___17 *);
	int (*compare)(struct fib_rule___17 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___17 *, struct sk_buff___32 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___17 *);
	void (*flush_cache)(struct fib_rules_ops___17 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___196 *owner;
	struct net___40 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___17 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___40 *);
	int (*fib_dump)(struct net___40 *, struct notifier_block *);
	struct module___196 *owner;
	struct callback_head rcu;
};

struct dst_entry___18 {
	struct net_device___32 *dev;
	struct dst_ops___38 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___32 *);
	int (*output)(struct net___40 *, struct sock___19 *, struct sk_buff___32 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___17;

struct neigh_parms___18;

struct neigh_ops___17;

struct neighbour___18 {
	struct neighbour___18 *next;
	struct neigh_table___17 *tbl;
	struct neigh_parms___18 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___28 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___18 *, struct sk_buff___32 *);
	const struct neigh_ops___17 *ops;
	struct callback_head rcu;
	struct net_device___32 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

enum {
	XFRM_MSG_BASE = 16,
	XFRM_MSG_NEWSA = 16,
	XFRM_MSG_DELSA = 17,
	XFRM_MSG_GETSA = 18,
	XFRM_MSG_NEWPOLICY = 19,
	XFRM_MSG_DELPOLICY = 20,
	XFRM_MSG_GETPOLICY = 21,
	XFRM_MSG_ALLOCSPI = 22,
	XFRM_MSG_ACQUIRE = 23,
	XFRM_MSG_EXPIRE = 24,
	XFRM_MSG_UPDPOLICY = 25,
	XFRM_MSG_UPDSA = 26,
	XFRM_MSG_POLEXPIRE = 27,
	XFRM_MSG_FLUSHSA = 28,
	XFRM_MSG_FLUSHPOLICY = 29,
	XFRM_MSG_NEWAE = 30,
	XFRM_MSG_GETAE = 31,
	XFRM_MSG_REPORT = 32,
	XFRM_MSG_MIGRATE = 33,
	XFRM_MSG_NEWSADINFO = 34,
	XFRM_MSG_GETSADINFO = 35,
	XFRM_MSG_NEWSPDINFO = 36,
	XFRM_MSG_GETSPDINFO = 37,
	XFRM_MSG_MAPPING = 38,
	__XFRM_MSG_MAX = 39,
};

struct ucounts___202 {
	struct hlist_node node;
	struct user_namespace___202 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_prog_aux___29;

struct bpf_prog___27 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___29 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

struct seq_operations___216 {
	void * (*start)(struct seq_file___218 *, loff_t *);
	void (*stop)(struct seq_file___218 *, void *);
	void * (*next)(struct seq_file___218 *, void *, loff_t *);
	int (*show)(struct seq_file___218 *, void *);
};

struct pernet_operations___29 {
	struct list_head list;
	int (*init)(struct net___40 *);
	void (*exit)(struct net___40 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___28 {
	int (*ieee_getets)(struct net_device___32 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___32 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___32 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___32 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___32 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___32 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___32 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___32 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___32 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___32 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___32 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___32 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___32 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___32 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___32 *);
	u8 (*setstate)(struct net_device___32 *, u8);
	void (*getpermhwaddr)(struct net_device___32 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___32 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___32 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___32 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___32 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___32 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___32 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___32 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___32 *, int, u8 *);
	void (*setpfccfg)(struct net_device___32 *, int, u8);
	void (*getpfccfg)(struct net_device___32 *, int, u8 *);
	u8 (*setall)(struct net_device___32 *);
	u8 (*getcap)(struct net_device___32 *, int, u8 *);
	int (*getnumtcs)(struct net_device___32 *, int, u8 *);
	int (*setnumtcs)(struct net_device___32 *, int, u8);
	u8 (*getpfcstate)(struct net_device___32 *);
	void (*setpfcstate)(struct net_device___32 *, u8);
	void (*getbcncfg)(struct net_device___32 *, int, u32 *);
	void (*setbcncfg)(struct net_device___32 *, int, u32);
	void (*getbcnrp)(struct net_device___32 *, int, u8 *);
	void (*setbcnrp)(struct net_device___32 *, int, u8);
	int (*setapp)(struct net_device___32 *, u8, u16, u8);
	int (*getapp)(struct net_device___32 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___32 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___32 *, int, u8);
	u8 (*getdcbx)(struct net_device___32 *);
	u8 (*setdcbx)(struct net_device___32 *, u8);
	int (*peer_getappinfo)(struct net_device___32 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___32 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___32 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___32 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___32 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___32 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct bpf_map___187;

struct bpf_map_ops___187 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___187 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___187 *, struct file___242 *);
	void (*map_free)(struct bpf_map___187 *);
	int (*map_get_next_key)(struct bpf_map___187 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___187 *);
	void * (*map_lookup_elem)(struct bpf_map___187 *, void *);
	int (*map_update_elem)(struct bpf_map___187 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___187 *, void *);
	int (*map_push_elem)(struct bpf_map___187 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___187 *, void *);
	int (*map_peek_elem)(struct bpf_map___187 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___187 *, struct file___242 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___187 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___187 *, void *, struct seq_file___218 *);
	int (*map_check_btf)(const struct bpf_map___187 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___187 {
	const struct bpf_map_ops___187 *ops;
	struct bpf_map___187 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___235 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___28;

struct bpf_map_dev_ops___28 {
	int (*map_get_next_key)(struct bpf_offloaded_map___28 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___28 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___28 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___28 *, void *);
};

struct bpf_offloaded_map___28 {
	struct bpf_map___187 map;
	struct net_device___32 *netdev;
	const struct bpf_map_dev_ops___28 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___27 {
	int (*test_run)(struct bpf_prog___27 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___27 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___27 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___27 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___27 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___27 *, u32 *);
};

struct bpf_prog_offload_ops___27 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___27 *);
	int (*translate)(struct bpf_prog___27 *);
	void (*destroy)(struct bpf_prog___27 *);
};

struct bpf_prog_offload___27 {
	struct bpf_prog___27 *prog;
	struct net_device___32 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___27 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___29 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___27 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___27 *ops;
	struct bpf_map___187 **used_maps;
	struct bpf_prog___27 *prog;
	struct user_struct___235 *user;
	u64 load_time;
	struct bpf_map___187 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___27 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___27 {
	struct bpf_prog___27 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___27 {
	struct callback_head rcu;
	struct bpf_prog_array_item___27 items[0];
};

struct cgroup_bpf___27 {
	struct bpf_prog_array___27 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___27 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___187;

typedef void (*kthread_work_func_t___187)(struct kthread_work___187 *);

struct kthread_worker___187;

struct kthread_work___187 {
	struct list_head node;
	kthread_work_func_t___187 func;
	struct kthread_worker___187 *worker;
	int canceling;
};

struct kthread_worker___187 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___243 *task;
	struct kthread_work___187 *current_work;
};

struct kthread_delayed_work___187 {
	struct kthread_work___187 work;
	struct timer_list timer;
};

struct psi_group___187 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___187 *poll_kworker;
	struct kthread_delayed_work___187 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___187;

struct cgroup_rstat_cpu___187;

struct cgroup___187 {
	struct cgroup_subsys_state___188 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___236 *kn;
	struct cgroup_file___187 procs_file;
	struct cgroup_file___187 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___188 *subsys[13];
	struct cgroup_root___187 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___187 *dom_cgrp;
	struct cgroup_rstat_cpu___187 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___27 bpf;
	atomic_t congestion_count;
	struct cgroup___187 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___187 psi;
	int ancestor_ids[0];
};

struct cftype___187;

struct cgroup_subsys___187 {
	struct cgroup_subsys_state___188 * (*css_alloc)(struct cgroup_subsys_state___188 *);
	int (*css_online)(struct cgroup_subsys_state___188 *);
	void (*css_offline)(struct cgroup_subsys_state___188 *);
	void (*css_released)(struct cgroup_subsys_state___188 *);
	void (*css_free)(struct cgroup_subsys_state___188 *);
	void (*css_reset)(struct cgroup_subsys_state___188 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___188 *, int);
	int (*css_extra_stat_show)(struct seq_file___218 *, struct cgroup_subsys_state___188 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___243 *);
	void (*cancel_fork)(struct task_struct___243 *);
	void (*fork)(struct task_struct___243 *);
	void (*exit)(struct task_struct___243 *);
	void (*free)(struct task_struct___243 *);
	void (*bind)(struct cgroup_subsys_state___188 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___187 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___187 *dfl_cftypes;
	struct cftype___187 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___187 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___187 *updated_children;
	struct cgroup___187 *updated_next;
};

struct cgroup_root___187 {
	struct kernfs_root___236 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___187 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___187 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___187 *ss;
	struct list_head node;
	struct kernfs_ops___236 *kf_ops;
	int (*open)(struct kernfs_open_file___236 *);
	void (*release)(struct kernfs_open_file___236 *);
	u64 (*read_u64)(struct cgroup_subsys_state___188 *, struct cftype___187 *);
	s64 (*read_s64)(struct cgroup_subsys_state___188 *, struct cftype___187 *);
	int (*seq_show)(struct seq_file___218 *, void *);
	void * (*seq_start)(struct seq_file___218 *, loff_t *);
	void * (*seq_next)(struct seq_file___218 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___218 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___188 *, struct cftype___187 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___188 *, struct cftype___187 *, s64);
	ssize_t (*write)(struct kernfs_open_file___236 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___236 *, struct poll_table_struct___150 *);
};

struct xdp_rxq_info___28 {
	struct net_device___32 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___28 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___32 *dev_rx;
};

struct header_ops___28 {
	int (*create)(struct sk_buff___32 *, struct net_device___32 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___32 *, unsigned char *);
	int (*cache)(const struct neighbour___18 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___32 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___28 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___28 *, int);
	int poll_owner;
	struct net_device___32 *dev;
	struct sk_buff___32 *gro_list;
	struct sk_buff___32 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___28 {
	struct net_device___32 *dev;
	struct Qdisc___27 *qdisc;
	struct Qdisc___27 *qdisc_sleeping;
	struct kobject___230 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___32 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___27 {
	struct sk_buff___32 *head;
	struct sk_buff___32 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___27;

struct Qdisc___27 {
	int (*enqueue)(struct sk_buff___32 *, struct Qdisc___27 *, struct sk_buff___32 **);
	struct sk_buff___32 * (*dequeue)(struct Qdisc___27 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___27 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___28 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___28 gso_skb;
	struct qdisc_skb_head___27 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___27 *next_sched;
	struct sk_buff_head___28 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___28 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___230 kobj;
	struct net_device___32 *dev;
	long: 64;
	struct xdp_rxq_info___28 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___28)(struct net_device___32 *, struct sk_buff___32 *, struct net_device___32 *);

struct netdev_bpf___28 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___27 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___27 *prog;
			const struct bpf_prog_offload_ops___27 *ops;
		} verifier;
		struct {
			struct bpf_prog___27 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___28 *offmap;
		};
		struct {
			struct xdp_umem *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___28 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___32 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___28 {
	int (*tls_dev_add)(struct net_device___32 *, struct sock___19 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___32 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___32 *, struct sock___19 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___28 {
	int (*ndo_init)(struct net_device___32 *);
	void (*ndo_uninit)(struct net_device___32 *);
	int (*ndo_open)(struct net_device___32 *);
	int (*ndo_stop)(struct net_device___32 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___32 *, struct net_device___32 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___32 *, struct net_device___32 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___32 *, struct sk_buff___32 *, struct net_device___32 *, select_queue_fallback_t___28);
	void (*ndo_change_rx_flags)(struct net_device___32 *, int);
	void (*ndo_set_rx_mode)(struct net_device___32 *);
	int (*ndo_set_mac_address)(struct net_device___32 *, void *);
	int (*ndo_validate_addr)(struct net_device___32 *);
	int (*ndo_do_ioctl)(struct net_device___32 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___32 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___32 *, int);
	int (*ndo_neigh_setup)(struct net_device___32 *, struct neigh_parms___18 *);
	void (*ndo_tx_timeout)(struct net_device___32 *);
	void (*ndo_get_stats64)(struct net_device___32 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___32 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___32 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___32 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___32 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___32 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___32 *);
	int (*ndo_netpoll_setup)(struct net_device___32 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___32 *);
	int (*ndo_set_vf_mac)(struct net_device___32 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___32 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___32 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___32 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___32 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___32 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___32 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___32 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___32 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___32 *, int, struct sk_buff___32 *);
	int (*ndo_set_vf_guid)(struct net_device___32 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___32 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___32 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___32 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___32 *, const struct sk_buff___32 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___32 *, struct net_device___32 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___32 *, struct net_device___32 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___32 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___32 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___32 *, struct neighbour___18 *);
	void (*ndo_neigh_destroy)(struct net_device___32 *, struct neighbour___18 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___32 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___32 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___32 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___32 *, struct netlink_callback___28 *, struct net_device___32 *, struct net_device___32 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___32 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___32 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___32 *, u32, u32, struct net_device___32 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___32 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___32 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___32 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___32 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___32 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___32 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___32 *, struct net_device___32 *);
	void (*ndo_dfwd_del_station)(struct net_device___32 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___32 *);
	int (*ndo_set_tx_maxrate)(struct net_device___32 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___32 *);
	int (*ndo_change_proto_down)(struct net_device___32 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___32 *, struct sk_buff___32 *);
	void (*ndo_set_rx_headroom)(struct net_device___32 *, int);
	int (*ndo_bpf)(struct net_device___32 *, struct netdev_bpf___28 *);
	int (*ndo_xdp_xmit)(struct net_device___32 *, int, struct xdp_frame___28 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___32 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___32 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___18 {
	possible_net_t___29 net;
	struct net_device___32 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___18 *);
	void (*neigh_cleanup)(struct neighbour___18 *);
	struct neigh_table___17 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___18 {
	u32 (*l3mdev_fib_table)(const struct net_device___32 *);
	struct sk_buff___32 * (*l3mdev_l3_rcv)(struct net_device___32 *, struct sk_buff___32 *, u16);
	struct sk_buff___32 * (*l3mdev_l3_out)(struct net_device___32 *, struct sock___19 *, struct sk_buff___32 *, u16);
	struct dst_entry___18 * (*l3mdev_link_scope_lookup)(const struct net_device___32 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct tcf_proto___27;

struct mini_Qdisc___27 {
	struct tcf_proto___27 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___27 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___32 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___40 *, struct net_device___32 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___32 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___32 *, struct list_head *);
	size_t (*get_size)(const struct net_device___32 *);
	int (*fill_info)(struct sk_buff___32 *, const struct net_device___32 *);
	size_t (*get_xstats_size)(const struct net_device___32 *);
	int (*fill_xstats)(struct sk_buff___32 *, const struct net_device___32 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___32 *, struct net_device___32 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___32 *, const struct net_device___32 *);
	int (*fill_slave_info)(struct sk_buff___32 *, const struct net_device___32 *, const struct net_device___32 *);
	struct net___40 * (*get_link_net)(const struct net_device___32 *);
	size_t (*get_linkxstats_size)(const struct net_device___32 *, int);
	int (*fill_linkxstats)(struct sk_buff___32 *, const struct net_device___32 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___28 {
	struct list_head poll_list;
	struct sk_buff_head___28 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___28 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___27 *output_queue;
	struct Qdisc___27 **output_queue_tailp;
	struct sk_buff___32 *completion_queue;
	struct sk_buff_head___28 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___28 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___28 input_pkt_queue;
	struct napi_struct___28 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

enum {
	RTM_BASE = 16,
	RTM_NEWLINK = 16,
	RTM_DELLINK = 17,
	RTM_GETLINK = 18,
	RTM_SETLINK = 19,
	RTM_NEWADDR = 20,
	RTM_DELADDR = 21,
	RTM_GETADDR = 22,
	RTM_NEWROUTE = 24,
	RTM_DELROUTE = 25,
	RTM_GETROUTE = 26,
	RTM_NEWNEIGH = 28,
	RTM_DELNEIGH = 29,
	RTM_GETNEIGH = 30,
	RTM_NEWRULE = 32,
	RTM_DELRULE = 33,
	RTM_GETRULE = 34,
	RTM_NEWQDISC = 36,
	RTM_DELQDISC = 37,
	RTM_GETQDISC = 38,
	RTM_NEWTCLASS = 40,
	RTM_DELTCLASS = 41,
	RTM_GETTCLASS = 42,
	RTM_NEWTFILTER = 44,
	RTM_DELTFILTER = 45,
	RTM_GETTFILTER = 46,
	RTM_NEWACTION = 48,
	RTM_DELACTION = 49,
	RTM_GETACTION = 50,
	RTM_NEWPREFIX = 52,
	RTM_GETMULTICAST = 58,
	RTM_GETANYCAST = 62,
	RTM_NEWNEIGHTBL = 64,
	RTM_GETNEIGHTBL = 66,
	RTM_SETNEIGHTBL = 67,
	RTM_NEWNDUSEROPT = 68,
	RTM_NEWADDRLABEL = 72,
	RTM_DELADDRLABEL = 73,
	RTM_GETADDRLABEL = 74,
	RTM_GETDCB = 78,
	RTM_SETDCB = 79,
	RTM_NEWNETCONF = 80,
	RTM_DELNETCONF = 81,
	RTM_GETNETCONF = 82,
	RTM_NEWMDB = 84,
	RTM_DELMDB = 85,
	RTM_GETMDB = 86,
	RTM_NEWNSID = 88,
	RTM_DELNSID = 89,
	RTM_GETNSID = 90,
	RTM_NEWSTATS = 92,
	RTM_GETSTATS = 94,
	RTM_NEWCACHEREPORT = 96,
	RTM_NEWCHAIN = 100,
	RTM_DELCHAIN = 101,
	RTM_GETCHAIN = 102,
	__RTM_MAX = 103,
};

struct bdi_writeback_congested___118 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___118 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___118 {
	struct bio___118 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___118 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___118 bip_inline_vecs[0];
};

struct bio_set___118 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___118 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___103 {
	struct mem_cgroup___103 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___103 {
	struct lruvec___242 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___103 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___103 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct kernel_param_ops___193 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___193 *);
	int (*get)(char *, const struct kernel_param___193 *);
	void (*free)(void *);
};

struct kparam_array___193;

struct kernel_param___193 {
	const char *name;
	struct module___196 *mod;
	const struct kernel_param_ops___193 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___193 *arr;
	};
};

struct kparam_array___193 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___193 *ops;
	void *elem;
};

struct module_attribute___193 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___193 *, struct module_kobject___193 *, char *);
	ssize_t (*store)(struct module_attribute___193 *, struct module_kobject___193 *, const char *, size_t);
	void (*setup)(struct module___196 *, const char *);
	int (*test)(struct module___196 *);
	void (*free)(struct module___196 *);
};

struct gnet_dump___27 {
	spinlock_t *lock;
	struct sk_buff___32 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___27;

struct Qdisc_ops___27 {
	struct Qdisc_ops___27 *next;
	const struct Qdisc_class_ops___27 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___32 *, struct Qdisc___27 *, struct sk_buff___32 **);
	struct sk_buff___32 * (*dequeue)(struct Qdisc___27 *);
	struct sk_buff___32 * (*peek)(struct Qdisc___27 *);
	int (*init)(struct Qdisc___27 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___27 *);
	void (*destroy)(struct Qdisc___27 *);
	int (*change)(struct Qdisc___27 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___27 *);
	int (*change_tx_queue_len)(struct Qdisc___27 *, unsigned int);
	int (*dump)(struct Qdisc___27 *, struct sk_buff___32 *);
	int (*dump_stats)(struct Qdisc___27 *, struct gnet_dump___27 *);
	void (*ingress_block_set)(struct Qdisc___27 *, u32);
	void (*egress_block_set)(struct Qdisc___27 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___27 *);
	u32 (*egress_block_get)(struct Qdisc___27 *);
	struct module___196 *owner;
};

struct tcf_block___27;

struct Qdisc_class_ops___27 {
	unsigned int flags;
	struct netdev_queue___28 * (*select_queue)(struct Qdisc___27 *, struct tcmsg *);
	int (*graft)(struct Qdisc___27 *, long unsigned int, struct Qdisc___27 *, struct Qdisc___27 **, struct netlink_ext_ack *);
	struct Qdisc___27 * (*leaf)(struct Qdisc___27 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___27 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___27 *, u32);
	int (*change)(struct Qdisc___27 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___27 *, long unsigned int);
	void (*walk)(struct Qdisc___27 *, struct qdisc_walker *);
	struct tcf_block___27 * (*tcf_block)(struct Qdisc___27 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___27 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___27 *, long unsigned int);
	int (*dump)(struct Qdisc___27 *, long unsigned int, struct sk_buff___32 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___27 *, long unsigned int, struct gnet_dump___27 *);
};

struct tcf_chain___27;

struct tcf_block___27 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___40 *net;
	struct Qdisc___27 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___27 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___27;

struct tcf_proto_ops___27;

struct tcf_proto___27 {
	struct tcf_proto___27 *next;
	void *root;
	int (*classify)(struct sk_buff___32 *, const struct tcf_proto___27 *, struct tcf_result___27 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___27 *ops;
	struct tcf_chain___27 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___27 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___27 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___27 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___32 *, const struct tcf_proto___27 *, struct tcf_result___27 *);
	int (*init)(struct tcf_proto___27 *);
	void (*destroy)(struct tcf_proto___27 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___27 *, u32);
	void (*put)(struct tcf_proto___27 *, void *);
	int (*change)(struct net___40 *, struct sk_buff___32 *, struct tcf_proto___27 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___27 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___27 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___27 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___40 *, struct tcf_chain___27 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___40 *, struct tcf_proto___27 *, void *, struct sk_buff___32 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___32 *, struct net___40 *, void *);
	struct module___196 *owner;
	int flags;
};

struct tcf_chain___27 {
	struct mutex filter_chain_lock;
	struct tcf_proto___27 *filter_chain;
	struct list_head list;
	struct tcf_block___27 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___27 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___17 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___27 *prog;
};

struct bpf_redirect_info___27 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___187 *map;
	struct bpf_map___187 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___17;

struct neigh_hash_table___17;

struct neigh_table___17 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___32 *, __u32 *);
	bool (*key_eq)(const struct neighbour___18 *, const void *);
	int (*constructor)(struct neighbour___18 *);
	int (*pconstructor)(struct pneigh_entry___17 *);
	void (*pdestructor)(struct pneigh_entry___17 *);
	void (*proxy_redo)(struct sk_buff___32 *);
	char *id;
	struct neigh_parms___18 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___28 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___17 *nht;
	struct pneigh_entry___17 **phash_buckets;
};

struct neigh_ops___17 {
	int family;
	void (*solicit)(struct neighbour___18 *, struct sk_buff___32 *);
	void (*error_report)(struct neighbour___18 *, struct sk_buff___32 *);
	int (*output)(struct neighbour___18 *, struct sk_buff___32 *);
	int (*connected_output)(struct neighbour___18 *, struct sk_buff___32 *);
};

struct pneigh_entry___17 {
	struct pneigh_entry___17 *next;
	possible_net_t___29 net;
	struct net_device___32 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___17 {
	struct neighbour___18 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___17 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___17 *ctarget;
	struct net___40 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___17 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___17 *rule;
	u32 table;
	int flags;
};

struct proto___17 {
	void (*close)(struct sock___19 *, long int);
	int (*pre_connect)(struct sock___19 *, struct sockaddr *, int);
	int (*connect)(struct sock___19 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___19 *, int);
	struct sock___19 * (*accept)(struct sock___19 *, int, int *, bool);
	int (*ioctl)(struct sock___19 *, int, long unsigned int);
	int (*init)(struct sock___19 *);
	void (*destroy)(struct sock___19 *);
	void (*shutdown)(struct sock___19 *, int);
	int (*setsockopt)(struct sock___19 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___19 *, int, int, char *, int *);
	void (*keepalive)(struct sock___19 *, int);
	int (*sendmsg)(struct sock___19 *, struct msghdr___19 *, size_t);
	int (*recvmsg)(struct sock___19 *, struct msghdr___19 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___19 *, struct page___243 *, int, size_t, int);
	int (*bind)(struct sock___19 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___19 *, struct sk_buff___32 *);
	void (*release_cb)(struct sock___19 *);
	int (*hash)(struct sock___19 *);
	void (*unhash)(struct sock___19 *);
	void (*rehash)(struct sock___19 *);
	int (*get_port)(struct sock___19 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___19 *);
	bool (*stream_memory_read)(const struct sock___19 *);
	void (*enter_memory_pressure)(struct sock___19 *);
	void (*leave_memory_pressure)(struct sock___19 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___3 *rsk_prot;
	struct timewait_sock_ops___3 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___196 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___19 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct nlmsg_perm {
	u16 nlmsg_type;
	u32 perm;
};

struct module___197;

struct file___243;

struct kiocb___243;

struct iov_iter___110;

struct poll_table_struct___151;

struct vm_area_struct___244;

struct inode___243;

struct file_lock___243;

struct page___244;

struct pipe_inode_info___53;

struct seq_file___219;

struct file_operations___243 {
	struct module___197 *owner;
	loff_t (*llseek)(struct file___243 *, loff_t, int);
	ssize_t (*read)(struct file___243 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___243 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___243 *, struct iov_iter___110 *);
	ssize_t (*write_iter)(struct kiocb___243 *, struct iov_iter___110 *);
	int (*iopoll)(struct kiocb___243 *, bool);
	int (*iterate)(struct file___243 *, struct dir_context *);
	int (*iterate_shared)(struct file___243 *, struct dir_context *);
	__poll_t (*poll)(struct file___243 *, struct poll_table_struct___151 *);
	long int (*unlocked_ioctl)(struct file___243 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___243 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___243 *, struct vm_area_struct___244 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___243 *, struct file___243 *);
	int (*flush)(struct file___243 *, fl_owner_t);
	int (*release)(struct inode___243 *, struct file___243 *);
	int (*fsync)(struct file___243 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___243 *, int);
	int (*lock)(struct file___243 *, int, struct file_lock___243 *);
	ssize_t (*sendpage)(struct file___243 *, struct page___244 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___243 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___243 *, int, struct file_lock___243 *);
	ssize_t (*splice_write)(struct pipe_inode_info___53 *, struct file___243 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___243 *, loff_t *, struct pipe_inode_info___53 *, size_t, unsigned int);
	int (*setlease)(struct file___243 *, long int, struct file_lock___243 **, void **);
	long int (*fallocate)(struct file___243 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___219 *, struct file___243 *);
	ssize_t (*copy_file_range)(struct file___243 *, loff_t, struct file___243 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___243 *, loff_t, struct file___243 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___243 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___243 {
	u64 seqnum;
	struct vm_area_struct___244 *vmas[4];
};

struct page_frag___243 {
	struct page___244 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___243;

struct mem_cgroup___104;

struct pid___183;

struct cred___236;

struct nsproxy___223;

struct signal_struct___201;

struct bio_list___119;

struct backing_dev_info___119;

struct css_set___188;

struct vm_struct___160;

struct task_struct___244 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___244 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___243 *mm;
	struct mm_struct___243 *active_mm;
	struct vmacache___243 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___244 *real_parent;
	struct task_struct___244 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___244 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___104 *active_memcg;
	long int rh_reserved2;
	struct pid___183 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___183 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___183 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___236 *ptracer_cred;
	const struct cred___236 *real_cred;
	const struct cred___236 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___223 *nsproxy;
	struct signal_struct___201 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___244 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___119 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___119 *backing_dev_info;
	struct io_context___60 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___188 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___53 *splice_pipe;
	struct page_frag___243 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___104 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___244 *oom_reaper_list;
	struct vm_struct___160 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___127 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___244 *pgtable_t___243;

struct address_space___242;

struct dev_pagemap___233;

struct page___244 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___242 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___244 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___243 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___243 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___233 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___104 *mem_cgroup;
};

struct pglist_data___243;

struct lruvec___243 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___243 *pgdat;
};

struct zone___243 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___243 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___243 {
	struct zone___243 *zone;
	int zone_idx;
};

struct zonelist___243 {
	struct zoneref___243 _zonerefs[25];
};

struct pglist_data___243 {
	struct zone___243 node_zones[3];
	struct zonelist___243 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___244 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___244 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___243 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___244 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___244 *owner;
};

struct secondary_data___244 {
	void *stack;
	struct task_struct___244 *task;
	long int status;
};

struct blocking_notifier_head___243 {
	struct rw_semaphore___244 rwsem;
	struct notifier_block *head;
};

struct cgroup___188;

struct cgroup_subsys___188;

struct cgroup_subsys_state___189 {
	struct cgroup___188 *cgroup;
	struct cgroup_subsys___188 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___189 *parent;
};

struct mem_cgroup_id___22 {
	int id;
	union {
		refcount_t ref;
		struct {
			atomic_t ref;
		} __UNIQUE_ID_rh_kabi_hide53;
		union {		};
	};
};

struct kernfs_node___237;

struct cgroup_file___188 {
	struct kernfs_node___237 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___104;

struct mem_cgroup___104 {
	struct cgroup_subsys_state___189 css;
	struct mem_cgroup_id___22 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___188 events_file;
	struct cgroup_file___188 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___244 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___104 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct key___236;

struct ucounts___203;

struct user_namespace___203 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___203 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___28 ns;
	long unsigned int flags;
	struct key___236 *persistent_keyring_register;
	struct rw_semaphore___244 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___203 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct pid_namespace___183;

struct upid___183 {
	int nr;
	struct pid_namespace___183 *ns;
};

struct dentry___243;

struct pid_namespace___183 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___244 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___183 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___243 *proc_self;
	struct dentry___243 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___203 *user_ns;
	struct ucounts___203 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___28 ns;
};

struct pid___183 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___183 numbers[1];
};

struct user_struct___236 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___236 *uid_keyring;
	struct key___236 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___233;

struct vm_area_struct___244 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___244 *vm_next;
	struct vm_area_struct___244 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___243 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___233 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___243 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct linux_binfmt___40;

struct core_state___243;

struct mm_struct___243 {
	struct {
		struct vm_area_struct___244 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___243 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___244 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___40 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___243 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___244 *owner;
		struct user_namespace___203 *user_ns;
		struct file___243 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___243 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___236 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___236 *session_keyring;
	struct key___236 *process_keyring;
	struct key___236 *thread_keyring;
	struct key___236 *request_key_auth;
	void *security;
	struct user_struct___236 *user;
	struct user_namespace___203 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___41;

struct cgroup_namespace___188;

struct nsproxy___223 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___183 *pid_ns_for_children;
	struct net___41 *net_ns;
	struct cgroup_namespace___188 *cgroup_ns;
};

struct signal_struct___201 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___244 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___244 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___183 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___183 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___243 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___183 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___119;

struct bio_list___119 {
	struct bio___119 *head;
	struct bio___119 *tail;
};

struct bdi_writeback_congested___119;

struct bdi_writeback___119 {
	struct backing_dev_info___119 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___119 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___189 *memcg_css;
	struct cgroup_subsys_state___189 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___207;

struct backing_dev_info___119 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___119 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___207 *dev;
	struct device___207 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___243 *debug_dir;
	struct dentry___243 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___188 {
	struct cgroup_subsys_state___189 *subsys[13];
	refcount_t refcount;
	struct css_set___188 *dom_cset;
	struct cgroup___188 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___188 *mg_src_cgrp;
	struct cgroup___188 *mg_dst_cgrp;
	struct css_set___188 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___242;

struct pipe_buffer___53;

struct pipe_inode_info___53 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___244 *tmp_page;
	struct fasync_struct___242 *fasync_readers;
	struct fasync_struct___242 *fasync_writers;
	struct pipe_buffer___53 *bufs;
	struct user_struct___236 *user;
};

struct vm_struct___160 {
	struct vm_struct___160 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___244 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___213 {
	struct task_struct___244 task;
	long unsigned int stack[8192];
};

struct address_space_operations___242;

struct address_space___242 {
	struct inode___243 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___244 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___242 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___233)(struct vm_area_struct___244 *, long unsigned int, const struct page___244 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___233)(struct page___244 *, void *);

struct dev_pagemap___233 {
	dev_page_fault_t___233 page_fault;
	dev_page_free_t___233 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___207 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___242 {
	struct vfsmount *mnt;
	struct dentry___243 *dentry;
};

struct fown_struct___183 {
	rwlock_t lock;
	struct pid___183 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___243 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___242 f_path;
	struct inode___243 *f_inode;
	const struct file_operations___243 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___183 f_owner;
	const struct cred___236 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___242 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___233;

struct vm_operations_struct___233 {
	void (*open)(struct vm_area_struct___244 *);
	void (*close)(struct vm_area_struct___244 *);
	int (*split)(struct vm_area_struct___244 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___244 *);
	vm_fault_t (*fault)(struct vm_fault___233 *);
	vm_fault_t (*huge_fault)(struct vm_fault___233 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___233 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___244 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___233 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___233 *);
	int (*access)(struct vm_area_struct___244 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___244 *);
	int (*set_policy)(struct vm_area_struct___244 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___244 *, long unsigned int);
	struct page___244 * (*find_special_page)(struct vm_area_struct___244 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___243 {
	struct task_struct___244 *task;
	struct core_thread___243 *next;
};

struct core_state___243 {
	atomic_t nr_threads;
	struct core_thread___243 dumper;
	struct completion startup;
};

struct linux_binprm___41;

struct coredump_params___40;

struct linux_binfmt___40 {
	struct list_head lh;
	struct module___197 *module;
	int (*load_binary)(struct linux_binprm___41 *);
	int (*load_shlib)(struct file___243 *);
	int (*core_dump)(struct coredump_params___40 *);
	long unsigned int min_coredump;
};

struct vm_fault___233 {
	struct vm_area_struct___244 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___244 *cow_page;
	struct mem_cgroup___104 *memcg;
	struct page___244 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___243 prealloc_pte;
};

struct kset___230;

struct kobj_type___230;

struct kobject___231 {
	const char *name;
	struct list_head entry;
	struct kobject___231 *parent;
	struct kset___230 *kset;
	struct kobj_type___230 *ktype;
	struct kernfs_node___237 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___194 {
	struct kobject___231 kobj;
	struct module___197 *mod;
	struct kobject___231 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___194 {
	struct module___197 *mod;
	struct latch_tree_node node;
};

struct module_layout___194 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___194 mtn;
};

struct module_attribute___194;

struct kernel_param___194;

struct module___197 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___194 mkobj;
	struct module_attribute___194 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___231 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___194 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___194 core_layout;
	struct module_layout___194 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide54;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide55;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bio_vec___119 {
	struct page___244 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___110 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___119 *bvec;
		struct pipe_inode_info___53 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct msghdr___20 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___110 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___243 *msg_iocb;
};

struct kiocb___243 {
	struct file___243 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___243 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dentry_operations___242;

struct super_block___242;

struct dentry___243 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___243 *d_parent;
	struct qstr d_name;
	struct inode___243 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___242 *d_op;
	struct super_block___242 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___242;

struct block_device___243;

struct inode___243 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___242 *i_op;
	struct super_block___242 *i_sb;
	struct address_space___242 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___244 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___119 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___243 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___242 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___53 *i_pipe;
		struct block_device___243 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___242 {
	int (*d_revalidate)(struct dentry___243 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___243 *, unsigned int);
	int (*d_hash)(const struct dentry___243 *, struct qstr *);
	int (*d_compare)(const struct dentry___243 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___243 *);
	int (*d_init)(struct dentry___243 *);
	void (*d_release)(struct dentry___243 *);
	void (*d_prune)(struct dentry___243 *);
	void (*d_iput)(struct dentry___243 *, struct inode___243 *);
	char * (*d_dname)(struct dentry___243 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___242 *);
	int (*d_manage)(const struct path___242 *, bool);
	struct dentry___243 * (*d_real)(struct dentry___243 *, const struct inode___243 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___242;

struct mem_dqinfo___242 {
	struct quota_format_type___242 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___242;

struct quota_info___242 {
	unsigned int flags;
	struct rw_semaphore___244 dqio_sem;
	struct inode___243 *files[3];
	struct mem_dqinfo___242 info[3];
	const struct quota_format_ops___242 *ops[3];
};

struct rcuwait___242 {
	struct task_struct___244 *task;
};

struct percpu_rw_semaphore___242 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___244 rw_sem;
	struct rcuwait___242 writer;
	int readers_block;
};

struct sb_writers___242 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___242 rw_sem[3];
};

struct shrink_control___104;

struct shrinker___104 {
	long unsigned int (*count_objects)(struct shrinker___104 *, struct shrink_control___104 *);
	long unsigned int (*scan_objects)(struct shrinker___104 *, struct shrink_control___104 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___242;

struct super_operations___242;

struct dquot_operations___242;

struct quotactl_ops___242;

struct super_block___242 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___242 *s_type;
	const struct super_operations___242 *s_op;
	const struct dquot_operations___242 *dq_op;
	const struct quotactl_ops___242 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___243 *s_root;
	struct rw_semaphore___244 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___243 *s_bdev;
	struct backing_dev_info___119 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___242 s_dquot;
	struct sb_writers___242 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___242 *s_d_op;
	int cleancache_poolid;
	struct shrinker___104 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___203 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___104 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___104 *memcg;
};

struct iattr___242 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___243 *ia_file;
};

struct dquot___242 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___242 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___242 {
	int qf_fmt_id;
	const struct quota_format_ops___242 *qf_ops;
	struct module___197 *qf_owner;
	struct quota_format_type___242 *qf_next;
};

struct quota_format_ops___242 {
	int (*check_quota_file)(struct super_block___242 *, int);
	int (*read_file_info)(struct super_block___242 *, int);
	int (*write_file_info)(struct super_block___242 *, int);
	int (*free_file_info)(struct super_block___242 *, int);
	int (*read_dqblk)(struct dquot___242 *);
	int (*commit_dqblk)(struct dquot___242 *);
	int (*release_dqblk)(struct dquot___242 *);
	int (*get_next_id)(struct super_block___242 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___242 {
	int (*write_dquot)(struct dquot___242 *);
	struct dquot___242 * (*alloc_dquot)(struct super_block___242 *, int);
	void (*destroy_dquot)(struct dquot___242 *);
	int (*acquire_dquot)(struct dquot___242 *);
	int (*release_dquot)(struct dquot___242 *);
	int (*mark_dirty)(struct dquot___242 *);
	int (*write_info)(struct super_block___242 *, int);
	qsize_t * (*get_reserved_space)(struct inode___243 *);
	int (*get_projid)(struct inode___243 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___243 *, qsize_t *);
	int (*get_next_id)(struct super_block___242 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___242 {
	int (*quota_on)(struct super_block___242 *, int, int, const struct path___242 *);
	int (*quota_off)(struct super_block___242 *, int);
	int (*quota_enable)(struct super_block___242 *, unsigned int);
	int (*quota_disable)(struct super_block___242 *, unsigned int);
	int (*quota_sync)(struct super_block___242 *, int);
	int (*set_info)(struct super_block___242 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___242 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___242 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___242 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___242 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___242 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___115;

struct address_space_operations___242 {
	int (*writepage)(struct page___244 *, struct writeback_control___115 *);
	int (*readpage)(struct file___243 *, struct page___244 *);
	int (*writepages)(struct address_space___242 *, struct writeback_control___115 *);
	int (*set_page_dirty)(struct page___244 *);
	int (*readpages)(struct file___243 *, struct address_space___242 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___243 *, struct address_space___242 *, loff_t, unsigned int, unsigned int, struct page___244 **, void **);
	int (*write_end)(struct file___243 *, struct address_space___242 *, loff_t, unsigned int, unsigned int, struct page___244 *, void *);
	sector_t (*bmap)(struct address_space___242 *, sector_t);
	void (*invalidatepage)(struct page___244 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___244 *, gfp_t);
	void (*freepage)(struct page___244 *);
	ssize_t (*direct_IO)(struct kiocb___243 *, struct iov_iter___110 *);
	int (*migratepage)(struct address_space___242 *, struct page___244 *, struct page___244 *, enum migrate_mode);
	bool (*isolate_page)(struct page___244 *, isolate_mode_t);
	void (*putback_page)(struct page___244 *);
	int (*launder_page)(struct page___244 *);
	int (*is_partially_uptodate)(struct page___244 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___244 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___242 *, struct page___244 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___243 *, sector_t *);
	void (*swap_deactivate)(struct file___243 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___115 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___119 *wb;
	struct inode___243 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___243 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___243 *bd_inode;
	struct super_block___242 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___243 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___119 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___242 {
	struct dentry___243 * (*lookup)(struct inode___243 *, struct dentry___243 *, unsigned int);
	const char * (*get_link)(struct dentry___243 *, struct inode___243 *, struct delayed_call *);
	int (*permission)(struct inode___243 *, int);
	struct posix_acl * (*get_acl)(struct inode___243 *, int);
	int (*readlink)(struct dentry___243 *, char *, int);
	int (*create)(struct inode___243 *, struct dentry___243 *, umode_t, bool);
	int (*link)(struct dentry___243 *, struct inode___243 *, struct dentry___243 *);
	int (*unlink)(struct inode___243 *, struct dentry___243 *);
	int (*symlink)(struct inode___243 *, struct dentry___243 *, const char *);
	int (*mkdir)(struct inode___243 *, struct dentry___243 *, umode_t);
	int (*rmdir)(struct inode___243 *, struct dentry___243 *);
	int (*mknod)(struct inode___243 *, struct dentry___243 *, umode_t, dev_t);
	int (*rename)(struct inode___243 *, struct dentry___243 *, struct inode___243 *, struct dentry___243 *, unsigned int);
	int (*setattr)(struct dentry___243 *, struct iattr___242 *);
	int (*getattr)(const struct path___242 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___243 *, char *, size_t);
	int (*fiemap)(struct inode___243 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___243 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___243 *, struct dentry___243 *, struct file___243 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___243 *, struct dentry___243 *, umode_t);
	int (*set_acl)(struct inode___243 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___242 {
	void (*fl_copy_lock)(struct file_lock___243 *, struct file_lock___243 *);
	void (*fl_release_private)(struct file_lock___243 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___242;

struct file_lock___243 {
	struct file_lock___243 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___243 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___242 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___242 *fl_ops;
	const struct lock_manager_operations___242 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___242 {
	int (*lm_compare_owner)(struct file_lock___243 *, struct file_lock___243 *);
	long unsigned int (*lm_owner_key)(struct file_lock___243 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___243 *);
	int (*lm_grant)(struct file_lock___243 *, int);
	bool (*lm_break)(struct file_lock___243 *);
	int (*lm_change)(struct file_lock___243 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___243 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___242 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___242 *fa_next;
	struct file___243 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___242 {
	const char *name;
	int fs_flags;
	struct dentry___243 * (*mount)(struct file_system_type___242 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___242 *);
	struct module___197 *owner;
	struct file_system_type___242 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___242 {
	struct inode___243 * (*alloc_inode)(struct super_block___242 *);
	void (*destroy_inode)(struct inode___243 *);
	void (*dirty_inode)(struct inode___243 *, int);
	int (*write_inode)(struct inode___243 *, struct writeback_control___115 *);
	int (*drop_inode)(struct inode___243 *);
	void (*evict_inode)(struct inode___243 *);
	void (*put_super)(struct super_block___242 *);
	int (*sync_fs)(struct super_block___242 *, int);
	int (*freeze_super)(struct super_block___242 *);
	int (*freeze_fs)(struct super_block___242 *);
	int (*thaw_super)(struct super_block___242 *);
	int (*unfreeze_fs)(struct super_block___242 *);
	int (*statfs)(struct dentry___243 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___242 *, int *, char *);
	void (*umount_begin)(struct super_block___242 *);
	int (*show_options)(struct seq_file___219 *, struct dentry___243 *);
	int (*show_devname)(struct seq_file___219 *, struct dentry___243 *);
	int (*show_path)(struct seq_file___219 *, struct dentry___243 *);
	int (*show_stats)(struct seq_file___219 *, struct dentry___243 *);
	ssize_t (*quota_read)(struct super_block___242 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___242 *, int, const char *, size_t, loff_t);
	struct dquot___242 ** (*get_dquots)(struct inode___243 *);
	int (*bdev_try_to_free_page)(struct super_block___242 *, struct page___244 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___242 *, struct shrink_control___104 *);
	long int (*free_cached_objects)(struct super_block___242 *, struct shrink_control___104 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___153)(struct file___243 *, wait_queue_head_t *, struct poll_table_struct___151 *);

struct poll_table_struct___151 {
	poll_queue_proc___153 _qproc;
	__poll_t _key;
};

struct seq_operations___217;

struct seq_file___219 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___217 *op;
	int poll_event;
	const struct file___243 *file;
	void *private;
};

typedef void bio_end_io_t___119(struct bio___119 *);

struct bio_integrity_payload___119;

struct bio_set___119;

struct bio___119 {
	struct bio___119 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___119 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___119 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___119 *bi_io_vec;
	struct bio_set___119 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___119 bi_inline_vecs[0];
};

struct socket_wq___19 {
	wait_queue_head_t wait;
	struct fasync_struct___242 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct sock___20;

struct proto_ops___19;

struct socket___20 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___19 *wq;
	struct file___243 *file;
	struct sock___20 *sk;
	const struct proto_ops___19 *ops;
};

typedef struct {
	struct net___41 *net;
} possible_net_t___30;

struct proto___18;

struct sock_common___18 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___18 *skc_prot;
	possible_net_t___30 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___20 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___33;

struct sk_buff_head___29 {
	struct sk_buff___33 *next;
	struct sk_buff___33 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___18;

struct dst_entry___19;

struct net_device___33;

struct sock___20 {
	struct sock_common___18 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___29 sk_error_queue;
	struct sk_buff_head___29 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___33 *head;
		struct sk_buff___33 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___18 *sk_filter;
	union {
		struct socket_wq___19 *sk_wq;
		struct socket_wq___19 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___19 *sk_rx_dst;
	struct dst_entry___19 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___33 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___29 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___243 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___18 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___183 *sk_peer_pid;
	const struct cred___236 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___20 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___104 *sk_memcg;
	void (*sk_state_change)(struct sock___20 *);
	void (*sk_data_ready)(struct sock___20 *);
	void (*sk_write_space)(struct sock___20 *);
	void (*sk_error_report)(struct sock___20 *);
	int (*sk_backlog_rcv)(struct sock___20 *, struct sk_buff___33 *);
	struct sk_buff___33 * (*sk_validate_xmit_skb)(struct sock___20 *, struct net_device___33 *, struct sk_buff___33 *);
	void (*sk_destruct)(struct sock___20 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

typedef int (*sk_read_actor_t___18)(read_descriptor_t *, struct sk_buff___33 *, unsigned int, size_t);

struct proto_ops___19 {
	int family;
	struct module___197 *owner;
	int (*release)(struct socket___20 *);
	int (*bind)(struct socket___20 *, struct sockaddr *, int);
	int (*connect)(struct socket___20 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___20 *, struct socket___20 *);
	int (*accept)(struct socket___20 *, struct socket___20 *, int, bool);
	int (*getname)(struct socket___20 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___243 *, struct socket___20 *, struct poll_table_struct___151 *);
	int (*ioctl)(struct socket___20 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___20 *, int);
	int (*shutdown)(struct socket___20 *, int);
	int (*setsockopt)(struct socket___20 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___20 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___20 *, struct msghdr___20 *, size_t);
	int (*recvmsg)(struct socket___20 *, struct msghdr___20 *, size_t, int);
	int (*mmap)(struct file___243 *, struct socket___20 *, struct vm_area_struct___244 *);
	ssize_t (*sendpage)(struct socket___20 *, struct page___244 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___20 *, loff_t *, struct pipe_inode_info___53 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___20 *, int);
	int (*peek_len)(struct socket___20 *);
	int (*read_sock)(struct sock___20 *, read_descriptor_t *, sk_read_actor_t___18);
	int (*sendpage_locked)(struct sock___20 *, struct page___244 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___20 *, struct msghdr___20 *, size_t);
	int (*set_rcvlowat)(struct sock___20 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct nf_bridge_info___29;

struct sk_buff___33 {
	union {
		struct {
			struct sk_buff___33 *next;
			struct sk_buff___33 *prev;
			union {
				struct net_device___33 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___20 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___33 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___29 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___29;

struct netns_frags___29 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___29 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ip_ra_chain___7;

struct fib_rules_ops___18;

struct fib_notifier_ops___18;

struct netns_ipv4___29 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___7 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___18 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___20 *fibnl;
	struct sock___20 **icmp_sk;
	struct sock___20 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___20 **tcp_sk;
	struct netns_frags___29 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___18 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___18 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___18 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___19;

struct dst_ops___39 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___39 *);
	struct dst_entry___19 * (*check)(struct dst_entry___19 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___19 *);
	unsigned int (*mtu)(const struct dst_entry___19 *);
	u32 * (*cow_metrics)(struct dst_entry___19 *, long unsigned int);
	void (*destroy)(struct dst_entry___19 *);
	void (*ifdown)(struct dst_entry___19 *, struct net_device___33 *, int);
	struct dst_entry___19 * (*negative_advice)(struct dst_entry___19 *);
	void (*link_failure)(struct sk_buff___33 *);
	void (*update_pmtu)(struct dst_entry___19 *, struct sock___20 *, struct sk_buff___33 *, u32);
	void (*redirect)(struct dst_entry___19 *, struct sock___20 *, struct sk_buff___33 *);
	int (*local_out)(struct net___41 *, struct sock___20 *, struct sk_buff___33 *);
	struct neighbour___19 * (*neigh_lookup)(const struct dst_entry___19 *, struct sk_buff___33 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___19 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___39 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___29 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___39 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___18 *fib6_rules_ops;
	struct sock___20 **icmp_sk;
	struct sock___20 *ndisc_sk;
	struct sock___20 *tcp_sk;
	struct sock___20 *igmp_sk;
	struct sock___20 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___18 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___18 *notifier_ops;
	struct fib_notifier_ops___18 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___19 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___20 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___29 {
	struct netns_frags___29 frags;
};

struct netns_xfrm___39 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___20 *nlsk;
	struct sock___20 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___39 xfrm4_dst_ops;
	struct dst_ops___39 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___28;

struct net___41 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___203 *user_ns;
	struct ucounts___203 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___28 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___20 *rtnl;
	struct sock___20 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___33 *loopback_dev;
	struct netns_core core;
	struct netns_mib___2 mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___29 ipv4;
	struct netns_ipv6___39 ipv6;
	struct netns_sctp___19 sctp;
	struct netns_nf___2 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___29 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___20 *nfnl;
	struct sock___20 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___39 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can___2 can;
	struct sock___20 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___28 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kernfs_root___237;

struct kernfs_elem_dir___237 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___237 *root;
};

struct kernfs_syscall_ops___237;

struct kernfs_root___237 {
	struct kernfs_node___237 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___237 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___237 {
	struct kernfs_node___237 *target_kn;
};

struct kernfs_ops___237;

struct kernfs_elem_attr___237 {
	const struct kernfs_ops___237 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___237 *notify_next;
};

struct kernfs_node___237 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___237 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___237 dir;
		struct kernfs_elem_symlink___237 symlink;
		struct kernfs_elem_attr___237 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___237;

struct kernfs_ops___237 {
	int (*open)(struct kernfs_open_file___237 *);
	void (*release)(struct kernfs_open_file___237 *);
	int (*seq_show)(struct seq_file___219 *, void *);
	void * (*seq_start)(struct seq_file___219 *, loff_t *);
	void * (*seq_next)(struct seq_file___219 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___219 *, void *);
	ssize_t (*read)(struct kernfs_open_file___237 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___237 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___237 *, struct vm_area_struct___244 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___237 *, struct poll_table_struct___151 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___237 {
	int (*remount_fs)(struct kernfs_root___237 *, int *, char *);
	int (*show_options)(struct seq_file___219 *, struct kernfs_root___237 *);
	int (*mkdir)(struct kernfs_node___237 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___237 *);
	int (*rename)(struct kernfs_node___237 *, struct kernfs_node___237 *, const char *);
	int (*show_path)(struct seq_file___219 *, struct kernfs_node___237 *, struct kernfs_root___237 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___237 {
	struct kernfs_node___237 *kn;
	struct file___243 *file;
	struct seq_file___219 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___233 *vm_ops;
};

struct kobj_ns_type_operations___18 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___20 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___208;

struct attribute_group___209 {
	const char *name;
	umode_t (*is_visible)(struct kobject___231 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___231 *, struct bin_attribute___208 *, int);
	struct attribute **attrs;
	struct bin_attribute___208 **bin_attrs;
};

struct bin_attribute___208 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___243 *, struct kobject___231 *, struct bin_attribute___208 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___243 *, struct kobject___231 *, struct bin_attribute___208 *, char *, loff_t, size_t);
	int (*mmap)(struct file___243 *, struct kobject___231 *, struct bin_attribute___208 *, struct vm_area_struct___244 *);
};

struct sysfs_ops___230 {
	ssize_t (*show)(struct kobject___231 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___231 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___230;

struct kset___230 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___231 kobj;
	const struct kset_uevent_ops___230 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___230 {
	void (*release)(struct kobject___231 *);
	const struct sysfs_ops___230 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___18 * (*child_ns_type)(struct kobject___231 *);
	const void * (*namespace)(struct kobject___231 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___230 {
	int (* const filter)(struct kset___230 *, struct kobject___231 *);
	const char * (* const name)(struct kset___230 *, struct kobject___231 *);
	int (* const uevent)(struct kset___230 *, struct kobject___231 *, struct kobj_uevent_env *);
};

struct kobj_attribute___224 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___231 *, struct kobj_attribute___224 *, char *);
	ssize_t (*store)(struct kobject___231 *, struct kobj_attribute___224 *, const char *, size_t);
};

struct dev_pm_ops___207 {
	int (*prepare)(struct device___207 *);
	void (*complete)(struct device___207 *);
	int (*suspend)(struct device___207 *);
	int (*resume)(struct device___207 *);
	int (*freeze)(struct device___207 *);
	int (*thaw)(struct device___207 *);
	int (*poweroff)(struct device___207 *);
	int (*restore)(struct device___207 *);
	int (*suspend_late)(struct device___207 *);
	int (*resume_early)(struct device___207 *);
	int (*freeze_late)(struct device___207 *);
	int (*thaw_early)(struct device___207 *);
	int (*poweroff_late)(struct device___207 *);
	int (*restore_early)(struct device___207 *);
	int (*suspend_noirq)(struct device___207 *);
	int (*resume_noirq)(struct device___207 *);
	int (*freeze_noirq)(struct device___207 *);
	int (*thaw_noirq)(struct device___207 *);
	int (*poweroff_noirq)(struct device___207 *);
	int (*restore_noirq)(struct device___207 *);
	int (*runtime_suspend)(struct device___207 *);
	int (*runtime_resume)(struct device___207 *);
	int (*runtime_idle)(struct device___207 *);
};

struct dev_pm_info___207 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___207 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___207;

struct bus_type___207;

struct device_driver___207;

struct dev_pm_domain___207;

struct dma_map_ops___50;

struct fwnode_handle___142;

struct class___207;

struct device___207 {
	struct device___207 *parent;
	struct device_private *p;
	struct kobject___231 kobj;
	const char *init_name;
	const struct device_type___207 *type;
	struct mutex mutex;
	struct bus_type___207 *bus;
	struct device_driver___207 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___207 power;
	struct dev_pm_domain___207 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___50 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___142 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___207 *class;
	const struct attribute_group___209 **groups;
	void (*release)(struct device___207 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___207 {
	struct dev_pm_ops___207 ops;
	void (*detach)(struct device___207 *, bool);
	int (*activate)(struct device___207 *);
	void (*sync)(struct device___207 *);
	void (*dismiss)(struct device___207 *);
};

struct bus_type___207 {
	const char *name;
	const char *dev_name;
	struct device___207 *dev_root;
	const struct attribute_group___209 **bus_groups;
	const struct attribute_group___209 **dev_groups;
	const struct attribute_group___209 **drv_groups;
	int (*match)(struct device___207 *, struct device_driver___207 *);
	int (*uevent)(struct device___207 *, struct kobj_uevent_env *);
	int (*probe)(struct device___207 *);
	int (*remove)(struct device___207 *);
	void (*shutdown)(struct device___207 *);
	int (*online)(struct device___207 *);
	int (*offline)(struct device___207 *);
	int (*suspend)(struct device___207 *, pm_message_t);
	int (*resume)(struct device___207 *);
	int (*num_vf)(struct device___207 *);
	int (*dma_configure)(struct device___207 *);
	const struct dev_pm_ops___207 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___207 {
	const char *name;
	struct bus_type___207 *bus;
	struct module___197 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___207 *);
	int (*remove)(struct device___207 *);
	void (*shutdown)(struct device___207 *);
	int (*suspend)(struct device___207 *, pm_message_t);
	int (*resume)(struct device___207 *);
	const struct attribute_group___209 **groups;
	const struct dev_pm_ops___207 *pm;
	void (*coredump)(struct device___207 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___207 {
	const char *name;
	const struct attribute_group___209 **groups;
	int (*uevent)(struct device___207 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___207 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___207 *);
	const struct dev_pm_ops___207 *pm;
};

struct class___207 {
	const char *name;
	struct module___197 *owner;
	const struct attribute_group___209 **class_groups;
	const struct attribute_group___209 **dev_groups;
	struct kobject___231 *dev_kobj;
	int (*dev_uevent)(struct device___207 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___207 *, umode_t *);
	void (*class_release)(struct class___207 *);
	void (*dev_release)(struct device___207 *);
	int (*shutdown_pre)(struct device___207 *);
	const struct kobj_ns_type_operations___18 *ns_type;
	const void * (*namespace)(struct device___207 *);
	const struct dev_pm_ops___207 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___50 {
	void * (*alloc)(struct device___207 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___207 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___207 *, struct vm_area_struct___244 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___207 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___207 *, struct page___244 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___207 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___207 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___207 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___207 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___207 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___207 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___207 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___207 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___207 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___207 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___207 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___207 *, u64);
	u64 (*get_required_mask)(struct device___207 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___142;

struct fwnode_handle___142 {
	struct fwnode_handle___142 *secondary;
	const struct fwnode_operations___142 *ops;
};

typedef void compound_page_dtor___233(struct page___244 *);

struct fwnode_reference_args___142;

struct fwnode_endpoint___142;

struct fwnode_operations___142 {
	struct fwnode_handle___142 * (*get)(struct fwnode_handle___142 *);
	void (*put)(struct fwnode_handle___142 *);
	bool (*device_is_available)(const struct fwnode_handle___142 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___142 *, const struct device___207 *);
	bool (*property_present)(const struct fwnode_handle___142 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___142 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___142 *, const char *, const char **, size_t);
	struct fwnode_handle___142 * (*get_parent)(const struct fwnode_handle___142 *);
	struct fwnode_handle___142 * (*get_next_child_node)(const struct fwnode_handle___142 *, struct fwnode_handle___142 *);
	struct fwnode_handle___142 * (*get_named_child_node)(const struct fwnode_handle___142 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___142 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___142 *);
	struct fwnode_handle___142 * (*graph_get_next_endpoint)(const struct fwnode_handle___142 *, struct fwnode_handle___142 *);
	struct fwnode_handle___142 * (*graph_get_remote_endpoint)(const struct fwnode_handle___142 *);
	struct fwnode_handle___142 * (*graph_get_port_parent)(struct fwnode_handle___142 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___142 *, struct fwnode_endpoint___142 *);
};

struct fwnode_endpoint___142 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___142 *local_fwnode;
};

struct fwnode_reference_args___142 {
	struct fwnode_handle___142 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___53;

struct pipe_buffer___53 {
	struct page___244 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___53 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___53 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___53 *, struct pipe_buffer___53 *);
	void (*release)(struct pipe_inode_info___53 *, struct pipe_buffer___53 *);
	int (*steal)(struct pipe_inode_info___53 *, struct pipe_buffer___53 *);
	union {
		bool (*get)(struct pipe_inode_info___53 *, struct pipe_buffer___53 *);
		struct {
			void (*get)(struct pipe_inode_info___53 *, struct pipe_buffer___53 *);
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
};

struct nf_bridge_info___29 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___29 = 0,
		BRNF_PROTO_8021Q___29 = 1,
		BRNF_PROTO_PPPOE___29 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___33 *physindev;
	struct net_device___33 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___29(struct sk_buff___33 **);

struct net_device_ops___29;

struct ethtool_ops___29;

struct l3mdev_ops___19;

struct ndisc_ops___11;

struct xfrmdev_ops___29;

struct tlsdev_ops___29;

struct header_ops___29;

struct inet6_dev___11;

struct netdev_rx_queue___29;

struct mini_Qdisc___28;

struct netdev_queue___29;

struct Qdisc___28;

struct rtnl_link_ops___28;

struct dcbnl_rtnl_ops___29;

struct net_device___33 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___29 *netdev_ops;
	const struct ethtool_ops___29 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___19 *l3mdev_ops;
	const struct ndisc_ops___11 *ndisc_ops;
	const struct xfrmdev_ops___29 *xfrmdev_ops;
	const struct tlsdev_ops___29 *tlsdev_ops;
	const struct header_ops___29 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___230 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___11 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___29 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___28 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___29 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___28 *miniq_ingress;
	struct netdev_queue___29 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___29 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___28 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___28 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___29 = 0,
		NETREG_REGISTERED___29 = 1,
		NETREG_UNREGISTERING___29 = 2,
		NETREG_UNREGISTERED___29 = 3,
		NETREG_RELEASED___29 = 4,
		NETREG_DUMMY___29 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___29 = 0,
		RTNL_LINK_INITIALIZING___29 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___33 *);
	struct netpoll_info *npinfo;
	possible_net_t___30 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___207 dev;
	const struct attribute_group___209 *sysfs_groups[4];
	const struct attribute_group___209 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___28 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___29 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct ethtool_ops___29 {
	int (*get_settings)(struct net_device___33 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___33 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___33 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___33 *);
	void (*get_regs)(struct net_device___33 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___33 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___33 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___33 *);
	void (*set_msglevel)(struct net_device___33 *, u32);
	int (*nway_reset)(struct net_device___33 *);
	u32 (*get_link)(struct net_device___33 *);
	int (*get_eeprom_len)(struct net_device___33 *);
	int (*get_eeprom)(struct net_device___33 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___33 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___33 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___33 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___33 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___33 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___33 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___33 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___33 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___33 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___33 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___33 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___33 *);
	void (*complete)(struct net_device___33 *);
	u32 (*get_priv_flags)(struct net_device___33 *);
	int (*set_priv_flags)(struct net_device___33 *, u32);
	int (*get_sset_count)(struct net_device___33 *, int);
	int (*get_rxnfc)(struct net_device___33 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___33 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___33 *, struct ethtool_flash *);
	int (*reset)(struct net_device___33 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___33 *);
	u32 (*get_rxfh_indir_size)(struct net_device___33 *);
	int (*get_rxfh)(struct net_device___33 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___33 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___33 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___33 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___33 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___33 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___33 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___33 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___33 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___33 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___33 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___33 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___33 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___33 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___33 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___33 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___33 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___33 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___33 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___33 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___33 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___33 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	int (*get_fecparam)(struct net_device___33 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___33 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___33 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___33 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___33 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___29;

struct inet_frags___29 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___29 *, const void *);
	void (*destructor)(struct inet_frag_queue___29 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___29 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___33 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___33 *fragments_tail;
	struct sk_buff___33 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___29 *net;
	struct callback_head rcu;
};

struct ip_ra_chain___7 {
	struct ip_ra_chain___7 *next;
	struct sock___20 *sk;
	union {
		void (*destructor)(struct sock___20 *);
		struct sock___20 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___18;

struct fib_lookup_arg___18;

struct fib_rules_ops___18 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___18 *, struct flowi *, int, struct fib_lookup_arg___18 *);
	bool (*suppress)(struct fib_rule___18 *, struct fib_lookup_arg___18 *);
	int (*match)(struct fib_rule___18 *, struct flowi *, int);
	int (*configure)(struct fib_rule___18 *, struct sk_buff___33 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___18 *);
	int (*compare)(struct fib_rule___18 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___18 *, struct sk_buff___33 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___18 *);
	void (*flush_cache)(struct fib_rules_ops___18 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___197 *owner;
	struct net___41 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___18 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___41 *);
	int (*fib_dump)(struct net___41 *, struct notifier_block *);
	struct module___197 *owner;
	struct callback_head rcu;
};

struct dst_entry___19 {
	struct net_device___33 *dev;
	struct dst_ops___39 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___33 *);
	int (*output)(struct net___41 *, struct sock___20 *, struct sk_buff___33 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___18;

struct neigh_parms___19;

struct neigh_ops___18;

struct neighbour___19 {
	struct neighbour___19 *next;
	struct neigh_table___18 *tbl;
	struct neigh_parms___19 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___29 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___19 *, struct sk_buff___33 *);
	const struct neigh_ops___18 *ops;
	struct callback_head rcu;
	struct net_device___33 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct ucounts___203 {
	struct hlist_node node;
	struct user_namespace___203 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_prog_aux___30;

struct bpf_prog___28 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___30 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

typedef int (*key_restrict_link_func_t___236)(struct key___236 *, const struct key_type *, const union key_payload *, struct key___236 *);

struct key_restriction___236;

struct key___236 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___244 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key___5 index_key;
		struct {
			struct key_type___5 *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___236 *restrict_link;
};

struct key_restriction___236 {
	key_restrict_link_func_t___236 check;
	struct key___236 *key;
	struct key_type *keytype;
};

struct seq_operations___217 {
	void * (*start)(struct seq_file___219 *, loff_t *);
	void (*stop)(struct seq_file___219 *, void *);
	void * (*next)(struct seq_file___219 *, void *, loff_t *);
	int (*show)(struct seq_file___219 *, void *);
};

struct pernet_operations___30 {
	struct list_head list;
	int (*init)(struct net___41 *);
	void (*exit)(struct net___41 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___29 {
	int (*ieee_getets)(struct net_device___33 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___33 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___33 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___33 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___33 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___33 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___33 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___33 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___33 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___33 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___33 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___33 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___33 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___33 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___33 *);
	u8 (*setstate)(struct net_device___33 *, u8);
	void (*getpermhwaddr)(struct net_device___33 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___33 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___33 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___33 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___33 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___33 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___33 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___33 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___33 *, int, u8 *);
	void (*setpfccfg)(struct net_device___33 *, int, u8);
	void (*getpfccfg)(struct net_device___33 *, int, u8 *);
	u8 (*setall)(struct net_device___33 *);
	u8 (*getcap)(struct net_device___33 *, int, u8 *);
	int (*getnumtcs)(struct net_device___33 *, int, u8 *);
	int (*setnumtcs)(struct net_device___33 *, int, u8);
	u8 (*getpfcstate)(struct net_device___33 *);
	void (*setpfcstate)(struct net_device___33 *, u8);
	void (*getbcncfg)(struct net_device___33 *, int, u32 *);
	void (*setbcncfg)(struct net_device___33 *, int, u32);
	void (*getbcnrp)(struct net_device___33 *, int, u8 *);
	void (*setbcnrp)(struct net_device___33 *, int, u8);
	int (*setapp)(struct net_device___33 *, u8, u16, u8);
	int (*getapp)(struct net_device___33 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___33 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___33 *, int, u8);
	u8 (*getdcbx)(struct net_device___33 *);
	u8 (*setdcbx)(struct net_device___33 *, u8);
	int (*peer_getappinfo)(struct net_device___33 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___33 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___33 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___33 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___33 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___33 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___188 {
	refcount_t count;
	struct ns_common___28 ns;
	struct user_namespace___203 *user_ns;
	struct ucounts___203 *ucounts;
	struct css_set___188 *root_cset;
};

struct bpf_map___188;

struct bpf_map_ops___188 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___188 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___188 *, struct file___243 *);
	void (*map_free)(struct bpf_map___188 *);
	int (*map_get_next_key)(struct bpf_map___188 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___188 *);
	void * (*map_lookup_elem)(struct bpf_map___188 *, void *);
	int (*map_update_elem)(struct bpf_map___188 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___188 *, void *);
	int (*map_push_elem)(struct bpf_map___188 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___188 *, void *);
	int (*map_peek_elem)(struct bpf_map___188 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___188 *, struct file___243 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___188 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___188 *, void *, struct seq_file___219 *);
	int (*map_check_btf)(const struct bpf_map___188 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___188 {
	const struct bpf_map_ops___188 *ops;
	struct bpf_map___188 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___236 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___29;

struct bpf_map_dev_ops___29 {
	int (*map_get_next_key)(struct bpf_offloaded_map___29 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___29 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___29 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___29 *, void *);
};

struct bpf_offloaded_map___29 {
	struct bpf_map___188 map;
	struct net_device___33 *netdev;
	const struct bpf_map_dev_ops___29 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___28 {
	int (*test_run)(struct bpf_prog___28 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___28 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___28 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___28 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___28 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___28 *, u32 *);
};

struct bpf_prog_offload_ops___28 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___28 *);
	int (*translate)(struct bpf_prog___28 *);
	void (*destroy)(struct bpf_prog___28 *);
};

struct bpf_prog_offload___28 {
	struct bpf_prog___28 *prog;
	struct net_device___33 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___28 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___30 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___28 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___28 *ops;
	struct bpf_map___188 **used_maps;
	struct bpf_prog___28 *prog;
	struct user_struct___236 *user;
	u64 load_time;
	struct bpf_map___188 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___28 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___28 {
	struct bpf_prog___28 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___28 {
	struct callback_head rcu;
	struct bpf_prog_array_item___28 items[0];
};

struct cgroup_bpf___28 {
	struct bpf_prog_array___28 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___28 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___188;

typedef void (*kthread_work_func_t___188)(struct kthread_work___188 *);

struct kthread_worker___188;

struct kthread_work___188 {
	struct list_head node;
	kthread_work_func_t___188 func;
	struct kthread_worker___188 *worker;
	int canceling;
};

struct kthread_worker___188 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___244 *task;
	struct kthread_work___188 *current_work;
};

struct kthread_delayed_work___188 {
	struct kthread_work___188 work;
	struct timer_list timer;
};

struct psi_group___188 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___188 *poll_kworker;
	struct kthread_delayed_work___188 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___188;

struct cgroup_rstat_cpu___188;

struct cgroup___188 {
	struct cgroup_subsys_state___189 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___237 *kn;
	struct cgroup_file___188 procs_file;
	struct cgroup_file___188 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___189 *subsys[13];
	struct cgroup_root___188 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___188 *dom_cgrp;
	struct cgroup_rstat_cpu___188 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___28 bpf;
	atomic_t congestion_count;
	struct cgroup___188 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___188 psi;
	int ancestor_ids[0];
};

struct cftype___188;

struct cgroup_subsys___188 {
	struct cgroup_subsys_state___189 * (*css_alloc)(struct cgroup_subsys_state___189 *);
	int (*css_online)(struct cgroup_subsys_state___189 *);
	void (*css_offline)(struct cgroup_subsys_state___189 *);
	void (*css_released)(struct cgroup_subsys_state___189 *);
	void (*css_free)(struct cgroup_subsys_state___189 *);
	void (*css_reset)(struct cgroup_subsys_state___189 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___189 *, int);
	int (*css_extra_stat_show)(struct seq_file___219 *, struct cgroup_subsys_state___189 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___244 *);
	void (*cancel_fork)(struct task_struct___244 *);
	void (*fork)(struct task_struct___244 *);
	void (*exit)(struct task_struct___244 *);
	void (*free)(struct task_struct___244 *);
	void (*bind)(struct cgroup_subsys_state___189 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___188 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___188 *dfl_cftypes;
	struct cftype___188 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___188 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___188 *updated_children;
	struct cgroup___188 *updated_next;
};

struct cgroup_root___188 {
	struct kernfs_root___237 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___188 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___188 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___188 *ss;
	struct list_head node;
	struct kernfs_ops___237 *kf_ops;
	int (*open)(struct kernfs_open_file___237 *);
	void (*release)(struct kernfs_open_file___237 *);
	u64 (*read_u64)(struct cgroup_subsys_state___189 *, struct cftype___188 *);
	s64 (*read_s64)(struct cgroup_subsys_state___189 *, struct cftype___188 *);
	int (*seq_show)(struct seq_file___219 *, void *);
	void * (*seq_start)(struct seq_file___219 *, loff_t *);
	void * (*seq_next)(struct seq_file___219 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___219 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___189 *, struct cftype___188 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___189 *, struct cftype___188 *, s64);
	ssize_t (*write)(struct kernfs_open_file___237 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___237 *, struct poll_table_struct___151 *);
};

struct xdp_rxq_info___29 {
	struct net_device___33 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___29 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___33 *dev_rx;
};

struct netlink_callback___29 {
	struct sk_buff___33 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___29 *);
	int (*dump)(struct sk_buff___33 *, struct netlink_callback___29 *);
	int (*done)(struct netlink_callback___29 *);
	void *data;
	struct module___197 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___29 {
	int (*create)(struct sk_buff___33 *, struct net_device___33 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___33 *, unsigned char *);
	int (*cache)(const struct neighbour___19 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___33 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___29 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___29 *, int);
	int poll_owner;
	struct net_device___33 *dev;
	struct sk_buff___33 *gro_list;
	struct sk_buff___33 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___29 {
	struct net_device___33 *dev;
	struct Qdisc___28 *qdisc;
	struct Qdisc___28 *qdisc_sleeping;
	struct kobject___231 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___33 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___28 {
	struct sk_buff___33 *head;
	struct sk_buff___33 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___28;

struct Qdisc___28 {
	int (*enqueue)(struct sk_buff___33 *, struct Qdisc___28 *, struct sk_buff___33 **);
	struct sk_buff___33 * (*dequeue)(struct Qdisc___28 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___28 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___29 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___29 gso_skb;
	struct qdisc_skb_head___28 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___28 *next_sched;
	struct sk_buff_head___29 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___29 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___231 kobj;
	struct net_device___33 *dev;
	long: 64;
	struct xdp_rxq_info___29 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___29)(struct net_device___33 *, struct sk_buff___33 *, struct net_device___33 *);

struct netdev_bpf___29 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___28 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___28 *prog;
			const struct bpf_prog_offload_ops___28 *ops;
		} verifier;
		struct {
			struct bpf_prog___28 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___29 *offmap;
		};
		struct {
			struct xdp_umem *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___29 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___33 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___29 {
	int (*tls_dev_add)(struct net_device___33 *, struct sock___20 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___33 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___33 *, struct sock___20 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___29 {
	int (*ndo_init)(struct net_device___33 *);
	void (*ndo_uninit)(struct net_device___33 *);
	int (*ndo_open)(struct net_device___33 *);
	int (*ndo_stop)(struct net_device___33 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___33 *, struct net_device___33 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___33 *, struct net_device___33 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___33 *, struct sk_buff___33 *, struct net_device___33 *, select_queue_fallback_t___29);
	void (*ndo_change_rx_flags)(struct net_device___33 *, int);
	void (*ndo_set_rx_mode)(struct net_device___33 *);
	int (*ndo_set_mac_address)(struct net_device___33 *, void *);
	int (*ndo_validate_addr)(struct net_device___33 *);
	int (*ndo_do_ioctl)(struct net_device___33 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___33 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___33 *, int);
	int (*ndo_neigh_setup)(struct net_device___33 *, struct neigh_parms___19 *);
	void (*ndo_tx_timeout)(struct net_device___33 *);
	void (*ndo_get_stats64)(struct net_device___33 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___33 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___33 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___33 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___33 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___33 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___33 *);
	int (*ndo_netpoll_setup)(struct net_device___33 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___33 *);
	int (*ndo_set_vf_mac)(struct net_device___33 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___33 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___33 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___33 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___33 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___33 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___33 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___33 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___33 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___33 *, int, struct sk_buff___33 *);
	int (*ndo_set_vf_guid)(struct net_device___33 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___33 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___33 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___33 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___33 *, const struct sk_buff___33 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___33 *, struct net_device___33 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___33 *, struct net_device___33 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___33 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___33 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___33 *, struct neighbour___19 *);
	void (*ndo_neigh_destroy)(struct net_device___33 *, struct neighbour___19 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___33 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___33 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___33 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___33 *, struct netlink_callback___29 *, struct net_device___33 *, struct net_device___33 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___33 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___33 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___33 *, u32, u32, struct net_device___33 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___33 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___33 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___33 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___33 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___33 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___33 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___33 *, struct net_device___33 *);
	void (*ndo_dfwd_del_station)(struct net_device___33 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___33 *);
	int (*ndo_set_tx_maxrate)(struct net_device___33 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___33 *);
	int (*ndo_change_proto_down)(struct net_device___33 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___33 *, struct sk_buff___33 *);
	void (*ndo_set_rx_headroom)(struct net_device___33 *, int);
	int (*ndo_bpf)(struct net_device___33 *, struct netdev_bpf___29 *);
	int (*ndo_xdp_xmit)(struct net_device___33 *, int, struct xdp_frame___29 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___33 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___33 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___19 {
	possible_net_t___30 net;
	struct net_device___33 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___19 *);
	void (*neigh_cleanup)(struct neighbour___19 *);
	struct neigh_table___18 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___19 {
	u32 (*l3mdev_fib_table)(const struct net_device___33 *);
	struct sk_buff___33 * (*l3mdev_l3_rcv)(struct net_device___33 *, struct sk_buff___33 *, u16);
	struct sk_buff___33 * (*l3mdev_l3_out)(struct net_device___33 *, struct sock___20 *, struct sk_buff___33 *, u16);
	struct dst_entry___19 * (*l3mdev_link_scope_lookup)(const struct net_device___33 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct ndisc_ops___11 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___33 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___33 *, struct neighbour___19 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___33 *, u8, struct neighbour___19 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___33 *, struct sk_buff___33 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___41 *, struct net_device___33 *, const struct prefix_info *, struct inet6_dev___11 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___10;

struct inet6_dev___11 {
	struct net_device___33 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___10 *mc_list;
	struct ifmcaddr6___10 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	u8 rndid[8];
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___19 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
};

struct tcf_proto___28;

struct mini_Qdisc___28 {
	struct tcf_proto___28 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___28 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___33 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___41 *, struct net_device___33 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___33 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___33 *, struct list_head *);
	size_t (*get_size)(const struct net_device___33 *);
	int (*fill_info)(struct sk_buff___33 *, const struct net_device___33 *);
	size_t (*get_xstats_size)(const struct net_device___33 *);
	int (*fill_xstats)(struct sk_buff___33 *, const struct net_device___33 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___33 *, struct net_device___33 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___33 *, const struct net_device___33 *);
	int (*fill_slave_info)(struct sk_buff___33 *, const struct net_device___33 *, const struct net_device___33 *);
	struct net___41 * (*get_link_net)(const struct net_device___33 *);
	size_t (*get_linkxstats_size)(const struct net_device___33 *, int);
	int (*fill_linkxstats)(struct sk_buff___33 *, const struct net_device___33 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct netdev_notifier_info___2 {
	struct net_device___33 *dev;
	struct netlink_ext_ack *extack;
};

struct softnet_data___29 {
	struct list_head poll_list;
	struct sk_buff_head___29 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___29 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___28 *output_queue;
	struct Qdisc___28 **output_queue_tailp;
	struct sk_buff___33 *completion_queue;
	struct sk_buff_head___29 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___29 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___29 input_pkt_queue;
	struct napi_struct___29 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct linux_binprm___41 {
	char buf[256];
	struct vm_area_struct___244 *vma;
	long unsigned int vma_pages;
	struct mm_struct___243 *mm;
	long unsigned int p;
	unsigned int called_set_creds: 1;
	unsigned int cap_elevated: 1;
	unsigned int secureexec: 1;
	unsigned int recursion_depth;
	struct file___243 *file;
	struct cred___236 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
};

struct coredump_params___40 {
	union {
		const kernel_siginfo_t *siginfo;
		struct {
			const siginfo_t *siginfo;
		} __UNIQUE_ID_rh_kabi_hide38;
		union {		};
	};
	struct pt_regs *regs;
	struct file___243 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
};

struct bdi_writeback_congested___119 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___119 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___119 {
	struct bio___119 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___119 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___119 bip_inline_vecs[0];
};

struct bio_set___119 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___119 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___104 {
	struct mem_cgroup___104 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___104 {
	struct lruvec___243 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___104 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___104 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct kernel_param_ops___194 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___194 *);
	int (*get)(char *, const struct kernel_param___194 *);
	void (*free)(void *);
};

struct kparam_array___194;

struct kernel_param___194 {
	const char *name;
	struct module___197 *mod;
	const struct kernel_param_ops___194 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___194 *arr;
	};
};

struct kparam_array___194 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___194 *ops;
	void *elem;
};

struct module_attribute___194 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___194 *, struct module_kobject___194 *, char *);
	ssize_t (*store)(struct module_attribute___194 *, struct module_kobject___194 *, const char *, size_t);
	void (*setup)(struct module___197 *, const char *);
	int (*test)(struct module___197 *);
	void (*free)(struct module___197 *);
};

struct gnet_dump___28 {
	spinlock_t *lock;
	struct sk_buff___33 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___28;

struct Qdisc_ops___28 {
	struct Qdisc_ops___28 *next;
	const struct Qdisc_class_ops___28 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___33 *, struct Qdisc___28 *, struct sk_buff___33 **);
	struct sk_buff___33 * (*dequeue)(struct Qdisc___28 *);
	struct sk_buff___33 * (*peek)(struct Qdisc___28 *);
	int (*init)(struct Qdisc___28 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___28 *);
	void (*destroy)(struct Qdisc___28 *);
	int (*change)(struct Qdisc___28 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___28 *);
	int (*change_tx_queue_len)(struct Qdisc___28 *, unsigned int);
	int (*dump)(struct Qdisc___28 *, struct sk_buff___33 *);
	int (*dump_stats)(struct Qdisc___28 *, struct gnet_dump___28 *);
	void (*ingress_block_set)(struct Qdisc___28 *, u32);
	void (*egress_block_set)(struct Qdisc___28 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___28 *);
	u32 (*egress_block_get)(struct Qdisc___28 *);
	struct module___197 *owner;
};

struct tcf_block___28;

struct Qdisc_class_ops___28 {
	unsigned int flags;
	struct netdev_queue___29 * (*select_queue)(struct Qdisc___28 *, struct tcmsg *);
	int (*graft)(struct Qdisc___28 *, long unsigned int, struct Qdisc___28 *, struct Qdisc___28 **, struct netlink_ext_ack *);
	struct Qdisc___28 * (*leaf)(struct Qdisc___28 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___28 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___28 *, u32);
	int (*change)(struct Qdisc___28 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___28 *, long unsigned int);
	void (*walk)(struct Qdisc___28 *, struct qdisc_walker *);
	struct tcf_block___28 * (*tcf_block)(struct Qdisc___28 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___28 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___28 *, long unsigned int);
	int (*dump)(struct Qdisc___28 *, long unsigned int, struct sk_buff___33 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___28 *, long unsigned int, struct gnet_dump___28 *);
};

struct tcf_chain___28;

struct tcf_block___28 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___41 *net;
	struct Qdisc___28 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___28 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___28;

struct tcf_proto_ops___28;

struct tcf_proto___28 {
	struct tcf_proto___28 *next;
	void *root;
	int (*classify)(struct sk_buff___33 *, const struct tcf_proto___28 *, struct tcf_result___28 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___28 *ops;
	struct tcf_chain___28 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___28 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___28 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___28 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___33 *, const struct tcf_proto___28 *, struct tcf_result___28 *);
	int (*init)(struct tcf_proto___28 *);
	void (*destroy)(struct tcf_proto___28 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___28 *, u32);
	void (*put)(struct tcf_proto___28 *, void *);
	int (*change)(struct net___41 *, struct sk_buff___33 *, struct tcf_proto___28 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___28 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___28 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___28 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___41 *, struct tcf_chain___28 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___41 *, struct tcf_proto___28 *, void *, struct sk_buff___33 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___33 *, struct net___41 *, void *);
	struct module___197 *owner;
	int flags;
};

struct tcf_chain___28 {
	struct mutex filter_chain_lock;
	struct tcf_proto___28 *filter_chain;
	struct list_head list;
	struct tcf_block___28 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___28 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___18 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___28 *prog;
};

struct bpf_redirect_info___28 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___188 *map;
	struct bpf_map___188 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___18;

struct neigh_hash_table___18;

struct neigh_table___18 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___33 *, __u32 *);
	bool (*key_eq)(const struct neighbour___19 *, const void *);
	int (*constructor)(struct neighbour___19 *);
	int (*pconstructor)(struct pneigh_entry___18 *);
	void (*pdestructor)(struct pneigh_entry___18 *);
	void (*proxy_redo)(struct sk_buff___33 *);
	char *id;
	struct neigh_parms___19 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___29 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___18 *nht;
	struct pneigh_entry___18 **phash_buckets;
};

struct neigh_ops___18 {
	int family;
	void (*solicit)(struct neighbour___19 *, struct sk_buff___33 *);
	void (*error_report)(struct neighbour___19 *, struct sk_buff___33 *);
	int (*output)(struct neighbour___19 *, struct sk_buff___33 *);
	int (*connected_output)(struct neighbour___19 *, struct sk_buff___33 *);
};

struct pneigh_entry___18 {
	struct pneigh_entry___18 *next;
	possible_net_t___30 net;
	struct net_device___33 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___18 {
	struct neighbour___19 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___18 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___18 *ctarget;
	struct net___41 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___18 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___18 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___11;

struct timewait_sock_ops___11;

struct proto___18 {
	void (*close)(struct sock___20 *, long int);
	int (*pre_connect)(struct sock___20 *, struct sockaddr *, int);
	int (*connect)(struct sock___20 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___20 *, int);
	struct sock___20 * (*accept)(struct sock___20 *, int, int *, bool);
	int (*ioctl)(struct sock___20 *, int, long unsigned int);
	int (*init)(struct sock___20 *);
	void (*destroy)(struct sock___20 *);
	void (*shutdown)(struct sock___20 *, int);
	int (*setsockopt)(struct sock___20 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___20 *, int, int, char *, int *);
	void (*keepalive)(struct sock___20 *, int);
	int (*sendmsg)(struct sock___20 *, struct msghdr___20 *, size_t);
	int (*recvmsg)(struct sock___20 *, struct msghdr___20 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___20 *, struct page___244 *, int, size_t, int);
	int (*bind)(struct sock___20 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___20 *, struct sk_buff___33 *);
	void (*release_cb)(struct sock___20 *);
	int (*hash)(struct sock___20 *);
	void (*unhash)(struct sock___20 *);
	void (*rehash)(struct sock___20 *);
	int (*get_port)(struct sock___20 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___20 *);
	bool (*stream_memory_read)(const struct sock___20 *);
	void (*enter_memory_pressure)(struct sock___20 *);
	void (*leave_memory_pressure)(struct sock___20 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___11 *rsk_prot;
	struct timewait_sock_ops___11 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___197 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___20 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct request_sock___11;

struct request_sock_ops___11 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___20 *, struct request_sock___11 *);
	void (*send_ack)(const struct sock___20 *, struct sk_buff___33 *, struct request_sock___11 *);
	void (*send_reset)(const struct sock___20 *, struct sk_buff___33 *);
	void (*destructor)(struct request_sock___11 *);
	void (*syn_ack_timeout)(const struct request_sock___11 *);
};

struct timewait_sock_ops___11 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___20 *, struct sock___20 *, void *);
	void (*twsk_destructor)(struct sock___20 *);
};

struct request_sock___11 {
	struct sock_common___18 __req_common;
	struct request_sock___11 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___11 *rsk_ops;
	struct sock___20 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___10 {
	struct in6_addr mca_addr;
	struct inet6_dev___11 *idev;
	struct ifmcaddr6___10 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ip6_ra_chain___10 {
	struct ip6_ra_chain___10 *next;
	struct sock___20 *sk;
	int sel;
	void (*destructor)(struct sock___20 *);
};

struct netif_security_struct {
	struct net___41 *ns;
	int ifindex;
	u32 sid;
};

struct sel_netif {
	struct list_head list;
	struct netif_security_struct nsec;
	struct callback_head callback_head;
};

struct module___198;

struct file___244;

struct kiocb___244;

struct iov_iter___111;

struct poll_table_struct___152;

struct vm_area_struct___245;

struct inode___244;

struct file_lock___244;

struct page___245;

struct pipe_inode_info___54;

struct seq_file___220;

struct file_operations___244 {
	struct module___198 *owner;
	loff_t (*llseek)(struct file___244 *, loff_t, int);
	ssize_t (*read)(struct file___244 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___244 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___244 *, struct iov_iter___111 *);
	ssize_t (*write_iter)(struct kiocb___244 *, struct iov_iter___111 *);
	int (*iopoll)(struct kiocb___244 *, bool);
	int (*iterate)(struct file___244 *, struct dir_context *);
	int (*iterate_shared)(struct file___244 *, struct dir_context *);
	__poll_t (*poll)(struct file___244 *, struct poll_table_struct___152 *);
	long int (*unlocked_ioctl)(struct file___244 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___244 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___244 *, struct vm_area_struct___245 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___244 *, struct file___244 *);
	int (*flush)(struct file___244 *, fl_owner_t);
	int (*release)(struct inode___244 *, struct file___244 *);
	int (*fsync)(struct file___244 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___244 *, int);
	int (*lock)(struct file___244 *, int, struct file_lock___244 *);
	ssize_t (*sendpage)(struct file___244 *, struct page___245 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___244 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___244 *, int, struct file_lock___244 *);
	ssize_t (*splice_write)(struct pipe_inode_info___54 *, struct file___244 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___244 *, loff_t *, struct pipe_inode_info___54 *, size_t, unsigned int);
	int (*setlease)(struct file___244 *, long int, struct file_lock___244 **, void **);
	long int (*fallocate)(struct file___244 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___220 *, struct file___244 *);
	ssize_t (*copy_file_range)(struct file___244 *, loff_t, struct file___244 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___244 *, loff_t, struct file___244 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___244 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___244 {
	u64 seqnum;
	struct vm_area_struct___245 *vmas[4];
};

struct page_frag___244 {
	struct page___245 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___244;

struct mem_cgroup___105;

struct pid___184;

struct cred___237;

struct nsproxy___224;

struct signal_struct___202;

struct bio_list___120;

struct backing_dev_info___120;

struct css_set___189;

struct vm_struct___161;

struct task_struct___245 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___245 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___244 *mm;
	struct mm_struct___244 *active_mm;
	struct vmacache___244 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___245 *real_parent;
	struct task_struct___245 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___245 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___105 *active_memcg;
	long int rh_reserved2;
	struct pid___184 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___184 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___184 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___237 *ptracer_cred;
	const struct cred___237 *real_cred;
	const struct cred___237 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___224 *nsproxy;
	struct signal_struct___202 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___245 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___120 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___120 *backing_dev_info;
	struct io_context___60 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___189 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___54 *splice_pipe;
	struct page_frag___244 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___105 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___245 *oom_reaper_list;
	struct vm_struct___161 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___127 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___245 *pgtable_t___244;

struct address_space___243;

struct dev_pagemap___234;

struct page___245 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___243 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___245 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___244 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___244 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___234 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___105 *mem_cgroup;
};

struct pglist_data___244;

struct lruvec___244 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___244 *pgdat;
};

struct zone___244 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___244 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___244 {
	struct zone___244 *zone;
	int zone_idx;
};

struct zonelist___244 {
	struct zoneref___244 _zonerefs[25];
};

struct pglist_data___244 {
	struct zone___244 node_zones[3];
	struct zonelist___244 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___245 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___245 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___244 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___245 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___245 *owner;
};

struct secondary_data___245 {
	void *stack;
	struct task_struct___245 *task;
	long int status;
};

struct blocking_notifier_head___244 {
	struct rw_semaphore___245 rwsem;
	struct notifier_block *head;
};

struct cgroup___189;

struct cgroup_subsys___189;

struct cgroup_subsys_state___190 {
	struct cgroup___189 *cgroup;
	struct cgroup_subsys___189 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___190 *parent;
};

struct kernfs_node___238;

struct cgroup_file___189 {
	struct kernfs_node___238 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___105;

struct mem_cgroup___105 {
	struct cgroup_subsys_state___190 css;
	struct mem_cgroup_id___16 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___189 events_file;
	struct cgroup_file___189 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___245 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___105 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___184;

struct upid___184 {
	int nr;
	struct pid_namespace___184 *ns;
};

struct dentry___244;

struct user_namespace___204;

struct ucounts___204;

struct pid_namespace___184 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___245 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___184 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___244 *proc_self;
	struct dentry___244 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___204 *user_ns;
	struct ucounts___204 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___28 ns;
};

struct pid___184 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___184 numbers[1];
};

struct key___237;

struct user_namespace___204 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___204 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___28 ns;
	long unsigned int flags;
	struct key___237 *persistent_keyring_register;
	struct rw_semaphore___245 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___204 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct user_struct___237 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___237 *uid_keyring;
	struct key___237 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___234;

struct vm_area_struct___245 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___245 *vm_next;
	struct vm_area_struct___245 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___244 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___234 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___244 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct linux_binfmt___41;

struct core_state___244;

struct mm_struct___244 {
	struct {
		struct vm_area_struct___245 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___244 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___245 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___41 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___244 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___245 *owner;
		struct user_namespace___204 *user_ns;
		struct file___244 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___244 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___237 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___237 *session_keyring;
	struct key___237 *process_keyring;
	struct key___237 *thread_keyring;
	struct key___237 *request_key_auth;
	void *security;
	struct user_struct___237 *user;
	struct user_namespace___204 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___42;

struct cgroup_namespace___189;

struct nsproxy___224 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___184 *pid_ns_for_children;
	struct net___42 *net_ns;
	struct cgroup_namespace___189 *cgroup_ns;
};

struct signal_struct___202 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___245 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___245 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___184 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___184 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___244 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___184 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___120;

struct bio_list___120 {
	struct bio___120 *head;
	struct bio___120 *tail;
};

struct bdi_writeback_congested___120;

struct bdi_writeback___120 {
	struct backing_dev_info___120 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___120 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___190 *memcg_css;
	struct cgroup_subsys_state___190 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___208;

struct backing_dev_info___120 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___120 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___208 *dev;
	struct device___208 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___244 *debug_dir;
	struct dentry___244 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___189 {
	struct cgroup_subsys_state___190 *subsys[13];
	refcount_t refcount;
	struct css_set___189 *dom_cset;
	struct cgroup___189 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___189 *mg_src_cgrp;
	struct cgroup___189 *mg_dst_cgrp;
	struct css_set___189 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___243;

struct pipe_buffer___54;

struct pipe_inode_info___54 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___245 *tmp_page;
	struct fasync_struct___243 *fasync_readers;
	struct fasync_struct___243 *fasync_writers;
	struct pipe_buffer___54 *bufs;
	struct user_struct___237 *user;
};

struct vm_struct___161 {
	struct vm_struct___161 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___245 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___214 {
	struct task_struct___245 task;
	long unsigned int stack[8192];
};

struct address_space_operations___243;

struct address_space___243 {
	struct inode___244 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___245 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___243 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___234)(struct vm_area_struct___245 *, long unsigned int, const struct page___245 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___234)(struct page___245 *, void *);

struct dev_pagemap___234 {
	dev_page_fault_t___234 page_fault;
	dev_page_free_t___234 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___208 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___243 {
	struct vfsmount *mnt;
	struct dentry___244 *dentry;
};

struct fown_struct___184 {
	rwlock_t lock;
	struct pid___184 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___244 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___243 f_path;
	struct inode___244 *f_inode;
	const struct file_operations___244 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___184 f_owner;
	const struct cred___237 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___243 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___234;

struct vm_operations_struct___234 {
	void (*open)(struct vm_area_struct___245 *);
	void (*close)(struct vm_area_struct___245 *);
	int (*split)(struct vm_area_struct___245 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___245 *);
	vm_fault_t (*fault)(struct vm_fault___234 *);
	vm_fault_t (*huge_fault)(struct vm_fault___234 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___234 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___245 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___234 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___234 *);
	int (*access)(struct vm_area_struct___245 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___245 *);
	int (*set_policy)(struct vm_area_struct___245 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___245 *, long unsigned int);
	struct page___245 * (*find_special_page)(struct vm_area_struct___245 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___244 {
	struct task_struct___245 *task;
	struct core_thread___244 *next;
};

struct core_state___244 {
	atomic_t nr_threads;
	struct core_thread___244 dumper;
	struct completion startup;
};

struct linux_binprm___42;

struct coredump_params___41;

struct linux_binfmt___41 {
	struct list_head lh;
	struct module___198 *module;
	int (*load_binary)(struct linux_binprm___42 *);
	int (*load_shlib)(struct file___244 *);
	int (*core_dump)(struct coredump_params___41 *);
	long unsigned int min_coredump;
};

struct vm_fault___234 {
	struct vm_area_struct___245 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___245 *cow_page;
	struct mem_cgroup___105 *memcg;
	struct page___245 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___244 prealloc_pte;
};

struct kset___231;

struct kobj_type___231;

struct kobject___232 {
	const char *name;
	struct list_head entry;
	struct kobject___232 *parent;
	struct kset___231 *kset;
	struct kobj_type___231 *ktype;
	struct kernfs_node___238 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___195 {
	struct kobject___232 kobj;
	struct module___198 *mod;
	struct kobject___232 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___195 {
	struct module___198 *mod;
	struct latch_tree_node node;
};

struct module_layout___195 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___195 mtn;
};

struct module_attribute___195;

struct kernel_param___195;

struct module___198 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___195 mkobj;
	struct module_attribute___195 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___232 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___195 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___195 core_layout;
	struct module_layout___195 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide53;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide54;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bio_vec___120 {
	struct page___245 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___111 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___120 *bvec;
		struct pipe_inode_info___54 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct msghdr___21 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___111 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___244 *msg_iocb;
};

struct kiocb___244 {
	struct file___244 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___244 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dentry_operations___243;

struct super_block___243;

struct dentry___244 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___244 *d_parent;
	struct qstr d_name;
	struct inode___244 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___243 *d_op;
	struct super_block___243 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___243;

struct block_device___244;

struct inode___244 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___243 *i_op;
	struct super_block___243 *i_sb;
	struct address_space___243 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___245 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___120 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___244 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___243 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___54 *i_pipe;
		struct block_device___244 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___243 {
	int (*d_revalidate)(struct dentry___244 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___244 *, unsigned int);
	int (*d_hash)(const struct dentry___244 *, struct qstr *);
	int (*d_compare)(const struct dentry___244 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___244 *);
	int (*d_init)(struct dentry___244 *);
	void (*d_release)(struct dentry___244 *);
	void (*d_prune)(struct dentry___244 *);
	void (*d_iput)(struct dentry___244 *, struct inode___244 *);
	char * (*d_dname)(struct dentry___244 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___243 *);
	int (*d_manage)(const struct path___243 *, bool);
	struct dentry___244 * (*d_real)(struct dentry___244 *, const struct inode___244 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___243;

struct mem_dqinfo___243 {
	struct quota_format_type___243 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___243;

struct quota_info___243 {
	unsigned int flags;
	struct rw_semaphore___245 dqio_sem;
	struct inode___244 *files[3];
	struct mem_dqinfo___243 info[3];
	const struct quota_format_ops___243 *ops[3];
};

struct rcuwait___243 {
	struct task_struct___245 *task;
};

struct percpu_rw_semaphore___243 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___245 rw_sem;
	struct rcuwait___243 writer;
	int readers_block;
};

struct sb_writers___243 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___243 rw_sem[3];
};

struct shrink_control___105;

struct shrinker___105 {
	long unsigned int (*count_objects)(struct shrinker___105 *, struct shrink_control___105 *);
	long unsigned int (*scan_objects)(struct shrinker___105 *, struct shrink_control___105 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___243;

struct super_operations___243;

struct dquot_operations___243;

struct quotactl_ops___243;

struct super_block___243 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___243 *s_type;
	const struct super_operations___243 *s_op;
	const struct dquot_operations___243 *dq_op;
	const struct quotactl_ops___243 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___244 *s_root;
	struct rw_semaphore___245 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___244 *s_bdev;
	struct backing_dev_info___120 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___243 s_dquot;
	struct sb_writers___243 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___243 *s_d_op;
	int cleancache_poolid;
	struct shrinker___105 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___204 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___105 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___105 *memcg;
};

struct iattr___243 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___244 *ia_file;
};

struct dquot___243 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___243 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___243 {
	int qf_fmt_id;
	const struct quota_format_ops___243 *qf_ops;
	struct module___198 *qf_owner;
	struct quota_format_type___243 *qf_next;
};

struct quota_format_ops___243 {
	int (*check_quota_file)(struct super_block___243 *, int);
	int (*read_file_info)(struct super_block___243 *, int);
	int (*write_file_info)(struct super_block___243 *, int);
	int (*free_file_info)(struct super_block___243 *, int);
	int (*read_dqblk)(struct dquot___243 *);
	int (*commit_dqblk)(struct dquot___243 *);
	int (*release_dqblk)(struct dquot___243 *);
	int (*get_next_id)(struct super_block___243 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___243 {
	int (*write_dquot)(struct dquot___243 *);
	struct dquot___243 * (*alloc_dquot)(struct super_block___243 *, int);
	void (*destroy_dquot)(struct dquot___243 *);
	int (*acquire_dquot)(struct dquot___243 *);
	int (*release_dquot)(struct dquot___243 *);
	int (*mark_dirty)(struct dquot___243 *);
	int (*write_info)(struct super_block___243 *, int);
	qsize_t * (*get_reserved_space)(struct inode___244 *);
	int (*get_projid)(struct inode___244 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___244 *, qsize_t *);
	int (*get_next_id)(struct super_block___243 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___243 {
	int (*quota_on)(struct super_block___243 *, int, int, const struct path___243 *);
	int (*quota_off)(struct super_block___243 *, int);
	int (*quota_enable)(struct super_block___243 *, unsigned int);
	int (*quota_disable)(struct super_block___243 *, unsigned int);
	int (*quota_sync)(struct super_block___243 *, int);
	int (*set_info)(struct super_block___243 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___243 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___243 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___243 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___243 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___243 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___116;

struct address_space_operations___243 {
	int (*writepage)(struct page___245 *, struct writeback_control___116 *);
	int (*readpage)(struct file___244 *, struct page___245 *);
	int (*writepages)(struct address_space___243 *, struct writeback_control___116 *);
	int (*set_page_dirty)(struct page___245 *);
	int (*readpages)(struct file___244 *, struct address_space___243 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___244 *, struct address_space___243 *, loff_t, unsigned int, unsigned int, struct page___245 **, void **);
	int (*write_end)(struct file___244 *, struct address_space___243 *, loff_t, unsigned int, unsigned int, struct page___245 *, void *);
	sector_t (*bmap)(struct address_space___243 *, sector_t);
	void (*invalidatepage)(struct page___245 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___245 *, gfp_t);
	void (*freepage)(struct page___245 *);
	ssize_t (*direct_IO)(struct kiocb___244 *, struct iov_iter___111 *);
	int (*migratepage)(struct address_space___243 *, struct page___245 *, struct page___245 *, enum migrate_mode);
	bool (*isolate_page)(struct page___245 *, isolate_mode_t);
	void (*putback_page)(struct page___245 *);
	int (*launder_page)(struct page___245 *);
	int (*is_partially_uptodate)(struct page___245 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___245 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___243 *, struct page___245 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___244 *, sector_t *);
	void (*swap_deactivate)(struct file___244 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___116 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___120 *wb;
	struct inode___244 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___244 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___244 *bd_inode;
	struct super_block___243 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___244 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___120 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___243 {
	struct dentry___244 * (*lookup)(struct inode___244 *, struct dentry___244 *, unsigned int);
	const char * (*get_link)(struct dentry___244 *, struct inode___244 *, struct delayed_call *);
	int (*permission)(struct inode___244 *, int);
	struct posix_acl * (*get_acl)(struct inode___244 *, int);
	int (*readlink)(struct dentry___244 *, char *, int);
	int (*create)(struct inode___244 *, struct dentry___244 *, umode_t, bool);
	int (*link)(struct dentry___244 *, struct inode___244 *, struct dentry___244 *);
	int (*unlink)(struct inode___244 *, struct dentry___244 *);
	int (*symlink)(struct inode___244 *, struct dentry___244 *, const char *);
	int (*mkdir)(struct inode___244 *, struct dentry___244 *, umode_t);
	int (*rmdir)(struct inode___244 *, struct dentry___244 *);
	int (*mknod)(struct inode___244 *, struct dentry___244 *, umode_t, dev_t);
	int (*rename)(struct inode___244 *, struct dentry___244 *, struct inode___244 *, struct dentry___244 *, unsigned int);
	int (*setattr)(struct dentry___244 *, struct iattr___243 *);
	int (*getattr)(const struct path___243 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___244 *, char *, size_t);
	int (*fiemap)(struct inode___244 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___244 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___244 *, struct dentry___244 *, struct file___244 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___244 *, struct dentry___244 *, umode_t);
	int (*set_acl)(struct inode___244 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___243 {
	void (*fl_copy_lock)(struct file_lock___244 *, struct file_lock___244 *);
	void (*fl_release_private)(struct file_lock___244 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___243;

struct file_lock___244 {
	struct file_lock___244 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___244 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___243 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___243 *fl_ops;
	const struct lock_manager_operations___243 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___243 {
	int (*lm_compare_owner)(struct file_lock___244 *, struct file_lock___244 *);
	long unsigned int (*lm_owner_key)(struct file_lock___244 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___244 *);
	int (*lm_grant)(struct file_lock___244 *, int);
	bool (*lm_break)(struct file_lock___244 *);
	int (*lm_change)(struct file_lock___244 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___244 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___243 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___243 *fa_next;
	struct file___244 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___243 {
	const char *name;
	int fs_flags;
	struct dentry___244 * (*mount)(struct file_system_type___243 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___243 *);
	struct module___198 *owner;
	struct file_system_type___243 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___243 {
	struct inode___244 * (*alloc_inode)(struct super_block___243 *);
	void (*destroy_inode)(struct inode___244 *);
	void (*dirty_inode)(struct inode___244 *, int);
	int (*write_inode)(struct inode___244 *, struct writeback_control___116 *);
	int (*drop_inode)(struct inode___244 *);
	void (*evict_inode)(struct inode___244 *);
	void (*put_super)(struct super_block___243 *);
	int (*sync_fs)(struct super_block___243 *, int);
	int (*freeze_super)(struct super_block___243 *);
	int (*freeze_fs)(struct super_block___243 *);
	int (*thaw_super)(struct super_block___243 *);
	int (*unfreeze_fs)(struct super_block___243 *);
	int (*statfs)(struct dentry___244 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___243 *, int *, char *);
	void (*umount_begin)(struct super_block___243 *);
	int (*show_options)(struct seq_file___220 *, struct dentry___244 *);
	int (*show_devname)(struct seq_file___220 *, struct dentry___244 *);
	int (*show_path)(struct seq_file___220 *, struct dentry___244 *);
	int (*show_stats)(struct seq_file___220 *, struct dentry___244 *);
	ssize_t (*quota_read)(struct super_block___243 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___243 *, int, const char *, size_t, loff_t);
	struct dquot___243 ** (*get_dquots)(struct inode___244 *);
	int (*bdev_try_to_free_page)(struct super_block___243 *, struct page___245 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___243 *, struct shrink_control___105 *);
	long int (*free_cached_objects)(struct super_block___243 *, struct shrink_control___105 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___154)(struct file___244 *, wait_queue_head_t *, struct poll_table_struct___152 *);

struct poll_table_struct___152 {
	poll_queue_proc___154 _qproc;
	__poll_t _key;
};

struct seq_operations___218;

struct seq_file___220 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___218 *op;
	int poll_event;
	const struct file___244 *file;
	void *private;
};

typedef void bio_end_io_t___120(struct bio___120 *);

struct bio_integrity_payload___120;

struct bio_set___120;

struct bio___120 {
	struct bio___120 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___120 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___120 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___120 *bi_io_vec;
	struct bio_set___120 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___120 bi_inline_vecs[0];
};

struct socket_wq___20 {
	wait_queue_head_t wait;
	struct fasync_struct___243 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct sock___21;

struct proto_ops___20;

struct socket___21 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___20 *wq;
	struct file___244 *file;
	struct sock___21 *sk;
	const struct proto_ops___20 *ops;
};

typedef struct {
	struct net___42 *net;
} possible_net_t___31;

struct proto___19;

struct sock_common___19 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___19 *skc_prot;
	possible_net_t___31 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___21 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___34;

struct sk_buff_head___30 {
	struct sk_buff___34 *next;
	struct sk_buff___34 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___19;

struct dst_entry___20;

struct net_device___34;

struct sock___21 {
	struct sock_common___19 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___30 sk_error_queue;
	struct sk_buff_head___30 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___34 *head;
		struct sk_buff___34 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___19 *sk_filter;
	union {
		struct socket_wq___20 *sk_wq;
		struct socket_wq___20 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___20 *sk_rx_dst;
	struct dst_entry___20 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___34 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___30 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___244 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___19 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___184 *sk_peer_pid;
	const struct cred___237 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___21 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___105 *sk_memcg;
	void (*sk_state_change)(struct sock___21 *);
	void (*sk_data_ready)(struct sock___21 *);
	void (*sk_write_space)(struct sock___21 *);
	void (*sk_error_report)(struct sock___21 *);
	int (*sk_backlog_rcv)(struct sock___21 *, struct sk_buff___34 *);
	struct sk_buff___34 * (*sk_validate_xmit_skb)(struct sock___21 *, struct net_device___34 *, struct sk_buff___34 *);
	void (*sk_destruct)(struct sock___21 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

typedef int (*sk_read_actor_t___19)(read_descriptor_t *, struct sk_buff___34 *, unsigned int, size_t);

struct proto_ops___20 {
	int family;
	struct module___198 *owner;
	int (*release)(struct socket___21 *);
	int (*bind)(struct socket___21 *, struct sockaddr *, int);
	int (*connect)(struct socket___21 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___21 *, struct socket___21 *);
	int (*accept)(struct socket___21 *, struct socket___21 *, int, bool);
	int (*getname)(struct socket___21 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___244 *, struct socket___21 *, struct poll_table_struct___152 *);
	int (*ioctl)(struct socket___21 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___21 *, int);
	int (*shutdown)(struct socket___21 *, int);
	int (*setsockopt)(struct socket___21 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___21 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___21 *, struct msghdr___21 *, size_t);
	int (*recvmsg)(struct socket___21 *, struct msghdr___21 *, size_t, int);
	int (*mmap)(struct file___244 *, struct socket___21 *, struct vm_area_struct___245 *);
	ssize_t (*sendpage)(struct socket___21 *, struct page___245 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___21 *, loff_t *, struct pipe_inode_info___54 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___21 *, int);
	int (*peek_len)(struct socket___21 *);
	int (*read_sock)(struct sock___21 *, read_descriptor_t *, sk_read_actor_t___19);
	int (*sendpage_locked)(struct sock___21 *, struct page___245 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___21 *, struct msghdr___21 *, size_t);
	int (*set_rcvlowat)(struct sock___21 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct nf_bridge_info___30;

struct sk_buff___34 {
	union {
		struct {
			struct sk_buff___34 *next;
			struct sk_buff___34 *prev;
			union {
				struct net_device___34 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___21 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___34 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___30 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___30;

struct netns_frags___30 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___30 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ip_ra_chain___8;

struct fib_rules_ops___19;

struct fib_notifier_ops___19;

struct netns_ipv4___30 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___8 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___19 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___21 *fibnl;
	struct sock___21 **icmp_sk;
	struct sock___21 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___21 **tcp_sk;
	struct netns_frags___30 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___19 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___19 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___19 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___20;

struct dst_ops___40 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___40 *);
	struct dst_entry___20 * (*check)(struct dst_entry___20 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___20 *);
	unsigned int (*mtu)(const struct dst_entry___20 *);
	u32 * (*cow_metrics)(struct dst_entry___20 *, long unsigned int);
	void (*destroy)(struct dst_entry___20 *);
	void (*ifdown)(struct dst_entry___20 *, struct net_device___34 *, int);
	struct dst_entry___20 * (*negative_advice)(struct dst_entry___20 *);
	void (*link_failure)(struct sk_buff___34 *);
	void (*update_pmtu)(struct dst_entry___20 *, struct sock___21 *, struct sk_buff___34 *, u32);
	void (*redirect)(struct dst_entry___20 *, struct sock___21 *, struct sk_buff___34 *);
	int (*local_out)(struct net___42 *, struct sock___21 *, struct sk_buff___34 *);
	struct neighbour___20 * (*neigh_lookup)(const struct dst_entry___20 *, struct sk_buff___34 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___20 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___40 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___30 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___40 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___19 *fib6_rules_ops;
	struct sock___21 **icmp_sk;
	struct sock___21 *ndisc_sk;
	struct sock___21 *tcp_sk;
	struct sock___21 *igmp_sk;
	struct sock___21 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___19 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___19 *notifier_ops;
	struct fib_notifier_ops___19 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___20 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___21 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___30 {
	struct netns_frags___30 frags;
};

struct netns_xfrm___40 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___21 *nlsk;
	struct sock___21 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___40 xfrm4_dst_ops;
	struct dst_ops___40 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___29;

struct net___42 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___204 *user_ns;
	struct ucounts___204 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___28 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___21 *rtnl;
	struct sock___21 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___34 *loopback_dev;
	struct netns_core core;
	struct netns_mib___2 mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___30 ipv4;
	struct netns_ipv6___40 ipv6;
	struct netns_sctp___20 sctp;
	struct netns_nf___2 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___30 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___21 *nfnl;
	struct sock___21 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___40 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can___2 can;
	struct sock___21 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___29 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kernfs_root___238;

struct kernfs_elem_dir___238 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___238 *root;
};

struct kernfs_syscall_ops___238;

struct kernfs_root___238 {
	struct kernfs_node___238 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___238 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___238 {
	struct kernfs_node___238 *target_kn;
};

struct kernfs_ops___238;

struct kernfs_elem_attr___238 {
	const struct kernfs_ops___238 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___238 *notify_next;
};

struct kernfs_node___238 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___238 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___238 dir;
		struct kernfs_elem_symlink___238 symlink;
		struct kernfs_elem_attr___238 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___238;

struct kernfs_ops___238 {
	int (*open)(struct kernfs_open_file___238 *);
	void (*release)(struct kernfs_open_file___238 *);
	int (*seq_show)(struct seq_file___220 *, void *);
	void * (*seq_start)(struct seq_file___220 *, loff_t *);
	void * (*seq_next)(struct seq_file___220 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___220 *, void *);
	ssize_t (*read)(struct kernfs_open_file___238 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___238 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___238 *, struct vm_area_struct___245 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___238 *, struct poll_table_struct___152 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___238 {
	int (*remount_fs)(struct kernfs_root___238 *, int *, char *);
	int (*show_options)(struct seq_file___220 *, struct kernfs_root___238 *);
	int (*mkdir)(struct kernfs_node___238 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___238 *);
	int (*rename)(struct kernfs_node___238 *, struct kernfs_node___238 *, const char *);
	int (*show_path)(struct seq_file___220 *, struct kernfs_node___238 *, struct kernfs_root___238 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___238 {
	struct kernfs_node___238 *kn;
	struct file___244 *file;
	struct seq_file___220 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___234 *vm_ops;
};

struct kobj_ns_type_operations___19 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___21 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___209;

struct attribute_group___210 {
	const char *name;
	umode_t (*is_visible)(struct kobject___232 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___232 *, struct bin_attribute___209 *, int);
	struct attribute **attrs;
	struct bin_attribute___209 **bin_attrs;
};

struct bin_attribute___209 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___244 *, struct kobject___232 *, struct bin_attribute___209 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___244 *, struct kobject___232 *, struct bin_attribute___209 *, char *, loff_t, size_t);
	int (*mmap)(struct file___244 *, struct kobject___232 *, struct bin_attribute___209 *, struct vm_area_struct___245 *);
};

struct sysfs_ops___231 {
	ssize_t (*show)(struct kobject___232 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___232 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___231;

struct kset___231 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___232 kobj;
	const struct kset_uevent_ops___231 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___231 {
	void (*release)(struct kobject___232 *);
	const struct sysfs_ops___231 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___19 * (*child_ns_type)(struct kobject___232 *);
	const void * (*namespace)(struct kobject___232 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___231 {
	int (* const filter)(struct kset___231 *, struct kobject___232 *);
	const char * (* const name)(struct kset___231 *, struct kobject___232 *);
	int (* const uevent)(struct kset___231 *, struct kobject___232 *, struct kobj_uevent_env *);
};

struct kobj_attribute___225 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___232 *, struct kobj_attribute___225 *, char *);
	ssize_t (*store)(struct kobject___232 *, struct kobj_attribute___225 *, const char *, size_t);
};

struct dev_pm_ops___208 {
	int (*prepare)(struct device___208 *);
	void (*complete)(struct device___208 *);
	int (*suspend)(struct device___208 *);
	int (*resume)(struct device___208 *);
	int (*freeze)(struct device___208 *);
	int (*thaw)(struct device___208 *);
	int (*poweroff)(struct device___208 *);
	int (*restore)(struct device___208 *);
	int (*suspend_late)(struct device___208 *);
	int (*resume_early)(struct device___208 *);
	int (*freeze_late)(struct device___208 *);
	int (*thaw_early)(struct device___208 *);
	int (*poweroff_late)(struct device___208 *);
	int (*restore_early)(struct device___208 *);
	int (*suspend_noirq)(struct device___208 *);
	int (*resume_noirq)(struct device___208 *);
	int (*freeze_noirq)(struct device___208 *);
	int (*thaw_noirq)(struct device___208 *);
	int (*poweroff_noirq)(struct device___208 *);
	int (*restore_noirq)(struct device___208 *);
	int (*runtime_suspend)(struct device___208 *);
	int (*runtime_resume)(struct device___208 *);
	int (*runtime_idle)(struct device___208 *);
};

struct dev_pm_info___208 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___208 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___208;

struct bus_type___208;

struct device_driver___208;

struct dev_pm_domain___208;

struct dma_map_ops___51;

struct fwnode_handle___143;

struct class___208;

struct device___208 {
	struct device___208 *parent;
	struct device_private *p;
	struct kobject___232 kobj;
	const char *init_name;
	const struct device_type___208 *type;
	struct mutex mutex;
	struct bus_type___208 *bus;
	struct device_driver___208 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___208 power;
	struct dev_pm_domain___208 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___51 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___143 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___208 *class;
	const struct attribute_group___210 **groups;
	void (*release)(struct device___208 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___208 {
	struct dev_pm_ops___208 ops;
	void (*detach)(struct device___208 *, bool);
	int (*activate)(struct device___208 *);
	void (*sync)(struct device___208 *);
	void (*dismiss)(struct device___208 *);
};

struct bus_type___208 {
	const char *name;
	const char *dev_name;
	struct device___208 *dev_root;
	const struct attribute_group___210 **bus_groups;
	const struct attribute_group___210 **dev_groups;
	const struct attribute_group___210 **drv_groups;
	int (*match)(struct device___208 *, struct device_driver___208 *);
	int (*uevent)(struct device___208 *, struct kobj_uevent_env *);
	int (*probe)(struct device___208 *);
	int (*remove)(struct device___208 *);
	void (*shutdown)(struct device___208 *);
	int (*online)(struct device___208 *);
	int (*offline)(struct device___208 *);
	int (*suspend)(struct device___208 *, pm_message_t);
	int (*resume)(struct device___208 *);
	int (*num_vf)(struct device___208 *);
	int (*dma_configure)(struct device___208 *);
	const struct dev_pm_ops___208 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___208 {
	const char *name;
	struct bus_type___208 *bus;
	struct module___198 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___208 *);
	int (*remove)(struct device___208 *);
	void (*shutdown)(struct device___208 *);
	int (*suspend)(struct device___208 *, pm_message_t);
	int (*resume)(struct device___208 *);
	const struct attribute_group___210 **groups;
	const struct dev_pm_ops___208 *pm;
	void (*coredump)(struct device___208 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___208 {
	const char *name;
	const struct attribute_group___210 **groups;
	int (*uevent)(struct device___208 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___208 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___208 *);
	const struct dev_pm_ops___208 *pm;
};

struct class___208 {
	const char *name;
	struct module___198 *owner;
	const struct attribute_group___210 **class_groups;
	const struct attribute_group___210 **dev_groups;
	struct kobject___232 *dev_kobj;
	int (*dev_uevent)(struct device___208 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___208 *, umode_t *);
	void (*class_release)(struct class___208 *);
	void (*dev_release)(struct device___208 *);
	int (*shutdown_pre)(struct device___208 *);
	const struct kobj_ns_type_operations___19 *ns_type;
	const void * (*namespace)(struct device___208 *);
	const struct dev_pm_ops___208 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___51 {
	void * (*alloc)(struct device___208 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___208 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___208 *, struct vm_area_struct___245 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___208 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___208 *, struct page___245 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___208 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___208 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___208 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___208 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___208 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___208 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___208 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___208 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___208 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___208 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___208 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___208 *, u64);
	u64 (*get_required_mask)(struct device___208 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___143;

struct fwnode_handle___143 {
	struct fwnode_handle___143 *secondary;
	const struct fwnode_operations___143 *ops;
};

typedef void compound_page_dtor___234(struct page___245 *);

struct fwnode_reference_args___143;

struct fwnode_endpoint___143;

struct fwnode_operations___143 {
	struct fwnode_handle___143 * (*get)(struct fwnode_handle___143 *);
	void (*put)(struct fwnode_handle___143 *);
	bool (*device_is_available)(const struct fwnode_handle___143 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___143 *, const struct device___208 *);
	bool (*property_present)(const struct fwnode_handle___143 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___143 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___143 *, const char *, const char **, size_t);
	struct fwnode_handle___143 * (*get_parent)(const struct fwnode_handle___143 *);
	struct fwnode_handle___143 * (*get_next_child_node)(const struct fwnode_handle___143 *, struct fwnode_handle___143 *);
	struct fwnode_handle___143 * (*get_named_child_node)(const struct fwnode_handle___143 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___143 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___143 *);
	struct fwnode_handle___143 * (*graph_get_next_endpoint)(const struct fwnode_handle___143 *, struct fwnode_handle___143 *);
	struct fwnode_handle___143 * (*graph_get_remote_endpoint)(const struct fwnode_handle___143 *);
	struct fwnode_handle___143 * (*graph_get_port_parent)(struct fwnode_handle___143 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___143 *, struct fwnode_endpoint___143 *);
};

struct fwnode_endpoint___143 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___143 *local_fwnode;
};

struct fwnode_reference_args___143 {
	struct fwnode_handle___143 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___54;

struct pipe_buffer___54 {
	struct page___245 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___54 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___54 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___54 *, struct pipe_buffer___54 *);
	void (*release)(struct pipe_inode_info___54 *, struct pipe_buffer___54 *);
	int (*steal)(struct pipe_inode_info___54 *, struct pipe_buffer___54 *);
	union {
		bool (*get)(struct pipe_inode_info___54 *, struct pipe_buffer___54 *);
		struct {
			void (*get)(struct pipe_inode_info___54 *, struct pipe_buffer___54 *);
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
};

struct nf_bridge_info___30 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___30 = 0,
		BRNF_PROTO_8021Q___30 = 1,
		BRNF_PROTO_PPPOE___30 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___34 *physindev;
	struct net_device___34 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___30(struct sk_buff___34 **);

struct net_device_ops___30;

struct ethtool_ops___30;

struct l3mdev_ops___20;

struct ndisc_ops___12;

struct xfrmdev_ops___30;

struct tlsdev_ops___30;

struct header_ops___30;

struct inet6_dev___12;

struct netdev_rx_queue___30;

struct mini_Qdisc___29;

struct netdev_queue___30;

struct Qdisc___29;

struct rtnl_link_ops___29;

struct dcbnl_rtnl_ops___30;

struct net_device___34 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___30 *netdev_ops;
	const struct ethtool_ops___30 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___20 *l3mdev_ops;
	const struct ndisc_ops___12 *ndisc_ops;
	const struct xfrmdev_ops___30 *xfrmdev_ops;
	const struct tlsdev_ops___30 *tlsdev_ops;
	const struct header_ops___30 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___231 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___12 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___30 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___29 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___30 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___29 *miniq_ingress;
	struct netdev_queue___30 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___30 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___29 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___29 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___30 = 0,
		NETREG_REGISTERED___30 = 1,
		NETREG_UNREGISTERING___30 = 2,
		NETREG_UNREGISTERED___30 = 3,
		NETREG_RELEASED___30 = 4,
		NETREG_DUMMY___30 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___30 = 0,
		RTNL_LINK_INITIALIZING___30 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___34 *);
	struct netpoll_info *npinfo;
	possible_net_t___31 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___208 dev;
	const struct attribute_group___210 *sysfs_groups[4];
	const struct attribute_group___210 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___29 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___30 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct ethtool_ops___30 {
	int (*get_settings)(struct net_device___34 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___34 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___34 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___34 *);
	void (*get_regs)(struct net_device___34 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___34 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___34 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___34 *);
	void (*set_msglevel)(struct net_device___34 *, u32);
	int (*nway_reset)(struct net_device___34 *);
	u32 (*get_link)(struct net_device___34 *);
	int (*get_eeprom_len)(struct net_device___34 *);
	int (*get_eeprom)(struct net_device___34 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___34 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___34 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___34 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___34 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___34 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___34 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___34 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___34 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___34 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___34 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___34 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___34 *);
	void (*complete)(struct net_device___34 *);
	u32 (*get_priv_flags)(struct net_device___34 *);
	int (*set_priv_flags)(struct net_device___34 *, u32);
	int (*get_sset_count)(struct net_device___34 *, int);
	int (*get_rxnfc)(struct net_device___34 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___34 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___34 *, struct ethtool_flash *);
	int (*reset)(struct net_device___34 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___34 *);
	u32 (*get_rxfh_indir_size)(struct net_device___34 *);
	int (*get_rxfh)(struct net_device___34 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___34 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___34 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___34 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___34 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___34 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___34 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___34 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___34 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___34 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___34 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___34 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___34 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___34 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___34 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___34 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___34 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___34 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___34 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___34 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___34 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___34 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	int (*get_fecparam)(struct net_device___34 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___34 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___34 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___34 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___34 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___30;

struct inet_frags___30 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___30 *, const void *);
	void (*destructor)(struct inet_frag_queue___30 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___30 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___34 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___34 *fragments_tail;
	struct sk_buff___34 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___30 *net;
	struct callback_head rcu;
};

struct ip_ra_chain___8 {
	struct ip_ra_chain___8 *next;
	struct sock___21 *sk;
	union {
		void (*destructor)(struct sock___21 *);
		struct sock___21 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___19;

struct fib_lookup_arg___19;

struct fib_rules_ops___19 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___19 *, struct flowi *, int, struct fib_lookup_arg___19 *);
	bool (*suppress)(struct fib_rule___19 *, struct fib_lookup_arg___19 *);
	int (*match)(struct fib_rule___19 *, struct flowi *, int);
	int (*configure)(struct fib_rule___19 *, struct sk_buff___34 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___19 *);
	int (*compare)(struct fib_rule___19 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___19 *, struct sk_buff___34 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___19 *);
	void (*flush_cache)(struct fib_rules_ops___19 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___198 *owner;
	struct net___42 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___19 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___42 *);
	int (*fib_dump)(struct net___42 *, struct notifier_block *);
	struct module___198 *owner;
	struct callback_head rcu;
};

struct dst_entry___20 {
	struct net_device___34 *dev;
	struct dst_ops___40 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___34 *);
	int (*output)(struct net___42 *, struct sock___21 *, struct sk_buff___34 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___19;

struct neigh_parms___20;

struct neigh_ops___19;

struct neighbour___20 {
	struct neighbour___20 *next;
	struct neigh_table___19 *tbl;
	struct neigh_parms___20 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___30 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___20 *, struct sk_buff___34 *);
	const struct neigh_ops___19 *ops;
	struct callback_head rcu;
	struct net_device___34 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct ucounts___204 {
	struct hlist_node node;
	struct user_namespace___204 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_prog_aux___31;

struct bpf_prog___29 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___31 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

typedef int (*key_restrict_link_func_t___237)(struct key___237 *, const struct key_type *, const union key_payload *, struct key___237 *);

struct key_restriction___237;

struct key___237 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___245 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key___5 index_key;
		struct {
			struct key_type___5 *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___237 *restrict_link;
};

struct key_restriction___237 {
	key_restrict_link_func_t___237 check;
	struct key___237 *key;
	struct key_type *keytype;
};

struct seq_operations___218 {
	void * (*start)(struct seq_file___220 *, loff_t *);
	void (*stop)(struct seq_file___220 *, void *);
	void * (*next)(struct seq_file___220 *, void *, loff_t *);
	int (*show)(struct seq_file___220 *, void *);
};

struct pernet_operations___31 {
	struct list_head list;
	int (*init)(struct net___42 *);
	void (*exit)(struct net___42 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___30 {
	int (*ieee_getets)(struct net_device___34 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___34 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___34 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___34 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___34 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___34 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___34 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___34 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___34 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___34 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___34 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___34 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___34 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___34 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___34 *);
	u8 (*setstate)(struct net_device___34 *, u8);
	void (*getpermhwaddr)(struct net_device___34 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___34 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___34 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___34 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___34 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___34 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___34 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___34 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___34 *, int, u8 *);
	void (*setpfccfg)(struct net_device___34 *, int, u8);
	void (*getpfccfg)(struct net_device___34 *, int, u8 *);
	u8 (*setall)(struct net_device___34 *);
	u8 (*getcap)(struct net_device___34 *, int, u8 *);
	int (*getnumtcs)(struct net_device___34 *, int, u8 *);
	int (*setnumtcs)(struct net_device___34 *, int, u8);
	u8 (*getpfcstate)(struct net_device___34 *);
	void (*setpfcstate)(struct net_device___34 *, u8);
	void (*getbcncfg)(struct net_device___34 *, int, u32 *);
	void (*setbcncfg)(struct net_device___34 *, int, u32);
	void (*getbcnrp)(struct net_device___34 *, int, u8 *);
	void (*setbcnrp)(struct net_device___34 *, int, u8);
	int (*setapp)(struct net_device___34 *, u8, u16, u8);
	int (*getapp)(struct net_device___34 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___34 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___34 *, int, u8);
	u8 (*getdcbx)(struct net_device___34 *);
	u8 (*setdcbx)(struct net_device___34 *, u8);
	int (*peer_getappinfo)(struct net_device___34 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___34 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___34 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___34 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___34 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___34 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___189 {
	refcount_t count;
	struct ns_common___28 ns;
	struct user_namespace___204 *user_ns;
	struct ucounts___204 *ucounts;
	struct css_set___189 *root_cset;
};

struct bpf_map___189;

struct bpf_map_ops___189 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___189 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___189 *, struct file___244 *);
	void (*map_free)(struct bpf_map___189 *);
	int (*map_get_next_key)(struct bpf_map___189 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___189 *);
	void * (*map_lookup_elem)(struct bpf_map___189 *, void *);
	int (*map_update_elem)(struct bpf_map___189 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___189 *, void *);
	int (*map_push_elem)(struct bpf_map___189 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___189 *, void *);
	int (*map_peek_elem)(struct bpf_map___189 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___189 *, struct file___244 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___189 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___189 *, void *, struct seq_file___220 *);
	int (*map_check_btf)(const struct bpf_map___189 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___189 {
	const struct bpf_map_ops___189 *ops;
	struct bpf_map___189 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___237 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___30;

struct bpf_map_dev_ops___30 {
	int (*map_get_next_key)(struct bpf_offloaded_map___30 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___30 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___30 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___30 *, void *);
};

struct bpf_offloaded_map___30 {
	struct bpf_map___189 map;
	struct net_device___34 *netdev;
	const struct bpf_map_dev_ops___30 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___29 {
	int (*test_run)(struct bpf_prog___29 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___29 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___29 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___29 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___29 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___29 *, u32 *);
};

struct bpf_prog_offload_ops___29 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___29 *);
	int (*translate)(struct bpf_prog___29 *);
	void (*destroy)(struct bpf_prog___29 *);
};

struct bpf_prog_offload___29 {
	struct bpf_prog___29 *prog;
	struct net_device___34 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___29 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___31 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___29 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___29 *ops;
	struct bpf_map___189 **used_maps;
	struct bpf_prog___29 *prog;
	struct user_struct___237 *user;
	u64 load_time;
	struct bpf_map___189 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___29 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___29 {
	struct bpf_prog___29 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___29 {
	struct callback_head rcu;
	struct bpf_prog_array_item___29 items[0];
};

struct cgroup_bpf___29 {
	struct bpf_prog_array___29 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___29 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___189;

typedef void (*kthread_work_func_t___189)(struct kthread_work___189 *);

struct kthread_worker___189;

struct kthread_work___189 {
	struct list_head node;
	kthread_work_func_t___189 func;
	struct kthread_worker___189 *worker;
	int canceling;
};

struct kthread_worker___189 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___245 *task;
	struct kthread_work___189 *current_work;
};

struct kthread_delayed_work___189 {
	struct kthread_work___189 work;
	struct timer_list timer;
};

struct psi_group___189 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___189 *poll_kworker;
	struct kthread_delayed_work___189 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___189;

struct cgroup_rstat_cpu___189;

struct cgroup___189 {
	struct cgroup_subsys_state___190 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___238 *kn;
	struct cgroup_file___189 procs_file;
	struct cgroup_file___189 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___190 *subsys[13];
	struct cgroup_root___189 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___189 *dom_cgrp;
	struct cgroup_rstat_cpu___189 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___29 bpf;
	atomic_t congestion_count;
	struct cgroup___189 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___189 psi;
	int ancestor_ids[0];
};

struct cftype___189;

struct cgroup_subsys___189 {
	struct cgroup_subsys_state___190 * (*css_alloc)(struct cgroup_subsys_state___190 *);
	int (*css_online)(struct cgroup_subsys_state___190 *);
	void (*css_offline)(struct cgroup_subsys_state___190 *);
	void (*css_released)(struct cgroup_subsys_state___190 *);
	void (*css_free)(struct cgroup_subsys_state___190 *);
	void (*css_reset)(struct cgroup_subsys_state___190 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___190 *, int);
	int (*css_extra_stat_show)(struct seq_file___220 *, struct cgroup_subsys_state___190 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___245 *);
	void (*cancel_fork)(struct task_struct___245 *);
	void (*fork)(struct task_struct___245 *);
	void (*exit)(struct task_struct___245 *);
	void (*free)(struct task_struct___245 *);
	void (*bind)(struct cgroup_subsys_state___190 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___189 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___189 *dfl_cftypes;
	struct cftype___189 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___189 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___189 *updated_children;
	struct cgroup___189 *updated_next;
};

struct cgroup_root___189 {
	struct kernfs_root___238 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___189 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___189 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___189 *ss;
	struct list_head node;
	struct kernfs_ops___238 *kf_ops;
	int (*open)(struct kernfs_open_file___238 *);
	void (*release)(struct kernfs_open_file___238 *);
	u64 (*read_u64)(struct cgroup_subsys_state___190 *, struct cftype___189 *);
	s64 (*read_s64)(struct cgroup_subsys_state___190 *, struct cftype___189 *);
	int (*seq_show)(struct seq_file___220 *, void *);
	void * (*seq_start)(struct seq_file___220 *, loff_t *);
	void * (*seq_next)(struct seq_file___220 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___220 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___190 *, struct cftype___189 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___190 *, struct cftype___189 *, s64);
	ssize_t (*write)(struct kernfs_open_file___238 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___238 *, struct poll_table_struct___152 *);
};

struct xdp_rxq_info___30 {
	struct net_device___34 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___30 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___34 *dev_rx;
};

struct netlink_callback___30 {
	struct sk_buff___34 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___30 *);
	int (*dump)(struct sk_buff___34 *, struct netlink_callback___30 *);
	int (*done)(struct netlink_callback___30 *);
	void *data;
	struct module___198 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___30 {
	int (*create)(struct sk_buff___34 *, struct net_device___34 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___34 *, unsigned char *);
	int (*cache)(const struct neighbour___20 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___34 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___30 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___30 *, int);
	int poll_owner;
	struct net_device___34 *dev;
	struct sk_buff___34 *gro_list;
	struct sk_buff___34 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___30 {
	struct net_device___34 *dev;
	struct Qdisc___29 *qdisc;
	struct Qdisc___29 *qdisc_sleeping;
	struct kobject___232 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___34 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___29 {
	struct sk_buff___34 *head;
	struct sk_buff___34 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___29;

struct Qdisc___29 {
	int (*enqueue)(struct sk_buff___34 *, struct Qdisc___29 *, struct sk_buff___34 **);
	struct sk_buff___34 * (*dequeue)(struct Qdisc___29 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___29 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___30 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___30 gso_skb;
	struct qdisc_skb_head___29 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___29 *next_sched;
	struct sk_buff_head___30 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___30 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___232 kobj;
	struct net_device___34 *dev;
	long: 64;
	struct xdp_rxq_info___30 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___30)(struct net_device___34 *, struct sk_buff___34 *, struct net_device___34 *);

struct netdev_bpf___30 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___29 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___29 *prog;
			const struct bpf_prog_offload_ops___29 *ops;
		} verifier;
		struct {
			struct bpf_prog___29 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___30 *offmap;
		};
		struct {
			struct xdp_umem *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___30 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___34 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___30 {
	int (*tls_dev_add)(struct net_device___34 *, struct sock___21 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___34 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___34 *, struct sock___21 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___30 {
	int (*ndo_init)(struct net_device___34 *);
	void (*ndo_uninit)(struct net_device___34 *);
	int (*ndo_open)(struct net_device___34 *);
	int (*ndo_stop)(struct net_device___34 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___34 *, struct net_device___34 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___34 *, struct net_device___34 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___34 *, struct sk_buff___34 *, struct net_device___34 *, select_queue_fallback_t___30);
	void (*ndo_change_rx_flags)(struct net_device___34 *, int);
	void (*ndo_set_rx_mode)(struct net_device___34 *);
	int (*ndo_set_mac_address)(struct net_device___34 *, void *);
	int (*ndo_validate_addr)(struct net_device___34 *);
	int (*ndo_do_ioctl)(struct net_device___34 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___34 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___34 *, int);
	int (*ndo_neigh_setup)(struct net_device___34 *, struct neigh_parms___20 *);
	void (*ndo_tx_timeout)(struct net_device___34 *);
	void (*ndo_get_stats64)(struct net_device___34 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___34 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___34 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___34 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___34 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___34 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___34 *);
	int (*ndo_netpoll_setup)(struct net_device___34 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___34 *);
	int (*ndo_set_vf_mac)(struct net_device___34 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___34 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___34 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___34 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___34 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___34 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___34 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___34 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___34 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___34 *, int, struct sk_buff___34 *);
	int (*ndo_set_vf_guid)(struct net_device___34 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___34 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___34 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___34 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___34 *, const struct sk_buff___34 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___34 *, struct net_device___34 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___34 *, struct net_device___34 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___34 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___34 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___34 *, struct neighbour___20 *);
	void (*ndo_neigh_destroy)(struct net_device___34 *, struct neighbour___20 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___34 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___34 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___34 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___34 *, struct netlink_callback___30 *, struct net_device___34 *, struct net_device___34 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___34 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___34 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___34 *, u32, u32, struct net_device___34 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___34 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___34 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___34 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___34 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___34 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___34 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___34 *, struct net_device___34 *);
	void (*ndo_dfwd_del_station)(struct net_device___34 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___34 *);
	int (*ndo_set_tx_maxrate)(struct net_device___34 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___34 *);
	int (*ndo_change_proto_down)(struct net_device___34 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___34 *, struct sk_buff___34 *);
	void (*ndo_set_rx_headroom)(struct net_device___34 *, int);
	int (*ndo_bpf)(struct net_device___34 *, struct netdev_bpf___30 *);
	int (*ndo_xdp_xmit)(struct net_device___34 *, int, struct xdp_frame___30 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___34 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___34 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___20 {
	possible_net_t___31 net;
	struct net_device___34 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___20 *);
	void (*neigh_cleanup)(struct neighbour___20 *);
	struct neigh_table___19 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___20 {
	u32 (*l3mdev_fib_table)(const struct net_device___34 *);
	struct sk_buff___34 * (*l3mdev_l3_rcv)(struct net_device___34 *, struct sk_buff___34 *, u16);
	struct sk_buff___34 * (*l3mdev_l3_out)(struct net_device___34 *, struct sock___21 *, struct sk_buff___34 *, u16);
	struct dst_entry___20 * (*l3mdev_link_scope_lookup)(const struct net_device___34 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct ndisc_ops___12 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___34 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___34 *, struct neighbour___20 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___34 *, u8, struct neighbour___20 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___34 *, struct sk_buff___34 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___42 *, struct net_device___34 *, const struct prefix_info *, struct inet6_dev___12 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___11;

struct inet6_dev___12 {
	struct net_device___34 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___11 *mc_list;
	struct ifmcaddr6___11 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	u8 rndid[8];
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___20 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
};

struct tcf_proto___29;

struct mini_Qdisc___29 {
	struct tcf_proto___29 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___29 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___34 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___42 *, struct net_device___34 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___34 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___34 *, struct list_head *);
	size_t (*get_size)(const struct net_device___34 *);
	int (*fill_info)(struct sk_buff___34 *, const struct net_device___34 *);
	size_t (*get_xstats_size)(const struct net_device___34 *);
	int (*fill_xstats)(struct sk_buff___34 *, const struct net_device___34 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___34 *, struct net_device___34 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___34 *, const struct net_device___34 *);
	int (*fill_slave_info)(struct sk_buff___34 *, const struct net_device___34 *, const struct net_device___34 *);
	struct net___42 * (*get_link_net)(const struct net_device___34 *);
	size_t (*get_linkxstats_size)(const struct net_device___34 *, int);
	int (*fill_linkxstats)(struct sk_buff___34 *, const struct net_device___34 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___30 {
	struct list_head poll_list;
	struct sk_buff_head___30 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___30 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___29 *output_queue;
	struct Qdisc___29 **output_queue_tailp;
	struct sk_buff___34 *completion_queue;
	struct sk_buff_head___30 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___30 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___30 input_pkt_queue;
	struct napi_struct___30 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bdi_writeback_congested___120 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___120 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___120 {
	struct bio___120 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___120 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___120 bip_inline_vecs[0];
};

struct bio_set___120 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___120 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___105 {
	struct mem_cgroup___105 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___105 {
	struct lruvec___244 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___105 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___105 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct kernel_param_ops___195 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___195 *);
	int (*get)(char *, const struct kernel_param___195 *);
	void (*free)(void *);
};

struct kparam_array___195;

struct kernel_param___195 {
	const char *name;
	struct module___198 *mod;
	const struct kernel_param_ops___195 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___195 *arr;
	};
};

struct kparam_array___195 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___195 *ops;
	void *elem;
};

struct module_attribute___195 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___195 *, struct module_kobject___195 *, char *);
	ssize_t (*store)(struct module_attribute___195 *, struct module_kobject___195 *, const char *, size_t);
	void (*setup)(struct module___198 *, const char *);
	int (*test)(struct module___198 *);
	void (*free)(struct module___198 *);
};

struct gnet_dump___29 {
	spinlock_t *lock;
	struct sk_buff___34 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___29;

struct Qdisc_ops___29 {
	struct Qdisc_ops___29 *next;
	const struct Qdisc_class_ops___29 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___34 *, struct Qdisc___29 *, struct sk_buff___34 **);
	struct sk_buff___34 * (*dequeue)(struct Qdisc___29 *);
	struct sk_buff___34 * (*peek)(struct Qdisc___29 *);
	int (*init)(struct Qdisc___29 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___29 *);
	void (*destroy)(struct Qdisc___29 *);
	int (*change)(struct Qdisc___29 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___29 *);
	int (*change_tx_queue_len)(struct Qdisc___29 *, unsigned int);
	int (*dump)(struct Qdisc___29 *, struct sk_buff___34 *);
	int (*dump_stats)(struct Qdisc___29 *, struct gnet_dump___29 *);
	void (*ingress_block_set)(struct Qdisc___29 *, u32);
	void (*egress_block_set)(struct Qdisc___29 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___29 *);
	u32 (*egress_block_get)(struct Qdisc___29 *);
	struct module___198 *owner;
};

struct tcf_block___29;

struct Qdisc_class_ops___29 {
	unsigned int flags;
	struct netdev_queue___30 * (*select_queue)(struct Qdisc___29 *, struct tcmsg *);
	int (*graft)(struct Qdisc___29 *, long unsigned int, struct Qdisc___29 *, struct Qdisc___29 **, struct netlink_ext_ack *);
	struct Qdisc___29 * (*leaf)(struct Qdisc___29 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___29 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___29 *, u32);
	int (*change)(struct Qdisc___29 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___29 *, long unsigned int);
	void (*walk)(struct Qdisc___29 *, struct qdisc_walker *);
	struct tcf_block___29 * (*tcf_block)(struct Qdisc___29 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___29 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___29 *, long unsigned int);
	int (*dump)(struct Qdisc___29 *, long unsigned int, struct sk_buff___34 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___29 *, long unsigned int, struct gnet_dump___29 *);
};

struct tcf_chain___29;

struct tcf_block___29 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___42 *net;
	struct Qdisc___29 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___29 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___29;

struct tcf_proto_ops___29;

struct tcf_proto___29 {
	struct tcf_proto___29 *next;
	void *root;
	int (*classify)(struct sk_buff___34 *, const struct tcf_proto___29 *, struct tcf_result___29 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___29 *ops;
	struct tcf_chain___29 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___29 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___29 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___29 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___34 *, const struct tcf_proto___29 *, struct tcf_result___29 *);
	int (*init)(struct tcf_proto___29 *);
	void (*destroy)(struct tcf_proto___29 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___29 *, u32);
	void (*put)(struct tcf_proto___29 *, void *);
	int (*change)(struct net___42 *, struct sk_buff___34 *, struct tcf_proto___29 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___29 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___29 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___29 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___42 *, struct tcf_chain___29 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___42 *, struct tcf_proto___29 *, void *, struct sk_buff___34 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___34 *, struct net___42 *, void *);
	struct module___198 *owner;
	int flags;
};

struct tcf_chain___29 {
	struct mutex filter_chain_lock;
	struct tcf_proto___29 *filter_chain;
	struct list_head list;
	struct tcf_block___29 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___29 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___19 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___29 *prog;
};

struct bpf_redirect_info___29 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___189 *map;
	struct bpf_map___189 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___19;

struct neigh_hash_table___19;

struct neigh_table___19 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___34 *, __u32 *);
	bool (*key_eq)(const struct neighbour___20 *, const void *);
	int (*constructor)(struct neighbour___20 *);
	int (*pconstructor)(struct pneigh_entry___19 *);
	void (*pdestructor)(struct pneigh_entry___19 *);
	void (*proxy_redo)(struct sk_buff___34 *);
	char *id;
	struct neigh_parms___20 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___30 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___19 *nht;
	struct pneigh_entry___19 **phash_buckets;
};

struct neigh_ops___19 {
	int family;
	void (*solicit)(struct neighbour___20 *, struct sk_buff___34 *);
	void (*error_report)(struct neighbour___20 *, struct sk_buff___34 *);
	int (*output)(struct neighbour___20 *, struct sk_buff___34 *);
	int (*connected_output)(struct neighbour___20 *, struct sk_buff___34 *);
};

struct pneigh_entry___19 {
	struct pneigh_entry___19 *next;
	possible_net_t___31 net;
	struct net_device___34 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___19 {
	struct neighbour___20 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___19 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___19 *ctarget;
	struct net___42 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___19 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___19 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___12;

struct timewait_sock_ops___12;

struct proto___19 {
	void (*close)(struct sock___21 *, long int);
	int (*pre_connect)(struct sock___21 *, struct sockaddr *, int);
	int (*connect)(struct sock___21 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___21 *, int);
	struct sock___21 * (*accept)(struct sock___21 *, int, int *, bool);
	int (*ioctl)(struct sock___21 *, int, long unsigned int);
	int (*init)(struct sock___21 *);
	void (*destroy)(struct sock___21 *);
	void (*shutdown)(struct sock___21 *, int);
	int (*setsockopt)(struct sock___21 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___21 *, int, int, char *, int *);
	void (*keepalive)(struct sock___21 *, int);
	int (*sendmsg)(struct sock___21 *, struct msghdr___21 *, size_t);
	int (*recvmsg)(struct sock___21 *, struct msghdr___21 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___21 *, struct page___245 *, int, size_t, int);
	int (*bind)(struct sock___21 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___21 *, struct sk_buff___34 *);
	void (*release_cb)(struct sock___21 *);
	int (*hash)(struct sock___21 *);
	void (*unhash)(struct sock___21 *);
	void (*rehash)(struct sock___21 *);
	int (*get_port)(struct sock___21 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___21 *);
	bool (*stream_memory_read)(const struct sock___21 *);
	void (*enter_memory_pressure)(struct sock___21 *);
	void (*leave_memory_pressure)(struct sock___21 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___12 *rsk_prot;
	struct timewait_sock_ops___12 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___198 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___21 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct request_sock___12;

struct request_sock_ops___12 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___21 *, struct request_sock___12 *);
	void (*send_ack)(const struct sock___21 *, struct sk_buff___34 *, struct request_sock___12 *);
	void (*send_reset)(const struct sock___21 *, struct sk_buff___34 *);
	void (*destructor)(struct request_sock___12 *);
	void (*syn_ack_timeout)(const struct request_sock___12 *);
};

struct timewait_sock_ops___12 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___21 *, struct sock___21 *, void *);
	void (*twsk_destructor)(struct sock___21 *);
};

struct request_sock___12 {
	struct sock_common___19 __req_common;
	struct request_sock___12 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___12 *rsk_ops;
	struct sock___21 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___11 {
	struct in6_addr mca_addr;
	struct inet6_dev___12 *idev;
	struct ifmcaddr6___11 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ip6_ra_chain___11 {
	struct ip6_ra_chain___11 *next;
	struct sock___21 *sk;
	int sel;
	void (*destructor)(struct sock___21 *);
};

struct linux_binprm___42 {
	char buf[256];
	struct vm_area_struct___245 *vma;
	long unsigned int vma_pages;
	struct mm_struct___244 *mm;
	long unsigned int p;
	unsigned int called_set_creds: 1;
	unsigned int cap_elevated: 1;
	unsigned int secureexec: 1;
	unsigned int recursion_depth;
	struct file___244 *file;
	struct cred___237 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
};

struct coredump_params___41 {
	union {
		const kernel_siginfo_t *siginfo;
		struct {
			const siginfo_t *siginfo;
		} __UNIQUE_ID_rh_kabi_hide77;
		union {		};
	};
	struct pt_regs *regs;
	struct file___244 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
};

struct netnode_security_struct {
	union {
		__be32 ipv4;
		struct in6_addr ipv6;
	} addr;
	u32 sid;
	u16 family;
};

struct sel_netnode_bkt {
	unsigned int size;
	struct list_head list;
};

struct sel_netnode {
	struct netnode_security_struct nsec;
	struct list_head list;
	struct callback_head rcu;
};

struct netport_security_struct {
	u32 sid;
	u16 port;
	u8 protocol;
};

struct sel_netport_bkt {
	int size;
	struct list_head list;
};

struct sel_netport {
	struct netport_security_struct psec;
	struct list_head list;
	struct callback_head rcu;
};

struct module___199;

struct file___245;

struct kiocb___245;

struct iov_iter___112;

struct poll_table_struct___153;

struct vm_area_struct___246;

struct inode___245;

struct file_lock___245;

struct page___246;

struct pipe_inode_info___55;

struct seq_file___221;

struct file_operations___245 {
	struct module___199 *owner;
	loff_t (*llseek)(struct file___245 *, loff_t, int);
	ssize_t (*read)(struct file___245 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___245 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___245 *, struct iov_iter___112 *);
	ssize_t (*write_iter)(struct kiocb___245 *, struct iov_iter___112 *);
	int (*iopoll)(struct kiocb___245 *, bool);
	int (*iterate)(struct file___245 *, struct dir_context *);
	int (*iterate_shared)(struct file___245 *, struct dir_context *);
	__poll_t (*poll)(struct file___245 *, struct poll_table_struct___153 *);
	long int (*unlocked_ioctl)(struct file___245 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___245 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___245 *, struct vm_area_struct___246 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___245 *, struct file___245 *);
	int (*flush)(struct file___245 *, fl_owner_t);
	int (*release)(struct inode___245 *, struct file___245 *);
	int (*fsync)(struct file___245 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___245 *, int);
	int (*lock)(struct file___245 *, int, struct file_lock___245 *);
	ssize_t (*sendpage)(struct file___245 *, struct page___246 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___245 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___245 *, int, struct file_lock___245 *);
	ssize_t (*splice_write)(struct pipe_inode_info___55 *, struct file___245 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___245 *, loff_t *, struct pipe_inode_info___55 *, size_t, unsigned int);
	int (*setlease)(struct file___245 *, long int, struct file_lock___245 **, void **);
	long int (*fallocate)(struct file___245 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___221 *, struct file___245 *);
	ssize_t (*copy_file_range)(struct file___245 *, loff_t, struct file___245 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___245 *, loff_t, struct file___245 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___245 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___245 {
	u64 seqnum;
	struct vm_area_struct___246 *vmas[4];
};

struct page_frag___245 {
	struct page___246 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___245;

struct mem_cgroup___106;

struct pid___185;

struct cred___238;

struct nsproxy___225;

struct signal_struct___203;

struct bio_list___121;

struct backing_dev_info___121;

struct css_set___190;

struct vm_struct___162;

struct task_struct___246 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___246 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___245 *mm;
	struct mm_struct___245 *active_mm;
	struct vmacache___245 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___246 *real_parent;
	struct task_struct___246 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___246 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___106 *active_memcg;
	long int rh_reserved2;
	struct pid___185 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___185 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___185 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___238 *ptracer_cred;
	const struct cred___238 *real_cred;
	const struct cred___238 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___225 *nsproxy;
	struct signal_struct___203 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___246 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___121 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___121 *backing_dev_info;
	struct io_context___60 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___190 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___55 *splice_pipe;
	struct page_frag___245 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___106 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___246 *oom_reaper_list;
	struct vm_struct___162 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___127 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___185;

struct upid___185 {
	int nr;
	struct pid_namespace___185 *ns;
};

struct dentry___245;

struct user_namespace___205;

struct ucounts___205;

struct pid_namespace___185 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___246 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___185 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___245 *proc_self;
	struct dentry___245 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___205 *user_ns;
	struct ucounts___205 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___28 ns;
};

struct pid___185 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___185 numbers[1];
};

struct rw_semaphore___246 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___246 *owner;
};

struct key___238;

struct user_namespace___205 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___205 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___28 ns;
	long unsigned int flags;
	struct key___238 *persistent_keyring_register;
	struct rw_semaphore___246 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___205 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct secondary_data___246 {
	void *stack;
	struct task_struct___246 *task;
	long int status;
};

typedef struct page___246 *pgtable_t___245;

struct address_space___244;

struct dev_pagemap___235;

struct page___246 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___244 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___246 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___245 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___245 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___235 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___106 *mem_cgroup;
};

struct user_struct___238 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___238 *uid_keyring;
	struct key___238 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___235;

struct vm_area_struct___246 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___246 *vm_next;
	struct vm_area_struct___246 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___245 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___235 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___245 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct linux_binfmt___42;

struct core_state___245;

struct mm_struct___245 {
	struct {
		struct vm_area_struct___246 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___245 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___246 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___42 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___245 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___246 *owner;
		struct user_namespace___205 *user_ns;
		struct file___245 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___245 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup___190;

struct cgroup_subsys___190;

struct cgroup_subsys_state___191 {
	struct cgroup___190 *cgroup;
	struct cgroup_subsys___190 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___191 *parent;
};

struct kernfs_node___239;

struct cgroup_file___190 {
	struct kernfs_node___239 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___106;

struct mem_cgroup___106 {
	struct cgroup_subsys_state___191 css;
	struct mem_cgroup_id___22 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___190 events_file;
	struct cgroup_file___190 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___246 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___106 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cred___238 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___238 *session_keyring;
	struct key___238 *process_keyring;
	struct key___238 *thread_keyring;
	struct key___238 *request_key_auth;
	void *security;
	struct user_struct___238 *user;
	struct user_namespace___205 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___43;

struct cgroup_namespace___190;

struct nsproxy___225 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___185 *pid_ns_for_children;
	struct net___43 *net_ns;
	struct cgroup_namespace___190 *cgroup_ns;
};

struct signal_struct___203 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___246 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___246 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___185 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___185 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___245 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___185 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___121;

struct bio_list___121 {
	struct bio___121 *head;
	struct bio___121 *tail;
};

struct bdi_writeback_congested___121;

struct bdi_writeback___121 {
	struct backing_dev_info___121 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___121 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___191 *memcg_css;
	struct cgroup_subsys_state___191 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___209;

struct backing_dev_info___121 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___121 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___209 *dev;
	struct device___209 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___245 *debug_dir;
	struct dentry___245 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___190 {
	struct cgroup_subsys_state___191 *subsys[13];
	refcount_t refcount;
	struct css_set___190 *dom_cset;
	struct cgroup___190 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___190 *mg_src_cgrp;
	struct cgroup___190 *mg_dst_cgrp;
	struct css_set___190 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___244;

struct pipe_buffer___55;

struct pipe_inode_info___55 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___246 *tmp_page;
	struct fasync_struct___244 *fasync_readers;
	struct fasync_struct___244 *fasync_writers;
	struct pipe_buffer___55 *bufs;
	struct user_struct___238 *user;
};

struct vm_struct___162 {
	struct vm_struct___162 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___246 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___215 {
	struct task_struct___246 task;
	long unsigned int stack[8192];
};

struct dentry_operations___244;

struct super_block___244;

struct dentry___245 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___245 *d_parent;
	struct qstr d_name;
	struct inode___245 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___244 *d_op;
	struct super_block___244 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___244;

struct address_space___244 {
	struct inode___245 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___246 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___244 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___244;

struct block_device___245;

struct inode___245 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___244 *i_op;
	struct super_block___244 *i_sb;
	struct address_space___244 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___246 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___121 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___245 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___244 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___55 *i_pipe;
		struct block_device___245 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___244;

struct dentry_operations___244 {
	int (*d_revalidate)(struct dentry___245 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___245 *, unsigned int);
	int (*d_hash)(const struct dentry___245 *, struct qstr *);
	int (*d_compare)(const struct dentry___245 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___245 *);
	int (*d_init)(struct dentry___245 *);
	void (*d_release)(struct dentry___245 *);
	void (*d_prune)(struct dentry___245 *);
	void (*d_iput)(struct dentry___245 *, struct inode___245 *);
	char * (*d_dname)(struct dentry___245 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___244 *);
	int (*d_manage)(const struct path___244 *, bool);
	struct dentry___245 * (*d_real)(struct dentry___245 *, const struct inode___245 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___244;

struct mem_dqinfo___244 {
	struct quota_format_type___244 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___244;

struct quota_info___244 {
	unsigned int flags;
	struct rw_semaphore___246 dqio_sem;
	struct inode___245 *files[3];
	struct mem_dqinfo___244 info[3];
	const struct quota_format_ops___244 *ops[3];
};

struct rcuwait___244 {
	struct task_struct___246 *task;
};

struct percpu_rw_semaphore___244 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___246 rw_sem;
	struct rcuwait___244 writer;
	int readers_block;
};

struct sb_writers___244 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___244 rw_sem[3];
};

struct shrink_control___106;

struct shrinker___106 {
	long unsigned int (*count_objects)(struct shrinker___106 *, struct shrink_control___106 *);
	long unsigned int (*scan_objects)(struct shrinker___106 *, struct shrink_control___106 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___244;

struct super_operations___244;

struct dquot_operations___244;

struct quotactl_ops___244;

struct super_block___244 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___244 *s_type;
	const struct super_operations___244 *s_op;
	const struct dquot_operations___244 *dq_op;
	const struct quotactl_ops___244 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___245 *s_root;
	struct rw_semaphore___246 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___245 *s_bdev;
	struct backing_dev_info___121 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___244 s_dquot;
	struct sb_writers___244 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___244 *s_d_op;
	int cleancache_poolid;
	struct shrinker___106 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___205 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct path___244 {
	struct vfsmount *mnt;
	struct dentry___245 *dentry;
};

struct shrink_control___106 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___106 *memcg;
};

struct pglist_data___245;

struct lruvec___245 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___245 *pgdat;
};

struct zone___245 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___245 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___245 {
	struct zone___245 *zone;
	int zone_idx;
};

struct zonelist___245 {
	struct zoneref___245 _zonerefs[25];
};

struct pglist_data___245 {
	struct zone___245 node_zones[3];
	struct zonelist___245 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___246 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___246 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___245 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___245 {
	struct rw_semaphore___246 rwsem;
	struct notifier_block *head;
};

typedef int (*dev_page_fault_t___235)(struct vm_area_struct___246 *, long unsigned int, const struct page___246 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___235)(struct page___246 *, void *);

struct dev_pagemap___235 {
	dev_page_fault_t___235 page_fault;
	dev_page_free_t___235 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___209 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct fown_struct___185 {
	rwlock_t lock;
	struct pid___185 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___245 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___244 f_path;
	struct inode___245 *f_inode;
	const struct file_operations___245 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___185 f_owner;
	const struct cred___238 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___244 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___235;

struct vm_operations_struct___235 {
	void (*open)(struct vm_area_struct___246 *);
	void (*close)(struct vm_area_struct___246 *);
	int (*split)(struct vm_area_struct___246 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___246 *);
	vm_fault_t (*fault)(struct vm_fault___235 *);
	vm_fault_t (*huge_fault)(struct vm_fault___235 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___235 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___246 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___235 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___235 *);
	int (*access)(struct vm_area_struct___246 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___246 *);
	int (*set_policy)(struct vm_area_struct___246 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___246 *, long unsigned int);
	struct page___246 * (*find_special_page)(struct vm_area_struct___246 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___245 {
	struct task_struct___246 *task;
	struct core_thread___245 *next;
};

struct core_state___245 {
	atomic_t nr_threads;
	struct core_thread___245 dumper;
	struct completion startup;
};

struct linux_binprm___43;

struct coredump_params___42;

struct linux_binfmt___42 {
	struct list_head lh;
	struct module___199 *module;
	int (*load_binary)(struct linux_binprm___43 *);
	int (*load_shlib)(struct file___245 *);
	int (*core_dump)(struct coredump_params___42 *);
	long unsigned int min_coredump;
};

struct vm_fault___235 {
	struct vm_area_struct___246 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___246 *cow_page;
	struct mem_cgroup___106 *memcg;
	struct page___246 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___245 prealloc_pte;
};

struct kiocb___245 {
	struct file___245 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___245 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___244 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___245 *ia_file;
};

struct dquot___244 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___244 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___244 {
	int qf_fmt_id;
	const struct quota_format_ops___244 *qf_ops;
	struct module___199 *qf_owner;
	struct quota_format_type___244 *qf_next;
};

struct quota_format_ops___244 {
	int (*check_quota_file)(struct super_block___244 *, int);
	int (*read_file_info)(struct super_block___244 *, int);
	int (*write_file_info)(struct super_block___244 *, int);
	int (*free_file_info)(struct super_block___244 *, int);
	int (*read_dqblk)(struct dquot___244 *);
	int (*commit_dqblk)(struct dquot___244 *);
	int (*release_dqblk)(struct dquot___244 *);
	int (*get_next_id)(struct super_block___244 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___244 {
	int (*write_dquot)(struct dquot___244 *);
	struct dquot___244 * (*alloc_dquot)(struct super_block___244 *, int);
	void (*destroy_dquot)(struct dquot___244 *);
	int (*acquire_dquot)(struct dquot___244 *);
	int (*release_dquot)(struct dquot___244 *);
	int (*mark_dirty)(struct dquot___244 *);
	int (*write_info)(struct super_block___244 *, int);
	qsize_t * (*get_reserved_space)(struct inode___245 *);
	int (*get_projid)(struct inode___245 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___245 *, qsize_t *);
	int (*get_next_id)(struct super_block___244 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___244 {
	int (*quota_on)(struct super_block___244 *, int, int, const struct path___244 *);
	int (*quota_off)(struct super_block___244 *, int);
	int (*quota_enable)(struct super_block___244 *, unsigned int);
	int (*quota_disable)(struct super_block___244 *, unsigned int);
	int (*quota_sync)(struct super_block___244 *, int);
	int (*set_info)(struct super_block___244 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___244 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___244 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___244 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___244 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___244 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___232;

struct kobj_type___232;

struct kobject___233 {
	const char *name;
	struct list_head entry;
	struct kobject___233 *parent;
	struct kset___232 *kset;
	struct kobj_type___232 *ktype;
	struct kernfs_node___239 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___196 {
	struct kobject___233 kobj;
	struct module___199 *mod;
	struct kobject___233 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___196 {
	struct module___199 *mod;
	struct latch_tree_node node;
};

struct module_layout___196 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___196 mtn;
};

struct module_attribute___196;

struct kernel_param___196;

struct module___199 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___196 mkobj;
	struct module_attribute___196 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___233 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___196 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___196 core_layout;
	struct module_layout___196 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide54;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide55;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___117;

struct address_space_operations___244 {
	int (*writepage)(struct page___246 *, struct writeback_control___117 *);
	int (*readpage)(struct file___245 *, struct page___246 *);
	int (*writepages)(struct address_space___244 *, struct writeback_control___117 *);
	int (*set_page_dirty)(struct page___246 *);
	int (*readpages)(struct file___245 *, struct address_space___244 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___245 *, struct address_space___244 *, loff_t, unsigned int, unsigned int, struct page___246 **, void **);
	int (*write_end)(struct file___245 *, struct address_space___244 *, loff_t, unsigned int, unsigned int, struct page___246 *, void *);
	sector_t (*bmap)(struct address_space___244 *, sector_t);
	void (*invalidatepage)(struct page___246 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___246 *, gfp_t);
	void (*freepage)(struct page___246 *);
	ssize_t (*direct_IO)(struct kiocb___245 *, struct iov_iter___112 *);
	int (*migratepage)(struct address_space___244 *, struct page___246 *, struct page___246 *, enum migrate_mode);
	bool (*isolate_page)(struct page___246 *, isolate_mode_t);
	void (*putback_page)(struct page___246 *);
	int (*launder_page)(struct page___246 *);
	int (*is_partially_uptodate)(struct page___246 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___246 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___244 *, struct page___246 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___245 *, sector_t *);
	void (*swap_deactivate)(struct file___245 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___117 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___121 *wb;
	struct inode___245 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___121;

struct iov_iter___112 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___121 *bvec;
		struct pipe_inode_info___55 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___245 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___245 *bd_inode;
	struct super_block___244 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___245 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___121 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___244 {
	struct dentry___245 * (*lookup)(struct inode___245 *, struct dentry___245 *, unsigned int);
	const char * (*get_link)(struct dentry___245 *, struct inode___245 *, struct delayed_call *);
	int (*permission)(struct inode___245 *, int);
	struct posix_acl * (*get_acl)(struct inode___245 *, int);
	int (*readlink)(struct dentry___245 *, char *, int);
	int (*create)(struct inode___245 *, struct dentry___245 *, umode_t, bool);
	int (*link)(struct dentry___245 *, struct inode___245 *, struct dentry___245 *);
	int (*unlink)(struct inode___245 *, struct dentry___245 *);
	int (*symlink)(struct inode___245 *, struct dentry___245 *, const char *);
	int (*mkdir)(struct inode___245 *, struct dentry___245 *, umode_t);
	int (*rmdir)(struct inode___245 *, struct dentry___245 *);
	int (*mknod)(struct inode___245 *, struct dentry___245 *, umode_t, dev_t);
	int (*rename)(struct inode___245 *, struct dentry___245 *, struct inode___245 *, struct dentry___245 *, unsigned int);
	int (*setattr)(struct dentry___245 *, struct iattr___244 *);
	int (*getattr)(const struct path___244 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___245 *, char *, size_t);
	int (*fiemap)(struct inode___245 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___245 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___245 *, struct dentry___245 *, struct file___245 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___245 *, struct dentry___245 *, umode_t);
	int (*set_acl)(struct inode___245 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___244 {
	void (*fl_copy_lock)(struct file_lock___245 *, struct file_lock___245 *);
	void (*fl_release_private)(struct file_lock___245 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___244;

struct file_lock___245 {
	struct file_lock___245 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___245 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___244 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___244 *fl_ops;
	const struct lock_manager_operations___244 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___244 {
	int (*lm_compare_owner)(struct file_lock___245 *, struct file_lock___245 *);
	long unsigned int (*lm_owner_key)(struct file_lock___245 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___245 *);
	int (*lm_grant)(struct file_lock___245 *, int);
	bool (*lm_break)(struct file_lock___245 *);
	int (*lm_change)(struct file_lock___245 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___245 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___244 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___244 *fa_next;
	struct file___245 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___244 {
	const char *name;
	int fs_flags;
	struct dentry___245 * (*mount)(struct file_system_type___244 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___244 *);
	struct module___199 *owner;
	struct file_system_type___244 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___244 {
	struct inode___245 * (*alloc_inode)(struct super_block___244 *);
	void (*destroy_inode)(struct inode___245 *);
	void (*dirty_inode)(struct inode___245 *, int);
	int (*write_inode)(struct inode___245 *, struct writeback_control___117 *);
	int (*drop_inode)(struct inode___245 *);
	void (*evict_inode)(struct inode___245 *);
	void (*put_super)(struct super_block___244 *);
	int (*sync_fs)(struct super_block___244 *, int);
	int (*freeze_super)(struct super_block___244 *);
	int (*freeze_fs)(struct super_block___244 *);
	int (*thaw_super)(struct super_block___244 *);
	int (*unfreeze_fs)(struct super_block___244 *);
	int (*statfs)(struct dentry___245 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___244 *, int *, char *);
	void (*umount_begin)(struct super_block___244 *);
	int (*show_options)(struct seq_file___221 *, struct dentry___245 *);
	int (*show_devname)(struct seq_file___221 *, struct dentry___245 *);
	int (*show_path)(struct seq_file___221 *, struct dentry___245 *);
	int (*show_stats)(struct seq_file___221 *, struct dentry___245 *);
	ssize_t (*quota_read)(struct super_block___244 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___244 *, int, const char *, size_t, loff_t);
	struct dquot___244 ** (*get_dquots)(struct inode___245 *);
	int (*bdev_try_to_free_page)(struct super_block___244 *, struct page___246 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___244 *, struct shrink_control___106 *);
	long int (*free_cached_objects)(struct super_block___244 *, struct shrink_control___106 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___155)(struct file___245 *, wait_queue_head_t *, struct poll_table_struct___153 *);

struct poll_table_struct___153 {
	poll_queue_proc___155 _qproc;
	__poll_t _key;
};

struct seq_operations___219;

struct seq_file___221 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___219 *op;
	int poll_event;
	const struct file___245 *file;
	void *private;
};

typedef void bio_end_io_t___121(struct bio___121 *);

struct bio_vec___121 {
	struct page___246 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___121;

struct bio_set___121;

struct bio___121 {
	struct bio___121 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___121 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___121 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___121 *bi_io_vec;
	struct bio_set___121 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___121 bi_inline_vecs[0];
};

struct linux_binprm___43 {
	char buf[256];
	struct vm_area_struct___246 *vma;
	long unsigned int vma_pages;
	struct mm_struct___245 *mm;
	long unsigned int p;
	unsigned int called_set_creds: 1;
	unsigned int cap_elevated: 1;
	unsigned int secureexec: 1;
	unsigned int recursion_depth;
	struct file___245 *file;
	struct cred___238 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
};

struct coredump_params___42 {
	union {
		const kernel_siginfo_t *siginfo;
		struct {
			const siginfo_t *siginfo;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	struct pt_regs *regs;
	struct file___245 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
};

struct msghdr___22 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___112 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___245 *msg_iocb;
};

struct inet_frags___31;

struct netns_frags___31 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___31 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct inet_frag_queue___31;

struct inet_frags___31 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___31 *, const void *);
	void (*destructor)(struct inet_frag_queue___31 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct sk_buff___35;

struct inet_frag_queue___31 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___35 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___35 *fragments_tail;
	struct sk_buff___35 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___31 *net;
	struct callback_head rcu;
};

struct net_device___35;

struct sock___22;

struct nf_bridge_info___31;

struct sk_buff___35 {
	union {
		struct {
			struct sk_buff___35 *next;
			struct sk_buff___35 *prev;
			union {
				struct net_device___35 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___22 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___35 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___31 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct ip_ra_chain___9;

struct fib_rules_ops___20;

struct fib_notifier_ops___20;

struct netns_ipv4___31 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___9 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___20 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___22 *fibnl;
	struct sock___22 **icmp_sk;
	struct sock___22 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___22 **tcp_sk;
	struct netns_frags___31 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___20 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___20 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___20 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct ip_ra_chain___9 {
	struct ip_ra_chain___9 *next;
	struct sock___22 *sk;
	union {
		void (*destructor)(struct sock___22 *);
		struct sock___22 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___20;

struct fib_lookup_arg___20;

struct fib_rules_ops___20 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___20 *, struct flowi *, int, struct fib_lookup_arg___20 *);
	bool (*suppress)(struct fib_rule___20 *, struct fib_lookup_arg___20 *);
	int (*match)(struct fib_rule___20 *, struct flowi *, int);
	int (*configure)(struct fib_rule___20 *, struct sk_buff___35 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___20 *);
	int (*compare)(struct fib_rule___20 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___20 *, struct sk_buff___35 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___20 *);
	void (*flush_cache)(struct fib_rules_ops___20 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___199 *owner;
	struct net___43 *fro_net;
	struct callback_head rcu;
};

typedef struct {
	struct net___43 *net;
} possible_net_t___32;

struct proto___20;

struct sock_common___20 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___20 *skc_prot;
	possible_net_t___32 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___22 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff_head___31 {
	struct sk_buff___35 *next;
	struct sk_buff___35 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___20;

struct socket_wq___21;

struct dst_entry___21;

struct socket___22;

struct sock___22 {
	struct sock_common___20 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___31 sk_error_queue;
	struct sk_buff_head___31 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___35 *head;
		struct sk_buff___35 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___20 *sk_filter;
	union {
		struct socket_wq___21 *sk_wq;
		struct socket_wq___21 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___21 *sk_rx_dst;
	struct dst_entry___21 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___35 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___31 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___245 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___20 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___185 *sk_peer_pid;
	const struct cred___238 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___22 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___106 *sk_memcg;
	void (*sk_state_change)(struct sock___22 *);
	void (*sk_data_ready)(struct sock___22 *);
	void (*sk_write_space)(struct sock___22 *);
	void (*sk_error_report)(struct sock___22 *);
	int (*sk_backlog_rcv)(struct sock___22 *, struct sk_buff___35 *);
	struct sk_buff___35 * (*sk_validate_xmit_skb)(struct sock___22 *, struct net_device___35 *, struct sk_buff___35 *);
	void (*sk_destruct)(struct sock___22 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct fib_notifier_ops___20 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___43 *);
	int (*fib_dump)(struct net___43 *, struct notifier_block *);
	struct module___199 *owner;
	struct callback_head rcu;
};

struct neighbour___21;

struct dst_ops___41 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___41 *);
	struct dst_entry___21 * (*check)(struct dst_entry___21 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___21 *);
	unsigned int (*mtu)(const struct dst_entry___21 *);
	u32 * (*cow_metrics)(struct dst_entry___21 *, long unsigned int);
	void (*destroy)(struct dst_entry___21 *);
	void (*ifdown)(struct dst_entry___21 *, struct net_device___35 *, int);
	struct dst_entry___21 * (*negative_advice)(struct dst_entry___21 *);
	void (*link_failure)(struct sk_buff___35 *);
	void (*update_pmtu)(struct dst_entry___21 *, struct sock___22 *, struct sk_buff___35 *, u32);
	void (*redirect)(struct dst_entry___21 *, struct sock___22 *, struct sk_buff___35 *);
	int (*local_out)(struct net___43 *, struct sock___22 *, struct sk_buff___35 *);
	struct neighbour___21 * (*neigh_lookup)(const struct dst_entry___21 *, struct sk_buff___35 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___21 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct dst_entry___21 {
	struct net_device___35 *dev;
	struct dst_ops___41 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___35 *);
	int (*output)(struct net___43 *, struct sock___22 *, struct sk_buff___35 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

typedef rx_handler_result_t rx_handler_func_t___31(struct sk_buff___35 **);

struct dev_pm_info___209 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___209 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___209;

struct bus_type___209;

struct device_driver___209;

struct dev_pm_domain___209;

struct dma_map_ops___52;

struct fwnode_handle___144;

struct class___209;

struct attribute_group___211;

struct device___209 {
	struct device___209 *parent;
	struct device_private *p;
	struct kobject___233 kobj;
	const char *init_name;
	const struct device_type___209 *type;
	struct mutex mutex;
	struct bus_type___209 *bus;
	struct device_driver___209 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___209 power;
	struct dev_pm_domain___209 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___52 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___144 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___209 *class;
	const struct attribute_group___211 **groups;
	void (*release)(struct device___209 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct net_device_ops___31;

struct ethtool_ops___31;

struct l3mdev_ops___21;

struct ndisc_ops___13;

struct xfrmdev_ops___31;

struct tlsdev_ops___31;

struct header_ops___31;

struct inet6_dev___13;

struct netdev_rx_queue___31;

struct bpf_prog___30;

struct mini_Qdisc___30;

struct netdev_queue___31;

struct Qdisc___30;

struct rtnl_link_ops___30;

struct dcbnl_rtnl_ops___31;

struct net_device___35 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___31 *netdev_ops;
	const struct ethtool_ops___31 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___21 *l3mdev_ops;
	const struct ndisc_ops___13 *ndisc_ops;
	const struct xfrmdev_ops___31 *xfrmdev_ops;
	const struct tlsdev_ops___31 *tlsdev_ops;
	const struct header_ops___31 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___232 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___13 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___31 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___30 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___31 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___30 *miniq_ingress;
	struct netdev_queue___31 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___31 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___30 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___30 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___31 = 0,
		NETREG_REGISTERED___31 = 1,
		NETREG_UNREGISTERING___31 = 2,
		NETREG_UNREGISTERED___31 = 3,
		NETREG_RELEASED___31 = 4,
		NETREG_DUMMY___31 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___31 = 0,
		RTNL_LINK_INITIALIZING___31 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___35 *);
	struct netpoll_info *npinfo;
	possible_net_t___32 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___209 dev;
	const struct attribute_group___211 *sysfs_groups[4];
	const struct attribute_group___211 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___30 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___31 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct netns_ipv6___41 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___31 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___41 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___20 *fib6_rules_ops;
	struct sock___22 **icmp_sk;
	struct sock___22 *ndisc_sk;
	struct sock___22 *tcp_sk;
	struct sock___22 *igmp_sk;
	struct sock___22 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___20 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___20 *notifier_ops;
	struct fib_notifier_ops___20 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___21 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___22 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___31 {
	struct netns_frags___31 frags;
};

struct netns_xfrm___41 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___22 *nlsk;
	struct sock___22 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___41 xfrm4_dst_ops;
	struct dst_ops___41 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct net___43 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___205 *user_ns;
	struct ucounts___205 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___28 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___22 *rtnl;
	struct sock___22 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___35 *loopback_dev;
	struct netns_core core;
	struct netns_mib___2 mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___31 ipv4;
	struct netns_ipv6___41 ipv6;
	struct netns_sctp___21 sctp;
	struct netns_nf___2 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___31 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___22 *nfnl;
	struct sock___22 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___41 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can___2 can;
	struct sock___22 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___30 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neigh_table___20;

struct neigh_parms___21;

struct neigh_ops___20;

struct neighbour___21 {
	struct neighbour___21 *next;
	struct neigh_table___20 *tbl;
	struct neigh_parms___21 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___31 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___21 *, struct sk_buff___35 *);
	const struct neigh_ops___20 *ops;
	struct callback_head rcu;
	struct net_device___35 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct socket_wq___21 {
	wait_queue_head_t wait;
	struct fasync_struct___244 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___21;

struct socket___22 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___21 *wq;
	struct file___245 *file;
	struct sock___22 *sk;
	const struct proto_ops___21 *ops;
};

typedef int (*sk_read_actor_t___20)(read_descriptor_t *, struct sk_buff___35 *, unsigned int, size_t);

struct proto_ops___21 {
	int family;
	struct module___199 *owner;
	int (*release)(struct socket___22 *);
	int (*bind)(struct socket___22 *, struct sockaddr *, int);
	int (*connect)(struct socket___22 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___22 *, struct socket___22 *);
	int (*accept)(struct socket___22 *, struct socket___22 *, int, bool);
	int (*getname)(struct socket___22 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___245 *, struct socket___22 *, struct poll_table_struct___153 *);
	int (*ioctl)(struct socket___22 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___22 *, int);
	int (*shutdown)(struct socket___22 *, int);
	int (*setsockopt)(struct socket___22 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___22 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___22 *, struct msghdr___22 *, size_t);
	int (*recvmsg)(struct socket___22 *, struct msghdr___22 *, size_t, int);
	int (*mmap)(struct file___245 *, struct socket___22 *, struct vm_area_struct___246 *);
	ssize_t (*sendpage)(struct socket___22 *, struct page___246 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___22 *, loff_t *, struct pipe_inode_info___55 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___22 *, int);
	int (*peek_len)(struct socket___22 *);
	int (*read_sock)(struct sock___22 *, read_descriptor_t *, sk_read_actor_t___20);
	int (*sendpage_locked)(struct sock___22 *, struct page___246 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___22 *, struct msghdr___22 *, size_t);
	int (*set_rcvlowat)(struct sock___22 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct kernfs_root___239;

struct kernfs_elem_dir___239 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___239 *root;
};

struct kernfs_syscall_ops___239;

struct kernfs_root___239 {
	struct kernfs_node___239 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___239 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___239 {
	struct kernfs_node___239 *target_kn;
};

struct kernfs_ops___239;

struct kernfs_elem_attr___239 {
	const struct kernfs_ops___239 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___239 *notify_next;
};

struct kernfs_node___239 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___239 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___239 dir;
		struct kernfs_elem_symlink___239 symlink;
		struct kernfs_elem_attr___239 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___239;

struct kernfs_ops___239 {
	int (*open)(struct kernfs_open_file___239 *);
	void (*release)(struct kernfs_open_file___239 *);
	int (*seq_show)(struct seq_file___221 *, void *);
	void * (*seq_start)(struct seq_file___221 *, loff_t *);
	void * (*seq_next)(struct seq_file___221 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___221 *, void *);
	ssize_t (*read)(struct kernfs_open_file___239 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___239 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___239 *, struct vm_area_struct___246 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___239 *, struct poll_table_struct___153 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___239 {
	int (*remount_fs)(struct kernfs_root___239 *, int *, char *);
	int (*show_options)(struct seq_file___221 *, struct kernfs_root___239 *);
	int (*mkdir)(struct kernfs_node___239 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___239 *);
	int (*rename)(struct kernfs_node___239 *, struct kernfs_node___239 *, const char *);
	int (*show_path)(struct seq_file___221 *, struct kernfs_node___239 *, struct kernfs_root___239 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___239 {
	struct kernfs_node___239 *kn;
	struct file___245 *file;
	struct seq_file___221 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___235 *vm_ops;
};

struct kobj_ns_type_operations___20 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___22 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___210;

struct attribute_group___211 {
	const char *name;
	umode_t (*is_visible)(struct kobject___233 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___233 *, struct bin_attribute___210 *, int);
	struct attribute **attrs;
	struct bin_attribute___210 **bin_attrs;
};

struct bin_attribute___210 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___245 *, struct kobject___233 *, struct bin_attribute___210 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___245 *, struct kobject___233 *, struct bin_attribute___210 *, char *, loff_t, size_t);
	int (*mmap)(struct file___245 *, struct kobject___233 *, struct bin_attribute___210 *, struct vm_area_struct___246 *);
};

struct sysfs_ops___232 {
	ssize_t (*show)(struct kobject___233 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___233 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___232;

struct kset___232 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___233 kobj;
	const struct kset_uevent_ops___232 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___232 {
	void (*release)(struct kobject___233 *);
	const struct sysfs_ops___232 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___20 * (*child_ns_type)(struct kobject___233 *);
	const void * (*namespace)(struct kobject___233 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___232 {
	int (* const filter)(struct kset___232 *, struct kobject___233 *);
	const char * (* const name)(struct kset___232 *, struct kobject___233 *);
	int (* const uevent)(struct kset___232 *, struct kobject___233 *, struct kobj_uevent_env *);
};

struct kobj_attribute___226 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___233 *, struct kobj_attribute___226 *, char *);
	ssize_t (*store)(struct kobject___233 *, struct kobj_attribute___226 *, const char *, size_t);
};

struct dev_pm_ops___209 {
	int (*prepare)(struct device___209 *);
	void (*complete)(struct device___209 *);
	int (*suspend)(struct device___209 *);
	int (*resume)(struct device___209 *);
	int (*freeze)(struct device___209 *);
	int (*thaw)(struct device___209 *);
	int (*poweroff)(struct device___209 *);
	int (*restore)(struct device___209 *);
	int (*suspend_late)(struct device___209 *);
	int (*resume_early)(struct device___209 *);
	int (*freeze_late)(struct device___209 *);
	int (*thaw_early)(struct device___209 *);
	int (*poweroff_late)(struct device___209 *);
	int (*restore_early)(struct device___209 *);
	int (*suspend_noirq)(struct device___209 *);
	int (*resume_noirq)(struct device___209 *);
	int (*freeze_noirq)(struct device___209 *);
	int (*thaw_noirq)(struct device___209 *);
	int (*poweroff_noirq)(struct device___209 *);
	int (*restore_noirq)(struct device___209 *);
	int (*runtime_suspend)(struct device___209 *);
	int (*runtime_resume)(struct device___209 *);
	int (*runtime_idle)(struct device___209 *);
};

struct dev_pm_domain___209 {
	struct dev_pm_ops___209 ops;
	void (*detach)(struct device___209 *, bool);
	int (*activate)(struct device___209 *);
	void (*sync)(struct device___209 *);
	void (*dismiss)(struct device___209 *);
};

struct bus_type___209 {
	const char *name;
	const char *dev_name;
	struct device___209 *dev_root;
	const struct attribute_group___211 **bus_groups;
	const struct attribute_group___211 **dev_groups;
	const struct attribute_group___211 **drv_groups;
	int (*match)(struct device___209 *, struct device_driver___209 *);
	int (*uevent)(struct device___209 *, struct kobj_uevent_env *);
	int (*probe)(struct device___209 *);
	int (*remove)(struct device___209 *);
	void (*shutdown)(struct device___209 *);
	int (*online)(struct device___209 *);
	int (*offline)(struct device___209 *);
	int (*suspend)(struct device___209 *, pm_message_t);
	int (*resume)(struct device___209 *);
	int (*num_vf)(struct device___209 *);
	int (*dma_configure)(struct device___209 *);
	const struct dev_pm_ops___209 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___209 {
	const char *name;
	struct bus_type___209 *bus;
	struct module___199 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___209 *);
	int (*remove)(struct device___209 *);
	void (*shutdown)(struct device___209 *);
	int (*suspend)(struct device___209 *, pm_message_t);
	int (*resume)(struct device___209 *);
	const struct attribute_group___211 **groups;
	const struct dev_pm_ops___209 *pm;
	void (*coredump)(struct device___209 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___209 {
	const char *name;
	const struct attribute_group___211 **groups;
	int (*uevent)(struct device___209 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___209 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___209 *);
	const struct dev_pm_ops___209 *pm;
};

struct class___209 {
	const char *name;
	struct module___199 *owner;
	const struct attribute_group___211 **class_groups;
	const struct attribute_group___211 **dev_groups;
	struct kobject___233 *dev_kobj;
	int (*dev_uevent)(struct device___209 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___209 *, umode_t *);
	void (*class_release)(struct class___209 *);
	void (*dev_release)(struct device___209 *);
	int (*shutdown_pre)(struct device___209 *);
	const struct kobj_ns_type_operations___20 *ns_type;
	const void * (*namespace)(struct device___209 *);
	const struct dev_pm_ops___209 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___52 {
	void * (*alloc)(struct device___209 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___209 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___209 *, struct vm_area_struct___246 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___209 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___209 *, struct page___246 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___209 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___209 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___209 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___209 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___209 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___209 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___209 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___209 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___209 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___209 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___209 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___209 *, u64);
	u64 (*get_required_mask)(struct device___209 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___144;

struct fwnode_handle___144 {
	struct fwnode_handle___144 *secondary;
	const struct fwnode_operations___144 *ops;
};

typedef void compound_page_dtor___235(struct page___246 *);

struct fwnode_reference_args___144;

struct fwnode_endpoint___144;

struct fwnode_operations___144 {
	struct fwnode_handle___144 * (*get)(struct fwnode_handle___144 *);
	void (*put)(struct fwnode_handle___144 *);
	bool (*device_is_available)(const struct fwnode_handle___144 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___144 *, const struct device___209 *);
	bool (*property_present)(const struct fwnode_handle___144 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___144 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___144 *, const char *, const char **, size_t);
	struct fwnode_handle___144 * (*get_parent)(const struct fwnode_handle___144 *);
	struct fwnode_handle___144 * (*get_next_child_node)(const struct fwnode_handle___144 *, struct fwnode_handle___144 *);
	struct fwnode_handle___144 * (*get_named_child_node)(const struct fwnode_handle___144 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___144 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___144 *);
	struct fwnode_handle___144 * (*graph_get_next_endpoint)(const struct fwnode_handle___144 *, struct fwnode_handle___144 *);
	struct fwnode_handle___144 * (*graph_get_remote_endpoint)(const struct fwnode_handle___144 *);
	struct fwnode_handle___144 * (*graph_get_port_parent)(struct fwnode_handle___144 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___144 *, struct fwnode_endpoint___144 *);
};

struct fwnode_endpoint___144 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___144 *local_fwnode;
};

struct fwnode_reference_args___144 {
	struct fwnode_handle___144 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___55;

struct pipe_buffer___55 {
	struct page___246 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___55 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___55 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___55 *, struct pipe_buffer___55 *);
	void (*release)(struct pipe_inode_info___55 *, struct pipe_buffer___55 *);
	int (*steal)(struct pipe_inode_info___55 *, struct pipe_buffer___55 *);
	union {
		bool (*get)(struct pipe_inode_info___55 *, struct pipe_buffer___55 *);
		struct {
			void (*get)(struct pipe_inode_info___55 *, struct pipe_buffer___55 *);
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
};

struct nf_bridge_info___31 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___31 = 0,
		BRNF_PROTO_8021Q___31 = 1,
		BRNF_PROTO_PPPOE___31 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___35 *physindev;
	struct net_device___35 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

struct ucounts___205 {
	struct hlist_node node;
	struct user_namespace___205 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_prog_aux___32;

struct bpf_prog___30 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___32 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

typedef int (*key_restrict_link_func_t___238)(struct key___238 *, const struct key_type *, const union key_payload *, struct key___238 *);

struct key_restriction___238;

struct key___238 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___246 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key___5 index_key;
		struct {
			struct key_type___5 *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___238 *restrict_link;
};

struct key_restriction___238 {
	key_restrict_link_func_t___238 check;
	struct key___238 *key;
	struct key_type *keytype;
};

struct seq_operations___219 {
	void * (*start)(struct seq_file___221 *, loff_t *);
	void (*stop)(struct seq_file___221 *, void *);
	void * (*next)(struct seq_file___221 *, void *, loff_t *);
	int (*show)(struct seq_file___221 *, void *);
};

struct pernet_operations___32 {
	struct list_head list;
	int (*init)(struct net___43 *);
	void (*exit)(struct net___43 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct cgroup_namespace___190 {
	refcount_t count;
	struct ns_common___28 ns;
	struct user_namespace___205 *user_ns;
	struct ucounts___205 *ucounts;
	struct css_set___190 *root_cset;
};

struct ethtool_ops___31 {
	int (*get_settings)(struct net_device___35 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___35 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___35 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___35 *);
	void (*get_regs)(struct net_device___35 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___35 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___35 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___35 *);
	void (*set_msglevel)(struct net_device___35 *, u32);
	int (*nway_reset)(struct net_device___35 *);
	u32 (*get_link)(struct net_device___35 *);
	int (*get_eeprom_len)(struct net_device___35 *);
	int (*get_eeprom)(struct net_device___35 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___35 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___35 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___35 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___35 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___35 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___35 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___35 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___35 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___35 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___35 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___35 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___35 *);
	void (*complete)(struct net_device___35 *);
	u32 (*get_priv_flags)(struct net_device___35 *);
	int (*set_priv_flags)(struct net_device___35 *, u32);
	int (*get_sset_count)(struct net_device___35 *, int);
	int (*get_rxnfc)(struct net_device___35 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___35 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___35 *, struct ethtool_flash *);
	int (*reset)(struct net_device___35 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___35 *);
	u32 (*get_rxfh_indir_size)(struct net_device___35 *);
	int (*get_rxfh)(struct net_device___35 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___35 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___35 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___35 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___35 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___35 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___35 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___35 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___35 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___35 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___35 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___35 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___35 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___35 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___35 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___35 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___35 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___35 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___35 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___35 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___35 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___35 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	int (*get_fecparam)(struct net_device___35 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___35 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___35 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___35 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___35 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct dcbnl_rtnl_ops___31 {
	int (*ieee_getets)(struct net_device___35 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___35 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___35 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___35 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___35 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___35 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___35 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___35 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___35 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___35 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___35 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___35 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___35 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___35 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___35 *);
	u8 (*setstate)(struct net_device___35 *, u8);
	void (*getpermhwaddr)(struct net_device___35 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___35 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___35 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___35 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___35 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___35 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___35 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___35 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___35 *, int, u8 *);
	void (*setpfccfg)(struct net_device___35 *, int, u8);
	void (*getpfccfg)(struct net_device___35 *, int, u8 *);
	u8 (*setall)(struct net_device___35 *);
	u8 (*getcap)(struct net_device___35 *, int, u8 *);
	int (*getnumtcs)(struct net_device___35 *, int, u8 *);
	int (*setnumtcs)(struct net_device___35 *, int, u8);
	u8 (*getpfcstate)(struct net_device___35 *);
	void (*setpfcstate)(struct net_device___35 *, u8);
	void (*getbcncfg)(struct net_device___35 *, int, u32 *);
	void (*setbcncfg)(struct net_device___35 *, int, u32);
	void (*getbcnrp)(struct net_device___35 *, int, u8 *);
	void (*setbcnrp)(struct net_device___35 *, int, u8);
	int (*setapp)(struct net_device___35 *, u8, u16, u8);
	int (*getapp)(struct net_device___35 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___35 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___35 *, int, u8);
	u8 (*getdcbx)(struct net_device___35 *);
	u8 (*setdcbx)(struct net_device___35 *, u8);
	int (*peer_getappinfo)(struct net_device___35 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___35 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___35 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___35 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___35 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___35 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct bpf_map___190;

struct bpf_map_ops___190 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___190 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___190 *, struct file___245 *);
	void (*map_free)(struct bpf_map___190 *);
	int (*map_get_next_key)(struct bpf_map___190 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___190 *);
	void * (*map_lookup_elem)(struct bpf_map___190 *, void *);
	int (*map_update_elem)(struct bpf_map___190 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___190 *, void *);
	int (*map_push_elem)(struct bpf_map___190 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___190 *, void *);
	int (*map_peek_elem)(struct bpf_map___190 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___190 *, struct file___245 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___190 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___190 *, void *, struct seq_file___221 *);
	int (*map_check_btf)(const struct bpf_map___190 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___190 {
	const struct bpf_map_ops___190 *ops;
	struct bpf_map___190 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___238 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___31;

struct bpf_map_dev_ops___31 {
	int (*map_get_next_key)(struct bpf_offloaded_map___31 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___31 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___31 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___31 *, void *);
};

struct bpf_offloaded_map___31 {
	struct bpf_map___190 map;
	struct net_device___35 *netdev;
	const struct bpf_map_dev_ops___31 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___30 {
	int (*test_run)(struct bpf_prog___30 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___30 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___30 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___30 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___30 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___30 *, u32 *);
};

struct bpf_prog_offload_ops___30 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___30 *);
	int (*translate)(struct bpf_prog___30 *);
	void (*destroy)(struct bpf_prog___30 *);
};

struct bpf_prog_offload___30 {
	struct bpf_prog___30 *prog;
	struct net_device___35 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___30 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___32 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___30 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___30 *ops;
	struct bpf_map___190 **used_maps;
	struct bpf_prog___30 *prog;
	struct user_struct___238 *user;
	u64 load_time;
	struct bpf_map___190 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___30 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___30 {
	struct bpf_prog___30 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___30 {
	struct callback_head rcu;
	struct bpf_prog_array_item___30 items[0];
};

struct cgroup_bpf___30 {
	struct bpf_prog_array___30 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___30 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___190;

typedef void (*kthread_work_func_t___190)(struct kthread_work___190 *);

struct kthread_worker___190;

struct kthread_work___190 {
	struct list_head node;
	kthread_work_func_t___190 func;
	struct kthread_worker___190 *worker;
	int canceling;
};

struct kthread_worker___190 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___246 *task;
	struct kthread_work___190 *current_work;
};

struct kthread_delayed_work___190 {
	struct kthread_work___190 work;
	struct timer_list timer;
};

struct psi_group___190 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___190 *poll_kworker;
	struct kthread_delayed_work___190 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___190;

struct cgroup_rstat_cpu___190;

struct cgroup___190 {
	struct cgroup_subsys_state___191 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___239 *kn;
	struct cgroup_file___190 procs_file;
	struct cgroup_file___190 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___191 *subsys[13];
	struct cgroup_root___190 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___190 *dom_cgrp;
	struct cgroup_rstat_cpu___190 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___30 bpf;
	atomic_t congestion_count;
	struct cgroup___190 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___190 psi;
	int ancestor_ids[0];
};

struct cftype___190;

struct cgroup_subsys___190 {
	struct cgroup_subsys_state___191 * (*css_alloc)(struct cgroup_subsys_state___191 *);
	int (*css_online)(struct cgroup_subsys_state___191 *);
	void (*css_offline)(struct cgroup_subsys_state___191 *);
	void (*css_released)(struct cgroup_subsys_state___191 *);
	void (*css_free)(struct cgroup_subsys_state___191 *);
	void (*css_reset)(struct cgroup_subsys_state___191 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___191 *, int);
	int (*css_extra_stat_show)(struct seq_file___221 *, struct cgroup_subsys_state___191 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___246 *);
	void (*cancel_fork)(struct task_struct___246 *);
	void (*fork)(struct task_struct___246 *);
	void (*exit)(struct task_struct___246 *);
	void (*free)(struct task_struct___246 *);
	void (*bind)(struct cgroup_subsys_state___191 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___190 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___190 *dfl_cftypes;
	struct cftype___190 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___190 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___190 *updated_children;
	struct cgroup___190 *updated_next;
};

struct cgroup_root___190 {
	struct kernfs_root___239 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___190 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___190 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___190 *ss;
	struct list_head node;
	struct kernfs_ops___239 *kf_ops;
	int (*open)(struct kernfs_open_file___239 *);
	void (*release)(struct kernfs_open_file___239 *);
	u64 (*read_u64)(struct cgroup_subsys_state___191 *, struct cftype___190 *);
	s64 (*read_s64)(struct cgroup_subsys_state___191 *, struct cftype___190 *);
	int (*seq_show)(struct seq_file___221 *, void *);
	void * (*seq_start)(struct seq_file___221 *, loff_t *);
	void * (*seq_next)(struct seq_file___221 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___221 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___191 *, struct cftype___190 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___191 *, struct cftype___190 *, s64);
	ssize_t (*write)(struct kernfs_open_file___239 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___239 *, struct poll_table_struct___153 *);
};

struct xdp_rxq_info___31 {
	struct net_device___35 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___31 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___35 *dev_rx;
};

struct netlink_callback___31 {
	struct sk_buff___35 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___31 *);
	int (*dump)(struct sk_buff___35 *, struct netlink_callback___31 *);
	int (*done)(struct netlink_callback___31 *);
	void *data;
	struct module___199 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___31 {
	int (*create)(struct sk_buff___35 *, struct net_device___35 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___35 *, unsigned char *);
	int (*cache)(const struct neighbour___21 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___35 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___31 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___31 *, int);
	int poll_owner;
	struct net_device___35 *dev;
	struct sk_buff___35 *gro_list;
	struct sk_buff___35 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___31 {
	struct net_device___35 *dev;
	struct Qdisc___30 *qdisc;
	struct Qdisc___30 *qdisc_sleeping;
	struct kobject___233 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___35 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___30 {
	struct sk_buff___35 *head;
	struct sk_buff___35 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___30;

struct Qdisc___30 {
	int (*enqueue)(struct sk_buff___35 *, struct Qdisc___30 *, struct sk_buff___35 **);
	struct sk_buff___35 * (*dequeue)(struct Qdisc___30 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___30 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___31 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___31 gso_skb;
	struct qdisc_skb_head___30 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___30 *next_sched;
	struct sk_buff_head___31 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___31 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___233 kobj;
	struct net_device___35 *dev;
	long: 64;
	struct xdp_rxq_info___31 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___31)(struct net_device___35 *, struct sk_buff___35 *, struct net_device___35 *);

struct netdev_bpf___31 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___30 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___30 *prog;
			const struct bpf_prog_offload_ops___30 *ops;
		} verifier;
		struct {
			struct bpf_prog___30 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___31 *offmap;
		};
		struct {
			struct xdp_umem *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___31 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___35 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___31 {
	int (*tls_dev_add)(struct net_device___35 *, struct sock___22 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___35 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___35 *, struct sock___22 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___31 {
	int (*ndo_init)(struct net_device___35 *);
	void (*ndo_uninit)(struct net_device___35 *);
	int (*ndo_open)(struct net_device___35 *);
	int (*ndo_stop)(struct net_device___35 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___35 *, struct net_device___35 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___35 *, struct net_device___35 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___35 *, struct sk_buff___35 *, struct net_device___35 *, select_queue_fallback_t___31);
	void (*ndo_change_rx_flags)(struct net_device___35 *, int);
	void (*ndo_set_rx_mode)(struct net_device___35 *);
	int (*ndo_set_mac_address)(struct net_device___35 *, void *);
	int (*ndo_validate_addr)(struct net_device___35 *);
	int (*ndo_do_ioctl)(struct net_device___35 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___35 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___35 *, int);
	int (*ndo_neigh_setup)(struct net_device___35 *, struct neigh_parms___21 *);
	void (*ndo_tx_timeout)(struct net_device___35 *);
	void (*ndo_get_stats64)(struct net_device___35 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___35 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___35 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___35 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___35 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___35 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___35 *);
	int (*ndo_netpoll_setup)(struct net_device___35 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___35 *);
	int (*ndo_set_vf_mac)(struct net_device___35 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___35 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___35 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___35 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___35 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___35 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___35 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___35 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___35 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___35 *, int, struct sk_buff___35 *);
	int (*ndo_set_vf_guid)(struct net_device___35 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___35 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___35 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___35 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___35 *, const struct sk_buff___35 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___35 *, struct net_device___35 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___35 *, struct net_device___35 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___35 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___35 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___35 *, struct neighbour___21 *);
	void (*ndo_neigh_destroy)(struct net_device___35 *, struct neighbour___21 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___35 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___35 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___35 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___35 *, struct netlink_callback___31 *, struct net_device___35 *, struct net_device___35 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___35 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___35 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___35 *, u32, u32, struct net_device___35 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___35 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___35 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___35 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___35 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___35 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___35 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___35 *, struct net_device___35 *);
	void (*ndo_dfwd_del_station)(struct net_device___35 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___35 *);
	int (*ndo_set_tx_maxrate)(struct net_device___35 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___35 *);
	int (*ndo_change_proto_down)(struct net_device___35 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___35 *, struct sk_buff___35 *);
	void (*ndo_set_rx_headroom)(struct net_device___35 *, int);
	int (*ndo_bpf)(struct net_device___35 *, struct netdev_bpf___31 *);
	int (*ndo_xdp_xmit)(struct net_device___35 *, int, struct xdp_frame___31 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___35 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___35 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___21 {
	possible_net_t___32 net;
	struct net_device___35 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___21 *);
	void (*neigh_cleanup)(struct neighbour___21 *);
	struct neigh_table___20 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___21 {
	u32 (*l3mdev_fib_table)(const struct net_device___35 *);
	struct sk_buff___35 * (*l3mdev_l3_rcv)(struct net_device___35 *, struct sk_buff___35 *, u16);
	struct sk_buff___35 * (*l3mdev_l3_out)(struct net_device___35 *, struct sock___22 *, struct sk_buff___35 *, u16);
	struct dst_entry___21 * (*l3mdev_link_scope_lookup)(const struct net_device___35 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct ndisc_ops___13 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___35 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___35 *, struct neighbour___21 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___35 *, u8, struct neighbour___21 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___35 *, struct sk_buff___35 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___43 *, struct net_device___35 *, const struct prefix_info *, struct inet6_dev___13 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___12;

struct inet6_dev___13 {
	struct net_device___35 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___12 *mc_list;
	struct ifmcaddr6___12 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	u8 rndid[8];
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___21 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
};

struct tcf_proto___30;

struct mini_Qdisc___30 {
	struct tcf_proto___30 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___30 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___35 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___43 *, struct net_device___35 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___35 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___35 *, struct list_head *);
	size_t (*get_size)(const struct net_device___35 *);
	int (*fill_info)(struct sk_buff___35 *, const struct net_device___35 *);
	size_t (*get_xstats_size)(const struct net_device___35 *);
	int (*fill_xstats)(struct sk_buff___35 *, const struct net_device___35 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___35 *, struct net_device___35 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___35 *, const struct net_device___35 *);
	int (*fill_slave_info)(struct sk_buff___35 *, const struct net_device___35 *, const struct net_device___35 *);
	struct net___43 * (*get_link_net)(const struct net_device___35 *);
	size_t (*get_linkxstats_size)(const struct net_device___35 *, int);
	int (*fill_linkxstats)(struct sk_buff___35 *, const struct net_device___35 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___31 {
	struct list_head poll_list;
	struct sk_buff_head___31 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___31 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___30 *output_queue;
	struct Qdisc___30 **output_queue_tailp;
	struct sk_buff___35 *completion_queue;
	struct sk_buff_head___31 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___31 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___31 input_pkt_queue;
	struct napi_struct___31 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bdi_writeback_congested___121 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___121 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___121 {
	struct bio___121 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___121 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___121 bip_inline_vecs[0];
};

struct bio_set___121 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___121 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___106 {
	struct mem_cgroup___106 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___106 {
	struct lruvec___245 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___106 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___106 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct kernel_param_ops___196 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___196 *);
	int (*get)(char *, const struct kernel_param___196 *);
	void (*free)(void *);
};

struct kparam_array___196;

struct kernel_param___196 {
	const char *name;
	struct module___199 *mod;
	const struct kernel_param_ops___196 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___196 *arr;
	};
};

struct kparam_array___196 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___196 *ops;
	void *elem;
};

struct module_attribute___196 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___196 *, struct module_kobject___196 *, char *);
	ssize_t (*store)(struct module_attribute___196 *, struct module_kobject___196 *, const char *, size_t);
	void (*setup)(struct module___199 *, const char *);
	int (*test)(struct module___199 *);
	void (*free)(struct module___199 *);
};

struct gnet_dump___30 {
	spinlock_t *lock;
	struct sk_buff___35 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___30;

struct Qdisc_ops___30 {
	struct Qdisc_ops___30 *next;
	const struct Qdisc_class_ops___30 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___35 *, struct Qdisc___30 *, struct sk_buff___35 **);
	struct sk_buff___35 * (*dequeue)(struct Qdisc___30 *);
	struct sk_buff___35 * (*peek)(struct Qdisc___30 *);
	int (*init)(struct Qdisc___30 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___30 *);
	void (*destroy)(struct Qdisc___30 *);
	int (*change)(struct Qdisc___30 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___30 *);
	int (*change_tx_queue_len)(struct Qdisc___30 *, unsigned int);
	int (*dump)(struct Qdisc___30 *, struct sk_buff___35 *);
	int (*dump_stats)(struct Qdisc___30 *, struct gnet_dump___30 *);
	void (*ingress_block_set)(struct Qdisc___30 *, u32);
	void (*egress_block_set)(struct Qdisc___30 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___30 *);
	u32 (*egress_block_get)(struct Qdisc___30 *);
	struct module___199 *owner;
};

struct tcf_block___30;

struct Qdisc_class_ops___30 {
	unsigned int flags;
	struct netdev_queue___31 * (*select_queue)(struct Qdisc___30 *, struct tcmsg *);
	int (*graft)(struct Qdisc___30 *, long unsigned int, struct Qdisc___30 *, struct Qdisc___30 **, struct netlink_ext_ack *);
	struct Qdisc___30 * (*leaf)(struct Qdisc___30 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___30 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___30 *, u32);
	int (*change)(struct Qdisc___30 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___30 *, long unsigned int);
	void (*walk)(struct Qdisc___30 *, struct qdisc_walker *);
	struct tcf_block___30 * (*tcf_block)(struct Qdisc___30 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___30 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___30 *, long unsigned int);
	int (*dump)(struct Qdisc___30 *, long unsigned int, struct sk_buff___35 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___30 *, long unsigned int, struct gnet_dump___30 *);
};

struct tcf_chain___30;

struct tcf_block___30 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___43 *net;
	struct Qdisc___30 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___30 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___30;

struct tcf_proto_ops___30;

struct tcf_proto___30 {
	struct tcf_proto___30 *next;
	void *root;
	int (*classify)(struct sk_buff___35 *, const struct tcf_proto___30 *, struct tcf_result___30 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___30 *ops;
	struct tcf_chain___30 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___30 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___30 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___30 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___35 *, const struct tcf_proto___30 *, struct tcf_result___30 *);
	int (*init)(struct tcf_proto___30 *);
	void (*destroy)(struct tcf_proto___30 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___30 *, u32);
	void (*put)(struct tcf_proto___30 *, void *);
	int (*change)(struct net___43 *, struct sk_buff___35 *, struct tcf_proto___30 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___30 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___30 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___30 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___43 *, struct tcf_chain___30 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___43 *, struct tcf_proto___30 *, void *, struct sk_buff___35 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___35 *, struct net___43 *, void *);
	struct module___199 *owner;
	int flags;
};

struct tcf_chain___30 {
	struct mutex filter_chain_lock;
	struct tcf_proto___30 *filter_chain;
	struct list_head list;
	struct tcf_block___30 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___30 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___20 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___30 *prog;
};

struct bpf_redirect_info___30 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___190 *map;
	struct bpf_map___190 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___20;

struct neigh_hash_table___20;

struct neigh_table___20 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___35 *, __u32 *);
	bool (*key_eq)(const struct neighbour___21 *, const void *);
	int (*constructor)(struct neighbour___21 *);
	int (*pconstructor)(struct pneigh_entry___20 *);
	void (*pdestructor)(struct pneigh_entry___20 *);
	void (*proxy_redo)(struct sk_buff___35 *);
	char *id;
	struct neigh_parms___21 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___31 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___20 *nht;
	struct pneigh_entry___20 **phash_buckets;
};

struct neigh_ops___20 {
	int family;
	void (*solicit)(struct neighbour___21 *, struct sk_buff___35 *);
	void (*error_report)(struct neighbour___21 *, struct sk_buff___35 *);
	int (*output)(struct neighbour___21 *, struct sk_buff___35 *);
	int (*connected_output)(struct neighbour___21 *, struct sk_buff___35 *);
};

struct pneigh_entry___20 {
	struct pneigh_entry___20 *next;
	possible_net_t___32 net;
	struct net_device___35 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___20 {
	struct neighbour___21 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___20 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___20 *ctarget;
	struct net___43 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___20 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___20 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___13;

struct timewait_sock_ops___13;

struct proto___20 {
	void (*close)(struct sock___22 *, long int);
	int (*pre_connect)(struct sock___22 *, struct sockaddr *, int);
	int (*connect)(struct sock___22 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___22 *, int);
	struct sock___22 * (*accept)(struct sock___22 *, int, int *, bool);
	int (*ioctl)(struct sock___22 *, int, long unsigned int);
	int (*init)(struct sock___22 *);
	void (*destroy)(struct sock___22 *);
	void (*shutdown)(struct sock___22 *, int);
	int (*setsockopt)(struct sock___22 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___22 *, int, int, char *, int *);
	void (*keepalive)(struct sock___22 *, int);
	int (*sendmsg)(struct sock___22 *, struct msghdr___22 *, size_t);
	int (*recvmsg)(struct sock___22 *, struct msghdr___22 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___22 *, struct page___246 *, int, size_t, int);
	int (*bind)(struct sock___22 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___22 *, struct sk_buff___35 *);
	void (*release_cb)(struct sock___22 *);
	int (*hash)(struct sock___22 *);
	void (*unhash)(struct sock___22 *);
	void (*rehash)(struct sock___22 *);
	int (*get_port)(struct sock___22 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___22 *);
	bool (*stream_memory_read)(const struct sock___22 *);
	void (*enter_memory_pressure)(struct sock___22 *);
	void (*leave_memory_pressure)(struct sock___22 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___13 *rsk_prot;
	struct timewait_sock_ops___13 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___199 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___22 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct request_sock___13;

struct request_sock_ops___13 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___22 *, struct request_sock___13 *);
	void (*send_ack)(const struct sock___22 *, struct sk_buff___35 *, struct request_sock___13 *);
	void (*send_reset)(const struct sock___22 *, struct sk_buff___35 *);
	void (*destructor)(struct request_sock___13 *);
	void (*syn_ack_timeout)(const struct request_sock___13 *);
};

struct timewait_sock_ops___13 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___22 *, struct sock___22 *, void *);
	void (*twsk_destructor)(struct sock___22 *);
};

struct request_sock___13 {
	struct sock_common___20 __req_common;
	struct request_sock___13 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___13 *rsk_ops;
	struct sock___22 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___12 {
	struct in6_addr mca_addr;
	struct inet6_dev___13 *idev;
	struct ifmcaddr6___12 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ip6_ra_chain___12 {
	struct ip6_ra_chain___12 *next;
	struct sock___22 *sk;
	int sel;
	void (*destructor)(struct sock___22 *);
};

struct pkey_security_struct {
	u64 subnet_prefix;
	u16 pkey;
	u32 sid;
};

struct sel_ib_pkey_bkt {
	int size;
	struct list_head list;
};

struct sel_ib_pkey {
	struct pkey_security_struct psec;
	struct list_head list;
	struct callback_head rcu;
};

struct path___245;

struct request_sock___14;

struct request_sock_ops___3 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___19 *, struct request_sock___14 *);
	void (*send_ack)(const struct sock___19 *, struct sk_buff___32 *, struct request_sock___14 *);
	void (*send_reset)(const struct sock___19 *, struct sk_buff___32 *);
	void (*destructor)(struct request_sock___14 *);
	void (*syn_ack_timeout)(const struct request_sock___14 *);
};

struct request_sock___14 {
	struct sock_common___17 __req_common;
	struct request_sock___14 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___3 *rsk_ops;
	struct sock___19 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ebitmap_node {
	struct ebitmap_node *next;
	long unsigned int maps[6];
	u32 startbit;
};

struct ebitmap {
	struct ebitmap_node *node;
	u32 highbit;
};

struct policy_file {
	char *data;
	size_t len;
};

struct hashtab_node {
	void *key;
	void *datum;
	struct hashtab_node *next;
};

struct hashtab {
	struct hashtab_node **htable;
	u32 size;
	u32 nel;
	u32 (*hash_value)(struct hashtab *, const void *);
	int (*keycmp)(struct hashtab *, const void *, const void *);
};

struct hashtab_info {
	u32 slots_used;
	u32 max_chain_len;
};

struct symtab {
	struct hashtab *table;
	u32 nprim;
};

struct mls_level {
	u32 sens;
	struct ebitmap cat;
};

struct mls_range {
	struct mls_level level[2];
};

struct context {
	u32 user;
	u32 role;
	u32 type;
	u32 len;
	struct mls_range range;
	char *str;
};

struct sidtab_entry_leaf {
	struct context context;
};

struct sidtab_node_inner;

struct sidtab_node_leaf;

union sidtab_entry_inner {
	struct sidtab_node_inner *ptr_inner;
	struct sidtab_node_leaf *ptr_leaf;
};

struct sidtab_node_inner {
	union sidtab_entry_inner entries[8192];
};

struct sidtab_node_leaf {
	struct sidtab_entry_leaf entries[910];
};

struct sidtab_isid_entry {
	int set;
	struct context context;
};

struct sidtab;

struct sidtab_convert_params {
	int (*func)(struct context *, struct context *, void *);
	void *args;
	struct sidtab *target;
};

struct sidtab {
	union sidtab_entry_inner roots[3];
	atomic_t count;
	struct sidtab_convert_params *convert;
	spinlock_t lock;
	atomic_t rcache[3];
	struct sidtab_isid_entry isids[27];
};

typedef u16 uint16_t;

struct avtab_key {
	u16 source_type;
	u16 target_type;
	u16 target_class;
	u16 specified;
};

struct avtab_extended_perms {
	u8 specified;
	u8 driver;
	struct extended_perms_data perms;
};

struct avtab_datum {
	union {
		u32 data;
		struct avtab_extended_perms *xperms;
	} u;
};

struct avtab_node {
	struct avtab_key key;
	struct avtab_datum datum;
	struct avtab_node *next;
};

struct avtab {
	struct flex_array *htable;
	u32 nel;
	u32 nslot;
	u32 mask;
};

struct type_set;

struct constraint_expr {
	u32 expr_type;
	u32 attr;
	u32 op;
	struct ebitmap names;
	struct type_set *type_names;
	struct constraint_expr *next;
};

struct type_set {
	struct ebitmap types;
	struct ebitmap negset;
	u32 flags;
};

struct constraint_node {
	u32 permissions;
	struct constraint_expr *expr;
	struct constraint_node *next;
};

struct common_datum {
	u32 value;
	struct symtab permissions;
};

struct class_datum {
	u32 value;
	char *comkey;
	struct common_datum *comdatum;
	struct symtab permissions;
	struct constraint_node *constraints;
	struct constraint_node *validatetrans;
	char default_user;
	char default_role;
	char default_type;
	char default_range;
};

struct role_datum {
	u32 value;
	u32 bounds;
	struct ebitmap dominates;
	struct ebitmap types;
};

struct role_trans {
	u32 role;
	u32 type;
	u32 tclass;
	u32 new_role;
	struct role_trans *next;
};

struct role_allow {
	u32 role;
	u32 new_role;
	struct role_allow *next;
};

struct user_datum {
	u32 value;
	u32 bounds;
	struct ebitmap roles;
	struct mls_range range;
	struct mls_level dfltlevel;
};

struct cond_bool_datum {
	__u32 value;
	int state;
};

struct ocontext {
	union {
		char *name;
		struct {
			u8 protocol;
			u16 low_port;
			u16 high_port;
		} port;
		struct {
			u32 addr;
			u32 mask;
		} node;
		struct {
			u32 addr[4];
			u32 mask[4];
		} node6;
		struct {
			u64 subnet_prefix;
			u16 low_pkey;
			u16 high_pkey;
		} ibpkey;
		struct {
			char *dev_name;
			u8 port;
		} ibendport;
	} u;
	union {
		u32 sclass;
		u32 behavior;
	} v;
	struct context context[2];
	u32 sid[2];
	struct ocontext *next;
};

struct genfs {
	char *fstype;
	struct ocontext *head;
	struct genfs *next;
};

struct cond_node;

struct policydb {
	int mls_enabled;
	struct symtab symtab[8];
	struct flex_array *sym_val_to_name[8];
	struct class_datum **class_val_to_struct;
	struct role_datum **role_val_to_struct;
	struct user_datum **user_val_to_struct;
	struct flex_array *type_val_to_struct_array;
	struct avtab te_avtab;
	struct role_trans *role_tr;
	struct ebitmap filename_trans_ttypes;
	struct hashtab *filename_trans;
	struct cond_bool_datum **bool_val_to_struct;
	struct avtab te_cond_avtab;
	struct cond_node *cond_list;
	struct role_allow *role_allow;
	struct ocontext *ocontexts[9];
	struct genfs *genfs;
	struct hashtab *range_tr;
	struct flex_array *type_attr_map_array;
	struct ebitmap policycaps;
	struct ebitmap permissive_map;
	size_t len;
	unsigned int policyvers;
	unsigned int reject_unknown: 1;
	unsigned int allow_unknown: 1;
	u16 process_class;
	u32 process_trans_perms;
};

struct module___200;

struct file___246;

struct kiocb___246;

struct iov_iter___113;

struct poll_table_struct___154;

struct vm_area_struct___247;

struct inode___246;

struct file_lock___246;

struct page___247;

struct pipe_inode_info___56;

struct seq_file___222;

struct file_operations___246 {
	struct module___200 *owner;
	loff_t (*llseek)(struct file___246 *, loff_t, int);
	ssize_t (*read)(struct file___246 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___246 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___246 *, struct iov_iter___113 *);
	ssize_t (*write_iter)(struct kiocb___246 *, struct iov_iter___113 *);
	int (*iopoll)(struct kiocb___246 *, bool);
	int (*iterate)(struct file___246 *, struct dir_context *);
	int (*iterate_shared)(struct file___246 *, struct dir_context *);
	__poll_t (*poll)(struct file___246 *, struct poll_table_struct___154 *);
	long int (*unlocked_ioctl)(struct file___246 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___246 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___246 *, struct vm_area_struct___247 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___246 *, struct file___246 *);
	int (*flush)(struct file___246 *, fl_owner_t);
	int (*release)(struct inode___246 *, struct file___246 *);
	int (*fsync)(struct file___246 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___246 *, int);
	int (*lock)(struct file___246 *, int, struct file_lock___246 *);
	ssize_t (*sendpage)(struct file___246 *, struct page___247 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___246 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___246 *, int, struct file_lock___246 *);
	ssize_t (*splice_write)(struct pipe_inode_info___56 *, struct file___246 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___246 *, loff_t *, struct pipe_inode_info___56 *, size_t, unsigned int);
	int (*setlease)(struct file___246 *, long int, struct file_lock___246 **, void **);
	long int (*fallocate)(struct file___246 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___222 *, struct file___246 *);
	ssize_t (*copy_file_range)(struct file___246 *, loff_t, struct file___246 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___246 *, loff_t, struct file___246 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___246 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___246 {
	u64 seqnum;
	struct vm_area_struct___247 *vmas[4];
};

struct page_frag___246 {
	struct page___247 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___246;

struct mem_cgroup___107;

struct pid___186;

struct cred___239;

struct nsproxy___226;

struct signal_struct___204;

struct bio_list___122;

struct backing_dev_info___122;

struct css_set___191;

struct vm_struct___163;

struct task_struct___247 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___247 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___246 *mm;
	struct mm_struct___246 *active_mm;
	struct vmacache___246 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___247 *real_parent;
	struct task_struct___247 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___247 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___107 *active_memcg;
	long int rh_reserved2;
	struct pid___186 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___186 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___186 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___239 *ptracer_cred;
	const struct cred___239 *real_cred;
	const struct cred___239 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___226 *nsproxy;
	struct signal_struct___204 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___247 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___122 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___122 *backing_dev_info;
	struct io_context___60 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___191 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___56 *splice_pipe;
	struct page_frag___246 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___107 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___247 *oom_reaper_list;
	struct vm_struct___163 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___127 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___186;

struct upid___186 {
	int nr;
	struct pid_namespace___186 *ns;
};

struct dentry___246;

struct user_namespace___206;

struct ucounts___206;

struct pid_namespace___186 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___247 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___186 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___246 *proc_self;
	struct dentry___246 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___206 *user_ns;
	struct ucounts___206 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___28 ns;
};

struct pid___186 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___186 numbers[1];
};

struct rw_semaphore___247 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___247 *owner;
};

struct key___239;

struct user_namespace___206 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___206 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___28 ns;
	long unsigned int flags;
	struct key___239 *persistent_keyring_register;
	struct rw_semaphore___247 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___206 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct secondary_data___247 {
	void *stack;
	struct task_struct___247 *task;
	long int status;
};

typedef struct page___247 *pgtable_t___246;

struct address_space___245;

struct dev_pagemap___236;

struct page___247 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___245 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___247 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___246 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___246 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___236 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___107 *mem_cgroup;
};

struct user_struct___239 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___239 *uid_keyring;
	struct key___239 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___236;

struct vm_area_struct___247 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___247 *vm_next;
	struct vm_area_struct___247 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___246 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___236 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___246 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___246;

struct mm_struct___246 {
	struct {
		struct vm_area_struct___247 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___246 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___247 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___246 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___247 *owner;
		struct user_namespace___206 *user_ns;
		struct file___246 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___246 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup___191;

struct cgroup_subsys___191;

struct cgroup_subsys_state___192 {
	struct cgroup___191 *cgroup;
	struct cgroup_subsys___191 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___192 *parent;
};

struct kernfs_node___240;

struct cgroup_file___191 {
	struct kernfs_node___240 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___107;

struct mem_cgroup___107 {
	struct cgroup_subsys_state___192 css;
	struct mem_cgroup_id___16 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___191 events_file;
	struct cgroup_file___191 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___247 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___107 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cred___239 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___239 *session_keyring;
	struct key___239 *process_keyring;
	struct key___239 *thread_keyring;
	struct key___239 *request_key_auth;
	void *security;
	struct user_struct___239 *user;
	struct user_namespace___206 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___44;

struct cgroup_namespace___191;

struct nsproxy___226 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___186 *pid_ns_for_children;
	struct net___44 *net_ns;
	struct cgroup_namespace___191 *cgroup_ns;
};

struct signal_struct___204 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___247 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___247 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___186 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___186 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___246 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___186 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___122;

struct bio_list___122 {
	struct bio___122 *head;
	struct bio___122 *tail;
};

struct bdi_writeback_congested___122;

struct bdi_writeback___122 {
	struct backing_dev_info___122 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___122 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___192 *memcg_css;
	struct cgroup_subsys_state___192 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___210;

struct backing_dev_info___122 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___122 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___210 *dev;
	struct device___210 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___246 *debug_dir;
	struct dentry___246 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___191 {
	struct cgroup_subsys_state___192 *subsys[13];
	refcount_t refcount;
	struct css_set___191 *dom_cset;
	struct cgroup___191 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___191 *mg_src_cgrp;
	struct cgroup___191 *mg_dst_cgrp;
	struct css_set___191 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___245;

struct pipe_buffer___56;

struct pipe_inode_info___56 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___247 *tmp_page;
	struct fasync_struct___245 *fasync_readers;
	struct fasync_struct___245 *fasync_writers;
	struct pipe_buffer___56 *bufs;
	struct user_struct___239 *user;
};

struct vm_struct___163 {
	struct vm_struct___163 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___247 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___216 {
	struct task_struct___247 task;
	long unsigned int stack[8192];
};

struct pglist_data___246;

struct lruvec___246 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___246 *pgdat;
};

struct zone___246 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___246 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___246 {
	struct zone___246 *zone;
	int zone_idx;
};

struct zonelist___246 {
	struct zoneref___246 _zonerefs[25];
};

struct pglist_data___246 {
	struct zone___246 node_zones[3];
	struct zonelist___246 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___247 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___247 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___246 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___246 {
	struct rw_semaphore___247 rwsem;
	struct notifier_block *head;
};

typedef int (*key_restrict_link_func_t___239)(struct key___239 *, const struct key_type *, const union key_payload *, struct key___239 *);

struct key_restriction___239;

struct key___239 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___247 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key___5 index_key;
		struct {
			struct key_type___5 *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___239 *restrict_link;
};

struct key_restriction___239 {
	key_restrict_link_func_t___239 check;
	struct key___239 *key;
	struct key_type *keytype;
};

struct address_space_operations___245;

struct address_space___245 {
	struct inode___246 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___247 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___245 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___236)(struct vm_area_struct___247 *, long unsigned int, const struct page___247 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___236)(struct page___247 *, void *);

struct dev_pagemap___236 {
	dev_page_fault_t___236 page_fault;
	dev_page_free_t___236 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___210 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___246 {
	struct vfsmount *mnt;
	struct dentry___246 *dentry;
};

struct fown_struct___186 {
	rwlock_t lock;
	struct pid___186 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___246 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___246 f_path;
	struct inode___246 *f_inode;
	const struct file_operations___246 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___186 f_owner;
	const struct cred___239 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___245 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___236;

struct vm_operations_struct___236 {
	void (*open)(struct vm_area_struct___247 *);
	void (*close)(struct vm_area_struct___247 *);
	int (*split)(struct vm_area_struct___247 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___247 *);
	vm_fault_t (*fault)(struct vm_fault___236 *);
	vm_fault_t (*huge_fault)(struct vm_fault___236 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___236 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___247 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___236 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___236 *);
	int (*access)(struct vm_area_struct___247 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___247 *);
	int (*set_policy)(struct vm_area_struct___247 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___247 *, long unsigned int);
	struct page___247 * (*find_special_page)(struct vm_area_struct___247 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___246 {
	struct task_struct___247 *task;
	struct core_thread___246 *next;
};

struct core_state___246 {
	atomic_t nr_threads;
	struct core_thread___246 dumper;
	struct completion startup;
};

struct vm_fault___236 {
	struct vm_area_struct___247 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___247 *cow_page;
	struct mem_cgroup___107 *memcg;
	struct page___247 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___246 prealloc_pte;
};

struct shrink_control___107 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___107 *memcg;
};

struct shrinker___107 {
	long unsigned int (*count_objects)(struct shrinker___107 *, struct shrink_control___107 *);
	long unsigned int (*scan_objects)(struct shrinker___107 *, struct shrink_control___107 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct kset___233;

struct kobj_type___233;

struct kobject___234 {
	const char *name;
	struct list_head entry;
	struct kobject___234 *parent;
	struct kset___233 *kset;
	struct kobj_type___233 *ktype;
	struct kernfs_node___240 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___210 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___210 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___210;

struct bus_type___210;

struct device_driver___210;

struct dev_pm_domain___210;

struct dma_map_ops___53;

struct fwnode_handle___145;

struct class___210;

struct attribute_group___212;

struct device___210 {
	struct device___210 *parent;
	struct device_private *p;
	struct kobject___234 kobj;
	const char *init_name;
	const struct device_type___210 *type;
	struct mutex mutex;
	struct bus_type___210 *bus;
	struct device_driver___210 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___210 power;
	struct dev_pm_domain___210 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___53 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___145 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___210 *class;
	const struct attribute_group___212 **groups;
	void (*release)(struct device___210 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___245;

struct super_block___245;

struct dentry___246 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___246 *d_parent;
	struct qstr d_name;
	struct inode___246 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___245 *d_op;
	struct super_block___245 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___245;

struct block_device___246;

struct inode___246 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___245 *i_op;
	struct super_block___245 *i_sb;
	struct address_space___245 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___247 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___122 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___246 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___245 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___56 *i_pipe;
		struct block_device___246 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___245 {
	int (*d_revalidate)(struct dentry___246 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___246 *, unsigned int);
	int (*d_hash)(const struct dentry___246 *, struct qstr *);
	int (*d_compare)(const struct dentry___246 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___246 *);
	int (*d_init)(struct dentry___246 *);
	void (*d_release)(struct dentry___246 *);
	void (*d_prune)(struct dentry___246 *);
	void (*d_iput)(struct dentry___246 *, struct inode___246 *);
	char * (*d_dname)(struct dentry___246 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___246 *);
	int (*d_manage)(const struct path___246 *, bool);
	struct dentry___246 * (*d_real)(struct dentry___246 *, const struct inode___246 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___245;

struct mem_dqinfo___245 {
	struct quota_format_type___245 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___245;

struct quota_info___245 {
	unsigned int flags;
	struct rw_semaphore___247 dqio_sem;
	struct inode___246 *files[3];
	struct mem_dqinfo___245 info[3];
	const struct quota_format_ops___245 *ops[3];
};

struct rcuwait___245 {
	struct task_struct___247 *task;
};

struct percpu_rw_semaphore___245 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___247 rw_sem;
	struct rcuwait___245 writer;
	int readers_block;
};

struct sb_writers___245 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___245 rw_sem[3];
};

struct file_system_type___245;

struct super_operations___245;

struct dquot_operations___245;

struct quotactl_ops___245;

struct super_block___245 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___245 *s_type;
	const struct super_operations___245 *s_op;
	const struct dquot_operations___245 *dq_op;
	const struct quotactl_ops___245 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___246 *s_root;
	struct rw_semaphore___247 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___246 *s_bdev;
	struct backing_dev_info___122 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___245 s_dquot;
	struct sb_writers___245 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___245 *s_d_op;
	int cleancache_poolid;
	struct shrinker___107 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___206 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___246 {
	struct file___246 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___246 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___245 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___246 *ia_file;
};

struct dquot___245 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___245 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___245 {
	int qf_fmt_id;
	const struct quota_format_ops___245 *qf_ops;
	struct module___200 *qf_owner;
	struct quota_format_type___245 *qf_next;
};

struct quota_format_ops___245 {
	int (*check_quota_file)(struct super_block___245 *, int);
	int (*read_file_info)(struct super_block___245 *, int);
	int (*write_file_info)(struct super_block___245 *, int);
	int (*free_file_info)(struct super_block___245 *, int);
	int (*read_dqblk)(struct dquot___245 *);
	int (*commit_dqblk)(struct dquot___245 *);
	int (*release_dqblk)(struct dquot___245 *);
	int (*get_next_id)(struct super_block___245 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___245 {
	int (*write_dquot)(struct dquot___245 *);
	struct dquot___245 * (*alloc_dquot)(struct super_block___245 *, int);
	void (*destroy_dquot)(struct dquot___245 *);
	int (*acquire_dquot)(struct dquot___245 *);
	int (*release_dquot)(struct dquot___245 *);
	int (*mark_dirty)(struct dquot___245 *);
	int (*write_info)(struct super_block___245 *, int);
	qsize_t * (*get_reserved_space)(struct inode___246 *);
	int (*get_projid)(struct inode___246 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___246 *, qsize_t *);
	int (*get_next_id)(struct super_block___245 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___245 {
	int (*quota_on)(struct super_block___245 *, int, int, const struct path___246 *);
	int (*quota_off)(struct super_block___245 *, int);
	int (*quota_enable)(struct super_block___245 *, unsigned int);
	int (*quota_disable)(struct super_block___245 *, unsigned int);
	int (*quota_sync)(struct super_block___245 *, int);
	int (*set_info)(struct super_block___245 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___245 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___245 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___245 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___245 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___245 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___197 {
	struct kobject___234 kobj;
	struct module___200 *mod;
	struct kobject___234 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___197 {
	struct module___200 *mod;
	struct latch_tree_node node;
};

struct module_layout___197 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___197 mtn;
};

struct module_attribute___197;

struct kernel_param___197;

struct module___200 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___197 mkobj;
	struct module_attribute___197 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___234 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___197 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___197 core_layout;
	struct module_layout___197 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide53;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide54;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___118;

struct address_space_operations___245 {
	int (*writepage)(struct page___247 *, struct writeback_control___118 *);
	int (*readpage)(struct file___246 *, struct page___247 *);
	int (*writepages)(struct address_space___245 *, struct writeback_control___118 *);
	int (*set_page_dirty)(struct page___247 *);
	int (*readpages)(struct file___246 *, struct address_space___245 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___246 *, struct address_space___245 *, loff_t, unsigned int, unsigned int, struct page___247 **, void **);
	int (*write_end)(struct file___246 *, struct address_space___245 *, loff_t, unsigned int, unsigned int, struct page___247 *, void *);
	sector_t (*bmap)(struct address_space___245 *, sector_t);
	void (*invalidatepage)(struct page___247 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___247 *, gfp_t);
	void (*freepage)(struct page___247 *);
	ssize_t (*direct_IO)(struct kiocb___246 *, struct iov_iter___113 *);
	int (*migratepage)(struct address_space___245 *, struct page___247 *, struct page___247 *, enum migrate_mode);
	bool (*isolate_page)(struct page___247 *, isolate_mode_t);
	void (*putback_page)(struct page___247 *);
	int (*launder_page)(struct page___247 *);
	int (*is_partially_uptodate)(struct page___247 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___247 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___245 *, struct page___247 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___246 *, sector_t *);
	void (*swap_deactivate)(struct file___246 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___118 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___122 *wb;
	struct inode___246 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___122;

struct iov_iter___113 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___122 *bvec;
		struct pipe_inode_info___56 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___246 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___246 *bd_inode;
	struct super_block___245 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___246 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___122 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___245 {
	struct dentry___246 * (*lookup)(struct inode___246 *, struct dentry___246 *, unsigned int);
	const char * (*get_link)(struct dentry___246 *, struct inode___246 *, struct delayed_call *);
	int (*permission)(struct inode___246 *, int);
	struct posix_acl * (*get_acl)(struct inode___246 *, int);
	int (*readlink)(struct dentry___246 *, char *, int);
	int (*create)(struct inode___246 *, struct dentry___246 *, umode_t, bool);
	int (*link)(struct dentry___246 *, struct inode___246 *, struct dentry___246 *);
	int (*unlink)(struct inode___246 *, struct dentry___246 *);
	int (*symlink)(struct inode___246 *, struct dentry___246 *, const char *);
	int (*mkdir)(struct inode___246 *, struct dentry___246 *, umode_t);
	int (*rmdir)(struct inode___246 *, struct dentry___246 *);
	int (*mknod)(struct inode___246 *, struct dentry___246 *, umode_t, dev_t);
	int (*rename)(struct inode___246 *, struct dentry___246 *, struct inode___246 *, struct dentry___246 *, unsigned int);
	int (*setattr)(struct dentry___246 *, struct iattr___245 *);
	int (*getattr)(const struct path___246 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___246 *, char *, size_t);
	int (*fiemap)(struct inode___246 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___246 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___246 *, struct dentry___246 *, struct file___246 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___246 *, struct dentry___246 *, umode_t);
	int (*set_acl)(struct inode___246 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___245 {
	void (*fl_copy_lock)(struct file_lock___246 *, struct file_lock___246 *);
	void (*fl_release_private)(struct file_lock___246 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___245;

struct file_lock___246 {
	struct file_lock___246 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___246 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___245 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___245 *fl_ops;
	const struct lock_manager_operations___245 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___245 {
	int (*lm_compare_owner)(struct file_lock___246 *, struct file_lock___246 *);
	long unsigned int (*lm_owner_key)(struct file_lock___246 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___246 *);
	int (*lm_grant)(struct file_lock___246 *, int);
	bool (*lm_break)(struct file_lock___246 *);
	int (*lm_change)(struct file_lock___246 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___246 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___245 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___245 *fa_next;
	struct file___246 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___245 {
	const char *name;
	int fs_flags;
	struct dentry___246 * (*mount)(struct file_system_type___245 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___245 *);
	struct module___200 *owner;
	struct file_system_type___245 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___245 {
	struct inode___246 * (*alloc_inode)(struct super_block___245 *);
	void (*destroy_inode)(struct inode___246 *);
	void (*dirty_inode)(struct inode___246 *, int);
	int (*write_inode)(struct inode___246 *, struct writeback_control___118 *);
	int (*drop_inode)(struct inode___246 *);
	void (*evict_inode)(struct inode___246 *);
	void (*put_super)(struct super_block___245 *);
	int (*sync_fs)(struct super_block___245 *, int);
	int (*freeze_super)(struct super_block___245 *);
	int (*freeze_fs)(struct super_block___245 *);
	int (*thaw_super)(struct super_block___245 *);
	int (*unfreeze_fs)(struct super_block___245 *);
	int (*statfs)(struct dentry___246 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___245 *, int *, char *);
	void (*umount_begin)(struct super_block___245 *);
	int (*show_options)(struct seq_file___222 *, struct dentry___246 *);
	int (*show_devname)(struct seq_file___222 *, struct dentry___246 *);
	int (*show_path)(struct seq_file___222 *, struct dentry___246 *);
	int (*show_stats)(struct seq_file___222 *, struct dentry___246 *);
	ssize_t (*quota_read)(struct super_block___245 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___245 *, int, const char *, size_t, loff_t);
	struct dquot___245 ** (*get_dquots)(struct inode___246 *);
	int (*bdev_try_to_free_page)(struct super_block___245 *, struct page___247 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___245 *, struct shrink_control___107 *);
	long int (*free_cached_objects)(struct super_block___245 *, struct shrink_control___107 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___156)(struct file___246 *, wait_queue_head_t *, struct poll_table_struct___154 *);

struct poll_table_struct___154 {
	poll_queue_proc___156 _qproc;
	__poll_t _key;
};

struct seq_operations___220;

struct seq_file___222 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___220 *op;
	int poll_event;
	const struct file___246 *file;
	void *private;
};

typedef void bio_end_io_t___122(struct bio___122 *);

struct bio_vec___122 {
	struct page___247 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___122;

struct bio_set___122;

struct bio___122 {
	struct bio___122 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___122 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___122 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___122 *bi_io_vec;
	struct bio_set___122 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___122 bi_inline_vecs[0];
};

struct kobj_attribute___227 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___234 *, struct kobj_attribute___227 *, char *);
	ssize_t (*store)(struct kobject___234 *, struct kobj_attribute___227 *, const char *, size_t);
};

typedef void compound_page_dtor___236(struct page___247 *);

struct inet_frags___32;

struct netns_frags___32 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___32 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_rules_ops___21;

struct sock___23;

struct fib_notifier_ops___21;

struct netns_ipv4___32 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___21 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___23 *fibnl;
	struct sock___23 **icmp_sk;
	struct sock___23 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___23 **tcp_sk;
	struct netns_frags___32 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___21 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___21 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___21 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct dst_entry___22;

struct net_device___36;

struct sk_buff___36;

struct neighbour___22;

struct dst_ops___42 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___42 *);
	struct dst_entry___22 * (*check)(struct dst_entry___22 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___22 *);
	unsigned int (*mtu)(const struct dst_entry___22 *);
	u32 * (*cow_metrics)(struct dst_entry___22 *, long unsigned int);
	void (*destroy)(struct dst_entry___22 *);
	void (*ifdown)(struct dst_entry___22 *, struct net_device___36 *, int);
	struct dst_entry___22 * (*negative_advice)(struct dst_entry___22 *);
	void (*link_failure)(struct sk_buff___36 *);
	void (*update_pmtu)(struct dst_entry___22 *, struct sock___23 *, struct sk_buff___36 *, u32);
	void (*redirect)(struct dst_entry___22 *, struct sock___23 *, struct sk_buff___36 *);
	int (*local_out)(struct net___44 *, struct sock___23 *, struct sk_buff___36 *);
	struct neighbour___22 * (*neigh_lookup)(const struct dst_entry___22 *, struct sk_buff___36 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___22 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___42 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___32 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___42 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___21 *fib6_rules_ops;
	struct sock___23 **icmp_sk;
	struct sock___23 *ndisc_sk;
	struct sock___23 *tcp_sk;
	struct sock___23 *igmp_sk;
	struct sock___23 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___21 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___21 *notifier_ops;
	struct fib_notifier_ops___21 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___22 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___23 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___32 {
	struct netns_frags___32 frags;
};

struct netns_xfrm___42 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___23 *nlsk;
	struct sock___23 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___42 xfrm4_dst_ops;
	struct dst_ops___42 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___31;

struct net___44 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___206 *user_ns;
	struct ucounts___206 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___28 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___23 *rtnl;
	struct sock___23 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___36 *loopback_dev;
	struct netns_core core;
	struct netns_mib___2 mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___32 ipv4;
	struct netns_ipv6___42 ipv6;
	struct netns_sctp___22 sctp;
	struct netns_nf___2 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___32 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___23 *nfnl;
	struct sock___23 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___42 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can___2 can;
	struct sock___23 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___31 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cgroup_namespace___191 {
	refcount_t count;
	struct ns_common___28 ns;
	struct user_namespace___206 *user_ns;
	struct ucounts___206 *ucounts;
	struct css_set___191 *root_cset;
};

struct ucounts___206 {
	struct hlist_node node;
	struct user_namespace___206 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct msghdr___23 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___113 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___246 *msg_iocb;
};

struct selinux_mapping;

struct selinux_map {
	struct selinux_mapping *mapping;
	u16 size;
};

struct selinux_ss {
	struct sidtab *sidtab;
	struct policydb policydb;
	rwlock_t policy_rwlock;
	u32 latest_granting;
	struct selinux_map map;
	struct page___247 *status_page;
	struct mutex status_lock;
};

struct socket_wq___22 {
	wait_queue_head_t wait;
	struct fasync_struct___245 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___22;

struct socket___23 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___22 *wq;
	struct file___246 *file;
	struct sock___23 *sk;
	const struct proto_ops___22 *ops;
};

typedef struct {
	struct net___44 *net;
} possible_net_t___33;

struct proto___21;

struct sock_common___21 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___21 *skc_prot;
	possible_net_t___33 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___23 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff_head___32 {
	struct sk_buff___36 *next;
	struct sk_buff___36 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___21;

struct sock___23 {
	struct sock_common___21 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___32 sk_error_queue;
	struct sk_buff_head___32 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___36 *head;
		struct sk_buff___36 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___21 *sk_filter;
	union {
		struct socket_wq___22 *sk_wq;
		struct socket_wq___22 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___22 *sk_rx_dst;
	struct dst_entry___22 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___36 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___32 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___246 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___21 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___186 *sk_peer_pid;
	const struct cred___239 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___23 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___107 *sk_memcg;
	void (*sk_state_change)(struct sock___23 *);
	void (*sk_data_ready)(struct sock___23 *);
	void (*sk_write_space)(struct sock___23 *);
	void (*sk_error_report)(struct sock___23 *);
	int (*sk_backlog_rcv)(struct sock___23 *, struct sk_buff___36 *);
	struct sk_buff___36 * (*sk_validate_xmit_skb)(struct sock___23 *, struct net_device___36 *, struct sk_buff___36 *);
	void (*sk_destruct)(struct sock___23 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

typedef int (*sk_read_actor_t___21)(read_descriptor_t *, struct sk_buff___36 *, unsigned int, size_t);

struct proto_ops___22 {
	int family;
	struct module___200 *owner;
	int (*release)(struct socket___23 *);
	int (*bind)(struct socket___23 *, struct sockaddr *, int);
	int (*connect)(struct socket___23 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___23 *, struct socket___23 *);
	int (*accept)(struct socket___23 *, struct socket___23 *, int, bool);
	int (*getname)(struct socket___23 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___246 *, struct socket___23 *, struct poll_table_struct___154 *);
	int (*ioctl)(struct socket___23 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___23 *, int);
	int (*shutdown)(struct socket___23 *, int);
	int (*setsockopt)(struct socket___23 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___23 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___23 *, struct msghdr___23 *, size_t);
	int (*recvmsg)(struct socket___23 *, struct msghdr___23 *, size_t, int);
	int (*mmap)(struct file___246 *, struct socket___23 *, struct vm_area_struct___247 *);
	ssize_t (*sendpage)(struct socket___23 *, struct page___247 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___23 *, loff_t *, struct pipe_inode_info___56 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___23 *, int);
	int (*peek_len)(struct socket___23 *);
	int (*read_sock)(struct sock___23 *, read_descriptor_t *, sk_read_actor_t___21);
	int (*sendpage_locked)(struct sock___23 *, struct page___247 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___23 *, struct msghdr___23 *, size_t);
	int (*set_rcvlowat)(struct sock___23 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct nf_bridge_info___32;

struct sk_buff___36 {
	union {
		struct {
			struct sk_buff___36 *next;
			struct sk_buff___36 *prev;
			union {
				struct net_device___36 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___23 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___36 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___32 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct kernfs_root___240;

struct kernfs_elem_dir___240 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___240 *root;
};

struct kernfs_syscall_ops___240;

struct kernfs_root___240 {
	struct kernfs_node___240 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___240 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___240 {
	struct kernfs_node___240 *target_kn;
};

struct kernfs_ops___240;

struct kernfs_elem_attr___240 {
	const struct kernfs_ops___240 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___240 *notify_next;
};

struct kernfs_node___240 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___240 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___240 dir;
		struct kernfs_elem_symlink___240 symlink;
		struct kernfs_elem_attr___240 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___240;

struct kernfs_ops___240 {
	int (*open)(struct kernfs_open_file___240 *);
	void (*release)(struct kernfs_open_file___240 *);
	int (*seq_show)(struct seq_file___222 *, void *);
	void * (*seq_start)(struct seq_file___222 *, loff_t *);
	void * (*seq_next)(struct seq_file___222 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___222 *, void *);
	ssize_t (*read)(struct kernfs_open_file___240 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___240 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___240 *, struct vm_area_struct___247 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___240 *, struct poll_table_struct___154 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___240 {
	int (*remount_fs)(struct kernfs_root___240 *, int *, char *);
	int (*show_options)(struct seq_file___222 *, struct kernfs_root___240 *);
	int (*mkdir)(struct kernfs_node___240 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___240 *);
	int (*rename)(struct kernfs_node___240 *, struct kernfs_node___240 *, const char *);
	int (*show_path)(struct seq_file___222 *, struct kernfs_node___240 *, struct kernfs_root___240 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___240 {
	struct kernfs_node___240 *kn;
	struct file___246 *file;
	struct seq_file___222 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___236 *vm_ops;
};

struct kobj_ns_type_operations___21 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___23 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___211;

struct attribute_group___212 {
	const char *name;
	umode_t (*is_visible)(struct kobject___234 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___234 *, struct bin_attribute___211 *, int);
	struct attribute **attrs;
	struct bin_attribute___211 **bin_attrs;
};

struct bin_attribute___211 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___246 *, struct kobject___234 *, struct bin_attribute___211 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___246 *, struct kobject___234 *, struct bin_attribute___211 *, char *, loff_t, size_t);
	int (*mmap)(struct file___246 *, struct kobject___234 *, struct bin_attribute___211 *, struct vm_area_struct___247 *);
};

struct sysfs_ops___233 {
	ssize_t (*show)(struct kobject___234 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___234 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___233;

struct kset___233 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___234 kobj;
	const struct kset_uevent_ops___233 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___233 {
	void (*release)(struct kobject___234 *);
	const struct sysfs_ops___233 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___21 * (*child_ns_type)(struct kobject___234 *);
	const void * (*namespace)(struct kobject___234 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___233 {
	int (* const filter)(struct kset___233 *, struct kobject___234 *);
	const char * (* const name)(struct kset___233 *, struct kobject___234 *);
	int (* const uevent)(struct kset___233 *, struct kobject___234 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___210 {
	int (*prepare)(struct device___210 *);
	void (*complete)(struct device___210 *);
	int (*suspend)(struct device___210 *);
	int (*resume)(struct device___210 *);
	int (*freeze)(struct device___210 *);
	int (*thaw)(struct device___210 *);
	int (*poweroff)(struct device___210 *);
	int (*restore)(struct device___210 *);
	int (*suspend_late)(struct device___210 *);
	int (*resume_early)(struct device___210 *);
	int (*freeze_late)(struct device___210 *);
	int (*thaw_early)(struct device___210 *);
	int (*poweroff_late)(struct device___210 *);
	int (*restore_early)(struct device___210 *);
	int (*suspend_noirq)(struct device___210 *);
	int (*resume_noirq)(struct device___210 *);
	int (*freeze_noirq)(struct device___210 *);
	int (*thaw_noirq)(struct device___210 *);
	int (*poweroff_noirq)(struct device___210 *);
	int (*restore_noirq)(struct device___210 *);
	int (*runtime_suspend)(struct device___210 *);
	int (*runtime_resume)(struct device___210 *);
	int (*runtime_idle)(struct device___210 *);
};

struct dev_pm_domain___210 {
	struct dev_pm_ops___210 ops;
	void (*detach)(struct device___210 *, bool);
	int (*activate)(struct device___210 *);
	void (*sync)(struct device___210 *);
	void (*dismiss)(struct device___210 *);
};

struct bus_type___210 {
	const char *name;
	const char *dev_name;
	struct device___210 *dev_root;
	const struct attribute_group___212 **bus_groups;
	const struct attribute_group___212 **dev_groups;
	const struct attribute_group___212 **drv_groups;
	int (*match)(struct device___210 *, struct device_driver___210 *);
	int (*uevent)(struct device___210 *, struct kobj_uevent_env *);
	int (*probe)(struct device___210 *);
	int (*remove)(struct device___210 *);
	void (*shutdown)(struct device___210 *);
	int (*online)(struct device___210 *);
	int (*offline)(struct device___210 *);
	int (*suspend)(struct device___210 *, pm_message_t);
	int (*resume)(struct device___210 *);
	int (*num_vf)(struct device___210 *);
	int (*dma_configure)(struct device___210 *);
	const struct dev_pm_ops___210 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___210 {
	const char *name;
	struct bus_type___210 *bus;
	struct module___200 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___210 *);
	int (*remove)(struct device___210 *);
	void (*shutdown)(struct device___210 *);
	int (*suspend)(struct device___210 *, pm_message_t);
	int (*resume)(struct device___210 *);
	const struct attribute_group___212 **groups;
	const struct dev_pm_ops___210 *pm;
	void (*coredump)(struct device___210 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___210 {
	const char *name;
	const struct attribute_group___212 **groups;
	int (*uevent)(struct device___210 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___210 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___210 *);
	const struct dev_pm_ops___210 *pm;
};

struct class___210 {
	const char *name;
	struct module___200 *owner;
	const struct attribute_group___212 **class_groups;
	const struct attribute_group___212 **dev_groups;
	struct kobject___234 *dev_kobj;
	int (*dev_uevent)(struct device___210 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___210 *, umode_t *);
	void (*class_release)(struct class___210 *);
	void (*dev_release)(struct device___210 *);
	int (*shutdown_pre)(struct device___210 *);
	const struct kobj_ns_type_operations___21 *ns_type;
	const void * (*namespace)(struct device___210 *);
	const struct dev_pm_ops___210 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___53 {
	void * (*alloc)(struct device___210 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___210 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___210 *, struct vm_area_struct___247 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___210 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___210 *, struct page___247 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___210 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___210 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___210 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___210 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___210 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___210 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___210 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___210 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___210 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___210 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___210 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___210 *, u64);
	u64 (*get_required_mask)(struct device___210 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___145;

struct fwnode_handle___145 {
	struct fwnode_handle___145 *secondary;
	const struct fwnode_operations___145 *ops;
};

struct fwnode_reference_args___145;

struct fwnode_endpoint___145;

struct fwnode_operations___145 {
	struct fwnode_handle___145 * (*get)(struct fwnode_handle___145 *);
	void (*put)(struct fwnode_handle___145 *);
	bool (*device_is_available)(const struct fwnode_handle___145 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___145 *, const struct device___210 *);
	bool (*property_present)(const struct fwnode_handle___145 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___145 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___145 *, const char *, const char **, size_t);
	struct fwnode_handle___145 * (*get_parent)(const struct fwnode_handle___145 *);
	struct fwnode_handle___145 * (*get_next_child_node)(const struct fwnode_handle___145 *, struct fwnode_handle___145 *);
	struct fwnode_handle___145 * (*get_named_child_node)(const struct fwnode_handle___145 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___145 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___145 *);
	struct fwnode_handle___145 * (*graph_get_next_endpoint)(const struct fwnode_handle___145 *, struct fwnode_handle___145 *);
	struct fwnode_handle___145 * (*graph_get_remote_endpoint)(const struct fwnode_handle___145 *);
	struct fwnode_handle___145 * (*graph_get_port_parent)(struct fwnode_handle___145 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___145 *, struct fwnode_endpoint___145 *);
};

struct fwnode_endpoint___145 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___145 *local_fwnode;
};

struct fwnode_reference_args___145 {
	struct fwnode_handle___145 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___56;

struct pipe_buffer___56 {
	struct page___247 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___56 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___56 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___56 *, struct pipe_buffer___56 *);
	void (*release)(struct pipe_inode_info___56 *, struct pipe_buffer___56 *);
	int (*steal)(struct pipe_inode_info___56 *, struct pipe_buffer___56 *);
	union {
		bool (*get)(struct pipe_inode_info___56 *, struct pipe_buffer___56 *);
		struct {
			void (*get)(struct pipe_inode_info___56 *, struct pipe_buffer___56 *);
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
};

struct nf_bridge_info___32 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___32 = 0,
		BRNF_PROTO_8021Q___32 = 1,
		BRNF_PROTO_PPPOE___32 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___36 *physindev;
	struct net_device___36 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___32(struct sk_buff___36 **);

struct net_device_ops___32;

struct ethtool_ops___32;

struct l3mdev_ops___22;

struct xfrmdev_ops___32;

struct tlsdev_ops___32;

struct header_ops___32;

struct netdev_rx_queue___32;

struct mini_Qdisc___31;

struct netdev_queue___32;

struct Qdisc___31;

struct rtnl_link_ops___31;

struct dcbnl_rtnl_ops___32;

struct net_device___36 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___32 *netdev_ops;
	const struct ethtool_ops___32 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___22 *l3mdev_ops;
	const struct ndisc_ops___2 *ndisc_ops;
	const struct xfrmdev_ops___32 *xfrmdev_ops;
	const struct tlsdev_ops___32 *tlsdev_ops;
	const struct header_ops___32 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___233 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___2 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___32 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___31 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___32 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___31 *miniq_ingress;
	struct netdev_queue___32 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___32 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___31 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___31 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___32 = 0,
		NETREG_REGISTERED___32 = 1,
		NETREG_UNREGISTERING___32 = 2,
		NETREG_UNREGISTERED___32 = 3,
		NETREG_RELEASED___32 = 4,
		NETREG_DUMMY___32 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___32 = 0,
		RTNL_LINK_INITIALIZING___32 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___36 *);
	struct netpoll_info *npinfo;
	possible_net_t___33 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___210 dev;
	const struct attribute_group___212 *sysfs_groups[4];
	const struct attribute_group___212 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___31 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___32 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct netlink_callback___32 {
	struct sk_buff___36 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___32 *);
	int (*dump)(struct sk_buff___36 *, struct netlink_callback___32 *);
	int (*done)(struct netlink_callback___32 *);
	void *data;
	struct module___200 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct ethtool_ops___32 {
	int (*get_settings)(struct net_device___36 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___36 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___36 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___36 *);
	void (*get_regs)(struct net_device___36 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___36 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___36 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___36 *);
	void (*set_msglevel)(struct net_device___36 *, u32);
	int (*nway_reset)(struct net_device___36 *);
	u32 (*get_link)(struct net_device___36 *);
	int (*get_eeprom_len)(struct net_device___36 *);
	int (*get_eeprom)(struct net_device___36 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___36 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___36 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___36 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___36 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___36 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___36 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___36 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___36 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___36 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___36 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___36 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___36 *);
	void (*complete)(struct net_device___36 *);
	u32 (*get_priv_flags)(struct net_device___36 *);
	int (*set_priv_flags)(struct net_device___36 *, u32);
	int (*get_sset_count)(struct net_device___36 *, int);
	int (*get_rxnfc)(struct net_device___36 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___36 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___36 *, struct ethtool_flash *);
	int (*reset)(struct net_device___36 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___36 *);
	u32 (*get_rxfh_indir_size)(struct net_device___36 *);
	int (*get_rxfh)(struct net_device___36 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___36 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___36 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___36 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___36 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___36 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___36 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___36 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___36 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___36 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___36 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___36 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___36 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___36 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___36 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___36 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___36 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___36 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___36 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___36 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___36 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___36 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	int (*get_fecparam)(struct net_device___36 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___36 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___36 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___36 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___36 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___32;

struct inet_frags___32 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___32 *, const void *);
	void (*destructor)(struct inet_frag_queue___32 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___32 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___36 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___36 *fragments_tail;
	struct sk_buff___36 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___32 *net;
	struct callback_head rcu;
};

struct fib_rule___21;

struct fib_lookup_arg___21;

struct fib_rules_ops___21 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___21 *, struct flowi *, int, struct fib_lookup_arg___21 *);
	bool (*suppress)(struct fib_rule___21 *, struct fib_lookup_arg___21 *);
	int (*match)(struct fib_rule___21 *, struct flowi *, int);
	int (*configure)(struct fib_rule___21 *, struct sk_buff___36 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___21 *);
	int (*compare)(struct fib_rule___21 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___21 *, struct sk_buff___36 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___21 *);
	void (*flush_cache)(struct fib_rules_ops___21 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___200 *owner;
	struct net___44 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___21 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___44 *);
	int (*fib_dump)(struct net___44 *, struct notifier_block *);
	struct module___200 *owner;
	struct callback_head rcu;
};

struct dst_entry___22 {
	struct net_device___36 *dev;
	struct dst_ops___42 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___36 *);
	int (*output)(struct net___44 *, struct sock___23 *, struct sk_buff___36 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___21;

struct neigh_parms___22;

struct neigh_ops___21;

struct neighbour___22 {
	struct neighbour___22 *next;
	struct neigh_table___21 *tbl;
	struct neigh_parms___22 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___32 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___22 *, struct sk_buff___36 *);
	const struct neigh_ops___21 *ops;
	struct callback_head rcu;
	struct net_device___36 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct bpf_prog_aux___33;

struct bpf_prog___31 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___33 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

struct seq_operations___220 {
	void * (*start)(struct seq_file___222 *, loff_t *);
	void (*stop)(struct seq_file___222 *, void *);
	void * (*next)(struct seq_file___222 *, void *, loff_t *);
	int (*show)(struct seq_file___222 *, void *);
};

struct pernet_operations___33 {
	struct list_head list;
	int (*init)(struct net___44 *);
	void (*exit)(struct net___44 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___32 {
	int (*ieee_getets)(struct net_device___36 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___36 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___36 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___36 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___36 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___36 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___36 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___36 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___36 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___36 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___36 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___36 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___36 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___36 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___36 *);
	u8 (*setstate)(struct net_device___36 *, u8);
	void (*getpermhwaddr)(struct net_device___36 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___36 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___36 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___36 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___36 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___36 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___36 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___36 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___36 *, int, u8 *);
	void (*setpfccfg)(struct net_device___36 *, int, u8);
	void (*getpfccfg)(struct net_device___36 *, int, u8 *);
	u8 (*setall)(struct net_device___36 *);
	u8 (*getcap)(struct net_device___36 *, int, u8 *);
	int (*getnumtcs)(struct net_device___36 *, int, u8 *);
	int (*setnumtcs)(struct net_device___36 *, int, u8);
	u8 (*getpfcstate)(struct net_device___36 *);
	void (*setpfcstate)(struct net_device___36 *, u8);
	void (*getbcncfg)(struct net_device___36 *, int, u32 *);
	void (*setbcncfg)(struct net_device___36 *, int, u32);
	void (*getbcnrp)(struct net_device___36 *, int, u8 *);
	void (*setbcnrp)(struct net_device___36 *, int, u8);
	int (*setapp)(struct net_device___36 *, u8, u16, u8);
	int (*getapp)(struct net_device___36 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___36 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___36 *, int, u8);
	u8 (*getdcbx)(struct net_device___36 *);
	u8 (*setdcbx)(struct net_device___36 *, u8);
	int (*peer_getappinfo)(struct net_device___36 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___36 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___36 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___36 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___36 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___36 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct bpf_map___191;

struct bpf_map_ops___191 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___191 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___191 *, struct file___246 *);
	void (*map_free)(struct bpf_map___191 *);
	int (*map_get_next_key)(struct bpf_map___191 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___191 *);
	void * (*map_lookup_elem)(struct bpf_map___191 *, void *);
	int (*map_update_elem)(struct bpf_map___191 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___191 *, void *);
	int (*map_push_elem)(struct bpf_map___191 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___191 *, void *);
	int (*map_peek_elem)(struct bpf_map___191 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___191 *, struct file___246 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___191 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___191 *, void *, struct seq_file___222 *);
	int (*map_check_btf)(const struct bpf_map___191 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___191 {
	const struct bpf_map_ops___191 *ops;
	struct bpf_map___191 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___239 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___32;

struct bpf_map_dev_ops___32 {
	int (*map_get_next_key)(struct bpf_offloaded_map___32 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___32 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___32 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___32 *, void *);
};

struct bpf_offloaded_map___32 {
	struct bpf_map___191 map;
	struct net_device___36 *netdev;
	const struct bpf_map_dev_ops___32 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___31 {
	int (*test_run)(struct bpf_prog___31 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___31 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___31 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___31 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___31 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___31 *, u32 *);
};

struct bpf_prog_offload_ops___31 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___31 *);
	int (*translate)(struct bpf_prog___31 *);
	void (*destroy)(struct bpf_prog___31 *);
};

struct bpf_prog_offload___31 {
	struct bpf_prog___31 *prog;
	struct net_device___36 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___31 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___33 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___31 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___31 *ops;
	struct bpf_map___191 **used_maps;
	struct bpf_prog___31 *prog;
	struct user_struct___239 *user;
	u64 load_time;
	struct bpf_map___191 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___31 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___31 {
	struct bpf_prog___31 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___31 {
	struct callback_head rcu;
	struct bpf_prog_array_item___31 items[0];
};

struct cgroup_bpf___31 {
	struct bpf_prog_array___31 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___31 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___191;

typedef void (*kthread_work_func_t___191)(struct kthread_work___191 *);

struct kthread_worker___191;

struct kthread_work___191 {
	struct list_head node;
	kthread_work_func_t___191 func;
	struct kthread_worker___191 *worker;
	int canceling;
};

struct kthread_worker___191 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___247 *task;
	struct kthread_work___191 *current_work;
};

struct kthread_delayed_work___191 {
	struct kthread_work___191 work;
	struct timer_list timer;
};

struct psi_group___191 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___191 *poll_kworker;
	struct kthread_delayed_work___191 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___191;

struct cgroup_rstat_cpu___191;

struct cgroup___191 {
	struct cgroup_subsys_state___192 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___240 *kn;
	struct cgroup_file___191 procs_file;
	struct cgroup_file___191 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___192 *subsys[13];
	struct cgroup_root___191 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___191 *dom_cgrp;
	struct cgroup_rstat_cpu___191 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___31 bpf;
	atomic_t congestion_count;
	struct cgroup___191 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___191 psi;
	int ancestor_ids[0];
};

struct cftype___191;

struct cgroup_subsys___191 {
	struct cgroup_subsys_state___192 * (*css_alloc)(struct cgroup_subsys_state___192 *);
	int (*css_online)(struct cgroup_subsys_state___192 *);
	void (*css_offline)(struct cgroup_subsys_state___192 *);
	void (*css_released)(struct cgroup_subsys_state___192 *);
	void (*css_free)(struct cgroup_subsys_state___192 *);
	void (*css_reset)(struct cgroup_subsys_state___192 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___192 *, int);
	int (*css_extra_stat_show)(struct seq_file___222 *, struct cgroup_subsys_state___192 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___247 *);
	void (*cancel_fork)(struct task_struct___247 *);
	void (*fork)(struct task_struct___247 *);
	void (*exit)(struct task_struct___247 *);
	void (*free)(struct task_struct___247 *);
	void (*bind)(struct cgroup_subsys_state___192 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___191 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___191 *dfl_cftypes;
	struct cftype___191 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___191 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___191 *updated_children;
	struct cgroup___191 *updated_next;
};

struct cgroup_root___191 {
	struct kernfs_root___240 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___191 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___191 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___191 *ss;
	struct list_head node;
	struct kernfs_ops___240 *kf_ops;
	int (*open)(struct kernfs_open_file___240 *);
	void (*release)(struct kernfs_open_file___240 *);
	u64 (*read_u64)(struct cgroup_subsys_state___192 *, struct cftype___191 *);
	s64 (*read_s64)(struct cgroup_subsys_state___192 *, struct cftype___191 *);
	int (*seq_show)(struct seq_file___222 *, void *);
	void * (*seq_start)(struct seq_file___222 *, loff_t *);
	void * (*seq_next)(struct seq_file___222 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___222 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___192 *, struct cftype___191 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___192 *, struct cftype___191 *, s64);
	ssize_t (*write)(struct kernfs_open_file___240 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___240 *, struct poll_table_struct___154 *);
};

struct xdp_rxq_info___32 {
	struct net_device___36 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___32 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___36 *dev_rx;
};

struct header_ops___32 {
	int (*create)(struct sk_buff___36 *, struct net_device___36 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___36 *, unsigned char *);
	int (*cache)(const struct neighbour___22 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___36 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___32 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___32 *, int);
	int poll_owner;
	struct net_device___36 *dev;
	struct sk_buff___36 *gro_list;
	struct sk_buff___36 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___32 {
	struct net_device___36 *dev;
	struct Qdisc___31 *qdisc;
	struct Qdisc___31 *qdisc_sleeping;
	struct kobject___234 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___36 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___31 {
	struct sk_buff___36 *head;
	struct sk_buff___36 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___31;

struct Qdisc___31 {
	int (*enqueue)(struct sk_buff___36 *, struct Qdisc___31 *, struct sk_buff___36 **);
	struct sk_buff___36 * (*dequeue)(struct Qdisc___31 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___31 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___32 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___32 gso_skb;
	struct qdisc_skb_head___31 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___31 *next_sched;
	struct sk_buff_head___32 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___32 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___234 kobj;
	struct net_device___36 *dev;
	long: 64;
	struct xdp_rxq_info___32 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___32)(struct net_device___36 *, struct sk_buff___36 *, struct net_device___36 *);

struct netdev_bpf___32 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___31 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___31 *prog;
			const struct bpf_prog_offload_ops___31 *ops;
		} verifier;
		struct {
			struct bpf_prog___31 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___32 *offmap;
		};
		struct {
			struct xdp_umem *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___32 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___36 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___32 {
	int (*tls_dev_add)(struct net_device___36 *, struct sock___23 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___36 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___36 *, struct sock___23 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___32 {
	int (*ndo_init)(struct net_device___36 *);
	void (*ndo_uninit)(struct net_device___36 *);
	int (*ndo_open)(struct net_device___36 *);
	int (*ndo_stop)(struct net_device___36 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___36 *, struct net_device___36 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___36 *, struct net_device___36 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___36 *, struct sk_buff___36 *, struct net_device___36 *, select_queue_fallback_t___32);
	void (*ndo_change_rx_flags)(struct net_device___36 *, int);
	void (*ndo_set_rx_mode)(struct net_device___36 *);
	int (*ndo_set_mac_address)(struct net_device___36 *, void *);
	int (*ndo_validate_addr)(struct net_device___36 *);
	int (*ndo_do_ioctl)(struct net_device___36 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___36 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___36 *, int);
	int (*ndo_neigh_setup)(struct net_device___36 *, struct neigh_parms___22 *);
	void (*ndo_tx_timeout)(struct net_device___36 *);
	void (*ndo_get_stats64)(struct net_device___36 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___36 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___36 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___36 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___36 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___36 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___36 *);
	int (*ndo_netpoll_setup)(struct net_device___36 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___36 *);
	int (*ndo_set_vf_mac)(struct net_device___36 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___36 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___36 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___36 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___36 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___36 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___36 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___36 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___36 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___36 *, int, struct sk_buff___36 *);
	int (*ndo_set_vf_guid)(struct net_device___36 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___36 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___36 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___36 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___36 *, const struct sk_buff___36 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___36 *, struct net_device___36 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___36 *, struct net_device___36 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___36 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___36 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___36 *, struct neighbour___22 *);
	void (*ndo_neigh_destroy)(struct net_device___36 *, struct neighbour___22 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___36 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___36 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___36 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___36 *, struct netlink_callback___32 *, struct net_device___36 *, struct net_device___36 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___36 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___36 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___36 *, u32, u32, struct net_device___36 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___36 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___36 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___36 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___36 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___36 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___36 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___36 *, struct net_device___36 *);
	void (*ndo_dfwd_del_station)(struct net_device___36 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___36 *);
	int (*ndo_set_tx_maxrate)(struct net_device___36 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___36 *);
	int (*ndo_change_proto_down)(struct net_device___36 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___36 *, struct sk_buff___36 *);
	void (*ndo_set_rx_headroom)(struct net_device___36 *, int);
	int (*ndo_bpf)(struct net_device___36 *, struct netdev_bpf___32 *);
	int (*ndo_xdp_xmit)(struct net_device___36 *, int, struct xdp_frame___32 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___36 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___36 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___22 {
	possible_net_t___33 net;
	struct net_device___36 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___22 *);
	void (*neigh_cleanup)(struct neighbour___22 *);
	struct neigh_table___21 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___22 {
	u32 (*l3mdev_fib_table)(const struct net_device___36 *);
	struct sk_buff___36 * (*l3mdev_l3_rcv)(struct net_device___36 *, struct sk_buff___36 *, u16);
	struct sk_buff___36 * (*l3mdev_l3_out)(struct net_device___36 *, struct sock___23 *, struct sk_buff___36 *, u16);
	struct dst_entry___22 * (*l3mdev_link_scope_lookup)(const struct net_device___36 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct tcf_proto___31;

struct mini_Qdisc___31 {
	struct tcf_proto___31 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___31 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___36 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___44 *, struct net_device___36 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___36 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___36 *, struct list_head *);
	size_t (*get_size)(const struct net_device___36 *);
	int (*fill_info)(struct sk_buff___36 *, const struct net_device___36 *);
	size_t (*get_xstats_size)(const struct net_device___36 *);
	int (*fill_xstats)(struct sk_buff___36 *, const struct net_device___36 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___36 *, struct net_device___36 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___36 *, const struct net_device___36 *);
	int (*fill_slave_info)(struct sk_buff___36 *, const struct net_device___36 *, const struct net_device___36 *);
	struct net___44 * (*get_link_net)(const struct net_device___36 *);
	size_t (*get_linkxstats_size)(const struct net_device___36 *, int);
	int (*fill_linkxstats)(struct sk_buff___36 *, const struct net_device___36 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___32 {
	struct list_head poll_list;
	struct sk_buff_head___32 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___32 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___31 *output_queue;
	struct Qdisc___31 **output_queue_tailp;
	struct sk_buff___36 *completion_queue;
	struct sk_buff_head___32 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___32 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___32 input_pkt_queue;
	struct napi_struct___32 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bdi_writeback_congested___122 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___122 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___122 {
	struct bio___122 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___122 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___122 bip_inline_vecs[0];
};

struct bio_set___122 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___122 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___107 {
	struct mem_cgroup___107 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___107 {
	struct lruvec___246 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___107 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___107 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct kernel_param_ops___197 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___197 *);
	int (*get)(char *, const struct kernel_param___197 *);
	void (*free)(void *);
};

struct kparam_array___197;

struct kernel_param___197 {
	const char *name;
	struct module___200 *mod;
	const struct kernel_param_ops___197 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___197 *arr;
	};
};

struct kparam_array___197 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___197 *ops;
	void *elem;
};

struct module_attribute___197 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___197 *, struct module_kobject___197 *, char *);
	ssize_t (*store)(struct module_attribute___197 *, struct module_kobject___197 *, const char *, size_t);
	void (*setup)(struct module___200 *, const char *);
	int (*test)(struct module___200 *);
	void (*free)(struct module___200 *);
};

struct gnet_dump___31 {
	spinlock_t *lock;
	struct sk_buff___36 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___31;

struct Qdisc_ops___31 {
	struct Qdisc_ops___31 *next;
	const struct Qdisc_class_ops___31 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___36 *, struct Qdisc___31 *, struct sk_buff___36 **);
	struct sk_buff___36 * (*dequeue)(struct Qdisc___31 *);
	struct sk_buff___36 * (*peek)(struct Qdisc___31 *);
	int (*init)(struct Qdisc___31 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___31 *);
	void (*destroy)(struct Qdisc___31 *);
	int (*change)(struct Qdisc___31 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___31 *);
	int (*change_tx_queue_len)(struct Qdisc___31 *, unsigned int);
	int (*dump)(struct Qdisc___31 *, struct sk_buff___36 *);
	int (*dump_stats)(struct Qdisc___31 *, struct gnet_dump___31 *);
	void (*ingress_block_set)(struct Qdisc___31 *, u32);
	void (*egress_block_set)(struct Qdisc___31 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___31 *);
	u32 (*egress_block_get)(struct Qdisc___31 *);
	struct module___200 *owner;
};

struct tcf_block___31;

struct Qdisc_class_ops___31 {
	unsigned int flags;
	struct netdev_queue___32 * (*select_queue)(struct Qdisc___31 *, struct tcmsg *);
	int (*graft)(struct Qdisc___31 *, long unsigned int, struct Qdisc___31 *, struct Qdisc___31 **, struct netlink_ext_ack *);
	struct Qdisc___31 * (*leaf)(struct Qdisc___31 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___31 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___31 *, u32);
	int (*change)(struct Qdisc___31 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___31 *, long unsigned int);
	void (*walk)(struct Qdisc___31 *, struct qdisc_walker *);
	struct tcf_block___31 * (*tcf_block)(struct Qdisc___31 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___31 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___31 *, long unsigned int);
	int (*dump)(struct Qdisc___31 *, long unsigned int, struct sk_buff___36 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___31 *, long unsigned int, struct gnet_dump___31 *);
};

struct tcf_chain___31;

struct tcf_block___31 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___44 *net;
	struct Qdisc___31 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___31 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___31;

struct tcf_proto_ops___31;

struct tcf_proto___31 {
	struct tcf_proto___31 *next;
	void *root;
	int (*classify)(struct sk_buff___36 *, const struct tcf_proto___31 *, struct tcf_result___31 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___31 *ops;
	struct tcf_chain___31 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___31 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___31 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___31 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___36 *, const struct tcf_proto___31 *, struct tcf_result___31 *);
	int (*init)(struct tcf_proto___31 *);
	void (*destroy)(struct tcf_proto___31 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___31 *, u32);
	void (*put)(struct tcf_proto___31 *, void *);
	int (*change)(struct net___44 *, struct sk_buff___36 *, struct tcf_proto___31 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___31 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___31 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___31 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___44 *, struct tcf_chain___31 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___44 *, struct tcf_proto___31 *, void *, struct sk_buff___36 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___36 *, struct net___44 *, void *);
	struct module___200 *owner;
	int flags;
};

struct tcf_chain___31 {
	struct mutex filter_chain_lock;
	struct tcf_proto___31 *filter_chain;
	struct list_head list;
	struct tcf_block___31 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___31 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___21 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___31 *prog;
};

struct bpf_redirect_info___31 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___191 *map;
	struct bpf_map___191 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___21;

struct neigh_hash_table___21;

struct neigh_table___21 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___36 *, __u32 *);
	bool (*key_eq)(const struct neighbour___22 *, const void *);
	int (*constructor)(struct neighbour___22 *);
	int (*pconstructor)(struct pneigh_entry___21 *);
	void (*pdestructor)(struct pneigh_entry___21 *);
	void (*proxy_redo)(struct sk_buff___36 *);
	char *id;
	struct neigh_parms___22 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___32 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___21 *nht;
	struct pneigh_entry___21 **phash_buckets;
};

struct neigh_ops___21 {
	int family;
	void (*solicit)(struct neighbour___22 *, struct sk_buff___36 *);
	void (*error_report)(struct neighbour___22 *, struct sk_buff___36 *);
	int (*output)(struct neighbour___22 *, struct sk_buff___36 *);
	int (*connected_output)(struct neighbour___22 *, struct sk_buff___36 *);
};

struct pneigh_entry___21 {
	struct pneigh_entry___21 *next;
	possible_net_t___33 net;
	struct net_device___36 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___21 {
	struct neighbour___22 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___21 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___21 *ctarget;
	struct net___44 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___21 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___21 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___14;

struct proto___21 {
	void (*close)(struct sock___23 *, long int);
	int (*pre_connect)(struct sock___23 *, struct sockaddr *, int);
	int (*connect)(struct sock___23 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___23 *, int);
	struct sock___23 * (*accept)(struct sock___23 *, int, int *, bool);
	int (*ioctl)(struct sock___23 *, int, long unsigned int);
	int (*init)(struct sock___23 *);
	void (*destroy)(struct sock___23 *);
	void (*shutdown)(struct sock___23 *, int);
	int (*setsockopt)(struct sock___23 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___23 *, int, int, char *, int *);
	void (*keepalive)(struct sock___23 *, int);
	int (*sendmsg)(struct sock___23 *, struct msghdr___23 *, size_t);
	int (*recvmsg)(struct sock___23 *, struct msghdr___23 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___23 *, struct page___247 *, int, size_t, int);
	int (*bind)(struct sock___23 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___23 *, struct sk_buff___36 *);
	void (*release_cb)(struct sock___23 *);
	int (*hash)(struct sock___23 *);
	void (*unhash)(struct sock___23 *);
	void (*rehash)(struct sock___23 *);
	int (*get_port)(struct sock___23 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___23 *);
	bool (*stream_memory_read)(const struct sock___23 *);
	void (*enter_memory_pressure)(struct sock___23 *);
	void (*leave_memory_pressure)(struct sock___23 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___14 *rsk_prot;
	struct timewait_sock_ops___3 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___200 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___23 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct request_sock___15;

struct request_sock_ops___14 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___23 *, struct request_sock___15 *);
	void (*send_ack)(const struct sock___23 *, struct sk_buff___36 *, struct request_sock___15 *);
	void (*send_reset)(const struct sock___23 *, struct sk_buff___36 *);
	void (*destructor)(struct request_sock___15 *);
	void (*syn_ack_timeout)(const struct request_sock___15 *);
};

struct request_sock___15 {
	struct sock_common___21 __req_common;
	struct request_sock___15 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___14 *rsk_ops;
	struct sock___23 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct perm_datum {
	u32 value;
};

struct filename_trans {
	u32 stype;
	u32 ttype;
	u16 tclass;
	const char *name;
};

struct filename_trans_datum {
	u32 otype;
};

struct type_datum {
	u32 value;
	u32 bounds;
	unsigned char primary;
	unsigned char attribute;
};

struct level_datum {
	struct mls_level *level;
	unsigned char isalias;
};

struct cat_datum {
	u32 value;
	unsigned char isalias;
};

struct range_trans {
	u32 source_type;
	u32 target_type;
	u32 target_class;
};

struct cond_expr;

struct cond_av_list;

struct cond_node {
	int cur_state;
	struct cond_expr *expr;
	struct cond_av_list *true_list;
	struct cond_av_list *false_list;
	struct cond_node *next;
};

struct policy_data {
	struct policydb *p;
	void *fp;
};

struct cond_expr {
	__u32 expr_type;
	__u32 bool;
	struct cond_expr *next;
};

struct cond_av_list {
	struct avtab_node *node;
	struct cond_av_list *next;
};

struct selinux_mapping {
	u16 value;
	unsigned int num_perms;
	u32 perms[32];
};

struct policydb_compat_info {
	int version;
	int sym_num;
	int ocon_num;
};

struct module___201;

struct file___247;

struct kiocb___247;

struct iov_iter___114;

struct poll_table_struct___155;

struct vm_area_struct___248;

struct inode___247;

struct file_lock___247;

struct page___248;

struct pipe_inode_info___57;

struct seq_file___223;

struct file_operations___247 {
	struct module___201 *owner;
	loff_t (*llseek)(struct file___247 *, loff_t, int);
	ssize_t (*read)(struct file___247 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___247 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___247 *, struct iov_iter___114 *);
	ssize_t (*write_iter)(struct kiocb___247 *, struct iov_iter___114 *);
	int (*iopoll)(struct kiocb___247 *, bool);
	int (*iterate)(struct file___247 *, struct dir_context *);
	int (*iterate_shared)(struct file___247 *, struct dir_context *);
	__poll_t (*poll)(struct file___247 *, struct poll_table_struct___155 *);
	long int (*unlocked_ioctl)(struct file___247 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___247 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___247 *, struct vm_area_struct___248 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___247 *, struct file___247 *);
	int (*flush)(struct file___247 *, fl_owner_t);
	int (*release)(struct inode___247 *, struct file___247 *);
	int (*fsync)(struct file___247 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___247 *, int);
	int (*lock)(struct file___247 *, int, struct file_lock___247 *);
	ssize_t (*sendpage)(struct file___247 *, struct page___248 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___247 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___247 *, int, struct file_lock___247 *);
	ssize_t (*splice_write)(struct pipe_inode_info___57 *, struct file___247 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___247 *, loff_t *, struct pipe_inode_info___57 *, size_t, unsigned int);
	int (*setlease)(struct file___247 *, long int, struct file_lock___247 **, void **);
	long int (*fallocate)(struct file___247 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___223 *, struct file___247 *);
	ssize_t (*copy_file_range)(struct file___247 *, loff_t, struct file___247 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___247 *, loff_t, struct file___247 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___247 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___247 {
	u64 seqnum;
	struct vm_area_struct___248 *vmas[4];
};

struct page_frag___247 {
	struct page___248 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___247;

struct mem_cgroup___108;

struct pid___187;

struct cred___240;

struct nsproxy___227;

struct signal_struct___205;

struct bio_list___123;

struct backing_dev_info___123;

struct css_set___192;

struct vm_struct___164;

struct task_struct___248 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___248 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___247 *mm;
	struct mm_struct___247 *active_mm;
	struct vmacache___247 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___248 *real_parent;
	struct task_struct___248 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___248 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___108 *active_memcg;
	long int rh_reserved2;
	struct pid___187 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___187 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___187 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___240 *ptracer_cred;
	const struct cred___240 *real_cred;
	const struct cred___240 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___227 *nsproxy;
	struct signal_struct___205 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___248 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___123 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___123 *backing_dev_info;
	struct io_context___60 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___192 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___57 *splice_pipe;
	struct page_frag___247 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___108 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___248 *oom_reaper_list;
	struct vm_struct___164 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___127 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___248 *pgtable_t___247;

struct address_space___246;

struct dev_pagemap___237;

struct page___248 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___246 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___248 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___247 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___247 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___237 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___108 *mem_cgroup;
};

struct pglist_data___247;

struct lruvec___247 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___247 *pgdat;
};

struct zone___247 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___247 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___247 {
	struct zone___247 *zone;
	int zone_idx;
};

struct zonelist___247 {
	struct zoneref___247 _zonerefs[25];
};

struct pglist_data___247 {
	struct zone___247 node_zones[3];
	struct zonelist___247 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___248 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___248 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___247 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___248 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___248 *owner;
};

struct secondary_data___248 {
	void *stack;
	struct task_struct___248 *task;
	long int status;
};

struct blocking_notifier_head___247 {
	struct rw_semaphore___248 rwsem;
	struct notifier_block *head;
};

struct cgroup___192;

struct cgroup_subsys___192;

struct cgroup_subsys_state___193 {
	struct cgroup___192 *cgroup;
	struct cgroup_subsys___192 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___193 *parent;
};

struct kernfs_node___241;

struct cgroup_file___192 {
	struct kernfs_node___241 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___108;

struct mem_cgroup___108 {
	struct cgroup_subsys_state___193 css;
	struct mem_cgroup_id___16 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___192 events_file;
	struct cgroup_file___192 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___248 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___108 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___187;

struct upid___187 {
	int nr;
	struct pid_namespace___187 *ns;
};

struct dentry___247;

struct user_namespace___207;

struct ucounts___207;

struct pid_namespace___187 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___248 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___187 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___247 *proc_self;
	struct dentry___247 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___207 *user_ns;
	struct ucounts___207 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___28 ns;
};

struct pid___187 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___187 numbers[1];
};

struct key___240;

struct user_namespace___207 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___207 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___28 ns;
	long unsigned int flags;
	struct key___240 *persistent_keyring_register;
	struct rw_semaphore___248 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___207 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct user_struct___240 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___240 *uid_keyring;
	struct key___240 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___237;

struct vm_area_struct___248 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___248 *vm_next;
	struct vm_area_struct___248 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___247 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___237 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___247 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct linux_binfmt___43;

struct core_state___247;

struct mm_struct___247 {
	struct {
		struct vm_area_struct___248 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___247 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___248 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___43 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___247 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___248 *owner;
		struct user_namespace___207 *user_ns;
		struct file___247 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___247 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___240 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___240 *session_keyring;
	struct key___240 *process_keyring;
	struct key___240 *thread_keyring;
	struct key___240 *request_key_auth;
	void *security;
	struct user_struct___240 *user;
	struct user_namespace___207 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___45;

struct cgroup_namespace___192;

struct nsproxy___227 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___187 *pid_ns_for_children;
	struct net___45 *net_ns;
	struct cgroup_namespace___192 *cgroup_ns;
};

struct signal_struct___205 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___248 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___248 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___187 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___187 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___247 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___187 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___123;

struct bio_list___123 {
	struct bio___123 *head;
	struct bio___123 *tail;
};

struct bdi_writeback_congested___123;

struct bdi_writeback___123 {
	struct backing_dev_info___123 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___123 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___193 *memcg_css;
	struct cgroup_subsys_state___193 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___211;

struct backing_dev_info___123 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___123 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___211 *dev;
	struct device___211 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___247 *debug_dir;
	struct dentry___247 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___192 {
	struct cgroup_subsys_state___193 *subsys[13];
	refcount_t refcount;
	struct css_set___192 *dom_cset;
	struct cgroup___192 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___192 *mg_src_cgrp;
	struct cgroup___192 *mg_dst_cgrp;
	struct css_set___192 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___246;

struct pipe_buffer___57;

struct pipe_inode_info___57 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___248 *tmp_page;
	struct fasync_struct___246 *fasync_readers;
	struct fasync_struct___246 *fasync_writers;
	struct pipe_buffer___57 *bufs;
	struct user_struct___240 *user;
};

struct vm_struct___164 {
	struct vm_struct___164 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___248 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___217 {
	struct task_struct___248 task;
	long unsigned int stack[8192];
};

struct address_space_operations___246;

struct address_space___246 {
	struct inode___247 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___248 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___246 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___237)(struct vm_area_struct___248 *, long unsigned int, const struct page___248 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___237)(struct page___248 *, void *);

struct dev_pagemap___237 {
	dev_page_fault_t___237 page_fault;
	dev_page_free_t___237 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___211 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___247 {
	struct vfsmount *mnt;
	struct dentry___247 *dentry;
};

struct fown_struct___187 {
	rwlock_t lock;
	struct pid___187 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___247 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___247 f_path;
	struct inode___247 *f_inode;
	const struct file_operations___247 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___187 f_owner;
	const struct cred___240 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___246 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___237;

struct vm_operations_struct___237 {
	void (*open)(struct vm_area_struct___248 *);
	void (*close)(struct vm_area_struct___248 *);
	int (*split)(struct vm_area_struct___248 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___248 *);
	vm_fault_t (*fault)(struct vm_fault___237 *);
	vm_fault_t (*huge_fault)(struct vm_fault___237 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___237 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___248 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___237 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___237 *);
	int (*access)(struct vm_area_struct___248 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___248 *);
	int (*set_policy)(struct vm_area_struct___248 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___248 *, long unsigned int);
	struct page___248 * (*find_special_page)(struct vm_area_struct___248 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___247 {
	struct task_struct___248 *task;
	struct core_thread___247 *next;
};

struct core_state___247 {
	atomic_t nr_threads;
	struct core_thread___247 dumper;
	struct completion startup;
};

struct linux_binprm___44;

struct coredump_params___43;

struct linux_binfmt___43 {
	struct list_head lh;
	struct module___201 *module;
	int (*load_binary)(struct linux_binprm___44 *);
	int (*load_shlib)(struct file___247 *);
	int (*core_dump)(struct coredump_params___43 *);
	long unsigned int min_coredump;
};

struct vm_fault___237 {
	struct vm_area_struct___248 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___248 *cow_page;
	struct mem_cgroup___108 *memcg;
	struct page___248 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___247 prealloc_pte;
};

struct kset___234;

struct kobj_type___234;

struct kobject___235 {
	const char *name;
	struct list_head entry;
	struct kobject___235 *parent;
	struct kset___234 *kset;
	struct kobj_type___234 *ktype;
	struct kernfs_node___241 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___198 {
	struct kobject___235 kobj;
	struct module___201 *mod;
	struct kobject___235 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___198 {
	struct module___201 *mod;
	struct latch_tree_node node;
};

struct module_layout___198 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___198 mtn;
};

struct module_attribute___198;

struct kernel_param___198;

struct module___201 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___198 mkobj;
	struct module_attribute___198 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___235 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___198 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___198 core_layout;
	struct module_layout___198 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide53;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide54;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bio_vec___123 {
	struct page___248 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___114 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___123 *bvec;
		struct pipe_inode_info___57 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct msghdr___24 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___114 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___247 *msg_iocb;
};

struct kiocb___247 {
	struct file___247 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___247 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

typedef int (*key_restrict_link_func_t___240)(struct key___240 *, const struct key_type *, const union key_payload *, struct key___240 *);

struct key_restriction___240;

struct key___240 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___248 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key___5 index_key;
		struct {
			struct key_type___5 *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___240 *restrict_link;
};

struct key_restriction___240 {
	key_restrict_link_func_t___240 check;
	struct key___240 *key;
	struct key_type *keytype;
};

struct shrink_control___108 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___108 *memcg;
};

struct shrinker___108 {
	long unsigned int (*count_objects)(struct shrinker___108 *, struct shrink_control___108 *);
	long unsigned int (*scan_objects)(struct shrinker___108 *, struct shrink_control___108 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct dev_pm_info___211 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___211 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___211;

struct bus_type___211;

struct device_driver___211;

struct dev_pm_domain___211;

struct dma_map_ops___54;

struct fwnode_handle___146;

struct class___211;

struct attribute_group___213;

struct device___211 {
	struct device___211 *parent;
	struct device_private *p;
	struct kobject___235 kobj;
	const char *init_name;
	const struct device_type___211 *type;
	struct mutex mutex;
	struct bus_type___211 *bus;
	struct device_driver___211 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___211 power;
	struct dev_pm_domain___211 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___54 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___146 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___211 *class;
	const struct attribute_group___213 **groups;
	void (*release)(struct device___211 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___246;

struct super_block___246;

struct dentry___247 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___247 *d_parent;
	struct qstr d_name;
	struct inode___247 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___246 *d_op;
	struct super_block___246 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___246;

struct block_device___247;

struct inode___247 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___246 *i_op;
	struct super_block___246 *i_sb;
	struct address_space___246 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___248 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___123 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___247 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___246 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___57 *i_pipe;
		struct block_device___247 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___246 {
	int (*d_revalidate)(struct dentry___247 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___247 *, unsigned int);
	int (*d_hash)(const struct dentry___247 *, struct qstr *);
	int (*d_compare)(const struct dentry___247 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___247 *);
	int (*d_init)(struct dentry___247 *);
	void (*d_release)(struct dentry___247 *);
	void (*d_prune)(struct dentry___247 *);
	void (*d_iput)(struct dentry___247 *, struct inode___247 *);
	char * (*d_dname)(struct dentry___247 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___247 *);
	int (*d_manage)(const struct path___247 *, bool);
	struct dentry___247 * (*d_real)(struct dentry___247 *, const struct inode___247 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___246;

struct mem_dqinfo___246 {
	struct quota_format_type___246 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___246;

struct quota_info___246 {
	unsigned int flags;
	struct rw_semaphore___248 dqio_sem;
	struct inode___247 *files[3];
	struct mem_dqinfo___246 info[3];
	const struct quota_format_ops___246 *ops[3];
};

struct rcuwait___246 {
	struct task_struct___248 *task;
};

struct percpu_rw_semaphore___246 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___248 rw_sem;
	struct rcuwait___246 writer;
	int readers_block;
};

struct sb_writers___246 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___246 rw_sem[3];
};

struct file_system_type___246;

struct super_operations___246;

struct dquot_operations___246;

struct quotactl_ops___246;

struct super_block___246 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___246 *s_type;
	const struct super_operations___246 *s_op;
	const struct dquot_operations___246 *dq_op;
	const struct quotactl_ops___246 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___247 *s_root;
	struct rw_semaphore___248 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___247 *s_bdev;
	struct backing_dev_info___123 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___246 s_dquot;
	struct sb_writers___246 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___246 *s_d_op;
	int cleancache_poolid;
	struct shrinker___108 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___207 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct iattr___246 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___247 *ia_file;
};

struct dquot___246 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___246 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___246 {
	int qf_fmt_id;
	const struct quota_format_ops___246 *qf_ops;
	struct module___201 *qf_owner;
	struct quota_format_type___246 *qf_next;
};

struct quota_format_ops___246 {
	int (*check_quota_file)(struct super_block___246 *, int);
	int (*read_file_info)(struct super_block___246 *, int);
	int (*write_file_info)(struct super_block___246 *, int);
	int (*free_file_info)(struct super_block___246 *, int);
	int (*read_dqblk)(struct dquot___246 *);
	int (*commit_dqblk)(struct dquot___246 *);
	int (*release_dqblk)(struct dquot___246 *);
	int (*get_next_id)(struct super_block___246 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___246 {
	int (*write_dquot)(struct dquot___246 *);
	struct dquot___246 * (*alloc_dquot)(struct super_block___246 *, int);
	void (*destroy_dquot)(struct dquot___246 *);
	int (*acquire_dquot)(struct dquot___246 *);
	int (*release_dquot)(struct dquot___246 *);
	int (*mark_dirty)(struct dquot___246 *);
	int (*write_info)(struct super_block___246 *, int);
	qsize_t * (*get_reserved_space)(struct inode___247 *);
	int (*get_projid)(struct inode___247 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___247 *, qsize_t *);
	int (*get_next_id)(struct super_block___246 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___246 {
	int (*quota_on)(struct super_block___246 *, int, int, const struct path___247 *);
	int (*quota_off)(struct super_block___246 *, int);
	int (*quota_enable)(struct super_block___246 *, unsigned int);
	int (*quota_disable)(struct super_block___246 *, unsigned int);
	int (*quota_sync)(struct super_block___246 *, int);
	int (*set_info)(struct super_block___246 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___246 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___246 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___246 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___246 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___246 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___119;

struct address_space_operations___246 {
	int (*writepage)(struct page___248 *, struct writeback_control___119 *);
	int (*readpage)(struct file___247 *, struct page___248 *);
	int (*writepages)(struct address_space___246 *, struct writeback_control___119 *);
	int (*set_page_dirty)(struct page___248 *);
	int (*readpages)(struct file___247 *, struct address_space___246 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___247 *, struct address_space___246 *, loff_t, unsigned int, unsigned int, struct page___248 **, void **);
	int (*write_end)(struct file___247 *, struct address_space___246 *, loff_t, unsigned int, unsigned int, struct page___248 *, void *);
	sector_t (*bmap)(struct address_space___246 *, sector_t);
	void (*invalidatepage)(struct page___248 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___248 *, gfp_t);
	void (*freepage)(struct page___248 *);
	ssize_t (*direct_IO)(struct kiocb___247 *, struct iov_iter___114 *);
	int (*migratepage)(struct address_space___246 *, struct page___248 *, struct page___248 *, enum migrate_mode);
	bool (*isolate_page)(struct page___248 *, isolate_mode_t);
	void (*putback_page)(struct page___248 *);
	int (*launder_page)(struct page___248 *);
	int (*is_partially_uptodate)(struct page___248 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___248 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___246 *, struct page___248 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___247 *, sector_t *);
	void (*swap_deactivate)(struct file___247 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___119 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___123 *wb;
	struct inode___247 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___247 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___247 *bd_inode;
	struct super_block___246 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___247 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___123 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___246 {
	struct dentry___247 * (*lookup)(struct inode___247 *, struct dentry___247 *, unsigned int);
	const char * (*get_link)(struct dentry___247 *, struct inode___247 *, struct delayed_call *);
	int (*permission)(struct inode___247 *, int);
	struct posix_acl * (*get_acl)(struct inode___247 *, int);
	int (*readlink)(struct dentry___247 *, char *, int);
	int (*create)(struct inode___247 *, struct dentry___247 *, umode_t, bool);
	int (*link)(struct dentry___247 *, struct inode___247 *, struct dentry___247 *);
	int (*unlink)(struct inode___247 *, struct dentry___247 *);
	int (*symlink)(struct inode___247 *, struct dentry___247 *, const char *);
	int (*mkdir)(struct inode___247 *, struct dentry___247 *, umode_t);
	int (*rmdir)(struct inode___247 *, struct dentry___247 *);
	int (*mknod)(struct inode___247 *, struct dentry___247 *, umode_t, dev_t);
	int (*rename)(struct inode___247 *, struct dentry___247 *, struct inode___247 *, struct dentry___247 *, unsigned int);
	int (*setattr)(struct dentry___247 *, struct iattr___246 *);
	int (*getattr)(const struct path___247 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___247 *, char *, size_t);
	int (*fiemap)(struct inode___247 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___247 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___247 *, struct dentry___247 *, struct file___247 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___247 *, struct dentry___247 *, umode_t);
	int (*set_acl)(struct inode___247 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___246 {
	void (*fl_copy_lock)(struct file_lock___247 *, struct file_lock___247 *);
	void (*fl_release_private)(struct file_lock___247 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___246;

struct file_lock___247 {
	struct file_lock___247 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___247 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___246 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___246 *fl_ops;
	const struct lock_manager_operations___246 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___246 {
	int (*lm_compare_owner)(struct file_lock___247 *, struct file_lock___247 *);
	long unsigned int (*lm_owner_key)(struct file_lock___247 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___247 *);
	int (*lm_grant)(struct file_lock___247 *, int);
	bool (*lm_break)(struct file_lock___247 *);
	int (*lm_change)(struct file_lock___247 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___247 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___246 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___246 *fa_next;
	struct file___247 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___246 {
	const char *name;
	int fs_flags;
	struct dentry___247 * (*mount)(struct file_system_type___246 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___246 *);
	struct module___201 *owner;
	struct file_system_type___246 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___246 {
	struct inode___247 * (*alloc_inode)(struct super_block___246 *);
	void (*destroy_inode)(struct inode___247 *);
	void (*dirty_inode)(struct inode___247 *, int);
	int (*write_inode)(struct inode___247 *, struct writeback_control___119 *);
	int (*drop_inode)(struct inode___247 *);
	void (*evict_inode)(struct inode___247 *);
	void (*put_super)(struct super_block___246 *);
	int (*sync_fs)(struct super_block___246 *, int);
	int (*freeze_super)(struct super_block___246 *);
	int (*freeze_fs)(struct super_block___246 *);
	int (*thaw_super)(struct super_block___246 *);
	int (*unfreeze_fs)(struct super_block___246 *);
	int (*statfs)(struct dentry___247 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___246 *, int *, char *);
	void (*umount_begin)(struct super_block___246 *);
	int (*show_options)(struct seq_file___223 *, struct dentry___247 *);
	int (*show_devname)(struct seq_file___223 *, struct dentry___247 *);
	int (*show_path)(struct seq_file___223 *, struct dentry___247 *);
	int (*show_stats)(struct seq_file___223 *, struct dentry___247 *);
	ssize_t (*quota_read)(struct super_block___246 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___246 *, int, const char *, size_t, loff_t);
	struct dquot___246 ** (*get_dquots)(struct inode___247 *);
	int (*bdev_try_to_free_page)(struct super_block___246 *, struct page___248 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___246 *, struct shrink_control___108 *);
	long int (*free_cached_objects)(struct super_block___246 *, struct shrink_control___108 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___157)(struct file___247 *, wait_queue_head_t *, struct poll_table_struct___155 *);

struct poll_table_struct___155 {
	poll_queue_proc___157 _qproc;
	__poll_t _key;
};

struct seq_operations___221;

struct seq_file___223 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___221 *op;
	int poll_event;
	const struct file___247 *file;
	void *private;
};

typedef void bio_end_io_t___123(struct bio___123 *);

struct bio_integrity_payload___123;

struct bio_set___123;

struct bio___123 {
	struct bio___123 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___123 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___123 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___123 *bi_io_vec;
	struct bio_set___123 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___123 bi_inline_vecs[0];
};

struct kobj_attribute___228 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___235 *, struct kobj_attribute___228 *, char *);
	ssize_t (*store)(struct kobject___235 *, struct kobj_attribute___228 *, const char *, size_t);
};

typedef void compound_page_dtor___237(struct page___248 *);

struct inet_frags___33;

struct netns_frags___33 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___33 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ip_ra_chain___10;

struct fib_rules_ops___22;

struct sock___24;

struct fib_notifier_ops___22;

struct netns_ipv4___33 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___10 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___22 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___24 *fibnl;
	struct sock___24 **icmp_sk;
	struct sock___24 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___24 **tcp_sk;
	struct netns_frags___33 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___22 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___22 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___22 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct dst_entry___23;

struct net_device___37;

struct sk_buff___37;

struct neighbour___23;

struct dst_ops___43 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___43 *);
	struct dst_entry___23 * (*check)(struct dst_entry___23 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___23 *);
	unsigned int (*mtu)(const struct dst_entry___23 *);
	u32 * (*cow_metrics)(struct dst_entry___23 *, long unsigned int);
	void (*destroy)(struct dst_entry___23 *);
	void (*ifdown)(struct dst_entry___23 *, struct net_device___37 *, int);
	struct dst_entry___23 * (*negative_advice)(struct dst_entry___23 *);
	void (*link_failure)(struct sk_buff___37 *);
	void (*update_pmtu)(struct dst_entry___23 *, struct sock___24 *, struct sk_buff___37 *, u32);
	void (*redirect)(struct dst_entry___23 *, struct sock___24 *, struct sk_buff___37 *);
	int (*local_out)(struct net___45 *, struct sock___24 *, struct sk_buff___37 *);
	struct neighbour___23 * (*neigh_lookup)(const struct dst_entry___23 *, struct sk_buff___37 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___23 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___43 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___33 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___43 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___22 *fib6_rules_ops;
	struct sock___24 **icmp_sk;
	struct sock___24 *ndisc_sk;
	struct sock___24 *tcp_sk;
	struct sock___24 *igmp_sk;
	struct sock___24 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___22 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___22 *notifier_ops;
	struct fib_notifier_ops___22 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___23 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___24 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___33 {
	struct netns_frags___33 frags;
};

struct netns_xfrm___43 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___24 *nlsk;
	struct sock___24 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___43 xfrm4_dst_ops;
	struct dst_ops___43 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___32;

struct net___45 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___207 *user_ns;
	struct ucounts___207 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___28 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___24 *rtnl;
	struct sock___24 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___37 *loopback_dev;
	struct netns_core core;
	struct netns_mib___2 mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___33 ipv4;
	struct netns_ipv6___43 ipv6;
	struct netns_sctp___23 sctp;
	struct netns_nf___2 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___33 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___24 *nfnl;
	struct sock___24 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___43 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can___2 can;
	struct sock___24 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___32 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cgroup_namespace___192 {
	refcount_t count;
	struct ns_common___28 ns;
	struct user_namespace___207 *user_ns;
	struct ucounts___207 *ucounts;
	struct css_set___192 *root_cset;
};

struct ucounts___207 {
	struct hlist_node node;
	struct user_namespace___207 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct socket_wq___23 {
	wait_queue_head_t wait;
	struct fasync_struct___246 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___23;

struct socket___24 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___23 *wq;
	struct file___247 *file;
	struct sock___24 *sk;
	const struct proto_ops___23 *ops;
};

typedef struct {
	struct net___45 *net;
} possible_net_t___34;

struct proto___22;

struct sock_common___22 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___22 *skc_prot;
	possible_net_t___34 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___24 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff_head___33 {
	struct sk_buff___37 *next;
	struct sk_buff___37 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___22;

struct sock___24 {
	struct sock_common___22 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___33 sk_error_queue;
	struct sk_buff_head___33 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___37 *head;
		struct sk_buff___37 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___22 *sk_filter;
	union {
		struct socket_wq___23 *sk_wq;
		struct socket_wq___23 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___23 *sk_rx_dst;
	struct dst_entry___23 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___37 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___33 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___247 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___22 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___187 *sk_peer_pid;
	const struct cred___240 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___24 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___108 *sk_memcg;
	void (*sk_state_change)(struct sock___24 *);
	void (*sk_data_ready)(struct sock___24 *);
	void (*sk_write_space)(struct sock___24 *);
	void (*sk_error_report)(struct sock___24 *);
	int (*sk_backlog_rcv)(struct sock___24 *, struct sk_buff___37 *);
	struct sk_buff___37 * (*sk_validate_xmit_skb)(struct sock___24 *, struct net_device___37 *, struct sk_buff___37 *);
	void (*sk_destruct)(struct sock___24 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

typedef int (*sk_read_actor_t___22)(read_descriptor_t *, struct sk_buff___37 *, unsigned int, size_t);

struct proto_ops___23 {
	int family;
	struct module___201 *owner;
	int (*release)(struct socket___24 *);
	int (*bind)(struct socket___24 *, struct sockaddr *, int);
	int (*connect)(struct socket___24 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___24 *, struct socket___24 *);
	int (*accept)(struct socket___24 *, struct socket___24 *, int, bool);
	int (*getname)(struct socket___24 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___247 *, struct socket___24 *, struct poll_table_struct___155 *);
	int (*ioctl)(struct socket___24 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___24 *, int);
	int (*shutdown)(struct socket___24 *, int);
	int (*setsockopt)(struct socket___24 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___24 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___24 *, struct msghdr___24 *, size_t);
	int (*recvmsg)(struct socket___24 *, struct msghdr___24 *, size_t, int);
	int (*mmap)(struct file___247 *, struct socket___24 *, struct vm_area_struct___248 *);
	ssize_t (*sendpage)(struct socket___24 *, struct page___248 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___24 *, loff_t *, struct pipe_inode_info___57 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___24 *, int);
	int (*peek_len)(struct socket___24 *);
	int (*read_sock)(struct sock___24 *, read_descriptor_t *, sk_read_actor_t___22);
	int (*sendpage_locked)(struct sock___24 *, struct page___248 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___24 *, struct msghdr___24 *, size_t);
	int (*set_rcvlowat)(struct sock___24 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct nf_bridge_info___33;

struct sk_buff___37 {
	union {
		struct {
			struct sk_buff___37 *next;
			struct sk_buff___37 *prev;
			union {
				struct net_device___37 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___24 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___37 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___33 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct kernfs_root___241;

struct kernfs_elem_dir___241 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___241 *root;
};

struct kernfs_syscall_ops___241;

struct kernfs_root___241 {
	struct kernfs_node___241 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___241 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___241 {
	struct kernfs_node___241 *target_kn;
};

struct kernfs_ops___241;

struct kernfs_elem_attr___241 {
	const struct kernfs_ops___241 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___241 *notify_next;
};

struct kernfs_node___241 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___241 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___241 dir;
		struct kernfs_elem_symlink___241 symlink;
		struct kernfs_elem_attr___241 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___241;

struct kernfs_ops___241 {
	int (*open)(struct kernfs_open_file___241 *);
	void (*release)(struct kernfs_open_file___241 *);
	int (*seq_show)(struct seq_file___223 *, void *);
	void * (*seq_start)(struct seq_file___223 *, loff_t *);
	void * (*seq_next)(struct seq_file___223 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___223 *, void *);
	ssize_t (*read)(struct kernfs_open_file___241 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___241 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___241 *, struct vm_area_struct___248 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___241 *, struct poll_table_struct___155 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___241 {
	int (*remount_fs)(struct kernfs_root___241 *, int *, char *);
	int (*show_options)(struct seq_file___223 *, struct kernfs_root___241 *);
	int (*mkdir)(struct kernfs_node___241 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___241 *);
	int (*rename)(struct kernfs_node___241 *, struct kernfs_node___241 *, const char *);
	int (*show_path)(struct seq_file___223 *, struct kernfs_node___241 *, struct kernfs_root___241 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___241 {
	struct kernfs_node___241 *kn;
	struct file___247 *file;
	struct seq_file___223 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___237 *vm_ops;
};

struct kobj_ns_type_operations___22 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___24 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___212;

struct attribute_group___213 {
	const char *name;
	umode_t (*is_visible)(struct kobject___235 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___235 *, struct bin_attribute___212 *, int);
	struct attribute **attrs;
	struct bin_attribute___212 **bin_attrs;
};

struct bin_attribute___212 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___247 *, struct kobject___235 *, struct bin_attribute___212 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___247 *, struct kobject___235 *, struct bin_attribute___212 *, char *, loff_t, size_t);
	int (*mmap)(struct file___247 *, struct kobject___235 *, struct bin_attribute___212 *, struct vm_area_struct___248 *);
};

struct sysfs_ops___234 {
	ssize_t (*show)(struct kobject___235 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___235 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___234;

struct kset___234 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___235 kobj;
	const struct kset_uevent_ops___234 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___234 {
	void (*release)(struct kobject___235 *);
	const struct sysfs_ops___234 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___22 * (*child_ns_type)(struct kobject___235 *);
	const void * (*namespace)(struct kobject___235 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___234 {
	int (* const filter)(struct kset___234 *, struct kobject___235 *);
	const char * (* const name)(struct kset___234 *, struct kobject___235 *);
	int (* const uevent)(struct kset___234 *, struct kobject___235 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___211 {
	int (*prepare)(struct device___211 *);
	void (*complete)(struct device___211 *);
	int (*suspend)(struct device___211 *);
	int (*resume)(struct device___211 *);
	int (*freeze)(struct device___211 *);
	int (*thaw)(struct device___211 *);
	int (*poweroff)(struct device___211 *);
	int (*restore)(struct device___211 *);
	int (*suspend_late)(struct device___211 *);
	int (*resume_early)(struct device___211 *);
	int (*freeze_late)(struct device___211 *);
	int (*thaw_early)(struct device___211 *);
	int (*poweroff_late)(struct device___211 *);
	int (*restore_early)(struct device___211 *);
	int (*suspend_noirq)(struct device___211 *);
	int (*resume_noirq)(struct device___211 *);
	int (*freeze_noirq)(struct device___211 *);
	int (*thaw_noirq)(struct device___211 *);
	int (*poweroff_noirq)(struct device___211 *);
	int (*restore_noirq)(struct device___211 *);
	int (*runtime_suspend)(struct device___211 *);
	int (*runtime_resume)(struct device___211 *);
	int (*runtime_idle)(struct device___211 *);
};

struct dev_pm_domain___211 {
	struct dev_pm_ops___211 ops;
	void (*detach)(struct device___211 *, bool);
	int (*activate)(struct device___211 *);
	void (*sync)(struct device___211 *);
	void (*dismiss)(struct device___211 *);
};

struct bus_type___211 {
	const char *name;
	const char *dev_name;
	struct device___211 *dev_root;
	const struct attribute_group___213 **bus_groups;
	const struct attribute_group___213 **dev_groups;
	const struct attribute_group___213 **drv_groups;
	int (*match)(struct device___211 *, struct device_driver___211 *);
	int (*uevent)(struct device___211 *, struct kobj_uevent_env *);
	int (*probe)(struct device___211 *);
	int (*remove)(struct device___211 *);
	void (*shutdown)(struct device___211 *);
	int (*online)(struct device___211 *);
	int (*offline)(struct device___211 *);
	int (*suspend)(struct device___211 *, pm_message_t);
	int (*resume)(struct device___211 *);
	int (*num_vf)(struct device___211 *);
	int (*dma_configure)(struct device___211 *);
	const struct dev_pm_ops___211 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___211 {
	const char *name;
	struct bus_type___211 *bus;
	struct module___201 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___211 *);
	int (*remove)(struct device___211 *);
	void (*shutdown)(struct device___211 *);
	int (*suspend)(struct device___211 *, pm_message_t);
	int (*resume)(struct device___211 *);
	const struct attribute_group___213 **groups;
	const struct dev_pm_ops___211 *pm;
	void (*coredump)(struct device___211 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___211 {
	const char *name;
	const struct attribute_group___213 **groups;
	int (*uevent)(struct device___211 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___211 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___211 *);
	const struct dev_pm_ops___211 *pm;
};

struct class___211 {
	const char *name;
	struct module___201 *owner;
	const struct attribute_group___213 **class_groups;
	const struct attribute_group___213 **dev_groups;
	struct kobject___235 *dev_kobj;
	int (*dev_uevent)(struct device___211 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___211 *, umode_t *);
	void (*class_release)(struct class___211 *);
	void (*dev_release)(struct device___211 *);
	int (*shutdown_pre)(struct device___211 *);
	const struct kobj_ns_type_operations___22 *ns_type;
	const void * (*namespace)(struct device___211 *);
	const struct dev_pm_ops___211 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___54 {
	void * (*alloc)(struct device___211 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___211 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___211 *, struct vm_area_struct___248 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___211 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___211 *, struct page___248 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___211 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___211 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___211 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___211 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___211 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___211 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___211 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___211 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___211 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___211 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___211 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___211 *, u64);
	u64 (*get_required_mask)(struct device___211 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___146;

struct fwnode_handle___146 {
	struct fwnode_handle___146 *secondary;
	const struct fwnode_operations___146 *ops;
};

struct fwnode_reference_args___146;

struct fwnode_endpoint___146;

struct fwnode_operations___146 {
	struct fwnode_handle___146 * (*get)(struct fwnode_handle___146 *);
	void (*put)(struct fwnode_handle___146 *);
	bool (*device_is_available)(const struct fwnode_handle___146 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___146 *, const struct device___211 *);
	bool (*property_present)(const struct fwnode_handle___146 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___146 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___146 *, const char *, const char **, size_t);
	struct fwnode_handle___146 * (*get_parent)(const struct fwnode_handle___146 *);
	struct fwnode_handle___146 * (*get_next_child_node)(const struct fwnode_handle___146 *, struct fwnode_handle___146 *);
	struct fwnode_handle___146 * (*get_named_child_node)(const struct fwnode_handle___146 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___146 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___146 *);
	struct fwnode_handle___146 * (*graph_get_next_endpoint)(const struct fwnode_handle___146 *, struct fwnode_handle___146 *);
	struct fwnode_handle___146 * (*graph_get_remote_endpoint)(const struct fwnode_handle___146 *);
	struct fwnode_handle___146 * (*graph_get_port_parent)(struct fwnode_handle___146 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___146 *, struct fwnode_endpoint___146 *);
};

struct fwnode_endpoint___146 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___146 *local_fwnode;
};

struct fwnode_reference_args___146 {
	struct fwnode_handle___146 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___57;

struct pipe_buffer___57 {
	struct page___248 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___57 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___57 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___57 *, struct pipe_buffer___57 *);
	void (*release)(struct pipe_inode_info___57 *, struct pipe_buffer___57 *);
	int (*steal)(struct pipe_inode_info___57 *, struct pipe_buffer___57 *);
	union {
		bool (*get)(struct pipe_inode_info___57 *, struct pipe_buffer___57 *);
		struct {
			void (*get)(struct pipe_inode_info___57 *, struct pipe_buffer___57 *);
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
};

struct nf_bridge_info___33 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___33 = 0,
		BRNF_PROTO_8021Q___33 = 1,
		BRNF_PROTO_PPPOE___33 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___37 *physindev;
	struct net_device___37 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___33(struct sk_buff___37 **);

struct net_device_ops___33;

struct ethtool_ops___33;

struct l3mdev_ops___23;

struct ndisc_ops___14;

struct xfrmdev_ops___33;

struct tlsdev_ops___33;

struct header_ops___33;

struct inet6_dev___14;

struct netdev_rx_queue___33;

struct mini_Qdisc___32;

struct netdev_queue___33;

struct Qdisc___32;

struct rtnl_link_ops___32;

struct dcbnl_rtnl_ops___33;

struct net_device___37 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___33 *netdev_ops;
	const struct ethtool_ops___33 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___23 *l3mdev_ops;
	const struct ndisc_ops___14 *ndisc_ops;
	const struct xfrmdev_ops___33 *xfrmdev_ops;
	const struct tlsdev_ops___33 *tlsdev_ops;
	const struct header_ops___33 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___234 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___14 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___33 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___32 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___33 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___32 *miniq_ingress;
	struct netdev_queue___33 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___33 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___32 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___32 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___33 = 0,
		NETREG_REGISTERED___33 = 1,
		NETREG_UNREGISTERING___33 = 2,
		NETREG_UNREGISTERED___33 = 3,
		NETREG_RELEASED___33 = 4,
		NETREG_DUMMY___33 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___33 = 0,
		RTNL_LINK_INITIALIZING___33 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___37 *);
	struct netpoll_info *npinfo;
	possible_net_t___34 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___211 dev;
	const struct attribute_group___213 *sysfs_groups[4];
	const struct attribute_group___213 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___32 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___33 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct netlink_callback___33 {
	struct sk_buff___37 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___33 *);
	int (*dump)(struct sk_buff___37 *, struct netlink_callback___33 *);
	int (*done)(struct netlink_callback___33 *);
	void *data;
	struct module___201 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct ethtool_ops___33 {
	int (*get_settings)(struct net_device___37 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___37 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___37 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___37 *);
	void (*get_regs)(struct net_device___37 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___37 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___37 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___37 *);
	void (*set_msglevel)(struct net_device___37 *, u32);
	int (*nway_reset)(struct net_device___37 *);
	u32 (*get_link)(struct net_device___37 *);
	int (*get_eeprom_len)(struct net_device___37 *);
	int (*get_eeprom)(struct net_device___37 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___37 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___37 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___37 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___37 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___37 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___37 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___37 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___37 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___37 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___37 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___37 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___37 *);
	void (*complete)(struct net_device___37 *);
	u32 (*get_priv_flags)(struct net_device___37 *);
	int (*set_priv_flags)(struct net_device___37 *, u32);
	int (*get_sset_count)(struct net_device___37 *, int);
	int (*get_rxnfc)(struct net_device___37 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___37 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___37 *, struct ethtool_flash *);
	int (*reset)(struct net_device___37 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___37 *);
	u32 (*get_rxfh_indir_size)(struct net_device___37 *);
	int (*get_rxfh)(struct net_device___37 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___37 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___37 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___37 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___37 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___37 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___37 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___37 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___37 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___37 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___37 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___37 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___37 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___37 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___37 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___37 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___37 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___37 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___37 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___37 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___37 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___37 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	int (*get_fecparam)(struct net_device___37 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___37 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___37 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___37 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___37 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___33;

struct inet_frags___33 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___33 *, const void *);
	void (*destructor)(struct inet_frag_queue___33 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___33 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___37 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___37 *fragments_tail;
	struct sk_buff___37 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___33 *net;
	struct callback_head rcu;
};

struct ip_ra_chain___10 {
	struct ip_ra_chain___10 *next;
	struct sock___24 *sk;
	union {
		void (*destructor)(struct sock___24 *);
		struct sock___24 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___22;

struct fib_lookup_arg___22;

struct fib_rules_ops___22 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___22 *, struct flowi *, int, struct fib_lookup_arg___22 *);
	bool (*suppress)(struct fib_rule___22 *, struct fib_lookup_arg___22 *);
	int (*match)(struct fib_rule___22 *, struct flowi *, int);
	int (*configure)(struct fib_rule___22 *, struct sk_buff___37 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___22 *);
	int (*compare)(struct fib_rule___22 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___22 *, struct sk_buff___37 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___22 *);
	void (*flush_cache)(struct fib_rules_ops___22 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___201 *owner;
	struct net___45 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___22 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___45 *);
	int (*fib_dump)(struct net___45 *, struct notifier_block *);
	struct module___201 *owner;
	struct callback_head rcu;
};

struct dst_entry___23 {
	struct net_device___37 *dev;
	struct dst_ops___43 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___37 *);
	int (*output)(struct net___45 *, struct sock___24 *, struct sk_buff___37 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___22;

struct neigh_parms___23;

struct neigh_ops___22;

struct neighbour___23 {
	struct neighbour___23 *next;
	struct neigh_table___22 *tbl;
	struct neigh_parms___23 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___33 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___23 *, struct sk_buff___37 *);
	const struct neigh_ops___22 *ops;
	struct callback_head rcu;
	struct net_device___37 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct bpf_prog_aux___34;

struct bpf_prog___32 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___34 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

struct seq_operations___221 {
	void * (*start)(struct seq_file___223 *, loff_t *);
	void (*stop)(struct seq_file___223 *, void *);
	void * (*next)(struct seq_file___223 *, void *, loff_t *);
	int (*show)(struct seq_file___223 *, void *);
};

struct pernet_operations___34 {
	struct list_head list;
	int (*init)(struct net___45 *);
	void (*exit)(struct net___45 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___33 {
	int (*ieee_getets)(struct net_device___37 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___37 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___37 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___37 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___37 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___37 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___37 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___37 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___37 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___37 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___37 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___37 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___37 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___37 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___37 *);
	u8 (*setstate)(struct net_device___37 *, u8);
	void (*getpermhwaddr)(struct net_device___37 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___37 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___37 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___37 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___37 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___37 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___37 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___37 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___37 *, int, u8 *);
	void (*setpfccfg)(struct net_device___37 *, int, u8);
	void (*getpfccfg)(struct net_device___37 *, int, u8 *);
	u8 (*setall)(struct net_device___37 *);
	u8 (*getcap)(struct net_device___37 *, int, u8 *);
	int (*getnumtcs)(struct net_device___37 *, int, u8 *);
	int (*setnumtcs)(struct net_device___37 *, int, u8);
	u8 (*getpfcstate)(struct net_device___37 *);
	void (*setpfcstate)(struct net_device___37 *, u8);
	void (*getbcncfg)(struct net_device___37 *, int, u32 *);
	void (*setbcncfg)(struct net_device___37 *, int, u32);
	void (*getbcnrp)(struct net_device___37 *, int, u8 *);
	void (*setbcnrp)(struct net_device___37 *, int, u8);
	int (*setapp)(struct net_device___37 *, u8, u16, u8);
	int (*getapp)(struct net_device___37 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___37 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___37 *, int, u8);
	u8 (*getdcbx)(struct net_device___37 *);
	u8 (*setdcbx)(struct net_device___37 *, u8);
	int (*peer_getappinfo)(struct net_device___37 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___37 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___37 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___37 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___37 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___37 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct bpf_map___192;

struct bpf_map_ops___192 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___192 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___192 *, struct file___247 *);
	void (*map_free)(struct bpf_map___192 *);
	int (*map_get_next_key)(struct bpf_map___192 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___192 *);
	void * (*map_lookup_elem)(struct bpf_map___192 *, void *);
	int (*map_update_elem)(struct bpf_map___192 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___192 *, void *);
	int (*map_push_elem)(struct bpf_map___192 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___192 *, void *);
	int (*map_peek_elem)(struct bpf_map___192 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___192 *, struct file___247 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___192 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___192 *, void *, struct seq_file___223 *);
	int (*map_check_btf)(const struct bpf_map___192 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___192 {
	const struct bpf_map_ops___192 *ops;
	struct bpf_map___192 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___240 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___33;

struct bpf_map_dev_ops___33 {
	int (*map_get_next_key)(struct bpf_offloaded_map___33 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___33 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___33 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___33 *, void *);
};

struct bpf_offloaded_map___33 {
	struct bpf_map___192 map;
	struct net_device___37 *netdev;
	const struct bpf_map_dev_ops___33 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___32 {
	int (*test_run)(struct bpf_prog___32 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___32 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___32 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___32 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___32 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___32 *, u32 *);
};

struct bpf_prog_offload_ops___32 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___32 *);
	int (*translate)(struct bpf_prog___32 *);
	void (*destroy)(struct bpf_prog___32 *);
};

struct bpf_prog_offload___32 {
	struct bpf_prog___32 *prog;
	struct net_device___37 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___32 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___34 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___32 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___32 *ops;
	struct bpf_map___192 **used_maps;
	struct bpf_prog___32 *prog;
	struct user_struct___240 *user;
	u64 load_time;
	struct bpf_map___192 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___32 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___32 {
	struct bpf_prog___32 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___32 {
	struct callback_head rcu;
	struct bpf_prog_array_item___32 items[0];
};

struct cgroup_bpf___32 {
	struct bpf_prog_array___32 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___32 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___192;

typedef void (*kthread_work_func_t___192)(struct kthread_work___192 *);

struct kthread_worker___192;

struct kthread_work___192 {
	struct list_head node;
	kthread_work_func_t___192 func;
	struct kthread_worker___192 *worker;
	int canceling;
};

struct kthread_worker___192 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___248 *task;
	struct kthread_work___192 *current_work;
};

struct kthread_delayed_work___192 {
	struct kthread_work___192 work;
	struct timer_list timer;
};

struct psi_group___192 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___192 *poll_kworker;
	struct kthread_delayed_work___192 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___192;

struct cgroup_rstat_cpu___192;

struct cgroup___192 {
	struct cgroup_subsys_state___193 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___241 *kn;
	struct cgroup_file___192 procs_file;
	struct cgroup_file___192 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___193 *subsys[13];
	struct cgroup_root___192 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___192 *dom_cgrp;
	struct cgroup_rstat_cpu___192 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___32 bpf;
	atomic_t congestion_count;
	struct cgroup___192 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___192 psi;
	int ancestor_ids[0];
};

struct cftype___192;

struct cgroup_subsys___192 {
	struct cgroup_subsys_state___193 * (*css_alloc)(struct cgroup_subsys_state___193 *);
	int (*css_online)(struct cgroup_subsys_state___193 *);
	void (*css_offline)(struct cgroup_subsys_state___193 *);
	void (*css_released)(struct cgroup_subsys_state___193 *);
	void (*css_free)(struct cgroup_subsys_state___193 *);
	void (*css_reset)(struct cgroup_subsys_state___193 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___193 *, int);
	int (*css_extra_stat_show)(struct seq_file___223 *, struct cgroup_subsys_state___193 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___248 *);
	void (*cancel_fork)(struct task_struct___248 *);
	void (*fork)(struct task_struct___248 *);
	void (*exit)(struct task_struct___248 *);
	void (*free)(struct task_struct___248 *);
	void (*bind)(struct cgroup_subsys_state___193 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___192 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___192 *dfl_cftypes;
	struct cftype___192 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___192 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___192 *updated_children;
	struct cgroup___192 *updated_next;
};

struct cgroup_root___192 {
	struct kernfs_root___241 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___192 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___192 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___192 *ss;
	struct list_head node;
	struct kernfs_ops___241 *kf_ops;
	int (*open)(struct kernfs_open_file___241 *);
	void (*release)(struct kernfs_open_file___241 *);
	u64 (*read_u64)(struct cgroup_subsys_state___193 *, struct cftype___192 *);
	s64 (*read_s64)(struct cgroup_subsys_state___193 *, struct cftype___192 *);
	int (*seq_show)(struct seq_file___223 *, void *);
	void * (*seq_start)(struct seq_file___223 *, loff_t *);
	void * (*seq_next)(struct seq_file___223 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___223 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___193 *, struct cftype___192 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___193 *, struct cftype___192 *, s64);
	ssize_t (*write)(struct kernfs_open_file___241 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___241 *, struct poll_table_struct___155 *);
};

struct xdp_rxq_info___33 {
	struct net_device___37 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___33 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___37 *dev_rx;
};

struct header_ops___33 {
	int (*create)(struct sk_buff___37 *, struct net_device___37 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___37 *, unsigned char *);
	int (*cache)(const struct neighbour___23 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___37 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___33 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___33 *, int);
	int poll_owner;
	struct net_device___37 *dev;
	struct sk_buff___37 *gro_list;
	struct sk_buff___37 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___33 {
	struct net_device___37 *dev;
	struct Qdisc___32 *qdisc;
	struct Qdisc___32 *qdisc_sleeping;
	struct kobject___235 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___37 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___32 {
	struct sk_buff___37 *head;
	struct sk_buff___37 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___32;

struct Qdisc___32 {
	int (*enqueue)(struct sk_buff___37 *, struct Qdisc___32 *, struct sk_buff___37 **);
	struct sk_buff___37 * (*dequeue)(struct Qdisc___32 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___32 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___33 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___33 gso_skb;
	struct qdisc_skb_head___32 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___32 *next_sched;
	struct sk_buff_head___33 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___33 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___235 kobj;
	struct net_device___37 *dev;
	long: 64;
	struct xdp_rxq_info___33 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___33)(struct net_device___37 *, struct sk_buff___37 *, struct net_device___37 *);

struct netdev_bpf___33 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___32 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___32 *prog;
			const struct bpf_prog_offload_ops___32 *ops;
		} verifier;
		struct {
			struct bpf_prog___32 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___33 *offmap;
		};
		struct {
			struct xdp_umem *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___33 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___37 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___33 {
	int (*tls_dev_add)(struct net_device___37 *, struct sock___24 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___37 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___37 *, struct sock___24 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___33 {
	int (*ndo_init)(struct net_device___37 *);
	void (*ndo_uninit)(struct net_device___37 *);
	int (*ndo_open)(struct net_device___37 *);
	int (*ndo_stop)(struct net_device___37 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___37 *, struct net_device___37 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___37 *, struct net_device___37 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___37 *, struct sk_buff___37 *, struct net_device___37 *, select_queue_fallback_t___33);
	void (*ndo_change_rx_flags)(struct net_device___37 *, int);
	void (*ndo_set_rx_mode)(struct net_device___37 *);
	int (*ndo_set_mac_address)(struct net_device___37 *, void *);
	int (*ndo_validate_addr)(struct net_device___37 *);
	int (*ndo_do_ioctl)(struct net_device___37 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___37 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___37 *, int);
	int (*ndo_neigh_setup)(struct net_device___37 *, struct neigh_parms___23 *);
	void (*ndo_tx_timeout)(struct net_device___37 *);
	void (*ndo_get_stats64)(struct net_device___37 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___37 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___37 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___37 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___37 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___37 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___37 *);
	int (*ndo_netpoll_setup)(struct net_device___37 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___37 *);
	int (*ndo_set_vf_mac)(struct net_device___37 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___37 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___37 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___37 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___37 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___37 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___37 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___37 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___37 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___37 *, int, struct sk_buff___37 *);
	int (*ndo_set_vf_guid)(struct net_device___37 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___37 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___37 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___37 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___37 *, const struct sk_buff___37 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___37 *, struct net_device___37 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___37 *, struct net_device___37 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___37 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___37 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___37 *, struct neighbour___23 *);
	void (*ndo_neigh_destroy)(struct net_device___37 *, struct neighbour___23 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___37 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___37 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___37 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___37 *, struct netlink_callback___33 *, struct net_device___37 *, struct net_device___37 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___37 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___37 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___37 *, u32, u32, struct net_device___37 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___37 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___37 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___37 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___37 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___37 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___37 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___37 *, struct net_device___37 *);
	void (*ndo_dfwd_del_station)(struct net_device___37 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___37 *);
	int (*ndo_set_tx_maxrate)(struct net_device___37 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___37 *);
	int (*ndo_change_proto_down)(struct net_device___37 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___37 *, struct sk_buff___37 *);
	void (*ndo_set_rx_headroom)(struct net_device___37 *, int);
	int (*ndo_bpf)(struct net_device___37 *, struct netdev_bpf___33 *);
	int (*ndo_xdp_xmit)(struct net_device___37 *, int, struct xdp_frame___33 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___37 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___37 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___23 {
	possible_net_t___34 net;
	struct net_device___37 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___23 *);
	void (*neigh_cleanup)(struct neighbour___23 *);
	struct neigh_table___22 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___23 {
	u32 (*l3mdev_fib_table)(const struct net_device___37 *);
	struct sk_buff___37 * (*l3mdev_l3_rcv)(struct net_device___37 *, struct sk_buff___37 *, u16);
	struct sk_buff___37 * (*l3mdev_l3_out)(struct net_device___37 *, struct sock___24 *, struct sk_buff___37 *, u16);
	struct dst_entry___23 * (*l3mdev_link_scope_lookup)(const struct net_device___37 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct ndisc_ops___14 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___37 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___37 *, struct neighbour___23 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___37 *, u8, struct neighbour___23 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___37 *, struct sk_buff___37 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___45 *, struct net_device___37 *, const struct prefix_info *, struct inet6_dev___14 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___13;

struct inet6_dev___14 {
	struct net_device___37 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___13 *mc_list;
	struct ifmcaddr6___13 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	u8 rndid[8];
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___23 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
};

struct tcf_proto___32;

struct mini_Qdisc___32 {
	struct tcf_proto___32 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___32 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___37 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___45 *, struct net_device___37 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___37 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___37 *, struct list_head *);
	size_t (*get_size)(const struct net_device___37 *);
	int (*fill_info)(struct sk_buff___37 *, const struct net_device___37 *);
	size_t (*get_xstats_size)(const struct net_device___37 *);
	int (*fill_xstats)(struct sk_buff___37 *, const struct net_device___37 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___37 *, struct net_device___37 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___37 *, const struct net_device___37 *);
	int (*fill_slave_info)(struct sk_buff___37 *, const struct net_device___37 *, const struct net_device___37 *);
	struct net___45 * (*get_link_net)(const struct net_device___37 *);
	size_t (*get_linkxstats_size)(const struct net_device___37 *, int);
	int (*fill_linkxstats)(struct sk_buff___37 *, const struct net_device___37 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___33 {
	struct list_head poll_list;
	struct sk_buff_head___33 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___33 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___32 *output_queue;
	struct Qdisc___32 **output_queue_tailp;
	struct sk_buff___37 *completion_queue;
	struct sk_buff_head___33 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___33 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___33 input_pkt_queue;
	struct napi_struct___33 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bdi_writeback_congested___123 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___123 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___123 {
	struct bio___123 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___123 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___123 bip_inline_vecs[0];
};

struct bio_set___123 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___123 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___108 {
	struct mem_cgroup___108 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___108 {
	struct lruvec___247 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___108 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___108 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct kernel_param_ops___198 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___198 *);
	int (*get)(char *, const struct kernel_param___198 *);
	void (*free)(void *);
};

struct kparam_array___198;

struct kernel_param___198 {
	const char *name;
	struct module___201 *mod;
	const struct kernel_param_ops___198 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___198 *arr;
	};
};

struct kparam_array___198 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___198 *ops;
	void *elem;
};

struct module_attribute___198 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___198 *, struct module_kobject___198 *, char *);
	ssize_t (*store)(struct module_attribute___198 *, struct module_kobject___198 *, const char *, size_t);
	void (*setup)(struct module___201 *, const char *);
	int (*test)(struct module___201 *);
	void (*free)(struct module___201 *);
};

struct gnet_dump___32 {
	spinlock_t *lock;
	struct sk_buff___37 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___32;

struct Qdisc_ops___32 {
	struct Qdisc_ops___32 *next;
	const struct Qdisc_class_ops___32 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___37 *, struct Qdisc___32 *, struct sk_buff___37 **);
	struct sk_buff___37 * (*dequeue)(struct Qdisc___32 *);
	struct sk_buff___37 * (*peek)(struct Qdisc___32 *);
	int (*init)(struct Qdisc___32 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___32 *);
	void (*destroy)(struct Qdisc___32 *);
	int (*change)(struct Qdisc___32 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___32 *);
	int (*change_tx_queue_len)(struct Qdisc___32 *, unsigned int);
	int (*dump)(struct Qdisc___32 *, struct sk_buff___37 *);
	int (*dump_stats)(struct Qdisc___32 *, struct gnet_dump___32 *);
	void (*ingress_block_set)(struct Qdisc___32 *, u32);
	void (*egress_block_set)(struct Qdisc___32 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___32 *);
	u32 (*egress_block_get)(struct Qdisc___32 *);
	struct module___201 *owner;
};

struct tcf_block___32;

struct Qdisc_class_ops___32 {
	unsigned int flags;
	struct netdev_queue___33 * (*select_queue)(struct Qdisc___32 *, struct tcmsg *);
	int (*graft)(struct Qdisc___32 *, long unsigned int, struct Qdisc___32 *, struct Qdisc___32 **, struct netlink_ext_ack *);
	struct Qdisc___32 * (*leaf)(struct Qdisc___32 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___32 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___32 *, u32);
	int (*change)(struct Qdisc___32 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___32 *, long unsigned int);
	void (*walk)(struct Qdisc___32 *, struct qdisc_walker *);
	struct tcf_block___32 * (*tcf_block)(struct Qdisc___32 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___32 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___32 *, long unsigned int);
	int (*dump)(struct Qdisc___32 *, long unsigned int, struct sk_buff___37 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___32 *, long unsigned int, struct gnet_dump___32 *);
};

struct tcf_chain___32;

struct tcf_block___32 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___45 *net;
	struct Qdisc___32 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___32 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___32;

struct tcf_proto_ops___32;

struct tcf_proto___32 {
	struct tcf_proto___32 *next;
	void *root;
	int (*classify)(struct sk_buff___37 *, const struct tcf_proto___32 *, struct tcf_result___32 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___32 *ops;
	struct tcf_chain___32 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___32 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___32 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___32 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___37 *, const struct tcf_proto___32 *, struct tcf_result___32 *);
	int (*init)(struct tcf_proto___32 *);
	void (*destroy)(struct tcf_proto___32 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___32 *, u32);
	void (*put)(struct tcf_proto___32 *, void *);
	int (*change)(struct net___45 *, struct sk_buff___37 *, struct tcf_proto___32 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___32 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___32 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___32 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___45 *, struct tcf_chain___32 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___45 *, struct tcf_proto___32 *, void *, struct sk_buff___37 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___37 *, struct net___45 *, void *);
	struct module___201 *owner;
	int flags;
};

struct tcf_chain___32 {
	struct mutex filter_chain_lock;
	struct tcf_proto___32 *filter_chain;
	struct list_head list;
	struct tcf_block___32 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___32 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___22 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___32 *prog;
};

struct bpf_redirect_info___32 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___192 *map;
	struct bpf_map___192 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___22;

struct neigh_hash_table___22;

struct neigh_table___22 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___37 *, __u32 *);
	bool (*key_eq)(const struct neighbour___23 *, const void *);
	int (*constructor)(struct neighbour___23 *);
	int (*pconstructor)(struct pneigh_entry___22 *);
	void (*pdestructor)(struct pneigh_entry___22 *);
	void (*proxy_redo)(struct sk_buff___37 *);
	char *id;
	struct neigh_parms___23 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___33 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___22 *nht;
	struct pneigh_entry___22 **phash_buckets;
};

struct neigh_ops___22 {
	int family;
	void (*solicit)(struct neighbour___23 *, struct sk_buff___37 *);
	void (*error_report)(struct neighbour___23 *, struct sk_buff___37 *);
	int (*output)(struct neighbour___23 *, struct sk_buff___37 *);
	int (*connected_output)(struct neighbour___23 *, struct sk_buff___37 *);
};

struct pneigh_entry___22 {
	struct pneigh_entry___22 *next;
	possible_net_t___34 net;
	struct net_device___37 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___22 {
	struct neighbour___23 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___22 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___22 *ctarget;
	struct net___45 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___22 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___22 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___15;

struct timewait_sock_ops___14;

struct proto___22 {
	void (*close)(struct sock___24 *, long int);
	int (*pre_connect)(struct sock___24 *, struct sockaddr *, int);
	int (*connect)(struct sock___24 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___24 *, int);
	struct sock___24 * (*accept)(struct sock___24 *, int, int *, bool);
	int (*ioctl)(struct sock___24 *, int, long unsigned int);
	int (*init)(struct sock___24 *);
	void (*destroy)(struct sock___24 *);
	void (*shutdown)(struct sock___24 *, int);
	int (*setsockopt)(struct sock___24 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___24 *, int, int, char *, int *);
	void (*keepalive)(struct sock___24 *, int);
	int (*sendmsg)(struct sock___24 *, struct msghdr___24 *, size_t);
	int (*recvmsg)(struct sock___24 *, struct msghdr___24 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___24 *, struct page___248 *, int, size_t, int);
	int (*bind)(struct sock___24 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___24 *, struct sk_buff___37 *);
	void (*release_cb)(struct sock___24 *);
	int (*hash)(struct sock___24 *);
	void (*unhash)(struct sock___24 *);
	void (*rehash)(struct sock___24 *);
	int (*get_port)(struct sock___24 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___24 *);
	bool (*stream_memory_read)(const struct sock___24 *);
	void (*enter_memory_pressure)(struct sock___24 *);
	void (*leave_memory_pressure)(struct sock___24 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___15 *rsk_prot;
	struct timewait_sock_ops___14 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___201 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___24 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct request_sock___16;

struct request_sock_ops___15 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___24 *, struct request_sock___16 *);
	void (*send_ack)(const struct sock___24 *, struct sk_buff___37 *, struct request_sock___16 *);
	void (*send_reset)(const struct sock___24 *, struct sk_buff___37 *);
	void (*destructor)(struct request_sock___16 *);
	void (*syn_ack_timeout)(const struct request_sock___16 *);
};

struct timewait_sock_ops___14 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___24 *, struct sock___24 *, void *);
	void (*twsk_destructor)(struct sock___24 *);
};

struct request_sock___16 {
	struct sock_common___22 __req_common;
	struct request_sock___16 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___15 *rsk_ops;
	struct sock___24 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___13 {
	struct in6_addr mca_addr;
	struct inet6_dev___14 *idev;
	struct ifmcaddr6___13 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ip6_ra_chain___13 {
	struct ip6_ra_chain___13 *next;
	struct sock___24 *sk;
	int sel;
	void (*destructor)(struct sock___24 *);
};

struct selinux_ss___2;

struct selinux_state___2 {
	bool disabled;
	bool enforcing;
	bool checkreqprot;
	bool initialized;
	bool policycap[6];
	struct selinux_avc *avc;
	struct selinux_ss___2 *ss;
};

struct selinux_ss___2 {
	struct sidtab *sidtab;
	struct policydb policydb;
	rwlock_t policy_rwlock;
	u32 latest_granting;
	struct selinux_map map;
	struct page___248 *status_page;
	struct mutex status_lock;
};

struct linux_binprm___44 {
	char buf[256];
	struct vm_area_struct___248 *vma;
	long unsigned int vma_pages;
	struct mm_struct___247 *mm;
	long unsigned int p;
	unsigned int called_set_creds: 1;
	unsigned int cap_elevated: 1;
	unsigned int secureexec: 1;
	unsigned int recursion_depth;
	struct file___247 *file;
	struct cred___240 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
};

struct coredump_params___43 {
	union {
		const kernel_siginfo_t *siginfo;
		struct {
			const siginfo_t *siginfo;
		} __UNIQUE_ID_rh_kabi_hide77;
		union {		};
	};
	struct pt_regs *regs;
	struct file___247 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
};

struct superblock_security_struct___2 {
	struct super_block___246 *sb;
	u32 sid;
	u32 def_sid;
	u32 mntpoint_sid;
	short unsigned int behavior;
	short unsigned int flags;
	struct mutex lock;
	struct list_head isec_head;
	spinlock_t isec_lock;
};

struct convert_context_args {
	struct selinux_state___2 *state;
	struct policydb *oldp;
	struct policydb *newp;
};

struct selinux_audit_rule {
	u32 au_seqno;
	struct context au_ctxt;
};

struct selinux_ss___3;

struct selinux_state___3 {
	bool disabled;
	bool enforcing;
	bool checkreqprot;
	bool initialized;
	bool policycap[6];
	struct selinux_avc *avc;
	struct selinux_ss___3 *ss;
};

struct selinux_ss___3 {
	struct sidtab *sidtab;
	struct policydb policydb;
	rwlock_t policy_rwlock;
	u32 latest_granting;
	struct selinux_map map;
	struct page___243 *status_page;
	struct mutex status_lock;
};

struct cond_insertf_data {
	struct policydb *p;
	struct cond_av_list *other;
	struct cond_av_list *head;
	struct cond_av_list *tail;
};

struct selinux_ss___4;

struct selinux_state___4 {
	bool disabled;
	bool enforcing;
	bool checkreqprot;
	bool initialized;
	bool policycap[6];
	struct selinux_avc *avc;
	struct selinux_ss___4 *ss;
};

struct selinux_ss___4 {
	struct sidtab *sidtab;
	struct policydb policydb;
	rwlock_t policy_rwlock;
	u32 latest_granting;
	struct selinux_map map;
	struct page___242 *status_page;
	struct mutex status_lock;
};

struct selinux_kernel_status {
	u32 version;
	u32 sequence;
	u32 enforcing;
	u32 policyload;
	u32 deny_unknown;
};

struct module___202;

struct file___248;

struct kiocb___248;

struct iov_iter___115;

struct poll_table_struct___156;

struct vm_area_struct___249;

struct inode___248;

struct file_lock___248;

struct page___249;

struct pipe_inode_info___58;

struct seq_file___224;

struct file_operations___248 {
	struct module___202 *owner;
	loff_t (*llseek)(struct file___248 *, loff_t, int);
	ssize_t (*read)(struct file___248 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___248 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___248 *, struct iov_iter___115 *);
	ssize_t (*write_iter)(struct kiocb___248 *, struct iov_iter___115 *);
	int (*iopoll)(struct kiocb___248 *, bool);
	int (*iterate)(struct file___248 *, struct dir_context *);
	int (*iterate_shared)(struct file___248 *, struct dir_context *);
	__poll_t (*poll)(struct file___248 *, struct poll_table_struct___156 *);
	long int (*unlocked_ioctl)(struct file___248 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___248 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___248 *, struct vm_area_struct___249 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___248 *, struct file___248 *);
	int (*flush)(struct file___248 *, fl_owner_t);
	int (*release)(struct inode___248 *, struct file___248 *);
	int (*fsync)(struct file___248 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___248 *, int);
	int (*lock)(struct file___248 *, int, struct file_lock___248 *);
	ssize_t (*sendpage)(struct file___248 *, struct page___249 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___248 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___248 *, int, struct file_lock___248 *);
	ssize_t (*splice_write)(struct pipe_inode_info___58 *, struct file___248 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___248 *, loff_t *, struct pipe_inode_info___58 *, size_t, unsigned int);
	int (*setlease)(struct file___248 *, long int, struct file_lock___248 **, void **);
	long int (*fallocate)(struct file___248 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___224 *, struct file___248 *);
	ssize_t (*copy_file_range)(struct file___248 *, loff_t, struct file___248 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___248 *, loff_t, struct file___248 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___248 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___248 {
	u64 seqnum;
	struct vm_area_struct___249 *vmas[4];
};

struct page_frag___248 {
	struct page___249 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___248;

struct mem_cgroup___109;

struct pid___188;

struct cred___241;

struct nsproxy___228;

struct signal_struct___206;

struct bio_list___124;

struct backing_dev_info___124;

struct css_set___193;

struct vm_struct___165;

struct task_struct___249 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___249 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___248 *mm;
	struct mm_struct___248 *active_mm;
	struct vmacache___248 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___249 *real_parent;
	struct task_struct___249 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___249 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___109 *active_memcg;
	long int rh_reserved2;
	struct pid___188 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___188 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___188 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___241 *ptracer_cred;
	const struct cred___241 *real_cred;
	const struct cred___241 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___228 *nsproxy;
	struct signal_struct___206 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___249 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___124 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___124 *backing_dev_info;
	struct io_context___60 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___193 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___58 *splice_pipe;
	struct page_frag___248 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___109 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___249 *oom_reaper_list;
	struct vm_struct___165 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___127 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rw_semaphore___249 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___249 *owner;
};

struct key___241;

struct ucounts___208;

struct user_namespace___208 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___208 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___28 ns;
	long unsigned int flags;
	struct key___241 *persistent_keyring_register;
	struct rw_semaphore___249 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___208 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*key_restrict_link_func_t___241)(struct key___241 *, const struct key_type *, const union key_payload *, struct key___241 *);

struct key_restriction___241;

struct key___241 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___249 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key___5 index_key;
		struct {
			struct key_type___5 *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___241 *restrict_link;
};

struct key_restriction___241 {
	key_restrict_link_func_t___241 check;
	struct key___241 *key;
	struct key_type *keytype;
};

struct dentry_operations___247;

struct super_block___247;

struct dentry___248 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___248 *d_parent;
	struct qstr d_name;
	struct inode___248 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___247 *d_op;
	struct super_block___247 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___247;

struct address_space___247 {
	struct inode___248 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___249 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___247 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___247;

struct bdi_writeback___124;

struct block_device___248;

struct inode___248 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___247 *i_op;
	struct super_block___247 *i_sb;
	struct address_space___247 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___249 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___124 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___248 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___247 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___58 *i_pipe;
		struct block_device___248 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___248;

struct dentry_operations___247 {
	int (*d_revalidate)(struct dentry___248 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___248 *, unsigned int);
	int (*d_hash)(const struct dentry___248 *, struct qstr *);
	int (*d_compare)(const struct dentry___248 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___248 *);
	int (*d_init)(struct dentry___248 *);
	void (*d_release)(struct dentry___248 *);
	void (*d_prune)(struct dentry___248 *);
	void (*d_iput)(struct dentry___248 *, struct inode___248 *);
	char * (*d_dname)(struct dentry___248 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___248 *);
	int (*d_manage)(const struct path___248 *, bool);
	struct dentry___248 * (*d_real)(struct dentry___248 *, const struct inode___248 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___247;

struct mem_dqinfo___247 {
	struct quota_format_type___247 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___247;

struct quota_info___247 {
	unsigned int flags;
	struct rw_semaphore___249 dqio_sem;
	struct inode___248 *files[3];
	struct mem_dqinfo___247 info[3];
	const struct quota_format_ops___247 *ops[3];
};

struct rcuwait___247 {
	struct task_struct___249 *task;
};

struct percpu_rw_semaphore___247 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___249 rw_sem;
	struct rcuwait___247 writer;
	int readers_block;
};

struct sb_writers___247 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___247 rw_sem[3];
};

struct shrink_control___109;

struct shrinker___109 {
	long unsigned int (*count_objects)(struct shrinker___109 *, struct shrink_control___109 *);
	long unsigned int (*scan_objects)(struct shrinker___109 *, struct shrink_control___109 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___247;

struct super_operations___247;

struct dquot_operations___247;

struct quotactl_ops___247;

struct super_block___247 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___247 *s_type;
	const struct super_operations___247 *s_op;
	const struct dquot_operations___247 *dq_op;
	const struct quotactl_ops___247 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___248 *s_root;
	struct rw_semaphore___249 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___248 *s_bdev;
	struct backing_dev_info___124 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___247 s_dquot;
	struct sb_writers___247 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___247 *s_d_op;
	int cleancache_poolid;
	struct shrinker___109 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___208 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct path___248 {
	struct vfsmount *mnt;
	struct dentry___248 *dentry;
};

struct shrink_control___109 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___109 *memcg;
};

struct cgroup___193;

struct cgroup_subsys___193;

struct cgroup_subsys_state___194 {
	struct cgroup___193 *cgroup;
	struct cgroup_subsys___193 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___194 *parent;
};

struct kernfs_node___242;

struct cgroup_file___193 {
	struct kernfs_node___242 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___109;

struct mem_cgroup___109 {
	struct cgroup_subsys_state___194 css;
	struct mem_cgroup_id___16 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___193 events_file;
	struct cgroup_file___193 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___249 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___109 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___249 *pgtable_t___248;

struct dev_pagemap___238;

struct page___249 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___247 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___249 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___248 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___248 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___238 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___109 *mem_cgroup;
};

struct pglist_data___248;

struct lruvec___248 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___248 *pgdat;
};

struct zone___248 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___248 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___248 {
	struct zone___248 *zone;
	int zone_idx;
};

struct zonelist___248 {
	struct zoneref___248 _zonerefs[25];
};

struct pglist_data___248 {
	struct zone___248 node_zones[3];
	struct zonelist___248 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___249 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___249 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___248 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___249 {
	void *stack;
	struct task_struct___249 *task;
	long int status;
};

struct blocking_notifier_head___248 {
	struct rw_semaphore___249 rwsem;
	struct notifier_block *head;
};

struct pid_namespace___188;

struct upid___188 {
	int nr;
	struct pid_namespace___188 *ns;
};

struct pid_namespace___188 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___249 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___188 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___248 *proc_self;
	struct dentry___248 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___208 *user_ns;
	struct ucounts___208 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___28 ns;
};

struct pid___188 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___188 numbers[1];
};

struct vm_operations_struct___238;

struct vm_area_struct___249 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___249 *vm_next;
	struct vm_area_struct___249 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___248 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___238 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___248 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct linux_binfmt___44;

struct core_state___248;

struct mm_struct___248 {
	struct {
		struct vm_area_struct___249 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___248 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___249 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___44 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___248 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___249 *owner;
		struct user_namespace___208 *user_ns;
		struct file___248 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___248 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___238)(struct vm_area_struct___249 *, long unsigned int, const struct page___249 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___238)(struct page___249 *, void *);

struct device___212;

struct dev_pagemap___238 {
	dev_page_fault_t___238 page_fault;
	dev_page_free_t___238 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___212 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct fown_struct___188 {
	rwlock_t lock;
	struct pid___188 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___248 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___248 f_path;
	struct inode___248 *f_inode;
	const struct file_operations___248 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___188 f_owner;
	const struct cred___241 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___247 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___238;

struct vm_operations_struct___238 {
	void (*open)(struct vm_area_struct___249 *);
	void (*close)(struct vm_area_struct___249 *);
	int (*split)(struct vm_area_struct___249 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___249 *);
	vm_fault_t (*fault)(struct vm_fault___238 *);
	vm_fault_t (*huge_fault)(struct vm_fault___238 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___238 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___249 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___238 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___238 *);
	int (*access)(struct vm_area_struct___249 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___249 *);
	int (*set_policy)(struct vm_area_struct___249 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___249 *, long unsigned int);
	struct page___249 * (*find_special_page)(struct vm_area_struct___249 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___248 {
	struct task_struct___249 *task;
	struct core_thread___248 *next;
};

struct core_state___248 {
	atomic_t nr_threads;
	struct core_thread___248 dumper;
	struct completion startup;
};

struct linux_binprm___45;

struct coredump_params___44;

struct linux_binfmt___44 {
	struct list_head lh;
	struct module___202 *module;
	int (*load_binary)(struct linux_binprm___45 *);
	int (*load_shlib)(struct file___248 *);
	int (*core_dump)(struct coredump_params___44 *);
	long unsigned int min_coredump;
};

struct vm_fault___238 {
	struct vm_area_struct___249 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___249 *cow_page;
	struct mem_cgroup___109 *memcg;
	struct page___249 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___248 prealloc_pte;
};

struct user_struct___241 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___241 *uid_keyring;
	struct key___241 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___241 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___241 *session_keyring;
	struct key___241 *process_keyring;
	struct key___241 *thread_keyring;
	struct key___241 *request_key_auth;
	void *security;
	struct user_struct___241 *user;
	struct user_namespace___208 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___193;

struct nsproxy___228 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___188 *pid_ns_for_children;
	struct net___6 *net_ns;
	struct cgroup_namespace___193 *cgroup_ns;
};

struct signal_struct___206 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___249 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___249 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___188 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___188 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___248 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___188 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___124;

struct bio_list___124 {
	struct bio___124 *head;
	struct bio___124 *tail;
};

struct bdi_writeback_congested___124;

struct bdi_writeback___124 {
	struct backing_dev_info___124 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___124 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___194 *memcg_css;
	struct cgroup_subsys_state___194 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___124 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___124 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___212 *dev;
	struct device___212 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___248 *debug_dir;
	struct dentry___248 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___193 {
	struct cgroup_subsys_state___194 *subsys[13];
	refcount_t refcount;
	struct css_set___193 *dom_cset;
	struct cgroup___193 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___193 *mg_src_cgrp;
	struct cgroup___193 *mg_dst_cgrp;
	struct css_set___193 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___247;

struct pipe_buffer___58;

struct pipe_inode_info___58 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___249 *tmp_page;
	struct fasync_struct___247 *fasync_readers;
	struct fasync_struct___247 *fasync_writers;
	struct pipe_buffer___58 *bufs;
	struct user_struct___241 *user;
};

struct vm_struct___165 {
	struct vm_struct___165 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___249 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___218 {
	struct task_struct___249 task;
	long unsigned int stack[8192];
};

struct kiocb___248 {
	struct file___248 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___248 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___247 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___248 *ia_file;
};

struct dquot___247 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___247 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___247 {
	int qf_fmt_id;
	const struct quota_format_ops___247 *qf_ops;
	struct module___202 *qf_owner;
	struct quota_format_type___247 *qf_next;
};

struct quota_format_ops___247 {
	int (*check_quota_file)(struct super_block___247 *, int);
	int (*read_file_info)(struct super_block___247 *, int);
	int (*write_file_info)(struct super_block___247 *, int);
	int (*free_file_info)(struct super_block___247 *, int);
	int (*read_dqblk)(struct dquot___247 *);
	int (*commit_dqblk)(struct dquot___247 *);
	int (*release_dqblk)(struct dquot___247 *);
	int (*get_next_id)(struct super_block___247 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___247 {
	int (*write_dquot)(struct dquot___247 *);
	struct dquot___247 * (*alloc_dquot)(struct super_block___247 *, int);
	void (*destroy_dquot)(struct dquot___247 *);
	int (*acquire_dquot)(struct dquot___247 *);
	int (*release_dquot)(struct dquot___247 *);
	int (*mark_dirty)(struct dquot___247 *);
	int (*write_info)(struct super_block___247 *, int);
	qsize_t * (*get_reserved_space)(struct inode___248 *);
	int (*get_projid)(struct inode___248 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___248 *, qsize_t *);
	int (*get_next_id)(struct super_block___247 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___247 {
	int (*quota_on)(struct super_block___247 *, int, int, const struct path___248 *);
	int (*quota_off)(struct super_block___247 *, int);
	int (*quota_enable)(struct super_block___247 *, unsigned int);
	int (*quota_disable)(struct super_block___247 *, unsigned int);
	int (*quota_sync)(struct super_block___247 *, int);
	int (*set_info)(struct super_block___247 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___247 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___247 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___247 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___247 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___247 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___235;

struct kobj_type___235;

struct kobject___236 {
	const char *name;
	struct list_head entry;
	struct kobject___236 *parent;
	struct kset___235 *kset;
	struct kobj_type___235 *ktype;
	struct kernfs_node___242 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___199 {
	struct kobject___236 kobj;
	struct module___202 *mod;
	struct kobject___236 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___199 {
	struct module___202 *mod;
	struct latch_tree_node node;
};

struct module_layout___199 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___199 mtn;
};

struct module_attribute___199;

struct kernel_param___199;

struct module___202 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___199 mkobj;
	struct module_attribute___199 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___236 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___199 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___199 core_layout;
	struct module_layout___199 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide53;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide54;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___120;

struct address_space_operations___247 {
	int (*writepage)(struct page___249 *, struct writeback_control___120 *);
	int (*readpage)(struct file___248 *, struct page___249 *);
	int (*writepages)(struct address_space___247 *, struct writeback_control___120 *);
	int (*set_page_dirty)(struct page___249 *);
	int (*readpages)(struct file___248 *, struct address_space___247 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___248 *, struct address_space___247 *, loff_t, unsigned int, unsigned int, struct page___249 **, void **);
	int (*write_end)(struct file___248 *, struct address_space___247 *, loff_t, unsigned int, unsigned int, struct page___249 *, void *);
	sector_t (*bmap)(struct address_space___247 *, sector_t);
	void (*invalidatepage)(struct page___249 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___249 *, gfp_t);
	void (*freepage)(struct page___249 *);
	ssize_t (*direct_IO)(struct kiocb___248 *, struct iov_iter___115 *);
	int (*migratepage)(struct address_space___247 *, struct page___249 *, struct page___249 *, enum migrate_mode);
	bool (*isolate_page)(struct page___249 *, isolate_mode_t);
	void (*putback_page)(struct page___249 *);
	int (*launder_page)(struct page___249 *);
	int (*is_partially_uptodate)(struct page___249 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___249 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___247 *, struct page___249 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___248 *, sector_t *);
	void (*swap_deactivate)(struct file___248 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___120 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___124 *wb;
	struct inode___248 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___124;

struct iov_iter___115 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___124 *bvec;
		struct pipe_inode_info___58 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___248 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___248 *bd_inode;
	struct super_block___247 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___248 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___124 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___247 {
	struct dentry___248 * (*lookup)(struct inode___248 *, struct dentry___248 *, unsigned int);
	const char * (*get_link)(struct dentry___248 *, struct inode___248 *, struct delayed_call *);
	int (*permission)(struct inode___248 *, int);
	struct posix_acl * (*get_acl)(struct inode___248 *, int);
	int (*readlink)(struct dentry___248 *, char *, int);
	int (*create)(struct inode___248 *, struct dentry___248 *, umode_t, bool);
	int (*link)(struct dentry___248 *, struct inode___248 *, struct dentry___248 *);
	int (*unlink)(struct inode___248 *, struct dentry___248 *);
	int (*symlink)(struct inode___248 *, struct dentry___248 *, const char *);
	int (*mkdir)(struct inode___248 *, struct dentry___248 *, umode_t);
	int (*rmdir)(struct inode___248 *, struct dentry___248 *);
	int (*mknod)(struct inode___248 *, struct dentry___248 *, umode_t, dev_t);
	int (*rename)(struct inode___248 *, struct dentry___248 *, struct inode___248 *, struct dentry___248 *, unsigned int);
	int (*setattr)(struct dentry___248 *, struct iattr___247 *);
	int (*getattr)(const struct path___248 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___248 *, char *, size_t);
	int (*fiemap)(struct inode___248 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___248 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___248 *, struct dentry___248 *, struct file___248 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___248 *, struct dentry___248 *, umode_t);
	int (*set_acl)(struct inode___248 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___247 {
	void (*fl_copy_lock)(struct file_lock___248 *, struct file_lock___248 *);
	void (*fl_release_private)(struct file_lock___248 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___247;

struct file_lock___248 {
	struct file_lock___248 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___248 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___247 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___247 *fl_ops;
	const struct lock_manager_operations___247 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___247 {
	int (*lm_compare_owner)(struct file_lock___248 *, struct file_lock___248 *);
	long unsigned int (*lm_owner_key)(struct file_lock___248 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___248 *);
	int (*lm_grant)(struct file_lock___248 *, int);
	bool (*lm_break)(struct file_lock___248 *);
	int (*lm_change)(struct file_lock___248 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___248 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___247 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___247 *fa_next;
	struct file___248 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___247 {
	const char *name;
	int fs_flags;
	struct dentry___248 * (*mount)(struct file_system_type___247 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___247 *);
	struct module___202 *owner;
	struct file_system_type___247 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___247 {
	struct inode___248 * (*alloc_inode)(struct super_block___247 *);
	void (*destroy_inode)(struct inode___248 *);
	void (*dirty_inode)(struct inode___248 *, int);
	int (*write_inode)(struct inode___248 *, struct writeback_control___120 *);
	int (*drop_inode)(struct inode___248 *);
	void (*evict_inode)(struct inode___248 *);
	void (*put_super)(struct super_block___247 *);
	int (*sync_fs)(struct super_block___247 *, int);
	int (*freeze_super)(struct super_block___247 *);
	int (*freeze_fs)(struct super_block___247 *);
	int (*thaw_super)(struct super_block___247 *);
	int (*unfreeze_fs)(struct super_block___247 *);
	int (*statfs)(struct dentry___248 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___247 *, int *, char *);
	void (*umount_begin)(struct super_block___247 *);
	int (*show_options)(struct seq_file___224 *, struct dentry___248 *);
	int (*show_devname)(struct seq_file___224 *, struct dentry___248 *);
	int (*show_path)(struct seq_file___224 *, struct dentry___248 *);
	int (*show_stats)(struct seq_file___224 *, struct dentry___248 *);
	ssize_t (*quota_read)(struct super_block___247 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___247 *, int, const char *, size_t, loff_t);
	struct dquot___247 ** (*get_dquots)(struct inode___248 *);
	int (*bdev_try_to_free_page)(struct super_block___247 *, struct page___249 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___247 *, struct shrink_control___109 *);
	long int (*free_cached_objects)(struct super_block___247 *, struct shrink_control___109 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___158)(struct file___248 *, wait_queue_head_t *, struct poll_table_struct___156 *);

struct poll_table_struct___156 {
	poll_queue_proc___158 _qproc;
	__poll_t _key;
};

struct seq_operations___222;

struct seq_file___224 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___222 *op;
	int poll_event;
	const struct file___248 *file;
	void *private;
};

typedef void bio_end_io_t___124(struct bio___124 *);

struct bio_vec___124 {
	struct page___249 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___124;

struct bio_set___124;

struct bio___124 {
	struct bio___124 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___124 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___124 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___124 *bi_io_vec;
	struct bio_set___124 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___124 bi_inline_vecs[0];
};

struct dev_pm_info___212 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___212 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___212;

struct bus_type___212;

struct device_driver___212;

struct dev_pm_domain___212;

struct dma_map_ops___55;

struct fwnode_handle___147;

struct class___212;

struct attribute_group___214;

struct device___212 {
	struct device___212 *parent;
	struct device_private *p;
	struct kobject___236 kobj;
	const char *init_name;
	const struct device_type___212 *type;
	struct mutex mutex;
	struct bus_type___212 *bus;
	struct device_driver___212 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___212 power;
	struct dev_pm_domain___212 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___55 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___147 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___212 *class;
	const struct attribute_group___214 **groups;
	void (*release)(struct device___212 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct kobj_attribute___229 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___236 *, struct kobj_attribute___229 *, char *);
	ssize_t (*store)(struct kobject___236 *, struct kobj_attribute___229 *, const char *, size_t);
};

typedef void compound_page_dtor___238(struct page___249 *);

struct msghdr___25 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___115 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___248 *msg_iocb;
};

struct socket_wq___24 {
	wait_queue_head_t wait;
	struct fasync_struct___247 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct sock___25;

struct proto_ops___24;

struct socket___25 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___24 *wq;
	struct file___248 *file;
	struct sock___25 *sk;
	const struct proto_ops___24 *ops;
};

typedef struct {
	struct net___6 *net;
} possible_net_t___35;

struct proto___23;

struct sock_common___23 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___23 *skc_prot;
	possible_net_t___35 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___25 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff_head___34 {
	struct sk_buff___6 *next;
	struct sk_buff___6 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___23;

struct dst_entry___24;

struct sock___25 {
	struct sock_common___23 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___34 sk_error_queue;
	struct sk_buff_head___34 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___6 *head;
		struct sk_buff___6 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___23 *sk_filter;
	union {
		struct socket_wq___24 *sk_wq;
		struct socket_wq___24 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___24 *sk_rx_dst;
	struct dst_entry___24 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___6 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___34 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___248 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___23 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___188 *sk_peer_pid;
	const struct cred___241 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___25 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___109 *sk_memcg;
	void (*sk_state_change)(struct sock___25 *);
	void (*sk_data_ready)(struct sock___25 *);
	void (*sk_write_space)(struct sock___25 *);
	void (*sk_error_report)(struct sock___25 *);
	int (*sk_backlog_rcv)(struct sock___25 *, struct sk_buff___6 *);
	struct sk_buff___6 * (*sk_validate_xmit_skb)(struct sock___25 *, struct net_device___7 *, struct sk_buff___6 *);
	void (*sk_destruct)(struct sock___25 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

typedef int (*sk_read_actor_t___23)(read_descriptor_t *, struct sk_buff___6 *, unsigned int, size_t);

struct proto_ops___24 {
	int family;
	struct module___202 *owner;
	int (*release)(struct socket___25 *);
	int (*bind)(struct socket___25 *, struct sockaddr *, int);
	int (*connect)(struct socket___25 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___25 *, struct socket___25 *);
	int (*accept)(struct socket___25 *, struct socket___25 *, int, bool);
	int (*getname)(struct socket___25 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___248 *, struct socket___25 *, struct poll_table_struct___156 *);
	int (*ioctl)(struct socket___25 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___25 *, int);
	int (*shutdown)(struct socket___25 *, int);
	int (*setsockopt)(struct socket___25 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___25 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___25 *, struct msghdr___25 *, size_t);
	int (*recvmsg)(struct socket___25 *, struct msghdr___25 *, size_t, int);
	int (*mmap)(struct file___248 *, struct socket___25 *, struct vm_area_struct___249 *);
	ssize_t (*sendpage)(struct socket___25 *, struct page___249 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___25 *, loff_t *, struct pipe_inode_info___58 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___25 *, int);
	int (*peek_len)(struct socket___25 *);
	int (*read_sock)(struct sock___25 *, read_descriptor_t *, sk_read_actor_t___23);
	int (*sendpage_locked)(struct sock___25 *, struct page___249 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___25 *, struct msghdr___25 *, size_t);
	int (*set_rcvlowat)(struct sock___25 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct nf_bridge_info___34;

struct sk_buff___6 {
	union {
		struct {
			struct sk_buff___6 *next;
			struct sk_buff___6 *prev;
			union {
				struct net_device___7 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___25 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___6 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___34 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___34;

struct netns_frags___34 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___34 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ip_ra_chain___11;

struct fib_rules_ops___23;

struct fib_notifier_ops___23;

struct netns_ipv4___34 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___11 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___23 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___25 *fibnl;
	struct sock___25 **icmp_sk;
	struct sock___25 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___25 **tcp_sk;
	struct netns_frags___34 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___23 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___23 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___23 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct dst_ops___44 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___44 *);
	struct dst_entry___24 * (*check)(struct dst_entry___24 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___24 *);
	unsigned int (*mtu)(const struct dst_entry___24 *);
	u32 * (*cow_metrics)(struct dst_entry___24 *, long unsigned int);
	void (*destroy)(struct dst_entry___24 *);
	void (*ifdown)(struct dst_entry___24 *, struct net_device___7 *, int);
	struct dst_entry___24 * (*negative_advice)(struct dst_entry___24 *);
	void (*link_failure)(struct sk_buff___6 *);
	void (*update_pmtu)(struct dst_entry___24 *, struct sock___25 *, struct sk_buff___6 *, u32);
	void (*redirect)(struct dst_entry___24 *, struct sock___25 *, struct sk_buff___6 *);
	int (*local_out)(struct net___6 *, struct sock___25 *, struct sk_buff___6 *);
	struct neighbour___3 * (*neigh_lookup)(const struct dst_entry___24 *, struct sk_buff___6 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___24 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___44 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___34 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___44 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___23 *fib6_rules_ops;
	struct sock___25 **icmp_sk;
	struct sock___25 *ndisc_sk;
	struct sock___25 *tcp_sk;
	struct sock___25 *igmp_sk;
	struct sock___25 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___23 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___23 *notifier_ops;
	struct fib_notifier_ops___23 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___24 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___25 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___34 {
	struct netns_frags___34 frags;
};

struct netns_xfrm___44 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___25 *nlsk;
	struct sock___25 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___44 xfrm4_dst_ops;
	struct dst_ops___44 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___33;

struct net___6 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___208 *user_ns;
	struct ucounts___208 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___28 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___25 *rtnl;
	struct sock___25 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___7 *loopback_dev;
	struct netns_core core;
	struct netns_mib___2 mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___34 ipv4;
	struct netns_ipv6___44 ipv6;
	struct netns_sctp___24 sctp;
	struct netns_nf___2 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___34 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___25 *nfnl;
	struct sock___25 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___44 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can___2 can;
	struct sock___25 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___33 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kernfs_root___242;

struct kernfs_elem_dir___242 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___242 *root;
};

struct kernfs_syscall_ops___242;

struct kernfs_root___242 {
	struct kernfs_node___242 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___242 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___242 {
	struct kernfs_node___242 *target_kn;
};

struct kernfs_ops___242;

struct kernfs_elem_attr___242 {
	const struct kernfs_ops___242 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___242 *notify_next;
};

struct kernfs_node___242 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___242 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___242 dir;
		struct kernfs_elem_symlink___242 symlink;
		struct kernfs_elem_attr___242 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___242;

struct kernfs_ops___242 {
	int (*open)(struct kernfs_open_file___242 *);
	void (*release)(struct kernfs_open_file___242 *);
	int (*seq_show)(struct seq_file___224 *, void *);
	void * (*seq_start)(struct seq_file___224 *, loff_t *);
	void * (*seq_next)(struct seq_file___224 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___224 *, void *);
	ssize_t (*read)(struct kernfs_open_file___242 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___242 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___242 *, struct vm_area_struct___249 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___242 *, struct poll_table_struct___156 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___242 {
	int (*remount_fs)(struct kernfs_root___242 *, int *, char *);
	int (*show_options)(struct seq_file___224 *, struct kernfs_root___242 *);
	int (*mkdir)(struct kernfs_node___242 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___242 *);
	int (*rename)(struct kernfs_node___242 *, struct kernfs_node___242 *, const char *);
	int (*show_path)(struct seq_file___224 *, struct kernfs_node___242 *, struct kernfs_root___242 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___242 {
	struct kernfs_node___242 *kn;
	struct file___248 *file;
	struct seq_file___224 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___238 *vm_ops;
};

struct kobj_ns_type_operations___23 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___25 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___213;

struct attribute_group___214 {
	const char *name;
	umode_t (*is_visible)(struct kobject___236 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___236 *, struct bin_attribute___213 *, int);
	struct attribute **attrs;
	struct bin_attribute___213 **bin_attrs;
};

struct bin_attribute___213 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___248 *, struct kobject___236 *, struct bin_attribute___213 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___248 *, struct kobject___236 *, struct bin_attribute___213 *, char *, loff_t, size_t);
	int (*mmap)(struct file___248 *, struct kobject___236 *, struct bin_attribute___213 *, struct vm_area_struct___249 *);
};

struct sysfs_ops___235 {
	ssize_t (*show)(struct kobject___236 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___236 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___235;

struct kset___235 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___236 kobj;
	const struct kset_uevent_ops___235 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___235 {
	void (*release)(struct kobject___236 *);
	const struct sysfs_ops___235 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___23 * (*child_ns_type)(struct kobject___236 *);
	const void * (*namespace)(struct kobject___236 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___235 {
	int (* const filter)(struct kset___235 *, struct kobject___236 *);
	const char * (* const name)(struct kset___235 *, struct kobject___236 *);
	int (* const uevent)(struct kset___235 *, struct kobject___236 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___212 {
	int (*prepare)(struct device___212 *);
	void (*complete)(struct device___212 *);
	int (*suspend)(struct device___212 *);
	int (*resume)(struct device___212 *);
	int (*freeze)(struct device___212 *);
	int (*thaw)(struct device___212 *);
	int (*poweroff)(struct device___212 *);
	int (*restore)(struct device___212 *);
	int (*suspend_late)(struct device___212 *);
	int (*resume_early)(struct device___212 *);
	int (*freeze_late)(struct device___212 *);
	int (*thaw_early)(struct device___212 *);
	int (*poweroff_late)(struct device___212 *);
	int (*restore_early)(struct device___212 *);
	int (*suspend_noirq)(struct device___212 *);
	int (*resume_noirq)(struct device___212 *);
	int (*freeze_noirq)(struct device___212 *);
	int (*thaw_noirq)(struct device___212 *);
	int (*poweroff_noirq)(struct device___212 *);
	int (*restore_noirq)(struct device___212 *);
	int (*runtime_suspend)(struct device___212 *);
	int (*runtime_resume)(struct device___212 *);
	int (*runtime_idle)(struct device___212 *);
};

struct dev_pm_domain___212 {
	struct dev_pm_ops___212 ops;
	void (*detach)(struct device___212 *, bool);
	int (*activate)(struct device___212 *);
	void (*sync)(struct device___212 *);
	void (*dismiss)(struct device___212 *);
};

struct bus_type___212 {
	const char *name;
	const char *dev_name;
	struct device___212 *dev_root;
	const struct attribute_group___214 **bus_groups;
	const struct attribute_group___214 **dev_groups;
	const struct attribute_group___214 **drv_groups;
	int (*match)(struct device___212 *, struct device_driver___212 *);
	int (*uevent)(struct device___212 *, struct kobj_uevent_env *);
	int (*probe)(struct device___212 *);
	int (*remove)(struct device___212 *);
	void (*shutdown)(struct device___212 *);
	int (*online)(struct device___212 *);
	int (*offline)(struct device___212 *);
	int (*suspend)(struct device___212 *, pm_message_t);
	int (*resume)(struct device___212 *);
	int (*num_vf)(struct device___212 *);
	int (*dma_configure)(struct device___212 *);
	const struct dev_pm_ops___212 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___212 {
	const char *name;
	struct bus_type___212 *bus;
	struct module___202 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___212 *);
	int (*remove)(struct device___212 *);
	void (*shutdown)(struct device___212 *);
	int (*suspend)(struct device___212 *, pm_message_t);
	int (*resume)(struct device___212 *);
	const struct attribute_group___214 **groups;
	const struct dev_pm_ops___212 *pm;
	void (*coredump)(struct device___212 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___212 {
	const char *name;
	const struct attribute_group___214 **groups;
	int (*uevent)(struct device___212 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___212 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___212 *);
	const struct dev_pm_ops___212 *pm;
};

struct class___212 {
	const char *name;
	struct module___202 *owner;
	const struct attribute_group___214 **class_groups;
	const struct attribute_group___214 **dev_groups;
	struct kobject___236 *dev_kobj;
	int (*dev_uevent)(struct device___212 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___212 *, umode_t *);
	void (*class_release)(struct class___212 *);
	void (*dev_release)(struct device___212 *);
	int (*shutdown_pre)(struct device___212 *);
	const struct kobj_ns_type_operations___23 *ns_type;
	const void * (*namespace)(struct device___212 *);
	const struct dev_pm_ops___212 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___55 {
	void * (*alloc)(struct device___212 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___212 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___212 *, struct vm_area_struct___249 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___212 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___212 *, struct page___249 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___212 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___212 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___212 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___212 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___212 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___212 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___212 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___212 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___212 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___212 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___212 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___212 *, u64);
	u64 (*get_required_mask)(struct device___212 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___147;

struct fwnode_handle___147 {
	struct fwnode_handle___147 *secondary;
	const struct fwnode_operations___147 *ops;
};

struct fwnode_reference_args___147;

struct fwnode_endpoint___147;

struct fwnode_operations___147 {
	struct fwnode_handle___147 * (*get)(struct fwnode_handle___147 *);
	void (*put)(struct fwnode_handle___147 *);
	bool (*device_is_available)(const struct fwnode_handle___147 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___147 *, const struct device___212 *);
	bool (*property_present)(const struct fwnode_handle___147 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___147 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___147 *, const char *, const char **, size_t);
	struct fwnode_handle___147 * (*get_parent)(const struct fwnode_handle___147 *);
	struct fwnode_handle___147 * (*get_next_child_node)(const struct fwnode_handle___147 *, struct fwnode_handle___147 *);
	struct fwnode_handle___147 * (*get_named_child_node)(const struct fwnode_handle___147 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___147 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___147 *);
	struct fwnode_handle___147 * (*graph_get_next_endpoint)(const struct fwnode_handle___147 *, struct fwnode_handle___147 *);
	struct fwnode_handle___147 * (*graph_get_remote_endpoint)(const struct fwnode_handle___147 *);
	struct fwnode_handle___147 * (*graph_get_port_parent)(struct fwnode_handle___147 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___147 *, struct fwnode_endpoint___147 *);
};

struct fwnode_endpoint___147 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___147 *local_fwnode;
};

struct fwnode_reference_args___147 {
	struct fwnode_handle___147 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___58;

struct pipe_buffer___58 {
	struct page___249 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___58 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___58 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___58 *, struct pipe_buffer___58 *);
	void (*release)(struct pipe_inode_info___58 *, struct pipe_buffer___58 *);
	int (*steal)(struct pipe_inode_info___58 *, struct pipe_buffer___58 *);
	union {
		bool (*get)(struct pipe_inode_info___58 *, struct pipe_buffer___58 *);
		struct {
			void (*get)(struct pipe_inode_info___58 *, struct pipe_buffer___58 *);
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
};

struct nf_bridge_info___34 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___34 = 0,
		BRNF_PROTO_8021Q___34 = 1,
		BRNF_PROTO_PPPOE___34 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___7 *physindev;
	struct net_device___7 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___34(struct sk_buff___6 **);

struct net_device_ops___34;

struct ethtool_ops___34;

struct l3mdev_ops___24;

struct xfrmdev_ops___34;

struct tlsdev_ops___34;

struct header_ops___34;

struct netdev_rx_queue___34;

struct mini_Qdisc___33;

struct netdev_queue___34;

struct Qdisc___33;

struct rtnl_link_ops___33;

struct dcbnl_rtnl_ops___34;

struct net_device___7 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___34 *netdev_ops;
	const struct ethtool_ops___34 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___24 *l3mdev_ops;
	const struct ndisc_ops___2 *ndisc_ops;
	const struct xfrmdev_ops___34 *xfrmdev_ops;
	const struct tlsdev_ops___34 *tlsdev_ops;
	const struct header_ops___34 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___235 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___2 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___34 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___33 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___34 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___33 *miniq_ingress;
	struct netdev_queue___34 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___34 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___33 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___33 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___34 = 0,
		NETREG_REGISTERED___34 = 1,
		NETREG_UNREGISTERING___34 = 2,
		NETREG_UNREGISTERED___34 = 3,
		NETREG_RELEASED___34 = 4,
		NETREG_DUMMY___34 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___34 = 0,
		RTNL_LINK_INITIALIZING___34 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___7 *);
	struct netpoll_info *npinfo;
	possible_net_t___35 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___212 dev;
	const struct attribute_group___214 *sysfs_groups[4];
	const struct attribute_group___214 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___33 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___34 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct xfrm_offload {
	struct {
		__u32 low;
		__u32 hi;
	} seq;
	__u32 flags;
	__u32 status;
	__u8 proto;
};

struct sec_path {
	refcount_t refcnt;
	int len;
	int olen;
	struct xfrm_state *xvec[6];
	struct xfrm_offload ovec[1];
};

struct ethtool_ops___34 {
	int (*get_settings)(struct net_device___7 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___7 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___7 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___7 *);
	void (*get_regs)(struct net_device___7 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___7 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___7 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___7 *);
	void (*set_msglevel)(struct net_device___7 *, u32);
	int (*nway_reset)(struct net_device___7 *);
	u32 (*get_link)(struct net_device___7 *);
	int (*get_eeprom_len)(struct net_device___7 *);
	int (*get_eeprom)(struct net_device___7 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___7 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___7 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___7 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___7 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___7 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___7 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___7 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___7 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___7 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___7 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___7 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___7 *);
	void (*complete)(struct net_device___7 *);
	u32 (*get_priv_flags)(struct net_device___7 *);
	int (*set_priv_flags)(struct net_device___7 *, u32);
	int (*get_sset_count)(struct net_device___7 *, int);
	int (*get_rxnfc)(struct net_device___7 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___7 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___7 *, struct ethtool_flash *);
	int (*reset)(struct net_device___7 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___7 *);
	u32 (*get_rxfh_indir_size)(struct net_device___7 *);
	int (*get_rxfh)(struct net_device___7 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___7 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___7 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___7 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___7 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___7 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___7 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___7 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___7 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___7 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___7 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___7 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___7 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___7 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___7 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___7 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___7 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___7 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___7 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___7 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___7 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___7 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	int (*get_fecparam)(struct net_device___7 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___7 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___7 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___7 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___7 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___34;

struct inet_frags___34 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___34 *, const void *);
	void (*destructor)(struct inet_frag_queue___34 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___34 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___6 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___6 *fragments_tail;
	struct sk_buff___6 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___34 *net;
	struct callback_head rcu;
};

struct ip_ra_chain___11 {
	struct ip_ra_chain___11 *next;
	struct sock___25 *sk;
	union {
		void (*destructor)(struct sock___25 *);
		struct sock___25 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___23;

struct fib_lookup_arg___23;

struct fib_rules_ops___23 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___23 *, struct flowi *, int, struct fib_lookup_arg___23 *);
	bool (*suppress)(struct fib_rule___23 *, struct fib_lookup_arg___23 *);
	int (*match)(struct fib_rule___23 *, struct flowi *, int);
	int (*configure)(struct fib_rule___23 *, struct sk_buff___6 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___23 *);
	int (*compare)(struct fib_rule___23 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___23 *, struct sk_buff___6 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___23 *);
	void (*flush_cache)(struct fib_rules_ops___23 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___202 *owner;
	struct net___6 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___23 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___6 *);
	int (*fib_dump)(struct net___6 *, struct notifier_block *);
	struct module___202 *owner;
	struct callback_head rcu;
};

struct dst_entry___24 {
	struct net_device___7 *dev;
	struct dst_ops___44 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___6 *);
	int (*output)(struct net___6 *, struct sock___25 *, struct sk_buff___6 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___23;

struct neigh_parms___24;

struct neigh_ops___23;

struct neighbour___3 {
	struct neighbour___3 *next;
	struct neigh_table___23 *tbl;
	struct neigh_parms___24 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___34 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___3 *, struct sk_buff___6 *);
	const struct neigh_ops___23 *ops;
	struct callback_head rcu;
	struct net_device___7 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct rt6key {
	struct in6_addr addr;
	int plen;
};

struct fib6_nh {
	struct in6_addr nh_gw;
	struct net_device___7 *nh_dev;
	struct lwtunnel_state *nh_lwtstate;
	unsigned int nh_flags;
	atomic_t nh_upper_bound;
	int nh_weight;
};

struct fib6_node;

struct rt6_exception_bucket;

struct fib6_info {
	struct fib6_table *fib6_table;
	struct fib6_info *fib6_next;
	struct fib6_node *fib6_node;
	struct list_head fib6_siblings;
	unsigned int fib6_nsiblings;
	atomic_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	struct rt6_info **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
	long unsigned int last_probe;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 exception_bucket_flushed: 1;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 dst_host: 1;
	u8 fib6_destroying: 1;
	u8 unused: 2;
	struct fib6_nh fib6_nh;
	struct callback_head rcu;
};

struct uncached_list;

struct rt6_info {
	struct dst_entry___24 dst;
	struct fib6_info *from;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___2 *rt6i_idev;
	u32 rt6i_flags;
	struct rt6key rt6i_prefsrc;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct rt6_statistics {
	__u32 fib_nodes;
	__u32 fib_route_nodes;
	__u32 fib_rt_entries;
	__u32 fib_rt_cache;
	__u32 fib_discarded_routes;
	atomic_t fib_rt_alloc;
	atomic_t fib_rt_uncache;
};

struct fib6_node {
	struct fib6_node *parent;
	struct fib6_node *left;
	struct fib6_node *right;
	struct fib6_info *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

typedef union {
	__be32 a4;
	__be32 a6[4];
	struct in6_addr in6;
} xfrm_address_t;

struct xfrm_id {
	xfrm_address_t daddr;
	__be32 spi;
	__u8 proto;
};

struct xfrm_selector {
	xfrm_address_t daddr;
	xfrm_address_t saddr;
	__be16 dport;
	__be16 dport_mask;
	__be16 sport;
	__be16 sport_mask;
	__u16 family;
	__u8 prefixlen_d;
	__u8 prefixlen_s;
	__u8 proto;
	int ifindex;
	__kernel_uid32_t user;
};

struct xfrm_lifetime_cfg {
	__u64 soft_byte_limit;
	__u64 hard_byte_limit;
	__u64 soft_packet_limit;
	__u64 hard_packet_limit;
	__u64 soft_add_expires_seconds;
	__u64 hard_add_expires_seconds;
	__u64 soft_use_expires_seconds;
	__u64 hard_use_expires_seconds;
};

struct xfrm_lifetime_cur {
	__u64 bytes;
	__u64 packets;
	__u64 add_time;
	__u64 use_time;
};

struct xfrm_replay_state {
	__u32 oseq;
	__u32 seq;
	__u32 bitmap;
};

struct xfrm_replay_state_esn {
	unsigned int bmp_len;
	__u32 oseq;
	__u32 seq;
	__u32 oseq_hi;
	__u32 seq_hi;
	__u32 replay_window;
	__u32 bmp[0];
};

struct xfrm_algo {
	char alg_name[64];
	unsigned int alg_key_len;
	char alg_key[0];
};

struct xfrm_algo_auth {
	char alg_name[64];
	unsigned int alg_key_len;
	unsigned int alg_trunc_len;
	char alg_key[0];
};

struct xfrm_algo_aead {
	char alg_name[64];
	unsigned int alg_key_len;
	unsigned int alg_icv_len;
	char alg_key[0];
};

struct xfrm_stats {
	__u32 replay_window;
	__u32 replay;
	__u32 integrity_failed;
};

enum {
	XFRM_POLICY_TYPE_MAIN = 0,
	XFRM_POLICY_TYPE_SUB = 1,
	XFRM_POLICY_TYPE_MAX = 2,
	XFRM_POLICY_TYPE_ANY = 255,
};

struct xfrm_encap_tmpl {
	__u16 encap_type;
	__be16 encap_sport;
	__be16 encap_dport;
	xfrm_address_t encap_oa;
};

struct xfrm_mark {
	__u32 v;
	__u32 m;
};

struct xfrm_address_filter {
	xfrm_address_t saddr;
	xfrm_address_t daddr;
	__u16 family;
	__u8 splen;
	__u8 dplen;
};

struct ucounts___208 {
	struct hlist_node node;
	struct user_namespace___208 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_prog_aux___35;

struct bpf_prog___33 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___35 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

struct seq_operations___222 {
	void * (*start)(struct seq_file___224 *, loff_t *);
	void (*stop)(struct seq_file___224 *, void *);
	void * (*next)(struct seq_file___224 *, void *, loff_t *);
	int (*show)(struct seq_file___224 *, void *);
};

struct pernet_operations___35 {
	struct list_head list;
	int (*init)(struct net___6 *);
	void (*exit)(struct net___6 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___34 {
	int (*ieee_getets)(struct net_device___7 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___7 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___7 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___7 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___7 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___7 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___7 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___7 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___7 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___7 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___7 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___7 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___7 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___7 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___7 *);
	u8 (*setstate)(struct net_device___7 *, u8);
	void (*getpermhwaddr)(struct net_device___7 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___7 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___7 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___7 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___7 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___7 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___7 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___7 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___7 *, int, u8 *);
	void (*setpfccfg)(struct net_device___7 *, int, u8);
	void (*getpfccfg)(struct net_device___7 *, int, u8 *);
	u8 (*setall)(struct net_device___7 *);
	u8 (*getcap)(struct net_device___7 *, int, u8 *);
	int (*getnumtcs)(struct net_device___7 *, int, u8 *);
	int (*setnumtcs)(struct net_device___7 *, int, u8);
	u8 (*getpfcstate)(struct net_device___7 *);
	void (*setpfcstate)(struct net_device___7 *, u8);
	void (*getbcncfg)(struct net_device___7 *, int, u32 *);
	void (*setbcncfg)(struct net_device___7 *, int, u32);
	void (*getbcnrp)(struct net_device___7 *, int, u8 *);
	void (*setbcnrp)(struct net_device___7 *, int, u8);
	int (*setapp)(struct net_device___7 *, u8, u16, u8);
	int (*getapp)(struct net_device___7 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___7 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___7 *, int, u8);
	u8 (*getdcbx)(struct net_device___7 *);
	u8 (*setdcbx)(struct net_device___7 *, u8);
	int (*peer_getappinfo)(struct net_device___7 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___7 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___7 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___7 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___7 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___7 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___193 {
	refcount_t count;
	struct ns_common___28 ns;
	struct user_namespace___208 *user_ns;
	struct ucounts___208 *ucounts;
	struct css_set___193 *root_cset;
};

struct bpf_map___193;

struct bpf_map_ops___193 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___193 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___193 *, struct file___248 *);
	void (*map_free)(struct bpf_map___193 *);
	int (*map_get_next_key)(struct bpf_map___193 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___193 *);
	void * (*map_lookup_elem)(struct bpf_map___193 *, void *);
	int (*map_update_elem)(struct bpf_map___193 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___193 *, void *);
	int (*map_push_elem)(struct bpf_map___193 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___193 *, void *);
	int (*map_peek_elem)(struct bpf_map___193 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___193 *, struct file___248 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___193 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___193 *, void *, struct seq_file___224 *);
	int (*map_check_btf)(const struct bpf_map___193 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___193 {
	const struct bpf_map_ops___193 *ops;
	struct bpf_map___193 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___241 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___34;

struct bpf_map_dev_ops___34 {
	int (*map_get_next_key)(struct bpf_offloaded_map___34 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___34 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___34 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___34 *, void *);
};

struct bpf_offloaded_map___34 {
	struct bpf_map___193 map;
	struct net_device___7 *netdev;
	const struct bpf_map_dev_ops___34 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___33 {
	int (*test_run)(struct bpf_prog___33 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___33 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___33 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___33 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___33 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___33 *, u32 *);
};

struct bpf_prog_offload_ops___33 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___33 *);
	int (*translate)(struct bpf_prog___33 *);
	void (*destroy)(struct bpf_prog___33 *);
};

struct bpf_prog_offload___33 {
	struct bpf_prog___33 *prog;
	struct net_device___7 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___33 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___35 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___33 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___33 *ops;
	struct bpf_map___193 **used_maps;
	struct bpf_prog___33 *prog;
	struct user_struct___241 *user;
	u64 load_time;
	struct bpf_map___193 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___33 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___33 {
	struct bpf_prog___33 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___33 {
	struct callback_head rcu;
	struct bpf_prog_array_item___33 items[0];
};

struct cgroup_bpf___33 {
	struct bpf_prog_array___33 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___33 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___193;

typedef void (*kthread_work_func_t___193)(struct kthread_work___193 *);

struct kthread_worker___193;

struct kthread_work___193 {
	struct list_head node;
	kthread_work_func_t___193 func;
	struct kthread_worker___193 *worker;
	int canceling;
};

struct kthread_worker___193 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___249 *task;
	struct kthread_work___193 *current_work;
};

struct kthread_delayed_work___193 {
	struct kthread_work___193 work;
	struct timer_list timer;
};

struct psi_group___193 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___193 *poll_kworker;
	struct kthread_delayed_work___193 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___193;

struct cgroup_rstat_cpu___193;

struct cgroup___193 {
	struct cgroup_subsys_state___194 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___242 *kn;
	struct cgroup_file___193 procs_file;
	struct cgroup_file___193 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___194 *subsys[13];
	struct cgroup_root___193 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___193 *dom_cgrp;
	struct cgroup_rstat_cpu___193 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___33 bpf;
	atomic_t congestion_count;
	struct cgroup___193 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___193 psi;
	int ancestor_ids[0];
};

struct cftype___193;

struct cgroup_subsys___193 {
	struct cgroup_subsys_state___194 * (*css_alloc)(struct cgroup_subsys_state___194 *);
	int (*css_online)(struct cgroup_subsys_state___194 *);
	void (*css_offline)(struct cgroup_subsys_state___194 *);
	void (*css_released)(struct cgroup_subsys_state___194 *);
	void (*css_free)(struct cgroup_subsys_state___194 *);
	void (*css_reset)(struct cgroup_subsys_state___194 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___194 *, int);
	int (*css_extra_stat_show)(struct seq_file___224 *, struct cgroup_subsys_state___194 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___249 *);
	void (*cancel_fork)(struct task_struct___249 *);
	void (*fork)(struct task_struct___249 *);
	void (*exit)(struct task_struct___249 *);
	void (*free)(struct task_struct___249 *);
	void (*bind)(struct cgroup_subsys_state___194 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___193 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___193 *dfl_cftypes;
	struct cftype___193 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___193 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___193 *updated_children;
	struct cgroup___193 *updated_next;
};

struct cgroup_root___193 {
	struct kernfs_root___242 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___193 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___193 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___193 *ss;
	struct list_head node;
	struct kernfs_ops___242 *kf_ops;
	int (*open)(struct kernfs_open_file___242 *);
	void (*release)(struct kernfs_open_file___242 *);
	u64 (*read_u64)(struct cgroup_subsys_state___194 *, struct cftype___193 *);
	s64 (*read_s64)(struct cgroup_subsys_state___194 *, struct cftype___193 *);
	int (*seq_show)(struct seq_file___224 *, void *);
	void * (*seq_start)(struct seq_file___224 *, loff_t *);
	void * (*seq_next)(struct seq_file___224 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___224 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___194 *, struct cftype___193 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___194 *, struct cftype___193 *, s64);
	ssize_t (*write)(struct kernfs_open_file___242 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___242 *, struct poll_table_struct___156 *);
};

struct xdp_rxq_info___34 {
	struct net_device___7 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___34 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___7 *dev_rx;
};

struct netlink_callback___34 {
	struct sk_buff___6 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___34 *);
	int (*dump)(struct sk_buff___6 *, struct netlink_callback___34 *);
	int (*done)(struct netlink_callback___34 *);
	void *data;
	struct module___202 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___34 {
	int (*create)(struct sk_buff___6 *, struct net_device___7 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___6 *, unsigned char *);
	int (*cache)(const struct neighbour___3 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___7 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___34 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___34 *, int);
	int poll_owner;
	struct net_device___7 *dev;
	struct sk_buff___6 *gro_list;
	struct sk_buff___6 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___34 {
	struct net_device___7 *dev;
	struct Qdisc___33 *qdisc;
	struct Qdisc___33 *qdisc_sleeping;
	struct kobject___236 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___7 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___33 {
	struct sk_buff___6 *head;
	struct sk_buff___6 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___33;

struct Qdisc___33 {
	int (*enqueue)(struct sk_buff___6 *, struct Qdisc___33 *, struct sk_buff___6 **);
	struct sk_buff___6 * (*dequeue)(struct Qdisc___33 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___33 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___34 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___34 gso_skb;
	struct qdisc_skb_head___33 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___33 *next_sched;
	struct sk_buff_head___34 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___34 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___236 kobj;
	struct net_device___7 *dev;
	long: 64;
	struct xdp_rxq_info___34 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___34)(struct net_device___7 *, struct sk_buff___6 *, struct net_device___7 *);

struct netdev_bpf___34 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___33 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___33 *prog;
			const struct bpf_prog_offload_ops___33 *ops;
		} verifier;
		struct {
			struct bpf_prog___33 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___34 *offmap;
		};
		struct {
			struct xdp_umem *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___34 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___6 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct xfrm_state_walk {
	struct list_head all;
	u8 state;
	u8 dying;
	u8 proto;
	u32 seq;
	struct xfrm_address_filter *filter;
	long unsigned int rh_reserved1;
};

struct xfrm_state_offload {
	struct net_device___7 *dev;
	long unsigned int offload_handle;
	unsigned int num_exthdrs;
	u8 flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct xfrm_replay;

struct xfrm_type;

struct xfrm_mode;

struct xfrm_type_offload;

struct xfrm_state {
	possible_net_t___35 xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	refcount_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
		u32 output_mark;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	const char *geniv;
	struct xfrm_encap_tmpl *encap;
	xfrm_address_t *coaddr;
	struct xfrm_state *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	const struct xfrm_replay *repl;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct tasklet_hrtimer mtimer;
	struct xfrm_state_offload xso;
	long int saved_tmo;
	long unsigned int lastused;
	struct page_frag___248 xfrag;
	const struct xfrm_type *type;
	struct xfrm_mode *inner_mode;
	struct xfrm_mode *inner_mode_iaf;
	struct xfrm_mode *outer_mode;
	const struct xfrm_type_offload *type_offload;
	struct xfrm_sec_ctx___2 *security;
	void *data;
	u32 output_mark_mask;
	u32 if_id;
};

struct tlsdev_ops___34 {
	int (*tls_dev_add)(struct net_device___7 *, struct sock___25 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___7 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___7 *, struct sock___25 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___34 {
	int (*ndo_init)(struct net_device___7 *);
	void (*ndo_uninit)(struct net_device___7 *);
	int (*ndo_open)(struct net_device___7 *);
	int (*ndo_stop)(struct net_device___7 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___6 *, struct net_device___7 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___6 *, struct net_device___7 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___7 *, struct sk_buff___6 *, struct net_device___7 *, select_queue_fallback_t___34);
	void (*ndo_change_rx_flags)(struct net_device___7 *, int);
	void (*ndo_set_rx_mode)(struct net_device___7 *);
	int (*ndo_set_mac_address)(struct net_device___7 *, void *);
	int (*ndo_validate_addr)(struct net_device___7 *);
	int (*ndo_do_ioctl)(struct net_device___7 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___7 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___7 *, int);
	int (*ndo_neigh_setup)(struct net_device___7 *, struct neigh_parms___24 *);
	void (*ndo_tx_timeout)(struct net_device___7 *);
	void (*ndo_get_stats64)(struct net_device___7 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___7 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___7 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___7 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___7 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___7 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___7 *);
	int (*ndo_netpoll_setup)(struct net_device___7 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___7 *);
	int (*ndo_set_vf_mac)(struct net_device___7 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___7 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___7 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___7 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___7 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___7 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___7 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___7 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___7 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___7 *, int, struct sk_buff___6 *);
	int (*ndo_set_vf_guid)(struct net_device___7 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___7 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___7 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___7 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___7 *, const struct sk_buff___6 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___7 *, struct net_device___7 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___7 *, struct net_device___7 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___7 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___7 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___7 *, struct neighbour___3 *);
	void (*ndo_neigh_destroy)(struct net_device___7 *, struct neighbour___3 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___7 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___7 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___7 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___6 *, struct netlink_callback___34 *, struct net_device___7 *, struct net_device___7 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___7 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___7 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___6 *, u32, u32, struct net_device___7 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___7 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___7 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___7 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___7 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___7 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___7 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___7 *, struct net_device___7 *);
	void (*ndo_dfwd_del_station)(struct net_device___7 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___7 *);
	int (*ndo_set_tx_maxrate)(struct net_device___7 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___7 *);
	int (*ndo_change_proto_down)(struct net_device___7 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___7 *, struct sk_buff___6 *);
	void (*ndo_set_rx_headroom)(struct net_device___7 *, int);
	int (*ndo_bpf)(struct net_device___7 *, struct netdev_bpf___34 *);
	int (*ndo_xdp_xmit)(struct net_device___7 *, int, struct xdp_frame___34 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___7 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___7 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___24 {
	possible_net_t___35 net;
	struct net_device___7 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___3 *);
	void (*neigh_cleanup)(struct neighbour___3 *);
	struct neigh_table___23 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___24 {
	u32 (*l3mdev_fib_table)(const struct net_device___7 *);
	struct sk_buff___6 * (*l3mdev_l3_rcv)(struct net_device___7 *, struct sk_buff___6 *, u16);
	struct sk_buff___6 * (*l3mdev_l3_out)(struct net_device___7 *, struct sock___25 *, struct sk_buff___6 *, u16);
	struct dst_entry___24 * (*l3mdev_link_scope_lookup)(const struct net_device___7 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct ifmcaddr6___14;

struct inet6_dev___2 {
	struct net_device___7 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___14 *mc_list;
	struct ifmcaddr6___14 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	u8 rndid[8];
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___24 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
};

struct tcf_proto___33;

struct mini_Qdisc___33 {
	struct tcf_proto___33 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___33 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___7 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___6 *, struct net_device___7 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___7 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___7 *, struct list_head *);
	size_t (*get_size)(const struct net_device___7 *);
	int (*fill_info)(struct sk_buff___6 *, const struct net_device___7 *);
	size_t (*get_xstats_size)(const struct net_device___7 *);
	int (*fill_xstats)(struct sk_buff___6 *, const struct net_device___7 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___7 *, struct net_device___7 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___7 *, const struct net_device___7 *);
	int (*fill_slave_info)(struct sk_buff___6 *, const struct net_device___7 *, const struct net_device___7 *);
	struct net___6 * (*get_link_net)(const struct net_device___7 *);
	size_t (*get_linkxstats_size)(const struct net_device___7 *, int);
	int (*fill_linkxstats)(struct sk_buff___6 *, const struct net_device___7 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___34 {
	struct list_head poll_list;
	struct sk_buff_head___34 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___34 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___33 *output_queue;
	struct Qdisc___33 **output_queue_tailp;
	struct sk_buff___6 *completion_queue;
	struct sk_buff_head___34 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___34 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___34 input_pkt_queue;
	struct napi_struct___34 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bdi_writeback_congested___124 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___124 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___124 {
	struct bio___124 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___124 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___124 bip_inline_vecs[0];
};

struct bio_set___124 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___124 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___109 {
	struct mem_cgroup___109 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___109 {
	struct lruvec___248 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___109 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___109 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct kernel_param_ops___199 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___199 *);
	int (*get)(char *, const struct kernel_param___199 *);
	void (*free)(void *);
};

struct kparam_array___199;

struct kernel_param___199 {
	const char *name;
	struct module___202 *mod;
	const struct kernel_param_ops___199 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___199 *arr;
	};
};

struct kparam_array___199 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___199 *ops;
	void *elem;
};

struct module_attribute___199 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___199 *, struct module_kobject___199 *, char *);
	ssize_t (*store)(struct module_attribute___199 *, struct module_kobject___199 *, const char *, size_t);
	void (*setup)(struct module___202 *, const char *);
	int (*test)(struct module___202 *);
	void (*free)(struct module___202 *);
};

struct gnet_dump___33 {
	spinlock_t *lock;
	struct sk_buff___6 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___33;

struct Qdisc_ops___33 {
	struct Qdisc_ops___33 *next;
	const struct Qdisc_class_ops___33 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___6 *, struct Qdisc___33 *, struct sk_buff___6 **);
	struct sk_buff___6 * (*dequeue)(struct Qdisc___33 *);
	struct sk_buff___6 * (*peek)(struct Qdisc___33 *);
	int (*init)(struct Qdisc___33 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___33 *);
	void (*destroy)(struct Qdisc___33 *);
	int (*change)(struct Qdisc___33 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___33 *);
	int (*change_tx_queue_len)(struct Qdisc___33 *, unsigned int);
	int (*dump)(struct Qdisc___33 *, struct sk_buff___6 *);
	int (*dump_stats)(struct Qdisc___33 *, struct gnet_dump___33 *);
	void (*ingress_block_set)(struct Qdisc___33 *, u32);
	void (*egress_block_set)(struct Qdisc___33 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___33 *);
	u32 (*egress_block_get)(struct Qdisc___33 *);
	struct module___202 *owner;
};

struct tcf_block___33;

struct Qdisc_class_ops___33 {
	unsigned int flags;
	struct netdev_queue___34 * (*select_queue)(struct Qdisc___33 *, struct tcmsg *);
	int (*graft)(struct Qdisc___33 *, long unsigned int, struct Qdisc___33 *, struct Qdisc___33 **, struct netlink_ext_ack *);
	struct Qdisc___33 * (*leaf)(struct Qdisc___33 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___33 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___33 *, u32);
	int (*change)(struct Qdisc___33 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___33 *, long unsigned int);
	void (*walk)(struct Qdisc___33 *, struct qdisc_walker *);
	struct tcf_block___33 * (*tcf_block)(struct Qdisc___33 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___33 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___33 *, long unsigned int);
	int (*dump)(struct Qdisc___33 *, long unsigned int, struct sk_buff___6 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___33 *, long unsigned int, struct gnet_dump___33 *);
};

struct tcf_chain___33;

struct tcf_block___33 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___6 *net;
	struct Qdisc___33 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___33 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___33;

struct tcf_proto_ops___33;

struct tcf_proto___33 {
	struct tcf_proto___33 *next;
	void *root;
	int (*classify)(struct sk_buff___6 *, const struct tcf_proto___33 *, struct tcf_result___33 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___33 *ops;
	struct tcf_chain___33 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___33 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___33 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___33 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___6 *, const struct tcf_proto___33 *, struct tcf_result___33 *);
	int (*init)(struct tcf_proto___33 *);
	void (*destroy)(struct tcf_proto___33 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___33 *, u32);
	void (*put)(struct tcf_proto___33 *, void *);
	int (*change)(struct net___6 *, struct sk_buff___6 *, struct tcf_proto___33 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___33 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___33 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___33 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___6 *, struct tcf_chain___33 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___6 *, struct tcf_proto___33 *, void *, struct sk_buff___6 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___6 *, struct net___6 *, void *);
	struct module___202 *owner;
	int flags;
};

struct tcf_chain___33 {
	struct mutex filter_chain_lock;
	struct tcf_proto___33 *filter_chain;
	struct list_head list;
	struct tcf_block___33 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___33 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___23 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___33 *prog;
};

struct bpf_redirect_info___33 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___193 *map;
	struct bpf_map___193 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___23;

struct neigh_hash_table___23;

struct neigh_table___23 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___7 *, __u32 *);
	bool (*key_eq)(const struct neighbour___3 *, const void *);
	int (*constructor)(struct neighbour___3 *);
	int (*pconstructor)(struct pneigh_entry___23 *);
	void (*pdestructor)(struct pneigh_entry___23 *);
	void (*proxy_redo)(struct sk_buff___6 *);
	char *id;
	struct neigh_parms___24 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___34 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___23 *nht;
	struct pneigh_entry___23 **phash_buckets;
};

struct neigh_ops___23 {
	int family;
	void (*solicit)(struct neighbour___3 *, struct sk_buff___6 *);
	void (*error_report)(struct neighbour___3 *, struct sk_buff___6 *);
	int (*output)(struct neighbour___3 *, struct sk_buff___6 *);
	int (*connected_output)(struct neighbour___3 *, struct sk_buff___6 *);
};

struct pneigh_entry___23 {
	struct pneigh_entry___23 *next;
	possible_net_t___35 net;
	struct net_device___7 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___23 {
	struct neighbour___3 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___23 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___23 *ctarget;
	struct net___6 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___23 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___23 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___16;

struct proto___23 {
	void (*close)(struct sock___25 *, long int);
	int (*pre_connect)(struct sock___25 *, struct sockaddr *, int);
	int (*connect)(struct sock___25 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___25 *, int);
	struct sock___25 * (*accept)(struct sock___25 *, int, int *, bool);
	int (*ioctl)(struct sock___25 *, int, long unsigned int);
	int (*init)(struct sock___25 *);
	void (*destroy)(struct sock___25 *);
	void (*shutdown)(struct sock___25 *, int);
	int (*setsockopt)(struct sock___25 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___25 *, int, int, char *, int *);
	void (*keepalive)(struct sock___25 *, int);
	int (*sendmsg)(struct sock___25 *, struct msghdr___25 *, size_t);
	int (*recvmsg)(struct sock___25 *, struct msghdr___25 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___25 *, struct page___249 *, int, size_t, int);
	int (*bind)(struct sock___25 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___25 *, struct sk_buff___6 *);
	void (*release_cb)(struct sock___25 *);
	int (*hash)(struct sock___25 *);
	void (*unhash)(struct sock___25 *);
	void (*rehash)(struct sock___25 *);
	int (*get_port)(struct sock___25 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___25 *);
	bool (*stream_memory_read)(const struct sock___25 *);
	void (*enter_memory_pressure)(struct sock___25 *);
	void (*leave_memory_pressure)(struct sock___25 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___16 *rsk_prot;
	struct timewait_sock_ops___3 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___202 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___25 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct xfrm_policy_walk_entry {
	struct list_head all;
	u8 dead;
};

struct xfrm_policy_queue {
	struct sk_buff_head___34 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_tmpl {
	struct xfrm_id id;
	xfrm_address_t saddr;
	short unsigned int encap_family;
	u32 reqid;
	u8 mode;
	u8 share;
	u8 optional;
	u8 allalgs;
	u32 aalgos;
	u32 ealgos;
	u32 calgos;
};

struct xfrm_policy {
	possible_net_t___35 xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	refcount_t refcnt;
	struct timer_list timer;
	atomic_t genid;
	u32 priority;
	u32 index;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue polq;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx___2 *security;
	struct xfrm_tmpl xfrm_vec[6];
	struct callback_head rcu;
	u32 if_id;
};

struct udp_hslot;

struct udp_table {
	struct udp_hslot *hash;
	struct udp_hslot *hash2;
	unsigned int mask;
	unsigned int log;
};

struct request_sock___17;

struct request_sock_ops___16 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___25 *, struct request_sock___17 *);
	void (*send_ack)(const struct sock___25 *, struct sk_buff___6 *, struct request_sock___17 *);
	void (*send_reset)(const struct sock___25 *, struct sk_buff___6 *);
	void (*destructor)(struct request_sock___17 *);
	void (*syn_ack_timeout)(const struct request_sock___17 *);
};

struct timewait_sock_ops___3 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___25 *, struct sock___25 *, void *);
	void (*twsk_destructor)(struct sock___25 *);
};

struct request_sock___17 {
	struct sock_common___23 __req_common;
	struct request_sock___17 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___16 *rsk_ops;
	struct sock___25 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___14 {
	struct in6_addr mca_addr;
	struct inet6_dev___2 *idev;
	struct ifmcaddr6___14 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ip6_ra_chain___14 {
	struct ip6_ra_chain___14 *next;
	struct sock___25 *sk;
	int sel;
	void (*destructor)(struct sock___25 *);
};

struct rtable {
	struct dst_entry___24 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	__be32 rt_gateway;
	u32 rt_mtu_locked: 1;
	u32 rt_pmtu: 31;
	struct list_head rt_uncached;
	struct uncached_list *rt_uncached_list;
};

struct rt6_exception_bucket {
	struct hlist_head chain;
	int depth;
};

struct xfrm_replay {
	void (*advance)(struct xfrm_state *, __be32);
	int (*check)(struct xfrm_state *, struct sk_buff___6 *, __be32);
	int (*recheck)(struct xfrm_state *, struct sk_buff___6 *, __be32);
	void (*notify)(struct xfrm_state *, int);
	int (*overflow)(struct xfrm_state *, struct sk_buff___6 *);
};

struct xfrm_type {
	char *description;
	struct module___202 *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state *);
	void (*destructor)(struct xfrm_state *);
	int (*input)(struct xfrm_state *, struct sk_buff___6 *);
	int (*output)(struct xfrm_state *, struct sk_buff___6 *);
	int (*reject)(struct xfrm_state *, struct sk_buff___6 *, const struct flowi *);
	int (*hdr_offset)(struct xfrm_state *, struct sk_buff___6 *, u8 **);
	u32 (*get_mtu)(struct xfrm_state *, int);
};

struct xfrm_state_afinfo;

struct xfrm_mode {
	int (*input2)(struct xfrm_state *, struct sk_buff___6 *);
	int (*input)(struct xfrm_state *, struct sk_buff___6 *);
	int (*output2)(struct xfrm_state *, struct sk_buff___6 *);
	int (*output)(struct xfrm_state *, struct sk_buff___6 *);
	struct sk_buff___6 * (*gso_segment)(struct xfrm_state *, struct sk_buff___6 *, netdev_features_t);
	void (*xmit)(struct xfrm_state *, struct sk_buff___6 *);
	struct xfrm_state_afinfo *afinfo;
	struct module___202 *owner;
	unsigned int encap;
	int flags;
};

struct xfrm_type_offload {
	char *description;
	struct module___202 *owner;
	u8 proto;
	void (*encap)(struct xfrm_state *, struct sk_buff___6 *);
	int (*input_tail)(struct xfrm_state *, struct sk_buff___6 *);
	int (*xmit)(struct xfrm_state *, struct sk_buff___6 *, netdev_features_t);
};

struct xfrm_dst {
	union {
		struct dst_entry___24 dst;
		struct rtable rt;
		struct rt6_info rt6;
	} u;
	struct dst_entry___24 *route;
	struct dst_entry___24 *child;
	struct dst_entry___24 *path;
	struct xfrm_policy *pols[2];
	int num_pols;
	int num_xfrms;
	u32 xfrm_genid;
	u32 policy_genid;
	u32 route_mtu_cached;
	u32 child_mtu_cached;
	u32 route_cookie;
	u32 path_cookie;
};

struct xfrm_state_afinfo {
	unsigned int family;
	unsigned int proto;
	__be16 eth_proto;
	struct module___202 *owner;
	const struct xfrm_type *type_map[256];
	const struct xfrm_type_offload *type_offload_map[256];
	struct xfrm_mode *mode_map[5];
	int (*init_flags)(struct xfrm_state *);
	void (*init_tempsel)(struct xfrm_selector *, const struct flowi *);
	void (*init_temprop)(struct xfrm_state *, const struct xfrm_tmpl *, const xfrm_address_t *, const xfrm_address_t *);
	int (*tmpl_sort)(struct xfrm_tmpl **, struct xfrm_tmpl **, int);
	int (*state_sort)(struct xfrm_state **, struct xfrm_state **, int);
	int (*output)(struct net___6 *, struct sock___25 *, struct sk_buff___6 *);
	int (*output_finish)(struct sock___25 *, struct sk_buff___6 *);
	int (*extract_input)(struct xfrm_state *, struct sk_buff___6 *);
	int (*extract_output)(struct xfrm_state *, struct sk_buff___6 *);
	int (*transport_finish)(struct sk_buff___6 *, int);
	void (*local_error)(struct sk_buff___6 *, u32);
};

struct udp_hslot {
	struct hlist_head head;
	int count;
	spinlock_t lock;
};

struct lsm_network_audit___3 {
	int netif;
	struct sock___25 *sk;
	u16 family;
	__be16 dport;
	__be16 sport;
	union {
		struct {
			__be32 daddr;
			__be32 saddr;
		} v4;
		struct {
			struct in6_addr daddr;
			struct in6_addr saddr;
		} v6;
	} fam;
};

struct lsm_ioctlop_audit___3 {
	struct path___248 path;
	u16 cmd;
};

struct common_audit_data___3 {
	char type;
	union {
		struct path___248 path;
		struct dentry___248 *dentry;
		struct inode___248 *inode;
		struct lsm_network_audit___3 *net;
		int cap;
		int ipc_id;
		struct task_struct___249 *tsk;
		struct {
			key_serial_t key;
			char *key_desc;
		} key_struct;
		char *kmod_name;
		struct lsm_ioctlop_audit___3 *op;
		struct file___248 *file;
		struct lsm_ibpkey_audit *ibpkey;
		struct lsm_ibendport_audit *ibendport;
	} u;
	union {
		struct selinux_audit_data *selinux_audit_data;
	};
};

struct linux_binprm___45 {
	char buf[256];
	struct vm_area_struct___249 *vma;
	long unsigned int vma_pages;
	struct mm_struct___248 *mm;
	long unsigned int p;
	unsigned int called_set_creds: 1;
	unsigned int cap_elevated: 1;
	unsigned int secureexec: 1;
	unsigned int recursion_depth;
	struct file___248 *file;
	struct cred___241 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	unsigned int interp_flags;
	unsigned int interp_data;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
};

struct coredump_params___44 {
	union {
		const kernel_siginfo_t *siginfo;
		struct {
			const siginfo_t *siginfo;
		} __UNIQUE_ID_rh_kabi_hide77;
		union {		};
	};
	struct pt_regs *regs;
	struct file___248 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
};

struct crypto_async_request___6;

typedef void (*crypto_completion_t___6)(struct crypto_async_request___6 *, int);

struct crypto_tfm___6;

struct crypto_async_request___6 {
	struct list_head list;
	crypto_completion_t___6 complete;
	void *data;
	struct crypto_tfm___6 *tfm;
	u32 flags;
};

struct crypto_ablkcipher___6;

struct ablkcipher_request___6;

struct ablkcipher_tfm___6 {
	int (*setkey)(struct crypto_ablkcipher___6 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___6 *);
	int (*decrypt)(struct ablkcipher_request___6 *);
	struct crypto_ablkcipher___6 *base;
	unsigned int ivsize;
	unsigned int reqsize;
};

struct blkcipher_desc___6;

struct blkcipher_tfm___6 {
	void *iv;
	int (*setkey)(struct crypto_tfm___6 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___6 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___6 *, struct scatterlist *, struct scatterlist *, unsigned int);
};

struct cipher_tfm___6 {
	int (*cit_setkey)(struct crypto_tfm___6 *, const u8 *, unsigned int);
	void (*cit_encrypt_one)(struct crypto_tfm___6 *, u8 *, const u8 *);
	void (*cit_decrypt_one)(struct crypto_tfm___6 *, u8 *, const u8 *);
};

struct compress_tfm___6 {
	int (*cot_compress)(struct crypto_tfm___6 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*cot_decompress)(struct crypto_tfm___6 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___6;

struct crypto_tfm___6 {
	u32 crt_flags;
	union {
		struct ablkcipher_tfm___6 ablkcipher;
		struct blkcipher_tfm___6 blkcipher;
		struct cipher_tfm___6 cipher;
		struct compress_tfm___6 compress;
	} crt_u;
	void (*exit)(struct crypto_tfm___6 *);
	struct crypto_alg___6 *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct ablkcipher_request___6 {
	struct crypto_async_request___6 base;
	unsigned int nbytes;
	void *info;
	struct scatterlist *src;
	struct scatterlist *dst;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_blkcipher___6;

struct blkcipher_desc___6 {
	struct crypto_blkcipher___6 *tfm;
	void *info;
	u32 flags;
};

struct crypto_blkcipher___6 {
	struct crypto_tfm___6 base;
};

struct ablkcipher_alg___6 {
	int (*setkey)(struct crypto_ablkcipher___6 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___6 *);
	int (*decrypt)(struct ablkcipher_request___6 *);
	int (*givencrypt)(struct skcipher_givcrypt_request *);
	int (*givdecrypt)(struct skcipher_givcrypt_request *);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct crypto_ablkcipher___6 {
	struct crypto_tfm___6 base;
};

struct blkcipher_alg___6 {
	int (*setkey)(struct crypto_tfm___6 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___6 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___6 *, struct scatterlist *, struct scatterlist *, unsigned int);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct cipher_alg___6 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___6 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___6 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___6 *, u8 *, const u8 *);
};

struct compress_alg___6 {
	int (*coa_compress)(struct crypto_tfm___6 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___6 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___6 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type *cra_type;
	union {
		struct ablkcipher_alg___6 ablkcipher;
		struct blkcipher_alg___6 blkcipher;
		struct cipher_alg___6 cipher;
		struct compress_alg___6 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___6 *);
	void (*cra_exit)(struct crypto_tfm___6 *);
	void (*cra_destroy)(struct crypto_alg___6 *);
	struct module___198 *cra_module;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct crypto_shash___4 {
	unsigned int descsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_tfm___6 base;
};

struct inet_cork___2 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___20 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
	__u16 gso_size;
	u64 transmit_time;
};

struct inet_cork_full___2 {
	struct inet_cork___2 base;
	struct flowi fl;
};

struct ipv6_pinfo___2;

struct inet_sock___2 {
	struct sock___21 sk;
	struct ipv6_pinfo___2 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	__be16 inet_sport;
	__u16 inet_id;
	struct ip_options_rcu *inet_opt;
	int rx_dst_ifindex;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 bind_address_no_port: 1;
	__u8 defer_connect: 1;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___2 cork;
};

struct ipv6_fl_socklist___2;

struct ipv6_pinfo___2 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
			__u16 recvfragsize: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 repflow: 1;
	__u16 pmtudisc: 3;
	__u16 padding: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u16 autoflowlabel: 1;
	__u16 autoflowlabel_set: 1;
	__u8 min_hopcount;
	__u8 tclass;
	__be32 rcv_flowinfo;
	__u32 dst_cookie;
	__u32 rx_dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___2 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___34 *pktoptions;
	struct sk_buff___34 *rxpmtu;
	struct inet6_cork cork;
};

struct ip6_flowlabel___2;

struct ipv6_fl_socklist___2 {
	struct ipv6_fl_socklist___2 *next;
	struct ip6_flowlabel___2 *fl;
	struct callback_head rcu;
};

struct ip6_flowlabel___2 {
	struct ip6_flowlabel___2 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___184 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___42 *fl_net;
};

struct lsm_network_audit___4 {
	int netif;
	struct sock___21 *sk;
	u16 family;
	__be16 dport;
	__be16 sport;
	union {
		struct {
			__be32 daddr;
			__be32 saddr;
		} v4;
		struct {
			struct in6_addr daddr;
			struct in6_addr saddr;
		} v6;
	} fam;
};

struct lsm_ioctlop_audit___4 {
	struct path___243 path;
	u16 cmd;
};

struct common_audit_data___4 {
	char type;
	union {
		struct path___243 path;
		struct dentry___244 *dentry;
		struct inode___244 *inode;
		struct lsm_network_audit___4 *net;
		int cap;
		int ipc_id;
		struct task_struct___245 *tsk;
		struct {
			key_serial_t key;
			char *key_desc;
		} key_struct;
		char *kmod_name;
		struct lsm_ioctlop_audit___4 *op;
		struct file___244 *file;
		struct lsm_ibpkey_audit *ibpkey;
		struct lsm_ibendport_audit *ibendport;
	} u;
	union {
		struct selinux_audit_data *selinux_audit_data;
	};
};

struct sctp_chunk___2;

struct sctp_inq___2 {
	struct list_head in_chunk_list;
	struct sctp_chunk___2 *in_progress;
	struct work_struct immediate;
};

struct sctp_ep_common___2 {
	struct hlist_node node;
	int hashent;
	enum sctp_endpoint_type type;
	refcount_t refcnt;
	bool dead;
	struct sock___21 *sk;
	struct sctp_inq___2 inqueue;
	struct sctp_bind_addr bind_addr;
};

struct sctp_stream_interleave___2;

struct sctp_stream___2 {
	struct sctp_stream_out *out;
	struct sctp_stream_in *in;
	__u16 outcnt;
	__u16 incnt;
	struct sctp_stream_out *out_curr;
	union {
		struct {
			struct list_head prio_list;
		};
		struct {
			struct list_head rr_list;
			struct sctp_stream_out_ext *rr_next;
		};
	};
	struct sctp_stream_interleave___2 *si;
};

struct sctp_association___2;

struct sctp_outq___2 {
	struct sctp_association___2 *asoc;
	struct list_head out_chunk_list;
	struct sctp_sched_ops *sched;
	unsigned int out_qlen;
	unsigned int error;
	struct list_head control_chunk_list;
	struct list_head sacked;
	struct list_head retransmit;
	struct list_head abandoned;
	__u32 outstanding_bytes;
	char fast_rtx;
	char cork;
};

struct sctp_ulpq___2 {
	char pd_mode;
	struct sctp_association___2 *asoc;
	struct sk_buff_head___30 reasm;
	struct sk_buff_head___30 reasm_uo;
	struct sk_buff_head___30 lobby;
};

struct sctp_endpoint___3;

struct sctp_transport___2;

struct sctp_association___2 {
	struct sctp_ep_common___2 base;
	struct list_head asocs;
	sctp_assoc_t assoc_id;
	struct sctp_endpoint___3 *ep;
	struct sctp_cookie c;
	struct {
		struct list_head transport_addr_list;
		__u32 rwnd;
		__u16 transport_count;
		__u16 port;
		struct sctp_transport___2 *primary_path;
		union sctp_addr primary_addr;
		struct sctp_transport___2 *active_path;
		struct sctp_transport___2 *retran_path;
		struct sctp_transport___2 *last_sent_to;
		struct sctp_transport___2 *last_data_from;
		struct sctp_tsnmap tsn_map;
		__be16 addip_disabled_mask;
		__u16 ecn_capable: 1;
		__u16 ipv4_address: 1;
		__u16 ipv6_address: 1;
		__u16 hostname_address: 1;
		__u16 asconf_capable: 1;
		__u16 prsctp_capable: 1;
		__u16 reconf_capable: 1;
		__u16 intl_capable: 1;
		__u16 auth_capable: 1;
		__u16 sack_needed: 1;
		__u16 sack_generation: 1;
		__u16 zero_window_announced: 1;
		__u32 sack_cnt;
		__u32 adaptation_ind;
		struct sctp_inithdr_host i;
		void *cookie;
		int cookie_len;
		__u32 addip_serial;
		struct sctp_random_param *peer_random;
		struct sctp_chunks_param *peer_chunks;
		struct sctp_hmac_algo_param *peer_hmacs;
	} peer;
	enum sctp_state state;
	int overall_error_count;
	ktime_t cookie_life;
	long unsigned int rto_initial;
	long unsigned int rto_max;
	long unsigned int rto_min;
	int max_burst;
	int max_retrans;
	int pf_retrans;
	__u16 max_init_attempts;
	__u16 init_retries;
	long unsigned int max_init_timeo;
	long unsigned int hbinterval;
	__u16 pathmaxrxt;
	__u32 flowlabel;
	__u8 dscp;
	__u8 pmtu_pending;
	__u32 pathmtu;
	__u32 param_flags;
	__u32 sackfreq;
	long unsigned int sackdelay;
	long unsigned int timeouts[11];
	struct timer_list timers[11];
	struct sctp_transport___2 *shutdown_last_sent_to;
	struct sctp_transport___2 *init_last_sent_to;
	int shutdown_retries;
	__u32 next_tsn;
	__u32 ctsn_ack_point;
	__u32 adv_peer_ack_point;
	__u32 highest_sacked;
	__u32 fast_recovery_exit;
	__u8 fast_recovery;
	__u16 unack_data;
	__u32 rtx_data_chunks;
	__u32 rwnd;
	__u32 a_rwnd;
	__u32 rwnd_over;
	__u32 rwnd_press;
	int sndbuf_used;
	atomic_t rmem_alloc;
	wait_queue_head_t wait;
	__u32 frag_point;
	__u32 user_frag;
	int init_err_counter;
	int init_cycle;
	__u16 default_stream;
	__u16 default_flags;
	__u32 default_ppid;
	__u32 default_context;
	__u32 default_timetolive;
	__u32 default_rcv_context;
	struct sctp_stream___2 stream;
	struct sctp_outq___2 outqueue;
	struct sctp_ulpq___2 ulpq;
	__u32 last_ecne_tsn;
	__u32 last_cwr_tsn;
	int numduptsns;
	struct sctp_chunk___2 *addip_last_asconf;
	struct list_head asconf_ack_list;
	struct list_head addip_chunk_list;
	__u32 addip_serial;
	int src_out_of_asoc_ok;
	union sctp_addr *asconf_addr_del_pending;
	struct sctp_transport___2 *new_transport;
	struct list_head endpoint_shared_keys;
	struct sctp_auth_bytes *asoc_shared_key;
	struct sctp_shared_key *shkey;
	__u16 default_hmac_id;
	__u16 active_key_id;
	__u8 need_ecne: 1;
	__u8 temp: 1;
	__u8 force_delay: 1;
	__u8 strreset_enable;
	__u8 strreset_outstanding;
	__u32 strreset_outseq;
	__u32 strreset_inseq;
	__u32 strreset_result[2];
	struct sctp_chunk___2 *strreset_chunk;
	struct sctp_priv_assoc_stats stats;
	int sent_cnt_removable;
	__u16 subscribe;
	__u64 abandoned_unsent[3];
	__u64 abandoned_sent[3];
	struct callback_head rcu;
};

struct sctp_ulpevent___2 {
	struct sctp_association___2 *asoc;
	struct sctp_chunk___2 *chunk;
	unsigned int rmem_len;
	union {
		__u32 mid;
		__u16 ssn;
	};
	union {
		__u32 ppid;
		__u32 fsn;
	};
	__u32 tsn;
	__u32 cumtsn;
	__u16 stream;
	__u16 flags;
	__u16 msg_flags;
} __attribute__((packed));

struct sctp_chunk___2 {
	struct list_head list;
	refcount_t refcnt;
	int sent_count;
	union {
		struct list_head transmitted_list;
		struct list_head stream_list;
	};
	struct list_head frag_list;
	struct sk_buff___34 *skb;
	union {
		struct sk_buff___34 *head_skb;
		struct sctp_shared_key *shkey;
	};
	union sctp_params param_hdr;
	union {
		__u8 *v;
		struct sctp_datahdr *data_hdr;
		struct sctp_inithdr *init_hdr;
		struct sctp_sackhdr *sack_hdr;
		struct sctp_heartbeathdr *hb_hdr;
		struct sctp_sender_hb_info *hbs_hdr;
		struct sctp_shutdownhdr *shutdown_hdr;
		struct sctp_signed_cookie *cookie_hdr;
		struct sctp_ecnehdr *ecne_hdr;
		struct sctp_cwrhdr *ecn_cwr_hdr;
		struct sctp_errhdr *err_hdr;
		struct sctp_addiphdr *addip_hdr;
		struct sctp_fwdtsn_hdr *fwdtsn_hdr;
		struct sctp_authhdr *auth_hdr;
		struct sctp_idatahdr *idata_hdr;
		struct sctp_ifwdtsn_hdr *ifwdtsn_hdr;
	} subh;
	__u8 *chunk_end;
	struct sctp_chunkhdr *chunk_hdr;
	struct sctphdr *sctp_hdr;
	struct sctp_sndrcvinfo sinfo;
	struct sctp_association___2 *asoc;
	struct sctp_ep_common___2 *rcvr;
	long unsigned int sent_at;
	union sctp_addr source;
	union sctp_addr dest;
	struct sctp_datamsg *msg;
	struct sctp_transport___2 *transport;
	struct sk_buff___34 *auth_chunk;
	__u16 rtt_in_progress: 1;
	__u16 has_tsn: 1;
	__u16 has_ssn: 1;
	__u16 singleton: 1;
	__u16 end_of_packet: 1;
	__u16 ecn_ce_done: 1;
	__u16 pdiscard: 1;
	__u16 tsn_gap_acked: 1;
	__u16 data_accepted: 1;
	__u16 auth: 1;
	__u16 has_asconf: 1;
	__u16 tsn_missing_report: 2;
	__u16 fast_retransmit: 2;
};

struct sctp_stream_interleave___2 {
	__u16 data_chunk_len;
	__u16 ftsn_chunk_len;
	struct sctp_chunk___2 * (*make_datafrag)(const struct sctp_association___2 *, const struct sctp_sndrcvinfo *, int, __u8, gfp_t);
	void (*assign_number)(struct sctp_chunk___2 *);
	bool (*validate_data)(struct sctp_chunk___2 *);
	int (*ulpevent_data)(struct sctp_ulpq___2 *, struct sctp_chunk___2 *, gfp_t);
	int (*enqueue_event)(struct sctp_ulpq___2 *, struct sctp_ulpevent___2 *);
	void (*renege_events)(struct sctp_ulpq___2 *, struct sctp_chunk___2 *, gfp_t);
	void (*start_pd)(struct sctp_ulpq___2 *, gfp_t);
	void (*abort_pd)(struct sctp_ulpq___2 *, gfp_t);
	void (*generate_ftsn)(struct sctp_outq___2 *, __u32);
	bool (*validate_ftsn)(struct sctp_chunk___2 *);
	void (*report_ftsn)(struct sctp_ulpq___2 *, __u32);
	void (*handle_ftsn)(struct sctp_ulpq___2 *, struct sctp_chunk___2 *);
};

struct sctp_bind_bucket___2 {
	short unsigned int port;
	signed char fastreuse;
	signed char fastreuseport;
	kuid_t fastuid;
	struct hlist_node node;
	struct hlist_head owner;
	struct net___42 *net;
};

struct sctp_pf___2;

struct sctp_sock___2 {
	struct inet_sock___2 inet;
	enum sctp_socket_type type;
	struct sctp_pf___2 *pf;
	struct crypto_shash___4 *hmac;
	char *sctp_hmac_alg;
	struct sctp_endpoint___3 *ep;
	struct sctp_bind_bucket___2 *bind_hash;
	__u16 default_stream;
	__u32 default_ppid;
	__u16 default_flags;
	__u32 default_context;
	__u32 default_timetolive;
	__u32 default_rcv_context;
	int max_burst;
	__u32 hbinterval;
	__u16 pathmaxrxt;
	__u32 flowlabel;
	__u8 dscp;
	int pf_retrans;
	__u32 pathmtu;
	__u32 sackdelay;
	__u32 sackfreq;
	__u32 param_flags;
	__u32 default_ss;
	struct sctp_rtoinfo rtoinfo;
	struct sctp_paddrparams paddrparam;
	struct sctp_assocparams assocparams;
	__u16 subscribe;
	struct sctp_initmsg initmsg;
	int user_frag;
	__u32 autoclose;
	__u32 adaptation_ind;
	__u32 pd_point;
	__u16 nodelay: 1;
	__u16 reuse: 1;
	__u16 disable_fragments: 1;
	__u16 v4mapped: 1;
	__u16 frag_interleave: 1;
	__u16 recvrcvinfo: 1;
	__u16 recvnxtinfo: 1;
	__u16 data_ready_signalled: 1;
	atomic_t pd_mode;
	struct sk_buff_head___30 pd_lobby;
	struct list_head auto_asconf_list;
	int do_auto_asconf;
};

struct sctp_af___2;

struct sctp_pf___2 {
	void (*event_msgname)(struct sctp_ulpevent___2 *, char *, int *);
	void (*skb_msgname)(struct sk_buff___34 *, char *, int *);
	int (*af_supported)(sa_family_t, struct sctp_sock___2 *);
	int (*cmp_addr)(const union sctp_addr *, const union sctp_addr *, struct sctp_sock___2 *);
	int (*bind_verify)(struct sctp_sock___2 *, union sctp_addr *);
	int (*send_verify)(struct sctp_sock___2 *, union sctp_addr *);
	int (*supported_addrs)(const struct sctp_sock___2 *, __be16 *);
	struct sock___21 * (*create_accept_sk)(struct sock___21 *, struct sctp_association___2 *, bool);
	int (*addr_to_user)(struct sctp_sock___2 *, union sctp_addr *);
	void (*to_sk_saddr)(union sctp_addr *, struct sock___21 *);
	void (*to_sk_daddr)(union sctp_addr *, struct sock___21 *);
	void (*copy_ip_options)(struct sock___21 *, struct sock___21 *);
	struct sctp_af___2 *af;
};

struct sctp_endpoint___3 {
	struct sctp_ep_common___2 base;
	struct list_head asocs;
	__u8 secret_key[32];
	__u8 *digest;
	__u32 sndbuf_policy;
	__u32 rcvbuf_policy;
	struct crypto_shash___4 **auth_hmacs;
	struct sctp_hmac_algo_param *auth_hmacs_list;
	struct sctp_chunks_param *auth_chunk_list;
	struct list_head endpoint_shared_keys;
	__u16 active_key_id;
	__u8 auth_enable: 1;
	__u8 intl_enable: 1;
	__u8 prsctp_enable: 1;
	__u8 reconf_enable: 1;
	__u8 strreset_enable;
	u32 secid;
	u32 peer_secid;
};

struct sctp_af___2 {
	int (*sctp_xmit)(struct sk_buff___34 *, struct sctp_transport___2 *);
	int (*setsockopt)(struct sock___21 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___21 *, int, int, char *, int *);
	int (*compat_setsockopt)(struct sock___21 *, int, int, char *, unsigned int);
	int (*compat_getsockopt)(struct sock___21 *, int, int, char *, int *);
	void (*get_dst)(struct sctp_transport___2 *, union sctp_addr *, struct flowi *, struct sock___21 *);
	void (*get_saddr)(struct sctp_sock___2 *, struct sctp_transport___2 *, struct flowi *);
	void (*copy_addrlist)(struct list_head *, struct net_device___34 *);
	int (*cmp_addr)(const union sctp_addr *, const union sctp_addr *);
	void (*addr_copy)(union sctp_addr *, union sctp_addr *);
	void (*from_skb)(union sctp_addr *, struct sk_buff___34 *, int);
	void (*from_sk)(union sctp_addr *, struct sock___21 *);
	void (*from_addr_param)(union sctp_addr *, union sctp_addr_param *, __be16, int);
	int (*to_addr_param)(const union sctp_addr *, union sctp_addr_param *);
	int (*addr_valid)(union sctp_addr *, struct sctp_sock___2 *, const struct sk_buff___34 *);
	enum sctp_scope (*scope)(union sctp_addr *);
	void (*inaddr_any)(union sctp_addr *, __be16);
	int (*is_any)(const union sctp_addr *);
	int (*available)(union sctp_addr *, struct sctp_sock___2 *);
	int (*skb_iif)(const struct sk_buff___34 *);
	int (*is_ce)(const struct sk_buff___34 *);
	void (*seq_dump_addr)(struct seq_file___220 *, union sctp_addr *);
	void (*ecn_capable)(struct sock___21 *);
	__u16 net_header_len;
	int sockaddr_len;
	int (*ip_options_len)(struct sock___21 *);
	sa_family_t sa_family;
	struct list_head list;
};

struct sctp_packet___2 {
	__u16 source_port;
	__u16 destination_port;
	__u32 vtag;
	struct list_head chunk_list;
	size_t overhead;
	size_t size;
	size_t max_size;
	struct sctp_transport___2 *transport;
	struct sctp_chunk___2 *auth;
	u8 has_cookie_echo: 1;
	u8 has_sack: 1;
	u8 has_auth: 1;
	u8 has_data: 1;
	u8 ipfragok: 1;
};

struct sctp_transport___2 {
	struct list_head transports;
	struct rhlist_head node;
	refcount_t refcnt;
	__u32 rto_pending: 1;
	__u32 hb_sent: 1;
	__u32 pmtu_pending: 1;
	__u32 dst_pending_confirm: 1;
	__u32 sack_generation: 1;
	u32 dst_cookie;
	struct flowi fl;
	union sctp_addr ipaddr;
	struct sctp_af___2 *af_specific;
	struct sctp_association___2 *asoc;
	long unsigned int rto;
	__u32 rtt;
	__u32 rttvar;
	__u32 srtt;
	__u32 cwnd;
	__u32 ssthresh;
	__u32 partial_bytes_acked;
	__u32 flight_size;
	__u32 burst_limited;
	struct dst_entry___20 *dst;
	union sctp_addr saddr;
	long unsigned int hbinterval;
	long unsigned int sackdelay;
	__u32 sackfreq;
	atomic_t mtu_info;
	ktime_t last_time_heard;
	long unsigned int last_time_sent;
	long unsigned int last_time_ecne_reduced;
	__u16 pathmaxrxt;
	__u32 flowlabel;
	__u8 dscp;
	int pf_retrans;
	__u32 pathmtu;
	__u32 param_flags;
	int init_sent_count;
	int state;
	short unsigned int error_count;
	struct timer_list T3_rtx_timer;
	struct timer_list hb_timer;
	struct timer_list proto_unreach_timer;
	struct timer_list reconf_timer;
	struct list_head transmitted;
	struct sctp_packet___2 packet;
	struct list_head send_ready;
	struct {
		__u32 next_tsn_at_change;
		char changeover_active;
		char cycling_changeover;
		char cacc_saw_newack;
	} cacc;
	__u64 hb_nonce;
	struct callback_head rcu;
};

struct sockaddr_un {
	__kernel_sa_family_t sun_family;
	char sun_path[108];
};

struct unix_address {
	refcount_t refcnt;
	int len;
	unsigned int hash;
	struct sockaddr_un name[0];
};

struct unix_sock {
	struct sock___21 sk;
	struct unix_address *addr;
	struct path___243 path;
	struct mutex iolock;
	struct mutex bindlock;
	struct sock___21 *peer;
	struct list_head link;
	atomic_long_t inflight;
	spinlock_t lock;
	long unsigned int gc_flags;
	struct socket_wq___20 peer_wq;
	wait_queue_entry_t peer_wake;
	long: 64;
	long: 64;
	long: 64;
};

struct kernfs_node___243;

struct sockaddr___2;

struct msghdr___26;

struct flowi___2;

struct audit_krule___2;

union bpf_attr___2;

struct bpf_map___194;

struct bpf_prog_aux___36;

union security_list_options___4 {
	int (*binder_set_context_mgr)(struct task_struct___242 *);
	int (*binder_transaction)(struct task_struct___242 *, struct task_struct___242 *);
	int (*binder_transfer_binder)(struct task_struct___242 *, struct task_struct___242 *);
	int (*binder_transfer_file)(struct task_struct___242 *, struct task_struct___242 *, struct file___241 *);
	int (*ptrace_access_check)(struct task_struct___242 *, unsigned int);
	int (*ptrace_traceme)(struct task_struct___242 *);
	int (*capget)(struct task_struct___242 *, kernel_cap_t *, kernel_cap_t *, kernel_cap_t *);
	int (*capset)(struct cred___234 *, const struct cred___234 *, const kernel_cap_t *, const kernel_cap_t *, const kernel_cap_t *);
	int (*capable)(const struct cred___234 *, struct user_namespace___3 *, int, int);
	int (*quotactl)(int, int, int, struct super_block___240 *);
	int (*quota_on)(struct dentry___241 *);
	int (*syslog)(int);
	int (*settime)(const struct timespec64 *, const struct timezone *);
	int (*vm_enough_memory)(struct mm_struct___241 *, long int);
	int (*bprm_set_creds)(struct linux_binprm___2 *);
	int (*bprm_check_security)(struct linux_binprm___2 *);
	void (*bprm_committing_creds)(struct linux_binprm___2 *);
	void (*bprm_committed_creds)(struct linux_binprm___2 *);
	int (*sb_alloc_security)(struct super_block___240 *);
	void (*sb_free_security)(struct super_block___240 *);
	int (*sb_copy_data)(char *, char *);
	int (*sb_remount)(struct super_block___240 *, void *);
	int (*sb_kern_mount)(struct super_block___240 *, int, void *);
	int (*sb_show_options)(struct seq_file___9 *, struct super_block___240 *);
	int (*sb_statfs)(struct dentry___241 *);
	int (*sb_mount)(const char *, const struct path___240 *, const char *, long unsigned int, void *);
	int (*sb_umount)(struct vfsmount *, int);
	int (*sb_pivotroot)(const struct path___240 *, const struct path___240 *);
	int (*sb_set_mnt_opts)(struct super_block___240 *, struct security_mnt_opts *, long unsigned int, long unsigned int *);
	int (*sb_clone_mnt_opts)(const struct super_block___240 *, struct super_block___240 *, long unsigned int, long unsigned int *);
	int (*sb_parse_opts_str)(char *, struct security_mnt_opts *);
	int (*dentry_init_security)(struct dentry___241 *, int, const struct qstr *, void **, u32 *);
	int (*dentry_create_files_as)(struct dentry___241 *, int, struct qstr *, const struct cred___234 *, struct cred___234 *);
	int (*inode_alloc_security)(struct inode___241 *);
	void (*inode_free_security)(struct inode___241 *);
	int (*inode_init_security)(struct inode___241 *, struct inode___241 *, const struct qstr *, const char **, void **, size_t *);
	int (*inode_create)(struct inode___241 *, struct dentry___241 *, umode_t);
	int (*inode_link)(struct dentry___241 *, struct inode___241 *, struct dentry___241 *);
	int (*inode_unlink)(struct inode___241 *, struct dentry___241 *);
	int (*inode_symlink)(struct inode___241 *, struct dentry___241 *, const char *);
	int (*inode_mkdir)(struct inode___241 *, struct dentry___241 *, umode_t);
	int (*inode_rmdir)(struct inode___241 *, struct dentry___241 *);
	int (*inode_mknod)(struct inode___241 *, struct dentry___241 *, umode_t, dev_t);
	int (*inode_rename)(struct inode___241 *, struct dentry___241 *, struct inode___241 *, struct dentry___241 *);
	int (*inode_readlink)(struct dentry___241 *);
	int (*inode_follow_link)(struct dentry___241 *, struct inode___241 *, bool);
	int (*inode_permission)(struct inode___241 *, int);
	int (*inode_setattr)(struct dentry___241 *, struct iattr___240 *);
	int (*inode_getattr)(const struct path___240 *);
	int (*inode_setxattr)(struct dentry___241 *, const char *, const void *, size_t, int);
	void (*inode_post_setxattr)(struct dentry___241 *, const char *, const void *, size_t, int);
	int (*inode_getxattr)(struct dentry___241 *, const char *);
	int (*inode_listxattr)(struct dentry___241 *);
	int (*inode_removexattr)(struct dentry___241 *, const char *);
	int (*inode_need_killpriv)(struct dentry___241 *);
	int (*inode_killpriv)(struct dentry___241 *);
	int (*inode_getsecurity)(struct inode___241 *, const char *, void **, bool);
	int (*inode_setsecurity)(struct inode___241 *, const char *, const void *, size_t, int);
	int (*inode_listsecurity)(struct inode___241 *, char *, size_t);
	void (*inode_getsecid)(struct inode___241 *, u32 *);
	int (*inode_copy_up)(struct dentry___241 *, struct cred___234 **);
	int (*inode_copy_up_xattr)(const char *);
	int (*kernfs_init_security)(struct kernfs_node___243 *, struct kernfs_node___243 *);
	int (*file_permission)(struct file___241 *, int);
	int (*file_alloc_security)(struct file___241 *);
	void (*file_free_security)(struct file___241 *);
	int (*file_ioctl)(struct file___241 *, unsigned int, long unsigned int);
	int (*mmap_addr)(long unsigned int);
	int (*mmap_file)(struct file___241 *, long unsigned int, long unsigned int, long unsigned int);
	int (*file_mprotect)(struct vm_area_struct___242 *, long unsigned int, long unsigned int);
	int (*file_lock)(struct file___241 *, unsigned int);
	int (*file_fcntl)(struct file___241 *, unsigned int, long unsigned int);
	void (*file_set_fowner)(struct file___241 *);
	int (*file_send_sigiotask)(struct task_struct___242 *, struct fown_struct___181 *, int);
	int (*file_receive)(struct file___241 *);
	int (*file_open)(struct file___241 *);
	int (*task_alloc)(struct task_struct___242 *, long unsigned int);
	void (*task_free)(struct task_struct___242 *);
	int (*cred_alloc_blank)(struct cred___234 *, gfp_t);
	void (*cred_free)(struct cred___234 *);
	int (*cred_prepare)(struct cred___234 *, const struct cred___234 *, gfp_t);
	void (*cred_transfer)(struct cred___234 *, const struct cred___234 *);
	void (*cred_getsecid)(const struct cred___234 *, u32 *);
	int (*kernel_act_as)(struct cred___234 *, u32);
	int (*kernel_create_files_as)(struct cred___234 *, struct inode___241 *);
	int (*kernel_module_request)(char *);
	int (*kernel_read_file)(struct file___241 *, enum kernel_read_file_id);
	int (*kernel_post_read_file)(struct file___241 *, char *, loff_t, enum kernel_read_file_id);
	int (*task_fix_setuid)(struct cred___234 *, const struct cred___234 *, int);
	int (*task_setpgid)(struct task_struct___242 *, pid_t);
	int (*task_getpgid)(struct task_struct___242 *);
	int (*task_getsid)(struct task_struct___242 *);
	void (*task_getsecid)(struct task_struct___242 *, u32 *);
	int (*task_setnice)(struct task_struct___242 *, int);
	int (*task_setioprio)(struct task_struct___242 *, int);
	int (*task_getioprio)(struct task_struct___242 *);
	int (*task_prlimit)(const struct cred___234 *, const struct cred___234 *, unsigned int);
	int (*task_setrlimit)(struct task_struct___242 *, unsigned int, struct rlimit *);
	int (*task_setscheduler)(struct task_struct___242 *);
	int (*task_getscheduler)(struct task_struct___242 *);
	int (*task_movememory)(struct task_struct___242 *);
	int (*task_kill)(struct task_struct___242 *, struct kernel_siginfo *, int, const struct cred___234 *);
	int (*task_prctl)(int, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*task_to_inode)(struct task_struct___242 *, struct inode___241 *);
	int (*ipc_permission)(struct kern_ipc_perm *, short int);
	void (*ipc_getsecid)(struct kern_ipc_perm *, u32 *);
	int (*msg_msg_alloc_security)(struct msg_msg___2 *);
	void (*msg_msg_free_security)(struct msg_msg___2 *);
	int (*msg_queue_alloc_security)(struct kern_ipc_perm *);
	void (*msg_queue_free_security)(struct kern_ipc_perm *);
	int (*msg_queue_associate)(struct kern_ipc_perm *, int);
	int (*msg_queue_msgctl)(struct kern_ipc_perm *, int);
	int (*msg_queue_msgsnd)(struct kern_ipc_perm *, struct msg_msg___2 *, int);
	int (*msg_queue_msgrcv)(struct kern_ipc_perm *, struct msg_msg___2 *, struct task_struct___242 *, long int, int);
	int (*shm_alloc_security)(struct kern_ipc_perm *);
	void (*shm_free_security)(struct kern_ipc_perm *);
	int (*shm_associate)(struct kern_ipc_perm *, int);
	int (*shm_shmctl)(struct kern_ipc_perm *, int);
	int (*shm_shmat)(struct kern_ipc_perm *, char *, int);
	int (*sem_alloc_security)(struct kern_ipc_perm *);
	void (*sem_free_security)(struct kern_ipc_perm *);
	int (*sem_associate)(struct kern_ipc_perm *, int);
	int (*sem_semctl)(struct kern_ipc_perm *, int);
	int (*sem_semop)(struct kern_ipc_perm *, struct sembuf *, unsigned int, int);
	int (*netlink_send)(struct sock *, struct sk_buff___28 *);
	void (*d_instantiate)(struct dentry___241 *, struct inode___241 *);
	int (*getprocattr)(struct task_struct___242 *, char *, char **);
	int (*setprocattr)(const char *, void *, size_t);
	int (*ismaclabel)(const char *);
	int (*secid_to_secctx)(u32, char **, u32 *);
	int (*secctx_to_secid)(const char *, u32, u32 *);
	void (*release_secctx)(char *, u32);
	void (*inode_invalidate_secctx)(struct inode___241 *);
	int (*inode_notifysecctx)(struct inode___241 *, void *, u32);
	int (*inode_setsecctx)(struct dentry___241 *, void *, u32);
	int (*inode_getsecctx)(struct inode___241 *, void **, u32 *);
	int (*unix_stream_connect)(struct sock *, struct sock *, struct sock *);
	int (*unix_may_send)(struct socket___15 *, struct socket___15 *);
	int (*socket_create)(int, int, int, int);
	int (*socket_post_create)(struct socket___15 *, int, int, int, int);
	int (*socket_socketpair)(struct socket___15 *, struct socket___15 *);
	int (*socket_bind)(struct socket___15 *, struct sockaddr___2 *, int);
	int (*socket_connect)(struct socket___15 *, struct sockaddr___2 *, int);
	int (*socket_listen)(struct socket___15 *, int);
	int (*socket_accept)(struct socket___15 *, struct socket___15 *);
	int (*socket_sendmsg)(struct socket___15 *, struct msghdr___26 *, int);
	int (*socket_recvmsg)(struct socket___15 *, struct msghdr___26 *, int, int);
	int (*socket_getsockname)(struct socket___15 *);
	int (*socket_getpeername)(struct socket___15 *);
	int (*socket_getsockopt)(struct socket___15 *, int, int);
	int (*socket_setsockopt)(struct socket___15 *, int, int);
	int (*socket_shutdown)(struct socket___15 *, int);
	int (*socket_sock_rcv_skb)(struct sock *, struct sk_buff___28 *);
	int (*socket_getpeersec_stream)(struct socket___15 *, char *, int *, unsigned int);
	int (*socket_getpeersec_dgram)(struct socket___15 *, struct sk_buff___28 *, u32 *);
	int (*sk_alloc_security)(struct sock *, int, gfp_t);
	void (*sk_free_security)(struct sock *);
	void (*sk_clone_security)(const struct sock *, struct sock *);
	void (*sk_getsecid)(struct sock *, u32 *);
	void (*sock_graft)(struct sock *, struct socket___15 *);
	int (*inet_conn_request)(struct sock *, struct sk_buff___28 *, struct request_sock___7 *);
	void (*inet_csk_clone)(struct sock *, const struct request_sock___7 *);
	void (*inet_conn_established)(struct sock *, struct sk_buff___28 *);
	int (*secmark_relabel_packet)(u32);
	void (*secmark_refcount_inc)();
	void (*secmark_refcount_dec)();
	void (*req_classify_flow)(const struct request_sock___7 *, struct flowi___2 *);
	int (*tun_dev_alloc_security)(void **);
	void (*tun_dev_free_security)(void *);
	int (*tun_dev_create)();
	int (*tun_dev_attach_queue)(void *);
	int (*tun_dev_attach)(struct sock *, void *);
	int (*tun_dev_open)(void *);
	int (*sctp_assoc_request)(struct sctp_endpoint *, struct sk_buff___28 *);
	int (*sctp_bind_connect)(struct sock *, int, struct sockaddr___2 *, int);
	void (*sctp_sk_clone)(struct sctp_endpoint *, struct sock *, struct sock *);
	int (*ib_pkey_access)(void *, u64, u16);
	int (*ib_endport_manage_subnet)(void *, const char *, u8);
	int (*ib_alloc_security)(void **);
	void (*ib_free_security)(void *);
	int (*xfrm_policy_alloc_security)(struct xfrm_sec_ctx **, struct xfrm_user_sec_ctx *, gfp_t);
	int (*xfrm_policy_clone_security)(struct xfrm_sec_ctx *, struct xfrm_sec_ctx **);
	void (*xfrm_policy_free_security)(struct xfrm_sec_ctx *);
	int (*xfrm_policy_delete_security)(struct xfrm_sec_ctx *);
	int (*xfrm_state_alloc)(struct xfrm_state *, struct xfrm_user_sec_ctx *);
	int (*xfrm_state_alloc_acquire)(struct xfrm_state *, struct xfrm_sec_ctx *, u32);
	void (*xfrm_state_free_security)(struct xfrm_state *);
	int (*xfrm_state_delete_security)(struct xfrm_state *);
	int (*xfrm_policy_lookup)(struct xfrm_sec_ctx *, u32, u8);
	int (*xfrm_state_pol_flow_match)(struct xfrm_state *, struct xfrm_policy *, const struct flowi___2 *);
	int (*xfrm_decode_session)(struct sk_buff___28 *, u32 *, int);
	int (*key_alloc)(struct key___234 *, const struct cred___234 *, long unsigned int);
	void (*key_free)(struct key___234 *);
	int (*key_permission)(key_ref_t, const struct cred___234 *, unsigned int);
	int (*key_getsecurity)(struct key___234 *, char **);
	int (*audit_rule_init)(u32, u32, char *, void **);
	int (*audit_rule_known)(struct audit_krule___2 *);
	int (*audit_rule_match)(u32, u32, u32, void *, struct audit_context *);
	void (*audit_rule_free)(void *);
	int (*bpf)(int, union bpf_attr___2 *, unsigned int);
	int (*bpf_map)(struct bpf_map___194 *, fmode_t);
	int (*bpf_prog)(struct bpf_prog *);
	int (*bpf_map_alloc_security)(struct bpf_map___194 *);
	void (*bpf_map_free_security)(struct bpf_map___194 *);
	int (*bpf_prog_alloc_security)(struct bpf_prog_aux___36 *);
	void (*bpf_prog_free_security)(struct bpf_prog_aux___36 *);
};

struct security_hook_list___4 {
	struct hlist_node list;
	struct hlist_head *head;
	union security_list_options___4 hook;
	char *lsm;
};

struct ptrace_relation {
	struct task_struct___242 *tracer;
	struct task_struct___242 *tracee;
	bool invalid;
	struct list_head node;
	struct callback_head rcu;
};

struct access_report_info {
	struct callback_head work;
	const char *access;
	struct task_struct___242 *target;
	struct task_struct___242 *agent;
};

typedef int (*key_restrict_link_func_t___242)(struct key___229 *, const struct key_type *, const union key_payload *, struct key___229 *);

enum devcg_behavior {
	DEVCG_DEFAULT_NONE = 0,
	DEVCG_DEFAULT_ALLOW = 1,
	DEVCG_DEFAULT_DENY = 2,
};

struct dev_exception_item {
	u32 major;
	u32 minor;
	short int type;
	short int access;
	struct list_head list;
	struct callback_head rcu;
};

struct dev_cgroup {
	struct cgroup_subsys_state___182 css;
	struct list_head exceptions;
	enum devcg_behavior behavior;
};

struct module___203;

struct file___249;

struct kiocb___249;

struct iov_iter___116;

struct vm_area_struct___250;

struct inode___249;

struct file_lock___249;

struct page___250;

struct pipe_inode_info___59;

struct file_operations___249 {
	struct module___203 *owner;
	loff_t (*llseek)(struct file___249 *, loff_t, int);
	ssize_t (*read)(struct file___249 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___249 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___249 *, struct iov_iter___116 *);
	ssize_t (*write_iter)(struct kiocb___249 *, struct iov_iter___116 *);
	int (*iopoll)(struct kiocb___249 *, bool);
	int (*iterate)(struct file___249 *, struct dir_context *);
	int (*iterate_shared)(struct file___249 *, struct dir_context *);
	__poll_t (*poll)(struct file___249 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___249 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___249 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___249 *, struct vm_area_struct___250 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___249 *, struct file___249 *);
	int (*flush)(struct file___249 *, fl_owner_t);
	int (*release)(struct inode___249 *, struct file___249 *);
	int (*fsync)(struct file___249 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___249 *, int);
	int (*lock)(struct file___249 *, int, struct file_lock___249 *);
	ssize_t (*sendpage)(struct file___249 *, struct page___250 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___249 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___249 *, int, struct file_lock___249 *);
	ssize_t (*splice_write)(struct pipe_inode_info___59 *, struct file___249 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___249 *, loff_t *, struct pipe_inode_info___59 *, size_t, unsigned int);
	int (*setlease)(struct file___249 *, long int, struct file_lock___249 **, void **);
	long int (*fallocate)(struct file___249 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___249 *);
	ssize_t (*copy_file_range)(struct file___249 *, loff_t, struct file___249 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___249 *, loff_t, struct file___249 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___249 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___249 {
	u64 seqnum;
	struct vm_area_struct___250 *vmas[4];
};

struct page_frag___249 {
	struct page___250 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___249;

struct cred___242;

struct signal_struct___207;

struct vm_struct___166;

struct task_struct___250 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___250 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___249 *mm;
	struct mm_struct___249 *active_mm;
	struct vmacache___249 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___250 *real_parent;
	struct task_struct___250 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___250 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___188 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___188 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___188 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___242 *ptracer_cred;
	const struct cred___242 *real_cred;
	const struct cred___242 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___207 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___250 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___60 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___59 *splice_pipe;
	struct page_frag___249 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___250 *oom_reaper_list;
	struct vm_struct___166 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___127 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___250 *pgtable_t___249;

struct address_space___248;

struct dev_pagemap___239;

struct page___250 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___248 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___250 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___249 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___249 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___239 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___249;

struct lruvec___249 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___249 *pgdat;
};

struct zone___249 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___249 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___249 {
	struct zone___249 *zone;
	int zone_idx;
};

struct zonelist___249 {
	struct zoneref___249 _zonerefs[25];
};

struct pglist_data___249 {
	struct zone___249 node_zones[3];
	struct zonelist___249 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___250 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___250 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___249 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___250 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___250 *owner;
};

struct secondary_data___250 {
	void *stack;
	struct task_struct___250 *task;
	long int status;
};

struct blocking_notifier_head___249 {
	struct rw_semaphore___250 rwsem;
	struct notifier_block *head;
};

struct dentry___249;

struct path___249 {
	struct vfsmount *mnt;
	struct dentry___249 *dentry;
};

struct file___249 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___249 f_path;
	struct inode___249 *f_inode;
	const struct file_operations___249 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___188 f_owner;
	const struct cred___242 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___248 *f_mapping;
	errseq_t f_wb_err;
};

struct key___242;

struct user_struct___242;

struct cred___242 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___242 *session_keyring;
	struct key___242 *process_keyring;
	struct key___242 *thread_keyring;
	struct key___242 *request_key_auth;
	void *security;
	struct user_struct___242 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___243;

struct kernfs_elem_dir___243 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___243 *root;
};

struct kernfs_node___244;

struct kernfs_syscall_ops___243;

struct kernfs_root___243 {
	struct kernfs_node___244 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___243 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___243 {
	struct kernfs_node___244 *target_kn;
};

struct kernfs_ops___243;

struct kernfs_elem_attr___243 {
	const struct kernfs_ops___243 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___244 *notify_next;
};

struct kernfs_node___244 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___244 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___243 dir;
		struct kernfs_elem_symlink___243 symlink;
		struct kernfs_elem_attr___243 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___243;

struct kernfs_ops___243 {
	int (*open)(struct kernfs_open_file___243 *);
	void (*release)(struct kernfs_open_file___243 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___243 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___243 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___243 *, struct vm_area_struct___250 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___243 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___243 {
	int (*remount_fs)(struct kernfs_root___243 *, int *, char *);
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___243 *);
	int (*mkdir)(struct kernfs_node___244 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___244 *);
	int (*rename)(struct kernfs_node___244 *, struct kernfs_node___244 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___244 *, struct kernfs_root___243 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_operations_struct___239;

struct kernfs_open_file___243 {
	struct kernfs_node___244 *kn;
	struct file___249 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___239 *vm_ops;
};

struct vm_fault___239;

struct vm_operations_struct___239 {
	void (*open)(struct vm_area_struct___250 *);
	void (*close)(struct vm_area_struct___250 *);
	int (*split)(struct vm_area_struct___250 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___250 *);
	vm_fault_t (*fault)(struct vm_fault___239 *);
	vm_fault_t (*huge_fault)(struct vm_fault___239 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___239 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___250 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___239 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___239 *);
	int (*access)(struct vm_area_struct___250 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___250 *);
	int (*set_policy)(struct vm_area_struct___250 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___250 *, long unsigned int);
	struct page___250 * (*find_special_page)(struct vm_area_struct___250 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_area_struct___250 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___250 *vm_next;
	struct vm_area_struct___250 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___249 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___239 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___249 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___237;

struct bin_attribute___214;

struct attribute_group___215 {
	const char *name;
	umode_t (*is_visible)(struct kobject___237 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___237 *, struct bin_attribute___214 *, int);
	struct attribute **attrs;
	struct bin_attribute___214 **bin_attrs;
};

struct kset___236;

struct kobj_type___236;

struct kobject___237 {
	const char *name;
	struct list_head entry;
	struct kobject___237 *parent;
	struct kset___236 *kset;
	struct kobj_type___236 *ktype;
	struct kernfs_node___244 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___214 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___249 *, struct kobject___237 *, struct bin_attribute___214 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___249 *, struct kobject___237 *, struct bin_attribute___214 *, char *, loff_t, size_t);
	int (*mmap)(struct file___249 *, struct kobject___237 *, struct bin_attribute___214 *, struct vm_area_struct___250 *);
};

struct sysfs_ops___236 {
	ssize_t (*show)(struct kobject___237 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___237 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___236;

struct kset___236 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___237 kobj;
	const struct kset_uevent_ops___236 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___236 {
	void (*release)(struct kobject___237 *);
	const struct sysfs_ops___236 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___23 * (*child_ns_type)(struct kobject___237 *);
	const void * (*namespace)(struct kobject___237 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___236 {
	int (* const filter)(struct kset___236 *, struct kobject___237 *);
	const char * (* const name)(struct kset___236 *, struct kobject___237 *);
	int (* const uevent)(struct kset___236 *, struct kobject___237 *, struct kobj_uevent_env *);
};

struct kobj_attribute___230 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___237 *, struct kobj_attribute___230 *, char *);
	ssize_t (*store)(struct kobject___237 *, struct kobj_attribute___230 *, const char *, size_t);
};

struct kernel_param___200;

struct kernel_param_ops___200 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___200 *);
	int (*get)(char *, const struct kernel_param___200 *);
	void (*free)(void *);
};

struct kparam_array___200;

struct kernel_param___200 {
	const char *name;
	struct module___203 *mod;
	const struct kernel_param_ops___200 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___200 *arr;
	};
};

struct kparam_array___200 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___200 *ops;
	void *elem;
};

struct module_kobject___200 {
	struct kobject___237 kobj;
	struct module___203 *mod;
	struct kobject___237 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___200 {
	struct module___203 *mod;
	struct latch_tree_node node;
};

struct module_layout___200 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___200 mtn;
};

struct module_attribute___200;

struct module___203 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___200 mkobj;
	struct module_attribute___200 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___237 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___200 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___200 core_layout;
	struct module_layout___200 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___200 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___200 *, struct module_kobject___200 *, char *);
	ssize_t (*store)(struct module_attribute___200 *, struct module_kobject___200 *, const char *, size_t);
	void (*setup)(struct module___203 *, const char *);
	int (*test)(struct module___203 *);
	void (*free)(struct module___203 *);
};

struct user_struct___242 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___242 *uid_keyring;
	struct key___242 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___249;

struct mm_struct___249 {
	struct {
		struct vm_area_struct___250 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___249 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___250 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___249 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___250 *owner;
		struct user_namespace___3 *user_ns;
		struct file___249 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___249 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct signal_struct___207 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___250 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___250 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___188 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___188 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___249 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___188 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct fasync_struct___248;

struct pipe_buffer___59;

struct pipe_inode_info___59 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___250 *tmp_page;
	struct fasync_struct___248 *fasync_readers;
	struct fasync_struct___248 *fasync_writers;
	struct pipe_buffer___59 *bufs;
	struct user_struct___242 *user;
};

struct vm_struct___166 {
	struct vm_struct___166 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___250 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___219 {
	struct task_struct___250 task;
	long unsigned int stack[8192];
};

typedef int (*key_restrict_link_func_t___243)(struct key___242 *, const struct key_type *, const union key_payload *, struct key___242 *);

struct key_restriction___242;

struct key___242 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___250 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key___5 index_key;
		struct {
			struct key_type___5 *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___242 *restrict_link;
};

struct key_restriction___242 {
	key_restrict_link_func_t___243 check;
	struct key___242 *key;
	struct key_type *keytype;
};

struct address_space_operations___248;

struct address_space___248 {
	struct inode___249 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___250 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___248 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___239)(struct vm_area_struct___250 *, long unsigned int, const struct page___250 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___239)(struct page___250 *, void *);

struct device___213;

struct dev_pagemap___239 {
	dev_page_fault_t___239 page_fault;
	dev_page_free_t___239 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___213 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___249 {
	struct task_struct___250 *task;
	struct core_thread___249 *next;
};

struct core_state___249 {
	atomic_t nr_threads;
	struct core_thread___249 dumper;
	struct completion startup;
};

struct vm_fault___239 {
	struct vm_area_struct___250 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___250 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___250 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___249 prealloc_pte;
};

struct crypto_async_request___7;

typedef void (*crypto_completion_t___7)(struct crypto_async_request___7 *, int);

struct crypto_tfm___7;

struct crypto_async_request___7 {
	struct list_head list;
	crypto_completion_t___7 complete;
	void *data;
	struct crypto_tfm___7 *tfm;
	u32 flags;
};

struct crypto_ablkcipher___7;

struct ablkcipher_request___7;

struct ablkcipher_tfm___7 {
	int (*setkey)(struct crypto_ablkcipher___7 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___7 *);
	int (*decrypt)(struct ablkcipher_request___7 *);
	struct crypto_ablkcipher___7 *base;
	unsigned int ivsize;
	unsigned int reqsize;
};

struct blkcipher_desc___7;

struct blkcipher_tfm___7 {
	void *iv;
	int (*setkey)(struct crypto_tfm___7 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___7 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___7 *, struct scatterlist *, struct scatterlist *, unsigned int);
};

struct cipher_tfm___7 {
	int (*cit_setkey)(struct crypto_tfm___7 *, const u8 *, unsigned int);
	void (*cit_encrypt_one)(struct crypto_tfm___7 *, u8 *, const u8 *);
	void (*cit_decrypt_one)(struct crypto_tfm___7 *, u8 *, const u8 *);
};

struct compress_tfm___7 {
	int (*cot_compress)(struct crypto_tfm___7 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*cot_decompress)(struct crypto_tfm___7 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___7;

struct crypto_tfm___7 {
	u32 crt_flags;
	union {
		struct ablkcipher_tfm___7 ablkcipher;
		struct blkcipher_tfm___7 blkcipher;
		struct cipher_tfm___7 cipher;
		struct compress_tfm___7 compress;
	} crt_u;
	void (*exit)(struct crypto_tfm___7 *);
	struct crypto_alg___7 *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct ablkcipher_request___7 {
	struct crypto_async_request___7 base;
	unsigned int nbytes;
	void *info;
	struct scatterlist *src;
	struct scatterlist *dst;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_blkcipher___7;

struct blkcipher_desc___7 {
	struct crypto_blkcipher___7 *tfm;
	void *info;
	u32 flags;
};

struct crypto_blkcipher___7 {
	struct crypto_tfm___7 base;
};

struct ablkcipher_alg___7 {
	int (*setkey)(struct crypto_ablkcipher___7 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___7 *);
	int (*decrypt)(struct ablkcipher_request___7 *);
	int (*givencrypt)(struct skcipher_givcrypt_request *);
	int (*givdecrypt)(struct skcipher_givcrypt_request *);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct crypto_ablkcipher___7 {
	struct crypto_tfm___7 base;
};

struct blkcipher_alg___7 {
	int (*setkey)(struct crypto_tfm___7 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___7 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___7 *, struct scatterlist *, struct scatterlist *, unsigned int);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct cipher_alg___7 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___7 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___7 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___7 *, u8 *, const u8 *);
};

struct compress_alg___7 {
	int (*coa_compress)(struct crypto_tfm___7 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___7 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_type___2;

struct crypto_alg___7 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type___2 *cra_type;
	union {
		struct ablkcipher_alg___7 ablkcipher;
		struct blkcipher_alg___7 blkcipher;
		struct cipher_alg___7 cipher;
		struct compress_alg___7 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___7 *);
	void (*cra_exit)(struct crypto_tfm___7 *);
	void (*cra_destroy)(struct crypto_alg___7 *);
	struct module___203 *cra_module;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct crypto_instance___2;

struct crypto_type___2 {
	unsigned int (*ctxsize)(struct crypto_alg___7 *, u32, u32);
	unsigned int (*extsize)(struct crypto_alg___7 *);
	int (*init)(struct crypto_tfm___7 *, u32, u32);
	int (*init_tfm)(struct crypto_tfm___7 *);
	void (*show)(struct seq_file___9 *, struct crypto_alg___7 *);
	int (*report)(struct sk_buff___6 *, struct crypto_alg___7 *);
	void (*free)(struct crypto_instance___2 *);
	unsigned int type;
	unsigned int maskclear;
	unsigned int maskset;
	unsigned int tfmsize;
};

struct crypto_wait {
	struct completion completion;
	int err;
};

struct iov_iter___116 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___3 *bvec;
		struct pipe_inode_info___59 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct kiocb___249 {
	struct file___249 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___249 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dentry_operations___248;

struct super_block___248;

struct dentry___249 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___249 *d_parent;
	struct qstr d_name;
	struct inode___249 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___248 *d_op;
	struct super_block___248 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___248;

struct block_device___249;

struct inode___249 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___248 *i_op;
	struct super_block___248 *i_sb;
	struct address_space___248 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___250 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___249 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___248 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___59 *i_pipe;
		struct block_device___249 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___248 {
	int (*d_revalidate)(struct dentry___249 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___249 *, unsigned int);
	int (*d_hash)(const struct dentry___249 *, struct qstr *);
	int (*d_compare)(const struct dentry___249 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___249 *);
	int (*d_init)(struct dentry___249 *);
	void (*d_release)(struct dentry___249 *);
	void (*d_prune)(struct dentry___249 *);
	void (*d_iput)(struct dentry___249 *, struct inode___249 *);
	char * (*d_dname)(struct dentry___249 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___249 *);
	int (*d_manage)(const struct path___249 *, bool);
	struct dentry___249 * (*d_real)(struct dentry___249 *, const struct inode___249 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___248;

struct mem_dqinfo___248 {
	struct quota_format_type___248 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___248;

struct quota_info___248 {
	unsigned int flags;
	struct rw_semaphore___250 dqio_sem;
	struct inode___249 *files[3];
	struct mem_dqinfo___248 info[3];
	const struct quota_format_ops___248 *ops[3];
};

struct rcuwait___248 {
	struct task_struct___250 *task;
};

struct percpu_rw_semaphore___248 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___250 rw_sem;
	struct rcuwait___248 writer;
	int readers_block;
};

struct sb_writers___248 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___248 rw_sem[3];
};

struct file_system_type___248;

struct super_operations___248;

struct dquot_operations___248;

struct quotactl_ops___248;

struct super_block___248 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___248 *s_type;
	const struct super_operations___248 *s_op;
	const struct dquot_operations___248 *dq_op;
	const struct quotactl_ops___248 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___249 *s_root;
	struct rw_semaphore___250 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___249 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___248 s_dquot;
	struct sb_writers___248 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___248 *s_d_op;
	int cleancache_poolid;
	struct shrinker___109 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct iattr___248 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___249 *ia_file;
};

struct dquot___248 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___248 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___248 {
	int qf_fmt_id;
	const struct quota_format_ops___248 *qf_ops;
	struct module___203 *qf_owner;
	struct quota_format_type___248 *qf_next;
};

struct quota_format_ops___248 {
	int (*check_quota_file)(struct super_block___248 *, int);
	int (*read_file_info)(struct super_block___248 *, int);
	int (*write_file_info)(struct super_block___248 *, int);
	int (*free_file_info)(struct super_block___248 *, int);
	int (*read_dqblk)(struct dquot___248 *);
	int (*commit_dqblk)(struct dquot___248 *);
	int (*release_dqblk)(struct dquot___248 *);
	int (*get_next_id)(struct super_block___248 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___248 {
	int (*write_dquot)(struct dquot___248 *);
	struct dquot___248 * (*alloc_dquot)(struct super_block___248 *, int);
	void (*destroy_dquot)(struct dquot___248 *);
	int (*acquire_dquot)(struct dquot___248 *);
	int (*release_dquot)(struct dquot___248 *);
	int (*mark_dirty)(struct dquot___248 *);
	int (*write_info)(struct super_block___248 *, int);
	qsize_t * (*get_reserved_space)(struct inode___249 *);
	int (*get_projid)(struct inode___249 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___249 *, qsize_t *);
	int (*get_next_id)(struct super_block___248 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___248 {
	int (*quota_on)(struct super_block___248 *, int, int, const struct path___249 *);
	int (*quota_off)(struct super_block___248 *, int);
	int (*quota_enable)(struct super_block___248 *, unsigned int);
	int (*quota_disable)(struct super_block___248 *, unsigned int);
	int (*quota_sync)(struct super_block___248 *, int);
	int (*set_info)(struct super_block___248 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___248 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___248 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___248 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___248 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___248 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___248 {
	int (*writepage)(struct page___250 *, struct writeback_control___3 *);
	int (*readpage)(struct file___249 *, struct page___250 *);
	int (*writepages)(struct address_space___248 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___250 *);
	int (*readpages)(struct file___249 *, struct address_space___248 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___249 *, struct address_space___248 *, loff_t, unsigned int, unsigned int, struct page___250 **, void **);
	int (*write_end)(struct file___249 *, struct address_space___248 *, loff_t, unsigned int, unsigned int, struct page___250 *, void *);
	sector_t (*bmap)(struct address_space___248 *, sector_t);
	void (*invalidatepage)(struct page___250 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___250 *, gfp_t);
	void (*freepage)(struct page___250 *);
	ssize_t (*direct_IO)(struct kiocb___249 *, struct iov_iter___116 *);
	int (*migratepage)(struct address_space___248 *, struct page___250 *, struct page___250 *, enum migrate_mode);
	bool (*isolate_page)(struct page___250 *, isolate_mode_t);
	void (*putback_page)(struct page___250 *);
	int (*launder_page)(struct page___250 *);
	int (*is_partially_uptodate)(struct page___250 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___250 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___248 *, struct page___250 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___249 *, sector_t *);
	void (*swap_deactivate)(struct file___249 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___249 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___249 *bd_inode;
	struct super_block___248 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___249 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___248 {
	struct dentry___249 * (*lookup)(struct inode___249 *, struct dentry___249 *, unsigned int);
	const char * (*get_link)(struct dentry___249 *, struct inode___249 *, struct delayed_call *);
	int (*permission)(struct inode___249 *, int);
	struct posix_acl * (*get_acl)(struct inode___249 *, int);
	int (*readlink)(struct dentry___249 *, char *, int);
	int (*create)(struct inode___249 *, struct dentry___249 *, umode_t, bool);
	int (*link)(struct dentry___249 *, struct inode___249 *, struct dentry___249 *);
	int (*unlink)(struct inode___249 *, struct dentry___249 *);
	int (*symlink)(struct inode___249 *, struct dentry___249 *, const char *);
	int (*mkdir)(struct inode___249 *, struct dentry___249 *, umode_t);
	int (*rmdir)(struct inode___249 *, struct dentry___249 *);
	int (*mknod)(struct inode___249 *, struct dentry___249 *, umode_t, dev_t);
	int (*rename)(struct inode___249 *, struct dentry___249 *, struct inode___249 *, struct dentry___249 *, unsigned int);
	int (*setattr)(struct dentry___249 *, struct iattr___248 *);
	int (*getattr)(const struct path___249 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___249 *, char *, size_t);
	int (*fiemap)(struct inode___249 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___249 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___249 *, struct dentry___249 *, struct file___249 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___249 *, struct dentry___249 *, umode_t);
	int (*set_acl)(struct inode___249 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___248 {
	void (*fl_copy_lock)(struct file_lock___249 *, struct file_lock___249 *);
	void (*fl_release_private)(struct file_lock___249 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___248;

struct file_lock___249 {
	struct file_lock___249 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___249 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___248 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___248 *fl_ops;
	const struct lock_manager_operations___248 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___248 {
	int (*lm_compare_owner)(struct file_lock___249 *, struct file_lock___249 *);
	long unsigned int (*lm_owner_key)(struct file_lock___249 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___249 *);
	int (*lm_grant)(struct file_lock___249 *, int);
	bool (*lm_break)(struct file_lock___249 *);
	int (*lm_change)(struct file_lock___249 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___249 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___248 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___248 *fa_next;
	struct file___249 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___248 {
	const char *name;
	int fs_flags;
	struct dentry___249 * (*mount)(struct file_system_type___248 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___248 *);
	struct module___203 *owner;
	struct file_system_type___248 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___248 {
	struct inode___249 * (*alloc_inode)(struct super_block___248 *);
	void (*destroy_inode)(struct inode___249 *);
	void (*dirty_inode)(struct inode___249 *, int);
	int (*write_inode)(struct inode___249 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___249 *);
	void (*evict_inode)(struct inode___249 *);
	void (*put_super)(struct super_block___248 *);
	int (*sync_fs)(struct super_block___248 *, int);
	int (*freeze_super)(struct super_block___248 *);
	int (*freeze_fs)(struct super_block___248 *);
	int (*thaw_super)(struct super_block___248 *);
	int (*unfreeze_fs)(struct super_block___248 *);
	int (*statfs)(struct dentry___249 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___248 *, int *, char *);
	void (*umount_begin)(struct super_block___248 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___249 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___249 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___249 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___249 *);
	ssize_t (*quota_read)(struct super_block___248 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___248 *, int, const char *, size_t, loff_t);
	struct dquot___248 ** (*get_dquots)(struct inode___249 *);
	int (*bdev_try_to_free_page)(struct super_block___248 *, struct page___250 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___248 *, struct shrink_control___109 *);
	long int (*free_cached_objects)(struct super_block___248 *, struct shrink_control___109 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_ops___213 {
	int (*prepare)(struct device___213 *);
	void (*complete)(struct device___213 *);
	int (*suspend)(struct device___213 *);
	int (*resume)(struct device___213 *);
	int (*freeze)(struct device___213 *);
	int (*thaw)(struct device___213 *);
	int (*poweroff)(struct device___213 *);
	int (*restore)(struct device___213 *);
	int (*suspend_late)(struct device___213 *);
	int (*resume_early)(struct device___213 *);
	int (*freeze_late)(struct device___213 *);
	int (*thaw_early)(struct device___213 *);
	int (*poweroff_late)(struct device___213 *);
	int (*restore_early)(struct device___213 *);
	int (*suspend_noirq)(struct device___213 *);
	int (*resume_noirq)(struct device___213 *);
	int (*freeze_noirq)(struct device___213 *);
	int (*thaw_noirq)(struct device___213 *);
	int (*poweroff_noirq)(struct device___213 *);
	int (*restore_noirq)(struct device___213 *);
	int (*runtime_suspend)(struct device___213 *);
	int (*runtime_resume)(struct device___213 *);
	int (*runtime_idle)(struct device___213 *);
};

struct dev_pm_info___213 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___213 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___213;

struct bus_type___213;

struct device_driver___213;

struct dev_pm_domain___213;

struct dma_map_ops___56;

struct fwnode_handle___148;

struct class___213;

struct device___213 {
	struct device___213 *parent;
	struct device_private *p;
	struct kobject___237 kobj;
	const char *init_name;
	const struct device_type___213 *type;
	struct mutex mutex;
	struct bus_type___213 *bus;
	struct device_driver___213 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___213 power;
	struct dev_pm_domain___213 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___56 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___148 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___213 *class;
	const struct attribute_group___215 **groups;
	void (*release)(struct device___213 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___213 {
	struct dev_pm_ops___213 ops;
	void (*detach)(struct device___213 *, bool);
	int (*activate)(struct device___213 *);
	void (*sync)(struct device___213 *);
	void (*dismiss)(struct device___213 *);
};

struct bus_type___213 {
	const char *name;
	const char *dev_name;
	struct device___213 *dev_root;
	const struct attribute_group___215 **bus_groups;
	const struct attribute_group___215 **dev_groups;
	const struct attribute_group___215 **drv_groups;
	int (*match)(struct device___213 *, struct device_driver___213 *);
	int (*uevent)(struct device___213 *, struct kobj_uevent_env *);
	int (*probe)(struct device___213 *);
	int (*remove)(struct device___213 *);
	void (*shutdown)(struct device___213 *);
	int (*online)(struct device___213 *);
	int (*offline)(struct device___213 *);
	int (*suspend)(struct device___213 *, pm_message_t);
	int (*resume)(struct device___213 *);
	int (*num_vf)(struct device___213 *);
	int (*dma_configure)(struct device___213 *);
	const struct dev_pm_ops___213 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___213 {
	const char *name;
	struct bus_type___213 *bus;
	struct module___203 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___213 *);
	int (*remove)(struct device___213 *);
	void (*shutdown)(struct device___213 *);
	int (*suspend)(struct device___213 *, pm_message_t);
	int (*resume)(struct device___213 *);
	const struct attribute_group___215 **groups;
	const struct dev_pm_ops___213 *pm;
	void (*coredump)(struct device___213 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___213 {
	const char *name;
	const struct attribute_group___215 **groups;
	int (*uevent)(struct device___213 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___213 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___213 *);
	const struct dev_pm_ops___213 *pm;
};

struct class___213 {
	const char *name;
	struct module___203 *owner;
	const struct attribute_group___215 **class_groups;
	const struct attribute_group___215 **dev_groups;
	struct kobject___237 *dev_kobj;
	int (*dev_uevent)(struct device___213 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___213 *, umode_t *);
	void (*class_release)(struct class___213 *);
	void (*dev_release)(struct device___213 *);
	int (*shutdown_pre)(struct device___213 *);
	const struct kobj_ns_type_operations___23 *ns_type;
	const void * (*namespace)(struct device___213 *);
	const struct dev_pm_ops___213 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___56 {
	void * (*alloc)(struct device___213 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___213 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___213 *, struct vm_area_struct___250 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___213 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___213 *, struct page___250 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___213 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___213 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___213 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___213 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___213 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___213 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___213 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___213 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___213 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___213 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___213 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___213 *, u64);
	u64 (*get_required_mask)(struct device___213 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___148;

struct fwnode_handle___148 {
	struct fwnode_handle___148 *secondary;
	const struct fwnode_operations___148 *ops;
};

typedef void compound_page_dtor___239(struct page___250 *);

struct fwnode_reference_args___148;

struct fwnode_endpoint___148;

struct fwnode_operations___148 {
	struct fwnode_handle___148 * (*get)(struct fwnode_handle___148 *);
	void (*put)(struct fwnode_handle___148 *);
	bool (*device_is_available)(const struct fwnode_handle___148 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___148 *, const struct device___213 *);
	bool (*property_present)(const struct fwnode_handle___148 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___148 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___148 *, const char *, const char **, size_t);
	struct fwnode_handle___148 * (*get_parent)(const struct fwnode_handle___148 *);
	struct fwnode_handle___148 * (*get_next_child_node)(const struct fwnode_handle___148 *, struct fwnode_handle___148 *);
	struct fwnode_handle___148 * (*get_named_child_node)(const struct fwnode_handle___148 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___148 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___148 *);
	struct fwnode_handle___148 * (*graph_get_next_endpoint)(const struct fwnode_handle___148 *, struct fwnode_handle___148 *);
	struct fwnode_handle___148 * (*graph_get_remote_endpoint)(const struct fwnode_handle___148 *);
	struct fwnode_handle___148 * (*graph_get_port_parent)(struct fwnode_handle___148 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___148 *, struct fwnode_endpoint___148 *);
};

struct fwnode_endpoint___148 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___148 *local_fwnode;
};

struct fwnode_reference_args___148 {
	struct fwnode_handle___148 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___59;

struct pipe_buffer___59 {
	struct page___250 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___59 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___59 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___59 *, struct pipe_buffer___59 *);
	void (*release)(struct pipe_inode_info___59 *, struct pipe_buffer___59 *);
	int (*steal)(struct pipe_inode_info___59 *, struct pipe_buffer___59 *);
	union {
		bool (*get)(struct pipe_inode_info___59 *, struct pipe_buffer___59 *);
		struct {
			void (*get)(struct pipe_inode_info___59 *, struct pipe_buffer___59 *);
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
};

struct crypto_template___2;

struct crypto_instance___2 {
	struct crypto_alg___7 alg;
	struct crypto_template___2 *tmpl;
	struct hlist_node list;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_template___2 {
	struct list_head list;
	struct hlist_head instances;
	struct module___203 *module;
	struct crypto_instance___2 * (*alloc)(struct rtattr **);
	void (*free)(struct crypto_instance___2 *);
	int (*create)(struct crypto_template___2 *, struct rtattr **);
	char name[128];
};

enum {
	CRYPTO_MSG_ALG_REQUEST = 0,
	CRYPTO_MSG_ALG_REGISTER = 1,
	CRYPTO_MSG_ALG_LOADED = 2,
};

struct crypto_larval {
	struct crypto_alg___7 alg;
	struct crypto_alg___7 *adult;
	struct completion completion;
	u32 mask;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module___204;

struct file___250;

struct kiocb___250;

struct iov_iter___117;

struct vm_area_struct___251;

struct inode___250;

struct file_lock___250;

struct page___251;

struct pipe_inode_info___60;

struct file_operations___250 {
	struct module___204 *owner;
	loff_t (*llseek)(struct file___250 *, loff_t, int);
	ssize_t (*read)(struct file___250 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___250 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___250 *, struct iov_iter___117 *);
	ssize_t (*write_iter)(struct kiocb___250 *, struct iov_iter___117 *);
	int (*iopoll)(struct kiocb___250 *, bool);
	int (*iterate)(struct file___250 *, struct dir_context *);
	int (*iterate_shared)(struct file___250 *, struct dir_context *);
	__poll_t (*poll)(struct file___250 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___250 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___250 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___250 *, struct vm_area_struct___251 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___250 *, struct file___250 *);
	int (*flush)(struct file___250 *, fl_owner_t);
	int (*release)(struct inode___250 *, struct file___250 *);
	int (*fsync)(struct file___250 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___250 *, int);
	int (*lock)(struct file___250 *, int, struct file_lock___250 *);
	ssize_t (*sendpage)(struct file___250 *, struct page___251 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___250 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___250 *, int, struct file_lock___250 *);
	ssize_t (*splice_write)(struct pipe_inode_info___60 *, struct file___250 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___250 *, loff_t *, struct pipe_inode_info___60 *, size_t, unsigned int);
	int (*setlease)(struct file___250 *, long int, struct file_lock___250 **, void **);
	long int (*fallocate)(struct file___250 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___250 *);
	ssize_t (*copy_file_range)(struct file___250 *, loff_t, struct file___250 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___250 *, loff_t, struct file___250 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___250 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___250 {
	u64 seqnum;
	struct vm_area_struct___251 *vmas[4];
};

struct page_frag___250 {
	struct page___251 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___250;

struct vm_struct___167;

struct task_struct___251 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___251 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___250 *mm;
	struct mm_struct___250 *active_mm;
	struct vmacache___250 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___251 *real_parent;
	struct task_struct___251 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___251 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___188 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___188 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___188 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___2 *ptracer_cred;
	const struct cred___2 *real_cred;
	const struct cred___2 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___251 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___60 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___60 *splice_pipe;
	struct page_frag___250 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___251 *oom_reaper_list;
	struct vm_struct___167 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___127 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct secondary_data___251 {
	void *stack;
	struct task_struct___251 *task;
	long int status;
};

typedef struct page___251 *pgtable_t___250;

struct address_space___249;

struct dev_pagemap___240;

struct page___251 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___249 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___251 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___250 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___250 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___240 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___250;

struct lruvec___250 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___250 *pgdat;
};

struct zone___250 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___250 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___250 {
	struct zone___250 *zone;
	int zone_idx;
};

struct zonelist___250 {
	struct zoneref___250 _zonerefs[25];
};

struct pglist_data___250 {
	struct zone___250 node_zones[3];
	struct zonelist___250 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___251 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___251 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___250 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___251 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___251 *owner;
};

struct blocking_notifier_head___250 {
	struct rw_semaphore___251 rwsem;
	struct notifier_block *head;
};

struct dentry___250;

struct path___250 {
	struct vfsmount *mnt;
	struct dentry___250 *dentry;
};

struct file___250 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___250 f_path;
	struct inode___250 *f_inode;
	const struct file_operations___250 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___188 f_owner;
	const struct cred___2 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___249 *f_mapping;
	errseq_t f_wb_err;
};

struct kernfs_root___244;

struct kernfs_elem_dir___244 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___244 *root;
};

struct kernfs_node___245;

struct kernfs_syscall_ops___244;

struct kernfs_root___244 {
	struct kernfs_node___245 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___244 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___244 {
	struct kernfs_node___245 *target_kn;
};

struct kernfs_ops___244;

struct kernfs_elem_attr___244 {
	const struct kernfs_ops___244 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___245 *notify_next;
};

struct kernfs_node___245 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___245 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___244 dir;
		struct kernfs_elem_symlink___244 symlink;
		struct kernfs_elem_attr___244 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___244;

struct kernfs_ops___244 {
	int (*open)(struct kernfs_open_file___244 *);
	void (*release)(struct kernfs_open_file___244 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___244 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___244 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___244 *, struct vm_area_struct___251 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___244 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___244 {
	int (*remount_fs)(struct kernfs_root___244 *, int *, char *);
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___244 *);
	int (*mkdir)(struct kernfs_node___245 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___245 *);
	int (*rename)(struct kernfs_node___245 *, struct kernfs_node___245 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___245 *, struct kernfs_root___244 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_operations_struct___240;

struct kernfs_open_file___244 {
	struct kernfs_node___245 *kn;
	struct file___250 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___240 *vm_ops;
};

struct vm_fault___240;

struct vm_operations_struct___240 {
	void (*open)(struct vm_area_struct___251 *);
	void (*close)(struct vm_area_struct___251 *);
	int (*split)(struct vm_area_struct___251 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___251 *);
	vm_fault_t (*fault)(struct vm_fault___240 *);
	vm_fault_t (*huge_fault)(struct vm_fault___240 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___240 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___251 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___240 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___240 *);
	int (*access)(struct vm_area_struct___251 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___251 *);
	int (*set_policy)(struct vm_area_struct___251 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___251 *, long unsigned int);
	struct page___251 * (*find_special_page)(struct vm_area_struct___251 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_area_struct___251 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___251 *vm_next;
	struct vm_area_struct___251 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___250 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___240 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___250 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___238;

struct bin_attribute___215;

struct attribute_group___216 {
	const char *name;
	umode_t (*is_visible)(struct kobject___238 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___238 *, struct bin_attribute___215 *, int);
	struct attribute **attrs;
	struct bin_attribute___215 **bin_attrs;
};

struct kset___237;

struct kobj_type___237;

struct kobject___238 {
	const char *name;
	struct list_head entry;
	struct kobject___238 *parent;
	struct kset___237 *kset;
	struct kobj_type___237 *ktype;
	struct kernfs_node___245 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___215 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___250 *, struct kobject___238 *, struct bin_attribute___215 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___250 *, struct kobject___238 *, struct bin_attribute___215 *, char *, loff_t, size_t);
	int (*mmap)(struct file___250 *, struct kobject___238 *, struct bin_attribute___215 *, struct vm_area_struct___251 *);
};

struct sysfs_ops___237 {
	ssize_t (*show)(struct kobject___238 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___238 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___237;

struct kset___237 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___238 kobj;
	const struct kset_uevent_ops___237 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___237 {
	void (*release)(struct kobject___238 *);
	const struct sysfs_ops___237 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___23 * (*child_ns_type)(struct kobject___238 *);
	const void * (*namespace)(struct kobject___238 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___237 {
	int (* const filter)(struct kset___237 *, struct kobject___238 *);
	const char * (* const name)(struct kset___237 *, struct kobject___238 *);
	int (* const uevent)(struct kset___237 *, struct kobject___238 *, struct kobj_uevent_env *);
};

struct kobj_attribute___231 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___238 *, struct kobj_attribute___231 *, char *);
	ssize_t (*store)(struct kobject___238 *, struct kobj_attribute___231 *, const char *, size_t);
};

struct kernel_param___201;

struct kernel_param_ops___201 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___201 *);
	int (*get)(char *, const struct kernel_param___201 *);
	void (*free)(void *);
};

struct kparam_array___201;

struct kernel_param___201 {
	const char *name;
	struct module___204 *mod;
	const struct kernel_param_ops___201 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___201 *arr;
	};
};

struct kparam_array___201 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___201 *ops;
	void *elem;
};

struct module_kobject___201 {
	struct kobject___238 kobj;
	struct module___204 *mod;
	struct kobject___238 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___201 {
	struct module___204 *mod;
	struct latch_tree_node node;
};

struct module_layout___201 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___201 mtn;
};

struct module_attribute___201;

struct module___204 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___201 mkobj;
	struct module_attribute___201 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___238 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___201 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___201 core_layout;
	struct module_layout___201 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___201 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___201 *, struct module_kobject___201 *, char *);
	ssize_t (*store)(struct module_attribute___201 *, struct module_kobject___201 *, const char *, size_t);
	void (*setup)(struct module___204 *, const char *);
	int (*test)(struct module___204 *);
	void (*free)(struct module___204 *);
};

struct core_state___250;

struct mm_struct___250 {
	struct {
		struct vm_area_struct___251 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___250 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___251 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___250 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___251 *owner;
		struct user_namespace___3 *user_ns;
		struct file___250 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___250 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct fasync_struct___249;

struct pipe_buffer___60;

struct pipe_inode_info___60 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___251 *tmp_page;
	struct fasync_struct___249 *fasync_readers;
	struct fasync_struct___249 *fasync_writers;
	struct pipe_buffer___60 *bufs;
	struct user_struct___25 *user;
};

struct vm_struct___167 {
	struct vm_struct___167 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___251 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___249;

struct address_space___249 {
	struct inode___250 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___251 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___249 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___240)(struct vm_area_struct___251 *, long unsigned int, const struct page___251 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___240)(struct page___251 *, void *);

struct device___214;

struct dev_pagemap___240 {
	dev_page_fault_t___240 page_fault;
	dev_page_free_t___240 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___214 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___250 {
	struct task_struct___251 *task;
	struct core_thread___250 *next;
};

struct core_state___250 {
	atomic_t nr_threads;
	struct core_thread___250 dumper;
	struct completion startup;
};

struct vm_fault___240 {
	struct vm_area_struct___251 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___251 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___251 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___250 prealloc_pte;
};

struct crypto_async_request___8;

typedef void (*crypto_completion_t___8)(struct crypto_async_request___8 *, int);

struct crypto_tfm___8;

struct crypto_async_request___8 {
	struct list_head list;
	crypto_completion_t___8 complete;
	void *data;
	struct crypto_tfm___8 *tfm;
	u32 flags;
};

struct crypto_ablkcipher___8;

struct ablkcipher_request___8;

struct ablkcipher_tfm___8 {
	int (*setkey)(struct crypto_ablkcipher___8 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___8 *);
	int (*decrypt)(struct ablkcipher_request___8 *);
	struct crypto_ablkcipher___8 *base;
	unsigned int ivsize;
	unsigned int reqsize;
};

struct blkcipher_desc___8;

struct blkcipher_tfm___8 {
	void *iv;
	int (*setkey)(struct crypto_tfm___8 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___8 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___8 *, struct scatterlist *, struct scatterlist *, unsigned int);
};

struct cipher_tfm___8 {
	int (*cit_setkey)(struct crypto_tfm___8 *, const u8 *, unsigned int);
	void (*cit_encrypt_one)(struct crypto_tfm___8 *, u8 *, const u8 *);
	void (*cit_decrypt_one)(struct crypto_tfm___8 *, u8 *, const u8 *);
};

struct compress_tfm___8 {
	int (*cot_compress)(struct crypto_tfm___8 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*cot_decompress)(struct crypto_tfm___8 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___8;

struct crypto_tfm___8 {
	u32 crt_flags;
	union {
		struct ablkcipher_tfm___8 ablkcipher;
		struct blkcipher_tfm___8 blkcipher;
		struct cipher_tfm___8 cipher;
		struct compress_tfm___8 compress;
	} crt_u;
	void (*exit)(struct crypto_tfm___8 *);
	struct crypto_alg___8 *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct ablkcipher_request___8 {
	struct crypto_async_request___8 base;
	unsigned int nbytes;
	void *info;
	struct scatterlist *src;
	struct scatterlist *dst;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_blkcipher___8;

struct blkcipher_desc___8 {
	struct crypto_blkcipher___8 *tfm;
	void *info;
	u32 flags;
};

struct crypto_blkcipher___8 {
	struct crypto_tfm___8 base;
};

struct ablkcipher_alg___8 {
	int (*setkey)(struct crypto_ablkcipher___8 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___8 *);
	int (*decrypt)(struct ablkcipher_request___8 *);
	int (*givencrypt)(struct skcipher_givcrypt_request *);
	int (*givdecrypt)(struct skcipher_givcrypt_request *);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct crypto_ablkcipher___8 {
	struct crypto_tfm___8 base;
};

struct blkcipher_alg___8 {
	int (*setkey)(struct crypto_tfm___8 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___8 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___8 *, struct scatterlist *, struct scatterlist *, unsigned int);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct cipher_alg___8 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___8 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___8 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___8 *, u8 *, const u8 *);
};

struct compress_alg___8 {
	int (*coa_compress)(struct crypto_tfm___8 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___8 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_type___3;

struct crypto_alg___8 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type___3 *cra_type;
	union {
		struct ablkcipher_alg___8 ablkcipher;
		struct blkcipher_alg___8 blkcipher;
		struct cipher_alg___8 cipher;
		struct compress_alg___8 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___8 *);
	void (*cra_exit)(struct crypto_tfm___8 *);
	void (*cra_destroy)(struct crypto_alg___8 *);
	struct module___204 *cra_module;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct crypto_instance___3;

struct crypto_type___3 {
	unsigned int (*ctxsize)(struct crypto_alg___8 *, u32, u32);
	unsigned int (*extsize)(struct crypto_alg___8 *);
	int (*init)(struct crypto_tfm___8 *, u32, u32);
	int (*init_tfm)(struct crypto_tfm___8 *);
	void (*show)(struct seq_file___9 *, struct crypto_alg___8 *);
	int (*report)(struct sk_buff___6 *, struct crypto_alg___8 *);
	void (*free)(struct crypto_instance___3 *);
	unsigned int type;
	unsigned int maskclear;
	unsigned int maskset;
	unsigned int tfmsize;
};

struct iov_iter___117 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___3 *bvec;
		struct pipe_inode_info___60 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct kiocb___250 {
	struct file___250 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___250 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dentry_operations___249;

struct super_block___249;

struct dentry___250 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___250 *d_parent;
	struct qstr d_name;
	struct inode___250 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___249 *d_op;
	struct super_block___249 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___249;

struct block_device___250;

struct inode___250 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___249 *i_op;
	struct super_block___249 *i_sb;
	struct address_space___249 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___251 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___250 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___249 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___60 *i_pipe;
		struct block_device___250 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___249 {
	int (*d_revalidate)(struct dentry___250 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___250 *, unsigned int);
	int (*d_hash)(const struct dentry___250 *, struct qstr *);
	int (*d_compare)(const struct dentry___250 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___250 *);
	int (*d_init)(struct dentry___250 *);
	void (*d_release)(struct dentry___250 *);
	void (*d_prune)(struct dentry___250 *);
	void (*d_iput)(struct dentry___250 *, struct inode___250 *);
	char * (*d_dname)(struct dentry___250 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___250 *);
	int (*d_manage)(const struct path___250 *, bool);
	struct dentry___250 * (*d_real)(struct dentry___250 *, const struct inode___250 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___249;

struct mem_dqinfo___249 {
	struct quota_format_type___249 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___249;

struct quota_info___249 {
	unsigned int flags;
	struct rw_semaphore___251 dqio_sem;
	struct inode___250 *files[3];
	struct mem_dqinfo___249 info[3];
	const struct quota_format_ops___249 *ops[3];
};

struct rcuwait___249 {
	struct task_struct___251 *task;
};

struct percpu_rw_semaphore___249 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___251 rw_sem;
	struct rcuwait___249 writer;
	int readers_block;
};

struct sb_writers___249 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___249 rw_sem[3];
};

struct file_system_type___249;

struct super_operations___249;

struct dquot_operations___249;

struct quotactl_ops___249;

struct super_block___249 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___249 *s_type;
	const struct super_operations___249 *s_op;
	const struct dquot_operations___249 *dq_op;
	const struct quotactl_ops___249 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___250 *s_root;
	struct rw_semaphore___251 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___250 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___249 s_dquot;
	struct sb_writers___249 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___249 *s_d_op;
	int cleancache_poolid;
	struct shrinker___109 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct iattr___249 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___250 *ia_file;
};

struct dquot___249 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___249 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___249 {
	int qf_fmt_id;
	const struct quota_format_ops___249 *qf_ops;
	struct module___204 *qf_owner;
	struct quota_format_type___249 *qf_next;
};

struct quota_format_ops___249 {
	int (*check_quota_file)(struct super_block___249 *, int);
	int (*read_file_info)(struct super_block___249 *, int);
	int (*write_file_info)(struct super_block___249 *, int);
	int (*free_file_info)(struct super_block___249 *, int);
	int (*read_dqblk)(struct dquot___249 *);
	int (*commit_dqblk)(struct dquot___249 *);
	int (*release_dqblk)(struct dquot___249 *);
	int (*get_next_id)(struct super_block___249 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___249 {
	int (*write_dquot)(struct dquot___249 *);
	struct dquot___249 * (*alloc_dquot)(struct super_block___249 *, int);
	void (*destroy_dquot)(struct dquot___249 *);
	int (*acquire_dquot)(struct dquot___249 *);
	int (*release_dquot)(struct dquot___249 *);
	int (*mark_dirty)(struct dquot___249 *);
	int (*write_info)(struct super_block___249 *, int);
	qsize_t * (*get_reserved_space)(struct inode___250 *);
	int (*get_projid)(struct inode___250 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___250 *, qsize_t *);
	int (*get_next_id)(struct super_block___249 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___249 {
	int (*quota_on)(struct super_block___249 *, int, int, const struct path___250 *);
	int (*quota_off)(struct super_block___249 *, int);
	int (*quota_enable)(struct super_block___249 *, unsigned int);
	int (*quota_disable)(struct super_block___249 *, unsigned int);
	int (*quota_sync)(struct super_block___249 *, int);
	int (*set_info)(struct super_block___249 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___249 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___249 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___249 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___249 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___249 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___249 {
	int (*writepage)(struct page___251 *, struct writeback_control___3 *);
	int (*readpage)(struct file___250 *, struct page___251 *);
	int (*writepages)(struct address_space___249 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___251 *);
	int (*readpages)(struct file___250 *, struct address_space___249 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___250 *, struct address_space___249 *, loff_t, unsigned int, unsigned int, struct page___251 **, void **);
	int (*write_end)(struct file___250 *, struct address_space___249 *, loff_t, unsigned int, unsigned int, struct page___251 *, void *);
	sector_t (*bmap)(struct address_space___249 *, sector_t);
	void (*invalidatepage)(struct page___251 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___251 *, gfp_t);
	void (*freepage)(struct page___251 *);
	ssize_t (*direct_IO)(struct kiocb___250 *, struct iov_iter___117 *);
	int (*migratepage)(struct address_space___249 *, struct page___251 *, struct page___251 *, enum migrate_mode);
	bool (*isolate_page)(struct page___251 *, isolate_mode_t);
	void (*putback_page)(struct page___251 *);
	int (*launder_page)(struct page___251 *);
	int (*is_partially_uptodate)(struct page___251 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___251 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___249 *, struct page___251 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___250 *, sector_t *);
	void (*swap_deactivate)(struct file___250 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___250 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___250 *bd_inode;
	struct super_block___249 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___250 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___249 {
	struct dentry___250 * (*lookup)(struct inode___250 *, struct dentry___250 *, unsigned int);
	const char * (*get_link)(struct dentry___250 *, struct inode___250 *, struct delayed_call *);
	int (*permission)(struct inode___250 *, int);
	struct posix_acl * (*get_acl)(struct inode___250 *, int);
	int (*readlink)(struct dentry___250 *, char *, int);
	int (*create)(struct inode___250 *, struct dentry___250 *, umode_t, bool);
	int (*link)(struct dentry___250 *, struct inode___250 *, struct dentry___250 *);
	int (*unlink)(struct inode___250 *, struct dentry___250 *);
	int (*symlink)(struct inode___250 *, struct dentry___250 *, const char *);
	int (*mkdir)(struct inode___250 *, struct dentry___250 *, umode_t);
	int (*rmdir)(struct inode___250 *, struct dentry___250 *);
	int (*mknod)(struct inode___250 *, struct dentry___250 *, umode_t, dev_t);
	int (*rename)(struct inode___250 *, struct dentry___250 *, struct inode___250 *, struct dentry___250 *, unsigned int);
	int (*setattr)(struct dentry___250 *, struct iattr___249 *);
	int (*getattr)(const struct path___250 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___250 *, char *, size_t);
	int (*fiemap)(struct inode___250 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___250 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___250 *, struct dentry___250 *, struct file___250 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___250 *, struct dentry___250 *, umode_t);
	int (*set_acl)(struct inode___250 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___249 {
	void (*fl_copy_lock)(struct file_lock___250 *, struct file_lock___250 *);
	void (*fl_release_private)(struct file_lock___250 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___249;

struct file_lock___250 {
	struct file_lock___250 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___250 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___249 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___249 *fl_ops;
	const struct lock_manager_operations___249 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___249 {
	int (*lm_compare_owner)(struct file_lock___250 *, struct file_lock___250 *);
	long unsigned int (*lm_owner_key)(struct file_lock___250 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___250 *);
	int (*lm_grant)(struct file_lock___250 *, int);
	bool (*lm_break)(struct file_lock___250 *);
	int (*lm_change)(struct file_lock___250 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___250 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___249 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___249 *fa_next;
	struct file___250 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___249 {
	const char *name;
	int fs_flags;
	struct dentry___250 * (*mount)(struct file_system_type___249 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___249 *);
	struct module___204 *owner;
	struct file_system_type___249 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___249 {
	struct inode___250 * (*alloc_inode)(struct super_block___249 *);
	void (*destroy_inode)(struct inode___250 *);
	void (*dirty_inode)(struct inode___250 *, int);
	int (*write_inode)(struct inode___250 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___250 *);
	void (*evict_inode)(struct inode___250 *);
	void (*put_super)(struct super_block___249 *);
	int (*sync_fs)(struct super_block___249 *, int);
	int (*freeze_super)(struct super_block___249 *);
	int (*freeze_fs)(struct super_block___249 *);
	int (*thaw_super)(struct super_block___249 *);
	int (*unfreeze_fs)(struct super_block___249 *);
	int (*statfs)(struct dentry___250 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___249 *, int *, char *);
	void (*umount_begin)(struct super_block___249 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___250 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___250 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___250 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___250 *);
	ssize_t (*quota_read)(struct super_block___249 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___249 *, int, const char *, size_t, loff_t);
	struct dquot___249 ** (*get_dquots)(struct inode___250 *);
	int (*bdev_try_to_free_page)(struct super_block___249 *, struct page___251 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___249 *, struct shrink_control___109 *);
	long int (*free_cached_objects)(struct super_block___249 *, struct shrink_control___109 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_ops___214 {
	int (*prepare)(struct device___214 *);
	void (*complete)(struct device___214 *);
	int (*suspend)(struct device___214 *);
	int (*resume)(struct device___214 *);
	int (*freeze)(struct device___214 *);
	int (*thaw)(struct device___214 *);
	int (*poweroff)(struct device___214 *);
	int (*restore)(struct device___214 *);
	int (*suspend_late)(struct device___214 *);
	int (*resume_early)(struct device___214 *);
	int (*freeze_late)(struct device___214 *);
	int (*thaw_early)(struct device___214 *);
	int (*poweroff_late)(struct device___214 *);
	int (*restore_early)(struct device___214 *);
	int (*suspend_noirq)(struct device___214 *);
	int (*resume_noirq)(struct device___214 *);
	int (*freeze_noirq)(struct device___214 *);
	int (*thaw_noirq)(struct device___214 *);
	int (*poweroff_noirq)(struct device___214 *);
	int (*restore_noirq)(struct device___214 *);
	int (*runtime_suspend)(struct device___214 *);
	int (*runtime_resume)(struct device___214 *);
	int (*runtime_idle)(struct device___214 *);
};

struct dev_pm_info___214 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___214 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___214;

struct bus_type___214;

struct device_driver___214;

struct dev_pm_domain___214;

struct dma_map_ops___57;

struct fwnode_handle___149;

struct class___214;

struct device___214 {
	struct device___214 *parent;
	struct device_private *p;
	struct kobject___238 kobj;
	const char *init_name;
	const struct device_type___214 *type;
	struct mutex mutex;
	struct bus_type___214 *bus;
	struct device_driver___214 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___214 power;
	struct dev_pm_domain___214 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___57 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___149 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___214 *class;
	const struct attribute_group___216 **groups;
	void (*release)(struct device___214 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___214 {
	struct dev_pm_ops___214 ops;
	void (*detach)(struct device___214 *, bool);
	int (*activate)(struct device___214 *);
	void (*sync)(struct device___214 *);
	void (*dismiss)(struct device___214 *);
};

struct bus_type___214 {
	const char *name;
	const char *dev_name;
	struct device___214 *dev_root;
	const struct attribute_group___216 **bus_groups;
	const struct attribute_group___216 **dev_groups;
	const struct attribute_group___216 **drv_groups;
	int (*match)(struct device___214 *, struct device_driver___214 *);
	int (*uevent)(struct device___214 *, struct kobj_uevent_env *);
	int (*probe)(struct device___214 *);
	int (*remove)(struct device___214 *);
	void (*shutdown)(struct device___214 *);
	int (*online)(struct device___214 *);
	int (*offline)(struct device___214 *);
	int (*suspend)(struct device___214 *, pm_message_t);
	int (*resume)(struct device___214 *);
	int (*num_vf)(struct device___214 *);
	int (*dma_configure)(struct device___214 *);
	const struct dev_pm_ops___214 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___214 {
	const char *name;
	struct bus_type___214 *bus;
	struct module___204 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___214 *);
	int (*remove)(struct device___214 *);
	void (*shutdown)(struct device___214 *);
	int (*suspend)(struct device___214 *, pm_message_t);
	int (*resume)(struct device___214 *);
	const struct attribute_group___216 **groups;
	const struct dev_pm_ops___214 *pm;
	void (*coredump)(struct device___214 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___214 {
	const char *name;
	const struct attribute_group___216 **groups;
	int (*uevent)(struct device___214 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___214 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___214 *);
	const struct dev_pm_ops___214 *pm;
};

struct class___214 {
	const char *name;
	struct module___204 *owner;
	const struct attribute_group___216 **class_groups;
	const struct attribute_group___216 **dev_groups;
	struct kobject___238 *dev_kobj;
	int (*dev_uevent)(struct device___214 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___214 *, umode_t *);
	void (*class_release)(struct class___214 *);
	void (*dev_release)(struct device___214 *);
	int (*shutdown_pre)(struct device___214 *);
	const struct kobj_ns_type_operations___23 *ns_type;
	const void * (*namespace)(struct device___214 *);
	const struct dev_pm_ops___214 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___57 {
	void * (*alloc)(struct device___214 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___214 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___214 *, struct vm_area_struct___251 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___214 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___214 *, struct page___251 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___214 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___214 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___214 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___214 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___214 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___214 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___214 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___214 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___214 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___214 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___214 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___214 *, u64);
	u64 (*get_required_mask)(struct device___214 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___149;

struct fwnode_handle___149 {
	struct fwnode_handle___149 *secondary;
	const struct fwnode_operations___149 *ops;
};

typedef void compound_page_dtor___240(struct page___251 *);

struct fwnode_reference_args___149;

struct fwnode_endpoint___149;

struct fwnode_operations___149 {
	struct fwnode_handle___149 * (*get)(struct fwnode_handle___149 *);
	void (*put)(struct fwnode_handle___149 *);
	bool (*device_is_available)(const struct fwnode_handle___149 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___149 *, const struct device___214 *);
	bool (*property_present)(const struct fwnode_handle___149 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___149 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___149 *, const char *, const char **, size_t);
	struct fwnode_handle___149 * (*get_parent)(const struct fwnode_handle___149 *);
	struct fwnode_handle___149 * (*get_next_child_node)(const struct fwnode_handle___149 *, struct fwnode_handle___149 *);
	struct fwnode_handle___149 * (*get_named_child_node)(const struct fwnode_handle___149 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___149 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___149 *);
	struct fwnode_handle___149 * (*graph_get_next_endpoint)(const struct fwnode_handle___149 *, struct fwnode_handle___149 *);
	struct fwnode_handle___149 * (*graph_get_remote_endpoint)(const struct fwnode_handle___149 *);
	struct fwnode_handle___149 * (*graph_get_port_parent)(struct fwnode_handle___149 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___149 *, struct fwnode_endpoint___149 *);
};

struct fwnode_endpoint___149 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___149 *local_fwnode;
};

struct fwnode_reference_args___149 {
	struct fwnode_handle___149 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___60;

struct pipe_buffer___60 {
	struct page___251 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___60 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___60 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___60 *, struct pipe_buffer___60 *);
	void (*release)(struct pipe_inode_info___60 *, struct pipe_buffer___60 *);
	int (*steal)(struct pipe_inode_info___60 *, struct pipe_buffer___60 *);
	union {
		bool (*get)(struct pipe_inode_info___60 *, struct pipe_buffer___60 *);
		struct {
			void (*get)(struct pipe_inode_info___60 *, struct pipe_buffer___60 *);
		} __UNIQUE_ID_rh_kabi_hide21;
		union {		};
	};
};

struct crypto_template___3;

struct crypto_instance___3 {
	struct crypto_alg___8 alg;
	struct crypto_template___3 *tmpl;
	struct hlist_node list;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_template___3 {
	struct list_head list;
	struct hlist_head instances;
	struct module___204 *module;
	struct crypto_instance___3 * (*alloc)(struct rtattr **);
	void (*free)(struct crypto_instance___3 *);
	int (*create)(struct crypto_template___3 *, struct rtattr **);
	char name[128];
};

struct crypto_async_request___9;

typedef void (*crypto_completion_t___9)(struct crypto_async_request___9 *, int);

struct crypto_tfm___9;

struct crypto_async_request___9 {
	struct list_head list;
	crypto_completion_t___9 complete;
	void *data;
	struct crypto_tfm___9 *tfm;
	u32 flags;
};

struct crypto_ablkcipher___9;

struct ablkcipher_request___9;

struct ablkcipher_tfm___9 {
	int (*setkey)(struct crypto_ablkcipher___9 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___9 *);
	int (*decrypt)(struct ablkcipher_request___9 *);
	struct crypto_ablkcipher___9 *base;
	unsigned int ivsize;
	unsigned int reqsize;
};

struct blkcipher_desc___9;

struct blkcipher_tfm___9 {
	void *iv;
	int (*setkey)(struct crypto_tfm___9 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___9 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___9 *, struct scatterlist *, struct scatterlist *, unsigned int);
};

struct cipher_tfm___9 {
	int (*cit_setkey)(struct crypto_tfm___9 *, const u8 *, unsigned int);
	void (*cit_encrypt_one)(struct crypto_tfm___9 *, u8 *, const u8 *);
	void (*cit_decrypt_one)(struct crypto_tfm___9 *, u8 *, const u8 *);
};

struct compress_tfm___9 {
	int (*cot_compress)(struct crypto_tfm___9 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*cot_decompress)(struct crypto_tfm___9 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___9;

struct crypto_tfm___9 {
	u32 crt_flags;
	union {
		struct ablkcipher_tfm___9 ablkcipher;
		struct blkcipher_tfm___9 blkcipher;
		struct cipher_tfm___9 cipher;
		struct compress_tfm___9 compress;
	} crt_u;
	void (*exit)(struct crypto_tfm___9 *);
	struct crypto_alg___9 *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct ablkcipher_request___9 {
	struct crypto_async_request___9 base;
	unsigned int nbytes;
	void *info;
	struct scatterlist *src;
	struct scatterlist *dst;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_blkcipher___9;

struct blkcipher_desc___9 {
	struct crypto_blkcipher___9 *tfm;
	void *info;
	u32 flags;
};

struct crypto_blkcipher___9 {
	struct crypto_tfm___9 base;
};

struct ablkcipher_alg___9 {
	int (*setkey)(struct crypto_ablkcipher___9 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___9 *);
	int (*decrypt)(struct ablkcipher_request___9 *);
	int (*givencrypt)(struct skcipher_givcrypt_request *);
	int (*givdecrypt)(struct skcipher_givcrypt_request *);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct crypto_ablkcipher___9 {
	struct crypto_tfm___9 base;
};

struct blkcipher_alg___9 {
	int (*setkey)(struct crypto_tfm___9 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___9 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___9 *, struct scatterlist *, struct scatterlist *, unsigned int);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct cipher_alg___9 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___9 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___9 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___9 *, u8 *, const u8 *);
};

struct compress_alg___9 {
	int (*coa_compress)(struct crypto_tfm___9 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___9 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_type___4;

struct crypto_alg___9 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type___4 *cra_type;
	union {
		struct ablkcipher_alg___9 ablkcipher;
		struct blkcipher_alg___9 blkcipher;
		struct cipher_alg___9 cipher;
		struct compress_alg___9 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___9 *);
	void (*cra_exit)(struct crypto_tfm___9 *);
	void (*cra_destroy)(struct crypto_alg___9 *);
	struct module___23 *cra_module;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct crypto_instance___4;

struct crypto_type___4 {
	unsigned int (*ctxsize)(struct crypto_alg___9 *, u32, u32);
	unsigned int (*extsize)(struct crypto_alg___9 *);
	int (*init)(struct crypto_tfm___9 *, u32, u32);
	int (*init_tfm)(struct crypto_tfm___9 *);
	void (*show)(struct seq_file___23 *, struct crypto_alg___9 *);
	int (*report)(struct sk_buff___4 *, struct crypto_alg___9 *);
	void (*free)(struct crypto_instance___4 *);
	unsigned int type;
	unsigned int maskclear;
	unsigned int maskset;
	unsigned int tfmsize;
};

enum {
	CRYPTOA_UNSPEC = 0,
	CRYPTOA_ALG = 1,
	CRYPTOA_TYPE = 2,
	CRYPTOA_U32 = 3,
	__CRYPTOA_MAX = 4,
};

struct crypto_attr_alg {
	char name[128];
};

struct crypto_attr_type {
	u32 type;
	u32 mask;
};

struct crypto_attr_u32 {
	u32 num;
};

struct crypto_template___4;

struct crypto_instance___4 {
	struct crypto_alg___9 alg;
	struct crypto_template___4 *tmpl;
	struct hlist_node list;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_template___4 {
	struct list_head list;
	struct hlist_head instances;
	struct module___23 *module;
	struct crypto_instance___4 * (*alloc)(struct rtattr **);
	void (*free)(struct crypto_instance___4 *);
	int (*create)(struct crypto_template___4 *, struct rtattr **);
	char name[128];
};

struct rtattr {
	short unsigned int rta_len;
	short unsigned int rta_type;
};

struct crypto_spawn {
	struct list_head list;
	struct crypto_alg___9 *alg;
	struct crypto_instance___4 *inst;
	const struct crypto_type___4 *frontend;
	u32 mask;
};

struct crypto_queue {
	struct list_head list;
	struct list_head *backlog;
	unsigned int qlen;
	unsigned int max_qlen;
};

struct crypto_larval___2 {
	struct crypto_alg___9 alg;
	struct crypto_alg___9 *adult;
	struct completion completion;
	u32 mask;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct crypto_async_request___10;

typedef void (*crypto_completion_t___10)(struct crypto_async_request___10 *, int);

struct crypto_tfm___10;

struct crypto_async_request___10 {
	struct list_head list;
	crypto_completion_t___10 complete;
	void *data;
	struct crypto_tfm___10 *tfm;
	u32 flags;
};

struct crypto_ablkcipher___10;

struct ablkcipher_request___10;

struct ablkcipher_tfm___10 {
	int (*setkey)(struct crypto_ablkcipher___10 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___10 *);
	int (*decrypt)(struct ablkcipher_request___10 *);
	struct crypto_ablkcipher___10 *base;
	unsigned int ivsize;
	unsigned int reqsize;
};

struct blkcipher_desc___10;

struct blkcipher_tfm___10 {
	void *iv;
	int (*setkey)(struct crypto_tfm___10 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___10 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___10 *, struct scatterlist *, struct scatterlist *, unsigned int);
};

struct cipher_tfm___10 {
	int (*cit_setkey)(struct crypto_tfm___10 *, const u8 *, unsigned int);
	void (*cit_encrypt_one)(struct crypto_tfm___10 *, u8 *, const u8 *);
	void (*cit_decrypt_one)(struct crypto_tfm___10 *, u8 *, const u8 *);
};

struct compress_tfm___10 {
	int (*cot_compress)(struct crypto_tfm___10 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*cot_decompress)(struct crypto_tfm___10 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___10;

struct crypto_tfm___10 {
	u32 crt_flags;
	union {
		struct ablkcipher_tfm___10 ablkcipher;
		struct blkcipher_tfm___10 blkcipher;
		struct cipher_tfm___10 cipher;
		struct compress_tfm___10 compress;
	} crt_u;
	void (*exit)(struct crypto_tfm___10 *);
	struct crypto_alg___10 *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct ablkcipher_request___10 {
	struct crypto_async_request___10 base;
	unsigned int nbytes;
	void *info;
	struct scatterlist *src;
	struct scatterlist *dst;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_blkcipher___10;

struct blkcipher_desc___10 {
	struct crypto_blkcipher___10 *tfm;
	void *info;
	u32 flags;
};

struct crypto_blkcipher___10 {
	struct crypto_tfm___10 base;
};

struct ablkcipher_alg___10 {
	int (*setkey)(struct crypto_ablkcipher___10 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___10 *);
	int (*decrypt)(struct ablkcipher_request___10 *);
	int (*givencrypt)(struct skcipher_givcrypt_request *);
	int (*givdecrypt)(struct skcipher_givcrypt_request *);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct crypto_ablkcipher___10 {
	struct crypto_tfm___10 base;
};

struct blkcipher_alg___10 {
	int (*setkey)(struct crypto_tfm___10 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___10 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___10 *, struct scatterlist *, struct scatterlist *, unsigned int);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct cipher_alg___10 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___10 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___10 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___10 *, u8 *, const u8 *);
};

struct compress_alg___10 {
	int (*coa_compress)(struct crypto_tfm___10 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___10 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_type___5;

struct crypto_alg___10 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type___5 *cra_type;
	union {
		struct ablkcipher_alg___10 ablkcipher;
		struct blkcipher_alg___10 blkcipher;
		struct cipher_alg___10 cipher;
		struct compress_alg___10 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___10 *);
	void (*cra_exit)(struct crypto_tfm___10 *);
	void (*cra_destroy)(struct crypto_alg___10 *);
	struct module___175 *cra_module;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct crypto_instance___5;

struct crypto_type___5 {
	unsigned int (*ctxsize)(struct crypto_alg___10 *, u32, u32);
	unsigned int (*extsize)(struct crypto_alg___10 *);
	int (*init)(struct crypto_tfm___10 *, u32, u32);
	int (*init_tfm)(struct crypto_tfm___10 *);
	void (*show)(struct seq_file___195 *, struct crypto_alg___10 *);
	int (*report)(struct sk_buff___6 *, struct crypto_alg___10 *);
	void (*free)(struct crypto_instance___5 *);
	unsigned int type;
	unsigned int maskclear;
	unsigned int maskset;
	unsigned int tfmsize;
};

struct crypto_template___5;

struct crypto_instance___5 {
	struct crypto_alg___10 alg;
	struct crypto_template___5 *tmpl;
	struct hlist_node list;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_template___5 {
	struct list_head list;
	struct hlist_head instances;
	struct module___175 *module;
	struct crypto_instance___5 * (*alloc)(struct rtattr **);
	void (*free)(struct crypto_instance___5 *);
	int (*create)(struct crypto_template___5 *, struct rtattr **);
	char name[128];
};

struct aead_request___2 {
	struct crypto_async_request___9 base;
	unsigned int assoclen;
	unsigned int cryptlen;
	u8 *iv;
	struct scatterlist *src;
	struct scatterlist *dst;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_aead___2;

struct aead_alg___2 {
	int (*setkey)(struct crypto_aead___2 *, const u8 *, unsigned int);
	int (*setauthsize)(struct crypto_aead___2 *, unsigned int);
	int (*encrypt)(struct aead_request___2 *);
	int (*decrypt)(struct aead_request___2 *);
	int (*init)(struct crypto_aead___2 *);
	void (*exit)(struct crypto_aead___2 *);
	const char *geniv;
	unsigned int ivsize;
	unsigned int maxauthsize;
	unsigned int chunksize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_alg___9 base;
};

struct crypto_aead___2 {
	unsigned int authsize;
	unsigned int reqsize;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_tfm___9 base;
};

struct aead_instance {
	void (*free)(struct aead_instance *);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	union {
		struct {
			char head[128];
			struct crypto_instance___4 base;
		} s;
		struct aead_alg___2 alg;
	};
};

struct crypto_aead_spawn {
	struct crypto_spawn base;
};

struct crypto_skcipher___2;

struct aead_geniv_ctx {
	spinlock_t lock;
	struct crypto_aead___2 *child;
	struct crypto_skcipher___2 *sknull;
	u8 salt[0];
};

struct crypto_rng;

struct rng_alg {
	int (*generate)(struct crypto_rng *, const u8 *, unsigned int, u8 *, unsigned int);
	int (*seed)(struct crypto_rng *, const u8 *, unsigned int);
	void (*set_ent)(struct crypto_rng *, const u8 *, unsigned int);
	unsigned int seedsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_alg___9 base;
};

struct crypto_rng {
	struct crypto_tfm___9 base;
};

enum crypto_attr_type_t {
	CRYPTOCFGA_UNSPEC = 0,
	CRYPTOCFGA_PRIORITY_VAL = 1,
	CRYPTOCFGA_REPORT_LARVAL = 2,
	CRYPTOCFGA_REPORT_HASH = 3,
	CRYPTOCFGA_REPORT_BLKCIPHER = 4,
	CRYPTOCFGA_REPORT_AEAD = 5,
	CRYPTOCFGA_REPORT_COMPRESS = 6,
	CRYPTOCFGA_REPORT_RNG = 7,
	CRYPTOCFGA_REPORT_CIPHER = 8,
	CRYPTOCFGA_REPORT_AKCIPHER = 9,
	CRYPTOCFGA_REPORT_KPP = 10,
	CRYPTOCFGA_REPORT_ACOMP = 11,
	__CRYPTOCFGA_MAX = 12,
};

struct crypto_report_aead {
	char type[64];
	char geniv[64];
	unsigned int blocksize;
	unsigned int maxauthsize;
	unsigned int ivsize;
};

struct module___205;

struct file___251;

struct kiocb___251;

struct iov_iter___118;

struct vm_area_struct___252;

struct inode___251;

struct file_lock___251;

struct page___252;

struct pipe_inode_info___61;

struct seq_file___225;

struct file_operations___251 {
	struct module___205 *owner;
	loff_t (*llseek)(struct file___251 *, loff_t, int);
	ssize_t (*read)(struct file___251 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___251 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___251 *, struct iov_iter___118 *);
	ssize_t (*write_iter)(struct kiocb___251 *, struct iov_iter___118 *);
	int (*iopoll)(struct kiocb___251 *, bool);
	int (*iterate)(struct file___251 *, struct dir_context *);
	int (*iterate_shared)(struct file___251 *, struct dir_context *);
	__poll_t (*poll)(struct file___251 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___251 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___251 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___251 *, struct vm_area_struct___252 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___251 *, struct file___251 *);
	int (*flush)(struct file___251 *, fl_owner_t);
	int (*release)(struct inode___251 *, struct file___251 *);
	int (*fsync)(struct file___251 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___251 *, int);
	int (*lock)(struct file___251 *, int, struct file_lock___251 *);
	ssize_t (*sendpage)(struct file___251 *, struct page___252 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___251 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___251 *, int, struct file_lock___251 *);
	ssize_t (*splice_write)(struct pipe_inode_info___61 *, struct file___251 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___251 *, loff_t *, struct pipe_inode_info___61 *, size_t, unsigned int);
	int (*setlease)(struct file___251 *, long int, struct file_lock___251 **, void **);
	long int (*fallocate)(struct file___251 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___225 *, struct file___251 *);
	ssize_t (*copy_file_range)(struct file___251 *, loff_t, struct file___251 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___251 *, loff_t, struct file___251 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___251 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___251 {
	u64 seqnum;
	struct vm_area_struct___252 *vmas[4];
};

struct page_frag___251 {
	struct page___252 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___251;

struct cred___243;

struct signal_struct___208;

struct vm_struct___168;

struct task_struct___252 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___252 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___251 *mm;
	struct mm_struct___251 *active_mm;
	struct vmacache___251 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___252 *real_parent;
	struct task_struct___252 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___252 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___188 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___188 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___188 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___243 *ptracer_cred;
	const struct cred___243 *real_cred;
	const struct cred___243 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___228 *nsproxy;
	struct signal_struct___208 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___252 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___60 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___61 *splice_pipe;
	struct page_frag___251 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___252 *oom_reaper_list;
	struct vm_struct___168 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___127 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___252 *pgtable_t___251;

struct address_space___250;

struct dev_pagemap___241;

struct page___252 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___250 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___252 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___251 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___251 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___241 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___251;

struct lruvec___251 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___251 *pgdat;
};

struct zone___251 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___251 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___251 {
	struct zone___251 *zone;
	int zone_idx;
};

struct zonelist___251 {
	struct zoneref___251 _zonerefs[25];
};

struct pglist_data___251 {
	struct zone___251 node_zones[3];
	struct zonelist___251 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___252 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___252 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___251 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___252 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___252 *owner;
};

struct secondary_data___252 {
	void *stack;
	struct task_struct___252 *task;
	long int status;
};

struct blocking_notifier_head___251 {
	struct rw_semaphore___252 rwsem;
	struct notifier_block *head;
};

struct key___243;

struct user_struct___243 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___243 *uid_keyring;
	struct key___243 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___241;

struct vm_area_struct___252 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___252 *vm_next;
	struct vm_area_struct___252 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___251 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___241 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___251 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___251;

struct mm_struct___251 {
	struct {
		struct vm_area_struct___252 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___251 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___252 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___251 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___252 *owner;
		struct user_namespace___3 *user_ns;
		struct file___251 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___251 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___243 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___243 *session_keyring;
	struct key___243 *process_keyring;
	struct key___243 *thread_keyring;
	struct key___243 *request_key_auth;
	void *security;
	struct user_struct___243 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct signal_struct___208 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___252 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___252 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___188 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___188 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___251 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___188 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct fasync_struct___250;

struct pipe_buffer___61;

struct pipe_inode_info___61 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___252 *tmp_page;
	struct fasync_struct___250 *fasync_readers;
	struct fasync_struct___250 *fasync_writers;
	struct pipe_buffer___61 *bufs;
	struct user_struct___243 *user;
};

struct vm_struct___168 {
	struct vm_struct___168 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___252 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___220 {
	struct task_struct___252 task;
	long unsigned int stack[8192];
};

struct address_space_operations___250;

struct address_space___250 {
	struct inode___251 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___252 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___250 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___241)(struct vm_area_struct___252 *, long unsigned int, const struct page___252 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___241)(struct page___252 *, void *);

struct device___215;

struct dev_pagemap___241 {
	dev_page_fault_t___241 page_fault;
	dev_page_free_t___241 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___215 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct dentry___251;

struct path___251 {
	struct vfsmount *mnt;
	struct dentry___251 *dentry;
};

struct file___251 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___251 f_path;
	struct inode___251 *f_inode;
	const struct file_operations___251 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___188 f_owner;
	const struct cred___243 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___250 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___241;

struct vm_operations_struct___241 {
	void (*open)(struct vm_area_struct___252 *);
	void (*close)(struct vm_area_struct___252 *);
	int (*split)(struct vm_area_struct___252 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___252 *);
	vm_fault_t (*fault)(struct vm_fault___241 *);
	vm_fault_t (*huge_fault)(struct vm_fault___241 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___241 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___252 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___241 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___241 *);
	int (*access)(struct vm_area_struct___252 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___252 *);
	int (*set_policy)(struct vm_area_struct___252 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___252 *, long unsigned int);
	struct page___252 * (*find_special_page)(struct vm_area_struct___252 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___251 {
	struct task_struct___252 *task;
	struct core_thread___251 *next;
};

struct core_state___251 {
	atomic_t nr_threads;
	struct core_thread___251 dumper;
	struct completion startup;
};

struct vm_fault___241 {
	struct vm_area_struct___252 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___252 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___252 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___251 prealloc_pte;
};

struct crypto_async_request___11;

typedef void (*crypto_completion_t___11)(struct crypto_async_request___11 *, int);

struct crypto_tfm___11;

struct crypto_async_request___11 {
	struct list_head list;
	crypto_completion_t___11 complete;
	void *data;
	struct crypto_tfm___11 *tfm;
	u32 flags;
};

struct crypto_ablkcipher___11;

struct ablkcipher_request___11;

struct ablkcipher_tfm___11 {
	int (*setkey)(struct crypto_ablkcipher___11 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___11 *);
	int (*decrypt)(struct ablkcipher_request___11 *);
	struct crypto_ablkcipher___11 *base;
	unsigned int ivsize;
	unsigned int reqsize;
};

struct blkcipher_desc___11;

struct blkcipher_tfm___11 {
	void *iv;
	int (*setkey)(struct crypto_tfm___11 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___11 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___11 *, struct scatterlist *, struct scatterlist *, unsigned int);
};

struct cipher_tfm___11 {
	int (*cit_setkey)(struct crypto_tfm___11 *, const u8 *, unsigned int);
	void (*cit_encrypt_one)(struct crypto_tfm___11 *, u8 *, const u8 *);
	void (*cit_decrypt_one)(struct crypto_tfm___11 *, u8 *, const u8 *);
};

struct compress_tfm___11 {
	int (*cot_compress)(struct crypto_tfm___11 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*cot_decompress)(struct crypto_tfm___11 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___11;

struct crypto_tfm___11 {
	u32 crt_flags;
	union {
		struct ablkcipher_tfm___11 ablkcipher;
		struct blkcipher_tfm___11 blkcipher;
		struct cipher_tfm___11 cipher;
		struct compress_tfm___11 compress;
	} crt_u;
	void (*exit)(struct crypto_tfm___11 *);
	struct crypto_alg___11 *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct ablkcipher_request___11 {
	struct crypto_async_request___11 base;
	unsigned int nbytes;
	void *info;
	struct scatterlist *src;
	struct scatterlist *dst;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_blkcipher___11;

struct blkcipher_desc___11 {
	struct crypto_blkcipher___11 *tfm;
	void *info;
	u32 flags;
};

struct crypto_blkcipher___11 {
	struct crypto_tfm___11 base;
};

struct skcipher_givcrypt_request___2;

struct ablkcipher_alg___11 {
	int (*setkey)(struct crypto_ablkcipher___11 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___11 *);
	int (*decrypt)(struct ablkcipher_request___11 *);
	int (*givencrypt)(struct skcipher_givcrypt_request___2 *);
	int (*givdecrypt)(struct skcipher_givcrypt_request___2 *);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct crypto_ablkcipher___11 {
	struct crypto_tfm___11 base;
};

struct skcipher_givcrypt_request___2 {
	u64 seq;
	u8 *giv;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ablkcipher_request___11 creq;
};

struct blkcipher_alg___11 {
	int (*setkey)(struct crypto_tfm___11 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___11 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___11 *, struct scatterlist *, struct scatterlist *, unsigned int);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct cipher_alg___11 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___11 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___11 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___11 *, u8 *, const u8 *);
};

struct compress_alg___11 {
	int (*coa_compress)(struct crypto_tfm___11 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___11 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_type___6;

struct crypto_alg___11 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type___6 *cra_type;
	union {
		struct ablkcipher_alg___11 ablkcipher;
		struct blkcipher_alg___11 blkcipher;
		struct cipher_alg___11 cipher;
		struct compress_alg___11 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___11 *);
	void (*cra_exit)(struct crypto_tfm___11 *);
	void (*cra_destroy)(struct crypto_alg___11 *);
	struct module___205 *cra_module;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct crypto_instance___6;

struct crypto_type___6 {
	unsigned int (*ctxsize)(struct crypto_alg___11 *, u32, u32);
	unsigned int (*extsize)(struct crypto_alg___11 *);
	int (*init)(struct crypto_tfm___11 *, u32, u32);
	int (*init_tfm)(struct crypto_tfm___11 *);
	void (*show)(struct seq_file___225 *, struct crypto_alg___11 *);
	int (*report)(struct sk_buff___6 *, struct crypto_alg___11 *);
	void (*free)(struct crypto_instance___6 *);
	unsigned int type;
	unsigned int maskclear;
	unsigned int maskset;
	unsigned int tfmsize;
};

struct kset___238;

struct kobj_type___238;

struct kernfs_node___246;

struct kobject___239 {
	const char *name;
	struct list_head entry;
	struct kobject___239 *parent;
	struct kset___238 *kset;
	struct kobj_type___238 *ktype;
	struct kernfs_node___246 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___202 {
	struct kobject___239 kobj;
	struct module___205 *mod;
	struct kobject___239 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___202 {
	struct module___205 *mod;
	struct latch_tree_node node;
};

struct module_layout___202 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___202 mtn;
};

struct module_attribute___202;

struct kernel_param___202;

struct module___205 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___202 mkobj;
	struct module_attribute___202 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___239 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___202 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___202 core_layout;
	struct module_layout___202 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct iov_iter___118 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___3 *bvec;
		struct pipe_inode_info___61 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct kiocb___251 {
	struct file___251 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___251 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dentry_operations___250;

struct super_block___250;

struct dentry___251 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___251 *d_parent;
	struct qstr d_name;
	struct inode___251 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___250 *d_op;
	struct super_block___250 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___250;

struct block_device___251;

struct inode___251 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___250 *i_op;
	struct super_block___250 *i_sb;
	struct address_space___250 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___252 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___251 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___250 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___61 *i_pipe;
		struct block_device___251 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___250 {
	int (*d_revalidate)(struct dentry___251 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___251 *, unsigned int);
	int (*d_hash)(const struct dentry___251 *, struct qstr *);
	int (*d_compare)(const struct dentry___251 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___251 *);
	int (*d_init)(struct dentry___251 *);
	void (*d_release)(struct dentry___251 *);
	void (*d_prune)(struct dentry___251 *);
	void (*d_iput)(struct dentry___251 *, struct inode___251 *);
	char * (*d_dname)(struct dentry___251 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___251 *);
	int (*d_manage)(const struct path___251 *, bool);
	struct dentry___251 * (*d_real)(struct dentry___251 *, const struct inode___251 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___250;

struct mem_dqinfo___250 {
	struct quota_format_type___250 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___250;

struct quota_info___250 {
	unsigned int flags;
	struct rw_semaphore___252 dqio_sem;
	struct inode___251 *files[3];
	struct mem_dqinfo___250 info[3];
	const struct quota_format_ops___250 *ops[3];
};

struct rcuwait___250 {
	struct task_struct___252 *task;
};

struct percpu_rw_semaphore___250 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___252 rw_sem;
	struct rcuwait___250 writer;
	int readers_block;
};

struct sb_writers___250 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___250 rw_sem[3];
};

struct file_system_type___250;

struct super_operations___250;

struct dquot_operations___250;

struct quotactl_ops___250;

struct super_block___250 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___250 *s_type;
	const struct super_operations___250 *s_op;
	const struct dquot_operations___250 *dq_op;
	const struct quotactl_ops___250 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___251 *s_root;
	struct rw_semaphore___252 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___251 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___250 s_dquot;
	struct sb_writers___250 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___250 *s_d_op;
	int cleancache_poolid;
	struct shrinker___109 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct iattr___250 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___251 *ia_file;
};

struct dquot___250 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___250 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___250 {
	int qf_fmt_id;
	const struct quota_format_ops___250 *qf_ops;
	struct module___205 *qf_owner;
	struct quota_format_type___250 *qf_next;
};

struct quota_format_ops___250 {
	int (*check_quota_file)(struct super_block___250 *, int);
	int (*read_file_info)(struct super_block___250 *, int);
	int (*write_file_info)(struct super_block___250 *, int);
	int (*free_file_info)(struct super_block___250 *, int);
	int (*read_dqblk)(struct dquot___250 *);
	int (*commit_dqblk)(struct dquot___250 *);
	int (*release_dqblk)(struct dquot___250 *);
	int (*get_next_id)(struct super_block___250 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___250 {
	int (*write_dquot)(struct dquot___250 *);
	struct dquot___250 * (*alloc_dquot)(struct super_block___250 *, int);
	void (*destroy_dquot)(struct dquot___250 *);
	int (*acquire_dquot)(struct dquot___250 *);
	int (*release_dquot)(struct dquot___250 *);
	int (*mark_dirty)(struct dquot___250 *);
	int (*write_info)(struct super_block___250 *, int);
	qsize_t * (*get_reserved_space)(struct inode___251 *);
	int (*get_projid)(struct inode___251 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___251 *, qsize_t *);
	int (*get_next_id)(struct super_block___250 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___250 {
	int (*quota_on)(struct super_block___250 *, int, int, const struct path___251 *);
	int (*quota_off)(struct super_block___250 *, int);
	int (*quota_enable)(struct super_block___250 *, unsigned int);
	int (*quota_disable)(struct super_block___250 *, unsigned int);
	int (*quota_sync)(struct super_block___250 *, int);
	int (*set_info)(struct super_block___250 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___250 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___250 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___250 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___250 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___250 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___250 {
	int (*writepage)(struct page___252 *, struct writeback_control___3 *);
	int (*readpage)(struct file___251 *, struct page___252 *);
	int (*writepages)(struct address_space___250 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___252 *);
	int (*readpages)(struct file___251 *, struct address_space___250 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___251 *, struct address_space___250 *, loff_t, unsigned int, unsigned int, struct page___252 **, void **);
	int (*write_end)(struct file___251 *, struct address_space___250 *, loff_t, unsigned int, unsigned int, struct page___252 *, void *);
	sector_t (*bmap)(struct address_space___250 *, sector_t);
	void (*invalidatepage)(struct page___252 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___252 *, gfp_t);
	void (*freepage)(struct page___252 *);
	ssize_t (*direct_IO)(struct kiocb___251 *, struct iov_iter___118 *);
	int (*migratepage)(struct address_space___250 *, struct page___252 *, struct page___252 *, enum migrate_mode);
	bool (*isolate_page)(struct page___252 *, isolate_mode_t);
	void (*putback_page)(struct page___252 *);
	int (*launder_page)(struct page___252 *);
	int (*is_partially_uptodate)(struct page___252 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___252 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___250 *, struct page___252 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___251 *, sector_t *);
	void (*swap_deactivate)(struct file___251 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___251 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___251 *bd_inode;
	struct super_block___250 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___251 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___250 {
	struct dentry___251 * (*lookup)(struct inode___251 *, struct dentry___251 *, unsigned int);
	const char * (*get_link)(struct dentry___251 *, struct inode___251 *, struct delayed_call *);
	int (*permission)(struct inode___251 *, int);
	struct posix_acl * (*get_acl)(struct inode___251 *, int);
	int (*readlink)(struct dentry___251 *, char *, int);
	int (*create)(struct inode___251 *, struct dentry___251 *, umode_t, bool);
	int (*link)(struct dentry___251 *, struct inode___251 *, struct dentry___251 *);
	int (*unlink)(struct inode___251 *, struct dentry___251 *);
	int (*symlink)(struct inode___251 *, struct dentry___251 *, const char *);
	int (*mkdir)(struct inode___251 *, struct dentry___251 *, umode_t);
	int (*rmdir)(struct inode___251 *, struct dentry___251 *);
	int (*mknod)(struct inode___251 *, struct dentry___251 *, umode_t, dev_t);
	int (*rename)(struct inode___251 *, struct dentry___251 *, struct inode___251 *, struct dentry___251 *, unsigned int);
	int (*setattr)(struct dentry___251 *, struct iattr___250 *);
	int (*getattr)(const struct path___251 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___251 *, char *, size_t);
	int (*fiemap)(struct inode___251 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___251 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___251 *, struct dentry___251 *, struct file___251 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___251 *, struct dentry___251 *, umode_t);
	int (*set_acl)(struct inode___251 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___250 {
	void (*fl_copy_lock)(struct file_lock___251 *, struct file_lock___251 *);
	void (*fl_release_private)(struct file_lock___251 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___250;

struct file_lock___251 {
	struct file_lock___251 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___251 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___250 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___250 *fl_ops;
	const struct lock_manager_operations___250 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___250 {
	int (*lm_compare_owner)(struct file_lock___251 *, struct file_lock___251 *);
	long unsigned int (*lm_owner_key)(struct file_lock___251 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___251 *);
	int (*lm_grant)(struct file_lock___251 *, int);
	bool (*lm_break)(struct file_lock___251 *);
	int (*lm_change)(struct file_lock___251 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___251 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___250 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___250 *fa_next;
	struct file___251 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___250 {
	const char *name;
	int fs_flags;
	struct dentry___251 * (*mount)(struct file_system_type___250 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___250 *);
	struct module___205 *owner;
	struct file_system_type___250 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___250 {
	struct inode___251 * (*alloc_inode)(struct super_block___250 *);
	void (*destroy_inode)(struct inode___251 *);
	void (*dirty_inode)(struct inode___251 *, int);
	int (*write_inode)(struct inode___251 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___251 *);
	void (*evict_inode)(struct inode___251 *);
	void (*put_super)(struct super_block___250 *);
	int (*sync_fs)(struct super_block___250 *, int);
	int (*freeze_super)(struct super_block___250 *);
	int (*freeze_fs)(struct super_block___250 *);
	int (*thaw_super)(struct super_block___250 *);
	int (*unfreeze_fs)(struct super_block___250 *);
	int (*statfs)(struct dentry___251 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___250 *, int *, char *);
	void (*umount_begin)(struct super_block___250 *);
	int (*show_options)(struct seq_file___225 *, struct dentry___251 *);
	int (*show_devname)(struct seq_file___225 *, struct dentry___251 *);
	int (*show_path)(struct seq_file___225 *, struct dentry___251 *);
	int (*show_stats)(struct seq_file___225 *, struct dentry___251 *);
	ssize_t (*quota_read)(struct super_block___250 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___250 *, int, const char *, size_t, loff_t);
	struct dquot___250 ** (*get_dquots)(struct inode___251 *);
	int (*bdev_try_to_free_page)(struct super_block___250 *, struct page___252 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___250 *, struct shrink_control___109 *);
	long int (*free_cached_objects)(struct super_block___250 *, struct shrink_control___109 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___223;

struct seq_file___225 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___223 *op;
	int poll_event;
	const struct file___251 *file;
	void *private;
};

struct kernfs_root___245;

struct kernfs_elem_dir___245 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___245 *root;
};

struct kernfs_syscall_ops___245;

struct kernfs_root___245 {
	struct kernfs_node___246 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___245 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___245 {
	struct kernfs_node___246 *target_kn;
};

struct kernfs_ops___245;

struct kernfs_elem_attr___245 {
	const struct kernfs_ops___245 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___246 *notify_next;
};

struct kernfs_node___246 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___246 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___245 dir;
		struct kernfs_elem_symlink___245 symlink;
		struct kernfs_elem_attr___245 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___245;

struct kernfs_ops___245 {
	int (*open)(struct kernfs_open_file___245 *);
	void (*release)(struct kernfs_open_file___245 *);
	int (*seq_show)(struct seq_file___225 *, void *);
	void * (*seq_start)(struct seq_file___225 *, loff_t *);
	void * (*seq_next)(struct seq_file___225 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___225 *, void *);
	ssize_t (*read)(struct kernfs_open_file___245 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___245 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___245 *, struct vm_area_struct___252 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___245 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___245 {
	int (*remount_fs)(struct kernfs_root___245 *, int *, char *);
	int (*show_options)(struct seq_file___225 *, struct kernfs_root___245 *);
	int (*mkdir)(struct kernfs_node___246 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___246 *);
	int (*rename)(struct kernfs_node___246 *, struct kernfs_node___246 *, const char *);
	int (*show_path)(struct seq_file___225 *, struct kernfs_node___246 *, struct kernfs_root___245 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___245 {
	struct kernfs_node___246 *kn;
	struct file___251 *file;
	struct seq_file___225 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___241 *vm_ops;
};

struct bin_attribute___216;

struct attribute_group___217 {
	const char *name;
	umode_t (*is_visible)(struct kobject___239 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___239 *, struct bin_attribute___216 *, int);
	struct attribute **attrs;
	struct bin_attribute___216 **bin_attrs;
};

struct bin_attribute___216 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___251 *, struct kobject___239 *, struct bin_attribute___216 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___251 *, struct kobject___239 *, struct bin_attribute___216 *, char *, loff_t, size_t);
	int (*mmap)(struct file___251 *, struct kobject___239 *, struct bin_attribute___216 *, struct vm_area_struct___252 *);
};

struct sysfs_ops___238 {
	ssize_t (*show)(struct kobject___239 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___239 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___238;

struct kset___238 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___239 kobj;
	const struct kset_uevent_ops___238 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___238 {
	void (*release)(struct kobject___239 *);
	const struct sysfs_ops___238 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___23 * (*child_ns_type)(struct kobject___239 *);
	const void * (*namespace)(struct kobject___239 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___238 {
	int (* const filter)(struct kset___238 *, struct kobject___239 *);
	const char * (* const name)(struct kset___238 *, struct kobject___239 *);
	int (* const uevent)(struct kset___238 *, struct kobject___239 *, struct kobj_uevent_env *);
};

struct kobj_attribute___232 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___239 *, struct kobj_attribute___232 *, char *);
	ssize_t (*store)(struct kobject___239 *, struct kobj_attribute___232 *, const char *, size_t);
};

struct dev_pm_ops___215 {
	int (*prepare)(struct device___215 *);
	void (*complete)(struct device___215 *);
	int (*suspend)(struct device___215 *);
	int (*resume)(struct device___215 *);
	int (*freeze)(struct device___215 *);
	int (*thaw)(struct device___215 *);
	int (*poweroff)(struct device___215 *);
	int (*restore)(struct device___215 *);
	int (*suspend_late)(struct device___215 *);
	int (*resume_early)(struct device___215 *);
	int (*freeze_late)(struct device___215 *);
	int (*thaw_early)(struct device___215 *);
	int (*poweroff_late)(struct device___215 *);
	int (*restore_early)(struct device___215 *);
	int (*suspend_noirq)(struct device___215 *);
	int (*resume_noirq)(struct device___215 *);
	int (*freeze_noirq)(struct device___215 *);
	int (*thaw_noirq)(struct device___215 *);
	int (*poweroff_noirq)(struct device___215 *);
	int (*restore_noirq)(struct device___215 *);
	int (*runtime_suspend)(struct device___215 *);
	int (*runtime_resume)(struct device___215 *);
	int (*runtime_idle)(struct device___215 *);
};

struct dev_pm_info___215 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___215 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___215;

struct bus_type___215;

struct device_driver___215;

struct dev_pm_domain___215;

struct dma_map_ops___58;

struct fwnode_handle___150;

struct class___215;

struct device___215 {
	struct device___215 *parent;
	struct device_private *p;
	struct kobject___239 kobj;
	const char *init_name;
	const struct device_type___215 *type;
	struct mutex mutex;
	struct bus_type___215 *bus;
	struct device_driver___215 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___215 power;
	struct dev_pm_domain___215 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___58 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___150 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___215 *class;
	const struct attribute_group___217 **groups;
	void (*release)(struct device___215 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___215 {
	struct dev_pm_ops___215 ops;
	void (*detach)(struct device___215 *, bool);
	int (*activate)(struct device___215 *);
	void (*sync)(struct device___215 *);
	void (*dismiss)(struct device___215 *);
};

struct bus_type___215 {
	const char *name;
	const char *dev_name;
	struct device___215 *dev_root;
	const struct attribute_group___217 **bus_groups;
	const struct attribute_group___217 **dev_groups;
	const struct attribute_group___217 **drv_groups;
	int (*match)(struct device___215 *, struct device_driver___215 *);
	int (*uevent)(struct device___215 *, struct kobj_uevent_env *);
	int (*probe)(struct device___215 *);
	int (*remove)(struct device___215 *);
	void (*shutdown)(struct device___215 *);
	int (*online)(struct device___215 *);
	int (*offline)(struct device___215 *);
	int (*suspend)(struct device___215 *, pm_message_t);
	int (*resume)(struct device___215 *);
	int (*num_vf)(struct device___215 *);
	int (*dma_configure)(struct device___215 *);
	const struct dev_pm_ops___215 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___215 {
	const char *name;
	struct bus_type___215 *bus;
	struct module___205 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___215 *);
	int (*remove)(struct device___215 *);
	void (*shutdown)(struct device___215 *);
	int (*suspend)(struct device___215 *, pm_message_t);
	int (*resume)(struct device___215 *);
	const struct attribute_group___217 **groups;
	const struct dev_pm_ops___215 *pm;
	void (*coredump)(struct device___215 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___215 {
	const char *name;
	const struct attribute_group___217 **groups;
	int (*uevent)(struct device___215 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___215 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___215 *);
	const struct dev_pm_ops___215 *pm;
};

struct class___215 {
	const char *name;
	struct module___205 *owner;
	const struct attribute_group___217 **class_groups;
	const struct attribute_group___217 **dev_groups;
	struct kobject___239 *dev_kobj;
	int (*dev_uevent)(struct device___215 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___215 *, umode_t *);
	void (*class_release)(struct class___215 *);
	void (*dev_release)(struct device___215 *);
	int (*shutdown_pre)(struct device___215 *);
	const struct kobj_ns_type_operations___23 *ns_type;
	const void * (*namespace)(struct device___215 *);
	const struct dev_pm_ops___215 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___58 {
	void * (*alloc)(struct device___215 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___215 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___215 *, struct vm_area_struct___252 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___215 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___215 *, struct page___252 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___215 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___215 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___215 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___215 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___215 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___215 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___215 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___215 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___215 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___215 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___215 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___215 *, u64);
	u64 (*get_required_mask)(struct device___215 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___150;

struct fwnode_handle___150 {
	struct fwnode_handle___150 *secondary;
	const struct fwnode_operations___150 *ops;
};

typedef void compound_page_dtor___241(struct page___252 *);

struct fwnode_reference_args___150;

struct fwnode_endpoint___150;

struct fwnode_operations___150 {
	struct fwnode_handle___150 * (*get)(struct fwnode_handle___150 *);
	void (*put)(struct fwnode_handle___150 *);
	bool (*device_is_available)(const struct fwnode_handle___150 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___150 *, const struct device___215 *);
	bool (*property_present)(const struct fwnode_handle___150 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___150 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___150 *, const char *, const char **, size_t);
	struct fwnode_handle___150 * (*get_parent)(const struct fwnode_handle___150 *);
	struct fwnode_handle___150 * (*get_next_child_node)(const struct fwnode_handle___150 *, struct fwnode_handle___150 *);
	struct fwnode_handle___150 * (*get_named_child_node)(const struct fwnode_handle___150 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___150 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___150 *);
	struct fwnode_handle___150 * (*graph_get_next_endpoint)(const struct fwnode_handle___150 *, struct fwnode_handle___150 *);
	struct fwnode_handle___150 * (*graph_get_remote_endpoint)(const struct fwnode_handle___150 *);
	struct fwnode_handle___150 * (*graph_get_port_parent)(struct fwnode_handle___150 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___150 *, struct fwnode_endpoint___150 *);
};

struct fwnode_endpoint___150 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___150 *local_fwnode;
};

struct fwnode_reference_args___150 {
	struct fwnode_handle___150 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___61;

struct pipe_buffer___61 {
	struct page___252 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___61 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___61 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___61 *, struct pipe_buffer___61 *);
	void (*release)(struct pipe_inode_info___61 *, struct pipe_buffer___61 *);
	int (*steal)(struct pipe_inode_info___61 *, struct pipe_buffer___61 *);
	union {
		bool (*get)(struct pipe_inode_info___61 *, struct pipe_buffer___61 *);
		struct {
			void (*get)(struct pipe_inode_info___61 *, struct pipe_buffer___61 *);
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
};

struct crypto_template___6;

struct crypto_instance___6 {
	struct crypto_alg___11 alg;
	struct crypto_template___6 *tmpl;
	struct hlist_node list;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_template___6 {
	struct list_head list;
	struct hlist_head instances;
	struct module___205 *module;
	struct crypto_instance___6 * (*alloc)(struct rtattr **);
	void (*free)(struct crypto_instance___6 *);
	int (*create)(struct crypto_template___6 *, struct rtattr **);
	char name[128];
};

struct ablkcipher_walk {
	struct {
		struct page___252 *page;
		unsigned int offset;
	} src;
	struct {
		struct page___252 *page;
		unsigned int offset;
	} dst;
	struct scatter_walk in;
	unsigned int nbytes;
	struct scatter_walk out;
	unsigned int total;
	struct list_head buffers;
	u8 *iv_buffer;
	u8 *iv;
	int flags;
	unsigned int blocksize;
};

typedef int (*key_restrict_link_func_t___244)(struct key___243 *, const struct key_type *, const union key_payload *, struct key___243 *);

struct key_restriction___243;

struct key___243 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___252 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key___5 index_key;
		struct {
			struct key_type___5 *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___243 *restrict_link;
};

struct key_restriction___243 {
	key_restrict_link_func_t___244 check;
	struct key___243 *key;
	struct key_type *keytype;
};

struct seq_operations___223 {
	void * (*start)(struct seq_file___225 *, loff_t *);
	void (*stop)(struct seq_file___225 *, void *);
	void * (*next)(struct seq_file___225 *, void *, loff_t *);
	int (*show)(struct seq_file___225 *, void *);
};

struct crypto_report_blkcipher {
	char type[64];
	char geniv[64];
	unsigned int blocksize;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct kernel_param_ops___202 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___202 *);
	int (*get)(char *, const struct kernel_param___202 *);
	void (*free)(void *);
};

struct kparam_array___202;

struct kernel_param___202 {
	const char *name;
	struct module___205 *mod;
	const struct kernel_param_ops___202 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___202 *arr;
	};
};

struct kparam_array___202 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___202 *ops;
	void *elem;
};

struct module_attribute___202 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___202 *, struct module_kobject___202 *, char *);
	ssize_t (*store)(struct module_attribute___202 *, struct module_kobject___202 *, const char *, size_t);
	void (*setup)(struct module___205 *, const char *);
	int (*test)(struct module___205 *);
	void (*free)(struct module___205 *);
};

struct ablkcipher_buffer {
	struct list_head entry;
	struct scatter_walk dst;
	unsigned int len;
	void *data;
};

enum {
	ABLKCIPHER_WALK_SLOW = 1,
};

struct module___206;

struct file___252;

struct kiocb___252;

struct iov_iter___119;

struct vm_area_struct___253;

struct inode___252;

struct file_lock___252;

struct page___253;

struct pipe_inode_info___62;

struct seq_file___226;

struct file_operations___252 {
	struct module___206 *owner;
	loff_t (*llseek)(struct file___252 *, loff_t, int);
	ssize_t (*read)(struct file___252 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___252 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___252 *, struct iov_iter___119 *);
	ssize_t (*write_iter)(struct kiocb___252 *, struct iov_iter___119 *);
	int (*iopoll)(struct kiocb___252 *, bool);
	int (*iterate)(struct file___252 *, struct dir_context *);
	int (*iterate_shared)(struct file___252 *, struct dir_context *);
	__poll_t (*poll)(struct file___252 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___252 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___252 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___252 *, struct vm_area_struct___253 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___252 *, struct file___252 *);
	int (*flush)(struct file___252 *, fl_owner_t);
	int (*release)(struct inode___252 *, struct file___252 *);
	int (*fsync)(struct file___252 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___252 *, int);
	int (*lock)(struct file___252 *, int, struct file_lock___252 *);
	ssize_t (*sendpage)(struct file___252 *, struct page___253 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___252 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___252 *, int, struct file_lock___252 *);
	ssize_t (*splice_write)(struct pipe_inode_info___62 *, struct file___252 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___252 *, loff_t *, struct pipe_inode_info___62 *, size_t, unsigned int);
	int (*setlease)(struct file___252 *, long int, struct file_lock___252 **, void **);
	long int (*fallocate)(struct file___252 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___226 *, struct file___252 *);
	ssize_t (*copy_file_range)(struct file___252 *, loff_t, struct file___252 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___252 *, loff_t, struct file___252 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___252 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___252 {
	u64 seqnum;
	struct vm_area_struct___253 *vmas[4];
};

struct page_frag___252 {
	struct page___253 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___252;

struct cred___244;

struct signal_struct___209;

struct vm_struct___169;

struct task_struct___253 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___253 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___252 *mm;
	struct mm_struct___252 *active_mm;
	struct vmacache___252 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___253 *real_parent;
	struct task_struct___253 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___253 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___188 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___188 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___188 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___244 *ptracer_cred;
	const struct cred___244 *real_cred;
	const struct cred___244 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___228 *nsproxy;
	struct signal_struct___209 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___253 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___60 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___62 *splice_pipe;
	struct page_frag___252 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___253 *oom_reaper_list;
	struct vm_struct___169 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___127 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___253 *pgtable_t___252;

struct address_space___251;

struct dev_pagemap___242;

struct page___253 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___251 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___253 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___252 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___252 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___242 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___252;

struct lruvec___252 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___252 *pgdat;
};

struct zone___252 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___252 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___252 {
	struct zone___252 *zone;
	int zone_idx;
};

struct zonelist___252 {
	struct zoneref___252 _zonerefs[25];
};

struct pglist_data___252 {
	struct zone___252 node_zones[3];
	struct zonelist___252 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___253 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___253 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___252 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___253 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___253 *owner;
};

struct secondary_data___253 {
	void *stack;
	struct task_struct___253 *task;
	long int status;
};

struct blocking_notifier_head___252 {
	struct rw_semaphore___253 rwsem;
	struct notifier_block *head;
};

struct key___244;

struct user_struct___244 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___244 *uid_keyring;
	struct key___244 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___242;

struct vm_area_struct___253 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___253 *vm_next;
	struct vm_area_struct___253 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___252 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___242 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___252 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___252;

struct mm_struct___252 {
	struct {
		struct vm_area_struct___253 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___252 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___253 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___252 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___253 *owner;
		struct user_namespace___3 *user_ns;
		struct file___252 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___252 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___244 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___244 *session_keyring;
	struct key___244 *process_keyring;
	struct key___244 *thread_keyring;
	struct key___244 *request_key_auth;
	void *security;
	struct user_struct___244 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct signal_struct___209 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___253 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___253 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___188 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___188 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___252 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___188 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct fasync_struct___251;

struct pipe_buffer___62;

struct pipe_inode_info___62 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___253 *tmp_page;
	struct fasync_struct___251 *fasync_readers;
	struct fasync_struct___251 *fasync_writers;
	struct pipe_buffer___62 *bufs;
	struct user_struct___244 *user;
};

struct vm_struct___169 {
	struct vm_struct___169 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___253 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___221 {
	struct task_struct___253 task;
	long unsigned int stack[8192];
};

struct address_space_operations___251;

struct address_space___251 {
	struct inode___252 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___253 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___251 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___242)(struct vm_area_struct___253 *, long unsigned int, const struct page___253 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___242)(struct page___253 *, void *);

struct device___216;

struct dev_pagemap___242 {
	dev_page_fault_t___242 page_fault;
	dev_page_free_t___242 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___216 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct dentry___252;

struct path___252 {
	struct vfsmount *mnt;
	struct dentry___252 *dentry;
};

struct file___252 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___252 f_path;
	struct inode___252 *f_inode;
	const struct file_operations___252 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___188 f_owner;
	const struct cred___244 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___251 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___242;

struct vm_operations_struct___242 {
	void (*open)(struct vm_area_struct___253 *);
	void (*close)(struct vm_area_struct___253 *);
	int (*split)(struct vm_area_struct___253 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___253 *);
	vm_fault_t (*fault)(struct vm_fault___242 *);
	vm_fault_t (*huge_fault)(struct vm_fault___242 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___242 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___253 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___242 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___242 *);
	int (*access)(struct vm_area_struct___253 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___253 *);
	int (*set_policy)(struct vm_area_struct___253 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___253 *, long unsigned int);
	struct page___253 * (*find_special_page)(struct vm_area_struct___253 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___252 {
	struct task_struct___253 *task;
	struct core_thread___252 *next;
};

struct core_state___252 {
	atomic_t nr_threads;
	struct core_thread___252 dumper;
	struct completion startup;
};

struct vm_fault___242 {
	struct vm_area_struct___253 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___253 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___253 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___252 prealloc_pte;
};

struct crypto_async_request___12;

typedef void (*crypto_completion_t___12)(struct crypto_async_request___12 *, int);

struct crypto_tfm___12;

struct crypto_async_request___12 {
	struct list_head list;
	crypto_completion_t___12 complete;
	void *data;
	struct crypto_tfm___12 *tfm;
	u32 flags;
};

struct crypto_ablkcipher___12;

struct ablkcipher_request___12;

struct ablkcipher_tfm___12 {
	int (*setkey)(struct crypto_ablkcipher___12 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___12 *);
	int (*decrypt)(struct ablkcipher_request___12 *);
	struct crypto_ablkcipher___12 *base;
	unsigned int ivsize;
	unsigned int reqsize;
};

struct blkcipher_desc___12;

struct blkcipher_tfm___12 {
	void *iv;
	int (*setkey)(struct crypto_tfm___12 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___12 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___12 *, struct scatterlist *, struct scatterlist *, unsigned int);
};

struct cipher_tfm___12 {
	int (*cit_setkey)(struct crypto_tfm___12 *, const u8 *, unsigned int);
	void (*cit_encrypt_one)(struct crypto_tfm___12 *, u8 *, const u8 *);
	void (*cit_decrypt_one)(struct crypto_tfm___12 *, u8 *, const u8 *);
};

struct compress_tfm___12 {
	int (*cot_compress)(struct crypto_tfm___12 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*cot_decompress)(struct crypto_tfm___12 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___12;

struct crypto_tfm___12 {
	u32 crt_flags;
	union {
		struct ablkcipher_tfm___12 ablkcipher;
		struct blkcipher_tfm___12 blkcipher;
		struct cipher_tfm___12 cipher;
		struct compress_tfm___12 compress;
	} crt_u;
	void (*exit)(struct crypto_tfm___12 *);
	struct crypto_alg___12 *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct ablkcipher_request___12 {
	struct crypto_async_request___12 base;
	unsigned int nbytes;
	void *info;
	struct scatterlist *src;
	struct scatterlist *dst;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_blkcipher___12;

struct blkcipher_desc___12 {
	struct crypto_blkcipher___12 *tfm;
	void *info;
	u32 flags;
};

struct crypto_blkcipher___12 {
	struct crypto_tfm___12 base;
};

struct skcipher_givcrypt_request___3;

struct ablkcipher_alg___12 {
	int (*setkey)(struct crypto_ablkcipher___12 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___12 *);
	int (*decrypt)(struct ablkcipher_request___12 *);
	int (*givencrypt)(struct skcipher_givcrypt_request___3 *);
	int (*givdecrypt)(struct skcipher_givcrypt_request___3 *);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct crypto_ablkcipher___12 {
	struct crypto_tfm___12 base;
};

struct skcipher_givcrypt_request___3 {
	u64 seq;
	u8 *giv;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ablkcipher_request___12 creq;
};

struct blkcipher_alg___12 {
	int (*setkey)(struct crypto_tfm___12 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___12 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___12 *, struct scatterlist *, struct scatterlist *, unsigned int);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct cipher_alg___12 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___12 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___12 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___12 *, u8 *, const u8 *);
};

struct compress_alg___12 {
	int (*coa_compress)(struct crypto_tfm___12 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___12 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_type___7;

struct crypto_alg___12 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type___7 *cra_type;
	union {
		struct ablkcipher_alg___12 ablkcipher;
		struct blkcipher_alg___12 blkcipher;
		struct cipher_alg___12 cipher;
		struct compress_alg___12 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___12 *);
	void (*cra_exit)(struct crypto_tfm___12 *);
	void (*cra_destroy)(struct crypto_alg___12 *);
	struct module___206 *cra_module;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct crypto_instance___7;

struct crypto_type___7 {
	unsigned int (*ctxsize)(struct crypto_alg___12 *, u32, u32);
	unsigned int (*extsize)(struct crypto_alg___12 *);
	int (*init)(struct crypto_tfm___12 *, u32, u32);
	int (*init_tfm)(struct crypto_tfm___12 *);
	void (*show)(struct seq_file___226 *, struct crypto_alg___12 *);
	int (*report)(struct sk_buff___6 *, struct crypto_alg___12 *);
	void (*free)(struct crypto_instance___7 *);
	unsigned int type;
	unsigned int maskclear;
	unsigned int maskset;
	unsigned int tfmsize;
};

struct kset___239;

struct kobj_type___239;

struct kernfs_node___247;

struct kobject___240 {
	const char *name;
	struct list_head entry;
	struct kobject___240 *parent;
	struct kset___239 *kset;
	struct kobj_type___239 *ktype;
	struct kernfs_node___247 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___203 {
	struct kobject___240 kobj;
	struct module___206 *mod;
	struct kobject___240 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___203 {
	struct module___206 *mod;
	struct latch_tree_node node;
};

struct module_layout___203 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___203 mtn;
};

struct module_attribute___203;

struct kernel_param___203;

struct module___206 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___203 mkobj;
	struct module_attribute___203 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___240 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___203 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___203 core_layout;
	struct module_layout___203 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct aead_request___3 {
	struct crypto_async_request___12 base;
	unsigned int assoclen;
	unsigned int cryptlen;
	u8 *iv;
	struct scatterlist *src;
	struct scatterlist *dst;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_aead___3;

struct aead_alg___3 {
	int (*setkey)(struct crypto_aead___3 *, const u8 *, unsigned int);
	int (*setauthsize)(struct crypto_aead___3 *, unsigned int);
	int (*encrypt)(struct aead_request___3 *);
	int (*decrypt)(struct aead_request___3 *);
	int (*init)(struct crypto_aead___3 *);
	void (*exit)(struct crypto_aead___3 *);
	const char *geniv;
	unsigned int ivsize;
	unsigned int maxauthsize;
	unsigned int chunksize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_alg___12 base;
};

struct crypto_aead___3 {
	unsigned int authsize;
	unsigned int reqsize;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_tfm___12 base;
};

struct iov_iter___119 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___3 *bvec;
		struct pipe_inode_info___62 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct kiocb___252 {
	struct file___252 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___252 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dentry_operations___251;

struct super_block___251;

struct dentry___252 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___252 *d_parent;
	struct qstr d_name;
	struct inode___252 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___251 *d_op;
	struct super_block___251 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___251;

struct block_device___252;

struct inode___252 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___251 *i_op;
	struct super_block___251 *i_sb;
	struct address_space___251 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___253 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___252 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___251 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___62 *i_pipe;
		struct block_device___252 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___251 {
	int (*d_revalidate)(struct dentry___252 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___252 *, unsigned int);
	int (*d_hash)(const struct dentry___252 *, struct qstr *);
	int (*d_compare)(const struct dentry___252 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___252 *);
	int (*d_init)(struct dentry___252 *);
	void (*d_release)(struct dentry___252 *);
	void (*d_prune)(struct dentry___252 *);
	void (*d_iput)(struct dentry___252 *, struct inode___252 *);
	char * (*d_dname)(struct dentry___252 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___252 *);
	int (*d_manage)(const struct path___252 *, bool);
	struct dentry___252 * (*d_real)(struct dentry___252 *, const struct inode___252 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___251;

struct mem_dqinfo___251 {
	struct quota_format_type___251 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___251;

struct quota_info___251 {
	unsigned int flags;
	struct rw_semaphore___253 dqio_sem;
	struct inode___252 *files[3];
	struct mem_dqinfo___251 info[3];
	const struct quota_format_ops___251 *ops[3];
};

struct rcuwait___251 {
	struct task_struct___253 *task;
};

struct percpu_rw_semaphore___251 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___253 rw_sem;
	struct rcuwait___251 writer;
	int readers_block;
};

struct sb_writers___251 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___251 rw_sem[3];
};

struct file_system_type___251;

struct super_operations___251;

struct dquot_operations___251;

struct quotactl_ops___251;

struct super_block___251 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___251 *s_type;
	const struct super_operations___251 *s_op;
	const struct dquot_operations___251 *dq_op;
	const struct quotactl_ops___251 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___252 *s_root;
	struct rw_semaphore___253 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___252 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___251 s_dquot;
	struct sb_writers___251 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___251 *s_d_op;
	int cleancache_poolid;
	struct shrinker___109 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct iattr___251 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___252 *ia_file;
};

struct dquot___251 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___251 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___251 {
	int qf_fmt_id;
	const struct quota_format_ops___251 *qf_ops;
	struct module___206 *qf_owner;
	struct quota_format_type___251 *qf_next;
};

struct quota_format_ops___251 {
	int (*check_quota_file)(struct super_block___251 *, int);
	int (*read_file_info)(struct super_block___251 *, int);
	int (*write_file_info)(struct super_block___251 *, int);
	int (*free_file_info)(struct super_block___251 *, int);
	int (*read_dqblk)(struct dquot___251 *);
	int (*commit_dqblk)(struct dquot___251 *);
	int (*release_dqblk)(struct dquot___251 *);
	int (*get_next_id)(struct super_block___251 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___251 {
	int (*write_dquot)(struct dquot___251 *);
	struct dquot___251 * (*alloc_dquot)(struct super_block___251 *, int);
	void (*destroy_dquot)(struct dquot___251 *);
	int (*acquire_dquot)(struct dquot___251 *);
	int (*release_dquot)(struct dquot___251 *);
	int (*mark_dirty)(struct dquot___251 *);
	int (*write_info)(struct super_block___251 *, int);
	qsize_t * (*get_reserved_space)(struct inode___252 *);
	int (*get_projid)(struct inode___252 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___252 *, qsize_t *);
	int (*get_next_id)(struct super_block___251 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___251 {
	int (*quota_on)(struct super_block___251 *, int, int, const struct path___252 *);
	int (*quota_off)(struct super_block___251 *, int);
	int (*quota_enable)(struct super_block___251 *, unsigned int);
	int (*quota_disable)(struct super_block___251 *, unsigned int);
	int (*quota_sync)(struct super_block___251 *, int);
	int (*set_info)(struct super_block___251 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___251 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___251 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___251 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___251 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___251 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___251 {
	int (*writepage)(struct page___253 *, struct writeback_control___3 *);
	int (*readpage)(struct file___252 *, struct page___253 *);
	int (*writepages)(struct address_space___251 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___253 *);
	int (*readpages)(struct file___252 *, struct address_space___251 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___252 *, struct address_space___251 *, loff_t, unsigned int, unsigned int, struct page___253 **, void **);
	int (*write_end)(struct file___252 *, struct address_space___251 *, loff_t, unsigned int, unsigned int, struct page___253 *, void *);
	sector_t (*bmap)(struct address_space___251 *, sector_t);
	void (*invalidatepage)(struct page___253 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___253 *, gfp_t);
	void (*freepage)(struct page___253 *);
	ssize_t (*direct_IO)(struct kiocb___252 *, struct iov_iter___119 *);
	int (*migratepage)(struct address_space___251 *, struct page___253 *, struct page___253 *, enum migrate_mode);
	bool (*isolate_page)(struct page___253 *, isolate_mode_t);
	void (*putback_page)(struct page___253 *);
	int (*launder_page)(struct page___253 *);
	int (*is_partially_uptodate)(struct page___253 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___253 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___251 *, struct page___253 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___252 *, sector_t *);
	void (*swap_deactivate)(struct file___252 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___252 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___252 *bd_inode;
	struct super_block___251 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___252 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___251 {
	struct dentry___252 * (*lookup)(struct inode___252 *, struct dentry___252 *, unsigned int);
	const char * (*get_link)(struct dentry___252 *, struct inode___252 *, struct delayed_call *);
	int (*permission)(struct inode___252 *, int);
	struct posix_acl * (*get_acl)(struct inode___252 *, int);
	int (*readlink)(struct dentry___252 *, char *, int);
	int (*create)(struct inode___252 *, struct dentry___252 *, umode_t, bool);
	int (*link)(struct dentry___252 *, struct inode___252 *, struct dentry___252 *);
	int (*unlink)(struct inode___252 *, struct dentry___252 *);
	int (*symlink)(struct inode___252 *, struct dentry___252 *, const char *);
	int (*mkdir)(struct inode___252 *, struct dentry___252 *, umode_t);
	int (*rmdir)(struct inode___252 *, struct dentry___252 *);
	int (*mknod)(struct inode___252 *, struct dentry___252 *, umode_t, dev_t);
	int (*rename)(struct inode___252 *, struct dentry___252 *, struct inode___252 *, struct dentry___252 *, unsigned int);
	int (*setattr)(struct dentry___252 *, struct iattr___251 *);
	int (*getattr)(const struct path___252 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___252 *, char *, size_t);
	int (*fiemap)(struct inode___252 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___252 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___252 *, struct dentry___252 *, struct file___252 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___252 *, struct dentry___252 *, umode_t);
	int (*set_acl)(struct inode___252 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___251 {
	void (*fl_copy_lock)(struct file_lock___252 *, struct file_lock___252 *);
	void (*fl_release_private)(struct file_lock___252 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___251;

struct file_lock___252 {
	struct file_lock___252 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___252 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___251 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___251 *fl_ops;
	const struct lock_manager_operations___251 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___251 {
	int (*lm_compare_owner)(struct file_lock___252 *, struct file_lock___252 *);
	long unsigned int (*lm_owner_key)(struct file_lock___252 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___252 *);
	int (*lm_grant)(struct file_lock___252 *, int);
	bool (*lm_break)(struct file_lock___252 *);
	int (*lm_change)(struct file_lock___252 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___252 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___251 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___251 *fa_next;
	struct file___252 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___251 {
	const char *name;
	int fs_flags;
	struct dentry___252 * (*mount)(struct file_system_type___251 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___251 *);
	struct module___206 *owner;
	struct file_system_type___251 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___251 {
	struct inode___252 * (*alloc_inode)(struct super_block___251 *);
	void (*destroy_inode)(struct inode___252 *);
	void (*dirty_inode)(struct inode___252 *, int);
	int (*write_inode)(struct inode___252 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___252 *);
	void (*evict_inode)(struct inode___252 *);
	void (*put_super)(struct super_block___251 *);
	int (*sync_fs)(struct super_block___251 *, int);
	int (*freeze_super)(struct super_block___251 *);
	int (*freeze_fs)(struct super_block___251 *);
	int (*thaw_super)(struct super_block___251 *);
	int (*unfreeze_fs)(struct super_block___251 *);
	int (*statfs)(struct dentry___252 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___251 *, int *, char *);
	void (*umount_begin)(struct super_block___251 *);
	int (*show_options)(struct seq_file___226 *, struct dentry___252 *);
	int (*show_devname)(struct seq_file___226 *, struct dentry___252 *);
	int (*show_path)(struct seq_file___226 *, struct dentry___252 *);
	int (*show_stats)(struct seq_file___226 *, struct dentry___252 *);
	ssize_t (*quota_read)(struct super_block___251 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___251 *, int, const char *, size_t, loff_t);
	struct dquot___251 ** (*get_dquots)(struct inode___252 *);
	int (*bdev_try_to_free_page)(struct super_block___251 *, struct page___253 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___251 *, struct shrink_control___109 *);
	long int (*free_cached_objects)(struct super_block___251 *, struct shrink_control___109 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___224;

struct seq_file___226 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___224 *op;
	int poll_event;
	const struct file___252 *file;
	void *private;
};

struct kernfs_root___246;

struct kernfs_elem_dir___246 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___246 *root;
};

struct kernfs_syscall_ops___246;

struct kernfs_root___246 {
	struct kernfs_node___247 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___246 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___246 {
	struct kernfs_node___247 *target_kn;
};

struct kernfs_ops___246;

struct kernfs_elem_attr___246 {
	const struct kernfs_ops___246 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___247 *notify_next;
};

struct kernfs_node___247 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___247 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___246 dir;
		struct kernfs_elem_symlink___246 symlink;
		struct kernfs_elem_attr___246 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___246;

struct kernfs_ops___246 {
	int (*open)(struct kernfs_open_file___246 *);
	void (*release)(struct kernfs_open_file___246 *);
	int (*seq_show)(struct seq_file___226 *, void *);
	void * (*seq_start)(struct seq_file___226 *, loff_t *);
	void * (*seq_next)(struct seq_file___226 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___226 *, void *);
	ssize_t (*read)(struct kernfs_open_file___246 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___246 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___246 *, struct vm_area_struct___253 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___246 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___246 {
	int (*remount_fs)(struct kernfs_root___246 *, int *, char *);
	int (*show_options)(struct seq_file___226 *, struct kernfs_root___246 *);
	int (*mkdir)(struct kernfs_node___247 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___247 *);
	int (*rename)(struct kernfs_node___247 *, struct kernfs_node___247 *, const char *);
	int (*show_path)(struct seq_file___226 *, struct kernfs_node___247 *, struct kernfs_root___246 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___246 {
	struct kernfs_node___247 *kn;
	struct file___252 *file;
	struct seq_file___226 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___242 *vm_ops;
};

struct bin_attribute___217;

struct attribute_group___218 {
	const char *name;
	umode_t (*is_visible)(struct kobject___240 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___240 *, struct bin_attribute___217 *, int);
	struct attribute **attrs;
	struct bin_attribute___217 **bin_attrs;
};

struct bin_attribute___217 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___252 *, struct kobject___240 *, struct bin_attribute___217 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___252 *, struct kobject___240 *, struct bin_attribute___217 *, char *, loff_t, size_t);
	int (*mmap)(struct file___252 *, struct kobject___240 *, struct bin_attribute___217 *, struct vm_area_struct___253 *);
};

struct sysfs_ops___239 {
	ssize_t (*show)(struct kobject___240 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___240 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___239;

struct kset___239 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___240 kobj;
	const struct kset_uevent_ops___239 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___239 {
	void (*release)(struct kobject___240 *);
	const struct sysfs_ops___239 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___23 * (*child_ns_type)(struct kobject___240 *);
	const void * (*namespace)(struct kobject___240 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___239 {
	int (* const filter)(struct kset___239 *, struct kobject___240 *);
	const char * (* const name)(struct kset___239 *, struct kobject___240 *);
	int (* const uevent)(struct kset___239 *, struct kobject___240 *, struct kobj_uevent_env *);
};

struct kobj_attribute___233 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___240 *, struct kobj_attribute___233 *, char *);
	ssize_t (*store)(struct kobject___240 *, struct kobj_attribute___233 *, const char *, size_t);
};

struct dev_pm_ops___216 {
	int (*prepare)(struct device___216 *);
	void (*complete)(struct device___216 *);
	int (*suspend)(struct device___216 *);
	int (*resume)(struct device___216 *);
	int (*freeze)(struct device___216 *);
	int (*thaw)(struct device___216 *);
	int (*poweroff)(struct device___216 *);
	int (*restore)(struct device___216 *);
	int (*suspend_late)(struct device___216 *);
	int (*resume_early)(struct device___216 *);
	int (*freeze_late)(struct device___216 *);
	int (*thaw_early)(struct device___216 *);
	int (*poweroff_late)(struct device___216 *);
	int (*restore_early)(struct device___216 *);
	int (*suspend_noirq)(struct device___216 *);
	int (*resume_noirq)(struct device___216 *);
	int (*freeze_noirq)(struct device___216 *);
	int (*thaw_noirq)(struct device___216 *);
	int (*poweroff_noirq)(struct device___216 *);
	int (*restore_noirq)(struct device___216 *);
	int (*runtime_suspend)(struct device___216 *);
	int (*runtime_resume)(struct device___216 *);
	int (*runtime_idle)(struct device___216 *);
};

struct dev_pm_info___216 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___216 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___216;

struct bus_type___216;

struct device_driver___216;

struct dev_pm_domain___216;

struct dma_map_ops___59;

struct fwnode_handle___151;

struct class___216;

struct device___216 {
	struct device___216 *parent;
	struct device_private *p;
	struct kobject___240 kobj;
	const char *init_name;
	const struct device_type___216 *type;
	struct mutex mutex;
	struct bus_type___216 *bus;
	struct device_driver___216 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___216 power;
	struct dev_pm_domain___216 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___59 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___151 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___216 *class;
	const struct attribute_group___218 **groups;
	void (*release)(struct device___216 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___216 {
	struct dev_pm_ops___216 ops;
	void (*detach)(struct device___216 *, bool);
	int (*activate)(struct device___216 *);
	void (*sync)(struct device___216 *);
	void (*dismiss)(struct device___216 *);
};

struct bus_type___216 {
	const char *name;
	const char *dev_name;
	struct device___216 *dev_root;
	const struct attribute_group___218 **bus_groups;
	const struct attribute_group___218 **dev_groups;
	const struct attribute_group___218 **drv_groups;
	int (*match)(struct device___216 *, struct device_driver___216 *);
	int (*uevent)(struct device___216 *, struct kobj_uevent_env *);
	int (*probe)(struct device___216 *);
	int (*remove)(struct device___216 *);
	void (*shutdown)(struct device___216 *);
	int (*online)(struct device___216 *);
	int (*offline)(struct device___216 *);
	int (*suspend)(struct device___216 *, pm_message_t);
	int (*resume)(struct device___216 *);
	int (*num_vf)(struct device___216 *);
	int (*dma_configure)(struct device___216 *);
	const struct dev_pm_ops___216 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___216 {
	const char *name;
	struct bus_type___216 *bus;
	struct module___206 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___216 *);
	int (*remove)(struct device___216 *);
	void (*shutdown)(struct device___216 *);
	int (*suspend)(struct device___216 *, pm_message_t);
	int (*resume)(struct device___216 *);
	const struct attribute_group___218 **groups;
	const struct dev_pm_ops___216 *pm;
	void (*coredump)(struct device___216 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___216 {
	const char *name;
	const struct attribute_group___218 **groups;
	int (*uevent)(struct device___216 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___216 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___216 *);
	const struct dev_pm_ops___216 *pm;
};

struct class___216 {
	const char *name;
	struct module___206 *owner;
	const struct attribute_group___218 **class_groups;
	const struct attribute_group___218 **dev_groups;
	struct kobject___240 *dev_kobj;
	int (*dev_uevent)(struct device___216 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___216 *, umode_t *);
	void (*class_release)(struct class___216 *);
	void (*dev_release)(struct device___216 *);
	int (*shutdown_pre)(struct device___216 *);
	const struct kobj_ns_type_operations___23 *ns_type;
	const void * (*namespace)(struct device___216 *);
	const struct dev_pm_ops___216 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___59 {
	void * (*alloc)(struct device___216 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___216 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___216 *, struct vm_area_struct___253 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___216 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___216 *, struct page___253 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___216 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___216 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___216 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___216 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___216 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___216 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___216 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___216 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___216 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___216 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___216 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___216 *, u64);
	u64 (*get_required_mask)(struct device___216 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___151;

struct fwnode_handle___151 {
	struct fwnode_handle___151 *secondary;
	const struct fwnode_operations___151 *ops;
};

typedef void compound_page_dtor___242(struct page___253 *);

struct fwnode_reference_args___151;

struct fwnode_endpoint___151;

struct fwnode_operations___151 {
	struct fwnode_handle___151 * (*get)(struct fwnode_handle___151 *);
	void (*put)(struct fwnode_handle___151 *);
	bool (*device_is_available)(const struct fwnode_handle___151 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___151 *, const struct device___216 *);
	bool (*property_present)(const struct fwnode_handle___151 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___151 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___151 *, const char *, const char **, size_t);
	struct fwnode_handle___151 * (*get_parent)(const struct fwnode_handle___151 *);
	struct fwnode_handle___151 * (*get_next_child_node)(const struct fwnode_handle___151 *, struct fwnode_handle___151 *);
	struct fwnode_handle___151 * (*get_named_child_node)(const struct fwnode_handle___151 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___151 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___151 *);
	struct fwnode_handle___151 * (*graph_get_next_endpoint)(const struct fwnode_handle___151 *, struct fwnode_handle___151 *);
	struct fwnode_handle___151 * (*graph_get_remote_endpoint)(const struct fwnode_handle___151 *);
	struct fwnode_handle___151 * (*graph_get_port_parent)(struct fwnode_handle___151 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___151 *, struct fwnode_endpoint___151 *);
};

struct fwnode_endpoint___151 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___151 *local_fwnode;
};

struct fwnode_reference_args___151 {
	struct fwnode_handle___151 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___62;

struct pipe_buffer___62 {
	struct page___253 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___62 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___62 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___62 *, struct pipe_buffer___62 *);
	void (*release)(struct pipe_inode_info___62 *, struct pipe_buffer___62 *);
	int (*steal)(struct pipe_inode_info___62 *, struct pipe_buffer___62 *);
	union {
		bool (*get)(struct pipe_inode_info___62 *, struct pipe_buffer___62 *);
		struct {
			void (*get)(struct pipe_inode_info___62 *, struct pipe_buffer___62 *);
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
};

struct crypto_template___7;

struct crypto_instance___7 {
	struct crypto_alg___12 alg;
	struct crypto_template___7 *tmpl;
	struct hlist_node list;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_template___7 {
	struct list_head list;
	struct hlist_head instances;
	struct module___206 *module;
	struct crypto_instance___7 * (*alloc)(struct rtattr **);
	void (*free)(struct crypto_instance___7 *);
	int (*create)(struct crypto_template___7 *, struct rtattr **);
	char name[128];
};

struct blkcipher_walk {
	union {
		struct {
			struct page___253 *page;
			long unsigned int offset;
		} phys;
		struct {
			u8 *page;
			u8 *addr;
		} virt;
	} src;
	union {
		struct {
			struct page___253 *page;
			long unsigned int offset;
		} phys;
		struct {
			u8 *page;
			u8 *addr;
		} virt;
	} dst;
	struct scatter_walk in;
	unsigned int nbytes;
	struct scatter_walk out;
	unsigned int total;
	void *page;
	u8 *buffer;
	u8 *iv;
	unsigned int ivsize;
	int flags;
	unsigned int walk_blocksize;
	unsigned int cipher_blocksize;
	unsigned int alignmask;
};

struct kernel_param_ops___203 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___203 *);
	int (*get)(char *, const struct kernel_param___203 *);
	void (*free)(void *);
};

struct kparam_array___203;

struct kernel_param___203 {
	const char *name;
	struct module___206 *mod;
	const struct kernel_param_ops___203 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___203 *arr;
	};
};

struct kparam_array___203 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___203 *ops;
	void *elem;
};

struct module_attribute___203 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___203 *, struct module_kobject___203 *, char *);
	ssize_t (*store)(struct module_attribute___203 *, struct module_kobject___203 *, const char *, size_t);
	void (*setup)(struct module___206 *, const char *);
	int (*test)(struct module___206 *);
	void (*free)(struct module___206 *);
};

typedef int (*key_restrict_link_func_t___245)(struct key___244 *, const struct key_type *, const union key_payload *, struct key___244 *);

struct key_restriction___244;

struct key___244 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___253 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key___5 index_key;
		struct {
			struct key_type___5 *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___244 *restrict_link;
};

struct key_restriction___244 {
	key_restrict_link_func_t___245 check;
	struct key___244 *key;
	struct key_type *keytype;
};

struct seq_operations___224 {
	void * (*start)(struct seq_file___226 *, loff_t *);
	void (*stop)(struct seq_file___226 *, void *);
	void * (*next)(struct seq_file___226 *, void *, loff_t *);
	int (*show)(struct seq_file___226 *, void *);
};

enum {
	BLKCIPHER_WALK_PHYS = 1,
	BLKCIPHER_WALK_SLOW = 2,
	BLKCIPHER_WALK_COPY = 4,
	BLKCIPHER_WALK_DIFF = 8,
};

struct crypto_async_request___13;

typedef void (*crypto_completion_t___13)(struct crypto_async_request___13 *, int);

struct crypto_tfm___13;

struct crypto_async_request___13 {
	struct list_head list;
	crypto_completion_t___13 complete;
	void *data;
	struct crypto_tfm___13 *tfm;
	u32 flags;
};

struct crypto_ablkcipher___13;

struct ablkcipher_request___13;

struct ablkcipher_tfm___13 {
	int (*setkey)(struct crypto_ablkcipher___13 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___13 *);
	int (*decrypt)(struct ablkcipher_request___13 *);
	struct crypto_ablkcipher___13 *base;
	unsigned int ivsize;
	unsigned int reqsize;
};

struct blkcipher_desc___13;

struct blkcipher_tfm___13 {
	void *iv;
	int (*setkey)(struct crypto_tfm___13 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___13 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___13 *, struct scatterlist *, struct scatterlist *, unsigned int);
};

struct cipher_tfm___13 {
	int (*cit_setkey)(struct crypto_tfm___13 *, const u8 *, unsigned int);
	void (*cit_encrypt_one)(struct crypto_tfm___13 *, u8 *, const u8 *);
	void (*cit_decrypt_one)(struct crypto_tfm___13 *, u8 *, const u8 *);
};

struct compress_tfm___13 {
	int (*cot_compress)(struct crypto_tfm___13 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*cot_decompress)(struct crypto_tfm___13 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___13;

struct crypto_tfm___13 {
	u32 crt_flags;
	union {
		struct ablkcipher_tfm___13 ablkcipher;
		struct blkcipher_tfm___13 blkcipher;
		struct cipher_tfm___13 cipher;
		struct compress_tfm___13 compress;
	} crt_u;
	void (*exit)(struct crypto_tfm___13 *);
	struct crypto_alg___13 *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct ablkcipher_request___13 {
	struct crypto_async_request___13 base;
	unsigned int nbytes;
	void *info;
	struct scatterlist *src;
	struct scatterlist *dst;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_blkcipher___13;

struct blkcipher_desc___13 {
	struct crypto_blkcipher___13 *tfm;
	void *info;
	u32 flags;
};

struct crypto_blkcipher___13 {
	struct crypto_tfm___13 base;
};

struct skcipher_givcrypt_request___4;

struct ablkcipher_alg___13 {
	int (*setkey)(struct crypto_ablkcipher___13 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___13 *);
	int (*decrypt)(struct ablkcipher_request___13 *);
	int (*givencrypt)(struct skcipher_givcrypt_request___4 *);
	int (*givdecrypt)(struct skcipher_givcrypt_request___4 *);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct crypto_ablkcipher___13 {
	struct crypto_tfm___13 base;
};

struct skcipher_givcrypt_request___4 {
	u64 seq;
	u8 *giv;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ablkcipher_request___13 creq;
};

struct blkcipher_alg___13 {
	int (*setkey)(struct crypto_tfm___13 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___13 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___13 *, struct scatterlist *, struct scatterlist *, unsigned int);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct cipher_alg___13 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___13 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___13 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___13 *, u8 *, const u8 *);
};

struct compress_alg___13 {
	int (*coa_compress)(struct crypto_tfm___13 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___13 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_type___8;

struct crypto_alg___13 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type___8 *cra_type;
	union {
		struct ablkcipher_alg___13 ablkcipher;
		struct blkcipher_alg___13 blkcipher;
		struct cipher_alg___13 cipher;
		struct compress_alg___13 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___13 *);
	void (*cra_exit)(struct crypto_tfm___13 *);
	void (*cra_destroy)(struct crypto_alg___13 *);
	struct module___23 *cra_module;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct crypto_instance___8;

struct crypto_type___8 {
	unsigned int (*ctxsize)(struct crypto_alg___13 *, u32, u32);
	unsigned int (*extsize)(struct crypto_alg___13 *);
	int (*init)(struct crypto_tfm___13 *, u32, u32);
	int (*init_tfm)(struct crypto_tfm___13 *);
	void (*show)(struct seq_file___23 *, struct crypto_alg___13 *);
	int (*report)(struct sk_buff___4 *, struct crypto_alg___13 *);
	void (*free)(struct crypto_instance___8 *);
	unsigned int type;
	unsigned int maskclear;
	unsigned int maskset;
	unsigned int tfmsize;
};

struct aead_request___4 {
	struct crypto_async_request___13 base;
	unsigned int assoclen;
	unsigned int cryptlen;
	u8 *iv;
	struct scatterlist *src;
	struct scatterlist *dst;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_aead___4;

struct aead_alg___4 {
	int (*setkey)(struct crypto_aead___4 *, const u8 *, unsigned int);
	int (*setauthsize)(struct crypto_aead___4 *, unsigned int);
	int (*encrypt)(struct aead_request___4 *);
	int (*decrypt)(struct aead_request___4 *);
	int (*init)(struct crypto_aead___4 *);
	void (*exit)(struct crypto_aead___4 *);
	const char *geniv;
	unsigned int ivsize;
	unsigned int maxauthsize;
	unsigned int chunksize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_alg___13 base;
};

struct crypto_aead___4 {
	unsigned int authsize;
	unsigned int reqsize;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_tfm___13 base;
};

struct crypto_template___8;

struct crypto_instance___8 {
	struct crypto_alg___13 alg;
	struct crypto_template___8 *tmpl;
	struct hlist_node list;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_template___8 {
	struct list_head list;
	struct hlist_head instances;
	struct module___23 *module;
	struct crypto_instance___8 * (*alloc)(struct rtattr **);
	void (*free)(struct crypto_instance___8 *);
	int (*create)(struct crypto_template___8 *, struct rtattr **);
	char name[128];
};

struct crypto_spawn___2 {
	struct list_head list;
	struct crypto_alg___13 *alg;
	struct crypto_instance___8 *inst;
	const struct crypto_type___8 *frontend;
	u32 mask;
};

struct skcipher_request___2 {
	unsigned int cryptlen;
	u8 *iv;
	struct scatterlist *src;
	struct scatterlist *dst;
	struct crypto_async_request___13 base;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_skcipher___2 {
	int (*setkey)(struct crypto_skcipher___2 *, const u8 *, unsigned int);
	int (*encrypt)(struct skcipher_request___2 *);
	int (*decrypt)(struct skcipher_request___2 *);
	unsigned int ivsize;
	unsigned int reqsize;
	unsigned int keysize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_tfm___13 base;
};

struct skcipher_alg___2 {
	int (*setkey)(struct crypto_skcipher___2 *, const u8 *, unsigned int);
	int (*encrypt)(struct skcipher_request___2 *);
	int (*decrypt)(struct skcipher_request___2 *);
	int (*init)(struct crypto_skcipher___2 *);
	void (*exit)(struct crypto_skcipher___2 *);
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
	unsigned int chunksize;
	unsigned int walksize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_alg___13 base;
};

struct skcipher_instance {
	void (*free)(struct skcipher_instance *);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	union {
		struct {
			char head[128];
			struct crypto_instance___8 base;
		} s;
		struct skcipher_alg___2 alg;
	};
};

struct crypto_skcipher_spawn {
	struct crypto_spawn___2 base;
};

enum {
	SKCIPHER_WALK_PHYS = 1,
	SKCIPHER_WALK_SLOW = 2,
	SKCIPHER_WALK_COPY = 4,
	SKCIPHER_WALK_DIFF = 8,
	SKCIPHER_WALK_SLEEP = 16,
};

struct skcipher_walk_buffer {
	struct list_head entry;
	struct scatter_walk dst;
	unsigned int len;
	u8 *data;
	u8 buffer[0];
};

struct hash_alg_common {
	unsigned int digestsize;
	unsigned int statesize;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_alg___12 base;
};

struct ahash_request {
	struct crypto_async_request___12 base;
	unsigned int nbytes;
	struct scatterlist *src;
	u8 *result;
	void *priv;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_ahash;

struct ahash_alg {
	int (*init)(struct ahash_request *);
	int (*update)(struct ahash_request *);
	int (*final)(struct ahash_request *);
	int (*finup)(struct ahash_request *);
	int (*digest)(struct ahash_request *);
	int (*export)(struct ahash_request *, void *);
	int (*import)(struct ahash_request *, const void *);
	int (*setkey)(struct crypto_ahash *, const u8 *, unsigned int);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hash_alg_common halg;
};

struct crypto_ahash {
	int (*init)(struct ahash_request *);
	int (*update)(struct ahash_request *);
	int (*final)(struct ahash_request *);
	int (*finup)(struct ahash_request *);
	int (*digest)(struct ahash_request *);
	int (*export)(struct ahash_request *, void *);
	int (*import)(struct ahash_request *, const void *);
	int (*setkey)(struct crypto_ahash *, const u8 *, unsigned int);
	unsigned int reqsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_tfm___12 base;
};

struct crypto_shash___5;

struct shash_desc___3 {
	struct crypto_shash___5 *tfm;
	u32 flags;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_shash___5 {
	unsigned int descsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_tfm___12 base;
};

struct shash_alg___2 {
	int (*init)(struct shash_desc___3 *);
	int (*update)(struct shash_desc___3 *, const u8 *, unsigned int);
	int (*final)(struct shash_desc___3 *, u8 *);
	int (*finup)(struct shash_desc___3 *, const u8 *, unsigned int, u8 *);
	int (*digest)(struct shash_desc___3 *, const u8 *, unsigned int, u8 *);
	int (*export)(struct shash_desc___3 *, void *);
	int (*import)(struct shash_desc___3 *, const void *);
	int (*setkey)(struct crypto_shash___5 *, const u8 *, unsigned int);
	unsigned int descsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int digestsize;
	unsigned int statesize;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_alg___12 base;
};

struct crypto_spawn___3 {
	struct list_head list;
	struct crypto_alg___12 *alg;
	struct crypto_instance___7 *inst;
	const struct crypto_type___7 *frontend;
	u32 mask;
};

struct crypto_hash_walk {
	char *data;
	unsigned int offset;
	unsigned int alignmask;
	struct page___253 *pg;
	unsigned int entrylen;
	unsigned int total;
	struct scatterlist *sg;
	unsigned int flags;
};

struct ahash_instance {
	struct ahash_alg alg;
};

struct crypto_ahash_spawn {
	struct crypto_spawn___3 base;
};

struct crypto_report_hash {
	char type[64];
	unsigned int blocksize;
	unsigned int digestsize;
};

struct ahash_request_priv {
	crypto_completion_t___12 complete;
	void *data;
	u8 *result;
	u32 flags;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *ubuf[0];
};

struct shash_instance {
	struct shash_alg___2 alg;
};

struct crypto_shash_spawn {
	struct crypto_spawn___3 base;
};

struct module___207;

struct file___253;

struct kiocb___253;

struct iov_iter___120;

struct vm_area_struct___254;

struct inode___253;

struct file_lock___253;

struct page___254;

struct pipe_inode_info___63;

struct seq_file___227;

struct file_operations___253 {
	struct module___207 *owner;
	loff_t (*llseek)(struct file___253 *, loff_t, int);
	ssize_t (*read)(struct file___253 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___253 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___253 *, struct iov_iter___120 *);
	ssize_t (*write_iter)(struct kiocb___253 *, struct iov_iter___120 *);
	int (*iopoll)(struct kiocb___253 *, bool);
	int (*iterate)(struct file___253 *, struct dir_context *);
	int (*iterate_shared)(struct file___253 *, struct dir_context *);
	__poll_t (*poll)(struct file___253 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___253 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___253 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___253 *, struct vm_area_struct___254 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___253 *, struct file___253 *);
	int (*flush)(struct file___253 *, fl_owner_t);
	int (*release)(struct inode___253 *, struct file___253 *);
	int (*fsync)(struct file___253 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___253 *, int);
	int (*lock)(struct file___253 *, int, struct file_lock___253 *);
	ssize_t (*sendpage)(struct file___253 *, struct page___254 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___253 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___253 *, int, struct file_lock___253 *);
	ssize_t (*splice_write)(struct pipe_inode_info___63 *, struct file___253 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___253 *, loff_t *, struct pipe_inode_info___63 *, size_t, unsigned int);
	int (*setlease)(struct file___253 *, long int, struct file_lock___253 **, void **);
	long int (*fallocate)(struct file___253 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___227 *, struct file___253 *);
	ssize_t (*copy_file_range)(struct file___253 *, loff_t, struct file___253 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___253 *, loff_t, struct file___253 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___253 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___253 {
	u64 seqnum;
	struct vm_area_struct___254 *vmas[4];
};

struct page_frag___253 {
	struct page___254 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___253;

struct cred___245;

struct signal_struct___210;

struct vm_struct___170;

struct task_struct___254 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___254 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___253 *mm;
	struct mm_struct___253 *active_mm;
	struct vmacache___253 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___254 *real_parent;
	struct task_struct___254 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___254 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___188 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___188 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___188 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___245 *ptracer_cred;
	const struct cred___245 *real_cred;
	const struct cred___245 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___228 *nsproxy;
	struct signal_struct___210 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___254 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___60 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___63 *splice_pipe;
	struct page_frag___253 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___254 *oom_reaper_list;
	struct vm_struct___170 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___127 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___254 *pgtable_t___253;

struct address_space___252;

struct dev_pagemap___243;

struct page___254 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___252 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___254 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___253 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___253 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___243 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___253;

struct lruvec___253 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___253 *pgdat;
};

struct zone___253 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___253 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___253 {
	struct zone___253 *zone;
	int zone_idx;
};

struct zonelist___253 {
	struct zoneref___253 _zonerefs[25];
};

struct pglist_data___253 {
	struct zone___253 node_zones[3];
	struct zonelist___253 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___254 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___254 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___253 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___254 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___254 *owner;
};

struct secondary_data___254 {
	void *stack;
	struct task_struct___254 *task;
	long int status;
};

struct blocking_notifier_head___253 {
	struct rw_semaphore___254 rwsem;
	struct notifier_block *head;
};

struct dentry___253;

struct path___253 {
	struct vfsmount *mnt;
	struct dentry___253 *dentry;
};

struct file___253 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___253 f_path;
	struct inode___253 *f_inode;
	const struct file_operations___253 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___188 f_owner;
	const struct cred___245 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___252 *f_mapping;
	errseq_t f_wb_err;
};

struct key___245;

struct user_struct___245;

struct cred___245 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___245 *session_keyring;
	struct key___245 *process_keyring;
	struct key___245 *thread_keyring;
	struct key___245 *request_key_auth;
	void *security;
	struct user_struct___245 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___247;

struct kernfs_elem_dir___247 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___247 *root;
};

struct kernfs_node___248;

struct kernfs_syscall_ops___247;

struct kernfs_root___247 {
	struct kernfs_node___248 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___247 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___247 {
	struct kernfs_node___248 *target_kn;
};

struct kernfs_ops___247;

struct kernfs_elem_attr___247 {
	const struct kernfs_ops___247 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___248 *notify_next;
};

struct kernfs_node___248 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___248 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___247 dir;
		struct kernfs_elem_symlink___247 symlink;
		struct kernfs_elem_attr___247 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___247;

struct kernfs_ops___247 {
	int (*open)(struct kernfs_open_file___247 *);
	void (*release)(struct kernfs_open_file___247 *);
	int (*seq_show)(struct seq_file___227 *, void *);
	void * (*seq_start)(struct seq_file___227 *, loff_t *);
	void * (*seq_next)(struct seq_file___227 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___227 *, void *);
	ssize_t (*read)(struct kernfs_open_file___247 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___247 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___247 *, struct vm_area_struct___254 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___247 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___247 {
	int (*remount_fs)(struct kernfs_root___247 *, int *, char *);
	int (*show_options)(struct seq_file___227 *, struct kernfs_root___247 *);
	int (*mkdir)(struct kernfs_node___248 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___248 *);
	int (*rename)(struct kernfs_node___248 *, struct kernfs_node___248 *, const char *);
	int (*show_path)(struct seq_file___227 *, struct kernfs_node___248 *, struct kernfs_root___247 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___225;

struct seq_file___227 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___225 *op;
	int poll_event;
	const struct file___253 *file;
	void *private;
};

struct vm_operations_struct___243;

struct kernfs_open_file___247 {
	struct kernfs_node___248 *kn;
	struct file___253 *file;
	struct seq_file___227 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___243 *vm_ops;
};

struct vm_fault___243;

struct vm_operations_struct___243 {
	void (*open)(struct vm_area_struct___254 *);
	void (*close)(struct vm_area_struct___254 *);
	int (*split)(struct vm_area_struct___254 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___254 *);
	vm_fault_t (*fault)(struct vm_fault___243 *);
	vm_fault_t (*huge_fault)(struct vm_fault___243 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___243 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___254 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___243 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___243 *);
	int (*access)(struct vm_area_struct___254 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___254 *);
	int (*set_policy)(struct vm_area_struct___254 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___254 *, long unsigned int);
	struct page___254 * (*find_special_page)(struct vm_area_struct___254 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_area_struct___254 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___254 *vm_next;
	struct vm_area_struct___254 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___253 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___243 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___253 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___241;

struct bin_attribute___218;

struct attribute_group___219 {
	const char *name;
	umode_t (*is_visible)(struct kobject___241 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___241 *, struct bin_attribute___218 *, int);
	struct attribute **attrs;
	struct bin_attribute___218 **bin_attrs;
};

struct kset___240;

struct kobj_type___240;

struct kobject___241 {
	const char *name;
	struct list_head entry;
	struct kobject___241 *parent;
	struct kset___240 *kset;
	struct kobj_type___240 *ktype;
	struct kernfs_node___248 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___218 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___253 *, struct kobject___241 *, struct bin_attribute___218 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___253 *, struct kobject___241 *, struct bin_attribute___218 *, char *, loff_t, size_t);
	int (*mmap)(struct file___253 *, struct kobject___241 *, struct bin_attribute___218 *, struct vm_area_struct___254 *);
};

struct sysfs_ops___240 {
	ssize_t (*show)(struct kobject___241 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___241 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___240;

struct kset___240 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___241 kobj;
	const struct kset_uevent_ops___240 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___240 {
	void (*release)(struct kobject___241 *);
	const struct sysfs_ops___240 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___23 * (*child_ns_type)(struct kobject___241 *);
	const void * (*namespace)(struct kobject___241 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___240 {
	int (* const filter)(struct kset___240 *, struct kobject___241 *);
	const char * (* const name)(struct kset___240 *, struct kobject___241 *);
	int (* const uevent)(struct kset___240 *, struct kobject___241 *, struct kobj_uevent_env *);
};

struct kobj_attribute___234 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___241 *, struct kobj_attribute___234 *, char *);
	ssize_t (*store)(struct kobject___241 *, struct kobj_attribute___234 *, const char *, size_t);
};

struct kernel_param___204;

struct kernel_param_ops___204 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___204 *);
	int (*get)(char *, const struct kernel_param___204 *);
	void (*free)(void *);
};

struct kparam_array___204;

struct kernel_param___204 {
	const char *name;
	struct module___207 *mod;
	const struct kernel_param_ops___204 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___204 *arr;
	};
};

struct kparam_array___204 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___204 *ops;
	void *elem;
};

struct module_kobject___204 {
	struct kobject___241 kobj;
	struct module___207 *mod;
	struct kobject___241 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___204 {
	struct module___207 *mod;
	struct latch_tree_node node;
};

struct module_layout___204 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___204 mtn;
};

struct module_attribute___204;

struct module___207 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___204 mkobj;
	struct module_attribute___204 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___241 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___204 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___204 core_layout;
	struct module_layout___204 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___204 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___204 *, struct module_kobject___204 *, char *);
	ssize_t (*store)(struct module_attribute___204 *, struct module_kobject___204 *, const char *, size_t);
	void (*setup)(struct module___207 *, const char *);
	int (*test)(struct module___207 *);
	void (*free)(struct module___207 *);
};

struct dentry_operations___252;

struct super_block___252;

struct dentry___253 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___253 *d_parent;
	struct qstr d_name;
	struct inode___253 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___252 *d_op;
	struct super_block___252 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___252;

struct address_space___252 {
	struct inode___253 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___254 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___252 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___252;

struct block_device___253;

struct inode___253 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___252 *i_op;
	struct super_block___252 *i_sb;
	struct address_space___252 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___254 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___253 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___252 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___63 *i_pipe;
		struct block_device___253 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___252 {
	int (*d_revalidate)(struct dentry___253 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___253 *, unsigned int);
	int (*d_hash)(const struct dentry___253 *, struct qstr *);
	int (*d_compare)(const struct dentry___253 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___253 *);
	int (*d_init)(struct dentry___253 *);
	void (*d_release)(struct dentry___253 *);
	void (*d_prune)(struct dentry___253 *);
	void (*d_iput)(struct dentry___253 *, struct inode___253 *);
	char * (*d_dname)(struct dentry___253 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___253 *);
	int (*d_manage)(const struct path___253 *, bool);
	struct dentry___253 * (*d_real)(struct dentry___253 *, const struct inode___253 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___252;

struct mem_dqinfo___252 {
	struct quota_format_type___252 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___252;

struct quota_info___252 {
	unsigned int flags;
	struct rw_semaphore___254 dqio_sem;
	struct inode___253 *files[3];
	struct mem_dqinfo___252 info[3];
	const struct quota_format_ops___252 *ops[3];
};

struct rcuwait___252 {
	struct task_struct___254 *task;
};

struct percpu_rw_semaphore___252 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___254 rw_sem;
	struct rcuwait___252 writer;
	int readers_block;
};

struct sb_writers___252 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___252 rw_sem[3];
};

struct file_system_type___252;

struct super_operations___252;

struct dquot_operations___252;

struct quotactl_ops___252;

struct super_block___252 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___252 *s_type;
	const struct super_operations___252 *s_op;
	const struct dquot_operations___252 *dq_op;
	const struct quotactl_ops___252 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___253 *s_root;
	struct rw_semaphore___254 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___253 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___252 s_dquot;
	struct sb_writers___252 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___252 *s_d_op;
	int cleancache_poolid;
	struct shrinker___109 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct core_state___253;

struct mm_struct___253 {
	struct {
		struct vm_area_struct___254 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___253 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___254 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___253 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___254 *owner;
		struct user_namespace___3 *user_ns;
		struct file___253 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___253 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___243)(struct vm_area_struct___254 *, long unsigned int, const struct page___254 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___243)(struct page___254 *, void *);

struct device___217;

struct dev_pagemap___243 {
	dev_page_fault_t___243 page_fault;
	dev_page_free_t___243 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___217 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___253 {
	struct task_struct___254 *task;
	struct core_thread___253 *next;
};

struct core_state___253 {
	atomic_t nr_threads;
	struct core_thread___253 dumper;
	struct completion startup;
};

struct vm_fault___243 {
	struct vm_area_struct___254 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___254 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___254 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___253 prealloc_pte;
};

struct user_struct___245 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___245 *uid_keyring;
	struct key___245 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct signal_struct___210 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___254 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___254 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___188 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___188 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___253 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___188 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct fasync_struct___252;

struct pipe_buffer___63;

struct pipe_inode_info___63 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___254 *tmp_page;
	struct fasync_struct___252 *fasync_readers;
	struct fasync_struct___252 *fasync_writers;
	struct pipe_buffer___63 *bufs;
	struct user_struct___245 *user;
};

struct vm_struct___170 {
	struct vm_struct___170 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___254 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___222 {
	struct task_struct___254 task;
	long unsigned int stack[8192];
};

struct kiocb___253 {
	struct file___253 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___253 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___252 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___253 *ia_file;
};

struct dquot___252 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___252 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___252 {
	int qf_fmt_id;
	const struct quota_format_ops___252 *qf_ops;
	struct module___207 *qf_owner;
	struct quota_format_type___252 *qf_next;
};

struct quota_format_ops___252 {
	int (*check_quota_file)(struct super_block___252 *, int);
	int (*read_file_info)(struct super_block___252 *, int);
	int (*write_file_info)(struct super_block___252 *, int);
	int (*free_file_info)(struct super_block___252 *, int);
	int (*read_dqblk)(struct dquot___252 *);
	int (*commit_dqblk)(struct dquot___252 *);
	int (*release_dqblk)(struct dquot___252 *);
	int (*get_next_id)(struct super_block___252 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___252 {
	int (*write_dquot)(struct dquot___252 *);
	struct dquot___252 * (*alloc_dquot)(struct super_block___252 *, int);
	void (*destroy_dquot)(struct dquot___252 *);
	int (*acquire_dquot)(struct dquot___252 *);
	int (*release_dquot)(struct dquot___252 *);
	int (*mark_dirty)(struct dquot___252 *);
	int (*write_info)(struct super_block___252 *, int);
	qsize_t * (*get_reserved_space)(struct inode___253 *);
	int (*get_projid)(struct inode___253 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___253 *, qsize_t *);
	int (*get_next_id)(struct super_block___252 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___252 {
	int (*quota_on)(struct super_block___252 *, int, int, const struct path___253 *);
	int (*quota_off)(struct super_block___252 *, int);
	int (*quota_enable)(struct super_block___252 *, unsigned int);
	int (*quota_disable)(struct super_block___252 *, unsigned int);
	int (*quota_sync)(struct super_block___252 *, int);
	int (*set_info)(struct super_block___252 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___252 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___252 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___252 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___252 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___252 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___252 {
	int (*writepage)(struct page___254 *, struct writeback_control___3 *);
	int (*readpage)(struct file___253 *, struct page___254 *);
	int (*writepages)(struct address_space___252 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___254 *);
	int (*readpages)(struct file___253 *, struct address_space___252 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___253 *, struct address_space___252 *, loff_t, unsigned int, unsigned int, struct page___254 **, void **);
	int (*write_end)(struct file___253 *, struct address_space___252 *, loff_t, unsigned int, unsigned int, struct page___254 *, void *);
	sector_t (*bmap)(struct address_space___252 *, sector_t);
	void (*invalidatepage)(struct page___254 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___254 *, gfp_t);
	void (*freepage)(struct page___254 *);
	ssize_t (*direct_IO)(struct kiocb___253 *, struct iov_iter___120 *);
	int (*migratepage)(struct address_space___252 *, struct page___254 *, struct page___254 *, enum migrate_mode);
	bool (*isolate_page)(struct page___254 *, isolate_mode_t);
	void (*putback_page)(struct page___254 *);
	int (*launder_page)(struct page___254 *);
	int (*is_partially_uptodate)(struct page___254 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___254 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___252 *, struct page___254 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___253 *, sector_t *);
	void (*swap_deactivate)(struct file___253 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct iov_iter___120 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___3 *bvec;
		struct pipe_inode_info___63 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___253 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___253 *bd_inode;
	struct super_block___252 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___253 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___252 {
	struct dentry___253 * (*lookup)(struct inode___253 *, struct dentry___253 *, unsigned int);
	const char * (*get_link)(struct dentry___253 *, struct inode___253 *, struct delayed_call *);
	int (*permission)(struct inode___253 *, int);
	struct posix_acl * (*get_acl)(struct inode___253 *, int);
	int (*readlink)(struct dentry___253 *, char *, int);
	int (*create)(struct inode___253 *, struct dentry___253 *, umode_t, bool);
	int (*link)(struct dentry___253 *, struct inode___253 *, struct dentry___253 *);
	int (*unlink)(struct inode___253 *, struct dentry___253 *);
	int (*symlink)(struct inode___253 *, struct dentry___253 *, const char *);
	int (*mkdir)(struct inode___253 *, struct dentry___253 *, umode_t);
	int (*rmdir)(struct inode___253 *, struct dentry___253 *);
	int (*mknod)(struct inode___253 *, struct dentry___253 *, umode_t, dev_t);
	int (*rename)(struct inode___253 *, struct dentry___253 *, struct inode___253 *, struct dentry___253 *, unsigned int);
	int (*setattr)(struct dentry___253 *, struct iattr___252 *);
	int (*getattr)(const struct path___253 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___253 *, char *, size_t);
	int (*fiemap)(struct inode___253 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___253 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___253 *, struct dentry___253 *, struct file___253 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___253 *, struct dentry___253 *, umode_t);
	int (*set_acl)(struct inode___253 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___252 {
	void (*fl_copy_lock)(struct file_lock___253 *, struct file_lock___253 *);
	void (*fl_release_private)(struct file_lock___253 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___252;

struct file_lock___253 {
	struct file_lock___253 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___253 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___252 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___252 *fl_ops;
	const struct lock_manager_operations___252 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___252 {
	int (*lm_compare_owner)(struct file_lock___253 *, struct file_lock___253 *);
	long unsigned int (*lm_owner_key)(struct file_lock___253 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___253 *);
	int (*lm_grant)(struct file_lock___253 *, int);
	bool (*lm_break)(struct file_lock___253 *);
	int (*lm_change)(struct file_lock___253 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___253 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___252 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___252 *fa_next;
	struct file___253 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___252 {
	const char *name;
	int fs_flags;
	struct dentry___253 * (*mount)(struct file_system_type___252 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___252 *);
	struct module___207 *owner;
	struct file_system_type___252 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___252 {
	struct inode___253 * (*alloc_inode)(struct super_block___252 *);
	void (*destroy_inode)(struct inode___253 *);
	void (*dirty_inode)(struct inode___253 *, int);
	int (*write_inode)(struct inode___253 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___253 *);
	void (*evict_inode)(struct inode___253 *);
	void (*put_super)(struct super_block___252 *);
	int (*sync_fs)(struct super_block___252 *, int);
	int (*freeze_super)(struct super_block___252 *);
	int (*freeze_fs)(struct super_block___252 *);
	int (*thaw_super)(struct super_block___252 *);
	int (*unfreeze_fs)(struct super_block___252 *);
	int (*statfs)(struct dentry___253 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___252 *, int *, char *);
	void (*umount_begin)(struct super_block___252 *);
	int (*show_options)(struct seq_file___227 *, struct dentry___253 *);
	int (*show_devname)(struct seq_file___227 *, struct dentry___253 *);
	int (*show_path)(struct seq_file___227 *, struct dentry___253 *);
	int (*show_stats)(struct seq_file___227 *, struct dentry___253 *);
	ssize_t (*quota_read)(struct super_block___252 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___252 *, int, const char *, size_t, loff_t);
	struct dquot___252 ** (*get_dquots)(struct inode___253 *);
	int (*bdev_try_to_free_page)(struct super_block___252 *, struct page___254 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___252 *, struct shrink_control___109 *);
	long int (*free_cached_objects)(struct super_block___252 *, struct shrink_control___109 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*key_restrict_link_func_t___246)(struct key___245 *, const struct key_type *, const union key_payload *, struct key___245 *);

struct key_restriction___245;

struct key___245 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___254 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key___5 index_key;
		struct {
			struct key_type___5 *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___245 *restrict_link;
};

struct key_restriction___245 {
	key_restrict_link_func_t___246 check;
	struct key___245 *key;
	struct key_type *keytype;
};

struct seq_operations___225 {
	void * (*start)(struct seq_file___227 *, loff_t *);
	void (*stop)(struct seq_file___227 *, void *);
	void * (*next)(struct seq_file___227 *, void *, loff_t *);
	int (*show)(struct seq_file___227 *, void *);
};

struct crypto_async_request___14;

typedef void (*crypto_completion_t___14)(struct crypto_async_request___14 *, int);

struct crypto_tfm___14;

struct crypto_async_request___14 {
	struct list_head list;
	crypto_completion_t___14 complete;
	void *data;
	struct crypto_tfm___14 *tfm;
	u32 flags;
};

struct crypto_ablkcipher___14;

struct ablkcipher_request___14;

struct ablkcipher_tfm___14 {
	int (*setkey)(struct crypto_ablkcipher___14 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___14 *);
	int (*decrypt)(struct ablkcipher_request___14 *);
	struct crypto_ablkcipher___14 *base;
	unsigned int ivsize;
	unsigned int reqsize;
};

struct blkcipher_desc___14;

struct blkcipher_tfm___14 {
	void *iv;
	int (*setkey)(struct crypto_tfm___14 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___14 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___14 *, struct scatterlist *, struct scatterlist *, unsigned int);
};

struct cipher_tfm___14 {
	int (*cit_setkey)(struct crypto_tfm___14 *, const u8 *, unsigned int);
	void (*cit_encrypt_one)(struct crypto_tfm___14 *, u8 *, const u8 *);
	void (*cit_decrypt_one)(struct crypto_tfm___14 *, u8 *, const u8 *);
};

struct compress_tfm___14 {
	int (*cot_compress)(struct crypto_tfm___14 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*cot_decompress)(struct crypto_tfm___14 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___14;

struct crypto_tfm___14 {
	u32 crt_flags;
	union {
		struct ablkcipher_tfm___14 ablkcipher;
		struct blkcipher_tfm___14 blkcipher;
		struct cipher_tfm___14 cipher;
		struct compress_tfm___14 compress;
	} crt_u;
	void (*exit)(struct crypto_tfm___14 *);
	struct crypto_alg___14 *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct ablkcipher_request___14 {
	struct crypto_async_request___14 base;
	unsigned int nbytes;
	void *info;
	struct scatterlist *src;
	struct scatterlist *dst;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_blkcipher___14;

struct blkcipher_desc___14 {
	struct crypto_blkcipher___14 *tfm;
	void *info;
	u32 flags;
};

struct crypto_blkcipher___14 {
	struct crypto_tfm___14 base;
};

struct ablkcipher_alg___14 {
	int (*setkey)(struct crypto_ablkcipher___14 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___14 *);
	int (*decrypt)(struct ablkcipher_request___14 *);
	int (*givencrypt)(struct skcipher_givcrypt_request *);
	int (*givdecrypt)(struct skcipher_givcrypt_request *);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct crypto_ablkcipher___14 {
	struct crypto_tfm___14 base;
};

struct blkcipher_alg___14 {
	int (*setkey)(struct crypto_tfm___14 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___14 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___14 *, struct scatterlist *, struct scatterlist *, unsigned int);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct cipher_alg___14 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___14 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___14 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___14 *, u8 *, const u8 *);
};

struct compress_alg___14 {
	int (*coa_compress)(struct crypto_tfm___14 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___14 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_type___9;

struct crypto_alg___14 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type___9 *cra_type;
	union {
		struct ablkcipher_alg___14 ablkcipher;
		struct blkcipher_alg___14 blkcipher;
		struct cipher_alg___14 cipher;
		struct compress_alg___14 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___14 *);
	void (*cra_exit)(struct crypto_tfm___14 *);
	void (*cra_destroy)(struct crypto_alg___14 *);
	struct module___207 *cra_module;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct crypto_instance___9;

struct crypto_type___9 {
	unsigned int (*ctxsize)(struct crypto_alg___14 *, u32, u32);
	unsigned int (*extsize)(struct crypto_alg___14 *);
	int (*init)(struct crypto_tfm___14 *, u32, u32);
	int (*init_tfm)(struct crypto_tfm___14 *);
	void (*show)(struct seq_file___227 *, struct crypto_alg___14 *);
	int (*report)(struct sk_buff___6 *, struct crypto_alg___14 *);
	void (*free)(struct crypto_instance___9 *);
	unsigned int type;
	unsigned int maskclear;
	unsigned int maskset;
	unsigned int tfmsize;
};

struct dev_pm_ops___217 {
	int (*prepare)(struct device___217 *);
	void (*complete)(struct device___217 *);
	int (*suspend)(struct device___217 *);
	int (*resume)(struct device___217 *);
	int (*freeze)(struct device___217 *);
	int (*thaw)(struct device___217 *);
	int (*poweroff)(struct device___217 *);
	int (*restore)(struct device___217 *);
	int (*suspend_late)(struct device___217 *);
	int (*resume_early)(struct device___217 *);
	int (*freeze_late)(struct device___217 *);
	int (*thaw_early)(struct device___217 *);
	int (*poweroff_late)(struct device___217 *);
	int (*restore_early)(struct device___217 *);
	int (*suspend_noirq)(struct device___217 *);
	int (*resume_noirq)(struct device___217 *);
	int (*freeze_noirq)(struct device___217 *);
	int (*thaw_noirq)(struct device___217 *);
	int (*poweroff_noirq)(struct device___217 *);
	int (*restore_noirq)(struct device___217 *);
	int (*runtime_suspend)(struct device___217 *);
	int (*runtime_resume)(struct device___217 *);
	int (*runtime_idle)(struct device___217 *);
};

struct dev_pm_info___217 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___217 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___217;

struct bus_type___217;

struct device_driver___217;

struct dev_pm_domain___217;

struct dma_map_ops___60;

struct fwnode_handle___152;

struct class___217;

struct device___217 {
	struct device___217 *parent;
	struct device_private *p;
	struct kobject___241 kobj;
	const char *init_name;
	const struct device_type___217 *type;
	struct mutex mutex;
	struct bus_type___217 *bus;
	struct device_driver___217 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___217 power;
	struct dev_pm_domain___217 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___60 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___152 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___217 *class;
	const struct attribute_group___219 **groups;
	void (*release)(struct device___217 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___217 {
	struct dev_pm_ops___217 ops;
	void (*detach)(struct device___217 *, bool);
	int (*activate)(struct device___217 *);
	void (*sync)(struct device___217 *);
	void (*dismiss)(struct device___217 *);
};

struct bus_type___217 {
	const char *name;
	const char *dev_name;
	struct device___217 *dev_root;
	const struct attribute_group___219 **bus_groups;
	const struct attribute_group___219 **dev_groups;
	const struct attribute_group___219 **drv_groups;
	int (*match)(struct device___217 *, struct device_driver___217 *);
	int (*uevent)(struct device___217 *, struct kobj_uevent_env *);
	int (*probe)(struct device___217 *);
	int (*remove)(struct device___217 *);
	void (*shutdown)(struct device___217 *);
	int (*online)(struct device___217 *);
	int (*offline)(struct device___217 *);
	int (*suspend)(struct device___217 *, pm_message_t);
	int (*resume)(struct device___217 *);
	int (*num_vf)(struct device___217 *);
	int (*dma_configure)(struct device___217 *);
	const struct dev_pm_ops___217 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___217 {
	const char *name;
	struct bus_type___217 *bus;
	struct module___207 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___217 *);
	int (*remove)(struct device___217 *);
	void (*shutdown)(struct device___217 *);
	int (*suspend)(struct device___217 *, pm_message_t);
	int (*resume)(struct device___217 *);
	const struct attribute_group___219 **groups;
	const struct dev_pm_ops___217 *pm;
	void (*coredump)(struct device___217 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___217 {
	const char *name;
	const struct attribute_group___219 **groups;
	int (*uevent)(struct device___217 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___217 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___217 *);
	const struct dev_pm_ops___217 *pm;
};

struct class___217 {
	const char *name;
	struct module___207 *owner;
	const struct attribute_group___219 **class_groups;
	const struct attribute_group___219 **dev_groups;
	struct kobject___241 *dev_kobj;
	int (*dev_uevent)(struct device___217 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___217 *, umode_t *);
	void (*class_release)(struct class___217 *);
	void (*dev_release)(struct device___217 *);
	int (*shutdown_pre)(struct device___217 *);
	const struct kobj_ns_type_operations___23 *ns_type;
	const void * (*namespace)(struct device___217 *);
	const struct dev_pm_ops___217 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___60 {
	void * (*alloc)(struct device___217 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___217 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___217 *, struct vm_area_struct___254 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___217 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___217 *, struct page___254 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___217 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___217 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___217 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___217 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___217 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___217 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___217 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___217 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___217 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___217 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___217 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___217 *, u64);
	u64 (*get_required_mask)(struct device___217 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___152;

struct fwnode_handle___152 {
	struct fwnode_handle___152 *secondary;
	const struct fwnode_operations___152 *ops;
};

typedef void compound_page_dtor___243(struct page___254 *);

struct fwnode_reference_args___152;

struct fwnode_endpoint___152;

struct fwnode_operations___152 {
	struct fwnode_handle___152 * (*get)(struct fwnode_handle___152 *);
	void (*put)(struct fwnode_handle___152 *);
	bool (*device_is_available)(const struct fwnode_handle___152 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___152 *, const struct device___217 *);
	bool (*property_present)(const struct fwnode_handle___152 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___152 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___152 *, const char *, const char **, size_t);
	struct fwnode_handle___152 * (*get_parent)(const struct fwnode_handle___152 *);
	struct fwnode_handle___152 * (*get_next_child_node)(const struct fwnode_handle___152 *, struct fwnode_handle___152 *);
	struct fwnode_handle___152 * (*get_named_child_node)(const struct fwnode_handle___152 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___152 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___152 *);
	struct fwnode_handle___152 * (*graph_get_next_endpoint)(const struct fwnode_handle___152 *, struct fwnode_handle___152 *);
	struct fwnode_handle___152 * (*graph_get_remote_endpoint)(const struct fwnode_handle___152 *);
	struct fwnode_handle___152 * (*graph_get_port_parent)(struct fwnode_handle___152 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___152 *, struct fwnode_endpoint___152 *);
};

struct fwnode_endpoint___152 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___152 *local_fwnode;
};

struct fwnode_reference_args___152 {
	struct fwnode_handle___152 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___63;

struct pipe_buffer___63 {
	struct page___254 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___63 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___63 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___63 *, struct pipe_buffer___63 *);
	void (*release)(struct pipe_inode_info___63 *, struct pipe_buffer___63 *);
	int (*steal)(struct pipe_inode_info___63 *, struct pipe_buffer___63 *);
	union {
		bool (*get)(struct pipe_inode_info___63 *, struct pipe_buffer___63 *);
		struct {
			void (*get)(struct pipe_inode_info___63 *, struct pipe_buffer___63 *);
		} __UNIQUE_ID_rh_kabi_hide21;
		union {		};
	};
};

struct crypto_template___9;

struct crypto_instance___9 {
	struct crypto_alg___14 alg;
	struct crypto_template___9 *tmpl;
	struct hlist_node list;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_template___9 {
	struct list_head list;
	struct hlist_head instances;
	struct module___207 *module;
	struct crypto_instance___9 * (*alloc)(struct rtattr **);
	void (*free)(struct crypto_instance___9 *);
	int (*create)(struct crypto_template___9 *, struct rtattr **);
	char name[128];
};

struct crypto_spawn___4 {
	struct list_head list;
	struct crypto_alg___14 *alg;
	struct crypto_instance___9 *inst;
	const struct crypto_type___9 *frontend;
	u32 mask;
};

struct crypto_report_akcipher {
	char type[64];
};

struct akcipher_request {
	struct crypto_async_request___14 base;
	struct scatterlist *src;
	struct scatterlist *dst;
	unsigned int src_len;
	unsigned int dst_len;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_akcipher {
	struct crypto_tfm___14 base;
};

struct akcipher_alg {
	int (*sign)(struct akcipher_request *);
	int (*verify)(struct akcipher_request *);
	int (*encrypt)(struct akcipher_request *);
	int (*decrypt)(struct akcipher_request *);
	int (*set_pub_key)(struct crypto_akcipher *, const void *, unsigned int);
	int (*set_priv_key)(struct crypto_akcipher *, const void *, unsigned int);
	unsigned int (*max_size)(struct crypto_akcipher *);
	int (*init)(struct crypto_akcipher *);
	void (*exit)(struct crypto_akcipher *);
	unsigned int reqsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_alg___14 base;
};

struct akcipher_instance {
	void (*free)(struct akcipher_instance *);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	union {
		struct {
			char head[128];
			struct crypto_instance___9 base;
		} s;
		struct akcipher_alg alg;
	};
};

struct crypto_akcipher_spawn {
	struct crypto_spawn___4 base;
};

struct crypto_report_kpp {
	char type[64];
};

struct kpp_request {
	struct crypto_async_request___14 base;
	struct scatterlist *src;
	struct scatterlist *dst;
	unsigned int src_len;
	unsigned int dst_len;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_kpp {
	struct crypto_tfm___14 base;
};

struct kpp_alg {
	int (*set_secret)(struct crypto_kpp *, const void *, unsigned int);
	int (*generate_public_key)(struct kpp_request *);
	int (*compute_shared_secret)(struct kpp_request *);
	unsigned int (*max_size)(struct crypto_kpp *);
	int (*init)(struct crypto_kpp *);
	void (*exit)(struct crypto_kpp *);
	unsigned int reqsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_alg___14 base;
};

enum asn1_class {
	ASN1_UNIV = 0,
	ASN1_APPL = 1,
	ASN1_CONT = 2,
	ASN1_PRIV = 3,
};

enum asn1_method {
	ASN1_PRIM = 0,
	ASN1_CONS = 1,
};

enum asn1_tag {
	ASN1_EOC = 0,
	ASN1_BOOL = 1,
	ASN1_INT = 2,
	ASN1_BTS = 3,
	ASN1_OTS = 4,
	ASN1_NULL = 5,
	ASN1_OID = 6,
	ASN1_ODE = 7,
	ASN1_EXT = 8,
	ASN1_REAL = 9,
	ASN1_ENUM = 10,
	ASN1_EPDV = 11,
	ASN1_UTF8STR = 12,
	ASN1_RELOID = 13,
	ASN1_SEQ = 16,
	ASN1_SET = 17,
	ASN1_NUMSTR = 18,
	ASN1_PRNSTR = 19,
	ASN1_TEXSTR = 20,
	ASN1_VIDSTR = 21,
	ASN1_IA5STR = 22,
	ASN1_UNITIM = 23,
	ASN1_GENTIM = 24,
	ASN1_GRASTR = 25,
	ASN1_VISSTR = 26,
	ASN1_GENSTR = 27,
	ASN1_UNISTR = 28,
	ASN1_CHRSTR = 29,
	ASN1_BMPSTR = 30,
	ASN1_LONG_TAG = 31,
};

typedef int (*asn1_action_t)(void *, size_t, unsigned char, const void *, size_t);

struct asn1_decoder {
	const unsigned char *machine;
	size_t machlen;
	const asn1_action_t *actions;
};

enum asn1_opcode {
	ASN1_OP_MATCH = 0,
	ASN1_OP_MATCH_OR_SKIP = 1,
	ASN1_OP_MATCH_ACT = 2,
	ASN1_OP_MATCH_ACT_OR_SKIP = 3,
	ASN1_OP_MATCH_JUMP = 4,
	ASN1_OP_MATCH_JUMP_OR_SKIP = 5,
	ASN1_OP_MATCH_ANY = 8,
	ASN1_OP_MATCH_ANY_OR_SKIP = 9,
	ASN1_OP_MATCH_ANY_ACT = 10,
	ASN1_OP_MATCH_ANY_ACT_OR_SKIP = 11,
	ASN1_OP_COND_MATCH_OR_SKIP = 17,
	ASN1_OP_COND_MATCH_ACT_OR_SKIP = 19,
	ASN1_OP_COND_MATCH_JUMP_OR_SKIP = 21,
	ASN1_OP_COND_MATCH_ANY = 24,
	ASN1_OP_COND_MATCH_ANY_OR_SKIP = 25,
	ASN1_OP_COND_MATCH_ANY_ACT = 26,
	ASN1_OP_COND_MATCH_ANY_ACT_OR_SKIP = 27,
	ASN1_OP_COND_FAIL = 28,
	ASN1_OP_COMPLETE = 29,
	ASN1_OP_ACT = 30,
	ASN1_OP_MAYBE_ACT = 31,
	ASN1_OP_END_SEQ = 32,
	ASN1_OP_END_SET = 33,
	ASN1_OP_END_SEQ_OF = 34,
	ASN1_OP_END_SET_OF = 35,
	ASN1_OP_END_SEQ_ACT = 36,
	ASN1_OP_END_SET_ACT = 37,
	ASN1_OP_END_SEQ_OF_ACT = 38,
	ASN1_OP_END_SET_OF_ACT = 39,
	ASN1_OP_RETURN = 40,
	ASN1_OP__NR = 41,
};

enum rsapubkey_actions {
	ACT_rsa_get_e = 0,
	ACT_rsa_get_n = 1,
	NR__rsapubkey_actions = 2,
};

enum rsaprivkey_actions {
	ACT_rsa_get_d = 0,
	ACT_rsa_get_dp = 1,
	ACT_rsa_get_dq = 2,
	ACT_rsa_get_e___2 = 3,
	ACT_rsa_get_n___2 = 4,
	ACT_rsa_get_p = 5,
	ACT_rsa_get_q = 6,
	ACT_rsa_get_qinv = 7,
	NR__rsaprivkey_actions = 8,
};

typedef long unsigned int mpi_limb_t;

struct gcry_mpi {
	int alloced;
	int nlimbs;
	int nbits;
	int sign;
	unsigned int flags;
	mpi_limb_t *d;
};

typedef struct gcry_mpi *MPI;

struct rsa_key {
	const u8 *n;
	const u8 *e;
	const u8 *d;
	const u8 *p;
	const u8 *q;
	const u8 *dp;
	const u8 *dq;
	const u8 *qinv;
	size_t n_sz;
	size_t e_sz;
	size_t d_sz;
	size_t p_sz;
	size_t q_sz;
	size_t dp_sz;
	size_t dq_sz;
	size_t qinv_sz;
};

struct rsa_mpi_key {
	MPI n;
	MPI e;
	MPI d;
};

struct crypto_template___10;

struct asn1_decoder___2;

struct akcipher_request___2 {
	struct crypto_async_request___13 base;
	struct scatterlist *src;
	struct scatterlist *dst;
	unsigned int src_len;
	unsigned int dst_len;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_akcipher___2 {
	struct crypto_tfm___13 base;
};

struct akcipher_alg___2 {
	int (*sign)(struct akcipher_request___2 *);
	int (*verify)(struct akcipher_request___2 *);
	int (*encrypt)(struct akcipher_request___2 *);
	int (*decrypt)(struct akcipher_request___2 *);
	int (*set_pub_key)(struct crypto_akcipher___2 *, const void *, unsigned int);
	int (*set_priv_key)(struct crypto_akcipher___2 *, const void *, unsigned int);
	unsigned int (*max_size)(struct crypto_akcipher___2 *);
	int (*init)(struct crypto_akcipher___2 *);
	void (*exit)(struct crypto_akcipher___2 *);
	unsigned int reqsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_alg___13 base;
};

struct akcipher_instance___2 {
	void (*free)(struct akcipher_instance___2 *);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	union {
		struct {
			char head[128];
			struct crypto_instance___8 base;
		} s;
		struct akcipher_alg___2 alg;
	};
};

struct crypto_akcipher_spawn___2 {
	struct crypto_spawn___3 base;
};

struct rsa_asn1_template {
	const char *name;
	const u8 *data;
	size_t size;
};

struct pkcs1pad_ctx {
	struct crypto_akcipher___2 *child;
	unsigned int key_size;
};

struct pkcs1pad_inst_ctx {
	struct crypto_akcipher_spawn___2 spawn;
	const struct rsa_asn1_template *digest_info;
};

struct pkcs1pad_request {
	struct scatterlist in_sg[2];
	struct scatterlist out_sg[1];
	uint8_t *in_buf;
	uint8_t *out_buf;
	long: 64;
	long: 64;
	struct akcipher_request___2 child_req;
};

struct crypto_report_acomp {
	char type[64];
};

struct acomp_req {
	struct crypto_async_request___14 base;
	struct scatterlist *src;
	struct scatterlist *dst;
	unsigned int slen;
	unsigned int dlen;
	u32 flags;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_acomp {
	int (*compress)(struct acomp_req *);
	int (*decompress)(struct acomp_req *);
	void (*dst_free)(struct scatterlist *);
	unsigned int reqsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_tfm___14 base;
};

struct acomp_alg {
	int (*compress)(struct acomp_req *);
	int (*decompress)(struct acomp_req *);
	void (*dst_free)(struct scatterlist *);
	int (*init)(struct crypto_acomp *);
	void (*exit)(struct crypto_acomp *);
	unsigned int reqsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_alg___14 base;
};

struct crypto_report_comp {
	char type[64];
};

struct crypto_scomp {
	struct crypto_tfm___14 base;
};

struct scomp_alg {
	void * (*alloc_ctx)(struct crypto_scomp *);
	void (*free_ctx)(struct crypto_scomp *, void *);
	int (*compress)(struct crypto_scomp *, const u8 *, unsigned int, u8 *, unsigned int *, void *);
	int (*decompress)(struct crypto_scomp *, const u8 *, unsigned int, u8 *, unsigned int *, void *);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_alg___14 base;
};

struct cryptomgr_param {
	struct rtattr *tb[34];
	struct {
		struct rtattr attr;
		struct crypto_attr_type data;
	} type;
	union {
		struct rtattr attr;
		struct {
			struct rtattr attr;
			struct crypto_attr_alg data;
		} alg;
		struct {
			struct rtattr attr;
			struct crypto_attr_u32 data;
		} nu32;
	} attrs[32];
	char template[128];
	struct crypto_larval___2 *larval;
	u32 otype;
	u32 omask;
};

struct crypto_test_param {
	char driver[128];
	char alg[128];
	u32 type;
};

struct module___208;

struct file___254;

struct kiocb___254;

struct iov_iter___121;

struct vm_area_struct___255;

struct inode___254;

struct file_lock___254;

struct page___255;

struct pipe_inode_info___64;

struct file_operations___254 {
	struct module___208 *owner;
	loff_t (*llseek)(struct file___254 *, loff_t, int);
	ssize_t (*read)(struct file___254 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___254 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___254 *, struct iov_iter___121 *);
	ssize_t (*write_iter)(struct kiocb___254 *, struct iov_iter___121 *);
	int (*iopoll)(struct kiocb___254 *, bool);
	int (*iterate)(struct file___254 *, struct dir_context *);
	int (*iterate_shared)(struct file___254 *, struct dir_context *);
	__poll_t (*poll)(struct file___254 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___254 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___254 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___254 *, struct vm_area_struct___255 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___254 *, struct file___254 *);
	int (*flush)(struct file___254 *, fl_owner_t);
	int (*release)(struct inode___254 *, struct file___254 *);
	int (*fsync)(struct file___254 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___254 *, int);
	int (*lock)(struct file___254 *, int, struct file_lock___254 *);
	ssize_t (*sendpage)(struct file___254 *, struct page___255 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___254 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___254 *, int, struct file_lock___254 *);
	ssize_t (*splice_write)(struct pipe_inode_info___64 *, struct file___254 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___254 *, loff_t *, struct pipe_inode_info___64 *, size_t, unsigned int);
	int (*setlease)(struct file___254 *, long int, struct file_lock___254 **, void **);
	long int (*fallocate)(struct file___254 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___254 *);
	ssize_t (*copy_file_range)(struct file___254 *, loff_t, struct file___254 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___254 *, loff_t, struct file___254 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___254 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___254 {
	u64 seqnum;
	struct vm_area_struct___255 *vmas[4];
};

struct page_frag___254 {
	struct page___255 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___254;

struct cred___246;

struct signal_struct___211;

struct vm_struct___171;

struct task_struct___255 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___255 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___254 *mm;
	struct mm_struct___254 *active_mm;
	struct vmacache___254 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___255 *real_parent;
	struct task_struct___255 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___255 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___188 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___188 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___188 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___246 *ptracer_cred;
	const struct cred___246 *real_cred;
	const struct cred___246 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___228 *nsproxy;
	struct signal_struct___211 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___255 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___60 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___64 *splice_pipe;
	struct page_frag___254 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___255 *oom_reaper_list;
	struct vm_struct___171 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___127 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___255 *pgtable_t___254;

struct address_space___253;

struct dev_pagemap___244;

struct page___255 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___253 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___255 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___254 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___254 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___244 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___254;

struct lruvec___254 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___254 *pgdat;
};

struct zone___254 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___254 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___254 {
	struct zone___254 *zone;
	int zone_idx;
};

struct zonelist___254 {
	struct zoneref___254 _zonerefs[25];
};

struct pglist_data___254 {
	struct zone___254 node_zones[3];
	struct zonelist___254 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___255 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___255 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___254 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___255 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___255 *owner;
};

struct secondary_data___255 {
	void *stack;
	struct task_struct___255 *task;
	long int status;
};

struct blocking_notifier_head___254 {
	struct rw_semaphore___255 rwsem;
	struct notifier_block *head;
};

struct key___246;

struct user_struct___246 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___246 *uid_keyring;
	struct key___246 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___244;

struct vm_area_struct___255 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___255 *vm_next;
	struct vm_area_struct___255 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___254 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___244 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___254 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___254;

struct mm_struct___254 {
	struct {
		struct vm_area_struct___255 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___254 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___255 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___254 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___255 *owner;
		struct user_namespace___3 *user_ns;
		struct file___254 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___254 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___246 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___246 *session_keyring;
	struct key___246 *process_keyring;
	struct key___246 *thread_keyring;
	struct key___246 *request_key_auth;
	void *security;
	struct user_struct___246 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct signal_struct___211 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___255 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___255 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___188 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___188 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___254 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___188 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct fasync_struct___253;

struct pipe_buffer___64;

struct pipe_inode_info___64 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___255 *tmp_page;
	struct fasync_struct___253 *fasync_readers;
	struct fasync_struct___253 *fasync_writers;
	struct pipe_buffer___64 *bufs;
	struct user_struct___246 *user;
};

struct vm_struct___171 {
	struct vm_struct___171 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___255 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___223 {
	struct task_struct___255 task;
	long unsigned int stack[8192];
};

struct address_space_operations___253;

struct address_space___253 {
	struct inode___254 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___255 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___253 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___244)(struct vm_area_struct___255 *, long unsigned int, const struct page___255 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___244)(struct page___255 *, void *);

struct device___218;

struct dev_pagemap___244 {
	dev_page_fault_t___244 page_fault;
	dev_page_free_t___244 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___218 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct dentry___254;

struct path___254 {
	struct vfsmount *mnt;
	struct dentry___254 *dentry;
};

struct file___254 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___254 f_path;
	struct inode___254 *f_inode;
	const struct file_operations___254 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___188 f_owner;
	const struct cred___246 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___253 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___244;

struct vm_operations_struct___244 {
	void (*open)(struct vm_area_struct___255 *);
	void (*close)(struct vm_area_struct___255 *);
	int (*split)(struct vm_area_struct___255 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___255 *);
	vm_fault_t (*fault)(struct vm_fault___244 *);
	vm_fault_t (*huge_fault)(struct vm_fault___244 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___244 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___255 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___244 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___244 *);
	int (*access)(struct vm_area_struct___255 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___255 *);
	int (*set_policy)(struct vm_area_struct___255 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___255 *, long unsigned int);
	struct page___255 * (*find_special_page)(struct vm_area_struct___255 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___254 {
	struct task_struct___255 *task;
	struct core_thread___254 *next;
};

struct core_state___254 {
	atomic_t nr_threads;
	struct core_thread___254 dumper;
	struct completion startup;
};

struct vm_fault___244 {
	struct vm_area_struct___255 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___255 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___255 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___254 prealloc_pte;
};

struct crypto_async_request___15;

typedef void (*crypto_completion_t___15)(struct crypto_async_request___15 *, int);

struct crypto_tfm___15;

struct crypto_async_request___15 {
	struct list_head list;
	crypto_completion_t___15 complete;
	void *data;
	struct crypto_tfm___15 *tfm;
	u32 flags;
};

struct crypto_ablkcipher___15;

struct ablkcipher_request___15;

struct ablkcipher_tfm___15 {
	int (*setkey)(struct crypto_ablkcipher___15 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___15 *);
	int (*decrypt)(struct ablkcipher_request___15 *);
	struct crypto_ablkcipher___15 *base;
	unsigned int ivsize;
	unsigned int reqsize;
};

struct blkcipher_desc___15;

struct blkcipher_tfm___15 {
	void *iv;
	int (*setkey)(struct crypto_tfm___15 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___15 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___15 *, struct scatterlist *, struct scatterlist *, unsigned int);
};

struct cipher_tfm___15 {
	int (*cit_setkey)(struct crypto_tfm___15 *, const u8 *, unsigned int);
	void (*cit_encrypt_one)(struct crypto_tfm___15 *, u8 *, const u8 *);
	void (*cit_decrypt_one)(struct crypto_tfm___15 *, u8 *, const u8 *);
};

struct compress_tfm___15 {
	int (*cot_compress)(struct crypto_tfm___15 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*cot_decompress)(struct crypto_tfm___15 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___15;

struct crypto_tfm___15 {
	u32 crt_flags;
	union {
		struct ablkcipher_tfm___15 ablkcipher;
		struct blkcipher_tfm___15 blkcipher;
		struct cipher_tfm___15 cipher;
		struct compress_tfm___15 compress;
	} crt_u;
	void (*exit)(struct crypto_tfm___15 *);
	struct crypto_alg___15 *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct ablkcipher_request___15 {
	struct crypto_async_request___15 base;
	unsigned int nbytes;
	void *info;
	struct scatterlist *src;
	struct scatterlist *dst;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_blkcipher___15;

struct blkcipher_desc___15 {
	struct crypto_blkcipher___15 *tfm;
	void *info;
	u32 flags;
};

struct crypto_blkcipher___15 {
	struct crypto_tfm___15 base;
};

struct skcipher_givcrypt_request___5;

struct ablkcipher_alg___15 {
	int (*setkey)(struct crypto_ablkcipher___15 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___15 *);
	int (*decrypt)(struct ablkcipher_request___15 *);
	int (*givencrypt)(struct skcipher_givcrypt_request___5 *);
	int (*givdecrypt)(struct skcipher_givcrypt_request___5 *);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct crypto_ablkcipher___15 {
	struct crypto_tfm___15 base;
};

struct skcipher_givcrypt_request___5 {
	u64 seq;
	u8 *giv;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ablkcipher_request___15 creq;
};

struct blkcipher_alg___15 {
	int (*setkey)(struct crypto_tfm___15 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___15 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___15 *, struct scatterlist *, struct scatterlist *, unsigned int);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct cipher_alg___15 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___15 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___15 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___15 *, u8 *, const u8 *);
};

struct compress_alg___15 {
	int (*coa_compress)(struct crypto_tfm___15 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___15 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_type___10;

struct crypto_alg___15 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type___10 *cra_type;
	union {
		struct ablkcipher_alg___15 ablkcipher;
		struct blkcipher_alg___15 blkcipher;
		struct cipher_alg___15 cipher;
		struct compress_alg___15 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___15 *);
	void (*cra_exit)(struct crypto_tfm___15 *);
	void (*cra_destroy)(struct crypto_alg___15 *);
	struct module___208 *cra_module;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct crypto_instance___10;

struct crypto_type___10 {
	unsigned int (*ctxsize)(struct crypto_alg___15 *, u32, u32);
	unsigned int (*extsize)(struct crypto_alg___15 *);
	int (*init)(struct crypto_tfm___15 *, u32, u32);
	int (*init_tfm)(struct crypto_tfm___15 *);
	void (*show)(struct seq_file___9 *, struct crypto_alg___15 *);
	int (*report)(struct sk_buff___6 *, struct crypto_alg___15 *);
	void (*free)(struct crypto_instance___10 *);
	unsigned int type;
	unsigned int maskclear;
	unsigned int maskset;
	unsigned int tfmsize;
};

struct kset___241;

struct kobj_type___241;

struct kernfs_node___249;

struct kobject___242 {
	const char *name;
	struct list_head entry;
	struct kobject___242 *parent;
	struct kset___241 *kset;
	struct kobj_type___241 *ktype;
	struct kernfs_node___249 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___205 {
	struct kobject___242 kobj;
	struct module___208 *mod;
	struct kobject___242 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___205 {
	struct module___208 *mod;
	struct latch_tree_node node;
};

struct module_layout___205 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___205 mtn;
};

struct module_attribute___205;

struct kernel_param___205;

struct module___208 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___205 mkobj;
	struct module_attribute___205 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___242 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___205 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___205 core_layout;
	struct module_layout___205 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct crypto_cipher___2 {
	struct crypto_tfm___15 base;
};

struct crypto_comp___2 {
	struct crypto_tfm___15 base;
};

struct aead_request___5 {
	struct crypto_async_request___15 base;
	unsigned int assoclen;
	unsigned int cryptlen;
	u8 *iv;
	struct scatterlist *src;
	struct scatterlist *dst;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_aead___5;

struct aead_alg___5 {
	int (*setkey)(struct crypto_aead___5 *, const u8 *, unsigned int);
	int (*setauthsize)(struct crypto_aead___5 *, unsigned int);
	int (*encrypt)(struct aead_request___5 *);
	int (*decrypt)(struct aead_request___5 *);
	int (*init)(struct crypto_aead___5 *);
	void (*exit)(struct crypto_aead___5 *);
	const char *geniv;
	unsigned int ivsize;
	unsigned int maxauthsize;
	unsigned int chunksize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_alg___15 base;
};

struct crypto_aead___5 {
	unsigned int authsize;
	unsigned int reqsize;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_tfm___15 base;
};

struct hash_alg_common___2 {
	unsigned int digestsize;
	unsigned int statesize;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_alg___15 base;
};

struct ahash_request___2 {
	struct crypto_async_request___15 base;
	unsigned int nbytes;
	struct scatterlist *src;
	u8 *result;
	void *priv;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_ahash___2 {
	int (*init)(struct ahash_request___2 *);
	int (*update)(struct ahash_request___2 *);
	int (*final)(struct ahash_request___2 *);
	int (*finup)(struct ahash_request___2 *);
	int (*digest)(struct ahash_request___2 *);
	int (*export)(struct ahash_request___2 *, void *);
	int (*import)(struct ahash_request___2 *, const void *);
	int (*setkey)(struct crypto_ahash___2 *, const u8 *, unsigned int);
	unsigned int reqsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_tfm___15 base;
};

struct crypto_shash___6;

struct shash_desc___4 {
	struct crypto_shash___6 *tfm;
	u32 flags;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_shash___6 {
	unsigned int descsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_tfm___15 base;
};

struct skcipher_request___3 {
	unsigned int cryptlen;
	u8 *iv;
	struct scatterlist *src;
	struct scatterlist *dst;
	struct crypto_async_request___15 base;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_skcipher___3 {
	int (*setkey)(struct crypto_skcipher___3 *, const u8 *, unsigned int);
	int (*encrypt)(struct skcipher_request___3 *);
	int (*decrypt)(struct skcipher_request___3 *);
	unsigned int ivsize;
	unsigned int reqsize;
	unsigned int keysize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_tfm___15 base;
};

struct kernfs_root___248;

struct kernfs_elem_dir___248 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___248 *root;
};

struct kernfs_syscall_ops___248;

struct kernfs_root___248 {
	struct kernfs_node___249 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___248 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___248 {
	struct kernfs_node___249 *target_kn;
};

struct kernfs_ops___248;

struct kernfs_elem_attr___248 {
	const struct kernfs_ops___248 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___249 *notify_next;
};

struct kernfs_node___249 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___249 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___248 dir;
		struct kernfs_elem_symlink___248 symlink;
		struct kernfs_elem_attr___248 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___248;

struct kernfs_ops___248 {
	int (*open)(struct kernfs_open_file___248 *);
	void (*release)(struct kernfs_open_file___248 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___248 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___248 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___248 *, struct vm_area_struct___255 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___248 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___248 {
	int (*remount_fs)(struct kernfs_root___248 *, int *, char *);
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___248 *);
	int (*mkdir)(struct kernfs_node___249 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___249 *);
	int (*rename)(struct kernfs_node___249 *, struct kernfs_node___249 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___249 *, struct kernfs_root___248 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___248 {
	struct kernfs_node___249 *kn;
	struct file___254 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___244 *vm_ops;
};

struct bin_attribute___219;

struct attribute_group___220 {
	const char *name;
	umode_t (*is_visible)(struct kobject___242 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___242 *, struct bin_attribute___219 *, int);
	struct attribute **attrs;
	struct bin_attribute___219 **bin_attrs;
};

struct bin_attribute___219 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___254 *, struct kobject___242 *, struct bin_attribute___219 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___254 *, struct kobject___242 *, struct bin_attribute___219 *, char *, loff_t, size_t);
	int (*mmap)(struct file___254 *, struct kobject___242 *, struct bin_attribute___219 *, struct vm_area_struct___255 *);
};

struct sysfs_ops___241 {
	ssize_t (*show)(struct kobject___242 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___242 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___241;

struct kset___241 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___242 kobj;
	const struct kset_uevent_ops___241 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___241 {
	void (*release)(struct kobject___242 *);
	const struct sysfs_ops___241 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___23 * (*child_ns_type)(struct kobject___242 *);
	const void * (*namespace)(struct kobject___242 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___241 {
	int (* const filter)(struct kset___241 *, struct kobject___242 *);
	const char * (* const name)(struct kset___241 *, struct kobject___242 *);
	int (* const uevent)(struct kset___241 *, struct kobject___242 *, struct kobj_uevent_env *);
};

struct kobj_attribute___235 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___242 *, struct kobj_attribute___235 *, char *);
	ssize_t (*store)(struct kobject___242 *, struct kobj_attribute___235 *, const char *, size_t);
};

struct kernel_param_ops___205 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___205 *);
	int (*get)(char *, const struct kernel_param___205 *);
	void (*free)(void *);
};

struct kparam_array___205;

struct kernel_param___205 {
	const char *name;
	struct module___208 *mod;
	const struct kernel_param_ops___205 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___205 *arr;
	};
};

struct kparam_array___205 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___205 *ops;
	void *elem;
};

struct module_attribute___205 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___205 *, struct module_kobject___205 *, char *);
	ssize_t (*store)(struct module_attribute___205 *, struct module_kobject___205 *, const char *, size_t);
	void (*setup)(struct module___208 *, const char *);
	int (*test)(struct module___208 *);
	void (*free)(struct module___208 *);
};

struct dev_pm_info___218 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___218 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___218;

struct bus_type___218;

struct device_driver___218;

struct dev_pm_domain___218;

struct dma_map_ops___61;

struct fwnode_handle___153;

struct class___218;

struct device___218 {
	struct device___218 *parent;
	struct device_private *p;
	struct kobject___242 kobj;
	const char *init_name;
	const struct device_type___218 *type;
	struct mutex mutex;
	struct bus_type___218 *bus;
	struct device_driver___218 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___218 power;
	struct dev_pm_domain___218 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___61 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___153 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___218 *class;
	const struct attribute_group___220 **groups;
	void (*release)(struct device___218 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___253;

struct super_block___253;

struct dentry___254 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___254 *d_parent;
	struct qstr d_name;
	struct inode___254 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___253 *d_op;
	struct super_block___253 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___253;

struct block_device___254;

struct inode___254 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___253 *i_op;
	struct super_block___253 *i_sb;
	struct address_space___253 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___255 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___254 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___253 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___64 *i_pipe;
		struct block_device___254 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___253 {
	int (*d_revalidate)(struct dentry___254 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___254 *, unsigned int);
	int (*d_hash)(const struct dentry___254 *, struct qstr *);
	int (*d_compare)(const struct dentry___254 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___254 *);
	int (*d_init)(struct dentry___254 *);
	void (*d_release)(struct dentry___254 *);
	void (*d_prune)(struct dentry___254 *);
	void (*d_iput)(struct dentry___254 *, struct inode___254 *);
	char * (*d_dname)(struct dentry___254 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___254 *);
	int (*d_manage)(const struct path___254 *, bool);
	struct dentry___254 * (*d_real)(struct dentry___254 *, const struct inode___254 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___253;

struct mem_dqinfo___253 {
	struct quota_format_type___253 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___253;

struct quota_info___253 {
	unsigned int flags;
	struct rw_semaphore___255 dqio_sem;
	struct inode___254 *files[3];
	struct mem_dqinfo___253 info[3];
	const struct quota_format_ops___253 *ops[3];
};

struct rcuwait___253 {
	struct task_struct___255 *task;
};

struct percpu_rw_semaphore___253 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___255 rw_sem;
	struct rcuwait___253 writer;
	int readers_block;
};

struct sb_writers___253 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___253 rw_sem[3];
};

struct file_system_type___253;

struct super_operations___253;

struct dquot_operations___253;

struct quotactl_ops___253;

struct super_block___253 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___253 *s_type;
	const struct super_operations___253 *s_op;
	const struct dquot_operations___253 *dq_op;
	const struct quotactl_ops___253 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___254 *s_root;
	struct rw_semaphore___255 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___254 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___253 s_dquot;
	struct sb_writers___253 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___253 *s_d_op;
	int cleancache_poolid;
	struct shrinker___109 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___254 {
	struct file___254 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___254 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___253 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___254 *ia_file;
};

struct dquot___253 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___253 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___253 {
	int qf_fmt_id;
	const struct quota_format_ops___253 *qf_ops;
	struct module___208 *qf_owner;
	struct quota_format_type___253 *qf_next;
};

struct quota_format_ops___253 {
	int (*check_quota_file)(struct super_block___253 *, int);
	int (*read_file_info)(struct super_block___253 *, int);
	int (*write_file_info)(struct super_block___253 *, int);
	int (*free_file_info)(struct super_block___253 *, int);
	int (*read_dqblk)(struct dquot___253 *);
	int (*commit_dqblk)(struct dquot___253 *);
	int (*release_dqblk)(struct dquot___253 *);
	int (*get_next_id)(struct super_block___253 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___253 {
	int (*write_dquot)(struct dquot___253 *);
	struct dquot___253 * (*alloc_dquot)(struct super_block___253 *, int);
	void (*destroy_dquot)(struct dquot___253 *);
	int (*acquire_dquot)(struct dquot___253 *);
	int (*release_dquot)(struct dquot___253 *);
	int (*mark_dirty)(struct dquot___253 *);
	int (*write_info)(struct super_block___253 *, int);
	qsize_t * (*get_reserved_space)(struct inode___254 *);
	int (*get_projid)(struct inode___254 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___254 *, qsize_t *);
	int (*get_next_id)(struct super_block___253 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___253 {
	int (*quota_on)(struct super_block___253 *, int, int, const struct path___254 *);
	int (*quota_off)(struct super_block___253 *, int);
	int (*quota_enable)(struct super_block___253 *, unsigned int);
	int (*quota_disable)(struct super_block___253 *, unsigned int);
	int (*quota_sync)(struct super_block___253 *, int);
	int (*set_info)(struct super_block___253 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___253 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___253 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___253 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___253 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___253 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___253 {
	int (*writepage)(struct page___255 *, struct writeback_control___3 *);
	int (*readpage)(struct file___254 *, struct page___255 *);
	int (*writepages)(struct address_space___253 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___255 *);
	int (*readpages)(struct file___254 *, struct address_space___253 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___254 *, struct address_space___253 *, loff_t, unsigned int, unsigned int, struct page___255 **, void **);
	int (*write_end)(struct file___254 *, struct address_space___253 *, loff_t, unsigned int, unsigned int, struct page___255 *, void *);
	sector_t (*bmap)(struct address_space___253 *, sector_t);
	void (*invalidatepage)(struct page___255 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___255 *, gfp_t);
	void (*freepage)(struct page___255 *);
	ssize_t (*direct_IO)(struct kiocb___254 *, struct iov_iter___121 *);
	int (*migratepage)(struct address_space___253 *, struct page___255 *, struct page___255 *, enum migrate_mode);
	bool (*isolate_page)(struct page___255 *, isolate_mode_t);
	void (*putback_page)(struct page___255 *);
	int (*launder_page)(struct page___255 *);
	int (*is_partially_uptodate)(struct page___255 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___255 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___253 *, struct page___255 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___254 *, sector_t *);
	void (*swap_deactivate)(struct file___254 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct iov_iter___121 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___3 *bvec;
		struct pipe_inode_info___64 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___254 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___254 *bd_inode;
	struct super_block___253 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___254 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___253 {
	struct dentry___254 * (*lookup)(struct inode___254 *, struct dentry___254 *, unsigned int);
	const char * (*get_link)(struct dentry___254 *, struct inode___254 *, struct delayed_call *);
	int (*permission)(struct inode___254 *, int);
	struct posix_acl * (*get_acl)(struct inode___254 *, int);
	int (*readlink)(struct dentry___254 *, char *, int);
	int (*create)(struct inode___254 *, struct dentry___254 *, umode_t, bool);
	int (*link)(struct dentry___254 *, struct inode___254 *, struct dentry___254 *);
	int (*unlink)(struct inode___254 *, struct dentry___254 *);
	int (*symlink)(struct inode___254 *, struct dentry___254 *, const char *);
	int (*mkdir)(struct inode___254 *, struct dentry___254 *, umode_t);
	int (*rmdir)(struct inode___254 *, struct dentry___254 *);
	int (*mknod)(struct inode___254 *, struct dentry___254 *, umode_t, dev_t);
	int (*rename)(struct inode___254 *, struct dentry___254 *, struct inode___254 *, struct dentry___254 *, unsigned int);
	int (*setattr)(struct dentry___254 *, struct iattr___253 *);
	int (*getattr)(const struct path___254 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___254 *, char *, size_t);
	int (*fiemap)(struct inode___254 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___254 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___254 *, struct dentry___254 *, struct file___254 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___254 *, struct dentry___254 *, umode_t);
	int (*set_acl)(struct inode___254 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___253 {
	void (*fl_copy_lock)(struct file_lock___254 *, struct file_lock___254 *);
	void (*fl_release_private)(struct file_lock___254 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___253;

struct file_lock___254 {
	struct file_lock___254 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___254 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___253 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___253 *fl_ops;
	const struct lock_manager_operations___253 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___253 {
	int (*lm_compare_owner)(struct file_lock___254 *, struct file_lock___254 *);
	long unsigned int (*lm_owner_key)(struct file_lock___254 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___254 *);
	int (*lm_grant)(struct file_lock___254 *, int);
	bool (*lm_break)(struct file_lock___254 *);
	int (*lm_change)(struct file_lock___254 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___254 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___253 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___253 *fa_next;
	struct file___254 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___253 {
	const char *name;
	int fs_flags;
	struct dentry___254 * (*mount)(struct file_system_type___253 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___253 *);
	struct module___208 *owner;
	struct file_system_type___253 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___253 {
	struct inode___254 * (*alloc_inode)(struct super_block___253 *);
	void (*destroy_inode)(struct inode___254 *);
	void (*dirty_inode)(struct inode___254 *, int);
	int (*write_inode)(struct inode___254 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___254 *);
	void (*evict_inode)(struct inode___254 *);
	void (*put_super)(struct super_block___253 *);
	int (*sync_fs)(struct super_block___253 *, int);
	int (*freeze_super)(struct super_block___253 *);
	int (*freeze_fs)(struct super_block___253 *);
	int (*thaw_super)(struct super_block___253 *);
	int (*unfreeze_fs)(struct super_block___253 *);
	int (*statfs)(struct dentry___254 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___253 *, int *, char *);
	void (*umount_begin)(struct super_block___253 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___254 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___254 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___254 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___254 *);
	ssize_t (*quota_read)(struct super_block___253 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___253 *, int, const char *, size_t, loff_t);
	struct dquot___253 ** (*get_dquots)(struct inode___254 *);
	int (*bdev_try_to_free_page)(struct super_block___253 *, struct page___255 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___253 *, struct shrink_control___109 *);
	long int (*free_cached_objects)(struct super_block___253 *, struct shrink_control___109 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___244(struct page___255 *);

struct fwnode_operations___153;

struct fwnode_handle___153 {
	struct fwnode_handle___153 *secondary;
	const struct fwnode_operations___153 *ops;
};

struct fwnode_reference_args___153;

struct fwnode_endpoint___153;

struct fwnode_operations___153 {
	struct fwnode_handle___153 * (*get)(struct fwnode_handle___153 *);
	void (*put)(struct fwnode_handle___153 *);
	bool (*device_is_available)(const struct fwnode_handle___153 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___153 *, const struct device___218 *);
	bool (*property_present)(const struct fwnode_handle___153 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___153 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___153 *, const char *, const char **, size_t);
	struct fwnode_handle___153 * (*get_parent)(const struct fwnode_handle___153 *);
	struct fwnode_handle___153 * (*get_next_child_node)(const struct fwnode_handle___153 *, struct fwnode_handle___153 *);
	struct fwnode_handle___153 * (*get_named_child_node)(const struct fwnode_handle___153 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___153 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___153 *);
	struct fwnode_handle___153 * (*graph_get_next_endpoint)(const struct fwnode_handle___153 *, struct fwnode_handle___153 *);
	struct fwnode_handle___153 * (*graph_get_remote_endpoint)(const struct fwnode_handle___153 *);
	struct fwnode_handle___153 * (*graph_get_port_parent)(struct fwnode_handle___153 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___153 *, struct fwnode_endpoint___153 *);
};

struct fwnode_endpoint___153 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___153 *local_fwnode;
};

struct fwnode_reference_args___153 {
	struct fwnode_handle___153 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct crypto_rng___2;

struct rng_alg___2 {
	int (*generate)(struct crypto_rng___2 *, const u8 *, unsigned int, u8 *, unsigned int);
	int (*seed)(struct crypto_rng___2 *, const u8 *, unsigned int);
	void (*set_ent)(struct crypto_rng___2 *, const u8 *, unsigned int);
	unsigned int seedsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_alg___15 base;
};

struct crypto_rng___2 {
	struct crypto_tfm___15 base;
};

struct dev_pm_ops___218 {
	int (*prepare)(struct device___218 *);
	void (*complete)(struct device___218 *);
	int (*suspend)(struct device___218 *);
	int (*resume)(struct device___218 *);
	int (*freeze)(struct device___218 *);
	int (*thaw)(struct device___218 *);
	int (*poweroff)(struct device___218 *);
	int (*restore)(struct device___218 *);
	int (*suspend_late)(struct device___218 *);
	int (*resume_early)(struct device___218 *);
	int (*freeze_late)(struct device___218 *);
	int (*thaw_early)(struct device___218 *);
	int (*poweroff_late)(struct device___218 *);
	int (*restore_early)(struct device___218 *);
	int (*suspend_noirq)(struct device___218 *);
	int (*resume_noirq)(struct device___218 *);
	int (*freeze_noirq)(struct device___218 *);
	int (*thaw_noirq)(struct device___218 *);
	int (*poweroff_noirq)(struct device___218 *);
	int (*restore_noirq)(struct device___218 *);
	int (*runtime_suspend)(struct device___218 *);
	int (*runtime_resume)(struct device___218 *);
	int (*runtime_idle)(struct device___218 *);
};

struct dev_pm_domain___218 {
	struct dev_pm_ops___218 ops;
	void (*detach)(struct device___218 *, bool);
	int (*activate)(struct device___218 *);
	void (*sync)(struct device___218 *);
	void (*dismiss)(struct device___218 *);
};

struct bus_type___218 {
	const char *name;
	const char *dev_name;
	struct device___218 *dev_root;
	const struct attribute_group___220 **bus_groups;
	const struct attribute_group___220 **dev_groups;
	const struct attribute_group___220 **drv_groups;
	int (*match)(struct device___218 *, struct device_driver___218 *);
	int (*uevent)(struct device___218 *, struct kobj_uevent_env *);
	int (*probe)(struct device___218 *);
	int (*remove)(struct device___218 *);
	void (*shutdown)(struct device___218 *);
	int (*online)(struct device___218 *);
	int (*offline)(struct device___218 *);
	int (*suspend)(struct device___218 *, pm_message_t);
	int (*resume)(struct device___218 *);
	int (*num_vf)(struct device___218 *);
	int (*dma_configure)(struct device___218 *);
	const struct dev_pm_ops___218 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___218 {
	const char *name;
	struct bus_type___218 *bus;
	struct module___208 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___218 *);
	int (*remove)(struct device___218 *);
	void (*shutdown)(struct device___218 *);
	int (*suspend)(struct device___218 *, pm_message_t);
	int (*resume)(struct device___218 *);
	const struct attribute_group___220 **groups;
	const struct dev_pm_ops___218 *pm;
	void (*coredump)(struct device___218 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___218 {
	const char *name;
	const struct attribute_group___220 **groups;
	int (*uevent)(struct device___218 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___218 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___218 *);
	const struct dev_pm_ops___218 *pm;
};

struct class___218 {
	const char *name;
	struct module___208 *owner;
	const struct attribute_group___220 **class_groups;
	const struct attribute_group___220 **dev_groups;
	struct kobject___242 *dev_kobj;
	int (*dev_uevent)(struct device___218 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___218 *, umode_t *);
	void (*class_release)(struct class___218 *);
	void (*dev_release)(struct device___218 *);
	int (*shutdown_pre)(struct device___218 *);
	const struct kobj_ns_type_operations___23 *ns_type;
	const void * (*namespace)(struct device___218 *);
	const struct dev_pm_ops___218 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___61 {
	void * (*alloc)(struct device___218 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___218 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___218 *, struct vm_area_struct___255 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___218 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___218 *, struct page___255 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___218 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___218 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___218 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___218 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___218 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___218 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___218 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___218 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___218 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___218 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___218 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___218 *, u64);
	u64 (*get_required_mask)(struct device___218 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct pipe_buf_operations___64;

struct pipe_buffer___64 {
	struct page___255 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___64 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___64 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___64 *, struct pipe_buffer___64 *);
	void (*release)(struct pipe_inode_info___64 *, struct pipe_buffer___64 *);
	int (*steal)(struct pipe_inode_info___64 *, struct pipe_buffer___64 *);
	union {
		bool (*get)(struct pipe_inode_info___64 *, struct pipe_buffer___64 *);
		struct {
			void (*get)(struct pipe_inode_info___64 *, struct pipe_buffer___64 *);
		} __UNIQUE_ID_rh_kabi_hide21;
		union {		};
	};
};

struct crypto_template___11;

struct crypto_instance___10 {
	struct crypto_alg___15 alg;
	struct crypto_template___11 *tmpl;
	struct hlist_node list;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_template___11 {
	struct list_head list;
	struct hlist_head instances;
	struct module___208 *module;
	struct crypto_instance___10 * (*alloc)(struct rtattr **);
	void (*free)(struct crypto_instance___10 *);
	int (*create)(struct crypto_template___11 *, struct rtattr **);
	char name[128];
};

struct drbg_string {
	const unsigned char *buf;
	size_t len;
	struct list_head list;
};

struct drbg_test_data {
	struct drbg_string *testentropy;
};

struct akcipher_request___3 {
	struct crypto_async_request___15 base;
	struct scatterlist *src;
	struct scatterlist *dst;
	unsigned int src_len;
	unsigned int dst_len;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_akcipher___3 {
	struct crypto_tfm___15 base;
};

struct akcipher_alg___3 {
	int (*sign)(struct akcipher_request___3 *);
	int (*verify)(struct akcipher_request___3 *);
	int (*encrypt)(struct akcipher_request___3 *);
	int (*decrypt)(struct akcipher_request___3 *);
	int (*set_pub_key)(struct crypto_akcipher___3 *, const void *, unsigned int);
	int (*set_priv_key)(struct crypto_akcipher___3 *, const void *, unsigned int);
	unsigned int (*max_size)(struct crypto_akcipher___3 *);
	int (*init)(struct crypto_akcipher___3 *);
	void (*exit)(struct crypto_akcipher___3 *);
	unsigned int reqsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_alg___15 base;
};

struct kpp_request___2 {
	struct crypto_async_request___15 base;
	struct scatterlist *src;
	struct scatterlist *dst;
	unsigned int src_len;
	unsigned int dst_len;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_kpp___2 {
	struct crypto_tfm___15 base;
};

struct kpp_alg___2 {
	int (*set_secret)(struct crypto_kpp___2 *, const void *, unsigned int);
	int (*generate_public_key)(struct kpp_request___2 *);
	int (*compute_shared_secret)(struct kpp_request___2 *);
	unsigned int (*max_size)(struct crypto_kpp___2 *);
	int (*init)(struct crypto_kpp___2 *);
	void (*exit)(struct crypto_kpp___2 *);
	unsigned int reqsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_alg___15 base;
};

struct acomp_req___2 {
	struct crypto_async_request___15 base;
	struct scatterlist *src;
	struct scatterlist *dst;
	unsigned int slen;
	unsigned int dlen;
	u32 flags;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_acomp___2 {
	int (*compress)(struct acomp_req___2 *);
	int (*decompress)(struct acomp_req___2 *);
	void (*dst_free)(struct scatterlist *);
	unsigned int reqsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_tfm___15 base;
};

typedef int (*key_restrict_link_func_t___247)(struct key___246 *, const struct key_type *, const union key_payload *, struct key___246 *);

struct key_restriction___246;

struct key___246 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___255 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key___5 index_key;
		struct {
			struct key_type___5 *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___246 *restrict_link;
};

struct key_restriction___246 {
	key_restrict_link_func_t___247 check;
	struct key___246 *key;
	struct key_type *keytype;
};

struct hash_testvec {
	const char *key;
	const char *plaintext;
	const char *digest;
	unsigned char tap[8];
	short unsigned int psize;
	unsigned char np;
	unsigned char ksize;
};

struct cipher_testvec {
	const char *key;
	const char *iv;
	const char *ptext;
	const char *ctext;
	short unsigned int tap[8];
	int np;
	unsigned char also_non_np;
	bool fail;
	unsigned char wk;
	unsigned char klen;
	short unsigned int len;
	bool fips_skip;
	bool generates_iv;
};

struct aead_testvec {
	const char *key;
	const char *iv;
	const char *input;
	const char *assoc;
	const char *result;
	unsigned char tap[8];
	unsigned char atap[8];
	int np;
	int anp;
	bool fail;
	unsigned char novrfy;
	unsigned char wk;
	unsigned char klen;
	short unsigned int ilen;
	short unsigned int alen;
	short unsigned int rlen;
};

struct cprng_testvec {
	const char *key;
	const char *dt;
	const char *v;
	const char *result;
	unsigned char klen;
	short unsigned int dtlen;
	short unsigned int vlen;
	short unsigned int rlen;
	short unsigned int loops;
};

struct drbg_testvec {
	const unsigned char *entropy;
	size_t entropylen;
	const unsigned char *entpra;
	const unsigned char *entprb;
	size_t entprlen;
	const unsigned char *addtla;
	const unsigned char *addtlb;
	size_t addtllen;
	const unsigned char *pers;
	size_t perslen;
	const unsigned char *expected;
	size_t expectedlen;
};

struct akcipher_testvec {
	const unsigned char *key;
	const unsigned char *m;
	const unsigned char *c;
	unsigned int key_len;
	unsigned int m_size;
	unsigned int c_size;
	bool public_key_vec;
	bool siggen_sigver_test;
};

struct kpp_testvec {
	const unsigned char *secret;
	const unsigned char *b_secret;
	const unsigned char *b_public;
	const unsigned char *expected_a_public;
	const unsigned char *expected_ss;
	short unsigned int secret_size;
	short unsigned int b_secret_size;
	short unsigned int b_public_size;
	short unsigned int expected_a_public_size;
	short unsigned int expected_ss_size;
	bool genkey;
};

struct comp_testvec {
	int inlen;
	int outlen;
	char input[512];
	char output[512];
};

struct aead_test_suite {
	struct {
		const struct aead_testvec *vecs;
		unsigned int count;
	} enc;
	struct {
		const struct aead_testvec *vecs;
		unsigned int count;
	} dec;
};

struct cipher_test_suite {
	const struct cipher_testvec *vecs;
	unsigned int count;
};

struct comp_test_suite {
	struct {
		const struct comp_testvec *vecs;
		unsigned int count;
	} comp;
	struct {
		const struct comp_testvec *vecs;
		unsigned int count;
	} decomp;
};

struct hash_test_suite {
	const struct hash_testvec *vecs;
	unsigned int count;
};

struct cprng_test_suite {
	const struct cprng_testvec *vecs;
	unsigned int count;
};

struct drbg_test_suite {
	const struct drbg_testvec *vecs;
	unsigned int count;
};

struct akcipher_test_suite {
	const struct akcipher_testvec *vecs;
	unsigned int count;
};

struct kpp_test_suite {
	const struct kpp_testvec *vecs;
	unsigned int count;
};

struct alg_test_desc {
	const char *alg;
	int (*test)(const struct alg_test_desc *, const char *, u32, u32);
	int fips_allowed;
	union {
		struct aead_test_suite aead;
		struct cipher_test_suite cipher;
		struct comp_test_suite comp;
		struct hash_test_suite hash;
		struct cprng_test_suite cprng;
		struct drbg_test_suite drbg;
		struct akcipher_test_suite akcipher;
		struct kpp_test_suite kpp;
	} suite;
};

struct hmac_ctx {
	struct crypto_shash___5 *hash;
};

struct md5_state {
	u32 hash[4];
	u32 block[16];
	u64 byte_count;
};

struct sha1_state {
	u32 state[5];
	u64 count;
	u8 buffer[64];
};

typedef void sha1_block_fn(struct sha1_state *, const u8 *, int);

struct sha256_state {
	u32 state[8];
	u64 count;
	u8 buf[64];
};

typedef void sha256_block_fn(struct sha256_state *, const u8 *, int);

typedef struct {
	u64 a;
	u64 b;
} u128;

typedef struct {
	__le64 b;
	__le64 a;
} le128;

struct gf128mul_4k {
	be128 t[256];
};

struct gf128mul_64k {
	struct gf128mul_4k *t[16];
};

struct crypto_cipher___3 {
	struct crypto_tfm___13 base;
};

struct crypto_ecb_ctx {
	struct crypto_cipher___3 *child;
};

struct crypto_cbc_ctx {
	struct crypto_cipher___3 *child;
};

struct crypto_cfb_ctx {
	struct crypto_cipher___3 *child;
};

struct crypto_ctr_ctx {
	struct crypto_cipher___3 *child;
};

struct crypto_rfc3686_ctx {
	struct crypto_skcipher___2 *child;
	u8 nonce[4];
};

struct crypto_rfc3686_req_ctx {
	u8 iv[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct skcipher_request___2 subreq;
};

struct gcm_instance_ctx {
	struct crypto_skcipher_spawn ctr;
	struct crypto_ahash_spawn ghash;
};

struct crypto_gcm_ctx {
	struct crypto_skcipher___2 *ctr;
	struct crypto_ahash *ghash;
};

struct crypto_rfc4106_ctx {
	struct crypto_aead___4 *child;
	u8 nonce[4];
};

struct crypto_rfc4106_req_ctx {
	struct scatterlist src[3];
	struct scatterlist dst[3];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct aead_request___4 subreq;
};

struct crypto_rfc4543_instance_ctx {
	struct crypto_aead_spawn aead;
};

struct crypto_rfc4543_ctx {
	struct crypto_aead___4 *child;
	struct crypto_skcipher___2 *null;
	u8 nonce[4];
};

struct crypto_rfc4543_req_ctx {
	struct aead_request___4 subreq;
};

struct crypto_gcm_ghash_ctx {
	unsigned int cryptlen;
	struct scatterlist *src;
	int (*complete)(struct aead_request___4 *, u32);
};

struct crypto_gcm_req_priv_ctx {
	u8 iv[16];
	u8 auth_tag[16];
	u8 iauth_tag[16];
	struct scatterlist src[3];
	struct scatterlist dst[3];
	struct scatterlist sg;
	struct crypto_gcm_ghash_ctx ghash_ctx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	union {
		struct ahash_request ahreq;
		struct skcipher_request___2 skreq;
	} u;
};

struct cryptd_ablkcipher {
	struct crypto_ablkcipher___13 base;
};

struct cryptd_skcipher {
	struct crypto_skcipher___2 base;
};

struct cryptd_ahash {
	struct crypto_ahash base;
};

struct cryptd_aead {
	struct crypto_aead___4 base;
};

struct cryptd_cpu_queue {
	struct crypto_queue queue;
	struct work_struct work;
};

struct cryptd_queue {
	struct cryptd_cpu_queue *cpu_queue;
};

struct cryptd_instance_ctx {
	struct crypto_spawn___3 spawn;
	struct cryptd_queue *queue;
};

struct skcipherd_instance_ctx {
	struct crypto_skcipher_spawn spawn;
	struct cryptd_queue *queue;
};

struct hashd_instance_ctx {
	struct crypto_shash_spawn spawn;
	struct cryptd_queue *queue;
};

struct aead_instance_ctx {
	struct crypto_aead_spawn aead_spawn;
	struct cryptd_queue *queue;
};

struct cryptd_blkcipher_ctx {
	atomic_t refcnt;
	struct crypto_blkcipher___13 *child;
};

struct cryptd_blkcipher_request_ctx {
	crypto_completion_t___13 complete;
};

struct cryptd_skcipher_ctx {
	atomic_t refcnt;
	struct crypto_skcipher___2 *child;
};

struct cryptd_skcipher_request_ctx {
	crypto_completion_t___13 complete;
};

struct cryptd_hash_ctx {
	atomic_t refcnt;
	struct crypto_shash___5 *child;
};

struct cryptd_hash_request_ctx {
	crypto_completion_t___13 complete;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct shash_desc___3 desc;
};

struct cryptd_aead_ctx {
	atomic_t refcnt;
	struct crypto_aead___4 *child;
};

struct cryptd_aead_request_ctx {
	crypto_completion_t___13 complete;
};

typedef unsigned char Byte;

typedef long unsigned int uLong;

struct internal_state;

struct z_stream_s {
	const Byte *next_in;
	uLong avail_in;
	uLong total_in;
	Byte *next_out;
	uLong avail_out;
	uLong total_out;
	char *msg;
	struct internal_state *state;
	void *workspace;
	int data_type;
	uLong adler;
	uLong reserved;
};

struct internal_state {
	int dummy;
};

struct deflate_ctx {
	struct z_stream_s comp_stream;
	struct z_stream_s decomp_stream;
};

struct chksum_ctx {
	u32 key;
};

struct chksum_desc_ctx {
	u32 crc;
};

struct crypto_shash___7;

struct shash_desc___5 {
	struct crypto_shash___7 *tfm;
	u32 flags;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_shash___7 {
	unsigned int descsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_tfm___14 base;
};

struct shash_alg___3 {
	int (*init)(struct shash_desc___5 *);
	int (*update)(struct shash_desc___5 *, const u8 *, unsigned int);
	int (*final)(struct shash_desc___5 *, u8 *);
	int (*finup)(struct shash_desc___5 *, const u8 *, unsigned int, u8 *);
	int (*digest)(struct shash_desc___5 *, const u8 *, unsigned int, u8 *);
	int (*export)(struct shash_desc___5 *, void *);
	int (*import)(struct shash_desc___5 *, const void *);
	int (*setkey)(struct crypto_shash___7 *, const u8 *, unsigned int);
	unsigned int descsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int digestsize;
	unsigned int statesize;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_alg___14 base;
};

struct chksum_desc_ctx___2 {
	__u16 crc;
};

struct lzo_ctx {
	void *lzo_comp_mem;
};

struct crypto_rng___3;

struct rng_alg___3 {
	int (*generate)(struct crypto_rng___3 *, const u8 *, unsigned int, u8 *, unsigned int);
	int (*seed)(struct crypto_rng___3 *, const u8 *, unsigned int);
	void (*set_ent)(struct crypto_rng___3 *, const u8 *, unsigned int);
	unsigned int seedsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_alg___12 base;
};

struct crypto_rng___3 {
	struct crypto_tfm___12 base;
};

struct crypto_report_rng {
	char type[64];
	unsigned int seedsize;
};

struct random_ready_callback {
	struct list_head list;
	void (*func)(struct random_ready_callback *);
	struct module___71 *owner;
};

struct crypto_async_request___16;

typedef void (*crypto_completion_t___16)(struct crypto_async_request___16 *, int);

struct crypto_tfm___16;

struct crypto_async_request___16 {
	struct list_head list;
	crypto_completion_t___16 complete;
	void *data;
	struct crypto_tfm___16 *tfm;
	u32 flags;
};

struct crypto_ablkcipher___16;

struct ablkcipher_request___16;

struct ablkcipher_tfm___16 {
	int (*setkey)(struct crypto_ablkcipher___16 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___16 *);
	int (*decrypt)(struct ablkcipher_request___16 *);
	struct crypto_ablkcipher___16 *base;
	unsigned int ivsize;
	unsigned int reqsize;
};

struct blkcipher_desc___16;

struct blkcipher_tfm___16 {
	void *iv;
	int (*setkey)(struct crypto_tfm___16 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___16 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___16 *, struct scatterlist *, struct scatterlist *, unsigned int);
};

struct cipher_tfm___16 {
	int (*cit_setkey)(struct crypto_tfm___16 *, const u8 *, unsigned int);
	void (*cit_encrypt_one)(struct crypto_tfm___16 *, u8 *, const u8 *);
	void (*cit_decrypt_one)(struct crypto_tfm___16 *, u8 *, const u8 *);
};

struct compress_tfm___16 {
	int (*cot_compress)(struct crypto_tfm___16 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*cot_decompress)(struct crypto_tfm___16 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___16;

struct crypto_tfm___16 {
	u32 crt_flags;
	union {
		struct ablkcipher_tfm___16 ablkcipher;
		struct blkcipher_tfm___16 blkcipher;
		struct cipher_tfm___16 cipher;
		struct compress_tfm___16 compress;
	} crt_u;
	void (*exit)(struct crypto_tfm___16 *);
	struct crypto_alg___16 *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct ablkcipher_request___16 {
	struct crypto_async_request___16 base;
	unsigned int nbytes;
	void *info;
	struct scatterlist *src;
	struct scatterlist *dst;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_blkcipher___16;

struct blkcipher_desc___16 {
	struct crypto_blkcipher___16 *tfm;
	void *info;
	u32 flags;
};

struct crypto_blkcipher___16 {
	struct crypto_tfm___16 base;
};

struct skcipher_givcrypt_request___6;

struct ablkcipher_alg___16 {
	int (*setkey)(struct crypto_ablkcipher___16 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___16 *);
	int (*decrypt)(struct ablkcipher_request___16 *);
	int (*givencrypt)(struct skcipher_givcrypt_request___6 *);
	int (*givdecrypt)(struct skcipher_givcrypt_request___6 *);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct crypto_ablkcipher___16 {
	struct crypto_tfm___16 base;
};

struct skcipher_givcrypt_request___6 {
	u64 seq;
	u8 *giv;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ablkcipher_request___16 creq;
};

struct blkcipher_alg___16 {
	int (*setkey)(struct crypto_tfm___16 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___16 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___16 *, struct scatterlist *, struct scatterlist *, unsigned int);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct cipher_alg___16 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___16 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___16 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___16 *, u8 *, const u8 *);
};

struct compress_alg___16 {
	int (*coa_compress)(struct crypto_tfm___16 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___16 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_type___11;

struct crypto_alg___16 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type___11 *cra_type;
	union {
		struct ablkcipher_alg___16 ablkcipher;
		struct blkcipher_alg___16 blkcipher;
		struct cipher_alg___16 cipher;
		struct compress_alg___16 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___16 *);
	void (*cra_exit)(struct crypto_tfm___16 *);
	void (*cra_destroy)(struct crypto_alg___16 *);
	struct module___71 *cra_module;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct crypto_instance___11;

struct crypto_type___11 {
	unsigned int (*ctxsize)(struct crypto_alg___16 *, u32, u32);
	unsigned int (*extsize)(struct crypto_alg___16 *);
	int (*init)(struct crypto_tfm___16 *, u32, u32);
	int (*init_tfm)(struct crypto_tfm___16 *);
	void (*show)(struct seq_file___9 *, struct crypto_alg___16 *);
	int (*report)(struct sk_buff___6 *, struct crypto_alg___16 *);
	void (*free)(struct crypto_instance___11 *);
	unsigned int type;
	unsigned int maskclear;
	unsigned int maskset;
	unsigned int tfmsize;
};

struct crypto_cipher___4 {
	struct crypto_tfm___16 base;
};

struct crypto_shash___8;

struct shash_desc___6 {
	struct crypto_shash___8 *tfm;
	u32 flags;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_shash___8 {
	unsigned int descsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_tfm___16 base;
};

struct shash_alg___4 {
	int (*init)(struct shash_desc___6 *);
	int (*update)(struct shash_desc___6 *, const u8 *, unsigned int);
	int (*final)(struct shash_desc___6 *, u8 *);
	int (*finup)(struct shash_desc___6 *, const u8 *, unsigned int, u8 *);
	int (*digest)(struct shash_desc___6 *, const u8 *, unsigned int, u8 *);
	int (*export)(struct shash_desc___6 *, void *);
	int (*import)(struct shash_desc___6 *, const void *);
	int (*setkey)(struct crypto_shash___8 *, const u8 *, unsigned int);
	unsigned int descsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int digestsize;
	unsigned int statesize;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_alg___16 base;
};

struct skcipher_request___4 {
	unsigned int cryptlen;
	u8 *iv;
	struct scatterlist *src;
	struct scatterlist *dst;
	struct crypto_async_request___16 base;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_skcipher___4 {
	int (*setkey)(struct crypto_skcipher___4 *, const u8 *, unsigned int);
	int (*encrypt)(struct skcipher_request___4 *);
	int (*decrypt)(struct skcipher_request___4 *);
	unsigned int ivsize;
	unsigned int reqsize;
	unsigned int keysize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_tfm___16 base;
};

struct crypto_template___12;

struct crypto_instance___11 {
	struct crypto_alg___16 alg;
	struct crypto_template___12 *tmpl;
	struct hlist_node list;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_template___12 {
	struct list_head list;
	struct hlist_head instances;
	struct module___71 *module;
	struct crypto_instance___11 * (*alloc)(struct rtattr **);
	void (*free)(struct crypto_instance___11 *);
	int (*create)(struct crypto_template___12 *, struct rtattr **);
	char name[128];
};

struct crypto_rng___4;

struct rng_alg___4 {
	int (*generate)(struct crypto_rng___4 *, const u8 *, unsigned int, u8 *, unsigned int);
	int (*seed)(struct crypto_rng___4 *, const u8 *, unsigned int);
	void (*set_ent)(struct crypto_rng___4 *, const u8 *, unsigned int);
	unsigned int seedsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_alg___16 base;
};

struct crypto_rng___4 {
	struct crypto_tfm___16 base;
};

typedef uint32_t drbg_flag_t;

struct drbg_core {
	drbg_flag_t flags;
	__u8 statelen;
	__u8 blocklen_bytes;
	char cra_name[128];
	char backend_cra_name[128];
};

struct drbg_state;

struct drbg_state_ops {
	int (*update)(struct drbg_state *, struct list_head *, int);
	int (*generate)(struct drbg_state *, unsigned char *, unsigned int, struct list_head *);
	int (*crypto_init)(struct drbg_state *);
	int (*crypto_fini)(struct drbg_state *);
};

struct drbg_state {
	struct mutex drbg_mutex;
	unsigned char *V;
	unsigned char *Vbuf;
	unsigned char *C;
	unsigned char *Cbuf;
	size_t reseed_ctr;
	size_t reseed_threshold;
	unsigned char *scratchpad;
	unsigned char *scratchpadbuf;
	void *priv_data;
	struct crypto_skcipher___4 *ctr_handle;
	struct skcipher_request___4 *ctr_req;
	__u8 *ctr_null_value_buf;
	__u8 *ctr_null_value;
	__u8 *outscratchpadbuf;
	__u8 *outscratchpad;
	struct crypto_wait ctr_wait;
	bool seeded;
	bool pr;
	bool fips_primed;
	unsigned char *prev;
	struct work_struct seed_work;
	struct crypto_rng___4 *jent;
	const struct drbg_state_ops *d_ops;
	const struct drbg_core *core;
	struct drbg_string test_data;
	struct random_ready_callback random_ready;
};

enum drbg_prefixes {
	DRBG_PREFIX0 = 0,
	DRBG_PREFIX1 = 1,
	DRBG_PREFIX2 = 2,
	DRBG_PREFIX3 = 3,
};

struct sdesc {
	struct shash_desc___6 shash;
	char ctx[0];
};

struct s {
	__be32 conv;
};

struct rand_data {
	__u64 data;
	__u64 old_data;
	__u64 prev_time;
	__u64 last_delta;
	__s64 last_delta2;
	unsigned int stuck: 1;
	unsigned int osr;
	unsigned int stir: 1;
	unsigned int disable_unbias: 1;
	unsigned char *mem;
	unsigned int memlocation;
	unsigned int memblocks;
	unsigned int memblocksize;
	unsigned int memaccessloops;
};

union c {
	__u64 u64;
	__u32 u32[2];
};

struct crypto_rng___5;

struct rng_alg___5 {
	int (*generate)(struct crypto_rng___5 *, const u8 *, unsigned int, u8 *, unsigned int);
	int (*seed)(struct crypto_rng___5 *, const u8 *, unsigned int);
	void (*set_ent)(struct crypto_rng___5 *, const u8 *, unsigned int);
	unsigned int seedsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_alg___14 base;
};

struct crypto_rng___5 {
	struct crypto_tfm___14 base;
};

struct rand_data___2;

struct jitterentropy {
	spinlock_t jent_lock;
	struct rand_data___2 *entropy_collector;
};

struct ghash_ctx {
	struct gf128mul_4k *gf128;
};

struct ghash_desc_ctx {
	u8 buffer[16];
	u32 bytes;
};

struct sockaddr_alg {
	__u16 salg_family;
	__u8 salg_type[14];
	__u32 salg_feat;
	__u32 salg_mask;
	__u8 salg_name[64];
};

struct af_alg_iv {
	__u32 ivlen;
	__u8 iv[0];
};

struct crypto_async_request___17;

typedef void (*crypto_completion_t___17)(struct crypto_async_request___17 *, int);

struct crypto_tfm___17;

struct crypto_async_request___17 {
	struct list_head list;
	crypto_completion_t___17 complete;
	void *data;
	struct crypto_tfm___17 *tfm;
	u32 flags;
};

struct crypto_ablkcipher___17;

struct ablkcipher_request___17;

struct ablkcipher_tfm___17 {
	int (*setkey)(struct crypto_ablkcipher___17 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___17 *);
	int (*decrypt)(struct ablkcipher_request___17 *);
	struct crypto_ablkcipher___17 *base;
	unsigned int ivsize;
	unsigned int reqsize;
};

struct blkcipher_desc___17;

struct blkcipher_tfm___17 {
	void *iv;
	int (*setkey)(struct crypto_tfm___17 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___17 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___17 *, struct scatterlist *, struct scatterlist *, unsigned int);
};

struct cipher_tfm___17 {
	int (*cit_setkey)(struct crypto_tfm___17 *, const u8 *, unsigned int);
	void (*cit_encrypt_one)(struct crypto_tfm___17 *, u8 *, const u8 *);
	void (*cit_decrypt_one)(struct crypto_tfm___17 *, u8 *, const u8 *);
};

struct compress_tfm___17 {
	int (*cot_compress)(struct crypto_tfm___17 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*cot_decompress)(struct crypto_tfm___17 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___17;

struct crypto_tfm___17 {
	u32 crt_flags;
	union {
		struct ablkcipher_tfm___17 ablkcipher;
		struct blkcipher_tfm___17 blkcipher;
		struct cipher_tfm___17 cipher;
		struct compress_tfm___17 compress;
	} crt_u;
	void (*exit)(struct crypto_tfm___17 *);
	struct crypto_alg___17 *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct ablkcipher_request___17 {
	struct crypto_async_request___17 base;
	unsigned int nbytes;
	void *info;
	struct scatterlist *src;
	struct scatterlist *dst;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_blkcipher___17;

struct blkcipher_desc___17 {
	struct crypto_blkcipher___17 *tfm;
	void *info;
	u32 flags;
};

struct crypto_blkcipher___17 {
	struct crypto_tfm___17 base;
};

struct skcipher_givcrypt_request___7;

struct ablkcipher_alg___17 {
	int (*setkey)(struct crypto_ablkcipher___17 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___17 *);
	int (*decrypt)(struct ablkcipher_request___17 *);
	int (*givencrypt)(struct skcipher_givcrypt_request___7 *);
	int (*givdecrypt)(struct skcipher_givcrypt_request___7 *);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct crypto_ablkcipher___17 {
	struct crypto_tfm___17 base;
};

struct skcipher_givcrypt_request___7 {
	u64 seq;
	u8 *giv;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ablkcipher_request___17 creq;
};

struct blkcipher_alg___17 {
	int (*setkey)(struct crypto_tfm___17 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___17 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___17 *, struct scatterlist *, struct scatterlist *, unsigned int);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct cipher_alg___17 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___17 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___17 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___17 *, u8 *, const u8 *);
};

struct compress_alg___17 {
	int (*coa_compress)(struct crypto_tfm___17 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___17 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___17 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type *cra_type;
	union {
		struct ablkcipher_alg___17 ablkcipher;
		struct blkcipher_alg___17 blkcipher;
		struct cipher_alg___17 cipher;
		struct compress_alg___17 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___17 *);
	void (*cra_exit)(struct crypto_tfm___17 *);
	void (*cra_destroy)(struct crypto_alg___17 *);
	struct module___202 *cra_module;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cmsghdr {
	__kernel_size_t cmsg_len;
	int cmsg_level;
	int cmsg_type;
};

struct net_proto_family {
	int family;
	int (*create)(struct net___6 *, struct socket___25 *, int, int);
	struct module___202 *owner;
};

enum {
	SOCK_WAKE_IO = 0,
	SOCK_WAKE_WAITD = 1,
	SOCK_WAKE_SPACE = 2,
	SOCK_WAKE_URG = 3,
};

typedef struct poll_table_struct___156 poll_table___22;

struct aead_request___6 {
	struct crypto_async_request___17 base;
	unsigned int assoclen;
	unsigned int cryptlen;
	u8 *iv;
	struct scatterlist *src;
	struct scatterlist *dst;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct skcipher_request___5 {
	unsigned int cryptlen;
	u8 *iv;
	struct scatterlist *src;
	struct scatterlist *dst;
	struct crypto_async_request___17 base;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct af_alg_type;

struct alg_sock {
	struct sock___25 sk;
	struct sock___25 *parent;
	unsigned int refcnt;
	unsigned int nokey_refcnt;
	const struct af_alg_type *type;
	void *private;
};

struct af_alg_type {
	void * (*bind)(const char *, u32, u32);
	void (*release)(void *);
	int (*setkey)(void *, const u8 *, unsigned int);
	int (*accept)(void *, struct sock___25 *);
	int (*accept_nokey)(void *, struct sock___25 *);
	int (*setauthsize)(void *, unsigned int);
	struct proto_ops___24 *ops;
	struct proto_ops___24 *ops_nokey;
	struct module___202 *owner;
	char name[14];
};

struct af_alg_control {
	struct af_alg_iv *iv;
	int op;
	unsigned int aead_assoclen;
};

struct af_alg_sgl {
	struct scatterlist sg[17];
	struct page___249 *pages[16];
	unsigned int npages;
};

struct af_alg_tsgl {
	struct list_head list;
	unsigned int cur;
	struct scatterlist sg[0];
};

struct af_alg_rsgl {
	struct af_alg_sgl sgl;
	struct list_head list;
	size_t sg_num_bytes;
};

struct af_alg_async_req {
	struct kiocb___248 *iocb;
	struct sock___25 *sk;
	struct af_alg_rsgl first_rsgl;
	struct af_alg_rsgl *last_rsgl;
	struct list_head rsgl_list;
	struct scatterlist *tsgl;
	unsigned int tsgl_entries;
	unsigned int outlen;
	unsigned int areqlen;
	union {
		struct aead_request___6 aead_req;
		struct skcipher_request___5 skcipher_req;
	} cra_u;
};

struct af_alg_ctx {
	struct list_head tsgl_list;
	void *iv;
	size_t aead_assoclen;
	struct crypto_wait wait;
	size_t used;
	atomic_t rcvused;
	bool more;
	bool merge;
	bool enc;
	unsigned int len;
};

struct alg_type_list {
	const struct af_alg_type *type;
	struct list_head list;
};

struct hash_alg_common___3 {
	unsigned int digestsize;
	unsigned int statesize;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_alg___17 base;
};

struct ahash_request___3 {
	struct crypto_async_request___17 base;
	unsigned int nbytes;
	struct scatterlist *src;
	u8 *result;
	void *priv;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_ahash___3 {
	int (*init)(struct ahash_request___3 *);
	int (*update)(struct ahash_request___3 *);
	int (*final)(struct ahash_request___3 *);
	int (*finup)(struct ahash_request___3 *);
	int (*digest)(struct ahash_request___3 *);
	int (*export)(struct ahash_request___3 *, void *);
	int (*import)(struct ahash_request___3 *, const void *);
	int (*setkey)(struct crypto_ahash___3 *, const u8 *, unsigned int);
	unsigned int reqsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_tfm___17 base;
};

struct hash_ctx {
	struct af_alg_sgl sgl;
	u8 *result;
	struct crypto_wait wait;
	unsigned int len;
	bool more;
	long: 24;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ahash_request___3 req;
};

struct crypto_async_request___18;

typedef void (*crypto_completion_t___18)(struct crypto_async_request___18 *, int);

struct crypto_tfm___18;

struct crypto_async_request___18 {
	struct list_head list;
	crypto_completion_t___18 complete;
	void *data;
	struct crypto_tfm___18 *tfm;
	u32 flags;
};

struct crypto_ablkcipher___18;

struct ablkcipher_request___18;

struct ablkcipher_tfm___18 {
	int (*setkey)(struct crypto_ablkcipher___18 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___18 *);
	int (*decrypt)(struct ablkcipher_request___18 *);
	struct crypto_ablkcipher___18 *base;
	unsigned int ivsize;
	unsigned int reqsize;
};

struct blkcipher_desc___18;

struct blkcipher_tfm___18 {
	void *iv;
	int (*setkey)(struct crypto_tfm___18 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___18 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___18 *, struct scatterlist *, struct scatterlist *, unsigned int);
};

struct cipher_tfm___18 {
	int (*cit_setkey)(struct crypto_tfm___18 *, const u8 *, unsigned int);
	void (*cit_encrypt_one)(struct crypto_tfm___18 *, u8 *, const u8 *);
	void (*cit_decrypt_one)(struct crypto_tfm___18 *, u8 *, const u8 *);
};

struct compress_tfm___18 {
	int (*cot_compress)(struct crypto_tfm___18 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*cot_decompress)(struct crypto_tfm___18 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___18;

struct crypto_tfm___18 {
	u32 crt_flags;
	union {
		struct ablkcipher_tfm___18 ablkcipher;
		struct blkcipher_tfm___18 blkcipher;
		struct cipher_tfm___18 cipher;
		struct compress_tfm___18 compress;
	} crt_u;
	void (*exit)(struct crypto_tfm___18 *);
	struct crypto_alg___18 *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct ablkcipher_request___18 {
	struct crypto_async_request___18 base;
	unsigned int nbytes;
	void *info;
	struct scatterlist *src;
	struct scatterlist *dst;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_blkcipher___18;

struct blkcipher_desc___18 {
	struct crypto_blkcipher___18 *tfm;
	void *info;
	u32 flags;
};

struct crypto_blkcipher___18 {
	struct crypto_tfm___18 base;
};

struct skcipher_givcrypt_request___8;

struct ablkcipher_alg___18 {
	int (*setkey)(struct crypto_ablkcipher___18 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___18 *);
	int (*decrypt)(struct ablkcipher_request___18 *);
	int (*givencrypt)(struct skcipher_givcrypt_request___8 *);
	int (*givdecrypt)(struct skcipher_givcrypt_request___8 *);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct crypto_ablkcipher___18 {
	struct crypto_tfm___18 base;
};

struct skcipher_givcrypt_request___8 {
	u64 seq;
	u8 *giv;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ablkcipher_request___18 creq;
};

struct blkcipher_alg___18 {
	int (*setkey)(struct crypto_tfm___18 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___18 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___18 *, struct scatterlist *, struct scatterlist *, unsigned int);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct cipher_alg___18 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___18 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___18 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___18 *, u8 *, const u8 *);
};

struct compress_alg___18 {
	int (*coa_compress)(struct crypto_tfm___18 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___18 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_type___12;

struct crypto_alg___18 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type___12 *cra_type;
	union {
		struct ablkcipher_alg___18 ablkcipher;
		struct blkcipher_alg___18 blkcipher;
		struct cipher_alg___18 cipher;
		struct compress_alg___18 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___18 *);
	void (*cra_exit)(struct crypto_tfm___18 *);
	void (*cra_destroy)(struct crypto_alg___18 *);
	struct module___198 *cra_module;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct crypto_instance___12;

struct crypto_type___12 {
	unsigned int (*ctxsize)(struct crypto_alg___18 *, u32, u32);
	unsigned int (*extsize)(struct crypto_alg___18 *);
	int (*init)(struct crypto_tfm___18 *, u32, u32);
	int (*init_tfm)(struct crypto_tfm___18 *);
	void (*show)(struct seq_file___220 *, struct crypto_alg___18 *);
	int (*report)(struct sk_buff___34 *, struct crypto_alg___18 *);
	void (*free)(struct crypto_instance___12 *);
	unsigned int type;
	unsigned int maskclear;
	unsigned int maskset;
	unsigned int tfmsize;
};

struct crypto_template___13;

struct crypto_instance___12 {
	struct crypto_alg___18 alg;
	struct crypto_template___13 *tmpl;
	struct hlist_node list;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_template___13 {
	struct list_head list;
	struct hlist_head instances;
	struct module___198 *module;
	struct crypto_instance___12 * (*alloc)(struct rtattr **);
	void (*free)(struct crypto_instance___12 *);
	int (*create)(struct crypto_template___13 *, struct rtattr **);
	char name[128];
};

struct skcipher_request___6 {
	unsigned int cryptlen;
	u8 *iv;
	struct scatterlist *src;
	struct scatterlist *dst;
	struct crypto_async_request___18 base;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_skcipher___5 {
	int (*setkey)(struct crypto_skcipher___5 *, const u8 *, unsigned int);
	int (*encrypt)(struct skcipher_request___6 *);
	int (*decrypt)(struct skcipher_request___6 *);
	unsigned int ivsize;
	unsigned int reqsize;
	unsigned int keysize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_tfm___18 base;
};

struct aead_request___7 {
	struct crypto_async_request___18 base;
	unsigned int assoclen;
	unsigned int cryptlen;
	u8 *iv;
	struct scatterlist *src;
	struct scatterlist *dst;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct af_alg_type___2;

struct alg_sock___2 {
	struct sock___21 sk;
	struct sock___21 *parent;
	unsigned int refcnt;
	unsigned int nokey_refcnt;
	const struct af_alg_type___2 *type;
	void *private;
};

struct af_alg_type___2 {
	void * (*bind)(const char *, u32, u32);
	void (*release)(void *);
	int (*setkey)(void *, const u8 *, unsigned int);
	int (*accept)(void *, struct sock___21 *);
	int (*accept_nokey)(void *, struct sock___21 *);
	int (*setauthsize)(void *, unsigned int);
	struct proto_ops___20 *ops;
	struct proto_ops___20 *ops_nokey;
	struct module___198 *owner;
	char name[14];
};

struct af_alg_sgl___2 {
	struct scatterlist sg[17];
	struct page___245 *pages[16];
	unsigned int npages;
};

struct af_alg_rsgl___2 {
	struct af_alg_sgl___2 sgl;
	struct list_head list;
	size_t sg_num_bytes;
};

struct af_alg_async_req___2 {
	struct kiocb___244 *iocb;
	struct sock___21 *sk;
	struct af_alg_rsgl___2 first_rsgl;
	struct af_alg_rsgl___2 *last_rsgl;
	struct list_head rsgl_list;
	struct scatterlist *tsgl;
	unsigned int tsgl_entries;
	unsigned int outlen;
	unsigned int areqlen;
	union {
		struct aead_request___7 aead_req;
		struct skcipher_request___6 skcipher_req;
	} cra_u;
};

struct module___209;

struct file___255;

struct kiocb___255;

struct iov_iter___122;

struct poll_table_struct___157;

struct vm_area_struct___256;

struct inode___255;

struct file_lock___255;

struct page___256;

struct pipe_inode_info___65;

struct seq_file___228;

struct file_operations___255 {
	struct module___209 *owner;
	loff_t (*llseek)(struct file___255 *, loff_t, int);
	ssize_t (*read)(struct file___255 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___255 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___255 *, struct iov_iter___122 *);
	ssize_t (*write_iter)(struct kiocb___255 *, struct iov_iter___122 *);
	int (*iopoll)(struct kiocb___255 *, bool);
	int (*iterate)(struct file___255 *, struct dir_context *);
	int (*iterate_shared)(struct file___255 *, struct dir_context *);
	__poll_t (*poll)(struct file___255 *, struct poll_table_struct___157 *);
	long int (*unlocked_ioctl)(struct file___255 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___255 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___255 *, struct vm_area_struct___256 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___255 *, struct file___255 *);
	int (*flush)(struct file___255 *, fl_owner_t);
	int (*release)(struct inode___255 *, struct file___255 *);
	int (*fsync)(struct file___255 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___255 *, int);
	int (*lock)(struct file___255 *, int, struct file_lock___255 *);
	ssize_t (*sendpage)(struct file___255 *, struct page___256 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___255 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___255 *, int, struct file_lock___255 *);
	ssize_t (*splice_write)(struct pipe_inode_info___65 *, struct file___255 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___255 *, loff_t *, struct pipe_inode_info___65 *, size_t, unsigned int);
	int (*setlease)(struct file___255 *, long int, struct file_lock___255 **, void **);
	long int (*fallocate)(struct file___255 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___228 *, struct file___255 *);
	ssize_t (*copy_file_range)(struct file___255 *, loff_t, struct file___255 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___255 *, loff_t, struct file___255 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___255 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___255 {
	u64 seqnum;
	struct vm_area_struct___256 *vmas[4];
};

struct page_frag___255 {
	struct page___256 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___255;

struct mem_cgroup___110;

struct cred___247;

struct nsproxy___229;

struct signal_struct___212;

struct bio_list___125;

struct backing_dev_info___125;

struct css_set___194;

struct vm_struct___172;

struct task_struct___256 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___256 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___255 *mm;
	struct mm_struct___255 *active_mm;
	struct vmacache___255 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___256 *real_parent;
	struct task_struct___256 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___256 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___110 *active_memcg;
	long int rh_reserved2;
	struct pid___188 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___188 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___188 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___247 *ptracer_cred;
	const struct cred___247 *real_cred;
	const struct cred___247 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___229 *nsproxy;
	struct signal_struct___212 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___256 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___125 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___125 *backing_dev_info;
	struct io_context___60 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___194 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___65 *splice_pipe;
	struct page_frag___255 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___110 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___256 *oom_reaper_list;
	struct vm_struct___172 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___127 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rw_semaphore___256 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___256 *owner;
};

struct key___247;

struct ucounts___209;

struct user_namespace___209 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___209 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___28 ns;
	long unsigned int flags;
	struct key___247 *persistent_keyring_register;
	struct rw_semaphore___256 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___209 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___256 *pgtable_t___255;

struct address_space___254;

struct dev_pagemap___245;

struct page___256 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___254 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___256 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___255 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___255 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___245 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___110 *mem_cgroup;
};

struct pglist_data___255;

struct lruvec___255 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___255 *pgdat;
};

struct zone___255 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___255 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___255 {
	struct zone___255 *zone;
	int zone_idx;
};

struct zonelist___255 {
	struct zoneref___255 _zonerefs[25];
};

struct pglist_data___255 {
	struct zone___255 node_zones[3];
	struct zonelist___255 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___256 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___256 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___255 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___256 {
	void *stack;
	struct task_struct___256 *task;
	long int status;
};

struct blocking_notifier_head___255 {
	struct rw_semaphore___256 rwsem;
	struct notifier_block *head;
};

struct dentry___255;

struct path___255 {
	struct vfsmount *mnt;
	struct dentry___255 *dentry;
};

struct file___255 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___255 f_path;
	struct inode___255 *f_inode;
	const struct file_operations___255 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___188 f_owner;
	const struct cred___247 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___254 *f_mapping;
	errseq_t f_wb_err;
};

struct user_struct___247;

struct cred___247 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___247 *session_keyring;
	struct key___247 *process_keyring;
	struct key___247 *thread_keyring;
	struct key___247 *request_key_auth;
	void *security;
	struct user_struct___247 *user;
	struct user_namespace___209 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___249;

struct kernfs_elem_dir___249 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___249 *root;
};

struct kernfs_node___250;

struct kernfs_syscall_ops___249;

struct kernfs_root___249 {
	struct kernfs_node___250 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___249 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___249 {
	struct kernfs_node___250 *target_kn;
};

struct kernfs_ops___249;

struct kernfs_elem_attr___249 {
	const struct kernfs_ops___249 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___250 *notify_next;
};

struct kernfs_node___250 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___250 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___249 dir;
		struct kernfs_elem_symlink___249 symlink;
		struct kernfs_elem_attr___249 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___249;

struct kernfs_ops___249 {
	int (*open)(struct kernfs_open_file___249 *);
	void (*release)(struct kernfs_open_file___249 *);
	int (*seq_show)(struct seq_file___228 *, void *);
	void * (*seq_start)(struct seq_file___228 *, loff_t *);
	void * (*seq_next)(struct seq_file___228 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___228 *, void *);
	ssize_t (*read)(struct kernfs_open_file___249 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___249 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___249 *, struct vm_area_struct___256 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___249 *, struct poll_table_struct___157 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___249 {
	int (*remount_fs)(struct kernfs_root___249 *, int *, char *);
	int (*show_options)(struct seq_file___228 *, struct kernfs_root___249 *);
	int (*mkdir)(struct kernfs_node___250 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___250 *);
	int (*rename)(struct kernfs_node___250 *, struct kernfs_node___250 *, const char *);
	int (*show_path)(struct seq_file___228 *, struct kernfs_node___250 *, struct kernfs_root___249 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___226;

struct seq_file___228 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___226 *op;
	int poll_event;
	const struct file___255 *file;
	void *private;
};

struct vm_operations_struct___245;

struct kernfs_open_file___249 {
	struct kernfs_node___250 *kn;
	struct file___255 *file;
	struct seq_file___228 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___245 *vm_ops;
};

struct vm_fault___245;

struct vm_operations_struct___245 {
	void (*open)(struct vm_area_struct___256 *);
	void (*close)(struct vm_area_struct___256 *);
	int (*split)(struct vm_area_struct___256 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___256 *);
	vm_fault_t (*fault)(struct vm_fault___245 *);
	vm_fault_t (*huge_fault)(struct vm_fault___245 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___245 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___256 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___245 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___245 *);
	int (*access)(struct vm_area_struct___256 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___256 *);
	int (*set_policy)(struct vm_area_struct___256 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___256 *, long unsigned int);
	struct page___256 * (*find_special_page)(struct vm_area_struct___256 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___159)(struct file___255 *, wait_queue_head_t *, struct poll_table_struct___157 *);

struct poll_table_struct___157 {
	poll_queue_proc___159 _qproc;
	__poll_t _key;
};

struct vm_area_struct___256 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___256 *vm_next;
	struct vm_area_struct___256 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___255 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___245 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___255 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_ns_type_operations___24 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___4 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct net___46;

typedef struct {
	struct net___46 *net;
} possible_net_t___36;

struct proto___24;

struct sock_common___24 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___24 *skc_prot;
	possible_net_t___36 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___4 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff_head___35 {
	struct sk_buff___5 *next;
	struct sk_buff___5 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___24;

struct socket_wq___25;

struct socket___26;

struct sock___4 {
	struct sock_common___24 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___35 sk_error_queue;
	struct sk_buff_head___35 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___5 *head;
		struct sk_buff___5 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___24 *sk_filter;
	union {
		struct socket_wq___25 *sk_wq;
		struct socket_wq___25 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___3 *sk_rx_dst;
	struct dst_entry___3 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___5 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___35 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___255 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___24 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___188 *sk_peer_pid;
	const struct cred___247 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___26 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___110 *sk_memcg;
	void (*sk_state_change)(struct sock___4 *);
	void (*sk_data_ready)(struct sock___4 *);
	void (*sk_write_space)(struct sock___4 *);
	void (*sk_error_report)(struct sock___4 *);
	int (*sk_backlog_rcv)(struct sock___4 *, struct sk_buff___5 *);
	struct sk_buff___5 * (*sk_validate_xmit_skb)(struct sock___4 *, struct net_device___6 *, struct sk_buff___5 *);
	void (*sk_destruct)(struct sock___4 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kobject___243;

struct bin_attribute___220;

struct attribute_group___221 {
	const char *name;
	umode_t (*is_visible)(struct kobject___243 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___243 *, struct bin_attribute___220 *, int);
	struct attribute **attrs;
	struct bin_attribute___220 **bin_attrs;
};

struct kset___242;

struct kobj_type___242;

struct kobject___243 {
	const char *name;
	struct list_head entry;
	struct kobject___243 *parent;
	struct kset___242 *kset;
	struct kobj_type___242 *ktype;
	struct kernfs_node___250 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___220 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___255 *, struct kobject___243 *, struct bin_attribute___220 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___255 *, struct kobject___243 *, struct bin_attribute___220 *, char *, loff_t, size_t);
	int (*mmap)(struct file___255 *, struct kobject___243 *, struct bin_attribute___220 *, struct vm_area_struct___256 *);
};

struct sysfs_ops___242 {
	ssize_t (*show)(struct kobject___243 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___243 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___242;

struct kset___242 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___243 kobj;
	const struct kset_uevent_ops___242 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___242 {
	void (*release)(struct kobject___243 *);
	const struct sysfs_ops___242 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___24 * (*child_ns_type)(struct kobject___243 *);
	const void * (*namespace)(struct kobject___243 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___242 {
	int (* const filter)(struct kset___242 *, struct kobject___243 *);
	const char * (* const name)(struct kset___242 *, struct kobject___243 *);
	int (* const uevent)(struct kset___242 *, struct kobject___243 *, struct kobj_uevent_env *);
};

struct kobj_attribute___236 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___243 *, struct kobj_attribute___236 *, char *);
	ssize_t (*store)(struct kobject___243 *, struct kobj_attribute___236 *, const char *, size_t);
};

struct kernel_param___206;

struct kernel_param_ops___206 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___206 *);
	int (*get)(char *, const struct kernel_param___206 *);
	void (*free)(void *);
};

struct kparam_array___206;

struct kernel_param___206 {
	const char *name;
	struct module___209 *mod;
	const struct kernel_param_ops___206 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___206 *arr;
	};
};

struct kparam_array___206 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___206 *ops;
	void *elem;
};

struct module_kobject___206 {
	struct kobject___243 kobj;
	struct module___209 *mod;
	struct kobject___243 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___206 {
	struct module___209 *mod;
	struct latch_tree_node node;
};

struct module_layout___206 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___206 mtn;
};

struct module_attribute___206;

struct module___209 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___206 mkobj;
	struct module_attribute___206 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___243 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___206 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___206 core_layout;
	struct module_layout___206 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___206 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___206 *, struct module_kobject___206 *, char *);
	ssize_t (*store)(struct module_attribute___206 *, struct module_kobject___206 *, const char *, size_t);
	void (*setup)(struct module___209 *, const char *);
	int (*test)(struct module___209 *);
	void (*free)(struct module___209 *);
};

struct cgroup___194;

struct cgroup_subsys___194;

struct cgroup_subsys_state___195 {
	struct cgroup___194 *cgroup;
	struct cgroup_subsys___194 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___195 *parent;
};

struct cgroup_file___194 {
	struct kernfs_node___250 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___110;

struct mem_cgroup___110 {
	struct cgroup_subsys_state___195 css;
	struct mem_cgroup_id___13 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___194 events_file;
	struct cgroup_file___194 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___256 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___110 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct user_struct___247 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___247 *uid_keyring;
	struct key___247 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___255;

struct mm_struct___255 {
	struct {
		struct vm_area_struct___256 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___255 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___256 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___255 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___256 *owner;
		struct user_namespace___209 *user_ns;
		struct file___255 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___255 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___194;

struct nsproxy___229 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net___46 *net_ns;
	struct cgroup_namespace___194 *cgroup_ns;
};

struct signal_struct___212 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___256 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___256 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___188 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___188 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___255 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___188 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___125;

struct bio_list___125 {
	struct bio___125 *head;
	struct bio___125 *tail;
};

struct bdi_writeback_congested___125;

struct bdi_writeback___125 {
	struct backing_dev_info___125 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___125 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___195 *memcg_css;
	struct cgroup_subsys_state___195 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___219;

struct backing_dev_info___125 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___125 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___219 *dev;
	struct device___219 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___255 *debug_dir;
	struct dentry___255 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___194 {
	struct cgroup_subsys_state___195 *subsys[13];
	refcount_t refcount;
	struct css_set___194 *dom_cset;
	struct cgroup___194 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___194 *mg_src_cgrp;
	struct cgroup___194 *mg_dst_cgrp;
	struct css_set___194 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___254;

struct pipe_buffer___65;

struct pipe_inode_info___65 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___256 *tmp_page;
	struct fasync_struct___254 *fasync_readers;
	struct fasync_struct___254 *fasync_writers;
	struct pipe_buffer___65 *bufs;
	struct user_struct___247 *user;
};

struct vm_struct___172 {
	struct vm_struct___172 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___256 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___224 {
	struct task_struct___256 task;
	long unsigned int stack[8192];
};

struct address_space_operations___254;

struct address_space___254 {
	struct inode___255 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___256 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___254 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___245)(struct vm_area_struct___256 *, long unsigned int, const struct page___256 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___245)(struct page___256 *, void *);

struct dev_pagemap___245 {
	dev_page_fault_t___245 page_fault;
	dev_page_free_t___245 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___219 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___255 {
	struct task_struct___256 *task;
	struct core_thread___255 *next;
};

struct core_state___255 {
	atomic_t nr_threads;
	struct core_thread___255 dumper;
	struct completion startup;
};

struct vm_fault___245 {
	struct vm_area_struct___256 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___256 *cow_page;
	struct mem_cgroup___110 *memcg;
	struct page___256 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___255 prealloc_pte;
};

struct crypto_async_request___19;

typedef void (*crypto_completion_t___19)(struct crypto_async_request___19 *, int);

struct crypto_tfm___19;

struct crypto_async_request___19 {
	struct list_head list;
	crypto_completion_t___19 complete;
	void *data;
	struct crypto_tfm___19 *tfm;
	u32 flags;
};

struct crypto_ablkcipher___19;

struct ablkcipher_request___19;

struct ablkcipher_tfm___19 {
	int (*setkey)(struct crypto_ablkcipher___19 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___19 *);
	int (*decrypt)(struct ablkcipher_request___19 *);
	struct crypto_ablkcipher___19 *base;
	unsigned int ivsize;
	unsigned int reqsize;
};

struct blkcipher_desc___19;

struct blkcipher_tfm___19 {
	void *iv;
	int (*setkey)(struct crypto_tfm___19 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___19 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___19 *, struct scatterlist *, struct scatterlist *, unsigned int);
};

struct cipher_tfm___19 {
	int (*cit_setkey)(struct crypto_tfm___19 *, const u8 *, unsigned int);
	void (*cit_encrypt_one)(struct crypto_tfm___19 *, u8 *, const u8 *);
	void (*cit_decrypt_one)(struct crypto_tfm___19 *, u8 *, const u8 *);
};

struct compress_tfm___19 {
	int (*cot_compress)(struct crypto_tfm___19 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*cot_decompress)(struct crypto_tfm___19 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___19;

struct crypto_tfm___19 {
	u32 crt_flags;
	union {
		struct ablkcipher_tfm___19 ablkcipher;
		struct blkcipher_tfm___19 blkcipher;
		struct cipher_tfm___19 cipher;
		struct compress_tfm___19 compress;
	} crt_u;
	void (*exit)(struct crypto_tfm___19 *);
	struct crypto_alg___19 *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct ablkcipher_request___19 {
	struct crypto_async_request___19 base;
	unsigned int nbytes;
	void *info;
	struct scatterlist *src;
	struct scatterlist *dst;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_blkcipher___19;

struct blkcipher_desc___19 {
	struct crypto_blkcipher___19 *tfm;
	void *info;
	u32 flags;
};

struct crypto_blkcipher___19 {
	struct crypto_tfm___19 base;
};

struct skcipher_givcrypt_request___9;

struct ablkcipher_alg___19 {
	int (*setkey)(struct crypto_ablkcipher___19 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___19 *);
	int (*decrypt)(struct ablkcipher_request___19 *);
	int (*givencrypt)(struct skcipher_givcrypt_request___9 *);
	int (*givdecrypt)(struct skcipher_givcrypt_request___9 *);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct crypto_ablkcipher___19 {
	struct crypto_tfm___19 base;
};

struct skcipher_givcrypt_request___9 {
	u64 seq;
	u8 *giv;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ablkcipher_request___19 creq;
};

struct blkcipher_alg___19 {
	int (*setkey)(struct crypto_tfm___19 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___19 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___19 *, struct scatterlist *, struct scatterlist *, unsigned int);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct cipher_alg___19 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___19 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___19 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___19 *, u8 *, const u8 *);
};

struct compress_alg___19 {
	int (*coa_compress)(struct crypto_tfm___19 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___19 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___19 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type *cra_type;
	union {
		struct ablkcipher_alg___19 ablkcipher;
		struct blkcipher_alg___19 blkcipher;
		struct cipher_alg___19 cipher;
		struct compress_alg___19 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___19 *);
	void (*cra_exit)(struct crypto_tfm___19 *);
	void (*cra_destroy)(struct crypto_alg___19 *);
	struct module___209 *cra_module;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct crypto_rng___6;

struct rng_alg___6 {
	int (*generate)(struct crypto_rng___6 *, const u8 *, unsigned int, u8 *, unsigned int);
	int (*seed)(struct crypto_rng___6 *, const u8 *, unsigned int);
	void (*set_ent)(struct crypto_rng___6 *, const u8 *, unsigned int);
	unsigned int seedsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_alg___19 base;
};

struct crypto_rng___6 {
	struct crypto_tfm___19 base;
};

struct shrink_control___110 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___110 *memcg;
};

struct shrinker___110 {
	long unsigned int (*count_objects)(struct shrinker___110 *, struct shrink_control___110 *);
	long unsigned int (*scan_objects)(struct shrinker___110 *, struct shrink_control___110 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct dev_pm_info___219 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___219 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___219;

struct bus_type___219;

struct device_driver___219;

struct dev_pm_domain___219;

struct dma_map_ops___62;

struct fwnode_handle___154;

struct class___219;

struct device___219 {
	struct device___219 *parent;
	struct device_private *p;
	struct kobject___243 kobj;
	const char *init_name;
	const struct device_type___219 *type;
	struct mutex mutex;
	struct bus_type___219 *bus;
	struct device_driver___219 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___219 power;
	struct dev_pm_domain___219 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___62 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___154 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___219 *class;
	const struct attribute_group___221 **groups;
	void (*release)(struct device___219 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___254;

struct super_block___254;

struct dentry___255 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___255 *d_parent;
	struct qstr d_name;
	struct inode___255 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___254 *d_op;
	struct super_block___254 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___254;

struct block_device___255;

struct inode___255 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___254 *i_op;
	struct super_block___254 *i_sb;
	struct address_space___254 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___256 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___125 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___255 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___254 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___65 *i_pipe;
		struct block_device___255 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___254 {
	int (*d_revalidate)(struct dentry___255 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___255 *, unsigned int);
	int (*d_hash)(const struct dentry___255 *, struct qstr *);
	int (*d_compare)(const struct dentry___255 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___255 *);
	int (*d_init)(struct dentry___255 *);
	void (*d_release)(struct dentry___255 *);
	void (*d_prune)(struct dentry___255 *);
	void (*d_iput)(struct dentry___255 *, struct inode___255 *);
	char * (*d_dname)(struct dentry___255 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___255 *);
	int (*d_manage)(const struct path___255 *, bool);
	struct dentry___255 * (*d_real)(struct dentry___255 *, const struct inode___255 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___254;

struct mem_dqinfo___254 {
	struct quota_format_type___254 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___254;

struct quota_info___254 {
	unsigned int flags;
	struct rw_semaphore___256 dqio_sem;
	struct inode___255 *files[3];
	struct mem_dqinfo___254 info[3];
	const struct quota_format_ops___254 *ops[3];
};

struct rcuwait___254 {
	struct task_struct___256 *task;
};

struct percpu_rw_semaphore___254 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___256 rw_sem;
	struct rcuwait___254 writer;
	int readers_block;
};

struct sb_writers___254 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___254 rw_sem[3];
};

struct file_system_type___254;

struct super_operations___254;

struct dquot_operations___254;

struct quotactl_ops___254;

struct super_block___254 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___254 *s_type;
	const struct super_operations___254 *s_op;
	const struct dquot_operations___254 *dq_op;
	const struct quotactl_ops___254 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___255 *s_root;
	struct rw_semaphore___256 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___255 *s_bdev;
	struct backing_dev_info___125 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___254 s_dquot;
	struct sb_writers___254 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___254 *s_d_op;
	int cleancache_poolid;
	struct shrinker___110 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___209 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___255 {
	struct file___255 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___255 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___254 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___255 *ia_file;
};

struct dquot___254 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___254 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___254 {
	int qf_fmt_id;
	const struct quota_format_ops___254 *qf_ops;
	struct module___209 *qf_owner;
	struct quota_format_type___254 *qf_next;
};

struct quota_format_ops___254 {
	int (*check_quota_file)(struct super_block___254 *, int);
	int (*read_file_info)(struct super_block___254 *, int);
	int (*write_file_info)(struct super_block___254 *, int);
	int (*free_file_info)(struct super_block___254 *, int);
	int (*read_dqblk)(struct dquot___254 *);
	int (*commit_dqblk)(struct dquot___254 *);
	int (*release_dqblk)(struct dquot___254 *);
	int (*get_next_id)(struct super_block___254 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___254 {
	int (*write_dquot)(struct dquot___254 *);
	struct dquot___254 * (*alloc_dquot)(struct super_block___254 *, int);
	void (*destroy_dquot)(struct dquot___254 *);
	int (*acquire_dquot)(struct dquot___254 *);
	int (*release_dquot)(struct dquot___254 *);
	int (*mark_dirty)(struct dquot___254 *);
	int (*write_info)(struct super_block___254 *, int);
	qsize_t * (*get_reserved_space)(struct inode___255 *);
	int (*get_projid)(struct inode___255 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___255 *, qsize_t *);
	int (*get_next_id)(struct super_block___254 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___254 {
	int (*quota_on)(struct super_block___254 *, int, int, const struct path___255 *);
	int (*quota_off)(struct super_block___254 *, int);
	int (*quota_enable)(struct super_block___254 *, unsigned int);
	int (*quota_disable)(struct super_block___254 *, unsigned int);
	int (*quota_sync)(struct super_block___254 *, int);
	int (*set_info)(struct super_block___254 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___254 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___254 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___254 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___254 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___254 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___121;

struct address_space_operations___254 {
	int (*writepage)(struct page___256 *, struct writeback_control___121 *);
	int (*readpage)(struct file___255 *, struct page___256 *);
	int (*writepages)(struct address_space___254 *, struct writeback_control___121 *);
	int (*set_page_dirty)(struct page___256 *);
	int (*readpages)(struct file___255 *, struct address_space___254 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___255 *, struct address_space___254 *, loff_t, unsigned int, unsigned int, struct page___256 **, void **);
	int (*write_end)(struct file___255 *, struct address_space___254 *, loff_t, unsigned int, unsigned int, struct page___256 *, void *);
	sector_t (*bmap)(struct address_space___254 *, sector_t);
	void (*invalidatepage)(struct page___256 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___256 *, gfp_t);
	void (*freepage)(struct page___256 *);
	ssize_t (*direct_IO)(struct kiocb___255 *, struct iov_iter___122 *);
	int (*migratepage)(struct address_space___254 *, struct page___256 *, struct page___256 *, enum migrate_mode);
	bool (*isolate_page)(struct page___256 *, isolate_mode_t);
	void (*putback_page)(struct page___256 *);
	int (*launder_page)(struct page___256 *);
	int (*is_partially_uptodate)(struct page___256 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___256 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___254 *, struct page___256 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___255 *, sector_t *);
	void (*swap_deactivate)(struct file___255 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___121 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___125 *wb;
	struct inode___255 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___125;

struct iov_iter___122 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___125 *bvec;
		struct pipe_inode_info___65 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___255 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___255 *bd_inode;
	struct super_block___254 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___255 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___125 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___254 {
	struct dentry___255 * (*lookup)(struct inode___255 *, struct dentry___255 *, unsigned int);
	const char * (*get_link)(struct dentry___255 *, struct inode___255 *, struct delayed_call *);
	int (*permission)(struct inode___255 *, int);
	struct posix_acl * (*get_acl)(struct inode___255 *, int);
	int (*readlink)(struct dentry___255 *, char *, int);
	int (*create)(struct inode___255 *, struct dentry___255 *, umode_t, bool);
	int (*link)(struct dentry___255 *, struct inode___255 *, struct dentry___255 *);
	int (*unlink)(struct inode___255 *, struct dentry___255 *);
	int (*symlink)(struct inode___255 *, struct dentry___255 *, const char *);
	int (*mkdir)(struct inode___255 *, struct dentry___255 *, umode_t);
	int (*rmdir)(struct inode___255 *, struct dentry___255 *);
	int (*mknod)(struct inode___255 *, struct dentry___255 *, umode_t, dev_t);
	int (*rename)(struct inode___255 *, struct dentry___255 *, struct inode___255 *, struct dentry___255 *, unsigned int);
	int (*setattr)(struct dentry___255 *, struct iattr___254 *);
	int (*getattr)(const struct path___255 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___255 *, char *, size_t);
	int (*fiemap)(struct inode___255 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___255 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___255 *, struct dentry___255 *, struct file___255 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___255 *, struct dentry___255 *, umode_t);
	int (*set_acl)(struct inode___255 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___254 {
	void (*fl_copy_lock)(struct file_lock___255 *, struct file_lock___255 *);
	void (*fl_release_private)(struct file_lock___255 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___254;

struct file_lock___255 {
	struct file_lock___255 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___255 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___254 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___254 *fl_ops;
	const struct lock_manager_operations___254 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___254 {
	int (*lm_compare_owner)(struct file_lock___255 *, struct file_lock___255 *);
	long unsigned int (*lm_owner_key)(struct file_lock___255 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___255 *);
	int (*lm_grant)(struct file_lock___255 *, int);
	bool (*lm_break)(struct file_lock___255 *);
	int (*lm_change)(struct file_lock___255 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___255 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___254 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___254 *fa_next;
	struct file___255 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___254 {
	const char *name;
	int fs_flags;
	struct dentry___255 * (*mount)(struct file_system_type___254 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___254 *);
	struct module___209 *owner;
	struct file_system_type___254 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___254 {
	struct inode___255 * (*alloc_inode)(struct super_block___254 *);
	void (*destroy_inode)(struct inode___255 *);
	void (*dirty_inode)(struct inode___255 *, int);
	int (*write_inode)(struct inode___255 *, struct writeback_control___121 *);
	int (*drop_inode)(struct inode___255 *);
	void (*evict_inode)(struct inode___255 *);
	void (*put_super)(struct super_block___254 *);
	int (*sync_fs)(struct super_block___254 *, int);
	int (*freeze_super)(struct super_block___254 *);
	int (*freeze_fs)(struct super_block___254 *);
	int (*thaw_super)(struct super_block___254 *);
	int (*unfreeze_fs)(struct super_block___254 *);
	int (*statfs)(struct dentry___255 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___254 *, int *, char *);
	void (*umount_begin)(struct super_block___254 *);
	int (*show_options)(struct seq_file___228 *, struct dentry___255 *);
	int (*show_devname)(struct seq_file___228 *, struct dentry___255 *);
	int (*show_path)(struct seq_file___228 *, struct dentry___255 *);
	int (*show_stats)(struct seq_file___228 *, struct dentry___255 *);
	ssize_t (*quota_read)(struct super_block___254 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___254 *, int, const char *, size_t, loff_t);
	struct dquot___254 ** (*get_dquots)(struct inode___255 *);
	int (*bdev_try_to_free_page)(struct super_block___254 *, struct page___256 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___254 *, struct shrink_control___110 *);
	long int (*free_cached_objects)(struct super_block___254 *, struct shrink_control___110 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___125(struct bio___125 *);

struct bio_vec___125 {
	struct page___256 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___125;

struct bio_set___125;

struct bio___125 {
	struct bio___125 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___125 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___125 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___125 *bi_io_vec;
	struct bio_set___125 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___125 bi_inline_vecs[0];
};

typedef void compound_page_dtor___245(struct page___256 *);

struct fwnode_operations___154;

struct fwnode_handle___154 {
	struct fwnode_handle___154 *secondary;
	const struct fwnode_operations___154 *ops;
};

struct fwnode_reference_args___154;

struct fwnode_endpoint___154;

struct fwnode_operations___154 {
	struct fwnode_handle___154 * (*get)(struct fwnode_handle___154 *);
	void (*put)(struct fwnode_handle___154 *);
	bool (*device_is_available)(const struct fwnode_handle___154 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___154 *, const struct device___219 *);
	bool (*property_present)(const struct fwnode_handle___154 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___154 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___154 *, const char *, const char **, size_t);
	struct fwnode_handle___154 * (*get_parent)(const struct fwnode_handle___154 *);
	struct fwnode_handle___154 * (*get_next_child_node)(const struct fwnode_handle___154 *, struct fwnode_handle___154 *);
	struct fwnode_handle___154 * (*get_named_child_node)(const struct fwnode_handle___154 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___154 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___154 *);
	struct fwnode_handle___154 * (*graph_get_next_endpoint)(const struct fwnode_handle___154 *, struct fwnode_handle___154 *);
	struct fwnode_handle___154 * (*graph_get_remote_endpoint)(const struct fwnode_handle___154 *);
	struct fwnode_handle___154 * (*graph_get_port_parent)(struct fwnode_handle___154 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___154 *, struct fwnode_endpoint___154 *);
};

struct fwnode_endpoint___154 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___154 *local_fwnode;
};

struct fwnode_reference_args___154 {
	struct fwnode_handle___154 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct msghdr___27 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___122 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___255 *msg_iocb;
};

struct socket_wq___25 {
	wait_queue_head_t wait;
	struct fasync_struct___254 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___25;

struct socket___26 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___25 *wq;
	struct file___255 *file;
	struct sock___4 *sk;
	const struct proto_ops___25 *ops;
};

typedef int (*sk_read_actor_t___24)(read_descriptor_t *, struct sk_buff___5 *, unsigned int, size_t);

struct proto_ops___25 {
	int family;
	struct module___209 *owner;
	int (*release)(struct socket___26 *);
	int (*bind)(struct socket___26 *, struct sockaddr *, int);
	int (*connect)(struct socket___26 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___26 *, struct socket___26 *);
	int (*accept)(struct socket___26 *, struct socket___26 *, int, bool);
	int (*getname)(struct socket___26 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___255 *, struct socket___26 *, struct poll_table_struct___157 *);
	int (*ioctl)(struct socket___26 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___26 *, int);
	int (*shutdown)(struct socket___26 *, int);
	int (*setsockopt)(struct socket___26 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___26 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___26 *, struct msghdr___27 *, size_t);
	int (*recvmsg)(struct socket___26 *, struct msghdr___27 *, size_t, int);
	int (*mmap)(struct file___255 *, struct socket___26 *, struct vm_area_struct___256 *);
	ssize_t (*sendpage)(struct socket___26 *, struct page___256 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___26 *, loff_t *, struct pipe_inode_info___65 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___4 *, int);
	int (*peek_len)(struct socket___26 *);
	int (*read_sock)(struct sock___4 *, read_descriptor_t *, sk_read_actor_t___24);
	int (*sendpage_locked)(struct sock___4 *, struct page___256 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___4 *, struct msghdr___27 *, size_t);
	int (*set_rcvlowat)(struct sock___4 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct nf_bridge_info___35;

struct sk_buff___5 {
	union {
		struct {
			struct sk_buff___5 *next;
			struct sk_buff___5 *prev;
			union {
				struct net_device___6 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___4 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___5 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___35 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___35;

struct netns_frags___35 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___35 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_rules_ops___24;

struct fib_notifier_ops___24;

struct netns_ipv4___35 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___24 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___4 *fibnl;
	struct sock___4 **icmp_sk;
	struct sock___4 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___4 **tcp_sk;
	struct netns_frags___35 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___24 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___24 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___24 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___24;

struct dst_ops___45 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___45 *);
	struct dst_entry___3 * (*check)(struct dst_entry___3 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___3 *);
	unsigned int (*mtu)(const struct dst_entry___3 *);
	u32 * (*cow_metrics)(struct dst_entry___3 *, long unsigned int);
	void (*destroy)(struct dst_entry___3 *);
	void (*ifdown)(struct dst_entry___3 *, struct net_device___6 *, int);
	struct dst_entry___3 * (*negative_advice)(struct dst_entry___3 *);
	void (*link_failure)(struct sk_buff___5 *);
	void (*update_pmtu)(struct dst_entry___3 *, struct sock___4 *, struct sk_buff___5 *, u32);
	void (*redirect)(struct dst_entry___3 *, struct sock___4 *, struct sk_buff___5 *);
	int (*local_out)(struct net___46 *, struct sock___4 *, struct sk_buff___5 *);
	struct neighbour___24 * (*neigh_lookup)(const struct dst_entry___3 *, struct sk_buff___5 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___3 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___45 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___35 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___45 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___24 *fib6_rules_ops;
	struct sock___4 **icmp_sk;
	struct sock___4 *ndisc_sk;
	struct sock___4 *tcp_sk;
	struct sock___4 *igmp_sk;
	struct sock___4 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___24 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___24 *notifier_ops;
	struct fib_notifier_ops___24 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___25 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___4 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___35 {
	struct netns_frags___35 frags;
};

struct netns_xfrm___45 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___4 *nlsk;
	struct sock___4 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___45 xfrm4_dst_ops;
	struct dst_ops___45 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___34;

struct net___46 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___209 *user_ns;
	struct ucounts___209 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___28 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___4 *rtnl;
	struct sock___4 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___6 *loopback_dev;
	struct netns_core core;
	struct netns_mib___2 mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___35 ipv4;
	struct netns_ipv6___45 ipv6;
	struct netns_sctp___25 sctp;
	struct netns_nf___2 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___35 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___4 *nfnl;
	struct sock___4 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___45 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can___2 can;
	struct sock___4 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___34 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___219 {
	int (*prepare)(struct device___219 *);
	void (*complete)(struct device___219 *);
	int (*suspend)(struct device___219 *);
	int (*resume)(struct device___219 *);
	int (*freeze)(struct device___219 *);
	int (*thaw)(struct device___219 *);
	int (*poweroff)(struct device___219 *);
	int (*restore)(struct device___219 *);
	int (*suspend_late)(struct device___219 *);
	int (*resume_early)(struct device___219 *);
	int (*freeze_late)(struct device___219 *);
	int (*thaw_early)(struct device___219 *);
	int (*poweroff_late)(struct device___219 *);
	int (*restore_early)(struct device___219 *);
	int (*suspend_noirq)(struct device___219 *);
	int (*resume_noirq)(struct device___219 *);
	int (*freeze_noirq)(struct device___219 *);
	int (*thaw_noirq)(struct device___219 *);
	int (*poweroff_noirq)(struct device___219 *);
	int (*restore_noirq)(struct device___219 *);
	int (*runtime_suspend)(struct device___219 *);
	int (*runtime_resume)(struct device___219 *);
	int (*runtime_idle)(struct device___219 *);
};

struct dev_pm_domain___219 {
	struct dev_pm_ops___219 ops;
	void (*detach)(struct device___219 *, bool);
	int (*activate)(struct device___219 *);
	void (*sync)(struct device___219 *);
	void (*dismiss)(struct device___219 *);
};

struct bus_type___219 {
	const char *name;
	const char *dev_name;
	struct device___219 *dev_root;
	const struct attribute_group___221 **bus_groups;
	const struct attribute_group___221 **dev_groups;
	const struct attribute_group___221 **drv_groups;
	int (*match)(struct device___219 *, struct device_driver___219 *);
	int (*uevent)(struct device___219 *, struct kobj_uevent_env *);
	int (*probe)(struct device___219 *);
	int (*remove)(struct device___219 *);
	void (*shutdown)(struct device___219 *);
	int (*online)(struct device___219 *);
	int (*offline)(struct device___219 *);
	int (*suspend)(struct device___219 *, pm_message_t);
	int (*resume)(struct device___219 *);
	int (*num_vf)(struct device___219 *);
	int (*dma_configure)(struct device___219 *);
	const struct dev_pm_ops___219 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___219 {
	const char *name;
	struct bus_type___219 *bus;
	struct module___209 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___219 *);
	int (*remove)(struct device___219 *);
	void (*shutdown)(struct device___219 *);
	int (*suspend)(struct device___219 *, pm_message_t);
	int (*resume)(struct device___219 *);
	const struct attribute_group___221 **groups;
	const struct dev_pm_ops___219 *pm;
	void (*coredump)(struct device___219 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___219 {
	const char *name;
	const struct attribute_group___221 **groups;
	int (*uevent)(struct device___219 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___219 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___219 *);
	const struct dev_pm_ops___219 *pm;
};

struct class___219 {
	const char *name;
	struct module___209 *owner;
	const struct attribute_group___221 **class_groups;
	const struct attribute_group___221 **dev_groups;
	struct kobject___243 *dev_kobj;
	int (*dev_uevent)(struct device___219 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___219 *, umode_t *);
	void (*class_release)(struct class___219 *);
	void (*dev_release)(struct device___219 *);
	int (*shutdown_pre)(struct device___219 *);
	const struct kobj_ns_type_operations___24 *ns_type;
	const void * (*namespace)(struct device___219 *);
	const struct dev_pm_ops___219 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___62 {
	void * (*alloc)(struct device___219 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___219 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___219 *, struct vm_area_struct___256 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___219 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___219 *, struct page___256 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___219 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___219 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___219 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___219 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___219 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___219 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___219 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___219 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___219 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___219 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___219 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___219 *, u64);
	u64 (*get_required_mask)(struct device___219 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct pipe_buf_operations___65;

struct pipe_buffer___65 {
	struct page___256 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___65 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___65 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___65 *, struct pipe_buffer___65 *);
	void (*release)(struct pipe_inode_info___65 *, struct pipe_buffer___65 *);
	int (*steal)(struct pipe_inode_info___65 *, struct pipe_buffer___65 *);
	union {
		bool (*get)(struct pipe_inode_info___65 *, struct pipe_buffer___65 *);
		struct {
			void (*get)(struct pipe_inode_info___65 *, struct pipe_buffer___65 *);
		} __UNIQUE_ID_rh_kabi_hide21;
		union {		};
	};
};

struct nf_bridge_info___35 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___35 = 0,
		BRNF_PROTO_8021Q___35 = 1,
		BRNF_PROTO_PPPOE___35 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___6 *physindev;
	struct net_device___6 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___35(struct sk_buff___5 **);

struct net_device_ops___35;

struct ethtool_ops___35;

struct xfrmdev_ops___35;

struct tlsdev_ops___35;

struct header_ops___35;

struct netdev_rx_queue___35;

struct mini_Qdisc___34;

struct netdev_queue___35;

struct Qdisc___34;

struct rtnl_link_ops___34;

struct dcbnl_rtnl_ops___35;

struct net_device___6 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___35 *netdev_ops;
	const struct ethtool_ops___35 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___2 *l3mdev_ops;
	const struct ndisc_ops___2 *ndisc_ops;
	const struct xfrmdev_ops___35 *xfrmdev_ops;
	const struct tlsdev_ops___35 *tlsdev_ops;
	const struct header_ops___35 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___242 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___2 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___35 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___34 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___35 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___34 *miniq_ingress;
	struct netdev_queue___35 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___35 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___34 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___34 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___35 = 0,
		NETREG_REGISTERED___35 = 1,
		NETREG_UNREGISTERING___35 = 2,
		NETREG_UNREGISTERED___35 = 3,
		NETREG_RELEASED___35 = 4,
		NETREG_DUMMY___35 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___35 = 0,
		RTNL_LINK_INITIALIZING___35 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___6 *);
	struct netpoll_info *npinfo;
	possible_net_t___36 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___219 dev;
	const struct attribute_group___221 *sysfs_groups[4];
	const struct attribute_group___221 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___34 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___35 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide35;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct ethtool_ops___35 {
	int (*get_settings)(struct net_device___6 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___6 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___6 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___6 *);
	void (*get_regs)(struct net_device___6 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___6 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___6 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___6 *);
	void (*set_msglevel)(struct net_device___6 *, u32);
	int (*nway_reset)(struct net_device___6 *);
	u32 (*get_link)(struct net_device___6 *);
	int (*get_eeprom_len)(struct net_device___6 *);
	int (*get_eeprom)(struct net_device___6 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___6 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___6 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___6 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___6 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___6 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___6 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___6 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___6 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___6 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___6 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___6 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___6 *);
	void (*complete)(struct net_device___6 *);
	u32 (*get_priv_flags)(struct net_device___6 *);
	int (*set_priv_flags)(struct net_device___6 *, u32);
	int (*get_sset_count)(struct net_device___6 *, int);
	int (*get_rxnfc)(struct net_device___6 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___6 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___6 *, struct ethtool_flash *);
	int (*reset)(struct net_device___6 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___6 *);
	u32 (*get_rxfh_indir_size)(struct net_device___6 *);
	int (*get_rxfh)(struct net_device___6 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___6 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___6 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___6 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___6 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___6 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___6 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___6 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___6 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___6 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___6 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___6 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___6 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___6 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___6 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___6 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___6 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___6 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___6 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___6 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___6 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___6 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	int (*get_fecparam)(struct net_device___6 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___6 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___6 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___6 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___6 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___35;

struct inet_frags___35 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___35 *, const void *);
	void (*destructor)(struct inet_frag_queue___35 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___35 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___5 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___5 *fragments_tail;
	struct sk_buff___5 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___35 *net;
	struct callback_head rcu;
};

struct fib_rule___24;

struct fib_lookup_arg___24;

struct fib_rules_ops___24 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___24 *, struct flowi *, int, struct fib_lookup_arg___24 *);
	bool (*suppress)(struct fib_rule___24 *, struct fib_lookup_arg___24 *);
	int (*match)(struct fib_rule___24 *, struct flowi *, int);
	int (*configure)(struct fib_rule___24 *, struct sk_buff___5 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___24 *);
	int (*compare)(struct fib_rule___24 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___24 *, struct sk_buff___5 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___24 *);
	void (*flush_cache)(struct fib_rules_ops___24 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___209 *owner;
	struct net___46 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___24 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___46 *);
	int (*fib_dump)(struct net___46 *, struct notifier_block *);
	struct module___209 *owner;
	struct callback_head rcu;
};

struct dst_entry___3 {
	struct net_device___6 *dev;
	struct dst_ops___45 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___5 *);
	int (*output)(struct net___46 *, struct sock___4 *, struct sk_buff___5 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___24;

struct neigh_ops___24;

struct neighbour___24 {
	struct neighbour___24 *next;
	struct neigh_table___24 *tbl;
	struct neigh_parms___3 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___35 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___24 *, struct sk_buff___5 *);
	const struct neigh_ops___24 *ops;
	struct callback_head rcu;
	struct net_device___6 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct ucounts___209 {
	struct hlist_node node;
	struct user_namespace___209 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_prog_aux___37;

struct bpf_prog___34 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___37 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

typedef int (*key_restrict_link_func_t___248)(struct key___247 *, const struct key_type *, const union key_payload *, struct key___247 *);

struct key_restriction___247;

struct key___247 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___256 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key___5 index_key;
		struct {
			struct key_type___5 *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___247 *restrict_link;
};

struct key_restriction___247 {
	key_restrict_link_func_t___248 check;
	struct key___247 *key;
	struct key_type *keytype;
};

struct seq_operations___226 {
	void * (*start)(struct seq_file___228 *, loff_t *);
	void (*stop)(struct seq_file___228 *, void *);
	void * (*next)(struct seq_file___228 *, void *, loff_t *);
	int (*show)(struct seq_file___228 *, void *);
};

struct pernet_operations___36 {
	struct list_head list;
	int (*init)(struct net___46 *);
	void (*exit)(struct net___46 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___35 {
	int (*ieee_getets)(struct net_device___6 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___6 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___6 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___6 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___6 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___6 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___6 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___6 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___6 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___6 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___6 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___6 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___6 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___6 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___6 *);
	u8 (*setstate)(struct net_device___6 *, u8);
	void (*getpermhwaddr)(struct net_device___6 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___6 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___6 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___6 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___6 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___6 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___6 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___6 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___6 *, int, u8 *);
	void (*setpfccfg)(struct net_device___6 *, int, u8);
	void (*getpfccfg)(struct net_device___6 *, int, u8 *);
	u8 (*setall)(struct net_device___6 *);
	u8 (*getcap)(struct net_device___6 *, int, u8 *);
	int (*getnumtcs)(struct net_device___6 *, int, u8 *);
	int (*setnumtcs)(struct net_device___6 *, int, u8);
	u8 (*getpfcstate)(struct net_device___6 *);
	void (*setpfcstate)(struct net_device___6 *, u8);
	void (*getbcncfg)(struct net_device___6 *, int, u32 *);
	void (*setbcncfg)(struct net_device___6 *, int, u32);
	void (*getbcnrp)(struct net_device___6 *, int, u8 *);
	void (*setbcnrp)(struct net_device___6 *, int, u8);
	int (*setapp)(struct net_device___6 *, u8, u16, u8);
	int (*getapp)(struct net_device___6 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___6 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___6 *, int, u8);
	u8 (*getdcbx)(struct net_device___6 *);
	u8 (*setdcbx)(struct net_device___6 *, u8);
	int (*peer_getappinfo)(struct net_device___6 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___6 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___6 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___6 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___6 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___6 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___194 {
	refcount_t count;
	struct ns_common___28 ns;
	struct user_namespace___209 *user_ns;
	struct ucounts___209 *ucounts;
	struct css_set___194 *root_cset;
};

struct bpf_map___195;

struct bpf_map_ops___194 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___195 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___195 *, struct file___255 *);
	void (*map_free)(struct bpf_map___195 *);
	int (*map_get_next_key)(struct bpf_map___195 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___195 *);
	void * (*map_lookup_elem)(struct bpf_map___195 *, void *);
	int (*map_update_elem)(struct bpf_map___195 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___195 *, void *);
	int (*map_push_elem)(struct bpf_map___195 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___195 *, void *);
	int (*map_peek_elem)(struct bpf_map___195 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___195 *, struct file___255 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___195 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___195 *, void *, struct seq_file___228 *);
	int (*map_check_btf)(const struct bpf_map___195 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___195 {
	const struct bpf_map_ops___194 *ops;
	struct bpf_map___195 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___247 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___35;

struct bpf_map_dev_ops___35 {
	int (*map_get_next_key)(struct bpf_offloaded_map___35 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___35 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___35 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___35 *, void *);
};

struct bpf_offloaded_map___35 {
	struct bpf_map___195 map;
	struct net_device___6 *netdev;
	const struct bpf_map_dev_ops___35 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___34 {
	int (*test_run)(struct bpf_prog___34 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___34 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___34 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___34 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___34 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___34 *, u32 *);
};

struct bpf_prog_offload_ops___34 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___34 *);
	int (*translate)(struct bpf_prog___34 *);
	void (*destroy)(struct bpf_prog___34 *);
};

struct bpf_prog_offload___34 {
	struct bpf_prog___34 *prog;
	struct net_device___6 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___34 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___37 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___34 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___34 *ops;
	struct bpf_map___195 **used_maps;
	struct bpf_prog___34 *prog;
	struct user_struct___247 *user;
	u64 load_time;
	struct bpf_map___195 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___34 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___34 {
	struct bpf_prog___34 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___34 {
	struct callback_head rcu;
	struct bpf_prog_array_item___34 items[0];
};

struct cgroup_bpf___34 {
	struct bpf_prog_array___34 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___34 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___194;

typedef void (*kthread_work_func_t___194)(struct kthread_work___194 *);

struct kthread_worker___194;

struct kthread_work___194 {
	struct list_head node;
	kthread_work_func_t___194 func;
	struct kthread_worker___194 *worker;
	int canceling;
};

struct kthread_worker___194 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___256 *task;
	struct kthread_work___194 *current_work;
};

struct kthread_delayed_work___194 {
	struct kthread_work___194 work;
	struct timer_list timer;
};

struct psi_group___194 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___194 *poll_kworker;
	struct kthread_delayed_work___194 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___194;

struct cgroup_rstat_cpu___194;

struct cgroup___194 {
	struct cgroup_subsys_state___195 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___250 *kn;
	struct cgroup_file___194 procs_file;
	struct cgroup_file___194 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___195 *subsys[13];
	struct cgroup_root___194 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___194 *dom_cgrp;
	struct cgroup_rstat_cpu___194 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___34 bpf;
	atomic_t congestion_count;
	struct cgroup___194 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___194 psi;
	int ancestor_ids[0];
};

struct cftype___194;

struct cgroup_subsys___194 {
	struct cgroup_subsys_state___195 * (*css_alloc)(struct cgroup_subsys_state___195 *);
	int (*css_online)(struct cgroup_subsys_state___195 *);
	void (*css_offline)(struct cgroup_subsys_state___195 *);
	void (*css_released)(struct cgroup_subsys_state___195 *);
	void (*css_free)(struct cgroup_subsys_state___195 *);
	void (*css_reset)(struct cgroup_subsys_state___195 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___195 *, int);
	int (*css_extra_stat_show)(struct seq_file___228 *, struct cgroup_subsys_state___195 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___256 *);
	void (*cancel_fork)(struct task_struct___256 *);
	void (*fork)(struct task_struct___256 *);
	void (*exit)(struct task_struct___256 *);
	void (*free)(struct task_struct___256 *);
	void (*bind)(struct cgroup_subsys_state___195 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___194 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___194 *dfl_cftypes;
	struct cftype___194 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___194 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___194 *updated_children;
	struct cgroup___194 *updated_next;
};

struct cgroup_root___194 {
	struct kernfs_root___249 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___194 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___194 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___194 *ss;
	struct list_head node;
	struct kernfs_ops___249 *kf_ops;
	int (*open)(struct kernfs_open_file___249 *);
	void (*release)(struct kernfs_open_file___249 *);
	u64 (*read_u64)(struct cgroup_subsys_state___195 *, struct cftype___194 *);
	s64 (*read_s64)(struct cgroup_subsys_state___195 *, struct cftype___194 *);
	int (*seq_show)(struct seq_file___228 *, void *);
	void * (*seq_start)(struct seq_file___228 *, loff_t *);
	void * (*seq_next)(struct seq_file___228 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___228 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___195 *, struct cftype___194 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___195 *, struct cftype___194 *, s64);
	ssize_t (*write)(struct kernfs_open_file___249 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___249 *, struct poll_table_struct___157 *);
};

struct xdp_rxq_info___35 {
	struct net_device___6 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___35 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___6 *dev_rx;
};

struct netlink_callback___35 {
	struct sk_buff___5 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___35 *);
	int (*dump)(struct sk_buff___5 *, struct netlink_callback___35 *);
	int (*done)(struct netlink_callback___35 *);
	void *data;
	struct module___209 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___35 {
	int (*create)(struct sk_buff___5 *, struct net_device___6 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___5 *, unsigned char *);
	int (*cache)(const struct neighbour___24 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___6 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___35 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___35 *, int);
	int poll_owner;
	struct net_device___6 *dev;
	struct sk_buff___5 *gro_list;
	struct sk_buff___5 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___35 {
	struct net_device___6 *dev;
	struct Qdisc___34 *qdisc;
	struct Qdisc___34 *qdisc_sleeping;
	struct kobject___243 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___6 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___34 {
	struct sk_buff___5 *head;
	struct sk_buff___5 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___34;

struct Qdisc___34 {
	int (*enqueue)(struct sk_buff___5 *, struct Qdisc___34 *, struct sk_buff___5 **);
	struct sk_buff___5 * (*dequeue)(struct Qdisc___34 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___34 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___35 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___35 gso_skb;
	struct qdisc_skb_head___34 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___34 *next_sched;
	struct sk_buff_head___35 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___35 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___243 kobj;
	struct net_device___6 *dev;
	long: 64;
	struct xdp_rxq_info___35 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___35)(struct net_device___6 *, struct sk_buff___5 *, struct net_device___6 *);

struct netdev_bpf___35 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___34 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___34 *prog;
			const struct bpf_prog_offload_ops___34 *ops;
		} verifier;
		struct {
			struct bpf_prog___34 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___35 *offmap;
		};
		struct {
			struct xdp_umem *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___35 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___5 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___35 {
	int (*tls_dev_add)(struct net_device___6 *, struct sock___4 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___6 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___6 *, struct sock___4 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___35 {
	int (*ndo_init)(struct net_device___6 *);
	void (*ndo_uninit)(struct net_device___6 *);
	int (*ndo_open)(struct net_device___6 *);
	int (*ndo_stop)(struct net_device___6 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___5 *, struct net_device___6 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___5 *, struct net_device___6 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___6 *, struct sk_buff___5 *, struct net_device___6 *, select_queue_fallback_t___35);
	void (*ndo_change_rx_flags)(struct net_device___6 *, int);
	void (*ndo_set_rx_mode)(struct net_device___6 *);
	int (*ndo_set_mac_address)(struct net_device___6 *, void *);
	int (*ndo_validate_addr)(struct net_device___6 *);
	int (*ndo_do_ioctl)(struct net_device___6 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___6 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___6 *, int);
	int (*ndo_neigh_setup)(struct net_device___6 *, struct neigh_parms___3 *);
	void (*ndo_tx_timeout)(struct net_device___6 *);
	void (*ndo_get_stats64)(struct net_device___6 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___6 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___6 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___6 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___6 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___6 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___6 *);
	int (*ndo_netpoll_setup)(struct net_device___6 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___6 *);
	int (*ndo_set_vf_mac)(struct net_device___6 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___6 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___6 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___6 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___6 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___6 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___6 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___6 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___6 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___6 *, int, struct sk_buff___5 *);
	int (*ndo_set_vf_guid)(struct net_device___6 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___6 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___6 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___6 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___6 *, const struct sk_buff___5 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___6 *, struct net_device___6 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___6 *, struct net_device___6 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___6 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___6 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___6 *, struct neighbour___24 *);
	void (*ndo_neigh_destroy)(struct net_device___6 *, struct neighbour___24 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___6 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___6 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___6 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___5 *, struct netlink_callback___35 *, struct net_device___6 *, struct net_device___6 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___6 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___6 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___5 *, u32, u32, struct net_device___6 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___6 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___6 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___6 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___6 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___6 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___6 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___6 *, struct net_device___6 *);
	void (*ndo_dfwd_del_station)(struct net_device___6 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___6 *);
	int (*ndo_set_tx_maxrate)(struct net_device___6 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___6 *);
	int (*ndo_change_proto_down)(struct net_device___6 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___6 *, struct sk_buff___5 *);
	void (*ndo_set_rx_headroom)(struct net_device___6 *, int);
	int (*ndo_bpf)(struct net_device___6 *, struct netdev_bpf___35 *);
	int (*ndo_xdp_xmit)(struct net_device___6 *, int, struct xdp_frame___35 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___6 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___6 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___3 {
	possible_net_t___36 net;
	struct net_device___6 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___24 *);
	void (*neigh_cleanup)(struct neighbour___24 *);
	struct neigh_table___24 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct tcf_proto___34;

struct mini_Qdisc___34 {
	struct tcf_proto___34 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___34 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___6 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___46 *, struct net_device___6 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___6 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___6 *, struct list_head *);
	size_t (*get_size)(const struct net_device___6 *);
	int (*fill_info)(struct sk_buff___5 *, const struct net_device___6 *);
	size_t (*get_xstats_size)(const struct net_device___6 *);
	int (*fill_xstats)(struct sk_buff___5 *, const struct net_device___6 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___6 *, struct net_device___6 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___6 *, const struct net_device___6 *);
	int (*fill_slave_info)(struct sk_buff___5 *, const struct net_device___6 *, const struct net_device___6 *);
	struct net___46 * (*get_link_net)(const struct net_device___6 *);
	size_t (*get_linkxstats_size)(const struct net_device___6 *, int);
	int (*fill_linkxstats)(struct sk_buff___5 *, const struct net_device___6 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___35 {
	struct list_head poll_list;
	struct sk_buff_head___35 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___35 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___34 *output_queue;
	struct Qdisc___34 **output_queue_tailp;
	struct sk_buff___5 *completion_queue;
	struct sk_buff_head___35 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___35 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___35 input_pkt_queue;
	struct napi_struct___35 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bdi_writeback_congested___125 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___125 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___125 {
	struct bio___125 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___125 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___125 bip_inline_vecs[0];
};

struct bio_set___125 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___125 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___110 {
	struct mem_cgroup___110 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___110 {
	struct lruvec___255 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___110 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___110 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct gnet_dump___34 {
	spinlock_t *lock;
	struct sk_buff___5 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___34;

struct Qdisc_ops___34 {
	struct Qdisc_ops___34 *next;
	const struct Qdisc_class_ops___34 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___5 *, struct Qdisc___34 *, struct sk_buff___5 **);
	struct sk_buff___5 * (*dequeue)(struct Qdisc___34 *);
	struct sk_buff___5 * (*peek)(struct Qdisc___34 *);
	int (*init)(struct Qdisc___34 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___34 *);
	void (*destroy)(struct Qdisc___34 *);
	int (*change)(struct Qdisc___34 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___34 *);
	int (*change_tx_queue_len)(struct Qdisc___34 *, unsigned int);
	int (*dump)(struct Qdisc___34 *, struct sk_buff___5 *);
	int (*dump_stats)(struct Qdisc___34 *, struct gnet_dump___34 *);
	void (*ingress_block_set)(struct Qdisc___34 *, u32);
	void (*egress_block_set)(struct Qdisc___34 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___34 *);
	u32 (*egress_block_get)(struct Qdisc___34 *);
	struct module___209 *owner;
};

struct tcf_block___34;

struct Qdisc_class_ops___34 {
	unsigned int flags;
	struct netdev_queue___35 * (*select_queue)(struct Qdisc___34 *, struct tcmsg *);
	int (*graft)(struct Qdisc___34 *, long unsigned int, struct Qdisc___34 *, struct Qdisc___34 **, struct netlink_ext_ack *);
	struct Qdisc___34 * (*leaf)(struct Qdisc___34 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___34 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___34 *, u32);
	int (*change)(struct Qdisc___34 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___34 *, long unsigned int);
	void (*walk)(struct Qdisc___34 *, struct qdisc_walker *);
	struct tcf_block___34 * (*tcf_block)(struct Qdisc___34 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___34 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___34 *, long unsigned int);
	int (*dump)(struct Qdisc___34 *, long unsigned int, struct sk_buff___5 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___34 *, long unsigned int, struct gnet_dump___34 *);
};

struct tcf_chain___34;

struct tcf_block___34 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___46 *net;
	struct Qdisc___34 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___34 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___34;

struct tcf_proto_ops___34;

struct tcf_proto___34 {
	struct tcf_proto___34 *next;
	void *root;
	int (*classify)(struct sk_buff___5 *, const struct tcf_proto___34 *, struct tcf_result___34 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___34 *ops;
	struct tcf_chain___34 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___34 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___34 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___34 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___5 *, const struct tcf_proto___34 *, struct tcf_result___34 *);
	int (*init)(struct tcf_proto___34 *);
	void (*destroy)(struct tcf_proto___34 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___34 *, u32);
	void (*put)(struct tcf_proto___34 *, void *);
	int (*change)(struct net___46 *, struct sk_buff___5 *, struct tcf_proto___34 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___34 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___34 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___34 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___46 *, struct tcf_chain___34 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___46 *, struct tcf_proto___34 *, void *, struct sk_buff___5 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___5 *, struct net___46 *, void *);
	struct module___209 *owner;
	int flags;
};

struct tcf_chain___34 {
	struct mutex filter_chain_lock;
	struct tcf_proto___34 *filter_chain;
	struct list_head list;
	struct tcf_block___34 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___34 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___24 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___34 *prog;
};

struct bpf_redirect_info___34 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___195 *map;
	struct bpf_map___195 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___24;

struct neigh_hash_table___24;

struct neigh_table___24 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___6 *, __u32 *);
	bool (*key_eq)(const struct neighbour___24 *, const void *);
	int (*constructor)(struct neighbour___24 *);
	int (*pconstructor)(struct pneigh_entry___24 *);
	void (*pdestructor)(struct pneigh_entry___24 *);
	void (*proxy_redo)(struct sk_buff___5 *);
	char *id;
	struct neigh_parms___3 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___35 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___24 *nht;
	struct pneigh_entry___24 **phash_buckets;
};

struct neigh_ops___24 {
	int family;
	void (*solicit)(struct neighbour___24 *, struct sk_buff___5 *);
	void (*error_report)(struct neighbour___24 *, struct sk_buff___5 *);
	int (*output)(struct neighbour___24 *, struct sk_buff___5 *);
	int (*connected_output)(struct neighbour___24 *, struct sk_buff___5 *);
};

struct pneigh_entry___24 {
	struct pneigh_entry___24 *next;
	possible_net_t___36 net;
	struct net_device___6 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___24 {
	struct neighbour___24 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___24 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___24 *ctarget;
	struct net___46 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___24 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___24 *rule;
	u32 table;
	int flags;
};

struct proto___24 {
	void (*close)(struct sock___4 *, long int);
	int (*pre_connect)(struct sock___4 *, struct sockaddr *, int);
	int (*connect)(struct sock___4 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___4 *, int);
	struct sock___4 * (*accept)(struct sock___4 *, int, int *, bool);
	int (*ioctl)(struct sock___4 *, int, long unsigned int);
	int (*init)(struct sock___4 *);
	void (*destroy)(struct sock___4 *);
	void (*shutdown)(struct sock___4 *, int);
	int (*setsockopt)(struct sock___4 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___4 *, int, int, char *, int *);
	void (*keepalive)(struct sock___4 *, int);
	int (*sendmsg)(struct sock___4 *, struct msghdr___27 *, size_t);
	int (*recvmsg)(struct sock___4 *, struct msghdr___27 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___4 *, struct page___256 *, int, size_t, int);
	int (*bind)(struct sock___4 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___4 *, struct sk_buff___5 *);
	void (*release_cb)(struct sock___4 *);
	int (*hash)(struct sock___4 *);
	void (*unhash)(struct sock___4 *);
	void (*rehash)(struct sock___4 *);
	int (*get_port)(struct sock___4 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___4 *);
	bool (*stream_memory_read)(const struct sock___4 *);
	void (*enter_memory_pressure)(struct sock___4 *);
	void (*leave_memory_pressure)(struct sock___4 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___3 *rsk_prot;
	struct timewait_sock_ops___3 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___209 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___4 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct af_alg_type___3;

struct alg_sock___3 {
	struct sock___4 sk;
	struct sock___4 *parent;
	unsigned int refcnt;
	unsigned int nokey_refcnt;
	const struct af_alg_type___3 *type;
	void *private;
};

struct af_alg_type___3 {
	void * (*bind)(const char *, u32, u32);
	void (*release)(void *);
	int (*setkey)(void *, const u8 *, unsigned int);
	int (*accept)(void *, struct sock___4 *);
	int (*accept_nokey)(void *, struct sock___4 *);
	int (*setauthsize)(void *, unsigned int);
	struct proto_ops___25 *ops;
	struct proto_ops___25 *ops_nokey;
	struct module___209 *owner;
	char name[14];
};

struct rng_ctx {
	unsigned int len;
	struct crypto_rng___6 *drng;
};

struct crypto_aead___6;

struct aead_alg___6 {
	int (*setkey)(struct crypto_aead___6 *, const u8 *, unsigned int);
	int (*setauthsize)(struct crypto_aead___6 *, unsigned int);
	int (*encrypt)(struct aead_request___7 *);
	int (*decrypt)(struct aead_request___7 *);
	int (*init)(struct crypto_aead___6 *);
	void (*exit)(struct crypto_aead___6 *);
	const char *geniv;
	unsigned int ivsize;
	unsigned int maxauthsize;
	unsigned int chunksize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_alg___18 base;
};

struct crypto_aead___6 {
	unsigned int authsize;
	unsigned int reqsize;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_tfm___18 base;
};

struct aead_tfm {
	struct crypto_aead___6 *aead;
	struct crypto_skcipher___5 *null_tfm;
};

struct module___210;

struct file___256;

struct kiocb___256;

struct vm_area_struct___257;

struct inode___256;

struct file_lock___256;

struct page___257;

struct seq_file___229;

struct file_operations___256 {
	struct module___210 *owner;
	loff_t (*llseek)(struct file___256 *, loff_t, int);
	ssize_t (*read)(struct file___256 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___256 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___256 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___256 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___256 *, bool);
	int (*iterate)(struct file___256 *, struct dir_context *);
	int (*iterate_shared)(struct file___256 *, struct dir_context *);
	__poll_t (*poll)(struct file___256 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___256 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___256 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___256 *, struct vm_area_struct___257 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___256 *, struct file___256 *);
	int (*flush)(struct file___256 *, fl_owner_t);
	int (*release)(struct inode___256 *, struct file___256 *);
	int (*fsync)(struct file___256 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___256 *, int);
	int (*lock)(struct file___256 *, int, struct file_lock___256 *);
	ssize_t (*sendpage)(struct file___256 *, struct page___257 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___256 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___256 *, int, struct file_lock___256 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___256 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___256 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___256 *, long int, struct file_lock___256 **, void **);
	long int (*fallocate)(struct file___256 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___229 *, struct file___256 *);
	ssize_t (*copy_file_range)(struct file___256 *, loff_t, struct file___256 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___256 *, loff_t, struct file___256 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___256 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___256 {
	u64 seqnum;
	struct vm_area_struct___257 *vmas[4];
};

struct page_frag___256 {
	struct page___257 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___256;

struct cred___248;

struct task_struct___257 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___257 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___256 *mm;
	struct mm_struct___256 *active_mm;
	struct vmacache___256 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___257 *real_parent;
	struct task_struct___257 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___257 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___188 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___188 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___188 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___248 *ptracer_cred;
	const struct cred___248 *real_cred;
	const struct cred___248 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___257 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___60 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___256 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___257 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___127 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___255;

struct super_block___255;

struct dentry___256 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___256 *d_parent;
	struct qstr d_name;
	struct inode___256 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___255 *d_op;
	struct super_block___255 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct rw_semaphore___257 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___257 *owner;
};

struct address_space_operations___255;

struct address_space___255 {
	struct inode___256 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___257 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___255 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___255;

struct block_device___256;

struct inode___256 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___255 *i_op;
	struct super_block___255 *i_sb;
	struct address_space___255 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___257 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___256 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___255 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___256 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___256;

struct dentry_operations___255 {
	int (*d_revalidate)(struct dentry___256 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___256 *, unsigned int);
	int (*d_hash)(const struct dentry___256 *, struct qstr *);
	int (*d_compare)(const struct dentry___256 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___256 *);
	int (*d_init)(struct dentry___256 *);
	void (*d_release)(struct dentry___256 *);
	void (*d_prune)(struct dentry___256 *);
	void (*d_iput)(struct dentry___256 *, struct inode___256 *);
	char * (*d_dname)(struct dentry___256 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___256 *);
	int (*d_manage)(const struct path___256 *, bool);
	struct dentry___256 * (*d_real)(struct dentry___256 *, const struct inode___256 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___255;

struct mem_dqinfo___255 {
	struct quota_format_type___255 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___255;

struct quota_info___255 {
	unsigned int flags;
	struct rw_semaphore___257 dqio_sem;
	struct inode___256 *files[3];
	struct mem_dqinfo___255 info[3];
	const struct quota_format_ops___255 *ops[3];
};

struct rcuwait___255 {
	struct task_struct___257 *task;
};

struct percpu_rw_semaphore___255 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___257 rw_sem;
	struct rcuwait___255 writer;
	int readers_block;
};

struct sb_writers___255 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___255 rw_sem[3];
};

struct file_system_type___255;

struct super_operations___255;

struct dquot_operations___255;

struct quotactl_ops___255;

struct super_block___255 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___255 *s_type;
	const struct super_operations___255 *s_op;
	const struct dquot_operations___255 *dq_op;
	const struct quotactl_ops___255 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___256 *s_root;
	struct rw_semaphore___257 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___256 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___255 s_dquot;
	struct sb_writers___255 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___255 *s_d_op;
	int cleancache_poolid;
	struct shrinker___110 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct path___256 {
	struct vfsmount *mnt;
	struct dentry___256 *dentry;
};

typedef struct page___257 *pgtable_t___256;

struct page___257 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___255 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___257 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___256 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___256 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___245 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___256;

struct lruvec___256 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___256 *pgdat;
};

struct zone___256 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___256 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___256 {
	struct zone___256 *zone;
	int zone_idx;
};

struct zonelist___256 {
	struct zoneref___256 _zonerefs[25];
};

struct pglist_data___256 {
	struct zone___256 node_zones[3];
	struct zonelist___256 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___257 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___257 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___256 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___257 {
	void *stack;
	struct task_struct___257 *task;
	long int status;
};

struct blocking_notifier_head___256 {
	struct rw_semaphore___257 rwsem;
	struct notifier_block *head;
};

struct vm_area_struct___257 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___257 *vm_next;
	struct vm_area_struct___257 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___256 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___13 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___256 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___256;

struct mm_struct___256 {
	struct {
		struct vm_area_struct___257 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___256 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___257 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___256 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___257 *owner;
		struct user_namespace___3 *user_ns;
		struct file___256 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___256 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct file___256 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___256 f_path;
	struct inode___256 *f_inode;
	const struct file_operations___256 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___188 f_owner;
	const struct cred___248 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___255 *f_mapping;
	errseq_t f_wb_err;
};

struct core_thread___256 {
	struct task_struct___257 *task;
	struct core_thread___256 *next;
};

struct core_state___256 {
	atomic_t nr_threads;
	struct core_thread___256 dumper;
	struct completion startup;
};

struct key___248;

struct user_struct___248 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___248 *uid_keyring;
	struct key___248 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___248 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___248 *session_keyring;
	struct key___248 *process_keyring;
	struct key___248 *thread_keyring;
	struct key___248 *request_key_auth;
	void *security;
	struct user_struct___248 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kiocb___256 {
	struct file___256 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___256 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___255 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___256 *ia_file;
};

struct dquot___255 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___255 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___255 {
	int qf_fmt_id;
	const struct quota_format_ops___255 *qf_ops;
	struct module___210 *qf_owner;
	struct quota_format_type___255 *qf_next;
};

struct quota_format_ops___255 {
	int (*check_quota_file)(struct super_block___255 *, int);
	int (*read_file_info)(struct super_block___255 *, int);
	int (*write_file_info)(struct super_block___255 *, int);
	int (*free_file_info)(struct super_block___255 *, int);
	int (*read_dqblk)(struct dquot___255 *);
	int (*commit_dqblk)(struct dquot___255 *);
	int (*release_dqblk)(struct dquot___255 *);
	int (*get_next_id)(struct super_block___255 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___255 {
	int (*write_dquot)(struct dquot___255 *);
	struct dquot___255 * (*alloc_dquot)(struct super_block___255 *, int);
	void (*destroy_dquot)(struct dquot___255 *);
	int (*acquire_dquot)(struct dquot___255 *);
	int (*release_dquot)(struct dquot___255 *);
	int (*mark_dirty)(struct dquot___255 *);
	int (*write_info)(struct super_block___255 *, int);
	qsize_t * (*get_reserved_space)(struct inode___256 *);
	int (*get_projid)(struct inode___256 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___256 *, qsize_t *);
	int (*get_next_id)(struct super_block___255 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___255 {
	int (*quota_on)(struct super_block___255 *, int, int, const struct path___256 *);
	int (*quota_off)(struct super_block___255 *, int);
	int (*quota_enable)(struct super_block___255 *, unsigned int);
	int (*quota_disable)(struct super_block___255 *, unsigned int);
	int (*quota_sync)(struct super_block___255 *, int);
	int (*set_info)(struct super_block___255 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___255 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___255 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___255 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___255 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___255 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___243;

struct kobj_type___243;

struct kernfs_node___251;

struct kobject___244 {
	const char *name;
	struct list_head entry;
	struct kobject___244 *parent;
	struct kset___243 *kset;
	struct kobj_type___243 *ktype;
	struct kernfs_node___251 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___207 {
	struct kobject___244 kobj;
	struct module___210 *mod;
	struct kobject___244 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___207 {
	struct module___210 *mod;
	struct latch_tree_node node;
};

struct module_layout___207 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___207 mtn;
};

struct module_attribute___207;

struct kernel_param___207;

struct module___210 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___207 mkobj;
	struct module_attribute___207 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___244 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___207 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___207 core_layout;
	struct module_layout___207 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___255 {
	int (*writepage)(struct page___257 *, struct writeback_control___3 *);
	int (*readpage)(struct file___256 *, struct page___257 *);
	int (*writepages)(struct address_space___255 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___257 *);
	int (*readpages)(struct file___256 *, struct address_space___255 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___256 *, struct address_space___255 *, loff_t, unsigned int, unsigned int, struct page___257 **, void **);
	int (*write_end)(struct file___256 *, struct address_space___255 *, loff_t, unsigned int, unsigned int, struct page___257 *, void *);
	sector_t (*bmap)(struct address_space___255 *, sector_t);
	void (*invalidatepage)(struct page___257 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___257 *, gfp_t);
	void (*freepage)(struct page___257 *);
	ssize_t (*direct_IO)(struct kiocb___256 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___255 *, struct page___257 *, struct page___257 *, enum migrate_mode);
	bool (*isolate_page)(struct page___257 *, isolate_mode_t);
	void (*putback_page)(struct page___257 *);
	int (*launder_page)(struct page___257 *);
	int (*is_partially_uptodate)(struct page___257 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___257 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___255 *, struct page___257 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___256 *, sector_t *);
	void (*swap_deactivate)(struct file___256 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___256 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___256 *bd_inode;
	struct super_block___255 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___256 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___255 {
	struct dentry___256 * (*lookup)(struct inode___256 *, struct dentry___256 *, unsigned int);
	const char * (*get_link)(struct dentry___256 *, struct inode___256 *, struct delayed_call *);
	int (*permission)(struct inode___256 *, int);
	struct posix_acl * (*get_acl)(struct inode___256 *, int);
	int (*readlink)(struct dentry___256 *, char *, int);
	int (*create)(struct inode___256 *, struct dentry___256 *, umode_t, bool);
	int (*link)(struct dentry___256 *, struct inode___256 *, struct dentry___256 *);
	int (*unlink)(struct inode___256 *, struct dentry___256 *);
	int (*symlink)(struct inode___256 *, struct dentry___256 *, const char *);
	int (*mkdir)(struct inode___256 *, struct dentry___256 *, umode_t);
	int (*rmdir)(struct inode___256 *, struct dentry___256 *);
	int (*mknod)(struct inode___256 *, struct dentry___256 *, umode_t, dev_t);
	int (*rename)(struct inode___256 *, struct dentry___256 *, struct inode___256 *, struct dentry___256 *, unsigned int);
	int (*setattr)(struct dentry___256 *, struct iattr___255 *);
	int (*getattr)(const struct path___256 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___256 *, char *, size_t);
	int (*fiemap)(struct inode___256 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___256 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___256 *, struct dentry___256 *, struct file___256 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___256 *, struct dentry___256 *, umode_t);
	int (*set_acl)(struct inode___256 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___255 {
	void (*fl_copy_lock)(struct file_lock___256 *, struct file_lock___256 *);
	void (*fl_release_private)(struct file_lock___256 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___255;

struct lock_manager_operations___255;

struct file_lock___256 {
	struct file_lock___256 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___256 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___255 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___255 *fl_ops;
	const struct lock_manager_operations___255 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___255 {
	int (*lm_compare_owner)(struct file_lock___256 *, struct file_lock___256 *);
	long unsigned int (*lm_owner_key)(struct file_lock___256 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___256 *);
	int (*lm_grant)(struct file_lock___256 *, int);
	bool (*lm_break)(struct file_lock___256 *);
	int (*lm_change)(struct file_lock___256 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___256 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___255 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___255 *fa_next;
	struct file___256 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___255 {
	const char *name;
	int fs_flags;
	struct dentry___256 * (*mount)(struct file_system_type___255 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___255 *);
	struct module___210 *owner;
	struct file_system_type___255 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___255 {
	struct inode___256 * (*alloc_inode)(struct super_block___255 *);
	void (*destroy_inode)(struct inode___256 *);
	void (*dirty_inode)(struct inode___256 *, int);
	int (*write_inode)(struct inode___256 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___256 *);
	void (*evict_inode)(struct inode___256 *);
	void (*put_super)(struct super_block___255 *);
	int (*sync_fs)(struct super_block___255 *, int);
	int (*freeze_super)(struct super_block___255 *);
	int (*freeze_fs)(struct super_block___255 *);
	int (*thaw_super)(struct super_block___255 *);
	int (*unfreeze_fs)(struct super_block___255 *);
	int (*statfs)(struct dentry___256 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___255 *, int *, char *);
	void (*umount_begin)(struct super_block___255 *);
	int (*show_options)(struct seq_file___229 *, struct dentry___256 *);
	int (*show_devname)(struct seq_file___229 *, struct dentry___256 *);
	int (*show_path)(struct seq_file___229 *, struct dentry___256 *);
	int (*show_stats)(struct seq_file___229 *, struct dentry___256 *);
	ssize_t (*quota_read)(struct super_block___255 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___255 *, int, const char *, size_t, loff_t);
	struct dquot___255 ** (*get_dquots)(struct inode___256 *);
	int (*bdev_try_to_free_page)(struct super_block___255 *, struct page___257 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___255 *, struct shrink_control___110 *);
	long int (*free_cached_objects)(struct super_block___255 *, struct shrink_control___110 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___227;

struct seq_file___229 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___227 *op;
	int poll_event;
	const struct file___256 *file;
	void *private;
};

struct key_type___6;

struct keyring_index_key___6 {
	struct key_type___6 *type;
	const char *description;
	size_t desc_len;
};

struct key_construction___6;

typedef int (*request_key_actor_t___6)(struct key_construction___6 *, const char *, void *);

struct key_match_data___6;

struct key_restriction___248;

struct key_type___6 {
	const char *name;
	size_t def_datalen;
	int (*vet_description)(const char *);
	int (*preparse)(struct key_preparsed_payload *);
	void (*free_preparse)(struct key_preparsed_payload *);
	int (*instantiate)(struct key___248 *, struct key_preparsed_payload *);
	int (*update)(struct key___248 *, struct key_preparsed_payload *);
	int (*match_preparse)(struct key_match_data___6 *);
	void (*match_free)(struct key_match_data___6 *);
	void (*revoke)(struct key___248 *);
	void (*destroy)(struct key___248 *);
	void (*describe)(const struct key___248 *, struct seq_file___229 *);
	long int (*read)(const struct key___248 *, char *, size_t);
	request_key_actor_t___6 request_key;
	struct key_restriction___248 * (*lookup_restriction)(const char *);
	struct list_head link;
	struct lock_class_key lock_class;
};

typedef int (*key_restrict_link_func_t___249)(struct key___248 *, const struct key_type___6 *, const union key_payload *, struct key___248 *);

struct key___248 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___257 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key___6 index_key;
		struct {
			struct key_type___6 *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___248 *restrict_link;
};

struct key_restriction___248 {
	key_restrict_link_func_t___249 check;
	struct key___248 *key;
	struct key_type___6 *keytype;
};

struct seq_operations___227 {
	void * (*start)(struct seq_file___229 *, loff_t *);
	void (*stop)(struct seq_file___229 *, void *);
	void * (*next)(struct seq_file___229 *, void *, loff_t *);
	int (*show)(struct seq_file___229 *, void *);
};

struct key_construction___6 {
	struct key___248 *key;
	struct key___248 *authkey;
};

struct key_match_data___6 {
	bool (*cmp)(const struct key___248 *, const struct key_match_data___6 *);
	const void *raw_data;
	void *preparsed;
	unsigned int lookup_type;
};

enum asymmetric_payload_bits {
	asym_crypto = 0,
	asym_subtype = 1,
	asym_key_ids = 2,
	asym_auth = 3,
};

struct asymmetric_key_id {
	short unsigned int len;
	unsigned char data[0];
};

struct asymmetric_key_ids {
	void *id[2];
};

struct public_key_signature;

struct asymmetric_key_subtype___2 {
	struct module___210 *owner;
	const char *name;
	short unsigned int name_len;
	void (*describe)(const struct key___248 *, struct seq_file___229 *);
	void (*destroy)(void *, void *);
	int (*verify_signature)(const struct key___248 *, const struct public_key_signature *);
};

struct public_key_signature {
	struct asymmetric_key_id *auth_ids[2];
	u8 *s;
	u32 s_size;
	u8 *digest;
	u8 digest_size;
	const char *pkey_algo;
	const char *hash_algo;
};

struct asymmetric_key_parser {
	struct list_head link;
	struct module___210 *owner;
	const char *name;
	int (*parse)(struct key_preparsed_payload *);
};

struct kernfs_root___250;

struct kernfs_elem_dir___250 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___250 *root;
};

struct kernfs_syscall_ops___250;

struct kernfs_root___250 {
	struct kernfs_node___251 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___250 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___250 {
	struct kernfs_node___251 *target_kn;
};

struct kernfs_ops___250;

struct kernfs_elem_attr___250 {
	const struct kernfs_ops___250 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___251 *notify_next;
};

struct kernfs_node___251 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___251 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___250 dir;
		struct kernfs_elem_symlink___250 symlink;
		struct kernfs_elem_attr___250 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___250;

struct kernfs_ops___250 {
	int (*open)(struct kernfs_open_file___250 *);
	void (*release)(struct kernfs_open_file___250 *);
	int (*seq_show)(struct seq_file___229 *, void *);
	void * (*seq_start)(struct seq_file___229 *, loff_t *);
	void * (*seq_next)(struct seq_file___229 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___229 *, void *);
	ssize_t (*read)(struct kernfs_open_file___250 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___250 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___250 *, struct vm_area_struct___257 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___250 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___250 {
	int (*remount_fs)(struct kernfs_root___250 *, int *, char *);
	int (*show_options)(struct seq_file___229 *, struct kernfs_root___250 *);
	int (*mkdir)(struct kernfs_node___251 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___251 *);
	int (*rename)(struct kernfs_node___251 *, struct kernfs_node___251 *, const char *);
	int (*show_path)(struct seq_file___229 *, struct kernfs_node___251 *, struct kernfs_root___250 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___250 {
	struct kernfs_node___251 *kn;
	struct file___256 *file;
	struct seq_file___229 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___13 *vm_ops;
};

struct sysfs_ops___243 {
	ssize_t (*show)(struct kobject___244 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___244 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___243;

struct kset___243 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___244 kobj;
	const struct kset_uevent_ops___243 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___243 {
	void (*release)(struct kobject___244 *);
	const struct sysfs_ops___243 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___24 * (*child_ns_type)(struct kobject___244 *);
	const void * (*namespace)(struct kobject___244 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___243 {
	int (* const filter)(struct kset___243 *, struct kobject___244 *);
	const char * (* const name)(struct kset___243 *, struct kobject___244 *);
	int (* const uevent)(struct kset___243 *, struct kobject___244 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___207 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___207 *);
	int (*get)(char *, const struct kernel_param___207 *);
	void (*free)(void *);
};

struct kparam_array___207;

struct kernel_param___207 {
	const char *name;
	struct module___210 *mod;
	const struct kernel_param_ops___207 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___207 *arr;
	};
};

struct kparam_array___207 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___207 *ops;
	void *elem;
};

struct module_attribute___207 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___207 *, struct module_kobject___207 *, char *);
	ssize_t (*store)(struct module_attribute___207 *, struct module_kobject___207 *, const char *, size_t);
	void (*setup)(struct module___210 *, const char *);
	int (*test)(struct module___210 *);
	void (*free)(struct module___210 *);
};

struct asymmetric_key_subtype___3 {
	struct module___190 *owner;
	const char *name;
	short unsigned int name_len;
	void (*describe)(const struct key___228 *, struct seq_file___211 *);
	void (*destroy)(void *, void *);
	int (*verify_signature)(const struct key___228 *, const struct public_key_signature *);
};

struct public_key {
	void *key;
	u32 keylen;
	const char *id_type;
	const char *pkey_algo;
};

struct crypto_async_request___20;

typedef void (*crypto_completion_t___20)(struct crypto_async_request___20 *, int);

struct crypto_tfm___20;

struct crypto_async_request___20 {
	struct list_head list;
	crypto_completion_t___20 complete;
	void *data;
	struct crypto_tfm___20 *tfm;
	u32 flags;
};

struct crypto_ablkcipher___20;

struct ablkcipher_request___20;

struct ablkcipher_tfm___20 {
	int (*setkey)(struct crypto_ablkcipher___20 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___20 *);
	int (*decrypt)(struct ablkcipher_request___20 *);
	struct crypto_ablkcipher___20 *base;
	unsigned int ivsize;
	unsigned int reqsize;
};

struct blkcipher_desc___20;

struct blkcipher_tfm___20 {
	void *iv;
	int (*setkey)(struct crypto_tfm___20 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___20 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___20 *, struct scatterlist *, struct scatterlist *, unsigned int);
};

struct cipher_tfm___20 {
	int (*cit_setkey)(struct crypto_tfm___20 *, const u8 *, unsigned int);
	void (*cit_encrypt_one)(struct crypto_tfm___20 *, u8 *, const u8 *);
	void (*cit_decrypt_one)(struct crypto_tfm___20 *, u8 *, const u8 *);
};

struct compress_tfm___20 {
	int (*cot_compress)(struct crypto_tfm___20 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*cot_decompress)(struct crypto_tfm___20 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___20;

struct crypto_tfm___20 {
	u32 crt_flags;
	union {
		struct ablkcipher_tfm___20 ablkcipher;
		struct blkcipher_tfm___20 blkcipher;
		struct cipher_tfm___20 cipher;
		struct compress_tfm___20 compress;
	} crt_u;
	void (*exit)(struct crypto_tfm___20 *);
	struct crypto_alg___20 *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct ablkcipher_request___20 {
	struct crypto_async_request___20 base;
	unsigned int nbytes;
	void *info;
	struct scatterlist *src;
	struct scatterlist *dst;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_blkcipher___20;

struct blkcipher_desc___20 {
	struct crypto_blkcipher___20 *tfm;
	void *info;
	u32 flags;
};

struct crypto_blkcipher___20 {
	struct crypto_tfm___20 base;
};

struct ablkcipher_alg___20 {
	int (*setkey)(struct crypto_ablkcipher___20 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___20 *);
	int (*decrypt)(struct ablkcipher_request___20 *);
	int (*givencrypt)(struct skcipher_givcrypt_request *);
	int (*givdecrypt)(struct skcipher_givcrypt_request *);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct crypto_ablkcipher___20 {
	struct crypto_tfm___20 base;
};

struct blkcipher_alg___20 {
	int (*setkey)(struct crypto_tfm___20 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___20 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___20 *, struct scatterlist *, struct scatterlist *, unsigned int);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct cipher_alg___20 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___20 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___20 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___20 *, u8 *, const u8 *);
};

struct compress_alg___20 {
	int (*coa_compress)(struct crypto_tfm___20 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___20 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___20 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type *cra_type;
	union {
		struct ablkcipher_alg___20 ablkcipher;
		struct blkcipher_alg___20 blkcipher;
		struct cipher_alg___20 cipher;
		struct compress_alg___20 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___20 *);
	void (*cra_exit)(struct crypto_tfm___20 *);
	void (*cra_destroy)(struct crypto_alg___20 *);
	struct module___190 *cra_module;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct akcipher_request___4 {
	struct crypto_async_request___20 base;
	struct scatterlist *src;
	struct scatterlist *dst;
	unsigned int src_len;
	unsigned int dst_len;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_akcipher___4 {
	struct crypto_tfm___20 base;
};

struct akcipher_alg___4 {
	int (*sign)(struct akcipher_request___4 *);
	int (*verify)(struct akcipher_request___4 *);
	int (*encrypt)(struct akcipher_request___4 *);
	int (*decrypt)(struct akcipher_request___4 *);
	int (*set_pub_key)(struct crypto_akcipher___4 *, const void *, unsigned int);
	int (*set_priv_key)(struct crypto_akcipher___4 *, const void *, unsigned int);
	unsigned int (*max_size)(struct crypto_akcipher___4 *);
	int (*init)(struct crypto_akcipher___4 *);
	void (*exit)(struct crypto_akcipher___4 *);
	unsigned int reqsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_alg___20 base;
};

enum x509_actions {
	ACT_x509_extract_key_data = 0,
	ACT_x509_extract_name_segment = 1,
	ACT_x509_note_OID = 2,
	ACT_x509_note_issuer = 3,
	ACT_x509_note_not_after = 4,
	ACT_x509_note_not_before = 5,
	ACT_x509_note_pkey_algo = 6,
	ACT_x509_note_serial = 7,
	ACT_x509_note_signature = 8,
	ACT_x509_note_subject = 9,
	ACT_x509_note_tbs_certificate = 10,
	ACT_x509_process_extension = 11,
	NR__x509_actions = 12,
};

enum x509_akid_actions {
	ACT_x509_akid_note_kid = 0,
	ACT_x509_akid_note_name = 1,
	ACT_x509_akid_note_serial = 2,
	ACT_x509_extract_name_segment___2 = 3,
	ACT_x509_note_OID___2 = 4,
	NR__x509_akid_actions = 5,
};

enum OID {
	OID_id_dsa_with_sha1 = 0,
	OID_id_dsa = 1,
	OID_id_ecdsa_with_sha1 = 2,
	OID_id_ecPublicKey = 3,
	OID_rsaEncryption = 4,
	OID_md2WithRSAEncryption = 5,
	OID_md3WithRSAEncryption = 6,
	OID_md4WithRSAEncryption = 7,
	OID_sha1WithRSAEncryption = 8,
	OID_sha256WithRSAEncryption = 9,
	OID_sha384WithRSAEncryption = 10,
	OID_sha512WithRSAEncryption = 11,
	OID_sha224WithRSAEncryption = 12,
	OID_data = 13,
	OID_signed_data = 14,
	OID_email_address = 15,
	OID_contentType = 16,
	OID_messageDigest = 17,
	OID_signingTime = 18,
	OID_smimeCapabilites = 19,
	OID_smimeAuthenticatedAttrs = 20,
	OID_md2 = 21,
	OID_md4 = 22,
	OID_md5 = 23,
	OID_msIndirectData = 24,
	OID_msStatementType = 25,
	OID_msSpOpusInfo = 26,
	OID_msPeImageDataObjId = 27,
	OID_msIndividualSPKeyPurpose = 28,
	OID_msOutlookExpress = 29,
	OID_certAuthInfoAccess = 30,
	OID_sha1 = 31,
	OID_sha256 = 32,
	OID_sha384 = 33,
	OID_sha512 = 34,
	OID_sha224 = 35,
	OID_commonName = 36,
	OID_surname = 37,
	OID_countryName = 38,
	OID_locality = 39,
	OID_stateOrProvinceName = 40,
	OID_organizationName = 41,
	OID_organizationUnitName = 42,
	OID_title = 43,
	OID_description = 44,
	OID_name = 45,
	OID_givenName = 46,
	OID_initials = 47,
	OID_generationalQualifier = 48,
	OID_subjectKeyIdentifier = 49,
	OID_keyUsage = 50,
	OID_subjectAltName = 51,
	OID_issuerAltName = 52,
	OID_basicConstraints = 53,
	OID_crlDistributionPoints = 54,
	OID_certPolicies = 55,
	OID_authorityKeyIdentifier = 56,
	OID_extKeyUsage = 57,
	OID__NR = 58,
};

struct x509_certificate {
	struct x509_certificate *next;
	struct x509_certificate *signer;
	struct public_key *pub;
	struct public_key_signature *sig;
	char *issuer;
	char *subject;
	struct asymmetric_key_id *id;
	struct asymmetric_key_id *skid;
	time64_t valid_from;
	time64_t valid_to;
	const void *tbs;
	unsigned int tbs_size;
	unsigned int raw_sig_size;
	const void *raw_sig;
	const void *raw_serial;
	unsigned int raw_serial_size;
	unsigned int raw_issuer_size;
	const void *raw_issuer;
	const void *raw_subject;
	unsigned int raw_subject_size;
	unsigned int raw_skid_size;
	const void *raw_skid;
	unsigned int index;
	bool seen;
	bool verified;
	bool self_signed;
	bool unsupported_key;
	bool unsupported_sig;
	bool blacklisted;
};

struct x509_parse_context {
	struct x509_certificate *cert;
	long unsigned int data;
	const void *cert_start;
	const void *key;
	size_t key_size;
	enum OID last_oid;
	enum OID algo_oid;
	unsigned char nr_mpi;
	u8 o_size;
	u8 cn_size;
	u8 email_size;
	u16 o_offset;
	u16 cn_offset;
	u16 email_offset;
	unsigned int raw_akid_size;
	const void *raw_akid;
	const void *akid_raw_issuer;
	unsigned int akid_raw_issuer_size;
};

struct asymmetric_key_parser___2 {
	struct list_head link;
	struct module___190 *owner;
	const char *name;
	int (*parse)(struct key_preparsed_payload *);
};

struct crypto_shash___9;

struct shash_desc___7 {
	struct crypto_shash___9 *tfm;
	u32 flags;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_shash___9 {
	unsigned int descsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_tfm___20 base;
};

struct shash_alg___5 {
	int (*init)(struct shash_desc___7 *);
	int (*update)(struct shash_desc___7 *, const u8 *, unsigned int);
	int (*final)(struct shash_desc___7 *, u8 *);
	int (*finup)(struct shash_desc___7 *, const u8 *, unsigned int, u8 *);
	int (*digest)(struct shash_desc___7 *, const u8 *, unsigned int, u8 *);
	int (*export)(struct shash_desc___7 *, void *);
	int (*import)(struct shash_desc___7 *, const void *);
	int (*setkey)(struct crypto_shash___9 *, const u8 *, unsigned int);
	unsigned int descsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int digestsize;
	unsigned int statesize;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_alg___20 base;
};

enum pkcs7_actions {
	ACT_pkcs7_check_content_type = 0,
	ACT_pkcs7_extract_cert = 1,
	ACT_pkcs7_note_OID = 2,
	ACT_pkcs7_note_certificate_list = 3,
	ACT_pkcs7_note_content = 4,
	ACT_pkcs7_note_data = 5,
	ACT_pkcs7_note_signed_info = 6,
	ACT_pkcs7_note_signeddata_version = 7,
	ACT_pkcs7_note_signerinfo_version = 8,
	ACT_pkcs7_sig_note_authenticated_attr = 9,
	ACT_pkcs7_sig_note_digest_algo = 10,
	ACT_pkcs7_sig_note_issuer = 11,
	ACT_pkcs7_sig_note_pkey_algo = 12,
	ACT_pkcs7_sig_note_serial = 13,
	ACT_pkcs7_sig_note_set_of_authattrs = 14,
	ACT_pkcs7_sig_note_signature = 15,
	ACT_pkcs7_sig_note_skid = 16,
	NR__pkcs7_actions = 17,
};

struct pkcs7_signed_info {
	struct pkcs7_signed_info *next;
	struct x509_certificate *signer;
	unsigned int index;
	bool unsupported_crypto;
	bool blacklisted;
	const void *msgdigest;
	unsigned int msgdigest_len;
	unsigned int authattrs_len;
	const void *authattrs;
	long unsigned int aa_set;
	time64_t signing_time;
	struct public_key_signature *sig;
};

struct pkcs7_message___2 {
	struct x509_certificate *certs;
	struct x509_certificate *crl;
	struct pkcs7_signed_info *signed_infos;
	u8 version;
	bool have_authattrs;
	enum OID data_type;
	size_t data_len;
	size_t data_hdrlen;
	const void *data;
};

struct pkcs7_parse_context {
	struct pkcs7_message___2 *msg;
	struct pkcs7_signed_info *sinfo;
	struct pkcs7_signed_info **ppsinfo;
	struct x509_certificate *certs;
	struct x509_certificate **ppcerts;
	long unsigned int data;
	enum OID last_oid;
	unsigned int x509_index;
	unsigned int sinfo_index;
	const void *raw_serial;
	unsigned int raw_serial_size;
	unsigned int raw_issuer_size;
	const void *raw_issuer;
	const void *raw_skid;
	unsigned int raw_skid_size;
	bool expect_skid;
};

struct mz_hdr {
	uint16_t magic;
	uint16_t lbsize;
	uint16_t blocks;
	uint16_t relocs;
	uint16_t hdrsize;
	uint16_t min_extra_pps;
	uint16_t max_extra_pps;
	uint16_t ss;
	uint16_t sp;
	uint16_t checksum;
	uint16_t ip;
	uint16_t cs;
	uint16_t reloc_table_offset;
	uint16_t overlay_num;
	uint16_t reserved0[4];
	uint16_t oem_id;
	uint16_t oem_info;
	uint16_t reserved1[10];
	uint32_t peaddr;
	char message[0];
};

struct pe_hdr {
	uint32_t magic;
	uint16_t machine;
	uint16_t sections;
	uint32_t timestamp;
	uint32_t symbol_table;
	uint32_t symbols;
	uint16_t opt_hdr_size;
	uint16_t flags;
};

struct pe32_opt_hdr {
	uint16_t magic;
	uint8_t ld_major;
	uint8_t ld_minor;
	uint32_t text_size;
	uint32_t data_size;
	uint32_t bss_size;
	uint32_t entry_point;
	uint32_t code_base;
	uint32_t data_base;
	uint32_t image_base;
	uint32_t section_align;
	uint32_t file_align;
	uint16_t os_major;
	uint16_t os_minor;
	uint16_t image_major;
	uint16_t image_minor;
	uint16_t subsys_major;
	uint16_t subsys_minor;
	uint32_t win32_version;
	uint32_t image_size;
	uint32_t header_size;
	uint32_t csum;
	uint16_t subsys;
	uint16_t dll_flags;
	uint32_t stack_size_req;
	uint32_t stack_size;
	uint32_t heap_size_req;
	uint32_t heap_size;
	uint32_t loader_flags;
	uint32_t data_dirs;
};

struct pe32plus_opt_hdr {
	uint16_t magic;
	uint8_t ld_major;
	uint8_t ld_minor;
	uint32_t text_size;
	uint32_t data_size;
	uint32_t bss_size;
	uint32_t entry_point;
	uint32_t code_base;
	uint64_t image_base;
	uint32_t section_align;
	uint32_t file_align;
	uint16_t os_major;
	uint16_t os_minor;
	uint16_t image_major;
	uint16_t image_minor;
	uint16_t subsys_major;
	uint16_t subsys_minor;
	uint32_t win32_version;
	uint32_t image_size;
	uint32_t header_size;
	uint32_t csum;
	uint16_t subsys;
	uint16_t dll_flags;
	uint64_t stack_size_req;
	uint64_t stack_size;
	uint64_t heap_size_req;
	uint64_t heap_size;
	uint32_t loader_flags;
	uint32_t data_dirs;
};

struct data_dirent {
	uint32_t virtual_address;
	uint32_t size;
};

struct data_directory {
	struct data_dirent exports;
	struct data_dirent imports;
	struct data_dirent resources;
	struct data_dirent exceptions;
	struct data_dirent certs;
	struct data_dirent base_relocations;
	struct data_dirent debug;
	struct data_dirent arch;
	struct data_dirent global_ptr;
	struct data_dirent tls;
	struct data_dirent load_config;
	struct data_dirent bound_imports;
	struct data_dirent import_addrs;
	struct data_dirent delay_imports;
	struct data_dirent clr_runtime_hdr;
	struct data_dirent reserved;
};

struct section_header {
	char name[8];
	uint32_t virtual_size;
	uint32_t virtual_address;
	uint32_t raw_data_size;
	uint32_t data_addr;
	uint32_t relocs;
	uint32_t line_numbers;
	uint16_t num_relocs;
	uint16_t num_lin_numbers;
	uint32_t flags;
};

struct win_certificate {
	uint32_t length;
	uint16_t revision;
	uint16_t cert_type;
};

struct pefile_context {
	unsigned int header_size;
	unsigned int image_checksum_offset;
	unsigned int cert_dirent_offset;
	unsigned int n_data_dirents;
	unsigned int n_sections;
	unsigned int certs_size;
	unsigned int sig_offset;
	unsigned int sig_len;
	const struct section_header *secs;
	const void *digest;
	unsigned int digest_len;
	const char *digest_algo;
};

enum mscode_actions {
	ACT_mscode_note_content_type = 0,
	ACT_mscode_note_digest = 1,
	ACT_mscode_note_digest_algo = 2,
	NR__mscode_actions = 3,
};

enum hash_algo {
	HASH_ALGO_MD4 = 0,
	HASH_ALGO_MD5 = 1,
	HASH_ALGO_SHA1 = 2,
	HASH_ALGO_RIPE_MD_160 = 3,
	HASH_ALGO_SHA256 = 4,
	HASH_ALGO_SHA384 = 5,
	HASH_ALGO_SHA512 = 6,
	HASH_ALGO_SHA224 = 7,
	HASH_ALGO_RIPE_MD_128 = 8,
	HASH_ALGO_RIPE_MD_256 = 9,
	HASH_ALGO_RIPE_MD_320 = 10,
	HASH_ALGO_WP_256 = 11,
	HASH_ALGO_WP_384 = 12,
	HASH_ALGO_WP_512 = 13,
	HASH_ALGO_TGR_128 = 14,
	HASH_ALGO_TGR_160 = 15,
	HASH_ALGO_TGR_192 = 16,
	HASH_ALGO_SM3_256 = 17,
	HASH_ALGO__LAST = 18,
};

struct simd_skcipher_alg___2 {
	const char *ialg_name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct skcipher_alg___2 alg;
};

struct simd_skcipher_ctx {
	struct cryptd_skcipher *cryptd_tfm;
};

struct file___257;

struct kiocb___257;

struct iov_iter___123;

struct poll_table_struct___158;

struct vm_area_struct___258;

struct inode___257;

struct file_lock___257;

struct page___258;

struct seq_file___230;

struct file_operations___257 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___257 *, loff_t, int);
	ssize_t (*read)(struct file___257 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___257 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___257 *, struct iov_iter___123 *);
	ssize_t (*write_iter)(struct kiocb___257 *, struct iov_iter___123 *);
	int (*iopoll)(struct kiocb___257 *, bool);
	int (*iterate)(struct file___257 *, struct dir_context *);
	int (*iterate_shared)(struct file___257 *, struct dir_context *);
	__poll_t (*poll)(struct file___257 *, struct poll_table_struct___158 *);
	long int (*unlocked_ioctl)(struct file___257 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___257 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___257 *, struct vm_area_struct___258 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___257 *, struct file___257 *);
	int (*flush)(struct file___257 *, fl_owner_t);
	int (*release)(struct inode___257 *, struct file___257 *);
	int (*fsync)(struct file___257 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___257 *, int);
	int (*lock)(struct file___257 *, int, struct file_lock___257 *);
	ssize_t (*sendpage)(struct file___257 *, struct page___258 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___257 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___257 *, int, struct file_lock___257 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___257 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___257 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___257 *, long int, struct file_lock___257 **, void **);
	long int (*fallocate)(struct file___257 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___230 *, struct file___257 *);
	ssize_t (*copy_file_range)(struct file___257 *, loff_t, struct file___257 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___257 *, loff_t, struct file___257 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___257 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___257 {
	u64 seqnum;
	struct vm_area_struct___258 *vmas[4];
};

struct page_frag___257 {
	struct page___258 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___257;

struct mem_cgroup___111;

struct cred___249;

struct nsproxy___230;

struct bio_list___126;

struct backing_dev_info___126;

struct io_context___61;

struct css_set___195;

struct request_queue___58;

struct vm_struct___173;

struct task_struct___258 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___258 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___257 *mm;
	struct mm_struct___257 *active_mm;
	struct vmacache___257 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___258 *real_parent;
	struct task_struct___258 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___258 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___111 *active_memcg;
	long int rh_reserved2;
	struct pid___188 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___188 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___188 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___249 *ptracer_cred;
	const struct cred___249 *real_cred;
	const struct cred___249 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___230 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___258 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___126 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___126 *backing_dev_info;
	struct io_context___61 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___195 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___257 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___111 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___58 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___258 *oom_reaper_list;
	struct vm_struct___173 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___127 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___258 *pgtable_t___257;

struct address_space___256;

struct dev_pagemap___246;

struct page___258 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___256 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___258 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___257 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___257 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___246 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___111 *mem_cgroup;
};

struct pglist_data___257;

struct lruvec___257 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___257 *pgdat;
};

struct zone___257 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___257 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___257 {
	struct zone___257 *zone;
	int zone_idx;
};

struct zonelist___257 {
	struct zoneref___257 _zonerefs[25];
};

struct pglist_data___257 {
	struct zone___257 node_zones[3];
	struct zonelist___257 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___258 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___258 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___257 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___258 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___258 *owner;
};

struct secondary_data___258 {
	void *stack;
	struct task_struct___258 *task;
	long int status;
};

struct blocking_notifier_head___257 {
	struct rw_semaphore___258 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___246;

struct vm_area_struct___258 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___258 *vm_next;
	struct vm_area_struct___258 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___257 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___246 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___257 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___257;

struct user_namespace___210;

struct mm_struct___257 {
	struct {
		struct vm_area_struct___258 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___257 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___258 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___257 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___258 *owner;
		struct user_namespace___210 *user_ns;
		struct file___257 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___257 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___256;

struct address_space___256 {
	struct inode___257 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___258 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___256 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___246)(struct vm_area_struct___258 *, long unsigned int, const struct page___258 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___246)(struct page___258 *, void *);

struct device___220;

struct dev_pagemap___246 {
	dev_page_fault_t___246 page_fault;
	dev_page_free_t___246 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___220 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct cgroup___195;

struct cgroup_subsys___195;

struct cgroup_subsys_state___196 {
	struct cgroup___195 *cgroup;
	struct cgroup_subsys___195 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___196 *parent;
};

struct kernfs_node___252;

struct cgroup_file___195 {
	struct kernfs_node___252 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___111;

struct mem_cgroup___111 {
	struct cgroup_subsys_state___196 css;
	struct mem_cgroup_id___6 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___195 events_file;
	struct cgroup_file___195 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___258 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___111 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry___257;

struct path___257 {
	struct vfsmount *mnt;
	struct dentry___257 *dentry;
};

struct file___257 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___257 f_path;
	struct inode___257 *f_inode;
	const struct file_operations___257 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___188 f_owner;
	const struct cred___249 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___256 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___246;

struct vm_operations_struct___246 {
	void (*open)(struct vm_area_struct___258 *);
	void (*close)(struct vm_area_struct___258 *);
	int (*split)(struct vm_area_struct___258 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___258 *);
	vm_fault_t (*fault)(struct vm_fault___246 *);
	vm_fault_t (*huge_fault)(struct vm_fault___246 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___246 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___258 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___246 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___246 *);
	int (*access)(struct vm_area_struct___258 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___258 *);
	int (*set_policy)(struct vm_area_struct___258 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___258 *, long unsigned int);
	struct page___258 * (*find_special_page)(struct vm_area_struct___258 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___257 {
	struct task_struct___258 *task;
	struct core_thread___257 *next;
};

struct core_state___257 {
	atomic_t nr_threads;
	struct core_thread___257 dumper;
	struct completion startup;
};

struct key___249;

struct ucounts___210;

struct user_namespace___210 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___210 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___28 ns;
	long unsigned int flags;
	struct key___249 *persistent_keyring_register;
	struct rw_semaphore___258 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___210 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___246 {
	struct vm_area_struct___258 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___258 *cow_page;
	struct mem_cgroup___111 *memcg;
	struct page___258 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___257 prealloc_pte;
};

struct shrink_control___111 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___111 *memcg;
};

struct shrinker___111 {
	long unsigned int (*count_objects)(struct shrinker___111 *, struct shrink_control___111 *);
	long unsigned int (*scan_objects)(struct shrinker___111 *, struct shrink_control___111 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct user_struct___249 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___249 *uid_keyring;
	struct key___249 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___249 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___249 *session_keyring;
	struct key___249 *process_keyring;
	struct key___249 *thread_keyring;
	struct key___249 *request_key_auth;
	void *security;
	struct user_struct___249 *user;
	struct user_namespace___210 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___195;

struct nsproxy___230 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___195 *cgroup_ns;
};

struct bio___126;

struct bio_list___126 {
	struct bio___126 *head;
	struct bio___126 *tail;
};

struct bdi_writeback_congested___126;

struct bdi_writeback___126 {
	struct backing_dev_info___126 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___126 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___196 *memcg_css;
	struct cgroup_subsys_state___196 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___126 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___126 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___220 *dev;
	struct device___220 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___257 *debug_dir;
	struct dentry___257 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___61;

struct io_context___61 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___61 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___195 {
	struct cgroup_subsys_state___196 *subsys[13];
	refcount_t refcount;
	struct css_set___195 *dom_cset;
	struct cgroup___195 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___195 *mg_src_cgrp;
	struct cgroup___195 *mg_dst_cgrp;
	struct css_set___195 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

typedef blk_qc_t make_request_fn___57(struct request_queue___58 *, struct bio___126 *);

struct request___58;

typedef int dma_drain_needed_fn___57(struct request___58 *);

struct kset___244;

struct kobj_type___244;

struct kobject___245 {
	const char *name;
	struct list_head entry;
	struct kobject___245 *parent;
	struct kset___244 *kset;
	struct kobj_type___244 *ktype;
	struct kernfs_node___252 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___57;

struct bsg_class_device___57 {
	struct device___220 *class_dev;
	int minor;
	struct request_queue___58 *queue;
	const struct bsg_ops___57 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___126 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___126 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___57;

struct rq_qos___2;

struct blk_mq_ops___3;

struct blk_mq_ctx___3;

struct blk_mq_hw_ctx___3;

struct blk_stat_callback___3;

struct blkcg_gq___46;

struct blk_trace___4;

struct blk_flush_queue___3;

struct blk_mq_tag_set___3;

struct request_queue___58 {
	struct list_head queue_head;
	struct request___58 *last_merge;
	struct elevator_queue___57 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos___2 *rq_qos;
	make_request_fn___57 *make_request_fn;
	dma_drain_needed_fn___57 *dma_drain_needed;
	const struct blk_mq_ops___3 *mq_ops;
	struct blk_mq_ctx___3 *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___3 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___126 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___245 kobj;
	struct kobject___245 *mq_kobj;
	struct blk_integrity integrity;
	struct device___220 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback___3 *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___46 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace___4 *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue___3 *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	struct bsg_class_device___57 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set___3 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___126 bio_split;
	struct dentry___257 *debugfs_dir;
	struct dentry___257 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___173 {
	struct vm_struct___173 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___258 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dev_pm_info___220 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___220 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___220;

struct bus_type___220;

struct device_driver___220;

struct dev_pm_domain___220;

struct fwnode_handle___155;

struct class___220;

struct attribute_group___222;

struct device___220 {
	struct device___220 *parent;
	struct device_private *p;
	struct kobject___245 kobj;
	const char *init_name;
	const struct device_type___220 *type;
	struct mutex mutex;
	struct bus_type___220 *bus;
	struct device_driver___220 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___220 power;
	struct dev_pm_domain___220 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___155 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___220 *class;
	const struct attribute_group___222 **groups;
	void (*release)(struct device___220 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___256;

struct super_block___256;

struct dentry___257 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___257 *d_parent;
	struct qstr d_name;
	struct inode___257 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___256 *d_op;
	struct super_block___256 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___256;

struct block_device___257;

struct inode___257 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___256 *i_op;
	struct super_block___256 *i_sb;
	struct address_space___256 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___258 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___126 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___257 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___256 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___257 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___256 {
	int (*d_revalidate)(struct dentry___257 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___257 *, unsigned int);
	int (*d_hash)(const struct dentry___257 *, struct qstr *);
	int (*d_compare)(const struct dentry___257 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___257 *);
	int (*d_init)(struct dentry___257 *);
	void (*d_release)(struct dentry___257 *);
	void (*d_prune)(struct dentry___257 *);
	void (*d_iput)(struct dentry___257 *, struct inode___257 *);
	char * (*d_dname)(struct dentry___257 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___257 *);
	int (*d_manage)(const struct path___257 *, bool);
	struct dentry___257 * (*d_real)(struct dentry___257 *, const struct inode___257 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___256;

struct mem_dqinfo___256 {
	struct quota_format_type___256 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___256;

struct quota_info___256 {
	unsigned int flags;
	struct rw_semaphore___258 dqio_sem;
	struct inode___257 *files[3];
	struct mem_dqinfo___256 info[3];
	const struct quota_format_ops___256 *ops[3];
};

struct rcuwait___256 {
	struct task_struct___258 *task;
};

struct percpu_rw_semaphore___256 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___258 rw_sem;
	struct rcuwait___256 writer;
	int readers_block;
};

struct sb_writers___256 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___256 rw_sem[3];
};

struct file_system_type___256;

struct super_operations___256;

struct dquot_operations___256;

struct quotactl_ops___256;

struct super_block___256 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___256 *s_type;
	const struct super_operations___256 *s_op;
	const struct dquot_operations___256 *dq_op;
	const struct quotactl_ops___256 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___257 *s_root;
	struct rw_semaphore___258 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___257 *s_bdev;
	struct backing_dev_info___126 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___256 s_dquot;
	struct sb_writers___256 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___256 *s_d_op;
	int cleancache_poolid;
	struct shrinker___111 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___210 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct io_cq___61 {
	struct request_queue___58 *q;
	struct io_context___61 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___6 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___257 {
	struct file___257 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___257 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___256 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___257 *ia_file;
};

struct dquot___256 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___256 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___256 {
	int qf_fmt_id;
	const struct quota_format_ops___256 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___256 *qf_next;
};

struct quota_format_ops___256 {
	int (*check_quota_file)(struct super_block___256 *, int);
	int (*read_file_info)(struct super_block___256 *, int);
	int (*write_file_info)(struct super_block___256 *, int);
	int (*free_file_info)(struct super_block___256 *, int);
	int (*read_dqblk)(struct dquot___256 *);
	int (*commit_dqblk)(struct dquot___256 *);
	int (*release_dqblk)(struct dquot___256 *);
	int (*get_next_id)(struct super_block___256 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___256 {
	int (*write_dquot)(struct dquot___256 *);
	struct dquot___256 * (*alloc_dquot)(struct super_block___256 *, int);
	void (*destroy_dquot)(struct dquot___256 *);
	int (*acquire_dquot)(struct dquot___256 *);
	int (*release_dquot)(struct dquot___256 *);
	int (*mark_dirty)(struct dquot___256 *);
	int (*write_info)(struct super_block___256 *, int);
	qsize_t * (*get_reserved_space)(struct inode___257 *);
	int (*get_projid)(struct inode___257 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___257 *, qsize_t *);
	int (*get_next_id)(struct super_block___256 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___256 {
	int (*quota_on)(struct super_block___256 *, int, int, const struct path___257 *);
	int (*quota_off)(struct super_block___256 *, int);
	int (*quota_enable)(struct super_block___256 *, unsigned int);
	int (*quota_disable)(struct super_block___256 *, unsigned int);
	int (*quota_sync)(struct super_block___256 *, int);
	int (*set_info)(struct super_block___256 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___256 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___256 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___256 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___256 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___256 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___122;

struct swap_info_struct___72;

struct address_space_operations___256 {
	int (*writepage)(struct page___258 *, struct writeback_control___122 *);
	int (*readpage)(struct file___257 *, struct page___258 *);
	int (*writepages)(struct address_space___256 *, struct writeback_control___122 *);
	int (*set_page_dirty)(struct page___258 *);
	int (*readpages)(struct file___257 *, struct address_space___256 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___257 *, struct address_space___256 *, loff_t, unsigned int, unsigned int, struct page___258 **, void **);
	int (*write_end)(struct file___257 *, struct address_space___256 *, loff_t, unsigned int, unsigned int, struct page___258 *, void *);
	sector_t (*bmap)(struct address_space___256 *, sector_t);
	void (*invalidatepage)(struct page___258 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___258 *, gfp_t);
	void (*freepage)(struct page___258 *);
	ssize_t (*direct_IO)(struct kiocb___257 *, struct iov_iter___123 *);
	int (*migratepage)(struct address_space___256 *, struct page___258 *, struct page___258 *, enum migrate_mode);
	bool (*isolate_page)(struct page___258 *, isolate_mode_t);
	void (*putback_page)(struct page___258 *);
	int (*launder_page)(struct page___258 *);
	int (*is_partially_uptodate)(struct page___258 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___258 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___256 *, struct page___258 *);
	int (*swap_activate)(struct swap_info_struct___72 *, struct file___257 *, sector_t *);
	void (*swap_deactivate)(struct file___257 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___122 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___126 *wb;
	struct inode___257 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___126;

struct iov_iter___123 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___126 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct swap_info_struct___72 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___257 *bdev;
	struct file___257 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct hd_struct___58;

struct gendisk___58;

struct block_device___257 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___257 *bd_inode;
	struct super_block___256 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___257 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___58 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___58 *bd_disk;
	struct request_queue___58 *bd_queue;
	struct backing_dev_info___126 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct hd_struct___58 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___220 __dev;
	struct kobject___245 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___58;

struct block_device_operations___58;

struct gendisk___58 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___58 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___58 *part_tbl;
	struct hd_struct___58 part0;
	const struct block_device_operations___58 *fops;
	struct request_queue___58 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___258 lookup_sem;
	struct kobject___245 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___245 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___256 {
	struct dentry___257 * (*lookup)(struct inode___257 *, struct dentry___257 *, unsigned int);
	const char * (*get_link)(struct dentry___257 *, struct inode___257 *, struct delayed_call *);
	int (*permission)(struct inode___257 *, int);
	struct posix_acl * (*get_acl)(struct inode___257 *, int);
	int (*readlink)(struct dentry___257 *, char *, int);
	int (*create)(struct inode___257 *, struct dentry___257 *, umode_t, bool);
	int (*link)(struct dentry___257 *, struct inode___257 *, struct dentry___257 *);
	int (*unlink)(struct inode___257 *, struct dentry___257 *);
	int (*symlink)(struct inode___257 *, struct dentry___257 *, const char *);
	int (*mkdir)(struct inode___257 *, struct dentry___257 *, umode_t);
	int (*rmdir)(struct inode___257 *, struct dentry___257 *);
	int (*mknod)(struct inode___257 *, struct dentry___257 *, umode_t, dev_t);
	int (*rename)(struct inode___257 *, struct dentry___257 *, struct inode___257 *, struct dentry___257 *, unsigned int);
	int (*setattr)(struct dentry___257 *, struct iattr___256 *);
	int (*getattr)(const struct path___257 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___257 *, char *, size_t);
	int (*fiemap)(struct inode___257 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___257 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___257 *, struct dentry___257 *, struct file___257 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___257 *, struct dentry___257 *, umode_t);
	int (*set_acl)(struct inode___257 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___256 {
	void (*fl_copy_lock)(struct file_lock___257 *, struct file_lock___257 *);
	void (*fl_release_private)(struct file_lock___257 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___256;

struct lock_manager_operations___256;

struct file_lock___257 {
	struct file_lock___257 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___257 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___256 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___256 *fl_ops;
	const struct lock_manager_operations___256 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___256 {
	int (*lm_compare_owner)(struct file_lock___257 *, struct file_lock___257 *);
	long unsigned int (*lm_owner_key)(struct file_lock___257 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___257 *);
	int (*lm_grant)(struct file_lock___257 *, int);
	bool (*lm_break)(struct file_lock___257 *);
	int (*lm_change)(struct file_lock___257 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___257 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___256 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___256 *fa_next;
	struct file___257 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___256 {
	const char *name;
	int fs_flags;
	struct dentry___257 * (*mount)(struct file_system_type___256 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___256 *);
	struct module___11 *owner;
	struct file_system_type___256 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___256 {
	struct inode___257 * (*alloc_inode)(struct super_block___256 *);
	void (*destroy_inode)(struct inode___257 *);
	void (*dirty_inode)(struct inode___257 *, int);
	int (*write_inode)(struct inode___257 *, struct writeback_control___122 *);
	int (*drop_inode)(struct inode___257 *);
	void (*evict_inode)(struct inode___257 *);
	void (*put_super)(struct super_block___256 *);
	int (*sync_fs)(struct super_block___256 *, int);
	int (*freeze_super)(struct super_block___256 *);
	int (*freeze_fs)(struct super_block___256 *);
	int (*thaw_super)(struct super_block___256 *);
	int (*unfreeze_fs)(struct super_block___256 *);
	int (*statfs)(struct dentry___257 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___256 *, int *, char *);
	void (*umount_begin)(struct super_block___256 *);
	int (*show_options)(struct seq_file___230 *, struct dentry___257 *);
	int (*show_devname)(struct seq_file___230 *, struct dentry___257 *);
	int (*show_path)(struct seq_file___230 *, struct dentry___257 *);
	int (*show_stats)(struct seq_file___230 *, struct dentry___257 *);
	ssize_t (*quota_read)(struct super_block___256 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___256 *, int, const char *, size_t, loff_t);
	struct dquot___256 ** (*get_dquots)(struct inode___257 *);
	int (*bdev_try_to_free_page)(struct super_block___256 *, struct page___258 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___256 *, struct shrink_control___111 *);
	long int (*free_cached_objects)(struct super_block___256 *, struct shrink_control___111 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___160)(struct file___257 *, wait_queue_head_t *, struct poll_table_struct___158 *);

struct poll_table_struct___158 {
	poll_queue_proc___160 _qproc;
	__poll_t _key;
};

struct seq_operations___228;

struct seq_file___230 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___228 *op;
	int poll_event;
	const struct file___257 *file;
	void *private;
};

typedef void bio_end_io_t___126(struct bio___126 *);

struct bio_vec___126 {
	struct page___258 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___126;

struct bio___126 {
	struct bio___126 *bi_next;
	struct gendisk___58 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___126 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___46 *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___126 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___126 *bi_io_vec;
	struct bio_set___126 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___126 bi_inline_vecs[0];
};

struct kobj_attribute___237 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___245 *, struct kobj_attribute___237 *, char *);
	ssize_t (*store)(struct kobject___245 *, struct kobj_attribute___237 *, const char *, size_t);
};

typedef void compound_page_dtor___246(struct page___258 *);

typedef int (*key_restrict_link_func_t___250)(struct key___249 *, const struct key_type *, const union key_payload *, struct key___249 *);

struct key_restriction___249;

struct key___249 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___258 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key___6 index_key;
		struct {
			struct key_type___6 *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___249 *restrict_link;
};

struct key_restriction___249 {
	key_restrict_link_func_t___250 check;
	struct key___249 *key;
	struct key_type *keytype;
};

struct seq_operations___228 {
	void * (*start)(struct seq_file___230 *, loff_t *);
	void (*stop)(struct seq_file___230 *, void *);
	void * (*next)(struct seq_file___230 *, void *, loff_t *);
	int (*show)(struct seq_file___230 *, void *);
};

struct kernfs_root___251;

struct kernfs_elem_dir___251 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___251 *root;
};

struct kernfs_syscall_ops___251;

struct kernfs_root___251 {
	struct kernfs_node___252 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___251 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___251 {
	struct kernfs_node___252 *target_kn;
};

struct kernfs_ops___251;

struct kernfs_elem_attr___251 {
	const struct kernfs_ops___251 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___252 *notify_next;
};

struct kernfs_node___252 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___252 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___251 dir;
		struct kernfs_elem_symlink___251 symlink;
		struct kernfs_elem_attr___251 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___251;

struct kernfs_ops___251 {
	int (*open)(struct kernfs_open_file___251 *);
	void (*release)(struct kernfs_open_file___251 *);
	int (*seq_show)(struct seq_file___230 *, void *);
	void * (*seq_start)(struct seq_file___230 *, loff_t *);
	void * (*seq_next)(struct seq_file___230 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___230 *, void *);
	ssize_t (*read)(struct kernfs_open_file___251 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___251 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___251 *, struct vm_area_struct___258 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___251 *, struct poll_table_struct___158 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___251 {
	int (*remount_fs)(struct kernfs_root___251 *, int *, char *);
	int (*show_options)(struct seq_file___230 *, struct kernfs_root___251 *);
	int (*mkdir)(struct kernfs_node___252 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___252 *);
	int (*rename)(struct kernfs_node___252 *, struct kernfs_node___252 *, const char *);
	int (*show_path)(struct seq_file___230 *, struct kernfs_node___252 *, struct kernfs_root___251 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___251 {
	struct kernfs_node___252 *kn;
	struct file___257 *file;
	struct seq_file___230 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___246 *vm_ops;
};

struct cgroup_namespace___195 {
	refcount_t count;
	struct ns_common___28 ns;
	struct user_namespace___210 *user_ns;
	struct ucounts___210 *ucounts;
	struct css_set___195 *root_cset;
};

struct ucounts___210 {
	struct hlist_node node;
	struct user_namespace___210 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___196;

struct bpf_map_ops___195 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___196 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___196 *, struct file___257 *);
	void (*map_free)(struct bpf_map___196 *);
	int (*map_get_next_key)(struct bpf_map___196 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___196 *);
	void * (*map_lookup_elem)(struct bpf_map___196 *, void *);
	int (*map_update_elem)(struct bpf_map___196 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___196 *, void *);
	int (*map_push_elem)(struct bpf_map___196 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___196 *, void *);
	int (*map_peek_elem)(struct bpf_map___196 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___196 *, struct file___257 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___196 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___196 *, void *, struct seq_file___230 *);
	int (*map_check_btf)(const struct bpf_map___196 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___196 {
	const struct bpf_map_ops___195 *ops;
	struct bpf_map___196 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___249 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___195;

typedef void (*kthread_work_func_t___195)(struct kthread_work___195 *);

struct kthread_worker___195;

struct kthread_work___195 {
	struct list_head node;
	kthread_work_func_t___195 func;
	struct kthread_worker___195 *worker;
	int canceling;
};

struct kthread_worker___195 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___258 *task;
	struct kthread_work___195 *current_work;
};

struct kthread_delayed_work___195 {
	struct kthread_work___195 work;
	struct timer_list timer;
};

struct psi_group___195 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___195 *poll_kworker;
	struct kthread_delayed_work___195 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___195;

struct cgroup_rstat_cpu___195;

struct cgroup___195 {
	struct cgroup_subsys_state___196 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___252 *kn;
	struct cgroup_file___195 procs_file;
	struct cgroup_file___195 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___196 *subsys[13];
	struct cgroup_root___195 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___195 *dom_cgrp;
	struct cgroup_rstat_cpu___195 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___34 bpf;
	atomic_t congestion_count;
	struct cgroup___195 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___195 psi;
	int ancestor_ids[0];
};

struct cftype___195;

struct cgroup_subsys___195 {
	struct cgroup_subsys_state___196 * (*css_alloc)(struct cgroup_subsys_state___196 *);
	int (*css_online)(struct cgroup_subsys_state___196 *);
	void (*css_offline)(struct cgroup_subsys_state___196 *);
	void (*css_released)(struct cgroup_subsys_state___196 *);
	void (*css_free)(struct cgroup_subsys_state___196 *);
	void (*css_reset)(struct cgroup_subsys_state___196 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___196 *, int);
	int (*css_extra_stat_show)(struct seq_file___230 *, struct cgroup_subsys_state___196 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___258 *);
	void (*cancel_fork)(struct task_struct___258 *);
	void (*fork)(struct task_struct___258 *);
	void (*exit)(struct task_struct___258 *);
	void (*free)(struct task_struct___258 *);
	void (*bind)(struct cgroup_subsys_state___196 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___195 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___195 *dfl_cftypes;
	struct cftype___195 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___195 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___195 *updated_children;
	struct cgroup___195 *updated_next;
};

struct cgroup_root___195 {
	struct kernfs_root___251 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___195 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___195 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___195 *ss;
	struct list_head node;
	struct kernfs_ops___251 *kf_ops;
	int (*open)(struct kernfs_open_file___251 *);
	void (*release)(struct kernfs_open_file___251 *);
	u64 (*read_u64)(struct cgroup_subsys_state___196 *, struct cftype___195 *);
	s64 (*read_s64)(struct cgroup_subsys_state___196 *, struct cftype___195 *);
	int (*seq_show)(struct seq_file___230 *, void *);
	void * (*seq_start)(struct seq_file___230 *, loff_t *);
	void * (*seq_next)(struct seq_file___230 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___230 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___196 *, struct cftype___195 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___196 *, struct cftype___195 *, s64);
	ssize_t (*write)(struct kernfs_open_file___251 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___251 *, struct poll_table_struct___158 *);
};

struct bdi_writeback_congested___126 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___126 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___126 {
	struct bio___126 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___126 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___126 bip_inline_vecs[0];
};

struct blkcg___46;

struct blkg_policy_data___46;

struct blkcg_gq___46 {
	struct request_queue___58 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___46 *blkcg;
	struct bdi_writeback_congested___126 *wb_congested;
	struct blkcg_gq___46 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_rwstat stat_bytes;
	struct blkg_rwstat stat_ios;
	struct blkg_policy_data___46 *pd[5];
	struct callback_head callback_head;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
};

struct biovec_slab {
	int nr_vecs;
	char *name;
	struct kmem_cache *slab;
};

struct mem_cgroup_reclaim_iter___111 {
	struct mem_cgroup___111 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___111 {
	struct lruvec___257 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___111 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___111 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct bin_attribute___221;

struct attribute_group___222 {
	const char *name;
	umode_t (*is_visible)(struct kobject___245 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___245 *, struct bin_attribute___221 *, int);
	struct attribute **attrs;
	struct bin_attribute___221 **bin_attrs;
};

struct bin_attribute___221 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___257 *, struct kobject___245 *, struct bin_attribute___221 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___257 *, struct kobject___245 *, struct bin_attribute___221 *, char *, loff_t, size_t);
	int (*mmap)(struct file___257 *, struct kobject___245 *, struct bin_attribute___221 *, struct vm_area_struct___258 *);
};

struct sysfs_ops___244 {
	ssize_t (*show)(struct kobject___245 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___245 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___244;

struct kset___244 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___245 kobj;
	const struct kset_uevent_ops___244 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___244 {
	void (*release)(struct kobject___245 *);
	const struct sysfs_ops___244 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___24 * (*child_ns_type)(struct kobject___245 *);
	const void * (*namespace)(struct kobject___245 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___244 {
	int (* const filter)(struct kset___244 *, struct kobject___245 *);
	const char * (* const name)(struct kset___244 *, struct kobject___245 *);
	int (* const uevent)(struct kset___244 *, struct kobject___245 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___220 {
	int (*prepare)(struct device___220 *);
	void (*complete)(struct device___220 *);
	int (*suspend)(struct device___220 *);
	int (*resume)(struct device___220 *);
	int (*freeze)(struct device___220 *);
	int (*thaw)(struct device___220 *);
	int (*poweroff)(struct device___220 *);
	int (*restore)(struct device___220 *);
	int (*suspend_late)(struct device___220 *);
	int (*resume_early)(struct device___220 *);
	int (*freeze_late)(struct device___220 *);
	int (*thaw_early)(struct device___220 *);
	int (*poweroff_late)(struct device___220 *);
	int (*restore_early)(struct device___220 *);
	int (*suspend_noirq)(struct device___220 *);
	int (*resume_noirq)(struct device___220 *);
	int (*freeze_noirq)(struct device___220 *);
	int (*thaw_noirq)(struct device___220 *);
	int (*poweroff_noirq)(struct device___220 *);
	int (*restore_noirq)(struct device___220 *);
	int (*runtime_suspend)(struct device___220 *);
	int (*runtime_resume)(struct device___220 *);
	int (*runtime_idle)(struct device___220 *);
};

struct dev_pm_domain___220 {
	struct dev_pm_ops___220 ops;
	void (*detach)(struct device___220 *, bool);
	int (*activate)(struct device___220 *);
	void (*sync)(struct device___220 *);
	void (*dismiss)(struct device___220 *);
};

struct bus_type___220 {
	const char *name;
	const char *dev_name;
	struct device___220 *dev_root;
	const struct attribute_group___222 **bus_groups;
	const struct attribute_group___222 **dev_groups;
	const struct attribute_group___222 **drv_groups;
	int (*match)(struct device___220 *, struct device_driver___220 *);
	int (*uevent)(struct device___220 *, struct kobj_uevent_env *);
	int (*probe)(struct device___220 *);
	int (*remove)(struct device___220 *);
	void (*shutdown)(struct device___220 *);
	int (*online)(struct device___220 *);
	int (*offline)(struct device___220 *);
	int (*suspend)(struct device___220 *, pm_message_t);
	int (*resume)(struct device___220 *);
	int (*num_vf)(struct device___220 *);
	int (*dma_configure)(struct device___220 *);
	const struct dev_pm_ops___220 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___220 {
	const char *name;
	struct bus_type___220 *bus;
	struct module___11 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___220 *);
	int (*remove)(struct device___220 *);
	void (*shutdown)(struct device___220 *);
	int (*suspend)(struct device___220 *, pm_message_t);
	int (*resume)(struct device___220 *);
	const struct attribute_group___222 **groups;
	const struct dev_pm_ops___220 *pm;
	void (*coredump)(struct device___220 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___220 {
	const char *name;
	const struct attribute_group___222 **groups;
	int (*uevent)(struct device___220 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___220 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___220 *);
	const struct dev_pm_ops___220 *pm;
};

struct class___220 {
	const char *name;
	struct module___11 *owner;
	const struct attribute_group___222 **class_groups;
	const struct attribute_group___222 **dev_groups;
	struct kobject___245 *dev_kobj;
	int (*dev_uevent)(struct device___220 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___220 *, umode_t *);
	void (*class_release)(struct class___220 *);
	void (*dev_release)(struct device___220 *);
	int (*shutdown_pre)(struct device___220 *);
	const struct kobj_ns_type_operations___24 *ns_type;
	const void * (*namespace)(struct device___220 *);
	const struct dev_pm_ops___220 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct fwnode_operations___155;

struct fwnode_handle___155 {
	struct fwnode_handle___155 *secondary;
	const struct fwnode_operations___155 *ops;
};

struct node___170 {
	struct device___220 dev;
};

struct disk_part_tbl___58 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___58 *last_lookup;
	struct hd_struct___58 *part[0];
};

struct block_device_operations___58 {
	int (*open)(struct block_device___257 *, fmode_t);
	void (*release)(struct gendisk___58 *, fmode_t);
	int (*rw_page)(struct block_device___257 *, sector_t, struct page___258 *, unsigned int);
	int (*ioctl)(struct block_device___257 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___257 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___58 *, unsigned int);
	int (*media_changed)(struct gendisk___58 *);
	void (*unlock_native_capacity)(struct gendisk___58 *);
	int (*revalidate_disk)(struct gendisk___58 *);
	int (*getgeo)(struct block_device___257 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___257 *, long unsigned int);
	int (*report_zones)(struct gendisk___58 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___11 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___57 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___58 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___58 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___58 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___57(struct request___58 *, blk_status_t);

struct request___58 {
	struct request_queue___58 *q;
	struct blk_mq_ctx___3 *mq_ctx;
	struct blk_mq_hw_ctx___3 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___126 *bio;
	struct bio___126 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___126 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___61 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___57 *saved_end_io;
		} flush;
	};
	struct gendisk___58 *rq_disk;
	struct hd_struct___58 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___57 *end_io;
	void *end_io_data;
	struct request___58 *next_rq;
};

struct fwnode_reference_args___155;

struct fwnode_endpoint___155;

struct fwnode_operations___155 {
	struct fwnode_handle___155 * (*get)(struct fwnode_handle___155 *);
	void (*put)(struct fwnode_handle___155 *);
	bool (*device_is_available)(const struct fwnode_handle___155 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___155 *, const struct device___220 *);
	bool (*property_present)(const struct fwnode_handle___155 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___155 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___155 *, const char *, const char **, size_t);
	struct fwnode_handle___155 * (*get_parent)(const struct fwnode_handle___155 *);
	struct fwnode_handle___155 * (*get_next_child_node)(const struct fwnode_handle___155 *, struct fwnode_handle___155 *);
	struct fwnode_handle___155 * (*get_named_child_node)(const struct fwnode_handle___155 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___155 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___155 *);
	struct fwnode_handle___155 * (*graph_get_next_endpoint)(const struct fwnode_handle___155 *, struct fwnode_handle___155 *);
	struct fwnode_handle___155 * (*graph_get_remote_endpoint)(const struct fwnode_handle___155 *);
	struct fwnode_handle___155 * (*graph_get_port_parent)(struct fwnode_handle___155 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___155 *, struct fwnode_endpoint___155 *);
};

struct fwnode_endpoint___155 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___155 *local_fwnode;
};

struct fwnode_reference_args___155 {
	struct fwnode_handle___155 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct blk_mq_ctxs___2;

struct blk_mq_ctx___3 {
	struct {
		spinlock_t lock;
		struct list_head rq_lists[3];
		long: 64;
	};
	unsigned int cpu;
	short unsigned int index_hw[3];
	struct blk_mq_hw_ctx___3 *hctxs[3];
	long unsigned int rq_dispatched[2];
	long unsigned int rq_merged;
	long unsigned int rq_completed[2];
	struct request_queue___58 *queue;
	struct blk_mq_ctxs___2 *ctxs;
	struct kobject___245 kobj;
};

struct blk_mq_tags___2;

struct blk_mq_hw_ctx___3 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___58 *queue;
	struct blk_flush_queue___3 *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx___3 *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx___3 **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags___2 *tags;
	struct blk_mq_tags___2 *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	unsigned int rh_reserved_nr_expired;
	struct hlist_node cpuhp_dead;
	struct kobject___245 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___257 *debugfs_dir;
	struct dentry___257 *sched_debugfs_dir;
	struct list_head hctx_list;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___57;

struct blk_mq_alloc_data___3;

struct elevator_mq_ops___57 {
	int (*init_sched)(struct request_queue___58 *, struct elevator_type___57 *);
	void (*exit_sched)(struct elevator_queue___57 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___3 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___3 *, unsigned int);
	bool (*allow_merge)(struct request_queue___58 *, struct request___58 *, struct bio___126 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx___3 *, struct bio___126 *);
	int (*request_merge)(struct request_queue___58 *, struct request___58 **, struct bio___126 *);
	void (*request_merged)(struct request_queue___58 *, struct request___58 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___58 *, struct request___58 *, struct request___58 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data___3 *);
	void (*prepare_request)(struct request___58 *, struct bio___126 *);
	void (*finish_request)(struct request___58 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___3 *, struct list_head *, bool);
	struct request___58 * (*dispatch_request)(struct blk_mq_hw_ctx___3 *);
	bool (*has_work)(struct blk_mq_hw_ctx___3 *);
	void (*completed_request)(struct request___58 *, u64);
	void (*started_request)(struct request___58 *);
	void (*requeue_request)(struct request___58 *);
	struct request___58 * (*former_request)(struct request_queue___58 *, struct request___58 *);
	struct request___58 * (*next_request)(struct request_queue___58 *, struct request___58 *);
	void (*init_icq)(struct io_cq___61 *);
	void (*exit_icq)(struct io_cq___61 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx___3 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___57;

struct elevator_type___57 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___57 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___57 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___11 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___57 {
	struct elevator_type___57 *type;
	void *elevator_data;
	struct kobject___245 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct blk_mq_alloc_data___3 {
	struct request_queue___58 *q;
	blk_mq_req_flags_t flags;
	unsigned int shallow_depth;
	unsigned int cmd_flags;
	struct blk_mq_ctx___3 *ctx;
	struct blk_mq_hw_ctx___3 *hctx;
};

struct elv_fs_entry___57 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___57 *, char *);
	ssize_t (*store)(struct elevator_queue___57 *, const char *, size_t);
};

enum rq_qos_id {
	RQ_QOS_WBT = 0,
	RQ_QOS_CGROUP = 1,
};

struct rq_qos_ops;

struct rq_qos___2 {
	struct rq_qos_ops *ops;
	struct request_queue___58 *q;
	enum rq_qos_id id;
	struct rq_qos___2 *next;
};

struct blk_mq_queue_data___3;

typedef blk_status_t queue_rq_fn___3(struct blk_mq_hw_ctx___3 *, const struct blk_mq_queue_data___3 *);

typedef void commit_rqs_fn___3(struct blk_mq_hw_ctx___3 *);

typedef bool get_budget_fn___3(struct blk_mq_hw_ctx___3 *);

typedef void put_budget_fn___3(struct blk_mq_hw_ctx___3 *);

typedef enum blk_eh_timer_return timeout_fn___3(struct request___58 *, bool);

typedef int poll_fn___3(struct blk_mq_hw_ctx___3 *);

typedef void complete_fn___3(struct request___58 *);

typedef int init_hctx_fn___3(struct blk_mq_hw_ctx___3 *, void *, unsigned int);

typedef void exit_hctx_fn___3(struct blk_mq_hw_ctx___3 *, unsigned int);

typedef int init_request_fn___3(struct blk_mq_tag_set___3 *, struct request___58 *, unsigned int, unsigned int);

typedef void exit_request_fn___3(struct blk_mq_tag_set___3 *, struct request___58 *, unsigned int);

typedef bool busy_fn___3(struct request_queue___58 *);

typedef int map_queues_fn___3(struct blk_mq_tag_set___3 *);

typedef void cleanup_rq_fn___3(struct request___58 *);

struct blk_mq_ops___3 {
	queue_rq_fn___3 *queue_rq;
	commit_rqs_fn___3 *commit_rqs;
	get_budget_fn___3 *get_budget;
	put_budget_fn___3 *put_budget;
	timeout_fn___3 *timeout;
	poll_fn___3 *poll;
	complete_fn___3 *complete;
	init_hctx_fn___3 *init_hctx;
	exit_hctx_fn___3 *exit_hctx;
	init_request_fn___3 *init_request;
	exit_request_fn___3 *exit_request;
	void (*initialize_rq_fn)(struct request___58 *);
	busy_fn___3 *busy;
	map_queues_fn___3 *map_queues;
	void (*show_rq)(struct seq_file___230 *, struct request___58 *);
	union {
		cleanup_rq_fn___3 *cleanup_rq;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide45;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct blk_stat_callback___3 {
	struct list_head list;
	struct timer_list timer;
	struct blk_rq_stat *cpu_stat;
	int (*bucket_fn)(const struct request___58 *);
	unsigned int buckets;
	struct blk_rq_stat *stat;
	void (*timer_fn)(struct blk_stat_callback___3 *);
	void *data;
	struct callback_head rcu;
};

struct rchan___4;

struct blk_trace___4 {
	int trace_state;
	struct rchan___4 *rchan;
	long unsigned int *sequence;
	unsigned char *msg_data;
	u16 act_mask;
	u64 start_lba;
	u64 end_lba;
	u32 pid;
	u32 dev;
	struct dentry___257 *dir;
	struct dentry___257 *dropped_file;
	struct dentry___257 *msg_file;
	struct list_head running_list;
	atomic_t dropped;
};

struct blk_flush_queue___3 {
	unsigned int flush_queue_delayed: 1;
	unsigned int flush_pending_idx: 1;
	unsigned int flush_running_idx: 1;
	long unsigned int flush_pending_since;
	struct list_head flush_queue[2];
	struct list_head flush_data_in_flight;
	struct request___58 *flush_rq;
	struct request___58 *orig_rq;
	spinlock_t mq_flush_lock;
};

struct blk_mq_tag_set___3 {
	struct blk_mq_queue_map map[6];
	unsigned int nr_maps;
	const struct blk_mq_ops___3 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	struct blk_mq_tags___2 **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct rq_map_data {
	struct page___258 **pages;
	int page_order;
	int nr_entries;
	long unsigned int offset;
	int null_mapped;
	int from_user;
};

struct blkcg_policy_data___46;

struct blkcg___46 {
	struct cgroup_subsys_state___196 css;
	spinlock_t lock;
	struct xarray blkg_tree;
	struct blkcg_gq___46 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___46 *cpd[5];
	struct list_head all_blkcgs_node;
	struct list_head cgwb_list;
	refcount_t cgwb_refcnt;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct blkcg_policy_data___46 {
	struct blkcg___46 *blkcg;
	int plid;
};

struct blkg_policy_data___46 {
	struct blkcg_gq___46 *blkg;
	int plid;
};

struct rchan_buf___4 {
	void *start;
	void *data;
	size_t offset;
	size_t subbufs_produced;
	size_t subbufs_consumed;
	struct rchan___4 *chan;
	wait_queue_head_t read_wait;
	struct irq_work wakeup_work;
	struct dentry___257 *dentry;
	struct kref kref;
	struct page___258 **page_array;
	unsigned int page_count;
	unsigned int finalized;
	size_t *padding;
	size_t prev_padding;
	size_t bytes_consumed;
	size_t early_bytes;
	unsigned int cpu;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
};

struct rchan_callbacks___4;

struct rchan___4 {
	u32 version;
	size_t subbuf_size;
	size_t n_subbufs;
	size_t alloc_size;
	struct rchan_callbacks___4 *cb;
	struct kref kref;
	void *private_data;
	size_t last_toobig;
	struct rchan_buf___4 **buf;
	int is_global;
	struct list_head list;
	struct dentry___257 *parent;
	int has_base_filename;
	char base_filename[255];
};

struct rchan_callbacks___4 {
	int (*subbuf_start)(struct rchan_buf___4 *, void *, void *, size_t);
	void (*buf_mapped)(struct rchan_buf___4 *, struct file___257 *);
	void (*buf_unmapped)(struct rchan_buf___4 *, struct file___257 *);
	struct dentry___257 * (*create_buf_file)(const char *, struct dentry___257 *, umode_t, struct rchan_buf___4 *, int *);
	int (*remove_buf_file)(struct dentry___257 *);
};

struct blk_mq_tags___2 {
	unsigned int nr_tags;
	unsigned int nr_reserved_tags;
	atomic_t active_queues;
	struct sbitmap_queue bitmap_tags;
	struct sbitmap_queue breserved_tags;
	struct request___58 **rqs;
	struct request___58 **static_rqs;
	struct list_head page_list;
};

struct blk_mq_queue_data___3 {
	struct request___58 *rq;
	bool last;
	long unsigned int rh_reserved1;
};

enum xen_domain_type {
	XEN_NATIVE = 0,
	XEN_PV_DOMAIN = 1,
	XEN_HVM_DOMAIN = 2,
};

struct blk_mq_ctxs___2 {
	struct kobject___245 kobj;
	struct blk_mq_ctx___3 *queue_ctx;
};

struct rq_qos_ops {
	void (*throttle)(struct rq_qos___2 *, struct bio___126 *);
	void (*track)(struct rq_qos___2 *, struct request___58 *, struct bio___126 *);
	void (*issue)(struct rq_qos___2 *, struct request___58 *);
	void (*requeue)(struct rq_qos___2 *, struct request___58 *);
	void (*done)(struct rq_qos___2 *, struct request___58 *);
	void (*done_bio)(struct rq_qos___2 *, struct bio___126 *);
	void (*cleanup)(struct rq_qos___2 *, struct bio___126 *);
	void (*exit)(struct rq_qos___2 *);
};

struct bio_slab {
	struct kmem_cache *slab;
	unsigned int slab_ref;
	unsigned int slab_size;
	char name[8];
};

struct bio_map_data {
	int is_our_pages;
	struct iov_iter___123 iter;
	struct iovec iov[0];
};

struct module___211;

struct file___258;

struct kiocb___258;

struct iov_iter___124;

struct poll_table_struct___159;

struct vm_area_struct___259;

struct inode___258;

struct file_lock___258;

struct page___259;

struct seq_file___231;

struct file_operations___258 {
	struct module___211 *owner;
	loff_t (*llseek)(struct file___258 *, loff_t, int);
	ssize_t (*read)(struct file___258 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___258 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___258 *, struct iov_iter___124 *);
	ssize_t (*write_iter)(struct kiocb___258 *, struct iov_iter___124 *);
	int (*iopoll)(struct kiocb___258 *, bool);
	int (*iterate)(struct file___258 *, struct dir_context *);
	int (*iterate_shared)(struct file___258 *, struct dir_context *);
	__poll_t (*poll)(struct file___258 *, struct poll_table_struct___159 *);
	long int (*unlocked_ioctl)(struct file___258 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___258 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___258 *, struct vm_area_struct___259 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___258 *, struct file___258 *);
	int (*flush)(struct file___258 *, fl_owner_t);
	int (*release)(struct inode___258 *, struct file___258 *);
	int (*fsync)(struct file___258 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___258 *, int);
	int (*lock)(struct file___258 *, int, struct file_lock___258 *);
	ssize_t (*sendpage)(struct file___258 *, struct page___259 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___258 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___258 *, int, struct file_lock___258 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___258 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___258 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___258 *, long int, struct file_lock___258 **, void **);
	long int (*fallocate)(struct file___258 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___231 *, struct file___258 *);
	ssize_t (*copy_file_range)(struct file___258 *, loff_t, struct file___258 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___258 *, loff_t, struct file___258 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___258 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___258 {
	u64 seqnum;
	struct vm_area_struct___259 *vmas[4];
};

struct page_frag___258 {
	struct page___259 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___258;

struct cred___250;

struct nsproxy___231;

struct bio_list___127;

struct backing_dev_info___127;

struct io_context___62;

struct css_set___196;

struct request_queue___59;

struct vm_struct___174;

struct task_struct___259 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___259 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___258 *mm;
	struct mm_struct___258 *active_mm;
	struct vmacache___258 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___259 *real_parent;
	struct task_struct___259 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___259 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___188 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___188 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___188 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___250 *ptracer_cred;
	const struct cred___250 *real_cred;
	const struct cred___250 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___231 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___259 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___127 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___127 *backing_dev_info;
	struct io_context___62 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___196 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___258 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___59 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___259 *oom_reaper_list;
	struct vm_struct___174 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___127 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___257;

struct super_block___257;

struct dentry___258 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___258 *d_parent;
	struct qstr d_name;
	struct inode___258 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___257 *d_op;
	struct super_block___257 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct rw_semaphore___259 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___259 *owner;
};

struct address_space_operations___257;

struct address_space___257 {
	struct inode___258 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___259 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___257 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___257;

struct bdi_writeback___127;

struct block_device___258;

struct inode___258 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___257 *i_op;
	struct super_block___257 *i_sb;
	struct address_space___257 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___259 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___127 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___258 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___257 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___258 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___258;

struct dentry_operations___257 {
	int (*d_revalidate)(struct dentry___258 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___258 *, unsigned int);
	int (*d_hash)(const struct dentry___258 *, struct qstr *);
	int (*d_compare)(const struct dentry___258 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___258 *);
	int (*d_init)(struct dentry___258 *);
	void (*d_release)(struct dentry___258 *);
	void (*d_prune)(struct dentry___258 *);
	void (*d_iput)(struct dentry___258 *, struct inode___258 *);
	char * (*d_dname)(struct dentry___258 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___258 *);
	int (*d_manage)(const struct path___258 *, bool);
	struct dentry___258 * (*d_real)(struct dentry___258 *, const struct inode___258 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___257;

struct mem_dqinfo___257 {
	struct quota_format_type___257 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___257;

struct quota_info___257 {
	unsigned int flags;
	struct rw_semaphore___259 dqio_sem;
	struct inode___258 *files[3];
	struct mem_dqinfo___257 info[3];
	const struct quota_format_ops___257 *ops[3];
};

struct rcuwait___257 {
	struct task_struct___259 *task;
};

struct percpu_rw_semaphore___257 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___259 rw_sem;
	struct rcuwait___257 writer;
	int readers_block;
};

struct sb_writers___257 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___257 rw_sem[3];
};

struct file_system_type___257;

struct super_operations___257;

struct dquot_operations___257;

struct quotactl_ops___257;

struct user_namespace___211;

struct super_block___257 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___257 *s_type;
	const struct super_operations___257 *s_op;
	const struct dquot_operations___257 *dq_op;
	const struct quotactl_ops___257 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___258 *s_root;
	struct rw_semaphore___259 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___258 *s_bdev;
	struct backing_dev_info___127 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___257 s_dquot;
	struct sb_writers___257 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___257 *s_d_op;
	int cleancache_poolid;
	struct shrinker___111 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___211 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct path___258 {
	struct vfsmount *mnt;
	struct dentry___258 *dentry;
};

struct key___250;

struct ucounts___211;

struct user_namespace___211 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___211 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___28 ns;
	long unsigned int flags;
	struct key___250 *persistent_keyring_register;
	struct rw_semaphore___259 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___211 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___259 *pgtable_t___258;

struct dev_pagemap___247;

struct page___259 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___257 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___259 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___258 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___258 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___247 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___258;

struct lruvec___258 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___258 *pgdat;
};

struct zone___258 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___258 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___258 {
	struct zone___258 *zone;
	int zone_idx;
};

struct zonelist___258 {
	struct zoneref___258 _zonerefs[25];
};

struct pglist_data___258 {
	struct zone___258 node_zones[3];
	struct zonelist___258 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___259 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___259 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___258 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___259 {
	void *stack;
	struct task_struct___259 *task;
	long int status;
};

struct blocking_notifier_head___258 {
	struct rw_semaphore___259 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___247;

struct vm_area_struct___259 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___259 *vm_next;
	struct vm_area_struct___259 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___258 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___247 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___258 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___258;

struct mm_struct___258 {
	struct {
		struct vm_area_struct___259 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___258 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___259 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___258 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___259 *owner;
		struct user_namespace___211 *user_ns;
		struct file___258 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___258 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___247)(struct vm_area_struct___259 *, long unsigned int, const struct page___259 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___247)(struct page___259 *, void *);

struct device___221;

struct dev_pagemap___247 {
	dev_page_fault_t___247 page_fault;
	dev_page_free_t___247 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___221 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct file___258 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___258 f_path;
	struct inode___258 *f_inode;
	const struct file_operations___258 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___188 f_owner;
	const struct cred___250 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___257 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___247;

struct vm_operations_struct___247 {
	void (*open)(struct vm_area_struct___259 *);
	void (*close)(struct vm_area_struct___259 *);
	int (*split)(struct vm_area_struct___259 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___259 *);
	vm_fault_t (*fault)(struct vm_fault___247 *);
	vm_fault_t (*huge_fault)(struct vm_fault___247 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___247 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___259 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___247 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___247 *);
	int (*access)(struct vm_area_struct___259 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___259 *);
	int (*set_policy)(struct vm_area_struct___259 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___259 *, long unsigned int);
	struct page___259 * (*find_special_page)(struct vm_area_struct___259 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___258 {
	struct task_struct___259 *task;
	struct core_thread___258 *next;
};

struct core_state___258 {
	atomic_t nr_threads;
	struct core_thread___258 dumper;
	struct completion startup;
};

struct vm_fault___247 {
	struct vm_area_struct___259 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___259 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___259 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___258 prealloc_pte;
};

struct user_struct___250 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___250 *uid_keyring;
	struct key___250 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___250 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___250 *session_keyring;
	struct key___250 *process_keyring;
	struct key___250 *thread_keyring;
	struct key___250 *request_key_auth;
	void *security;
	struct user_struct___250 *user;
	struct user_namespace___211 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___196;

struct nsproxy___231 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___196 *cgroup_ns;
};

struct bio___127;

struct bio_list___127 {
	struct bio___127 *head;
	struct bio___127 *tail;
};

struct bdi_writeback_congested___127;

struct cgroup_subsys_state___197;

struct bdi_writeback___127 {
	struct backing_dev_info___127 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___127 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___197 *memcg_css;
	struct cgroup_subsys_state___197 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___127 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___127 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___221 *dev;
	struct device___221 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___258 *debug_dir;
	struct dentry___258 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___62;

struct io_context___62 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___62 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___196;

struct css_set___196 {
	struct cgroup_subsys_state___197 *subsys[13];
	refcount_t refcount;
	struct css_set___196 *dom_cset;
	struct cgroup___196 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___196 *mg_src_cgrp;
	struct cgroup___196 *mg_dst_cgrp;
	struct css_set___196 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

typedef blk_qc_t make_request_fn___58(struct request_queue___59 *, struct bio___127 *);

struct request___59;

typedef int dma_drain_needed_fn___58(struct request___59 *);

struct kset___245;

struct kobj_type___245;

struct kernfs_node___253;

struct kobject___246 {
	const char *name;
	struct list_head entry;
	struct kobject___246 *parent;
	struct kset___245 *kset;
	struct kobj_type___245 *ktype;
	struct kernfs_node___253 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___58;

struct bsg_class_device___58 {
	struct device___221 *class_dev;
	int minor;
	struct request_queue___59 *queue;
	const struct bsg_ops___58 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___127 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___127 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___58;

struct rq_qos___3;

struct blk_mq_ops___4;

struct blk_mq_ctx___4;

struct blk_mq_hw_ctx___4;

struct blk_stat_callback___4;

struct blkcg_gq___47;

struct blk_trace___5;

struct blk_flush_queue___4;

struct blk_mq_tag_set___4;

struct request_queue___59 {
	struct list_head queue_head;
	struct request___59 *last_merge;
	struct elevator_queue___58 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos___3 *rq_qos;
	make_request_fn___58 *make_request_fn;
	dma_drain_needed_fn___58 *dma_drain_needed;
	const struct blk_mq_ops___4 *mq_ops;
	struct blk_mq_ctx___4 *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___4 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___127 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___246 kobj;
	struct kobject___246 *mq_kobj;
	struct blk_integrity integrity;
	struct device___221 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback___4 *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___47 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace___5 *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue___4 *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	struct bsg_class_device___58 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set___4 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___127 bio_split;
	struct dentry___258 *debugfs_dir;
	struct dentry___258 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___174 {
	struct vm_struct___174 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___259 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct io_cq___62 {
	struct request_queue___59 *q;
	struct io_context___62 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___6 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___258 {
	struct file___258 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___258 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___257 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___258 *ia_file;
};

struct dquot___257 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___257 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___257 {
	int qf_fmt_id;
	const struct quota_format_ops___257 *qf_ops;
	struct module___211 *qf_owner;
	struct quota_format_type___257 *qf_next;
};

struct quota_format_ops___257 {
	int (*check_quota_file)(struct super_block___257 *, int);
	int (*read_file_info)(struct super_block___257 *, int);
	int (*write_file_info)(struct super_block___257 *, int);
	int (*free_file_info)(struct super_block___257 *, int);
	int (*read_dqblk)(struct dquot___257 *);
	int (*commit_dqblk)(struct dquot___257 *);
	int (*release_dqblk)(struct dquot___257 *);
	int (*get_next_id)(struct super_block___257 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___257 {
	int (*write_dquot)(struct dquot___257 *);
	struct dquot___257 * (*alloc_dquot)(struct super_block___257 *, int);
	void (*destroy_dquot)(struct dquot___257 *);
	int (*acquire_dquot)(struct dquot___257 *);
	int (*release_dquot)(struct dquot___257 *);
	int (*mark_dirty)(struct dquot___257 *);
	int (*write_info)(struct super_block___257 *, int);
	qsize_t * (*get_reserved_space)(struct inode___258 *);
	int (*get_projid)(struct inode___258 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___258 *, qsize_t *);
	int (*get_next_id)(struct super_block___257 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___257 {
	int (*quota_on)(struct super_block___257 *, int, int, const struct path___258 *);
	int (*quota_off)(struct super_block___257 *, int);
	int (*quota_enable)(struct super_block___257 *, unsigned int);
	int (*quota_disable)(struct super_block___257 *, unsigned int);
	int (*quota_sync)(struct super_block___257 *, int);
	int (*set_info)(struct super_block___257 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___257 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___257 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___257 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___257 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___257 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___208 {
	struct kobject___246 kobj;
	struct module___211 *mod;
	struct kobject___246 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___208 {
	struct module___211 *mod;
	struct latch_tree_node node;
};

struct module_layout___208 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___208 mtn;
};

struct module_attribute___208;

struct kernel_param___208;

struct module___211 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___208 mkobj;
	struct module_attribute___208 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___246 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___208 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___208 core_layout;
	struct module_layout___208 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide40;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide41;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___257 {
	int (*writepage)(struct page___259 *, struct writeback_control___3 *);
	int (*readpage)(struct file___258 *, struct page___259 *);
	int (*writepages)(struct address_space___257 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___259 *);
	int (*readpages)(struct file___258 *, struct address_space___257 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___258 *, struct address_space___257 *, loff_t, unsigned int, unsigned int, struct page___259 **, void **);
	int (*write_end)(struct file___258 *, struct address_space___257 *, loff_t, unsigned int, unsigned int, struct page___259 *, void *);
	sector_t (*bmap)(struct address_space___257 *, sector_t);
	void (*invalidatepage)(struct page___259 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___259 *, gfp_t);
	void (*freepage)(struct page___259 *);
	ssize_t (*direct_IO)(struct kiocb___258 *, struct iov_iter___124 *);
	int (*migratepage)(struct address_space___257 *, struct page___259 *, struct page___259 *, enum migrate_mode);
	bool (*isolate_page)(struct page___259 *, isolate_mode_t);
	void (*putback_page)(struct page___259 *);
	int (*launder_page)(struct page___259 *);
	int (*is_partially_uptodate)(struct page___259 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___259 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___257 *, struct page___259 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___258 *, sector_t *);
	void (*swap_deactivate)(struct file___258 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio_vec___127;

struct iov_iter___124 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___127 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct hd_struct___59;

struct gendisk___59;

struct block_device___258 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___258 *bd_inode;
	struct super_block___257 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___258 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___59 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___59 *bd_disk;
	struct request_queue___59 *bd_queue;
	struct backing_dev_info___127 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___221 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___221 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___221;

struct bus_type___221;

struct device_driver___221;

struct dev_pm_domain___221;

struct fwnode_handle___156;

struct class___221;

struct attribute_group___223;

struct device___221 {
	struct device___221 *parent;
	struct device_private *p;
	struct kobject___246 kobj;
	const char *init_name;
	const struct device_type___221 *type;
	struct mutex mutex;
	struct bus_type___221 *bus;
	struct device_driver___221 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___221 power;
	struct dev_pm_domain___221 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___156 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___221 *class;
	const struct attribute_group___223 **groups;
	void (*release)(struct device___221 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___59 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___221 __dev;
	struct kobject___246 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___59;

struct block_device_operations___59;

struct gendisk___59 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___59 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___59 *part_tbl;
	struct hd_struct___59 part0;
	const struct block_device_operations___59 *fops;
	struct request_queue___59 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___259 lookup_sem;
	struct kobject___246 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___246 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___257 {
	struct dentry___258 * (*lookup)(struct inode___258 *, struct dentry___258 *, unsigned int);
	const char * (*get_link)(struct dentry___258 *, struct inode___258 *, struct delayed_call *);
	int (*permission)(struct inode___258 *, int);
	struct posix_acl * (*get_acl)(struct inode___258 *, int);
	int (*readlink)(struct dentry___258 *, char *, int);
	int (*create)(struct inode___258 *, struct dentry___258 *, umode_t, bool);
	int (*link)(struct dentry___258 *, struct inode___258 *, struct dentry___258 *);
	int (*unlink)(struct inode___258 *, struct dentry___258 *);
	int (*symlink)(struct inode___258 *, struct dentry___258 *, const char *);
	int (*mkdir)(struct inode___258 *, struct dentry___258 *, umode_t);
	int (*rmdir)(struct inode___258 *, struct dentry___258 *);
	int (*mknod)(struct inode___258 *, struct dentry___258 *, umode_t, dev_t);
	int (*rename)(struct inode___258 *, struct dentry___258 *, struct inode___258 *, struct dentry___258 *, unsigned int);
	int (*setattr)(struct dentry___258 *, struct iattr___257 *);
	int (*getattr)(const struct path___258 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___258 *, char *, size_t);
	int (*fiemap)(struct inode___258 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___258 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___258 *, struct dentry___258 *, struct file___258 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___258 *, struct dentry___258 *, umode_t);
	int (*set_acl)(struct inode___258 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___257 {
	void (*fl_copy_lock)(struct file_lock___258 *, struct file_lock___258 *);
	void (*fl_release_private)(struct file_lock___258 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___257;

struct lock_manager_operations___257;

struct file_lock___258 {
	struct file_lock___258 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___258 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___257 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___257 *fl_ops;
	const struct lock_manager_operations___257 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___257 {
	int (*lm_compare_owner)(struct file_lock___258 *, struct file_lock___258 *);
	long unsigned int (*lm_owner_key)(struct file_lock___258 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___258 *);
	int (*lm_grant)(struct file_lock___258 *, int);
	bool (*lm_break)(struct file_lock___258 *);
	int (*lm_change)(struct file_lock___258 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___258 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___257 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___257 *fa_next;
	struct file___258 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___257 {
	const char *name;
	int fs_flags;
	struct dentry___258 * (*mount)(struct file_system_type___257 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___257 *);
	struct module___211 *owner;
	struct file_system_type___257 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___257 {
	struct inode___258 * (*alloc_inode)(struct super_block___257 *);
	void (*destroy_inode)(struct inode___258 *);
	void (*dirty_inode)(struct inode___258 *, int);
	int (*write_inode)(struct inode___258 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___258 *);
	void (*evict_inode)(struct inode___258 *);
	void (*put_super)(struct super_block___257 *);
	int (*sync_fs)(struct super_block___257 *, int);
	int (*freeze_super)(struct super_block___257 *);
	int (*freeze_fs)(struct super_block___257 *);
	int (*thaw_super)(struct super_block___257 *);
	int (*unfreeze_fs)(struct super_block___257 *);
	int (*statfs)(struct dentry___258 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___257 *, int *, char *);
	void (*umount_begin)(struct super_block___257 *);
	int (*show_options)(struct seq_file___231 *, struct dentry___258 *);
	int (*show_devname)(struct seq_file___231 *, struct dentry___258 *);
	int (*show_path)(struct seq_file___231 *, struct dentry___258 *);
	int (*show_stats)(struct seq_file___231 *, struct dentry___258 *);
	ssize_t (*quota_read)(struct super_block___257 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___257 *, int, const char *, size_t, loff_t);
	struct dquot___257 ** (*get_dquots)(struct inode___258 *);
	int (*bdev_try_to_free_page)(struct super_block___257 *, struct page___259 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___257 *, struct shrink_control___111 *);
	long int (*free_cached_objects)(struct super_block___257 *, struct shrink_control___111 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___161)(struct file___258 *, wait_queue_head_t *, struct poll_table_struct___159 *);

struct poll_table_struct___159 {
	poll_queue_proc___161 _qproc;
	__poll_t _key;
};

struct seq_operations___229;

struct seq_file___231 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___229 *op;
	int poll_event;
	const struct file___258 *file;
	void *private;
};

typedef void bio_end_io_t___127(struct bio___127 *);

struct bio_vec___127 {
	struct page___259 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___127;

struct bio___127 {
	struct bio___127 *bi_next;
	struct gendisk___59 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___127 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___47 *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___127 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___127 *bi_io_vec;
	struct bio_set___127 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___127 bi_inline_vecs[0];
};

struct bio_integrity_payload___127 {
	struct bio___127 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___127 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___127 bip_inline_vecs[0];
};

struct blkcg___47;

struct blkg_policy_data___47;

struct blkcg_gq___47 {
	struct request_queue___59 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___47 *blkcg;
	struct bdi_writeback_congested___127 *wb_congested;
	struct blkcg_gq___47 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_rwstat stat_bytes;
	struct blkg_rwstat stat_ios;
	struct blkg_policy_data___47 *pd[5];
	struct callback_head callback_head;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
};

struct dev_pm_ops___221;

struct device_type___221 {
	const char *name;
	const struct attribute_group___223 **groups;
	int (*uevent)(struct device___221 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___221 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___221 *);
	const struct dev_pm_ops___221 *pm;
};

struct class___221 {
	const char *name;
	struct module___211 *owner;
	const struct attribute_group___223 **class_groups;
	const struct attribute_group___223 **dev_groups;
	struct kobject___246 *dev_kobj;
	int (*dev_uevent)(struct device___221 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___221 *, umode_t *);
	void (*class_release)(struct class___221 *);
	void (*dev_release)(struct device___221 *);
	int (*shutdown_pre)(struct device___221 *);
	const struct kobj_ns_type_operations___24 *ns_type;
	const void * (*namespace)(struct device___221 *);
	const struct dev_pm_ops___221 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct kernfs_root___252;

struct kernfs_elem_dir___252 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___252 *root;
};

struct kernfs_syscall_ops___252;

struct kernfs_root___252 {
	struct kernfs_node___253 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___252 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___252 {
	struct kernfs_node___253 *target_kn;
};

struct kernfs_ops___252;

struct kernfs_elem_attr___252 {
	const struct kernfs_ops___252 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___253 *notify_next;
};

struct kernfs_node___253 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___253 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___252 dir;
		struct kernfs_elem_symlink___252 symlink;
		struct kernfs_elem_attr___252 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___252;

struct kernfs_ops___252 {
	int (*open)(struct kernfs_open_file___252 *);
	void (*release)(struct kernfs_open_file___252 *);
	int (*seq_show)(struct seq_file___231 *, void *);
	void * (*seq_start)(struct seq_file___231 *, loff_t *);
	void * (*seq_next)(struct seq_file___231 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___231 *, void *);
	ssize_t (*read)(struct kernfs_open_file___252 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___252 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___252 *, struct vm_area_struct___259 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___252 *, struct poll_table_struct___159 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___252 {
	int (*remount_fs)(struct kernfs_root___252 *, int *, char *);
	int (*show_options)(struct seq_file___231 *, struct kernfs_root___252 *);
	int (*mkdir)(struct kernfs_node___253 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___253 *);
	int (*rename)(struct kernfs_node___253 *, struct kernfs_node___253 *, const char *);
	int (*show_path)(struct seq_file___231 *, struct kernfs_node___253 *, struct kernfs_root___252 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___252 {
	struct kernfs_node___253 *kn;
	struct file___258 *file;
	struct seq_file___231 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___247 *vm_ops;
};

struct bin_attribute___222;

struct attribute_group___223 {
	const char *name;
	umode_t (*is_visible)(struct kobject___246 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___246 *, struct bin_attribute___222 *, int);
	struct attribute **attrs;
	struct bin_attribute___222 **bin_attrs;
};

struct bin_attribute___222 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___258 *, struct kobject___246 *, struct bin_attribute___222 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___258 *, struct kobject___246 *, struct bin_attribute___222 *, char *, loff_t, size_t);
	int (*mmap)(struct file___258 *, struct kobject___246 *, struct bin_attribute___222 *, struct vm_area_struct___259 *);
};

struct sysfs_ops___245 {
	ssize_t (*show)(struct kobject___246 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___246 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___245;

struct kset___245 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___246 kobj;
	const struct kset_uevent_ops___245 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___245 {
	void (*release)(struct kobject___246 *);
	const struct sysfs_ops___245 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___24 * (*child_ns_type)(struct kobject___246 *);
	const void * (*namespace)(struct kobject___246 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___245 {
	int (* const filter)(struct kset___245 *, struct kobject___246 *);
	const char * (* const name)(struct kset___245 *, struct kobject___246 *);
	int (* const uevent)(struct kset___245 *, struct kobject___246 *, struct kobj_uevent_env *);
};

struct kobj_attribute___238 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___246 *, struct kobj_attribute___238 *, char *);
	ssize_t (*store)(struct kobject___246 *, struct kobj_attribute___238 *, const char *, size_t);
};

struct dev_pm_ops___221 {
	int (*prepare)(struct device___221 *);
	void (*complete)(struct device___221 *);
	int (*suspend)(struct device___221 *);
	int (*resume)(struct device___221 *);
	int (*freeze)(struct device___221 *);
	int (*thaw)(struct device___221 *);
	int (*poweroff)(struct device___221 *);
	int (*restore)(struct device___221 *);
	int (*suspend_late)(struct device___221 *);
	int (*resume_early)(struct device___221 *);
	int (*freeze_late)(struct device___221 *);
	int (*thaw_early)(struct device___221 *);
	int (*poweroff_late)(struct device___221 *);
	int (*restore_early)(struct device___221 *);
	int (*suspend_noirq)(struct device___221 *);
	int (*resume_noirq)(struct device___221 *);
	int (*freeze_noirq)(struct device___221 *);
	int (*thaw_noirq)(struct device___221 *);
	int (*poweroff_noirq)(struct device___221 *);
	int (*restore_noirq)(struct device___221 *);
	int (*runtime_suspend)(struct device___221 *);
	int (*runtime_resume)(struct device___221 *);
	int (*runtime_idle)(struct device___221 *);
};

struct dev_pm_domain___221 {
	struct dev_pm_ops___221 ops;
	void (*detach)(struct device___221 *, bool);
	int (*activate)(struct device___221 *);
	void (*sync)(struct device___221 *);
	void (*dismiss)(struct device___221 *);
};

struct bus_type___221 {
	const char *name;
	const char *dev_name;
	struct device___221 *dev_root;
	const struct attribute_group___223 **bus_groups;
	const struct attribute_group___223 **dev_groups;
	const struct attribute_group___223 **drv_groups;
	int (*match)(struct device___221 *, struct device_driver___221 *);
	int (*uevent)(struct device___221 *, struct kobj_uevent_env *);
	int (*probe)(struct device___221 *);
	int (*remove)(struct device___221 *);
	void (*shutdown)(struct device___221 *);
	int (*online)(struct device___221 *);
	int (*offline)(struct device___221 *);
	int (*suspend)(struct device___221 *, pm_message_t);
	int (*resume)(struct device___221 *);
	int (*num_vf)(struct device___221 *);
	int (*dma_configure)(struct device___221 *);
	const struct dev_pm_ops___221 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___221 {
	const char *name;
	struct bus_type___221 *bus;
	struct module___211 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___221 *);
	int (*remove)(struct device___221 *);
	void (*shutdown)(struct device___221 *);
	int (*suspend)(struct device___221 *, pm_message_t);
	int (*resume)(struct device___221 *);
	const struct attribute_group___223 **groups;
	const struct dev_pm_ops___221 *pm;
	void (*coredump)(struct device___221 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct fwnode_operations___156;

struct fwnode_handle___156 {
	struct fwnode_handle___156 *secondary;
	const struct fwnode_operations___156 *ops;
};

struct disk_part_tbl___59 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___59 *last_lookup;
	struct hd_struct___59 *part[0];
};

struct block_device_operations___59 {
	int (*open)(struct block_device___258 *, fmode_t);
	void (*release)(struct gendisk___59 *, fmode_t);
	int (*rw_page)(struct block_device___258 *, sector_t, struct page___259 *, unsigned int);
	int (*ioctl)(struct block_device___258 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___258 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___59 *, unsigned int);
	int (*media_changed)(struct gendisk___59 *);
	void (*unlock_native_capacity)(struct gendisk___59 *);
	int (*revalidate_disk)(struct gendisk___59 *);
	int (*getgeo)(struct block_device___258 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___258 *, long unsigned int);
	int (*report_zones)(struct gendisk___59 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___211 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___247(struct page___259 *);

struct bdi_writeback_congested___127 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___127 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct cgroup_subsys___196;

struct cgroup_subsys_state___197 {
	struct cgroup___196 *cgroup;
	struct cgroup_subsys___196 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___197 *parent;
};

struct bsg_ops___58 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___59 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___59 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___59 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___58(struct request___59 *, blk_status_t);

struct request___59 {
	struct request_queue___59 *q;
	struct blk_mq_ctx___4 *mq_ctx;
	struct blk_mq_hw_ctx___4 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___127 *bio;
	struct bio___127 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___127 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___62 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___58 *saved_end_io;
		} flush;
	};
	struct gendisk___59 *rq_disk;
	struct hd_struct___59 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___58 *end_io;
	void *end_io_data;
	struct request___59 *next_rq;
};

struct fwnode_reference_args___156;

struct fwnode_endpoint___156;

struct fwnode_operations___156 {
	struct fwnode_handle___156 * (*get)(struct fwnode_handle___156 *);
	void (*put)(struct fwnode_handle___156 *);
	bool (*device_is_available)(const struct fwnode_handle___156 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___156 *, const struct device___221 *);
	bool (*property_present)(const struct fwnode_handle___156 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___156 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___156 *, const char *, const char **, size_t);
	struct fwnode_handle___156 * (*get_parent)(const struct fwnode_handle___156 *);
	struct fwnode_handle___156 * (*get_next_child_node)(const struct fwnode_handle___156 *, struct fwnode_handle___156 *);
	struct fwnode_handle___156 * (*get_named_child_node)(const struct fwnode_handle___156 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___156 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___156 *);
	struct fwnode_handle___156 * (*graph_get_next_endpoint)(const struct fwnode_handle___156 *, struct fwnode_handle___156 *);
	struct fwnode_handle___156 * (*graph_get_remote_endpoint)(const struct fwnode_handle___156 *);
	struct fwnode_handle___156 * (*graph_get_port_parent)(struct fwnode_handle___156 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___156 *, struct fwnode_endpoint___156 *);
};

struct fwnode_endpoint___156 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___156 *local_fwnode;
};

struct fwnode_reference_args___156 {
	struct fwnode_handle___156 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct blk_mq_ctxs___3;

struct blk_mq_ctx___4 {
	struct {
		spinlock_t lock;
		struct list_head rq_lists[3];
		long: 64;
	};
	unsigned int cpu;
	short unsigned int index_hw[3];
	struct blk_mq_hw_ctx___4 *hctxs[3];
	long unsigned int rq_dispatched[2];
	long unsigned int rq_merged;
	long unsigned int rq_completed[2];
	struct request_queue___59 *queue;
	struct blk_mq_ctxs___3 *ctxs;
	struct kobject___246 kobj;
};

struct blk_mq_tags___3;

struct blk_mq_hw_ctx___4 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___59 *queue;
	struct blk_flush_queue___4 *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx___4 *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx___4 **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags___3 *tags;
	struct blk_mq_tags___3 *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	unsigned int rh_reserved_nr_expired;
	struct hlist_node cpuhp_dead;
	struct kobject___246 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___258 *debugfs_dir;
	struct dentry___258 *sched_debugfs_dir;
	struct list_head hctx_list;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___58;

struct blk_mq_alloc_data___4;

struct elevator_mq_ops___58 {
	int (*init_sched)(struct request_queue___59 *, struct elevator_type___58 *);
	void (*exit_sched)(struct elevator_queue___58 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___4 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___4 *, unsigned int);
	bool (*allow_merge)(struct request_queue___59 *, struct request___59 *, struct bio___127 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx___4 *, struct bio___127 *);
	int (*request_merge)(struct request_queue___59 *, struct request___59 **, struct bio___127 *);
	void (*request_merged)(struct request_queue___59 *, struct request___59 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___59 *, struct request___59 *, struct request___59 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data___4 *);
	void (*prepare_request)(struct request___59 *, struct bio___127 *);
	void (*finish_request)(struct request___59 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___4 *, struct list_head *, bool);
	struct request___59 * (*dispatch_request)(struct blk_mq_hw_ctx___4 *);
	bool (*has_work)(struct blk_mq_hw_ctx___4 *);
	void (*completed_request)(struct request___59 *, u64);
	void (*started_request)(struct request___59 *);
	void (*requeue_request)(struct request___59 *);
	struct request___59 * (*former_request)(struct request_queue___59 *, struct request___59 *);
	struct request___59 * (*next_request)(struct request_queue___59 *, struct request___59 *);
	void (*init_icq)(struct io_cq___62 *);
	void (*exit_icq)(struct io_cq___62 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx___4 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___58;

struct elevator_type___58 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___58 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___58 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___211 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___58 {
	struct elevator_type___58 *type;
	void *elevator_data;
	struct kobject___246 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct blk_mq_alloc_data___4 {
	struct request_queue___59 *q;
	blk_mq_req_flags_t flags;
	unsigned int shallow_depth;
	unsigned int cmd_flags;
	struct blk_mq_ctx___4 *ctx;
	struct blk_mq_hw_ctx___4 *hctx;
};

struct elv_fs_entry___58 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___58 *, char *);
	ssize_t (*store)(struct elevator_queue___58 *, const char *, size_t);
};

struct rq_qos_ops___2;

struct rq_qos___3 {
	struct rq_qos_ops___2 *ops;
	struct request_queue___59 *q;
	enum rq_qos_id id;
	struct rq_qos___3 *next;
};

struct blk_mq_queue_data___4;

typedef blk_status_t queue_rq_fn___4(struct blk_mq_hw_ctx___4 *, const struct blk_mq_queue_data___4 *);

typedef void commit_rqs_fn___4(struct blk_mq_hw_ctx___4 *);

typedef bool get_budget_fn___4(struct blk_mq_hw_ctx___4 *);

typedef void put_budget_fn___4(struct blk_mq_hw_ctx___4 *);

typedef enum blk_eh_timer_return timeout_fn___4(struct request___59 *, bool);

typedef int poll_fn___4(struct blk_mq_hw_ctx___4 *);

typedef void complete_fn___4(struct request___59 *);

typedef int init_hctx_fn___4(struct blk_mq_hw_ctx___4 *, void *, unsigned int);

typedef void exit_hctx_fn___4(struct blk_mq_hw_ctx___4 *, unsigned int);

typedef int init_request_fn___4(struct blk_mq_tag_set___4 *, struct request___59 *, unsigned int, unsigned int);

typedef void exit_request_fn___4(struct blk_mq_tag_set___4 *, struct request___59 *, unsigned int);

typedef bool busy_fn___4(struct request_queue___59 *);

typedef int map_queues_fn___4(struct blk_mq_tag_set___4 *);

typedef void cleanup_rq_fn___4(struct request___59 *);

struct blk_mq_ops___4 {
	queue_rq_fn___4 *queue_rq;
	commit_rqs_fn___4 *commit_rqs;
	get_budget_fn___4 *get_budget;
	put_budget_fn___4 *put_budget;
	timeout_fn___4 *timeout;
	poll_fn___4 *poll;
	complete_fn___4 *complete;
	init_hctx_fn___4 *init_hctx;
	exit_hctx_fn___4 *exit_hctx;
	init_request_fn___4 *init_request;
	exit_request_fn___4 *exit_request;
	void (*initialize_rq_fn)(struct request___59 *);
	busy_fn___4 *busy;
	map_queues_fn___4 *map_queues;
	void (*show_rq)(struct seq_file___231 *, struct request___59 *);
	union {
		cleanup_rq_fn___4 *cleanup_rq;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide46;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct blk_stat_callback___4 {
	struct list_head list;
	struct timer_list timer;
	struct blk_rq_stat *cpu_stat;
	int (*bucket_fn)(const struct request___59 *);
	unsigned int buckets;
	struct blk_rq_stat *stat;
	void (*timer_fn)(struct blk_stat_callback___4 *);
	void *data;
	struct callback_head rcu;
};

struct rchan___5;

struct blk_trace___5 {
	int trace_state;
	struct rchan___5 *rchan;
	long unsigned int *sequence;
	unsigned char *msg_data;
	u16 act_mask;
	u64 start_lba;
	u64 end_lba;
	u32 pid;
	u32 dev;
	struct dentry___258 *dir;
	struct dentry___258 *dropped_file;
	struct dentry___258 *msg_file;
	struct list_head running_list;
	atomic_t dropped;
};

struct blk_flush_queue___4 {
	unsigned int flush_queue_delayed: 1;
	unsigned int flush_pending_idx: 1;
	unsigned int flush_running_idx: 1;
	long unsigned int flush_pending_since;
	struct list_head flush_queue[2];
	struct list_head flush_data_in_flight;
	struct request___59 *flush_rq;
	struct request___59 *orig_rq;
	spinlock_t mq_flush_lock;
};

struct blk_mq_tag_set___4 {
	struct blk_mq_queue_map map[6];
	unsigned int nr_maps;
	const struct blk_mq_ops___4 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	struct blk_mq_tags___3 **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct kernel_param_ops___208 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___208 *);
	int (*get)(char *, const struct kernel_param___208 *);
	void (*free)(void *);
};

struct kparam_array___208;

struct kernel_param___208 {
	const char *name;
	struct module___211 *mod;
	const struct kernel_param_ops___208 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___208 *arr;
	};
};

struct kparam_array___208 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___208 *ops;
	void *elem;
};

struct module_attribute___208 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___208 *, struct module_kobject___208 *, char *);
	ssize_t (*store)(struct module_attribute___208 *, struct module_kobject___208 *, const char *, size_t);
	void (*setup)(struct module___211 *, const char *);
	int (*test)(struct module___211 *);
	void (*free)(struct module___211 *);
};

struct rchan_buf___5 {
	void *start;
	void *data;
	size_t offset;
	size_t subbufs_produced;
	size_t subbufs_consumed;
	struct rchan___5 *chan;
	wait_queue_head_t read_wait;
	struct irq_work wakeup_work;
	struct dentry___258 *dentry;
	struct kref kref;
	struct page___259 **page_array;
	unsigned int page_count;
	unsigned int finalized;
	size_t *padding;
	size_t prev_padding;
	size_t bytes_consumed;
	size_t early_bytes;
	unsigned int cpu;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
};

struct rchan_callbacks___5;

struct rchan___5 {
	u32 version;
	size_t subbuf_size;
	size_t n_subbufs;
	size_t alloc_size;
	struct rchan_callbacks___5 *cb;
	struct kref kref;
	void *private_data;
	size_t last_toobig;
	struct rchan_buf___5 **buf;
	int is_global;
	struct list_head list;
	struct dentry___258 *parent;
	int has_base_filename;
	char base_filename[255];
};

struct rchan_callbacks___5 {
	int (*subbuf_start)(struct rchan_buf___5 *, void *, void *, size_t);
	void (*buf_mapped)(struct rchan_buf___5 *, struct file___258 *);
	void (*buf_unmapped)(struct rchan_buf___5 *, struct file___258 *);
	struct dentry___258 * (*create_buf_file)(const char *, struct dentry___258 *, umode_t, struct rchan_buf___5 *, int *);
	int (*remove_buf_file)(struct dentry___258 *);
};

typedef int (*key_restrict_link_func_t___251)(struct key___250 *, const struct key_type *, const union key_payload *, struct key___250 *);

struct key_restriction___250;

struct key___250 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___259 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key___6 index_key;
		struct {
			struct key_type___6 *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___250 *restrict_link;
};

struct key_restriction___250 {
	key_restrict_link_func_t___251 check;
	struct key___250 *key;
	struct key_type *keytype;
};

struct seq_operations___229 {
	void * (*start)(struct seq_file___231 *, loff_t *);
	void (*stop)(struct seq_file___231 *, void *);
	void * (*next)(struct seq_file___231 *, void *, loff_t *);
	int (*show)(struct seq_file___231 *, void *);
};

struct cgroup_namespace___196 {
	refcount_t count;
	struct ns_common___28 ns;
	struct user_namespace___211 *user_ns;
	struct ucounts___211 *ucounts;
	struct css_set___196 *root_cset;
};

struct ucounts___211 {
	struct hlist_node node;
	struct user_namespace___211 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___197;

struct bpf_map_ops___196 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___197 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___197 *, struct file___258 *);
	void (*map_free)(struct bpf_map___197 *);
	int (*map_get_next_key)(struct bpf_map___197 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___197 *);
	void * (*map_lookup_elem)(struct bpf_map___197 *, void *);
	int (*map_update_elem)(struct bpf_map___197 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___197 *, void *);
	int (*map_push_elem)(struct bpf_map___197 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___197 *, void *);
	int (*map_peek_elem)(struct bpf_map___197 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___197 *, struct file___258 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___197 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___197 *, void *, struct seq_file___231 *);
	int (*map_check_btf)(const struct bpf_map___197 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___197 {
	const struct bpf_map_ops___196 *ops;
	struct bpf_map___197 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___250 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___196;

typedef void (*kthread_work_func_t___196)(struct kthread_work___196 *);

struct kthread_worker___196;

struct kthread_work___196 {
	struct list_head node;
	kthread_work_func_t___196 func;
	struct kthread_worker___196 *worker;
	int canceling;
};

struct kthread_worker___196 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___259 *task;
	struct kthread_work___196 *current_work;
};

struct kthread_delayed_work___196 {
	struct kthread_work___196 work;
	struct timer_list timer;
};

struct psi_group___196 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___196 *poll_kworker;
	struct kthread_delayed_work___196 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___196 {
	struct kernfs_node___253 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_root___196;

struct cgroup_rstat_cpu___196;

struct cgroup___196 {
	struct cgroup_subsys_state___197 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___253 *kn;
	struct cgroup_file___196 procs_file;
	struct cgroup_file___196 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___197 *subsys[13];
	struct cgroup_root___196 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___196 *dom_cgrp;
	struct cgroup_rstat_cpu___196 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___34 bpf;
	atomic_t congestion_count;
	struct cgroup___196 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___196 psi;
	int ancestor_ids[0];
};

struct cftype___196;

struct cgroup_subsys___196 {
	struct cgroup_subsys_state___197 * (*css_alloc)(struct cgroup_subsys_state___197 *);
	int (*css_online)(struct cgroup_subsys_state___197 *);
	void (*css_offline)(struct cgroup_subsys_state___197 *);
	void (*css_released)(struct cgroup_subsys_state___197 *);
	void (*css_free)(struct cgroup_subsys_state___197 *);
	void (*css_reset)(struct cgroup_subsys_state___197 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___197 *, int);
	int (*css_extra_stat_show)(struct seq_file___231 *, struct cgroup_subsys_state___197 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___259 *);
	void (*cancel_fork)(struct task_struct___259 *);
	void (*fork)(struct task_struct___259 *);
	void (*exit)(struct task_struct___259 *);
	void (*free)(struct task_struct___259 *);
	void (*bind)(struct cgroup_subsys_state___197 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___196 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___196 *dfl_cftypes;
	struct cftype___196 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___196 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___196 *updated_children;
	struct cgroup___196 *updated_next;
};

struct cgroup_root___196 {
	struct kernfs_root___252 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___196 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___196 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___196 *ss;
	struct list_head node;
	struct kernfs_ops___252 *kf_ops;
	int (*open)(struct kernfs_open_file___252 *);
	void (*release)(struct kernfs_open_file___252 *);
	u64 (*read_u64)(struct cgroup_subsys_state___197 *, struct cftype___196 *);
	s64 (*read_s64)(struct cgroup_subsys_state___197 *, struct cftype___196 *);
	int (*seq_show)(struct seq_file___231 *, void *);
	void * (*seq_start)(struct seq_file___231 *, loff_t *);
	void * (*seq_next)(struct seq_file___231 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___231 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___197 *, struct cftype___196 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___197 *, struct cftype___196 *, s64);
	ssize_t (*write)(struct kernfs_open_file___252 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___252 *, struct poll_table_struct___159 *);
};

struct blkcg_policy_data___47;

struct blkcg___47 {
	struct cgroup_subsys_state___197 css;
	spinlock_t lock;
	struct xarray blkg_tree;
	struct blkcg_gq___47 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___47 *cpd[5];
	struct list_head all_blkcgs_node;
	struct list_head cgwb_list;
	refcount_t cgwb_refcnt;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct blkcg_policy_data___47 {
	struct blkcg___47 *blkcg;
	int plid;
};

struct blkg_policy_data___47 {
	struct blkcg_gq___47 *blkg;
	int plid;
};

struct blk_mq_tags___3 {
	unsigned int nr_tags;
	unsigned int nr_reserved_tags;
	atomic_t active_queues;
	struct sbitmap_queue bitmap_tags;
	struct sbitmap_queue breserved_tags;
	struct request___59 **rqs;
	struct request___59 **static_rqs;
	struct list_head page_list;
};

struct blk_mq_queue_data___4 {
	struct request___59 *rq;
	bool last;
	long unsigned int rh_reserved1;
};

enum {
	BLK_MQ_F_SHOULD_MERGE = 1,
	BLK_MQ_F_TAG_SHARED = 2,
	BLK_MQ_F_SG_MERGE = 4,
	BLK_MQ_F_BLOCKING = 32,
	BLK_MQ_F_NO_SCHED = 64,
	BLK_MQ_F_ALLOC_POLICY_START_BIT = 8,
	BLK_MQ_F_ALLOC_POLICY_BITS = 1,
	BLK_MQ_S_STOPPED = 0,
	BLK_MQ_S_TAG_ACTIVE = 1,
	BLK_MQ_S_SCHED_RESTART = 2,
	BLK_MQ_MAX_DEPTH = 10240,
	BLK_MQ_CPU_WORK_BATCH = 8,
};

struct blk_mq_ctxs___3 {
	struct kobject___246 kobj;
	struct blk_mq_ctx___4 *queue_ctx;
};

struct rq_qos_ops___2 {
	void (*throttle)(struct rq_qos___3 *, struct bio___127 *);
	void (*track)(struct rq_qos___3 *, struct request___59 *, struct bio___127 *);
	void (*issue)(struct rq_qos___3 *, struct request___59 *);
	void (*requeue)(struct rq_qos___3 *, struct request___59 *);
	void (*done)(struct rq_qos___3 *, struct request___59 *);
	void (*done_bio)(struct rq_qos___3 *, struct bio___127 *);
	void (*cleanup)(struct rq_qos___3 *, struct bio___127 *);
	void (*exit)(struct rq_qos___3 *);
};

enum {
	WBT_RWQ_BG = 0,
	WBT_RWQ_KSWAPD = 1,
	WBT_RWQ_DISCARD = 2,
	WBT_NUM_RWQ = 3,
};

struct module___212;

struct file___259;

struct kiocb___259;

struct iov_iter___125;

struct poll_table_struct___160;

struct vm_area_struct___260;

struct inode___259;

struct file_lock___259;

struct page___260;

struct seq_file___232;

struct file_operations___259 {
	struct module___212 *owner;
	loff_t (*llseek)(struct file___259 *, loff_t, int);
	ssize_t (*read)(struct file___259 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___259 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___259 *, struct iov_iter___125 *);
	ssize_t (*write_iter)(struct kiocb___259 *, struct iov_iter___125 *);
	int (*iopoll)(struct kiocb___259 *, bool);
	int (*iterate)(struct file___259 *, struct dir_context *);
	int (*iterate_shared)(struct file___259 *, struct dir_context *);
	__poll_t (*poll)(struct file___259 *, struct poll_table_struct___160 *);
	long int (*unlocked_ioctl)(struct file___259 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___259 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___259 *, struct vm_area_struct___260 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___259 *, struct file___259 *);
	int (*flush)(struct file___259 *, fl_owner_t);
	int (*release)(struct inode___259 *, struct file___259 *);
	int (*fsync)(struct file___259 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___259 *, int);
	int (*lock)(struct file___259 *, int, struct file_lock___259 *);
	ssize_t (*sendpage)(struct file___259 *, struct page___260 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___259 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___259 *, int, struct file_lock___259 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___259 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___259 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___259 *, long int, struct file_lock___259 **, void **);
	long int (*fallocate)(struct file___259 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___232 *, struct file___259 *);
	ssize_t (*copy_file_range)(struct file___259 *, loff_t, struct file___259 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___259 *, loff_t, struct file___259 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___259 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___259 {
	u64 seqnum;
	struct vm_area_struct___260 *vmas[4];
};

struct page_frag___259 {
	struct page___260 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___128;

struct debug_info___128 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___128 *hbp_break[16];
	struct perf_event___128 *hbp_watch[16];
};

struct thread_struct___128 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___128 debug;
	long: 64;
};

struct mm_struct___259;

struct mem_cgroup___112;

struct pid___189;

struct cred___251;

struct nsproxy___232;

struct signal_struct___213;

struct bio_list___128;

struct backing_dev_info___128;

struct io_context___63;

struct css_set___197;

struct perf_event_context___128;

struct request_queue___60;

struct vm_struct___175;

struct task_struct___260 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___260 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___259 *mm;
	struct mm_struct___259 *active_mm;
	struct vmacache___259 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___260 *real_parent;
	struct task_struct___260 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___260 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___112 *active_memcg;
	long int rh_reserved2;
	struct pid___189 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___189 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___189 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___251 *ptracer_cred;
	const struct cred___251 *real_cred;
	const struct cred___251 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___232 *nsproxy;
	struct signal_struct___213 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___260 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___128 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___128 *backing_dev_info;
	struct io_context___63 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___197 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___128 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___259 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___112 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___60 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___260 *oom_reaper_list;
	struct vm_struct___175 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___128 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___128 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___260 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___128)(struct perf_event___128 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___128;

struct fasync_struct___258;

struct pid_namespace___189;

struct trace_event_call___121;

struct perf_cgroup___128;

struct perf_event___128 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___128 *group_leader;
	struct pmu___128 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___128 hw;
	struct perf_event_context___128 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___128 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___260 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___258 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___128 *);
	struct callback_head callback_head;
	struct pid_namespace___189 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___128 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___128 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___121 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___128 *cgrp;
	struct list_head sb_list;
};

struct rw_semaphore___260 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___260 *owner;
};

struct key___251;

struct ucounts___212;

struct user_namespace___212 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___212 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___28 ns;
	long unsigned int flags;
	struct key___251 *persistent_keyring_register;
	struct rw_semaphore___260 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___212 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___260 *pgtable_t___259;

struct address_space___258;

struct dev_pagemap___248;

struct page___260 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___258 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___260 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___259 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___259 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___248 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___112 *mem_cgroup;
};

struct pglist_data___259;

struct lruvec___259 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___259 *pgdat;
};

struct zone___259 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___259 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___259 {
	struct zone___259 *zone;
	int zone_idx;
};

struct zonelist___259 {
	struct zoneref___259 _zonerefs[25];
};

struct pglist_data___259 {
	struct zone___259 node_zones[3];
	struct zonelist___259 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___260 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___260 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___259 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___260 {
	void *stack;
	struct task_struct___260 *task;
	long int status;
};

struct blocking_notifier_head___259 {
	struct rw_semaphore___260 rwsem;
	struct notifier_block *head;
};

struct dentry___259;

struct path___259 {
	struct vfsmount *mnt;
	struct dentry___259 *dentry;
};

struct fown_struct___189 {
	rwlock_t lock;
	struct pid___189 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___259 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___259 f_path;
	struct inode___259 *f_inode;
	const struct file_operations___259 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___189 f_owner;
	const struct cred___251 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___258 *f_mapping;
	errseq_t f_wb_err;
};

struct user_struct___251;

struct cred___251 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___251 *session_keyring;
	struct key___251 *process_keyring;
	struct key___251 *thread_keyring;
	struct key___251 *request_key_auth;
	void *security;
	struct user_struct___251 *user;
	struct user_namespace___212 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___253;

struct kernfs_elem_dir___253 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___253 *root;
};

struct kernfs_node___254;

struct kernfs_syscall_ops___253;

struct kernfs_root___253 {
	struct kernfs_node___254 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___253 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___253 {
	struct kernfs_node___254 *target_kn;
};

struct kernfs_ops___253;

struct kernfs_elem_attr___253 {
	const struct kernfs_ops___253 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___254 *notify_next;
};

struct kernfs_node___254 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___254 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___253 dir;
		struct kernfs_elem_symlink___253 symlink;
		struct kernfs_elem_attr___253 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___253;

struct kernfs_ops___253 {
	int (*open)(struct kernfs_open_file___253 *);
	void (*release)(struct kernfs_open_file___253 *);
	int (*seq_show)(struct seq_file___232 *, void *);
	void * (*seq_start)(struct seq_file___232 *, loff_t *);
	void * (*seq_next)(struct seq_file___232 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___232 *, void *);
	ssize_t (*read)(struct kernfs_open_file___253 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___253 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___253 *, struct vm_area_struct___260 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___253 *, struct poll_table_struct___160 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___253 {
	int (*remount_fs)(struct kernfs_root___253 *, int *, char *);
	int (*show_options)(struct seq_file___232 *, struct kernfs_root___253 *);
	int (*mkdir)(struct kernfs_node___254 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___254 *);
	int (*rename)(struct kernfs_node___254 *, struct kernfs_node___254 *, const char *);
	int (*show_path)(struct seq_file___232 *, struct kernfs_node___254 *, struct kernfs_root___253 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___230;

struct seq_file___232 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___230 *op;
	int poll_event;
	const struct file___259 *file;
	void *private;
};

struct vm_operations_struct___248;

struct kernfs_open_file___253 {
	struct kernfs_node___254 *kn;
	struct file___259 *file;
	struct seq_file___232 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___248 *vm_ops;
};

struct vm_fault___248;

struct vm_operations_struct___248 {
	void (*open)(struct vm_area_struct___260 *);
	void (*close)(struct vm_area_struct___260 *);
	int (*split)(struct vm_area_struct___260 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___260 *);
	vm_fault_t (*fault)(struct vm_fault___248 *);
	vm_fault_t (*huge_fault)(struct vm_fault___248 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___248 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___260 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___248 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___248 *);
	int (*access)(struct vm_area_struct___260 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___260 *);
	int (*set_policy)(struct vm_area_struct___260 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___260 *, long unsigned int);
	struct page___260 * (*find_special_page)(struct vm_area_struct___260 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___162)(struct file___259 *, wait_queue_head_t *, struct poll_table_struct___160 *);

struct poll_table_struct___160 {
	poll_queue_proc___162 _qproc;
	__poll_t _key;
};

struct vm_area_struct___260 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___260 *vm_next;
	struct vm_area_struct___260 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___259 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___248 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___259 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___247;

struct bin_attribute___223;

struct attribute_group___224 {
	const char *name;
	umode_t (*is_visible)(struct kobject___247 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___247 *, struct bin_attribute___223 *, int);
	struct attribute **attrs;
	struct bin_attribute___223 **bin_attrs;
};

struct kset___246;

struct kobj_type___246;

struct kobject___247 {
	const char *name;
	struct list_head entry;
	struct kobject___247 *parent;
	struct kset___246 *kset;
	struct kobj_type___246 *ktype;
	struct kernfs_node___254 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___223 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___259 *, struct kobject___247 *, struct bin_attribute___223 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___259 *, struct kobject___247 *, struct bin_attribute___223 *, char *, loff_t, size_t);
	int (*mmap)(struct file___259 *, struct kobject___247 *, struct bin_attribute___223 *, struct vm_area_struct___260 *);
};

struct sysfs_ops___246 {
	ssize_t (*show)(struct kobject___247 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___247 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___246;

struct kset___246 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___247 kobj;
	const struct kset_uevent_ops___246 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___246 {
	void (*release)(struct kobject___247 *);
	const struct sysfs_ops___246 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___24 * (*child_ns_type)(struct kobject___247 *);
	const void * (*namespace)(struct kobject___247 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___246 {
	int (* const filter)(struct kset___246 *, struct kobject___247 *);
	const char * (* const name)(struct kset___246 *, struct kobject___247 *);
	int (* const uevent)(struct kset___246 *, struct kobject___247 *, struct kobj_uevent_env *);
};

struct kobj_attribute___239 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___247 *, struct kobj_attribute___239 *, char *);
	ssize_t (*store)(struct kobject___247 *, struct kobj_attribute___239 *, const char *, size_t);
};

struct kernel_param___209;

struct kernel_param_ops___209 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___209 *);
	int (*get)(char *, const struct kernel_param___209 *);
	void (*free)(void *);
};

struct kparam_array___209;

struct kernel_param___209 {
	const char *name;
	struct module___212 *mod;
	const struct kernel_param_ops___209 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___209 *arr;
	};
};

struct kparam_array___209 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___209 *ops;
	void *elem;
};

struct module_kobject___209 {
	struct kobject___247 kobj;
	struct module___212 *mod;
	struct kobject___247 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___209 {
	struct module___212 *mod;
	struct latch_tree_node node;
};

struct module_layout___209 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___209 mtn;
};

struct module_attribute___209;

struct module___212 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___209 mkobj;
	struct module_attribute___209 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___247 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___209 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___209 core_layout;
	struct module_layout___209 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___121 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___209 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___209 *, struct module_kobject___209 *, char *);
	ssize_t (*store)(struct module_attribute___209 *, struct module_kobject___209 *, const char *, size_t);
	void (*setup)(struct module___212 *, const char *);
	int (*test)(struct module___212 *);
	void (*free)(struct module___212 *);
};

struct trace_event_class___121;

struct trace_event_call___121 {
	struct list_head list;
	struct trace_event_class___121 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___34 *prog_array;
	int (*perf_perm)(struct trace_event_call___121 *, struct perf_event___128 *);
};

struct dentry_operations___258;

struct super_block___258;

struct dentry___259 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___259 *d_parent;
	struct qstr d_name;
	struct inode___259 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___258 *d_op;
	struct super_block___258 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___258;

struct address_space___258 {
	struct inode___259 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___260 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___258 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___258;

struct bdi_writeback___128;

struct block_device___259;

struct inode___259 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___258 *i_op;
	struct super_block___258 *i_sb;
	struct address_space___258 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___260 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___128 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___259 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___258 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___259 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___258 {
	int (*d_revalidate)(struct dentry___259 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___259 *, unsigned int);
	int (*d_hash)(const struct dentry___259 *, struct qstr *);
	int (*d_compare)(const struct dentry___259 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___259 *);
	int (*d_init)(struct dentry___259 *);
	void (*d_release)(struct dentry___259 *);
	void (*d_prune)(struct dentry___259 *);
	void (*d_iput)(struct dentry___259 *, struct inode___259 *);
	char * (*d_dname)(struct dentry___259 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___259 *);
	int (*d_manage)(const struct path___259 *, bool);
	struct dentry___259 * (*d_real)(struct dentry___259 *, const struct inode___259 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___258;

struct mem_dqinfo___258 {
	struct quota_format_type___258 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___258;

struct quota_info___258 {
	unsigned int flags;
	struct rw_semaphore___260 dqio_sem;
	struct inode___259 *files[3];
	struct mem_dqinfo___258 info[3];
	const struct quota_format_ops___258 *ops[3];
};

struct rcuwait___258 {
	struct task_struct___260 *task;
};

struct percpu_rw_semaphore___258 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___260 rw_sem;
	struct rcuwait___258 writer;
	int readers_block;
};

struct sb_writers___258 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___258 rw_sem[3];
};

struct shrink_control___112;

struct shrinker___112 {
	long unsigned int (*count_objects)(struct shrinker___112 *, struct shrink_control___112 *);
	long unsigned int (*scan_objects)(struct shrinker___112 *, struct shrink_control___112 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___258;

struct super_operations___258;

struct dquot_operations___258;

struct quotactl_ops___258;

struct super_block___258 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___258 *s_type;
	const struct super_operations___258 *s_op;
	const struct dquot_operations___258 *dq_op;
	const struct quotactl_ops___258 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___259 *s_root;
	struct rw_semaphore___260 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___259 *s_bdev;
	struct backing_dev_info___128 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___258 s_dquot;
	struct sb_writers___258 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___258 *s_d_op;
	int cleancache_poolid;
	struct shrinker___112 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___212 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___112 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___112 *memcg;
};

struct cgroup___197;

struct cgroup_subsys___197;

struct cgroup_subsys_state___157 {
	struct cgroup___197 *cgroup;
	struct cgroup_subsys___197 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___157 *parent;
};

struct mem_cgroup_id___23 {
	int id;
	union {
		refcount_t ref;
		struct {
			atomic_t ref;
		} __UNIQUE_ID_rh_kabi_hide45;
		union {		};
	};
};

struct cgroup_file___197 {
	struct kernfs_node___254 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___112;

struct mem_cgroup___112 {
	struct cgroup_subsys_state___157 css;
	struct mem_cgroup_id___23 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___197 events_file;
	struct cgroup_file___197 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___260 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___112 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct upid___189 {
	int nr;
	struct pid_namespace___189 *ns;
};

struct pid_namespace___189 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___260 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___189 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___259 *proc_self;
	struct dentry___259 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___212 *user_ns;
	struct ucounts___212 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___28 ns;
};

struct pid___189 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___189 numbers[1];
};

struct core_state___259;

struct mm_struct___259 {
	struct {
		struct vm_area_struct___260 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___259 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___260 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___259 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___260 *owner;
		struct user_namespace___212 *user_ns;
		struct file___259 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___259 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___248)(struct vm_area_struct___260 *, long unsigned int, const struct page___260 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___248)(struct page___260 *, void *);

struct device___222;

struct dev_pagemap___248 {
	dev_page_fault_t___248 page_fault;
	dev_page_free_t___248 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___222 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___259 {
	struct task_struct___260 *task;
	struct core_thread___259 *next;
};

struct core_state___259 {
	atomic_t nr_threads;
	struct core_thread___259 dumper;
	struct completion startup;
};

struct vm_fault___248 {
	struct vm_area_struct___260 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___260 *cow_page;
	struct mem_cgroup___112 *memcg;
	struct page___260 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___259 prealloc_pte;
};

struct user_struct___251 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___251 *uid_keyring;
	struct key___251 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cgroup_namespace___197;

struct nsproxy___232 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___189 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___197 *cgroup_ns;
};

struct signal_struct___213 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___260 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___260 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___189 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___189 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___259 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___189 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide50;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___128;

struct bio_list___128 {
	struct bio___128 *head;
	struct bio___128 *tail;
};

struct bdi_writeback_congested___128;

struct bdi_writeback___128 {
	struct backing_dev_info___128 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___128 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___157 *memcg_css;
	struct cgroup_subsys_state___157 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___128 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___128 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___222 *dev;
	struct device___222 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___259 *debug_dir;
	struct dentry___259 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___63;

struct io_context___63 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___63 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___197 {
	struct cgroup_subsys_state___157 *subsys[13];
	refcount_t refcount;
	struct css_set___197 *dom_cset;
	struct cgroup___197 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___197 *mg_src_cgrp;
	struct cgroup___197 *mg_dst_cgrp;
	struct css_set___197 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___128 {
	struct pmu___128 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___260 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___128 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

typedef blk_qc_t make_request_fn___59(struct request_queue___60 *, struct bio___128 *);

struct request___60;

typedef int dma_drain_needed_fn___59(struct request___60 *);

struct bsg_ops___59;

struct bsg_class_device___59 {
	struct device___222 *class_dev;
	int minor;
	struct request_queue___60 *queue;
	const struct bsg_ops___59 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___128 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___128 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___59;

struct blk_mq_ops___5;

struct blk_mq_ctx___5;

struct blk_mq_hw_ctx___5;

struct blk_stat_callback___5;

struct blkcg_gq___48;

struct blk_flush_queue___5;

struct blk_mq_tag_set___5;

struct request_queue___60 {
	struct list_head queue_head;
	struct request___60 *last_merge;
	struct elevator_queue___59 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___59 *make_request_fn;
	dma_drain_needed_fn___59 *dma_drain_needed;
	const struct blk_mq_ops___5 *mq_ops;
	struct blk_mq_ctx___5 *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___5 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___128 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___247 kobj;
	struct kobject___247 *mq_kobj;
	struct blk_integrity integrity;
	struct device___222 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback___5 *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___48 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue___5 *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	struct bsg_class_device___59 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set___5 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___128 bio_split;
	struct dentry___259 *debugfs_dir;
	struct dentry___259 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___175 {
	struct vm_struct___175 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___260 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___225 {
	struct task_struct___260 task;
	long unsigned int stack[8192];
};

struct io_cq___63 {
	struct request_queue___60 *q;
	struct io_context___63 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___6 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct buffer_head___7;

typedef void bh_end_io_t___7(struct buffer_head___7 *, int);

struct buffer_head___7 {
	long unsigned int b_state;
	struct buffer_head___7 *b_this_page;
	struct page___260 *b_page;
	sector_t b_blocknr;
	size_t b_size;
	char *b_data;
	struct block_device___259 *b_bdev;
	bh_end_io_t___7 *b_end_io;
	void *b_private;
	struct list_head b_assoc_buffers;
	struct address_space___258 *b_assoc_map;
	atomic_t b_count;
};

struct kiocb___259 {
	struct file___259 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___259 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___258 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___259 *ia_file;
};

struct dquot___258 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___258 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___258 {
	int qf_fmt_id;
	const struct quota_format_ops___258 *qf_ops;
	struct module___212 *qf_owner;
	struct quota_format_type___258 *qf_next;
};

struct quota_format_ops___258 {
	int (*check_quota_file)(struct super_block___258 *, int);
	int (*read_file_info)(struct super_block___258 *, int);
	int (*write_file_info)(struct super_block___258 *, int);
	int (*free_file_info)(struct super_block___258 *, int);
	int (*read_dqblk)(struct dquot___258 *);
	int (*commit_dqblk)(struct dquot___258 *);
	int (*release_dqblk)(struct dquot___258 *);
	int (*get_next_id)(struct super_block___258 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___258 {
	int (*write_dquot)(struct dquot___258 *);
	struct dquot___258 * (*alloc_dquot)(struct super_block___258 *, int);
	void (*destroy_dquot)(struct dquot___258 *);
	int (*acquire_dquot)(struct dquot___258 *);
	int (*release_dquot)(struct dquot___258 *);
	int (*mark_dirty)(struct dquot___258 *);
	int (*write_info)(struct super_block___258 *, int);
	qsize_t * (*get_reserved_space)(struct inode___259 *);
	int (*get_projid)(struct inode___259 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___259 *, qsize_t *);
	int (*get_next_id)(struct super_block___258 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___258 {
	int (*quota_on)(struct super_block___258 *, int, int, const struct path___259 *);
	int (*quota_off)(struct super_block___258 *, int);
	int (*quota_enable)(struct super_block___258 *, unsigned int);
	int (*quota_disable)(struct super_block___258 *, unsigned int);
	int (*quota_sync)(struct super_block___258 *, int);
	int (*set_info)(struct super_block___258 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___258 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___258 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___258 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___258 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___258 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___123;

struct swap_info_struct___73;

struct address_space_operations___258 {
	int (*writepage)(struct page___260 *, struct writeback_control___123 *);
	int (*readpage)(struct file___259 *, struct page___260 *);
	int (*writepages)(struct address_space___258 *, struct writeback_control___123 *);
	int (*set_page_dirty)(struct page___260 *);
	int (*readpages)(struct file___259 *, struct address_space___258 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___259 *, struct address_space___258 *, loff_t, unsigned int, unsigned int, struct page___260 **, void **);
	int (*write_end)(struct file___259 *, struct address_space___258 *, loff_t, unsigned int, unsigned int, struct page___260 *, void *);
	sector_t (*bmap)(struct address_space___258 *, sector_t);
	void (*invalidatepage)(struct page___260 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___260 *, gfp_t);
	void (*freepage)(struct page___260 *);
	ssize_t (*direct_IO)(struct kiocb___259 *, struct iov_iter___125 *);
	int (*migratepage)(struct address_space___258 *, struct page___260 *, struct page___260 *, enum migrate_mode);
	bool (*isolate_page)(struct page___260 *, isolate_mode_t);
	void (*putback_page)(struct page___260 *);
	int (*launder_page)(struct page___260 *);
	int (*is_partially_uptodate)(struct page___260 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___260 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___258 *, struct page___260 *);
	int (*swap_activate)(struct swap_info_struct___73 *, struct file___259 *, sector_t *);
	void (*swap_deactivate)(struct file___259 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___123 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___128 *wb;
	struct inode___259 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___128;

struct iov_iter___125 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___128 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct swap_info_struct___73 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___259 *bdev;
	struct file___259 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct hd_struct___60;

struct gendisk___60;

struct block_device___259 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___259 *bd_inode;
	struct super_block___258 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___259 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___60 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___60 *bd_disk;
	struct request_queue___60 *bd_queue;
	struct backing_dev_info___128 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___222 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___222 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___222;

struct bus_type___222;

struct device_driver___222;

struct dev_pm_domain___222;

struct fwnode_handle___157;

struct class___222;

struct device___222 {
	struct device___222 *parent;
	struct device_private *p;
	struct kobject___247 kobj;
	const char *init_name;
	const struct device_type___222 *type;
	struct mutex mutex;
	struct bus_type___222 *bus;
	struct device_driver___222 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___222 power;
	struct dev_pm_domain___222 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___157 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___222 *class;
	const struct attribute_group___224 **groups;
	void (*release)(struct device___222 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___60 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___222 __dev;
	struct kobject___247 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___60;

struct block_device_operations___60;

struct gendisk___60 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___60 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___60 *part_tbl;
	struct hd_struct___60 part0;
	const struct block_device_operations___60 *fops;
	struct request_queue___60 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___260 lookup_sem;
	struct kobject___247 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___247 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___258 {
	struct dentry___259 * (*lookup)(struct inode___259 *, struct dentry___259 *, unsigned int);
	const char * (*get_link)(struct dentry___259 *, struct inode___259 *, struct delayed_call *);
	int (*permission)(struct inode___259 *, int);
	struct posix_acl * (*get_acl)(struct inode___259 *, int);
	int (*readlink)(struct dentry___259 *, char *, int);
	int (*create)(struct inode___259 *, struct dentry___259 *, umode_t, bool);
	int (*link)(struct dentry___259 *, struct inode___259 *, struct dentry___259 *);
	int (*unlink)(struct inode___259 *, struct dentry___259 *);
	int (*symlink)(struct inode___259 *, struct dentry___259 *, const char *);
	int (*mkdir)(struct inode___259 *, struct dentry___259 *, umode_t);
	int (*rmdir)(struct inode___259 *, struct dentry___259 *);
	int (*mknod)(struct inode___259 *, struct dentry___259 *, umode_t, dev_t);
	int (*rename)(struct inode___259 *, struct dentry___259 *, struct inode___259 *, struct dentry___259 *, unsigned int);
	int (*setattr)(struct dentry___259 *, struct iattr___258 *);
	int (*getattr)(const struct path___259 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___259 *, char *, size_t);
	int (*fiemap)(struct inode___259 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___259 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___259 *, struct dentry___259 *, struct file___259 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___259 *, struct dentry___259 *, umode_t);
	int (*set_acl)(struct inode___259 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___258 {
	void (*fl_copy_lock)(struct file_lock___259 *, struct file_lock___259 *);
	void (*fl_release_private)(struct file_lock___259 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___258;

struct file_lock___259 {
	struct file_lock___259 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___259 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___258 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___258 *fl_ops;
	const struct lock_manager_operations___258 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___258 {
	int (*lm_compare_owner)(struct file_lock___259 *, struct file_lock___259 *);
	long unsigned int (*lm_owner_key)(struct file_lock___259 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___259 *);
	int (*lm_grant)(struct file_lock___259 *, int);
	bool (*lm_break)(struct file_lock___259 *);
	int (*lm_change)(struct file_lock___259 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___259 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___258 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___258 *fa_next;
	struct file___259 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___258 {
	const char *name;
	int fs_flags;
	struct dentry___259 * (*mount)(struct file_system_type___258 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___258 *);
	struct module___212 *owner;
	struct file_system_type___258 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___258 {
	struct inode___259 * (*alloc_inode)(struct super_block___258 *);
	void (*destroy_inode)(struct inode___259 *);
	void (*dirty_inode)(struct inode___259 *, int);
	int (*write_inode)(struct inode___259 *, struct writeback_control___123 *);
	int (*drop_inode)(struct inode___259 *);
	void (*evict_inode)(struct inode___259 *);
	void (*put_super)(struct super_block___258 *);
	int (*sync_fs)(struct super_block___258 *, int);
	int (*freeze_super)(struct super_block___258 *);
	int (*freeze_fs)(struct super_block___258 *);
	int (*thaw_super)(struct super_block___258 *);
	int (*unfreeze_fs)(struct super_block___258 *);
	int (*statfs)(struct dentry___259 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___258 *, int *, char *);
	void (*umount_begin)(struct super_block___258 *);
	int (*show_options)(struct seq_file___232 *, struct dentry___259 *);
	int (*show_devname)(struct seq_file___232 *, struct dentry___259 *);
	int (*show_path)(struct seq_file___232 *, struct dentry___259 *);
	int (*show_stats)(struct seq_file___232 *, struct dentry___259 *);
	ssize_t (*quota_read)(struct super_block___258 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___258 *, int, const char *, size_t, loff_t);
	struct dquot___258 ** (*get_dquots)(struct inode___259 *);
	int (*bdev_try_to_free_page)(struct super_block___258 *, struct page___260 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___258 *, struct shrink_control___112 *);
	long int (*free_cached_objects)(struct super_block___258 *, struct shrink_control___112 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___128(struct bio___128 *);

struct bio_vec___128 {
	struct page___260 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___128;

struct bio___128 {
	struct bio___128 *bi_next;
	struct gendisk___60 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___128 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___48 *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___128 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___128 *bi_io_vec;
	struct bio_set___128 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___128 bi_inline_vecs[0];
};

enum {
	PERCPU_REF_INIT_ATOMIC = 1,
	PERCPU_REF_INIT_DEAD = 2,
};

struct bio_integrity_payload___128 {
	struct bio___128 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___128 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___128 bip_inline_vecs[0];
};

struct blkcg___48;

struct blkg_policy_data___48;

struct blkcg_gq___48 {
	struct request_queue___60 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___48 *blkcg;
	struct bdi_writeback_congested___128 *wb_congested;
	struct blkcg_gq___48 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_rwstat stat_bytes;
	struct blkg_rwstat stat_ios;
	struct blkg_policy_data___48 *pd[5];
	struct callback_head callback_head;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
};

struct dev_pm_ops___222;

struct device_type___222 {
	const char *name;
	const struct attribute_group___224 **groups;
	int (*uevent)(struct device___222 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___222 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___222 *);
	const struct dev_pm_ops___222 *pm;
};

struct class___222 {
	const char *name;
	struct module___212 *owner;
	const struct attribute_group___224 **class_groups;
	const struct attribute_group___224 **dev_groups;
	struct kobject___247 *dev_kobj;
	int (*dev_uevent)(struct device___222 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___222 *, umode_t *);
	void (*class_release)(struct class___222 *);
	void (*dev_release)(struct device___222 *);
	int (*shutdown_pre)(struct device___222 *);
	const struct kobj_ns_type_operations___24 *ns_type;
	const void * (*namespace)(struct device___222 *);
	const struct dev_pm_ops___222 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dev_pm_ops___222 {
	int (*prepare)(struct device___222 *);
	void (*complete)(struct device___222 *);
	int (*suspend)(struct device___222 *);
	int (*resume)(struct device___222 *);
	int (*freeze)(struct device___222 *);
	int (*thaw)(struct device___222 *);
	int (*poweroff)(struct device___222 *);
	int (*restore)(struct device___222 *);
	int (*suspend_late)(struct device___222 *);
	int (*resume_early)(struct device___222 *);
	int (*freeze_late)(struct device___222 *);
	int (*thaw_early)(struct device___222 *);
	int (*poweroff_late)(struct device___222 *);
	int (*restore_early)(struct device___222 *);
	int (*suspend_noirq)(struct device___222 *);
	int (*resume_noirq)(struct device___222 *);
	int (*freeze_noirq)(struct device___222 *);
	int (*thaw_noirq)(struct device___222 *);
	int (*poweroff_noirq)(struct device___222 *);
	int (*restore_noirq)(struct device___222 *);
	int (*runtime_suspend)(struct device___222 *);
	int (*runtime_resume)(struct device___222 *);
	int (*runtime_idle)(struct device___222 *);
};

struct dev_pm_domain___222 {
	struct dev_pm_ops___222 ops;
	void (*detach)(struct device___222 *, bool);
	int (*activate)(struct device___222 *);
	void (*sync)(struct device___222 *);
	void (*dismiss)(struct device___222 *);
};

struct bus_type___222 {
	const char *name;
	const char *dev_name;
	struct device___222 *dev_root;
	const struct attribute_group___224 **bus_groups;
	const struct attribute_group___224 **dev_groups;
	const struct attribute_group___224 **drv_groups;
	int (*match)(struct device___222 *, struct device_driver___222 *);
	int (*uevent)(struct device___222 *, struct kobj_uevent_env *);
	int (*probe)(struct device___222 *);
	int (*remove)(struct device___222 *);
	void (*shutdown)(struct device___222 *);
	int (*online)(struct device___222 *);
	int (*offline)(struct device___222 *);
	int (*suspend)(struct device___222 *, pm_message_t);
	int (*resume)(struct device___222 *);
	int (*num_vf)(struct device___222 *);
	int (*dma_configure)(struct device___222 *);
	const struct dev_pm_ops___222 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___222 {
	const char *name;
	struct bus_type___222 *bus;
	struct module___212 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___222 *);
	int (*remove)(struct device___222 *);
	void (*shutdown)(struct device___222 *);
	int (*suspend)(struct device___222 *, pm_message_t);
	int (*resume)(struct device___222 *);
	const struct attribute_group___224 **groups;
	const struct dev_pm_ops___222 *pm;
	void (*coredump)(struct device___222 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct fwnode_operations___157;

struct fwnode_handle___157 {
	struct fwnode_handle___157 *secondary;
	const struct fwnode_operations___157 *ops;
};

struct disk_part_tbl___60 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___60 *last_lookup;
	struct hd_struct___60 *part[0];
};

struct block_device_operations___60 {
	int (*open)(struct block_device___259 *, fmode_t);
	void (*release)(struct gendisk___60 *, fmode_t);
	int (*rw_page)(struct block_device___259 *, sector_t, struct page___260 *, unsigned int);
	int (*ioctl)(struct block_device___259 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___259 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___60 *, unsigned int);
	int (*media_changed)(struct gendisk___60 *);
	void (*unlock_native_capacity)(struct gendisk___60 *);
	int (*revalidate_disk)(struct gendisk___60 *);
	int (*getgeo)(struct block_device___259 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___259 *, long unsigned int);
	int (*report_zones)(struct gendisk___60 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___212 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___248(struct page___260 *);

struct bdi_writeback_congested___128 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___128 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bsg_ops___59 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___60 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___60 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___60 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___59(struct request___60 *, blk_status_t);

struct request___60 {
	struct request_queue___60 *q;
	struct blk_mq_ctx___5 *mq_ctx;
	struct blk_mq_hw_ctx___5 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___128 *bio;
	struct bio___128 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___128 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___63 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___59 *saved_end_io;
		} flush;
	};
	struct gendisk___60 *rq_disk;
	struct hd_struct___60 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___59 *end_io;
	void *end_io_data;
	struct request___60 *next_rq;
};

struct fwnode_reference_args___157;

struct fwnode_endpoint___157;

struct fwnode_operations___157 {
	struct fwnode_handle___157 * (*get)(struct fwnode_handle___157 *);
	void (*put)(struct fwnode_handle___157 *);
	bool (*device_is_available)(const struct fwnode_handle___157 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___157 *, const struct device___222 *);
	bool (*property_present)(const struct fwnode_handle___157 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___157 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___157 *, const char *, const char **, size_t);
	struct fwnode_handle___157 * (*get_parent)(const struct fwnode_handle___157 *);
	struct fwnode_handle___157 * (*get_next_child_node)(const struct fwnode_handle___157 *, struct fwnode_handle___157 *);
	struct fwnode_handle___157 * (*get_named_child_node)(const struct fwnode_handle___157 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___157 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___157 *);
	struct fwnode_handle___157 * (*graph_get_next_endpoint)(const struct fwnode_handle___157 *, struct fwnode_handle___157 *);
	struct fwnode_handle___157 * (*graph_get_remote_endpoint)(const struct fwnode_handle___157 *);
	struct fwnode_handle___157 * (*graph_get_port_parent)(struct fwnode_handle___157 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___157 *, struct fwnode_endpoint___157 *);
};

struct fwnode_endpoint___157 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___157 *local_fwnode;
};

struct fwnode_reference_args___157 {
	struct fwnode_handle___157 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct blk_mq_ctxs___4;

struct blk_mq_ctx___5 {
	struct {
		spinlock_t lock;
		struct list_head rq_lists[3];
		long: 64;
	};
	unsigned int cpu;
	short unsigned int index_hw[3];
	struct blk_mq_hw_ctx___5 *hctxs[3];
	long unsigned int rq_dispatched[2];
	long unsigned int rq_merged;
	long unsigned int rq_completed[2];
	struct request_queue___60 *queue;
	struct blk_mq_ctxs___4 *ctxs;
	struct kobject___247 kobj;
};

struct blk_mq_tags___4;

struct blk_mq_hw_ctx___5 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___60 *queue;
	struct blk_flush_queue___5 *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx___5 *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx___5 **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags___4 *tags;
	struct blk_mq_tags___4 *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	unsigned int rh_reserved_nr_expired;
	struct hlist_node cpuhp_dead;
	struct kobject___247 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___259 *debugfs_dir;
	struct dentry___259 *sched_debugfs_dir;
	struct list_head hctx_list;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___59;

struct blk_mq_alloc_data___5;

struct elevator_mq_ops___59 {
	int (*init_sched)(struct request_queue___60 *, struct elevator_type___59 *);
	void (*exit_sched)(struct elevator_queue___59 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___5 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___5 *, unsigned int);
	bool (*allow_merge)(struct request_queue___60 *, struct request___60 *, struct bio___128 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx___5 *, struct bio___128 *);
	int (*request_merge)(struct request_queue___60 *, struct request___60 **, struct bio___128 *);
	void (*request_merged)(struct request_queue___60 *, struct request___60 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___60 *, struct request___60 *, struct request___60 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data___5 *);
	void (*prepare_request)(struct request___60 *, struct bio___128 *);
	void (*finish_request)(struct request___60 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___5 *, struct list_head *, bool);
	struct request___60 * (*dispatch_request)(struct blk_mq_hw_ctx___5 *);
	bool (*has_work)(struct blk_mq_hw_ctx___5 *);
	void (*completed_request)(struct request___60 *, u64);
	void (*started_request)(struct request___60 *);
	void (*requeue_request)(struct request___60 *);
	struct request___60 * (*former_request)(struct request_queue___60 *, struct request___60 *);
	struct request___60 * (*next_request)(struct request_queue___60 *, struct request___60 *);
	void (*init_icq)(struct io_cq___63 *);
	void (*exit_icq)(struct io_cq___63 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx___5 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___59;

struct elevator_type___59 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___59 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___59 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___212 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___59 {
	struct elevator_type___59 *type;
	void *elevator_data;
	struct kobject___247 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct blk_mq_alloc_data___5 {
	struct request_queue___60 *q;
	blk_mq_req_flags_t flags;
	unsigned int shallow_depth;
	unsigned int cmd_flags;
	struct blk_mq_ctx___5 *ctx;
	struct blk_mq_hw_ctx___5 *hctx;
};

struct elv_fs_entry___59 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___59 *, char *);
	ssize_t (*store)(struct elevator_queue___59 *, const char *, size_t);
};

struct rq_qos_ops___3;

struct rq_qos {
	struct rq_qos_ops___3 *ops;
	struct request_queue___60 *q;
	enum rq_qos_id id;
	struct rq_qos *next;
};

struct blk_mq_queue_data___5;

typedef blk_status_t queue_rq_fn___5(struct blk_mq_hw_ctx___5 *, const struct blk_mq_queue_data___5 *);

typedef void commit_rqs_fn___5(struct blk_mq_hw_ctx___5 *);

typedef bool get_budget_fn___5(struct blk_mq_hw_ctx___5 *);

typedef void put_budget_fn___5(struct blk_mq_hw_ctx___5 *);

typedef enum blk_eh_timer_return timeout_fn___5(struct request___60 *, bool);

typedef int poll_fn___5(struct blk_mq_hw_ctx___5 *);

typedef void complete_fn___5(struct request___60 *);

typedef int init_hctx_fn___5(struct blk_mq_hw_ctx___5 *, void *, unsigned int);

typedef void exit_hctx_fn___5(struct blk_mq_hw_ctx___5 *, unsigned int);

typedef int init_request_fn___5(struct blk_mq_tag_set___5 *, struct request___60 *, unsigned int, unsigned int);

typedef void exit_request_fn___5(struct blk_mq_tag_set___5 *, struct request___60 *, unsigned int);

typedef bool busy_fn___5(struct request_queue___60 *);

typedef int map_queues_fn___5(struct blk_mq_tag_set___5 *);

typedef void cleanup_rq_fn___5(struct request___60 *);

struct blk_mq_ops___5 {
	queue_rq_fn___5 *queue_rq;
	commit_rqs_fn___5 *commit_rqs;
	get_budget_fn___5 *get_budget;
	put_budget_fn___5 *put_budget;
	timeout_fn___5 *timeout;
	poll_fn___5 *poll;
	complete_fn___5 *complete;
	init_hctx_fn___5 *init_hctx;
	exit_hctx_fn___5 *exit_hctx;
	init_request_fn___5 *init_request;
	exit_request_fn___5 *exit_request;
	void (*initialize_rq_fn)(struct request___60 *);
	busy_fn___5 *busy;
	map_queues_fn___5 *map_queues;
	void (*show_rq)(struct seq_file___232 *, struct request___60 *);
	union {
		cleanup_rq_fn___5 *cleanup_rq;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide44;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct blk_stat_callback___5 {
	struct list_head list;
	struct timer_list timer;
	struct blk_rq_stat *cpu_stat;
	int (*bucket_fn)(const struct request___60 *);
	unsigned int buckets;
	struct blk_rq_stat *stat;
	void (*timer_fn)(struct blk_stat_callback___5 *);
	void *data;
	struct callback_head rcu;
};

struct rchan___6;

struct blk_trace {
	int trace_state;
	struct rchan___6 *rchan;
	long unsigned int *sequence;
	unsigned char *msg_data;
	u16 act_mask;
	u64 start_lba;
	u64 end_lba;
	u32 pid;
	u32 dev;
	struct dentry___259 *dir;
	struct dentry___259 *dropped_file;
	struct dentry___259 *msg_file;
	struct list_head running_list;
	atomic_t dropped;
};

struct blk_flush_queue___5 {
	unsigned int flush_queue_delayed: 1;
	unsigned int flush_pending_idx: 1;
	unsigned int flush_running_idx: 1;
	long unsigned int flush_pending_since;
	struct list_head flush_queue[2];
	struct list_head flush_data_in_flight;
	struct request___60 *flush_rq;
	struct request___60 *orig_rq;
	spinlock_t mq_flush_lock;
};

struct blk_mq_tag_set___5 {
	struct blk_mq_queue_map map[6];
	unsigned int nr_maps;
	const struct blk_mq_ops___5 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	struct blk_mq_tags___4 **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct req_iterator {
	struct bvec_iter iter;
	struct bio___128 *bio;
};

struct blk_plug_cb;

typedef void (*blk_plug_cb_fn)(struct blk_plug_cb *, bool);

struct blk_plug_cb {
	struct list_head list;
	blk_plug_cb_fn callback;
	void *data;
};

typedef int (*key_restrict_link_func_t___252)(struct key___251 *, const struct key_type *, const union key_payload *, struct key___251 *);

struct key_restriction___251;

struct key___251 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___260 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key___6 index_key;
		struct {
			struct key_type___6 *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___251 *restrict_link;
};

struct key_restriction___251 {
	key_restrict_link_func_t___252 check;
	struct key___251 *key;
	struct key_type *keytype;
};

struct seq_operations___230 {
	void * (*start)(struct seq_file___232 *, loff_t *);
	void (*stop)(struct seq_file___232 *, void *);
	void * (*next)(struct seq_file___232 *, void *, loff_t *);
	int (*show)(struct seq_file___232 *, void *);
};

struct cgroup_namespace___197 {
	refcount_t count;
	struct ns_common___28 ns;
	struct user_namespace___212 *user_ns;
	struct ucounts___212 *ucounts;
	struct css_set___197 *root_cset;
};

struct ucounts___212 {
	struct hlist_node node;
	struct user_namespace___212 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___198;

struct bpf_map_ops___197 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___198 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___198 *, struct file___259 *);
	void (*map_free)(struct bpf_map___198 *);
	int (*map_get_next_key)(struct bpf_map___198 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___198 *);
	void * (*map_lookup_elem)(struct bpf_map___198 *, void *);
	int (*map_update_elem)(struct bpf_map___198 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___198 *, void *);
	int (*map_push_elem)(struct bpf_map___198 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___198 *, void *);
	int (*map_peek_elem)(struct bpf_map___198 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___198 *, struct file___259 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___198 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___198 *, void *, struct seq_file___232 *);
	int (*map_check_btf)(const struct bpf_map___198 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___198 {
	const struct bpf_map_ops___197 *ops;
	struct bpf_map___198 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___251 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___197;

typedef void (*kthread_work_func_t___197)(struct kthread_work___197 *);

struct kthread_worker___197;

struct kthread_work___197 {
	struct list_head node;
	kthread_work_func_t___197 func;
	struct kthread_worker___197 *worker;
	int canceling;
};

struct kthread_worker___197 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___260 *task;
	struct kthread_work___197 *current_work;
};

struct kthread_delayed_work___197 {
	struct kthread_work___197 work;
	struct timer_list timer;
};

struct psi_group___197 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___197 *poll_kworker;
	struct kthread_delayed_work___197 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___197;

struct cgroup_rstat_cpu___197;

struct cgroup___197 {
	struct cgroup_subsys_state___157 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___254 *kn;
	struct cgroup_file___197 procs_file;
	struct cgroup_file___197 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___157 *subsys[13];
	struct cgroup_root___197 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___197 *dom_cgrp;
	struct cgroup_rstat_cpu___197 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___34 bpf;
	atomic_t congestion_count;
	struct cgroup___197 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___197 psi;
	int ancestor_ids[0];
};

struct cftype___197;

struct cgroup_subsys___197 {
	struct cgroup_subsys_state___157 * (*css_alloc)(struct cgroup_subsys_state___157 *);
	int (*css_online)(struct cgroup_subsys_state___157 *);
	void (*css_offline)(struct cgroup_subsys_state___157 *);
	void (*css_released)(struct cgroup_subsys_state___157 *);
	void (*css_free)(struct cgroup_subsys_state___157 *);
	void (*css_reset)(struct cgroup_subsys_state___157 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___157 *, int);
	int (*css_extra_stat_show)(struct seq_file___232 *, struct cgroup_subsys_state___157 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___260 *);
	void (*cancel_fork)(struct task_struct___260 *);
	void (*fork)(struct task_struct___260 *);
	void (*exit)(struct task_struct___260 *);
	void (*free)(struct task_struct___260 *);
	void (*bind)(struct cgroup_subsys_state___157 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___197 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___197 *dfl_cftypes;
	struct cftype___197 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___197 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___197 *updated_children;
	struct cgroup___197 *updated_next;
};

struct cgroup_root___197 {
	struct kernfs_root___253 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___197 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___197 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___197 *ss;
	struct list_head node;
	struct kernfs_ops___253 *kf_ops;
	int (*open)(struct kernfs_open_file___253 *);
	void (*release)(struct kernfs_open_file___253 *);
	u64 (*read_u64)(struct cgroup_subsys_state___157 *, struct cftype___197 *);
	s64 (*read_s64)(struct cgroup_subsys_state___157 *, struct cftype___197 *);
	int (*seq_show)(struct seq_file___232 *, void *);
	void * (*seq_start)(struct seq_file___232 *, loff_t *);
	void * (*seq_next)(struct seq_file___232 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___232 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___157 *, struct cftype___197 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___157 *, struct cftype___197 *, s64);
	ssize_t (*write)(struct kernfs_open_file___253 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___253 *, struct poll_table_struct___160 *);
};

struct blkcg_policy_data___48;

struct blkcg___48 {
	struct cgroup_subsys_state___157 css;
	spinlock_t lock;
	struct xarray blkg_tree;
	struct blkcg_gq___48 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___48 *cpd[5];
	struct list_head all_blkcgs_node;
	struct list_head cgwb_list;
	refcount_t cgwb_refcnt;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct blkcg_policy_data___48 {
	struct blkcg___48 *blkcg;
	int plid;
};

struct blkg_policy_data___48 {
	struct blkcg_gq___48 *blkg;
	int plid;
};

struct blk_mq_tags___4 {
	unsigned int nr_tags;
	unsigned int nr_reserved_tags;
	atomic_t active_queues;
	struct sbitmap_queue bitmap_tags;
	struct sbitmap_queue breserved_tags;
	struct request___60 **rqs;
	struct request___60 **static_rqs;
	struct list_head page_list;
};

struct blk_mq_queue_data___5 {
	struct request___60 *rq;
	bool last;
	long unsigned int rh_reserved1;
};

enum {
	BLK_MQ_REQ_NOWAIT = 1,
	BLK_MQ_REQ_RESERVED = 2,
	BLK_MQ_REQ_INTERNAL = 4,
	BLK_MQ_REQ_PREEMPT = 8,
};

struct mem_cgroup_reclaim_iter___112 {
	struct mem_cgroup___112 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___112 {
	struct lruvec___259 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___112 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___112 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct node___171 {
	struct device___222 dev;
};

struct rchan_buf___6 {
	void *start;
	void *data;
	size_t offset;
	size_t subbufs_produced;
	size_t subbufs_consumed;
	struct rchan___6 *chan;
	wait_queue_head_t read_wait;
	struct irq_work wakeup_work;
	struct dentry___259 *dentry;
	struct kref kref;
	struct page___260 **page_array;
	unsigned int page_count;
	unsigned int finalized;
	size_t *padding;
	size_t prev_padding;
	size_t bytes_consumed;
	size_t early_bytes;
	unsigned int cpu;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
};

struct rchan_callbacks___6;

struct rchan___6 {
	u32 version;
	size_t subbuf_size;
	size_t n_subbufs;
	size_t alloc_size;
	struct rchan_callbacks___6 *cb;
	struct kref kref;
	void *private_data;
	size_t last_toobig;
	struct rchan_buf___6 **buf;
	int is_global;
	struct list_head list;
	struct dentry___259 *parent;
	int has_base_filename;
	char base_filename[255];
};

struct rchan_callbacks___6 {
	int (*subbuf_start)(struct rchan_buf___6 *, void *, void *, size_t);
	void (*buf_mapped)(struct rchan_buf___6 *, struct file___259 *);
	void (*buf_unmapped)(struct rchan_buf___6 *, struct file___259 *);
	struct dentry___259 * (*create_buf_file)(const char *, struct dentry___259 *, umode_t, struct rchan_buf___6 *, int *);
	int (*remove_buf_file)(struct dentry___259 *);
};

struct perf_cpu_context___128;

struct pmu___128 {
	struct list_head entry;
	struct module___212 *module;
	struct device___222 *dev;
	const struct attribute_group___224 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___128 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___128 *);
	void (*pmu_disable)(struct pmu___128 *);
	int (*event_init)(struct perf_event___128 *);
	void (*event_mapped)(struct perf_event___128 *, struct mm_struct___259 *);
	void (*event_unmapped)(struct perf_event___128 *, struct mm_struct___259 *);
	int (*add)(struct perf_event___128 *, int);
	void (*del)(struct perf_event___128 *, int);
	void (*start)(struct perf_event___128 *, int);
	void (*stop)(struct perf_event___128 *, int);
	void (*read)(struct perf_event___128 *);
	void (*start_txn)(struct pmu___128 *, unsigned int);
	int (*commit_txn)(struct pmu___128 *);
	void (*cancel_txn)(struct pmu___128 *);
	int (*event_idx)(struct perf_event___128 *);
	void (*sched_task)(struct perf_event_context___128 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___128 *);
	int (*filter_match)(struct perf_event___128 *);
	int (*check_period)(struct perf_event___128 *, u64);
};

struct perf_cpu_context___128 {
	struct perf_event_context___128 ctx;
	struct perf_event_context___128 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___128 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___128 {
	struct cgroup_subsys_state___157 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___121 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___121 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___121 *);
	struct list_head * (*get_fields)(struct trace_event_call___121 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___121 *);
};

struct trace_event_file___46;

struct trace_event_buffer___38 {
	struct ring_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___46 *trace_file;
	void *entry;
	long unsigned int flags;
	int pc;
};

struct trace_event_file___46 {
	struct list_head list;
	struct trace_event_call___121 *event_call;
	struct event_filter *filter;
	struct dentry___259 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_block_buffer {
	struct trace_entry ent;
	dev_t dev;
	sector_t sector;
	size_t size;
	char __data[0];
};

struct trace_event_raw_block_rq_requeue {
	struct trace_entry ent;
	dev_t dev;
	sector_t sector;
	unsigned int nr_sector;
	char rwbs[8];
	u32 __data_loc_cmd;
	char __data[0];
};

struct trace_event_raw_block_rq_complete {
	struct trace_entry ent;
	dev_t dev;
	sector_t sector;
	unsigned int nr_sector;
	int error;
	char rwbs[8];
	u32 __data_loc_cmd;
	char __data[0];
};

struct trace_event_raw_block_rq {
	struct trace_entry ent;
	dev_t dev;
	sector_t sector;
	unsigned int nr_sector;
	unsigned int bytes;
	char rwbs[8];
	char comm[16];
	u32 __data_loc_cmd;
	char __data[0];
};

struct trace_event_raw_block_bio_bounce {
	struct trace_entry ent;
	dev_t dev;
	sector_t sector;
	unsigned int nr_sector;
	char rwbs[8];
	char comm[16];
	char __data[0];
};

struct trace_event_raw_block_bio_complete {
	struct trace_entry ent;
	dev_t dev;
	sector_t sector;
	unsigned int nr_sector;
	int error;
	char rwbs[8];
	char __data[0];
};

struct trace_event_raw_block_bio_merge {
	struct trace_entry ent;
	dev_t dev;
	sector_t sector;
	unsigned int nr_sector;
	char rwbs[8];
	char comm[16];
	char __data[0];
};

struct trace_event_raw_block_bio_queue {
	struct trace_entry ent;
	dev_t dev;
	sector_t sector;
	unsigned int nr_sector;
	char rwbs[8];
	char comm[16];
	char __data[0];
};

struct trace_event_raw_block_get_rq {
	struct trace_entry ent;
	dev_t dev;
	sector_t sector;
	unsigned int nr_sector;
	char rwbs[8];
	char comm[16];
	char __data[0];
};

struct trace_event_raw_block_plug {
	struct trace_entry ent;
	char comm[16];
	char __data[0];
};

struct trace_event_raw_block_unplug {
	struct trace_entry ent;
	int nr_rq;
	char comm[16];
	char __data[0];
};

struct trace_event_raw_block_split {
	struct trace_entry ent;
	dev_t dev;
	sector_t sector;
	sector_t new_sector;
	char rwbs[8];
	char comm[16];
	char __data[0];
};

struct trace_event_raw_block_bio_remap {
	struct trace_entry ent;
	dev_t dev;
	sector_t sector;
	unsigned int nr_sector;
	dev_t old_dev;
	sector_t old_sector;
	char rwbs[8];
	char __data[0];
};

struct trace_event_raw_block_rq_remap {
	struct trace_entry ent;
	dev_t dev;
	sector_t sector;
	unsigned int nr_sector;
	dev_t old_dev;
	sector_t old_sector;
	unsigned int nr_bios;
	char rwbs[8];
	char __data[0];
};

struct trace_event_data_offsets_block_buffer {};

struct trace_event_data_offsets_block_rq_requeue {
	u32 cmd;
};

struct trace_event_data_offsets_block_rq_complete {
	u32 cmd;
};

struct trace_event_data_offsets_block_rq {
	u32 cmd;
};

struct trace_event_data_offsets_block_bio_bounce {};

struct trace_event_data_offsets_block_bio_complete {};

struct trace_event_data_offsets_block_bio_merge {};

struct trace_event_data_offsets_block_bio_queue {};

struct trace_event_data_offsets_block_get_rq {};

struct trace_event_data_offsets_block_plug {};

struct trace_event_data_offsets_block_unplug {};

struct trace_event_data_offsets_block_split {};

struct trace_event_data_offsets_block_bio_remap {};

struct trace_event_data_offsets_block_rq_remap {};

struct blk_mq_ctxs___4 {
	struct kobject___247 kobj;
	struct blk_mq_ctx___5 *queue_ctx;
};

struct rq_qos_ops___3 {
	void (*throttle)(struct rq_qos *, struct bio___128 *);
	void (*track)(struct rq_qos *, struct request___60 *, struct bio___128 *);
	void (*issue)(struct rq_qos *, struct request___60 *);
	void (*requeue)(struct rq_qos *, struct request___60 *);
	void (*done)(struct rq_qos *, struct request___60 *);
	void (*done_bio)(struct rq_qos *, struct bio___128 *);
	void (*cleanup)(struct rq_qos *, struct bio___128 *);
	void (*exit)(struct rq_qos *);
};

struct module___213;

struct file___260;

struct kiocb___260;

struct iov_iter___126;

struct poll_table_struct___161;

struct vm_area_struct___261;

struct inode___260;

struct file_lock___260;

struct page___261;

struct file_operations___260 {
	struct module___213 *owner;
	loff_t (*llseek)(struct file___260 *, loff_t, int);
	ssize_t (*read)(struct file___260 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___260 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___260 *, struct iov_iter___126 *);
	ssize_t (*write_iter)(struct kiocb___260 *, struct iov_iter___126 *);
	int (*iopoll)(struct kiocb___260 *, bool);
	int (*iterate)(struct file___260 *, struct dir_context *);
	int (*iterate_shared)(struct file___260 *, struct dir_context *);
	__poll_t (*poll)(struct file___260 *, struct poll_table_struct___161 *);
	long int (*unlocked_ioctl)(struct file___260 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___260 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___260 *, struct vm_area_struct___261 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___260 *, struct file___260 *);
	int (*flush)(struct file___260 *, fl_owner_t);
	int (*release)(struct inode___260 *, struct file___260 *);
	int (*fsync)(struct file___260 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___260 *, int);
	int (*lock)(struct file___260 *, int, struct file_lock___260 *);
	ssize_t (*sendpage)(struct file___260 *, struct page___261 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___260 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___260 *, int, struct file_lock___260 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___260 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___260 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___260 *, long int, struct file_lock___260 **, void **);
	long int (*fallocate)(struct file___260 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___3 *, struct file___260 *);
	ssize_t (*copy_file_range)(struct file___260 *, loff_t, struct file___260 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___260 *, loff_t, struct file___260 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___260 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___260 {
	u64 seqnum;
	struct vm_area_struct___261 *vmas[4];
};

struct page_frag___260 {
	struct page___261 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___260;

struct cred___252;

struct nsproxy___233;

struct bio_list___129;

struct backing_dev_info___129;

struct io_context___64;

struct css_set___198;

struct request_queue___61;

struct vm_struct___176;

struct task_struct___261 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___261 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___260 *mm;
	struct mm_struct___260 *active_mm;
	struct vmacache___260 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___261 *real_parent;
	struct task_struct___261 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___261 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___189 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___189 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___189 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___252 *ptracer_cred;
	const struct cred___252 *real_cred;
	const struct cred___252 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___233 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___261 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___129 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___129 *backing_dev_info;
	struct io_context___64 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___198 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___260 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___61 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___261 *oom_reaper_list;
	struct vm_struct___176 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___128 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___261 *pgtable_t___260;

struct address_space___259;

struct dev_pagemap___249;

struct page___261 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___259 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___261 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___260 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___260 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___249 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___260;

struct lruvec___260 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___260 *pgdat;
};

struct zone___260 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___260 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___260 {
	struct zone___260 *zone;
	int zone_idx;
};

struct zonelist___260 {
	struct zoneref___260 _zonerefs[25];
};

struct pglist_data___260 {
	struct zone___260 node_zones[3];
	struct zonelist___260 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___261 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___261 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___260 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___261 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___261 *owner;
};

struct secondary_data___261 {
	void *stack;
	struct task_struct___261 *task;
	long int status;
};

struct blocking_notifier_head___260 {
	struct rw_semaphore___261 rwsem;
	struct notifier_block *head;
};

struct key___252;

struct ucounts___213;

struct user_namespace___213 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___213 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___28 ns;
	long unsigned int flags;
	struct key___252 *persistent_keyring_register;
	struct rw_semaphore___261 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___213 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dentry___260;

struct path___260 {
	struct vfsmount *mnt;
	struct dentry___260 *dentry;
};

struct file___260 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___260 f_path;
	struct inode___260 *f_inode;
	const struct file_operations___260 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___189 f_owner;
	const struct cred___252 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___259 *f_mapping;
	errseq_t f_wb_err;
};

struct user_struct___252;

struct cred___252 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___252 *session_keyring;
	struct key___252 *process_keyring;
	struct key___252 *thread_keyring;
	struct key___252 *request_key_auth;
	void *security;
	struct user_struct___252 *user;
	struct user_namespace___213 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___254;

struct kernfs_elem_dir___254 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___254 *root;
};

struct kernfs_node___255;

struct kernfs_syscall_ops___254;

struct kernfs_root___254 {
	struct kernfs_node___255 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___254 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___254 {
	struct kernfs_node___255 *target_kn;
};

struct kernfs_ops___254;

struct kernfs_elem_attr___254 {
	const struct kernfs_ops___254 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___255 *notify_next;
};

struct kernfs_node___255 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___255 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___254 dir;
		struct kernfs_elem_symlink___254 symlink;
		struct kernfs_elem_attr___254 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___254;

struct kernfs_ops___254 {
	int (*open)(struct kernfs_open_file___254 *);
	void (*release)(struct kernfs_open_file___254 *);
	int (*seq_show)(struct seq_file___3 *, void *);
	void * (*seq_start)(struct seq_file___3 *, loff_t *);
	void * (*seq_next)(struct seq_file___3 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___3 *, void *);
	ssize_t (*read)(struct kernfs_open_file___254 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___254 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___254 *, struct vm_area_struct___261 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___254 *, struct poll_table_struct___161 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___254 {
	int (*remount_fs)(struct kernfs_root___254 *, int *, char *);
	int (*show_options)(struct seq_file___3 *, struct kernfs_root___254 *);
	int (*mkdir)(struct kernfs_node___255 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___255 *);
	int (*rename)(struct kernfs_node___255 *, struct kernfs_node___255 *, const char *);
	int (*show_path)(struct seq_file___3 *, struct kernfs_node___255 *, struct kernfs_root___254 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_file___3 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___2 *op;
	int poll_event;
	const struct file___260 *file;
	void *private;
};

struct vm_operations_struct___249;

struct kernfs_open_file___254 {
	struct kernfs_node___255 *kn;
	struct file___260 *file;
	struct seq_file___3 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___249 *vm_ops;
};

struct vm_fault___249;

struct vm_operations_struct___249 {
	void (*open)(struct vm_area_struct___261 *);
	void (*close)(struct vm_area_struct___261 *);
	int (*split)(struct vm_area_struct___261 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___261 *);
	vm_fault_t (*fault)(struct vm_fault___249 *);
	vm_fault_t (*huge_fault)(struct vm_fault___249 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___249 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___261 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___249 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___249 *);
	int (*access)(struct vm_area_struct___261 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___261 *);
	int (*set_policy)(struct vm_area_struct___261 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___261 *, long unsigned int);
	struct page___261 * (*find_special_page)(struct vm_area_struct___261 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___163)(struct file___260 *, wait_queue_head_t *, struct poll_table_struct___161 *);

struct poll_table_struct___161 {
	poll_queue_proc___163 _qproc;
	__poll_t _key;
};

struct vm_area_struct___261 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___261 *vm_next;
	struct vm_area_struct___261 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___260 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___249 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___260 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___248;

struct bin_attribute___224;

struct attribute_group___225 {
	const char *name;
	umode_t (*is_visible)(struct kobject___248 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___248 *, struct bin_attribute___224 *, int);
	struct attribute **attrs;
	struct bin_attribute___224 **bin_attrs;
};

struct kset___247;

struct kobj_type___247;

struct kobject___248 {
	const char *name;
	struct list_head entry;
	struct kobject___248 *parent;
	struct kset___247 *kset;
	struct kobj_type___247 *ktype;
	struct kernfs_node___255 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___224 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___260 *, struct kobject___248 *, struct bin_attribute___224 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___260 *, struct kobject___248 *, struct bin_attribute___224 *, char *, loff_t, size_t);
	int (*mmap)(struct file___260 *, struct kobject___248 *, struct bin_attribute___224 *, struct vm_area_struct___261 *);
};

struct sysfs_ops___247 {
	ssize_t (*show)(struct kobject___248 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___248 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___247;

struct kset___247 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___248 kobj;
	const struct kset_uevent_ops___247 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___247 {
	void (*release)(struct kobject___248 *);
	const struct sysfs_ops___247 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___24 * (*child_ns_type)(struct kobject___248 *);
	const void * (*namespace)(struct kobject___248 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___247 {
	int (* const filter)(struct kset___247 *, struct kobject___248 *);
	const char * (* const name)(struct kset___247 *, struct kobject___248 *);
	int (* const uevent)(struct kset___247 *, struct kobject___248 *, struct kobj_uevent_env *);
};

struct kobj_attribute___240 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___248 *, struct kobj_attribute___240 *, char *);
	ssize_t (*store)(struct kobject___248 *, struct kobj_attribute___240 *, const char *, size_t);
};

struct kernel_param___210;

struct kernel_param_ops___210 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___210 *);
	int (*get)(char *, const struct kernel_param___210 *);
	void (*free)(void *);
};

struct kparam_array___210;

struct kernel_param___210 {
	const char *name;
	struct module___213 *mod;
	const struct kernel_param_ops___210 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___210 *arr;
	};
};

struct kparam_array___210 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___210 *ops;
	void *elem;
};

struct module_kobject___210 {
	struct kobject___248 kobj;
	struct module___213 *mod;
	struct kobject___248 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___210 {
	struct module___213 *mod;
	struct latch_tree_node node;
};

struct module_layout___210 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___210 mtn;
};

struct module_attribute___210;

struct module___213 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___210 mkobj;
	struct module_attribute___210 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___248 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___210 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___210 core_layout;
	struct module_layout___210 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___210 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___210 *, struct module_kobject___210 *, char *);
	ssize_t (*store)(struct module_attribute___210 *, struct module_kobject___210 *, const char *, size_t);
	void (*setup)(struct module___213 *, const char *);
	int (*test)(struct module___213 *);
	void (*free)(struct module___213 *);
};

struct dentry_operations___259;

struct super_block___259;

struct dentry___260 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___260 *d_parent;
	struct qstr d_name;
	struct inode___260 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___259 *d_op;
	struct super_block___259 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___259;

struct address_space___259 {
	struct inode___260 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___261 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___259 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___259;

struct bdi_writeback___129;

struct block_device___260;

struct inode___260 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___259 *i_op;
	struct super_block___259 *i_sb;
	struct address_space___259 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___261 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___129 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___260 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___259 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___260 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___259 {
	int (*d_revalidate)(struct dentry___260 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___260 *, unsigned int);
	int (*d_hash)(const struct dentry___260 *, struct qstr *);
	int (*d_compare)(const struct dentry___260 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___260 *);
	int (*d_init)(struct dentry___260 *);
	void (*d_release)(struct dentry___260 *);
	void (*d_prune)(struct dentry___260 *);
	void (*d_iput)(struct dentry___260 *, struct inode___260 *);
	char * (*d_dname)(struct dentry___260 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___260 *);
	int (*d_manage)(const struct path___260 *, bool);
	struct dentry___260 * (*d_real)(struct dentry___260 *, const struct inode___260 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___259;

struct mem_dqinfo___259 {
	struct quota_format_type___259 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___259;

struct quota_info___259 {
	unsigned int flags;
	struct rw_semaphore___261 dqio_sem;
	struct inode___260 *files[3];
	struct mem_dqinfo___259 info[3];
	const struct quota_format_ops___259 *ops[3];
};

struct rcuwait___259 {
	struct task_struct___261 *task;
};

struct percpu_rw_semaphore___259 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___261 rw_sem;
	struct rcuwait___259 writer;
	int readers_block;
};

struct sb_writers___259 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___259 rw_sem[3];
};

struct file_system_type___259;

struct super_operations___259;

struct dquot_operations___259;

struct quotactl_ops___259;

struct super_block___259 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___259 *s_type;
	const struct super_operations___259 *s_op;
	const struct dquot_operations___259 *dq_op;
	const struct quotactl_ops___259 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___260 *s_root;
	struct rw_semaphore___261 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___260 *s_bdev;
	struct backing_dev_info___129 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___259 s_dquot;
	struct sb_writers___259 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___259 *s_d_op;
	int cleancache_poolid;
	struct shrinker___112 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___213 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct core_state___260;

struct mm_struct___260 {
	struct {
		struct vm_area_struct___261 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___260 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___261 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___260 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___261 *owner;
		struct user_namespace___213 *user_ns;
		struct file___260 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___260 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___249)(struct vm_area_struct___261 *, long unsigned int, const struct page___261 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___249)(struct page___261 *, void *);

struct device___223;

struct dev_pagemap___249 {
	dev_page_fault_t___249 page_fault;
	dev_page_free_t___249 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___223 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___260 {
	struct task_struct___261 *task;
	struct core_thread___260 *next;
};

struct core_state___260 {
	atomic_t nr_threads;
	struct core_thread___260 dumper;
	struct completion startup;
};

struct vm_fault___249 {
	struct vm_area_struct___261 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___261 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___261 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___260 prealloc_pte;
};

struct user_struct___252 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___252 *uid_keyring;
	struct key___252 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cgroup_namespace___198;

struct nsproxy___233 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___198 *cgroup_ns;
};

struct bio___129;

struct bio_list___129 {
	struct bio___129 *head;
	struct bio___129 *tail;
};

struct bdi_writeback_congested___129;

struct cgroup_subsys_state___198;

struct bdi_writeback___129 {
	struct backing_dev_info___129 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___129 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___198 *memcg_css;
	struct cgroup_subsys_state___198 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___129 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___129 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___223 *dev;
	struct device___223 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___260 *debug_dir;
	struct dentry___260 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___64;

struct io_context___64 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___64 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___198;

struct css_set___198 {
	struct cgroup_subsys_state___198 *subsys[13];
	refcount_t refcount;
	struct css_set___198 *dom_cset;
	struct cgroup___198 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___198 *mg_src_cgrp;
	struct cgroup___198 *mg_dst_cgrp;
	struct css_set___198 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

typedef blk_qc_t make_request_fn___60(struct request_queue___61 *, struct bio___129 *);

struct request___61;

typedef int dma_drain_needed_fn___60(struct request___61 *);

struct bsg_ops___60;

struct bsg_class_device___60 {
	struct device___223 *class_dev;
	int minor;
	struct request_queue___61 *queue;
	const struct bsg_ops___60 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___129 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___129 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___60;

struct rq_qos___4;

struct blk_mq_ops___6;

struct blk_mq_ctx___6;

struct blk_mq_hw_ctx___6;

struct blk_stat_callback___6;

struct blkcg_gq___49;

struct blk_trace___6;

struct blk_flush_queue___6;

struct blk_mq_tag_set___6;

struct request_queue___61 {
	struct list_head queue_head;
	struct request___61 *last_merge;
	struct elevator_queue___60 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos___4 *rq_qos;
	make_request_fn___60 *make_request_fn;
	dma_drain_needed_fn___60 *dma_drain_needed;
	const struct blk_mq_ops___6 *mq_ops;
	struct blk_mq_ctx___6 *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___6 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___129 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___248 kobj;
	struct kobject___248 *mq_kobj;
	struct blk_integrity integrity;
	struct device___223 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback___6 *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___49 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace___6 *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue___6 *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	struct bsg_class_device___60 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set___6 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___129 bio_split;
	struct dentry___260 *debugfs_dir;
	struct dentry___260 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___176 {
	struct vm_struct___176 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___261 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct io_cq___64 {
	struct request_queue___61 *q;
	struct io_context___64 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___6 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___260 {
	struct file___260 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___260 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___259 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___260 *ia_file;
};

struct dquot___259 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___259 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___259 {
	int qf_fmt_id;
	const struct quota_format_ops___259 *qf_ops;
	struct module___213 *qf_owner;
	struct quota_format_type___259 *qf_next;
};

struct quota_format_ops___259 {
	int (*check_quota_file)(struct super_block___259 *, int);
	int (*read_file_info)(struct super_block___259 *, int);
	int (*write_file_info)(struct super_block___259 *, int);
	int (*free_file_info)(struct super_block___259 *, int);
	int (*read_dqblk)(struct dquot___259 *);
	int (*commit_dqblk)(struct dquot___259 *);
	int (*release_dqblk)(struct dquot___259 *);
	int (*get_next_id)(struct super_block___259 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___259 {
	int (*write_dquot)(struct dquot___259 *);
	struct dquot___259 * (*alloc_dquot)(struct super_block___259 *, int);
	void (*destroy_dquot)(struct dquot___259 *);
	int (*acquire_dquot)(struct dquot___259 *);
	int (*release_dquot)(struct dquot___259 *);
	int (*mark_dirty)(struct dquot___259 *);
	int (*write_info)(struct super_block___259 *, int);
	qsize_t * (*get_reserved_space)(struct inode___260 *);
	int (*get_projid)(struct inode___260 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___260 *, qsize_t *);
	int (*get_next_id)(struct super_block___259 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___259 {
	int (*quota_on)(struct super_block___259 *, int, int, const struct path___260 *);
	int (*quota_off)(struct super_block___259 *, int);
	int (*quota_enable)(struct super_block___259 *, unsigned int);
	int (*quota_disable)(struct super_block___259 *, unsigned int);
	int (*quota_sync)(struct super_block___259 *, int);
	int (*set_info)(struct super_block___259 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___259 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___259 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___259 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___259 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___259 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___124;

struct address_space_operations___259 {
	int (*writepage)(struct page___261 *, struct writeback_control___124 *);
	int (*readpage)(struct file___260 *, struct page___261 *);
	int (*writepages)(struct address_space___259 *, struct writeback_control___124 *);
	int (*set_page_dirty)(struct page___261 *);
	int (*readpages)(struct file___260 *, struct address_space___259 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___260 *, struct address_space___259 *, loff_t, unsigned int, unsigned int, struct page___261 **, void **);
	int (*write_end)(struct file___260 *, struct address_space___259 *, loff_t, unsigned int, unsigned int, struct page___261 *, void *);
	sector_t (*bmap)(struct address_space___259 *, sector_t);
	void (*invalidatepage)(struct page___261 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___261 *, gfp_t);
	void (*freepage)(struct page___261 *);
	ssize_t (*direct_IO)(struct kiocb___260 *, struct iov_iter___126 *);
	int (*migratepage)(struct address_space___259 *, struct page___261 *, struct page___261 *, enum migrate_mode);
	bool (*isolate_page)(struct page___261 *, isolate_mode_t);
	void (*putback_page)(struct page___261 *);
	int (*launder_page)(struct page___261 *);
	int (*is_partially_uptodate)(struct page___261 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___261 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___259 *, struct page___261 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___260 *, sector_t *);
	void (*swap_deactivate)(struct file___260 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___124 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___129 *wb;
	struct inode___260 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___129;

struct iov_iter___126 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___129 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct hd_struct___61;

struct gendisk___61;

struct block_device___260 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___260 *bd_inode;
	struct super_block___259 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___260 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___61 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___61 *bd_disk;
	struct request_queue___61 *bd_queue;
	struct backing_dev_info___129 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___223 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___223 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___223;

struct bus_type___223;

struct device_driver___223;

struct dev_pm_domain___223;

struct fwnode_handle___158;

struct class___223;

struct device___223 {
	struct device___223 *parent;
	struct device_private *p;
	struct kobject___248 kobj;
	const char *init_name;
	const struct device_type___223 *type;
	struct mutex mutex;
	struct bus_type___223 *bus;
	struct device_driver___223 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___223 power;
	struct dev_pm_domain___223 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___158 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___223 *class;
	const struct attribute_group___225 **groups;
	void (*release)(struct device___223 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___61 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___223 __dev;
	struct kobject___248 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___61;

struct block_device_operations___61;

struct gendisk___61 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___61 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___61 *part_tbl;
	struct hd_struct___61 part0;
	const struct block_device_operations___61 *fops;
	struct request_queue___61 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___261 lookup_sem;
	struct kobject___248 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___248 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___259 {
	struct dentry___260 * (*lookup)(struct inode___260 *, struct dentry___260 *, unsigned int);
	const char * (*get_link)(struct dentry___260 *, struct inode___260 *, struct delayed_call *);
	int (*permission)(struct inode___260 *, int);
	struct posix_acl * (*get_acl)(struct inode___260 *, int);
	int (*readlink)(struct dentry___260 *, char *, int);
	int (*create)(struct inode___260 *, struct dentry___260 *, umode_t, bool);
	int (*link)(struct dentry___260 *, struct inode___260 *, struct dentry___260 *);
	int (*unlink)(struct inode___260 *, struct dentry___260 *);
	int (*symlink)(struct inode___260 *, struct dentry___260 *, const char *);
	int (*mkdir)(struct inode___260 *, struct dentry___260 *, umode_t);
	int (*rmdir)(struct inode___260 *, struct dentry___260 *);
	int (*mknod)(struct inode___260 *, struct dentry___260 *, umode_t, dev_t);
	int (*rename)(struct inode___260 *, struct dentry___260 *, struct inode___260 *, struct dentry___260 *, unsigned int);
	int (*setattr)(struct dentry___260 *, struct iattr___259 *);
	int (*getattr)(const struct path___260 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___260 *, char *, size_t);
	int (*fiemap)(struct inode___260 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___260 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___260 *, struct dentry___260 *, struct file___260 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___260 *, struct dentry___260 *, umode_t);
	int (*set_acl)(struct inode___260 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___259 {
	void (*fl_copy_lock)(struct file_lock___260 *, struct file_lock___260 *);
	void (*fl_release_private)(struct file_lock___260 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___259;

struct lock_manager_operations___259;

struct file_lock___260 {
	struct file_lock___260 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___260 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___259 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___259 *fl_ops;
	const struct lock_manager_operations___259 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___259 {
	int (*lm_compare_owner)(struct file_lock___260 *, struct file_lock___260 *);
	long unsigned int (*lm_owner_key)(struct file_lock___260 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___260 *);
	int (*lm_grant)(struct file_lock___260 *, int);
	bool (*lm_break)(struct file_lock___260 *);
	int (*lm_change)(struct file_lock___260 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___260 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___259 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___259 *fa_next;
	struct file___260 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___259 {
	const char *name;
	int fs_flags;
	struct dentry___260 * (*mount)(struct file_system_type___259 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___259 *);
	struct module___213 *owner;
	struct file_system_type___259 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___259 {
	struct inode___260 * (*alloc_inode)(struct super_block___259 *);
	void (*destroy_inode)(struct inode___260 *);
	void (*dirty_inode)(struct inode___260 *, int);
	int (*write_inode)(struct inode___260 *, struct writeback_control___124 *);
	int (*drop_inode)(struct inode___260 *);
	void (*evict_inode)(struct inode___260 *);
	void (*put_super)(struct super_block___259 *);
	int (*sync_fs)(struct super_block___259 *, int);
	int (*freeze_super)(struct super_block___259 *);
	int (*freeze_fs)(struct super_block___259 *);
	int (*thaw_super)(struct super_block___259 *);
	int (*unfreeze_fs)(struct super_block___259 *);
	int (*statfs)(struct dentry___260 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___259 *, int *, char *);
	void (*umount_begin)(struct super_block___259 *);
	int (*show_options)(struct seq_file___3 *, struct dentry___260 *);
	int (*show_devname)(struct seq_file___3 *, struct dentry___260 *);
	int (*show_path)(struct seq_file___3 *, struct dentry___260 *);
	int (*show_stats)(struct seq_file___3 *, struct dentry___260 *);
	ssize_t (*quota_read)(struct super_block___259 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___259 *, int, const char *, size_t, loff_t);
	struct dquot___259 ** (*get_dquots)(struct inode___260 *);
	int (*bdev_try_to_free_page)(struct super_block___259 *, struct page___261 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___259 *, struct shrink_control___112 *);
	long int (*free_cached_objects)(struct super_block___259 *, struct shrink_control___112 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___129(struct bio___129 *);

struct bio_vec___129 {
	struct page___261 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___129;

struct bio___129 {
	struct bio___129 *bi_next;
	struct gendisk___61 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___129 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___49 *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___129 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___129 *bi_io_vec;
	struct bio_set___129 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___129 bi_inline_vecs[0];
};

typedef void compound_page_dtor___249(struct page___261 *);

struct bio_integrity_payload___129 {
	struct bio___129 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___129 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___129 bip_inline_vecs[0];
};

struct blkcg___49;

struct blkg_policy_data___49;

struct blkcg_gq___49 {
	struct request_queue___61 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___49 *blkcg;
	struct bdi_writeback_congested___129 *wb_congested;
	struct blkcg_gq___49 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_rwstat stat_bytes;
	struct blkg_rwstat stat_ios;
	struct blkg_policy_data___49 *pd[5];
	struct callback_head callback_head;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
};

struct dev_pm_ops___223;

struct device_type___223 {
	const char *name;
	const struct attribute_group___225 **groups;
	int (*uevent)(struct device___223 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___223 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___223 *);
	const struct dev_pm_ops___223 *pm;
};

struct class___223 {
	const char *name;
	struct module___213 *owner;
	const struct attribute_group___225 **class_groups;
	const struct attribute_group___225 **dev_groups;
	struct kobject___248 *dev_kobj;
	int (*dev_uevent)(struct device___223 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___223 *, umode_t *);
	void (*class_release)(struct class___223 *);
	void (*dev_release)(struct device___223 *);
	int (*shutdown_pre)(struct device___223 *);
	const struct kobj_ns_type_operations___24 *ns_type;
	const void * (*namespace)(struct device___223 *);
	const struct dev_pm_ops___223 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dev_pm_ops___223 {
	int (*prepare)(struct device___223 *);
	void (*complete)(struct device___223 *);
	int (*suspend)(struct device___223 *);
	int (*resume)(struct device___223 *);
	int (*freeze)(struct device___223 *);
	int (*thaw)(struct device___223 *);
	int (*poweroff)(struct device___223 *);
	int (*restore)(struct device___223 *);
	int (*suspend_late)(struct device___223 *);
	int (*resume_early)(struct device___223 *);
	int (*freeze_late)(struct device___223 *);
	int (*thaw_early)(struct device___223 *);
	int (*poweroff_late)(struct device___223 *);
	int (*restore_early)(struct device___223 *);
	int (*suspend_noirq)(struct device___223 *);
	int (*resume_noirq)(struct device___223 *);
	int (*freeze_noirq)(struct device___223 *);
	int (*thaw_noirq)(struct device___223 *);
	int (*poweroff_noirq)(struct device___223 *);
	int (*restore_noirq)(struct device___223 *);
	int (*runtime_suspend)(struct device___223 *);
	int (*runtime_resume)(struct device___223 *);
	int (*runtime_idle)(struct device___223 *);
};

struct dev_pm_domain___223 {
	struct dev_pm_ops___223 ops;
	void (*detach)(struct device___223 *, bool);
	int (*activate)(struct device___223 *);
	void (*sync)(struct device___223 *);
	void (*dismiss)(struct device___223 *);
};

struct bus_type___223 {
	const char *name;
	const char *dev_name;
	struct device___223 *dev_root;
	const struct attribute_group___225 **bus_groups;
	const struct attribute_group___225 **dev_groups;
	const struct attribute_group___225 **drv_groups;
	int (*match)(struct device___223 *, struct device_driver___223 *);
	int (*uevent)(struct device___223 *, struct kobj_uevent_env *);
	int (*probe)(struct device___223 *);
	int (*remove)(struct device___223 *);
	void (*shutdown)(struct device___223 *);
	int (*online)(struct device___223 *);
	int (*offline)(struct device___223 *);
	int (*suspend)(struct device___223 *, pm_message_t);
	int (*resume)(struct device___223 *);
	int (*num_vf)(struct device___223 *);
	int (*dma_configure)(struct device___223 *);
	const struct dev_pm_ops___223 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___223 {
	const char *name;
	struct bus_type___223 *bus;
	struct module___213 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___223 *);
	int (*remove)(struct device___223 *);
	void (*shutdown)(struct device___223 *);
	int (*suspend)(struct device___223 *, pm_message_t);
	int (*resume)(struct device___223 *);
	const struct attribute_group___225 **groups;
	const struct dev_pm_ops___223 *pm;
	void (*coredump)(struct device___223 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct fwnode_operations___158;

struct fwnode_handle___158 {
	struct fwnode_handle___158 *secondary;
	const struct fwnode_operations___158 *ops;
};

struct disk_part_tbl___61 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___61 *last_lookup;
	struct hd_struct___61 *part[0];
};

struct block_device_operations___61 {
	int (*open)(struct block_device___260 *, fmode_t);
	void (*release)(struct gendisk___61 *, fmode_t);
	int (*rw_page)(struct block_device___260 *, sector_t, struct page___261 *, unsigned int);
	int (*ioctl)(struct block_device___260 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___260 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___61 *, unsigned int);
	int (*media_changed)(struct gendisk___61 *);
	void (*unlock_native_capacity)(struct gendisk___61 *);
	int (*revalidate_disk)(struct gendisk___61 *);
	int (*getgeo)(struct block_device___260 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___260 *, long unsigned int);
	int (*report_zones)(struct gendisk___61 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___213 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bdi_writeback_congested___129 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___129 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct cgroup_subsys___198;

struct cgroup_subsys_state___198 {
	struct cgroup___198 *cgroup;
	struct cgroup_subsys___198 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___198 *parent;
};

struct bsg_ops___60 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___61 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___61 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___61 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___60(struct request___61 *, blk_status_t);

struct request___61 {
	struct request_queue___61 *q;
	struct blk_mq_ctx___6 *mq_ctx;
	struct blk_mq_hw_ctx___6 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___129 *bio;
	struct bio___129 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___129 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___64 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___60 *saved_end_io;
		} flush;
	};
	struct gendisk___61 *rq_disk;
	struct hd_struct___61 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___60 *end_io;
	void *end_io_data;
	struct request___61 *next_rq;
};

struct fwnode_reference_args___158;

struct fwnode_endpoint___158;

struct fwnode_operations___158 {
	struct fwnode_handle___158 * (*get)(struct fwnode_handle___158 *);
	void (*put)(struct fwnode_handle___158 *);
	bool (*device_is_available)(const struct fwnode_handle___158 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___158 *, const struct device___223 *);
	bool (*property_present)(const struct fwnode_handle___158 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___158 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___158 *, const char *, const char **, size_t);
	struct fwnode_handle___158 * (*get_parent)(const struct fwnode_handle___158 *);
	struct fwnode_handle___158 * (*get_next_child_node)(const struct fwnode_handle___158 *, struct fwnode_handle___158 *);
	struct fwnode_handle___158 * (*get_named_child_node)(const struct fwnode_handle___158 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___158 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___158 *);
	struct fwnode_handle___158 * (*graph_get_next_endpoint)(const struct fwnode_handle___158 *, struct fwnode_handle___158 *);
	struct fwnode_handle___158 * (*graph_get_remote_endpoint)(const struct fwnode_handle___158 *);
	struct fwnode_handle___158 * (*graph_get_port_parent)(struct fwnode_handle___158 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___158 *, struct fwnode_endpoint___158 *);
};

struct fwnode_endpoint___158 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___158 *local_fwnode;
};

struct fwnode_reference_args___158 {
	struct fwnode_handle___158 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct blk_mq_ctxs___5;

struct blk_mq_ctx___6 {
	struct {
		spinlock_t lock;
		struct list_head rq_lists[3];
		long: 64;
	};
	unsigned int cpu;
	short unsigned int index_hw[3];
	struct blk_mq_hw_ctx___6 *hctxs[3];
	long unsigned int rq_dispatched[2];
	long unsigned int rq_merged;
	long unsigned int rq_completed[2];
	struct request_queue___61 *queue;
	struct blk_mq_ctxs___5 *ctxs;
	struct kobject___248 kobj;
};

struct blk_mq_tags___5;

struct blk_mq_hw_ctx___6 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___61 *queue;
	struct blk_flush_queue___6 *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx___6 *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx___6 **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags___5 *tags;
	struct blk_mq_tags___5 *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	unsigned int rh_reserved_nr_expired;
	struct hlist_node cpuhp_dead;
	struct kobject___248 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___260 *debugfs_dir;
	struct dentry___260 *sched_debugfs_dir;
	struct list_head hctx_list;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___60;

struct blk_mq_alloc_data___6;

struct elevator_mq_ops___60 {
	int (*init_sched)(struct request_queue___61 *, struct elevator_type___60 *);
	void (*exit_sched)(struct elevator_queue___60 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___6 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___6 *, unsigned int);
	bool (*allow_merge)(struct request_queue___61 *, struct request___61 *, struct bio___129 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx___6 *, struct bio___129 *);
	int (*request_merge)(struct request_queue___61 *, struct request___61 **, struct bio___129 *);
	void (*request_merged)(struct request_queue___61 *, struct request___61 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___61 *, struct request___61 *, struct request___61 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data___6 *);
	void (*prepare_request)(struct request___61 *, struct bio___129 *);
	void (*finish_request)(struct request___61 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___6 *, struct list_head *, bool);
	struct request___61 * (*dispatch_request)(struct blk_mq_hw_ctx___6 *);
	bool (*has_work)(struct blk_mq_hw_ctx___6 *);
	void (*completed_request)(struct request___61 *, u64);
	void (*started_request)(struct request___61 *);
	void (*requeue_request)(struct request___61 *);
	struct request___61 * (*former_request)(struct request_queue___61 *, struct request___61 *);
	struct request___61 * (*next_request)(struct request_queue___61 *, struct request___61 *);
	void (*init_icq)(struct io_cq___64 *);
	void (*exit_icq)(struct io_cq___64 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___60;

struct elevator_type___60 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___60 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___60 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___213 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___60 {
	struct elevator_type___60 *type;
	void *elevator_data;
	struct kobject___248 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct blk_mq_alloc_data___6 {
	struct request_queue___61 *q;
	blk_mq_req_flags_t flags;
	unsigned int shallow_depth;
	unsigned int cmd_flags;
	struct blk_mq_ctx___6 *ctx;
	struct blk_mq_hw_ctx___6 *hctx;
};

struct elv_fs_entry___60 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___60 *, char *);
	ssize_t (*store)(struct elevator_queue___60 *, const char *, size_t);
};

struct rq_qos_ops___4;

struct rq_qos___4 {
	struct rq_qos_ops___4 *ops;
	struct request_queue___61 *q;
	enum rq_qos_id id;
	struct rq_qos___4 *next;
};

struct blk_mq_queue_data___6;

typedef blk_status_t queue_rq_fn___6(struct blk_mq_hw_ctx___6 *, const struct blk_mq_queue_data___6 *);

typedef void commit_rqs_fn___6(struct blk_mq_hw_ctx___6 *);

typedef bool get_budget_fn___6(struct blk_mq_hw_ctx___6 *);

typedef void put_budget_fn___6(struct blk_mq_hw_ctx___6 *);

typedef enum blk_eh_timer_return timeout_fn___6(struct request___61 *, bool);

typedef int poll_fn___6(struct blk_mq_hw_ctx___6 *);

typedef void complete_fn___6(struct request___61 *);

typedef int init_hctx_fn___6(struct blk_mq_hw_ctx___6 *, void *, unsigned int);

typedef void exit_hctx_fn___6(struct blk_mq_hw_ctx___6 *, unsigned int);

typedef int init_request_fn___6(struct blk_mq_tag_set___6 *, struct request___61 *, unsigned int, unsigned int);

typedef void exit_request_fn___6(struct blk_mq_tag_set___6 *, struct request___61 *, unsigned int);

typedef bool busy_fn___6(struct request_queue___61 *);

typedef int map_queues_fn___6(struct blk_mq_tag_set___6 *);

typedef void cleanup_rq_fn___6(struct request___61 *);

struct blk_mq_ops___6 {
	queue_rq_fn___6 *queue_rq;
	commit_rqs_fn___6 *commit_rqs;
	get_budget_fn___6 *get_budget;
	put_budget_fn___6 *put_budget;
	timeout_fn___6 *timeout;
	poll_fn___6 *poll;
	complete_fn___6 *complete;
	init_hctx_fn___6 *init_hctx;
	exit_hctx_fn___6 *exit_hctx;
	init_request_fn___6 *init_request;
	exit_request_fn___6 *exit_request;
	void (*initialize_rq_fn)(struct request___61 *);
	busy_fn___6 *busy;
	map_queues_fn___6 *map_queues;
	void (*show_rq)(struct seq_file___3 *, struct request___61 *);
	union {
		cleanup_rq_fn___6 *cleanup_rq;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide46;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct blk_stat_callback___6 {
	struct list_head list;
	struct timer_list timer;
	struct blk_rq_stat *cpu_stat;
	int (*bucket_fn)(const struct request___61 *);
	unsigned int buckets;
	struct blk_rq_stat *stat;
	void (*timer_fn)(struct blk_stat_callback___6 *);
	void *data;
	struct callback_head rcu;
};

struct rchan___7;

struct blk_trace___6 {
	int trace_state;
	struct rchan___7 *rchan;
	long unsigned int *sequence;
	unsigned char *msg_data;
	u16 act_mask;
	u64 start_lba;
	u64 end_lba;
	u32 pid;
	u32 dev;
	struct dentry___260 *dir;
	struct dentry___260 *dropped_file;
	struct dentry___260 *msg_file;
	struct list_head running_list;
	atomic_t dropped;
};

struct blk_flush_queue___6 {
	unsigned int flush_queue_delayed: 1;
	unsigned int flush_pending_idx: 1;
	unsigned int flush_running_idx: 1;
	long unsigned int flush_pending_since;
	struct list_head flush_queue[2];
	struct list_head flush_data_in_flight;
	struct request___61 *flush_rq;
	struct request___61 *orig_rq;
	spinlock_t mq_flush_lock;
};

struct blk_mq_tag_set___6 {
	struct blk_mq_queue_map map[6];
	unsigned int nr_maps;
	const struct blk_mq_ops___6 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	struct blk_mq_tags___5 **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef int (*key_restrict_link_func_t___253)(struct key___252 *, const struct key_type *, const union key_payload *, struct key___252 *);

struct key_restriction___252;

struct key___252 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___261 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key___6 index_key;
		struct {
			struct key_type___6 *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___252 *restrict_link;
};

struct key_restriction___252 {
	key_restrict_link_func_t___253 check;
	struct key___252 *key;
	struct key_type *keytype;
};

struct seq_operations___2 {
	void * (*start)(struct seq_file___3 *, loff_t *);
	void (*stop)(struct seq_file___3 *, void *);
	void * (*next)(struct seq_file___3 *, void *, loff_t *);
	int (*show)(struct seq_file___3 *, void *);
};

struct cgroup_namespace___198 {
	refcount_t count;
	struct ns_common___28 ns;
	struct user_namespace___213 *user_ns;
	struct ucounts___213 *ucounts;
	struct css_set___198 *root_cset;
};

struct ucounts___213 {
	struct hlist_node node;
	struct user_namespace___213 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___199;

struct bpf_map_ops___198 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___199 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___199 *, struct file___260 *);
	void (*map_free)(struct bpf_map___199 *);
	int (*map_get_next_key)(struct bpf_map___199 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___199 *);
	void * (*map_lookup_elem)(struct bpf_map___199 *, void *);
	int (*map_update_elem)(struct bpf_map___199 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___199 *, void *);
	int (*map_push_elem)(struct bpf_map___199 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___199 *, void *);
	int (*map_peek_elem)(struct bpf_map___199 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___199 *, struct file___260 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___199 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___199 *, void *, struct seq_file___3 *);
	int (*map_check_btf)(const struct bpf_map___199 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___199 {
	const struct bpf_map_ops___198 *ops;
	struct bpf_map___199 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___252 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___198;

typedef void (*kthread_work_func_t___198)(struct kthread_work___198 *);

struct kthread_worker___198;

struct kthread_work___198 {
	struct list_head node;
	kthread_work_func_t___198 func;
	struct kthread_worker___198 *worker;
	int canceling;
};

struct kthread_worker___198 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___261 *task;
	struct kthread_work___198 *current_work;
};

struct kthread_delayed_work___198 {
	struct kthread_work___198 work;
	struct timer_list timer;
};

struct psi_group___198 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___198 *poll_kworker;
	struct kthread_delayed_work___198 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___198 {
	struct kernfs_node___255 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_root___198;

struct cgroup_rstat_cpu___198;

struct cgroup___198 {
	struct cgroup_subsys_state___198 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___255 *kn;
	struct cgroup_file___198 procs_file;
	struct cgroup_file___198 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___198 *subsys[13];
	struct cgroup_root___198 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___198 *dom_cgrp;
	struct cgroup_rstat_cpu___198 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___34 bpf;
	atomic_t congestion_count;
	struct cgroup___198 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___198 psi;
	int ancestor_ids[0];
};

struct cftype___198;

struct cgroup_subsys___198 {
	struct cgroup_subsys_state___198 * (*css_alloc)(struct cgroup_subsys_state___198 *);
	int (*css_online)(struct cgroup_subsys_state___198 *);
	void (*css_offline)(struct cgroup_subsys_state___198 *);
	void (*css_released)(struct cgroup_subsys_state___198 *);
	void (*css_free)(struct cgroup_subsys_state___198 *);
	void (*css_reset)(struct cgroup_subsys_state___198 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___198 *, int);
	int (*css_extra_stat_show)(struct seq_file___3 *, struct cgroup_subsys_state___198 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___261 *);
	void (*cancel_fork)(struct task_struct___261 *);
	void (*fork)(struct task_struct___261 *);
	void (*exit)(struct task_struct___261 *);
	void (*free)(struct task_struct___261 *);
	void (*bind)(struct cgroup_subsys_state___198 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___198 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___198 *dfl_cftypes;
	struct cftype___198 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___198 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___198 *updated_children;
	struct cgroup___198 *updated_next;
};

struct cgroup_root___198 {
	struct kernfs_root___254 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___198 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___198 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___198 *ss;
	struct list_head node;
	struct kernfs_ops___254 *kf_ops;
	int (*open)(struct kernfs_open_file___254 *);
	void (*release)(struct kernfs_open_file___254 *);
	u64 (*read_u64)(struct cgroup_subsys_state___198 *, struct cftype___198 *);
	s64 (*read_s64)(struct cgroup_subsys_state___198 *, struct cftype___198 *);
	int (*seq_show)(struct seq_file___3 *, void *);
	void * (*seq_start)(struct seq_file___3 *, loff_t *);
	void * (*seq_next)(struct seq_file___3 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___3 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___198 *, struct cftype___198 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___198 *, struct cftype___198 *, s64);
	ssize_t (*write)(struct kernfs_open_file___254 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___254 *, struct poll_table_struct___161 *);
};

struct blkcg_policy_data___49;

struct blkcg___49 {
	struct cgroup_subsys_state___198 css;
	spinlock_t lock;
	struct xarray blkg_tree;
	struct blkcg_gq___49 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___49 *cpd[5];
	struct list_head all_blkcgs_node;
	struct list_head cgwb_list;
	refcount_t cgwb_refcnt;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct blkcg_policy_data___49 {
	struct blkcg___49 *blkcg;
	int plid;
};

struct blkg_policy_data___49 {
	struct blkcg_gq___49 *blkg;
	int plid;
};

struct rchan_buf___7 {
	void *start;
	void *data;
	size_t offset;
	size_t subbufs_produced;
	size_t subbufs_consumed;
	struct rchan___7 *chan;
	wait_queue_head_t read_wait;
	struct irq_work wakeup_work;
	struct dentry___260 *dentry;
	struct kref kref;
	struct page___261 **page_array;
	unsigned int page_count;
	unsigned int finalized;
	size_t *padding;
	size_t prev_padding;
	size_t bytes_consumed;
	size_t early_bytes;
	unsigned int cpu;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
};

struct rchan_callbacks___7;

struct rchan___7 {
	u32 version;
	size_t subbuf_size;
	size_t n_subbufs;
	size_t alloc_size;
	struct rchan_callbacks___7 *cb;
	struct kref kref;
	void *private_data;
	size_t last_toobig;
	struct rchan_buf___7 **buf;
	int is_global;
	struct list_head list;
	struct dentry___260 *parent;
	int has_base_filename;
	char base_filename[255];
};

struct rchan_callbacks___7 {
	int (*subbuf_start)(struct rchan_buf___7 *, void *, void *, size_t);
	void (*buf_mapped)(struct rchan_buf___7 *, struct file___260 *);
	void (*buf_unmapped)(struct rchan_buf___7 *, struct file___260 *);
	struct dentry___260 * (*create_buf_file)(const char *, struct dentry___260 *, umode_t, struct rchan_buf___7 *, int *);
	int (*remove_buf_file)(struct dentry___260 *);
};

struct blk_mq_tags___5 {
	unsigned int nr_tags;
	unsigned int nr_reserved_tags;
	atomic_t active_queues;
	struct sbitmap_queue bitmap_tags;
	struct sbitmap_queue breserved_tags;
	struct request___61 **rqs;
	struct request___61 **static_rqs;
	struct list_head page_list;
};

struct blk_mq_queue_data___6 {
	struct request___61 *rq;
	bool last;
	long unsigned int rh_reserved1;
};

struct blk_mq_ctxs___5 {
	struct kobject___248 kobj;
	struct blk_mq_ctx___6 *queue_ctx;
};

struct rq_qos_ops___4 {
	void (*throttle)(struct rq_qos___4 *, struct bio___129 *);
	void (*track)(struct rq_qos___4 *, struct request___61 *, struct bio___129 *);
	void (*issue)(struct rq_qos___4 *, struct request___61 *);
	void (*requeue)(struct rq_qos___4 *, struct request___61 *);
	void (*done)(struct rq_qos___4 *, struct request___61 *);
	void (*done_bio)(struct rq_qos___4 *, struct bio___129 *);
	void (*cleanup)(struct rq_qos___4 *, struct bio___129 *);
	void (*exit)(struct rq_qos___4 *);
};

struct queue_sysfs_entry {
	struct attribute attr;
	ssize_t (*show)(struct request_queue___61 *, char *);
	ssize_t (*store)(struct request_queue___61 *, const char *, size_t);
};

enum {
	REQ_FSEQ_PREFLUSH = 1,
	REQ_FSEQ_DATA = 2,
	REQ_FSEQ_POSTFLUSH = 4,
	REQ_FSEQ_DONE = 8,
	REQ_FSEQ_ACTIONS = 7,
	FLUSH_PENDING_TIMEOUT = 500,
};

enum blk_default_limits {
	BLK_MAX_SEGMENTS = 128,
	BLK_SAFE_MAX_SECTORS = 255,
	BLK_DEF_MAX_SECTORS = 2560,
	BLK_MAX_SEGMENT_SIZE = 65536,
	BLK_SEG_BOUNDARY_MASK = 4294967295,
};

enum {
	ICQ_EXITED = 4,
};

struct module___214;

struct file___261;

struct kiocb___261;

struct iov_iter___127;

struct vm_area_struct___262;

struct inode___261;

struct file_lock___261;

struct page___262;

struct file_operations___261 {
	struct module___214 *owner;
	loff_t (*llseek)(struct file___261 *, loff_t, int);
	ssize_t (*read)(struct file___261 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___261 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___261 *, struct iov_iter___127 *);
	ssize_t (*write_iter)(struct kiocb___261 *, struct iov_iter___127 *);
	int (*iopoll)(struct kiocb___261 *, bool);
	int (*iterate)(struct file___261 *, struct dir_context *);
	int (*iterate_shared)(struct file___261 *, struct dir_context *);
	__poll_t (*poll)(struct file___261 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___261 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___261 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___261 *, struct vm_area_struct___262 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___261 *, struct file___261 *);
	int (*flush)(struct file___261 *, fl_owner_t);
	int (*release)(struct inode___261 *, struct file___261 *);
	int (*fsync)(struct file___261 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___261 *, int);
	int (*lock)(struct file___261 *, int, struct file_lock___261 *);
	ssize_t (*sendpage)(struct file___261 *, struct page___262 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___261 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___261 *, int, struct file_lock___261 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___261 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___261 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___261 *, long int, struct file_lock___261 **, void **);
	long int (*fallocate)(struct file___261 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___261 *);
	ssize_t (*copy_file_range)(struct file___261 *, loff_t, struct file___261 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___261 *, loff_t, struct file___261 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___261 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___261 {
	u64 seqnum;
	struct vm_area_struct___262 *vmas[4];
};

struct page_frag___261 {
	struct page___262 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___261;

struct bio_list___130;

struct backing_dev_info___130;

struct io_context___65;

struct request_queue___62;

struct vm_struct___177;

struct task_struct___262 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___262 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___261 *mm;
	struct mm_struct___261 *active_mm;
	struct vmacache___261 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___262 *real_parent;
	struct task_struct___262 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___262 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___189 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___189 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___189 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___2 *ptracer_cred;
	const struct cred___2 *real_cred;
	const struct cred___2 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___262 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___130 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___130 *backing_dev_info;
	struct io_context___65 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___261 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___62 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___262 *oom_reaper_list;
	struct vm_struct___177 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___128 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct secondary_data___262 {
	void *stack;
	struct task_struct___262 *task;
	long int status;
};

typedef struct page___262 *pgtable_t___261;

struct address_space___260;

struct dev_pagemap___250;

struct page___262 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___260 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___262 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___261 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___261 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___250 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct vm_operations_struct___250;

struct vm_area_struct___262 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___262 *vm_next;
	struct vm_area_struct___262 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___261 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___250 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___261 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct rw_semaphore___262 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___262 *owner;
};

struct core_state___261;

struct mm_struct___261 {
	struct {
		struct vm_area_struct___262 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___261 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___262 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___261 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___262 *owner;
		struct user_namespace___3 *user_ns;
		struct file___261 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___261 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct bio___130;

struct bio_list___130 {
	struct bio___130 *head;
	struct bio___130 *tail;
};

struct bdi_writeback_congested___130;

struct bdi_writeback___130 {
	struct backing_dev_info___130 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___130 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___157 *memcg_css;
	struct cgroup_subsys_state___157 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___224;

struct dentry___261;

struct backing_dev_info___130 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___130 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___224 *dev;
	struct device___224 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___261 *debug_dir;
	struct dentry___261 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___65;

struct io_context___65 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___65 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

typedef blk_qc_t make_request_fn___61(struct request_queue___62 *, struct bio___130 *);

struct request___62;

typedef int dma_drain_needed_fn___61(struct request___62 *);

struct kset___248;

struct kobj_type___248;

struct kernfs_node___256;

struct kobject___249 {
	const char *name;
	struct list_head entry;
	struct kobject___249 *parent;
	struct kset___248 *kset;
	struct kobj_type___248 *ktype;
	struct kernfs_node___256 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___61;

struct bsg_class_device___61 {
	struct device___224 *class_dev;
	int minor;
	struct request_queue___62 *queue;
	const struct bsg_ops___61 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___130 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___130 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___61;

struct blk_mq_ops___7;

struct blk_mq_ctx___7;

struct blk_mq_hw_ctx___7;

struct blk_stat_callback___7;

struct blk_flush_queue___7;

struct blk_mq_tag_set___7;

struct request_queue___62 {
	struct list_head queue_head;
	struct request___62 *last_merge;
	struct elevator_queue___61 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___61 *make_request_fn;
	dma_drain_needed_fn___61 *dma_drain_needed;
	const struct blk_mq_ops___7 *mq_ops;
	struct blk_mq_ctx___7 *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___7 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___130 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___249 kobj;
	struct kobject___249 *mq_kobj;
	struct blk_integrity integrity;
	struct device___224 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback___7 *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue___7 *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	struct bsg_class_device___61 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set___7 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___130 bio_split;
	struct dentry___261 *debugfs_dir;
	struct dentry___261 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___177 {
	struct vm_struct___177 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___262 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct pglist_data___261;

struct lruvec___261 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___261 *pgdat;
};

struct zone___261 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___261 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___261 {
	struct zone___261 *zone;
	int zone_idx;
};

struct zonelist___261 {
	struct zoneref___261 _zonerefs[25];
};

struct pglist_data___261 {
	struct zone___261 node_zones[3];
	struct zonelist___261 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___262 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___262 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___261 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___261 {
	struct rw_semaphore___262 rwsem;
	struct notifier_block *head;
};

struct path___261 {
	struct vfsmount *mnt;
	struct dentry___261 *dentry;
};

struct file___261 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___261 f_path;
	struct inode___261 *f_inode;
	const struct file_operations___261 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___189 f_owner;
	const struct cred___2 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___260 *f_mapping;
	errseq_t f_wb_err;
};

struct kernfs_root___255;

struct kernfs_elem_dir___255 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___255 *root;
};

struct kernfs_syscall_ops___255;

struct kernfs_root___255 {
	struct kernfs_node___256 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___255 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___255 {
	struct kernfs_node___256 *target_kn;
};

struct kernfs_ops___255;

struct kernfs_elem_attr___255 {
	const struct kernfs_ops___255 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___256 *notify_next;
};

struct kernfs_node___256 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___256 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___255 dir;
		struct kernfs_elem_symlink___255 symlink;
		struct kernfs_elem_attr___255 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___255;

struct kernfs_ops___255 {
	int (*open)(struct kernfs_open_file___255 *);
	void (*release)(struct kernfs_open_file___255 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___255 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___255 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___255 *, struct vm_area_struct___262 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___255 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___255 {
	int (*remount_fs)(struct kernfs_root___255 *, int *, char *);
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___255 *);
	int (*mkdir)(struct kernfs_node___256 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___256 *);
	int (*rename)(struct kernfs_node___256 *, struct kernfs_node___256 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___256 *, struct kernfs_root___255 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___255 {
	struct kernfs_node___256 *kn;
	struct file___261 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___250 *vm_ops;
};

struct vm_fault___250;

struct vm_operations_struct___250 {
	void (*open)(struct vm_area_struct___262 *);
	void (*close)(struct vm_area_struct___262 *);
	int (*split)(struct vm_area_struct___262 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___262 *);
	vm_fault_t (*fault)(struct vm_fault___250 *);
	vm_fault_t (*huge_fault)(struct vm_fault___250 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___250 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___262 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___250 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___250 *);
	int (*access)(struct vm_area_struct___262 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___262 *);
	int (*set_policy)(struct vm_area_struct___262 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___262 *, long unsigned int);
	struct page___262 * (*find_special_page)(struct vm_area_struct___262 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___225;

struct attribute_group___226 {
	const char *name;
	umode_t (*is_visible)(struct kobject___249 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___249 *, struct bin_attribute___225 *, int);
	struct attribute **attrs;
	struct bin_attribute___225 **bin_attrs;
};

struct bin_attribute___225 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___261 *, struct kobject___249 *, struct bin_attribute___225 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___261 *, struct kobject___249 *, struct bin_attribute___225 *, char *, loff_t, size_t);
	int (*mmap)(struct file___261 *, struct kobject___249 *, struct bin_attribute___225 *, struct vm_area_struct___262 *);
};

struct sysfs_ops___248 {
	ssize_t (*show)(struct kobject___249 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___249 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___248;

struct kset___248 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___249 kobj;
	const struct kset_uevent_ops___248 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___248 {
	void (*release)(struct kobject___249 *);
	const struct sysfs_ops___248 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___24 * (*child_ns_type)(struct kobject___249 *);
	const void * (*namespace)(struct kobject___249 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___248 {
	int (* const filter)(struct kset___248 *, struct kobject___249 *);
	const char * (* const name)(struct kset___248 *, struct kobject___249 *);
	int (* const uevent)(struct kset___248 *, struct kobject___249 *, struct kobj_uevent_env *);
};

struct kobj_attribute___241 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___249 *, struct kobj_attribute___241 *, char *);
	ssize_t (*store)(struct kobject___249 *, struct kobj_attribute___241 *, const char *, size_t);
};

struct kernel_param___211;

struct kernel_param_ops___211 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___211 *);
	int (*get)(char *, const struct kernel_param___211 *);
	void (*free)(void *);
};

struct kparam_array___211;

struct kernel_param___211 {
	const char *name;
	struct module___214 *mod;
	const struct kernel_param_ops___211 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___211 *arr;
	};
};

struct kparam_array___211 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___211 *ops;
	void *elem;
};

struct module_kobject___211 {
	struct kobject___249 kobj;
	struct module___214 *mod;
	struct kobject___249 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___211 {
	struct module___214 *mod;
	struct latch_tree_node node;
};

struct module_layout___211 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___211 mtn;
};

struct module_attribute___211;

struct module___214 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___211 mkobj;
	struct module_attribute___211 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___249 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___211 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___211 core_layout;
	struct module_layout___211 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___211 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___211 *, struct module_kobject___211 *, char *);
	ssize_t (*store)(struct module_attribute___211 *, struct module_kobject___211 *, const char *, size_t);
	void (*setup)(struct module___214 *, const char *);
	int (*test)(struct module___214 *);
	void (*free)(struct module___214 *);
};

struct dentry_operations___260;

struct super_block___260;

struct dentry___261 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___261 *d_parent;
	struct qstr d_name;
	struct inode___261 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___260 *d_op;
	struct super_block___260 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___260;

struct address_space___260 {
	struct inode___261 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___262 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___260 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___260;

struct block_device___261;

struct inode___261 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___260 *i_op;
	struct super_block___260 *i_sb;
	struct address_space___260 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___262 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___130 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___261 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___260 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___261 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___260 {
	int (*d_revalidate)(struct dentry___261 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___261 *, unsigned int);
	int (*d_hash)(const struct dentry___261 *, struct qstr *);
	int (*d_compare)(const struct dentry___261 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___261 *);
	int (*d_init)(struct dentry___261 *);
	void (*d_release)(struct dentry___261 *);
	void (*d_prune)(struct dentry___261 *);
	void (*d_iput)(struct dentry___261 *, struct inode___261 *);
	char * (*d_dname)(struct dentry___261 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___261 *);
	int (*d_manage)(const struct path___261 *, bool);
	struct dentry___261 * (*d_real)(struct dentry___261 *, const struct inode___261 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___260;

struct mem_dqinfo___260 {
	struct quota_format_type___260 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___260;

struct quota_info___260 {
	unsigned int flags;
	struct rw_semaphore___262 dqio_sem;
	struct inode___261 *files[3];
	struct mem_dqinfo___260 info[3];
	const struct quota_format_ops___260 *ops[3];
};

struct rcuwait___260 {
	struct task_struct___262 *task;
};

struct percpu_rw_semaphore___260 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___262 rw_sem;
	struct rcuwait___260 writer;
	int readers_block;
};

struct sb_writers___260 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___260 rw_sem[3];
};

struct file_system_type___260;

struct super_operations___260;

struct dquot_operations___260;

struct quotactl_ops___260;

struct super_block___260 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___260 *s_type;
	const struct super_operations___260 *s_op;
	const struct dquot_operations___260 *dq_op;
	const struct quotactl_ops___260 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___261 *s_root;
	struct rw_semaphore___262 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___261 *s_bdev;
	struct backing_dev_info___130 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___260 s_dquot;
	struct sb_writers___260 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___260 *s_d_op;
	int cleancache_poolid;
	struct shrinker___112 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

typedef int (*dev_page_fault_t___250)(struct vm_area_struct___262 *, long unsigned int, const struct page___262 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___250)(struct page___262 *, void *);

struct dev_pagemap___250 {
	dev_page_fault_t___250 page_fault;
	dev_page_free_t___250 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___224 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___261 {
	struct task_struct___262 *task;
	struct core_thread___261 *next;
};

struct core_state___261 {
	atomic_t nr_threads;
	struct core_thread___261 dumper;
	struct completion startup;
};

struct vm_fault___250 {
	struct vm_area_struct___262 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___262 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___262 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___261 prealloc_pte;
};

struct io_cq___65 {
	struct request_queue___62 *q;
	struct io_context___65 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___6 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___261 {
	struct file___261 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___261 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___260 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___261 *ia_file;
};

struct dquot___260 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___260 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___260 {
	int qf_fmt_id;
	const struct quota_format_ops___260 *qf_ops;
	struct module___214 *qf_owner;
	struct quota_format_type___260 *qf_next;
};

struct quota_format_ops___260 {
	int (*check_quota_file)(struct super_block___260 *, int);
	int (*read_file_info)(struct super_block___260 *, int);
	int (*write_file_info)(struct super_block___260 *, int);
	int (*free_file_info)(struct super_block___260 *, int);
	int (*read_dqblk)(struct dquot___260 *);
	int (*commit_dqblk)(struct dquot___260 *);
	int (*release_dqblk)(struct dquot___260 *);
	int (*get_next_id)(struct super_block___260 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___260 {
	int (*write_dquot)(struct dquot___260 *);
	struct dquot___260 * (*alloc_dquot)(struct super_block___260 *, int);
	void (*destroy_dquot)(struct dquot___260 *);
	int (*acquire_dquot)(struct dquot___260 *);
	int (*release_dquot)(struct dquot___260 *);
	int (*mark_dirty)(struct dquot___260 *);
	int (*write_info)(struct super_block___260 *, int);
	qsize_t * (*get_reserved_space)(struct inode___261 *);
	int (*get_projid)(struct inode___261 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___261 *, qsize_t *);
	int (*get_next_id)(struct super_block___260 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___260 {
	int (*quota_on)(struct super_block___260 *, int, int, const struct path___261 *);
	int (*quota_off)(struct super_block___260 *, int);
	int (*quota_enable)(struct super_block___260 *, unsigned int);
	int (*quota_disable)(struct super_block___260 *, unsigned int);
	int (*quota_sync)(struct super_block___260 *, int);
	int (*set_info)(struct super_block___260 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___260 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___260 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___260 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___260 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___260 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___260 {
	int (*writepage)(struct page___262 *, struct writeback_control___3 *);
	int (*readpage)(struct file___261 *, struct page___262 *);
	int (*writepages)(struct address_space___260 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___262 *);
	int (*readpages)(struct file___261 *, struct address_space___260 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___261 *, struct address_space___260 *, loff_t, unsigned int, unsigned int, struct page___262 **, void **);
	int (*write_end)(struct file___261 *, struct address_space___260 *, loff_t, unsigned int, unsigned int, struct page___262 *, void *);
	sector_t (*bmap)(struct address_space___260 *, sector_t);
	void (*invalidatepage)(struct page___262 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___262 *, gfp_t);
	void (*freepage)(struct page___262 *);
	ssize_t (*direct_IO)(struct kiocb___261 *, struct iov_iter___127 *);
	int (*migratepage)(struct address_space___260 *, struct page___262 *, struct page___262 *, enum migrate_mode);
	bool (*isolate_page)(struct page___262 *, isolate_mode_t);
	void (*putback_page)(struct page___262 *);
	int (*launder_page)(struct page___262 *);
	int (*is_partially_uptodate)(struct page___262 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___262 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___260 *, struct page___262 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___261 *, sector_t *);
	void (*swap_deactivate)(struct file___261 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio_vec___130;

struct iov_iter___127 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___130 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct hd_struct___62;

struct gendisk___62;

struct block_device___261 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___261 *bd_inode;
	struct super_block___260 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___261 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___62 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___62 *bd_disk;
	struct request_queue___62 *bd_queue;
	struct backing_dev_info___130 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___224 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___224 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___224;

struct bus_type___224;

struct device_driver___224;

struct dev_pm_domain___224;

struct fwnode_handle___159;

struct class___224;

struct device___224 {
	struct device___224 *parent;
	struct device_private *p;
	struct kobject___249 kobj;
	const char *init_name;
	const struct device_type___224 *type;
	struct mutex mutex;
	struct bus_type___224 *bus;
	struct device_driver___224 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___224 power;
	struct dev_pm_domain___224 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___159 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___224 *class;
	const struct attribute_group___226 **groups;
	void (*release)(struct device___224 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___62 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___224 __dev;
	struct kobject___249 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___62;

struct block_device_operations___62;

struct gendisk___62 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___62 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___62 *part_tbl;
	struct hd_struct___62 part0;
	const struct block_device_operations___62 *fops;
	struct request_queue___62 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___262 lookup_sem;
	struct kobject___249 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___249 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___260 {
	struct dentry___261 * (*lookup)(struct inode___261 *, struct dentry___261 *, unsigned int);
	const char * (*get_link)(struct dentry___261 *, struct inode___261 *, struct delayed_call *);
	int (*permission)(struct inode___261 *, int);
	struct posix_acl * (*get_acl)(struct inode___261 *, int);
	int (*readlink)(struct dentry___261 *, char *, int);
	int (*create)(struct inode___261 *, struct dentry___261 *, umode_t, bool);
	int (*link)(struct dentry___261 *, struct inode___261 *, struct dentry___261 *);
	int (*unlink)(struct inode___261 *, struct dentry___261 *);
	int (*symlink)(struct inode___261 *, struct dentry___261 *, const char *);
	int (*mkdir)(struct inode___261 *, struct dentry___261 *, umode_t);
	int (*rmdir)(struct inode___261 *, struct dentry___261 *);
	int (*mknod)(struct inode___261 *, struct dentry___261 *, umode_t, dev_t);
	int (*rename)(struct inode___261 *, struct dentry___261 *, struct inode___261 *, struct dentry___261 *, unsigned int);
	int (*setattr)(struct dentry___261 *, struct iattr___260 *);
	int (*getattr)(const struct path___261 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___261 *, char *, size_t);
	int (*fiemap)(struct inode___261 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___261 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___261 *, struct dentry___261 *, struct file___261 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___261 *, struct dentry___261 *, umode_t);
	int (*set_acl)(struct inode___261 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___260 {
	void (*fl_copy_lock)(struct file_lock___261 *, struct file_lock___261 *);
	void (*fl_release_private)(struct file_lock___261 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___260;

struct lock_manager_operations___260;

struct file_lock___261 {
	struct file_lock___261 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___261 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___260 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___260 *fl_ops;
	const struct lock_manager_operations___260 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___260 {
	int (*lm_compare_owner)(struct file_lock___261 *, struct file_lock___261 *);
	long unsigned int (*lm_owner_key)(struct file_lock___261 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___261 *);
	int (*lm_grant)(struct file_lock___261 *, int);
	bool (*lm_break)(struct file_lock___261 *);
	int (*lm_change)(struct file_lock___261 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___261 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___260 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___260 *fa_next;
	struct file___261 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___260 {
	const char *name;
	int fs_flags;
	struct dentry___261 * (*mount)(struct file_system_type___260 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___260 *);
	struct module___214 *owner;
	struct file_system_type___260 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___260 {
	struct inode___261 * (*alloc_inode)(struct super_block___260 *);
	void (*destroy_inode)(struct inode___261 *);
	void (*dirty_inode)(struct inode___261 *, int);
	int (*write_inode)(struct inode___261 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___261 *);
	void (*evict_inode)(struct inode___261 *);
	void (*put_super)(struct super_block___260 *);
	int (*sync_fs)(struct super_block___260 *, int);
	int (*freeze_super)(struct super_block___260 *);
	int (*freeze_fs)(struct super_block___260 *);
	int (*thaw_super)(struct super_block___260 *);
	int (*unfreeze_fs)(struct super_block___260 *);
	int (*statfs)(struct dentry___261 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___260 *, int *, char *);
	void (*umount_begin)(struct super_block___260 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___261 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___261 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___261 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___261 *);
	ssize_t (*quota_read)(struct super_block___260 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___260 *, int, const char *, size_t, loff_t);
	struct dquot___260 ** (*get_dquots)(struct inode___261 *);
	int (*bdev_try_to_free_page)(struct super_block___260 *, struct page___262 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___260 *, struct shrink_control___112 *);
	long int (*free_cached_objects)(struct super_block___260 *, struct shrink_control___112 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___130(struct bio___130 *);

struct bio_vec___130 {
	struct page___262 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___130;

struct bio___130 {
	struct bio___130 *bi_next;
	struct gendisk___62 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___130 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___130 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___130 *bi_io_vec;
	struct bio_set___130 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___130 bi_inline_vecs[0];
};

typedef void compound_page_dtor___250(struct page___262 *);

struct bio_integrity_payload___130 {
	struct bio___130 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___130 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___130 bip_inline_vecs[0];
};

struct dev_pm_ops___224;

struct device_type___224 {
	const char *name;
	const struct attribute_group___226 **groups;
	int (*uevent)(struct device___224 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___224 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___224 *);
	const struct dev_pm_ops___224 *pm;
};

struct class___224 {
	const char *name;
	struct module___214 *owner;
	const struct attribute_group___226 **class_groups;
	const struct attribute_group___226 **dev_groups;
	struct kobject___249 *dev_kobj;
	int (*dev_uevent)(struct device___224 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___224 *, umode_t *);
	void (*class_release)(struct class___224 *);
	void (*dev_release)(struct device___224 *);
	int (*shutdown_pre)(struct device___224 *);
	const struct kobj_ns_type_operations___24 *ns_type;
	const void * (*namespace)(struct device___224 *);
	const struct dev_pm_ops___224 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dev_pm_ops___224 {
	int (*prepare)(struct device___224 *);
	void (*complete)(struct device___224 *);
	int (*suspend)(struct device___224 *);
	int (*resume)(struct device___224 *);
	int (*freeze)(struct device___224 *);
	int (*thaw)(struct device___224 *);
	int (*poweroff)(struct device___224 *);
	int (*restore)(struct device___224 *);
	int (*suspend_late)(struct device___224 *);
	int (*resume_early)(struct device___224 *);
	int (*freeze_late)(struct device___224 *);
	int (*thaw_early)(struct device___224 *);
	int (*poweroff_late)(struct device___224 *);
	int (*restore_early)(struct device___224 *);
	int (*suspend_noirq)(struct device___224 *);
	int (*resume_noirq)(struct device___224 *);
	int (*freeze_noirq)(struct device___224 *);
	int (*thaw_noirq)(struct device___224 *);
	int (*poweroff_noirq)(struct device___224 *);
	int (*restore_noirq)(struct device___224 *);
	int (*runtime_suspend)(struct device___224 *);
	int (*runtime_resume)(struct device___224 *);
	int (*runtime_idle)(struct device___224 *);
};

struct dev_pm_domain___224 {
	struct dev_pm_ops___224 ops;
	void (*detach)(struct device___224 *, bool);
	int (*activate)(struct device___224 *);
	void (*sync)(struct device___224 *);
	void (*dismiss)(struct device___224 *);
};

struct bus_type___224 {
	const char *name;
	const char *dev_name;
	struct device___224 *dev_root;
	const struct attribute_group___226 **bus_groups;
	const struct attribute_group___226 **dev_groups;
	const struct attribute_group___226 **drv_groups;
	int (*match)(struct device___224 *, struct device_driver___224 *);
	int (*uevent)(struct device___224 *, struct kobj_uevent_env *);
	int (*probe)(struct device___224 *);
	int (*remove)(struct device___224 *);
	void (*shutdown)(struct device___224 *);
	int (*online)(struct device___224 *);
	int (*offline)(struct device___224 *);
	int (*suspend)(struct device___224 *, pm_message_t);
	int (*resume)(struct device___224 *);
	int (*num_vf)(struct device___224 *);
	int (*dma_configure)(struct device___224 *);
	const struct dev_pm_ops___224 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___224 {
	const char *name;
	struct bus_type___224 *bus;
	struct module___214 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___224 *);
	int (*remove)(struct device___224 *);
	void (*shutdown)(struct device___224 *);
	int (*suspend)(struct device___224 *, pm_message_t);
	int (*resume)(struct device___224 *);
	const struct attribute_group___226 **groups;
	const struct dev_pm_ops___224 *pm;
	void (*coredump)(struct device___224 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct fwnode_operations___159;

struct fwnode_handle___159 {
	struct fwnode_handle___159 *secondary;
	const struct fwnode_operations___159 *ops;
};

struct disk_part_tbl___62 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___62 *last_lookup;
	struct hd_struct___62 *part[0];
};

struct block_device_operations___62 {
	int (*open)(struct block_device___261 *, fmode_t);
	void (*release)(struct gendisk___62 *, fmode_t);
	int (*rw_page)(struct block_device___261 *, sector_t, struct page___262 *, unsigned int);
	int (*ioctl)(struct block_device___261 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___261 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___62 *, unsigned int);
	int (*media_changed)(struct gendisk___62 *);
	void (*unlock_native_capacity)(struct gendisk___62 *);
	int (*revalidate_disk)(struct gendisk___62 *);
	int (*getgeo)(struct block_device___261 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___261 *, long unsigned int);
	int (*report_zones)(struct gendisk___62 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___214 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bdi_writeback_congested___130 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___130 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bsg_ops___61 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___62 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___62 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___62 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___61(struct request___62 *, blk_status_t);

struct request___62 {
	struct request_queue___62 *q;
	struct blk_mq_ctx___7 *mq_ctx;
	struct blk_mq_hw_ctx___7 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___130 *bio;
	struct bio___130 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___130 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___65 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___61 *saved_end_io;
		} flush;
	};
	struct gendisk___62 *rq_disk;
	struct hd_struct___62 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___61 *end_io;
	void *end_io_data;
	struct request___62 *next_rq;
};

struct fwnode_reference_args___159;

struct fwnode_endpoint___159;

struct fwnode_operations___159 {
	struct fwnode_handle___159 * (*get)(struct fwnode_handle___159 *);
	void (*put)(struct fwnode_handle___159 *);
	bool (*device_is_available)(const struct fwnode_handle___159 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___159 *, const struct device___224 *);
	bool (*property_present)(const struct fwnode_handle___159 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___159 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___159 *, const char *, const char **, size_t);
	struct fwnode_handle___159 * (*get_parent)(const struct fwnode_handle___159 *);
	struct fwnode_handle___159 * (*get_next_child_node)(const struct fwnode_handle___159 *, struct fwnode_handle___159 *);
	struct fwnode_handle___159 * (*get_named_child_node)(const struct fwnode_handle___159 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___159 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___159 *);
	struct fwnode_handle___159 * (*graph_get_next_endpoint)(const struct fwnode_handle___159 *, struct fwnode_handle___159 *);
	struct fwnode_handle___159 * (*graph_get_remote_endpoint)(const struct fwnode_handle___159 *);
	struct fwnode_handle___159 * (*graph_get_port_parent)(struct fwnode_handle___159 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___159 *, struct fwnode_endpoint___159 *);
};

struct fwnode_endpoint___159 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___159 *local_fwnode;
};

struct fwnode_reference_args___159 {
	struct fwnode_handle___159 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct blk_mq_ctxs___6;

struct blk_mq_ctx___7 {
	struct {
		spinlock_t lock;
		struct list_head rq_lists[3];
		long: 64;
	};
	unsigned int cpu;
	short unsigned int index_hw[3];
	struct blk_mq_hw_ctx___7 *hctxs[3];
	long unsigned int rq_dispatched[2];
	long unsigned int rq_merged;
	long unsigned int rq_completed[2];
	struct request_queue___62 *queue;
	struct blk_mq_ctxs___6 *ctxs;
	struct kobject___249 kobj;
};

struct blk_mq_tags___6;

struct blk_mq_hw_ctx___7 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___62 *queue;
	struct blk_flush_queue___7 *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx___7 *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx___7 **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags___6 *tags;
	struct blk_mq_tags___6 *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	unsigned int rh_reserved_nr_expired;
	struct hlist_node cpuhp_dead;
	struct kobject___249 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___261 *debugfs_dir;
	struct dentry___261 *sched_debugfs_dir;
	struct list_head hctx_list;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___61;

struct blk_mq_alloc_data___7;

struct elevator_mq_ops___61 {
	int (*init_sched)(struct request_queue___62 *, struct elevator_type___61 *);
	void (*exit_sched)(struct elevator_queue___61 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___7 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___7 *, unsigned int);
	bool (*allow_merge)(struct request_queue___62 *, struct request___62 *, struct bio___130 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx___7 *, struct bio___130 *);
	int (*request_merge)(struct request_queue___62 *, struct request___62 **, struct bio___130 *);
	void (*request_merged)(struct request_queue___62 *, struct request___62 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___62 *, struct request___62 *, struct request___62 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data___7 *);
	void (*prepare_request)(struct request___62 *, struct bio___130 *);
	void (*finish_request)(struct request___62 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___7 *, struct list_head *, bool);
	struct request___62 * (*dispatch_request)(struct blk_mq_hw_ctx___7 *);
	bool (*has_work)(struct blk_mq_hw_ctx___7 *);
	void (*completed_request)(struct request___62 *, u64);
	void (*started_request)(struct request___62 *);
	void (*requeue_request)(struct request___62 *);
	struct request___62 * (*former_request)(struct request_queue___62 *, struct request___62 *);
	struct request___62 * (*next_request)(struct request_queue___62 *, struct request___62 *);
	void (*init_icq)(struct io_cq___65 *);
	void (*exit_icq)(struct io_cq___65 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx___7 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___61;

struct elevator_type___61 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___61 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___61 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___214 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___61 {
	struct elevator_type___61 *type;
	void *elevator_data;
	struct kobject___249 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct blk_mq_alloc_data___7 {
	struct request_queue___62 *q;
	blk_mq_req_flags_t flags;
	unsigned int shallow_depth;
	unsigned int cmd_flags;
	struct blk_mq_ctx___7 *ctx;
	struct blk_mq_hw_ctx___7 *hctx;
};

struct elv_fs_entry___61 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___61 *, char *);
	ssize_t (*store)(struct elevator_queue___61 *, const char *, size_t);
};

struct blk_mq_queue_data___7;

typedef blk_status_t queue_rq_fn___7(struct blk_mq_hw_ctx___7 *, const struct blk_mq_queue_data___7 *);

typedef void commit_rqs_fn___7(struct blk_mq_hw_ctx___7 *);

typedef bool get_budget_fn___7(struct blk_mq_hw_ctx___7 *);

typedef void put_budget_fn___7(struct blk_mq_hw_ctx___7 *);

typedef enum blk_eh_timer_return timeout_fn___7(struct request___62 *, bool);

typedef int poll_fn___7(struct blk_mq_hw_ctx___7 *);

typedef void complete_fn___7(struct request___62 *);

typedef int init_hctx_fn___7(struct blk_mq_hw_ctx___7 *, void *, unsigned int);

typedef void exit_hctx_fn___7(struct blk_mq_hw_ctx___7 *, unsigned int);

typedef int init_request_fn___7(struct blk_mq_tag_set___7 *, struct request___62 *, unsigned int, unsigned int);

typedef void exit_request_fn___7(struct blk_mq_tag_set___7 *, struct request___62 *, unsigned int);

typedef bool busy_fn___7(struct request_queue___62 *);

typedef int map_queues_fn___7(struct blk_mq_tag_set___7 *);

typedef void cleanup_rq_fn___7(struct request___62 *);

struct blk_mq_ops___7 {
	queue_rq_fn___7 *queue_rq;
	commit_rqs_fn___7 *commit_rqs;
	get_budget_fn___7 *get_budget;
	put_budget_fn___7 *put_budget;
	timeout_fn___7 *timeout;
	poll_fn___7 *poll;
	complete_fn___7 *complete;
	init_hctx_fn___7 *init_hctx;
	exit_hctx_fn___7 *exit_hctx;
	init_request_fn___7 *init_request;
	exit_request_fn___7 *exit_request;
	void (*initialize_rq_fn)(struct request___62 *);
	busy_fn___7 *busy;
	map_queues_fn___7 *map_queues;
	void (*show_rq)(struct seq_file___9 *, struct request___62 *);
	union {
		cleanup_rq_fn___7 *cleanup_rq;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide46;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct blk_stat_callback___7 {
	struct list_head list;
	struct timer_list timer;
	struct blk_rq_stat *cpu_stat;
	int (*bucket_fn)(const struct request___62 *);
	unsigned int buckets;
	struct blk_rq_stat *stat;
	void (*timer_fn)(struct blk_stat_callback___7 *);
	void *data;
	struct callback_head rcu;
};

struct blk_flush_queue___7 {
	unsigned int flush_queue_delayed: 1;
	unsigned int flush_pending_idx: 1;
	unsigned int flush_running_idx: 1;
	long unsigned int flush_pending_since;
	struct list_head flush_queue[2];
	struct list_head flush_data_in_flight;
	struct request___62 *flush_rq;
	struct request___62 *orig_rq;
	spinlock_t mq_flush_lock;
};

struct blk_mq_tag_set___7 {
	struct blk_mq_queue_map map[6];
	unsigned int nr_maps;
	const struct blk_mq_ops___7 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	struct blk_mq_tags___6 **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct rq_map_data___2 {
	struct page___262 **pages;
	int page_order;
	int nr_entries;
	long unsigned int offset;
	int null_mapped;
	int from_user;
};

struct blk_mq_tags___6 {
	unsigned int nr_tags;
	unsigned int nr_reserved_tags;
	atomic_t active_queues;
	struct sbitmap_queue bitmap_tags;
	struct sbitmap_queue breserved_tags;
	struct request___62 **rqs;
	struct request___62 **static_rqs;
	struct list_head page_list;
};

struct blk_mq_queue_data___7 {
	struct request___62 *rq;
	bool last;
	long unsigned int rh_reserved1;
};

struct blk_mq_ctxs___6 {
	struct kobject___249 kobj;
	struct blk_mq_ctx___7 *queue_ctx;
};

struct module___215;

struct file___262;

struct kiocb___262;

struct iov_iter___128;

struct poll_table_struct___162;

struct vm_area_struct___263;

struct inode___262;

struct file_lock___262;

struct page___263;

struct seq_file___233;

struct file_operations___262 {
	struct module___215 *owner;
	loff_t (*llseek)(struct file___262 *, loff_t, int);
	ssize_t (*read)(struct file___262 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___262 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___262 *, struct iov_iter___128 *);
	ssize_t (*write_iter)(struct kiocb___262 *, struct iov_iter___128 *);
	int (*iopoll)(struct kiocb___262 *, bool);
	int (*iterate)(struct file___262 *, struct dir_context *);
	int (*iterate_shared)(struct file___262 *, struct dir_context *);
	__poll_t (*poll)(struct file___262 *, struct poll_table_struct___162 *);
	long int (*unlocked_ioctl)(struct file___262 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___262 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___262 *, struct vm_area_struct___263 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___262 *, struct file___262 *);
	int (*flush)(struct file___262 *, fl_owner_t);
	int (*release)(struct inode___262 *, struct file___262 *);
	int (*fsync)(struct file___262 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___262 *, int);
	int (*lock)(struct file___262 *, int, struct file_lock___262 *);
	ssize_t (*sendpage)(struct file___262 *, struct page___263 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___262 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___262 *, int, struct file_lock___262 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___262 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___262 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___262 *, long int, struct file_lock___262 **, void **);
	long int (*fallocate)(struct file___262 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___233 *, struct file___262 *);
	ssize_t (*copy_file_range)(struct file___262 *, loff_t, struct file___262 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___262 *, loff_t, struct file___262 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___262 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___262 {
	u64 seqnum;
	struct vm_area_struct___263 *vmas[4];
};

struct page_frag___262 {
	struct page___263 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___262;

struct pid___190;

struct cred___253;

struct nsproxy___234;

struct signal_struct___214;

struct bio_list___131;

struct backing_dev_info___131;

struct io_context___66;

struct css_set___199;

struct request_queue___63;

struct vm_struct___178;

struct task_struct___263 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___263 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___262 *mm;
	struct mm_struct___262 *active_mm;
	struct vmacache___262 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___263 *real_parent;
	struct task_struct___263 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___263 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___190 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___190 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___190 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___253 *ptracer_cred;
	const struct cred___253 *real_cred;
	const struct cred___253 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___234 *nsproxy;
	struct signal_struct___214 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___263 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___131 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___131 *backing_dev_info;
	struct io_context___66 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___199 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___262 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___63 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___263 *oom_reaper_list;
	struct vm_struct___178 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___128 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rw_semaphore___263 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___263 *owner;
};

struct key___253;

struct ucounts___214;

struct user_namespace___214 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___214 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___28 ns;
	long unsigned int flags;
	struct key___253 *persistent_keyring_register;
	struct rw_semaphore___263 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___214 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___263 *pgtable_t___262;

struct address_space___261;

struct dev_pagemap___251;

struct page___263 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___261 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___263 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___262 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___262 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___251 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___262;

struct lruvec___262 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___262 *pgdat;
};

struct zone___262 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___262 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___262 {
	struct zone___262 *zone;
	int zone_idx;
};

struct zonelist___262 {
	struct zoneref___262 _zonerefs[25];
};

struct pglist_data___262 {
	struct zone___262 node_zones[3];
	struct zonelist___262 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___263 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___263 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___262 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___263 {
	void *stack;
	struct task_struct___263 *task;
	long int status;
};

struct blocking_notifier_head___262 {
	struct rw_semaphore___263 rwsem;
	struct notifier_block *head;
};

struct dentry___262;

struct path___262 {
	struct vfsmount *mnt;
	struct dentry___262 *dentry;
};

struct fown_struct___190 {
	rwlock_t lock;
	struct pid___190 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___262 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___262 f_path;
	struct inode___262 *f_inode;
	const struct file_operations___262 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___190 f_owner;
	const struct cred___253 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___261 *f_mapping;
	errseq_t f_wb_err;
};

struct user_struct___253;

struct cred___253 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___253 *session_keyring;
	struct key___253 *process_keyring;
	struct key___253 *thread_keyring;
	struct key___253 *request_key_auth;
	void *security;
	struct user_struct___253 *user;
	struct user_namespace___214 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___256;

struct kernfs_elem_dir___256 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___256 *root;
};

struct kernfs_node___257;

struct kernfs_syscall_ops___256;

struct kernfs_root___256 {
	struct kernfs_node___257 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___256 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___256 {
	struct kernfs_node___257 *target_kn;
};

struct kernfs_ops___256;

struct kernfs_elem_attr___256 {
	const struct kernfs_ops___256 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___257 *notify_next;
};

struct kernfs_node___257 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___257 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___256 dir;
		struct kernfs_elem_symlink___256 symlink;
		struct kernfs_elem_attr___256 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___256;

struct kernfs_ops___256 {
	int (*open)(struct kernfs_open_file___256 *);
	void (*release)(struct kernfs_open_file___256 *);
	int (*seq_show)(struct seq_file___233 *, void *);
	void * (*seq_start)(struct seq_file___233 *, loff_t *);
	void * (*seq_next)(struct seq_file___233 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___233 *, void *);
	ssize_t (*read)(struct kernfs_open_file___256 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___256 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___256 *, struct vm_area_struct___263 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___256 *, struct poll_table_struct___162 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___256 {
	int (*remount_fs)(struct kernfs_root___256 *, int *, char *);
	int (*show_options)(struct seq_file___233 *, struct kernfs_root___256 *);
	int (*mkdir)(struct kernfs_node___257 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___257 *);
	int (*rename)(struct kernfs_node___257 *, struct kernfs_node___257 *, const char *);
	int (*show_path)(struct seq_file___233 *, struct kernfs_node___257 *, struct kernfs_root___256 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___231;

struct seq_file___233 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___231 *op;
	int poll_event;
	const struct file___262 *file;
	void *private;
};

struct vm_operations_struct___251;

struct kernfs_open_file___256 {
	struct kernfs_node___257 *kn;
	struct file___262 *file;
	struct seq_file___233 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___251 *vm_ops;
};

struct vm_fault___251;

struct vm_operations_struct___251 {
	void (*open)(struct vm_area_struct___263 *);
	void (*close)(struct vm_area_struct___263 *);
	int (*split)(struct vm_area_struct___263 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___263 *);
	vm_fault_t (*fault)(struct vm_fault___251 *);
	vm_fault_t (*huge_fault)(struct vm_fault___251 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___251 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___263 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___251 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___251 *);
	int (*access)(struct vm_area_struct___263 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___263 *);
	int (*set_policy)(struct vm_area_struct___263 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___263 *, long unsigned int);
	struct page___263 * (*find_special_page)(struct vm_area_struct___263 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___164)(struct file___262 *, wait_queue_head_t *, struct poll_table_struct___162 *);

struct poll_table_struct___162 {
	poll_queue_proc___164 _qproc;
	__poll_t _key;
};

struct vm_area_struct___263 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___263 *vm_next;
	struct vm_area_struct___263 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___262 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___251 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___262 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___250;

struct bin_attribute___226;

struct attribute_group___227 {
	const char *name;
	umode_t (*is_visible)(struct kobject___250 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___250 *, struct bin_attribute___226 *, int);
	struct attribute **attrs;
	struct bin_attribute___226 **bin_attrs;
};

struct kset___249;

struct kobj_type___249;

struct kobject___250 {
	const char *name;
	struct list_head entry;
	struct kobject___250 *parent;
	struct kset___249 *kset;
	struct kobj_type___249 *ktype;
	struct kernfs_node___257 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___226 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___262 *, struct kobject___250 *, struct bin_attribute___226 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___262 *, struct kobject___250 *, struct bin_attribute___226 *, char *, loff_t, size_t);
	int (*mmap)(struct file___262 *, struct kobject___250 *, struct bin_attribute___226 *, struct vm_area_struct___263 *);
};

struct sysfs_ops___249 {
	ssize_t (*show)(struct kobject___250 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___250 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___249;

struct kset___249 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___250 kobj;
	const struct kset_uevent_ops___249 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___249 {
	void (*release)(struct kobject___250 *);
	const struct sysfs_ops___249 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___24 * (*child_ns_type)(struct kobject___250 *);
	const void * (*namespace)(struct kobject___250 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___249 {
	int (* const filter)(struct kset___249 *, struct kobject___250 *);
	const char * (* const name)(struct kset___249 *, struct kobject___250 *);
	int (* const uevent)(struct kset___249 *, struct kobject___250 *, struct kobj_uevent_env *);
};

struct kobj_attribute___242 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___250 *, struct kobj_attribute___242 *, char *);
	ssize_t (*store)(struct kobject___250 *, struct kobj_attribute___242 *, const char *, size_t);
};

struct kernel_param___212;

struct kernel_param_ops___212 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___212 *);
	int (*get)(char *, const struct kernel_param___212 *);
	void (*free)(void *);
};

struct kparam_array___212;

struct kernel_param___212 {
	const char *name;
	struct module___215 *mod;
	const struct kernel_param_ops___212 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___212 *arr;
	};
};

struct kparam_array___212 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___212 *ops;
	void *elem;
};

struct module_kobject___212 {
	struct kobject___250 kobj;
	struct module___215 *mod;
	struct kobject___250 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___212 {
	struct module___215 *mod;
	struct latch_tree_node node;
};

struct module_layout___212 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___212 mtn;
};

struct module_attribute___212;

struct module___215 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___212 mkobj;
	struct module_attribute___212 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___250 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___212 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___212 core_layout;
	struct module_layout___212 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___212 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___212 *, struct module_kobject___212 *, char *);
	ssize_t (*store)(struct module_attribute___212 *, struct module_kobject___212 *, const char *, size_t);
	void (*setup)(struct module___215 *, const char *);
	int (*test)(struct module___215 *);
	void (*free)(struct module___215 *);
};

struct dentry_operations___261;

struct super_block___261;

struct dentry___262 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___262 *d_parent;
	struct qstr d_name;
	struct inode___262 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___261 *d_op;
	struct super_block___261 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___261;

struct address_space___261 {
	struct inode___262 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___263 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___261 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___261;

struct bdi_writeback___131;

struct block_device___262;

struct inode___262 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___261 *i_op;
	struct super_block___261 *i_sb;
	struct address_space___261 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___263 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___131 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___262 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___261 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___262 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___261 {
	int (*d_revalidate)(struct dentry___262 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___262 *, unsigned int);
	int (*d_hash)(const struct dentry___262 *, struct qstr *);
	int (*d_compare)(const struct dentry___262 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___262 *);
	int (*d_init)(struct dentry___262 *);
	void (*d_release)(struct dentry___262 *);
	void (*d_prune)(struct dentry___262 *);
	void (*d_iput)(struct dentry___262 *, struct inode___262 *);
	char * (*d_dname)(struct dentry___262 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___262 *);
	int (*d_manage)(const struct path___262 *, bool);
	struct dentry___262 * (*d_real)(struct dentry___262 *, const struct inode___262 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___261;

struct mem_dqinfo___261 {
	struct quota_format_type___261 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___261;

struct quota_info___261 {
	unsigned int flags;
	struct rw_semaphore___263 dqio_sem;
	struct inode___262 *files[3];
	struct mem_dqinfo___261 info[3];
	const struct quota_format_ops___261 *ops[3];
};

struct rcuwait___261 {
	struct task_struct___263 *task;
};

struct percpu_rw_semaphore___261 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___263 rw_sem;
	struct rcuwait___261 writer;
	int readers_block;
};

struct sb_writers___261 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___261 rw_sem[3];
};

struct file_system_type___261;

struct super_operations___261;

struct dquot_operations___261;

struct quotactl_ops___261;

struct super_block___261 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___261 *s_type;
	const struct super_operations___261 *s_op;
	const struct dquot_operations___261 *dq_op;
	const struct quotactl_ops___261 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___262 *s_root;
	struct rw_semaphore___263 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___262 *s_bdev;
	struct backing_dev_info___131 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___261 s_dquot;
	struct sb_writers___261 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___261 *s_d_op;
	int cleancache_poolid;
	struct shrinker___112 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___214 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct pid_namespace___190;

struct upid___190 {
	int nr;
	struct pid_namespace___190 *ns;
};

struct pid_namespace___190 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___263 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___190 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___262 *proc_self;
	struct dentry___262 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___214 *user_ns;
	struct ucounts___214 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___28 ns;
};

struct pid___190 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___190 numbers[1];
};

struct core_state___262;

struct mm_struct___262 {
	struct {
		struct vm_area_struct___263 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___262 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___263 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___262 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___263 *owner;
		struct user_namespace___214 *user_ns;
		struct file___262 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___262 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___251)(struct vm_area_struct___263 *, long unsigned int, const struct page___263 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___251)(struct page___263 *, void *);

struct device___225;

struct dev_pagemap___251 {
	dev_page_fault_t___251 page_fault;
	dev_page_free_t___251 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___225 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___262 {
	struct task_struct___263 *task;
	struct core_thread___262 *next;
};

struct core_state___262 {
	atomic_t nr_threads;
	struct core_thread___262 dumper;
	struct completion startup;
};

struct vm_fault___251 {
	struct vm_area_struct___263 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___263 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___263 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___262 prealloc_pte;
};

struct hrtimer_sleeper___5 {
	struct hrtimer timer;
	struct task_struct___263 *task;
};

struct user_struct___253 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___253 *uid_keyring;
	struct key___253 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cgroup_namespace___199;

struct nsproxy___234 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___190 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___199 *cgroup_ns;
};

struct signal_struct___214 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___263 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___263 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___190 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___190 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___262 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___190 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide42;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___131;

struct bio_list___131 {
	struct bio___131 *head;
	struct bio___131 *tail;
};

struct bdi_writeback_congested___131;

struct cgroup_subsys_state___199;

struct bdi_writeback___131 {
	struct backing_dev_info___131 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___131 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___199 *memcg_css;
	struct cgroup_subsys_state___199 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___131 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___131 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___225 *dev;
	struct device___225 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___262 *debug_dir;
	struct dentry___262 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___66;

struct io_context___66 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___66 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___199;

struct css_set___199 {
	struct cgroup_subsys_state___199 *subsys[13];
	refcount_t refcount;
	struct css_set___199 *dom_cset;
	struct cgroup___199 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___199 *mg_src_cgrp;
	struct cgroup___199 *mg_dst_cgrp;
	struct css_set___199 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

typedef blk_qc_t make_request_fn___62(struct request_queue___63 *, struct bio___131 *);

struct request___63;

typedef int dma_drain_needed_fn___62(struct request___63 *);

struct bsg_ops___62;

struct bsg_class_device___62 {
	struct device___225 *class_dev;
	int minor;
	struct request_queue___63 *queue;
	const struct bsg_ops___62 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___131 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___131 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___62;

struct rq_qos___5;

struct blk_mq_ops___8;

struct blk_mq_ctx___8;

struct blk_mq_hw_ctx___8;

struct blk_stat_callback___8;

struct blkcg_gq___50;

struct blk_trace___7;

struct blk_flush_queue___8;

struct blk_mq_tag_set___8;

struct request_queue___63 {
	struct list_head queue_head;
	struct request___63 *last_merge;
	struct elevator_queue___62 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos___5 *rq_qos;
	make_request_fn___62 *make_request_fn;
	dma_drain_needed_fn___62 *dma_drain_needed;
	const struct blk_mq_ops___8 *mq_ops;
	struct blk_mq_ctx___8 *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___8 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___131 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___250 kobj;
	struct kobject___250 *mq_kobj;
	struct blk_integrity integrity;
	struct device___225 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback___8 *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___50 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace___7 *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue___8 *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	struct bsg_class_device___62 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set___8 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___131 bio_split;
	struct dentry___262 *debugfs_dir;
	struct dentry___262 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___178 {
	struct vm_struct___178 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___263 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___226 {
	struct task_struct___263 task;
	long unsigned int stack[8192];
};

struct io_cq___66 {
	struct request_queue___63 *q;
	struct io_context___66 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___6 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___262 {
	struct file___262 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___262 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___261 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___262 *ia_file;
};

struct dquot___261 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___261 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___261 {
	int qf_fmt_id;
	const struct quota_format_ops___261 *qf_ops;
	struct module___215 *qf_owner;
	struct quota_format_type___261 *qf_next;
};

struct quota_format_ops___261 {
	int (*check_quota_file)(struct super_block___261 *, int);
	int (*read_file_info)(struct super_block___261 *, int);
	int (*write_file_info)(struct super_block___261 *, int);
	int (*free_file_info)(struct super_block___261 *, int);
	int (*read_dqblk)(struct dquot___261 *);
	int (*commit_dqblk)(struct dquot___261 *);
	int (*release_dqblk)(struct dquot___261 *);
	int (*get_next_id)(struct super_block___261 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___261 {
	int (*write_dquot)(struct dquot___261 *);
	struct dquot___261 * (*alloc_dquot)(struct super_block___261 *, int);
	void (*destroy_dquot)(struct dquot___261 *);
	int (*acquire_dquot)(struct dquot___261 *);
	int (*release_dquot)(struct dquot___261 *);
	int (*mark_dirty)(struct dquot___261 *);
	int (*write_info)(struct super_block___261 *, int);
	qsize_t * (*get_reserved_space)(struct inode___262 *);
	int (*get_projid)(struct inode___262 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___262 *, qsize_t *);
	int (*get_next_id)(struct super_block___261 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___261 {
	int (*quota_on)(struct super_block___261 *, int, int, const struct path___262 *);
	int (*quota_off)(struct super_block___261 *, int);
	int (*quota_enable)(struct super_block___261 *, unsigned int);
	int (*quota_disable)(struct super_block___261 *, unsigned int);
	int (*quota_sync)(struct super_block___261 *, int);
	int (*set_info)(struct super_block___261 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___261 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___261 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___261 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___261 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___261 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___125;

struct address_space_operations___261 {
	int (*writepage)(struct page___263 *, struct writeback_control___125 *);
	int (*readpage)(struct file___262 *, struct page___263 *);
	int (*writepages)(struct address_space___261 *, struct writeback_control___125 *);
	int (*set_page_dirty)(struct page___263 *);
	int (*readpages)(struct file___262 *, struct address_space___261 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___262 *, struct address_space___261 *, loff_t, unsigned int, unsigned int, struct page___263 **, void **);
	int (*write_end)(struct file___262 *, struct address_space___261 *, loff_t, unsigned int, unsigned int, struct page___263 *, void *);
	sector_t (*bmap)(struct address_space___261 *, sector_t);
	void (*invalidatepage)(struct page___263 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___263 *, gfp_t);
	void (*freepage)(struct page___263 *);
	ssize_t (*direct_IO)(struct kiocb___262 *, struct iov_iter___128 *);
	int (*migratepage)(struct address_space___261 *, struct page___263 *, struct page___263 *, enum migrate_mode);
	bool (*isolate_page)(struct page___263 *, isolate_mode_t);
	void (*putback_page)(struct page___263 *);
	int (*launder_page)(struct page___263 *);
	int (*is_partially_uptodate)(struct page___263 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___263 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___261 *, struct page___263 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___262 *, sector_t *);
	void (*swap_deactivate)(struct file___262 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___125 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___131 *wb;
	struct inode___262 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___131;

struct iov_iter___128 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___131 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct hd_struct___63;

struct gendisk___63;

struct block_device___262 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___262 *bd_inode;
	struct super_block___261 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___262 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___63 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___63 *bd_disk;
	struct request_queue___63 *bd_queue;
	struct backing_dev_info___131 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___225 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___225 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___225;

struct bus_type___225;

struct device_driver___225;

struct dev_pm_domain___225;

struct fwnode_handle___160;

struct class___225;

struct device___225 {
	struct device___225 *parent;
	struct device_private *p;
	struct kobject___250 kobj;
	const char *init_name;
	const struct device_type___225 *type;
	struct mutex mutex;
	struct bus_type___225 *bus;
	struct device_driver___225 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___225 power;
	struct dev_pm_domain___225 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___160 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___225 *class;
	const struct attribute_group___227 **groups;
	void (*release)(struct device___225 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___63 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___225 __dev;
	struct kobject___250 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___63;

struct block_device_operations___63;

struct gendisk___63 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___63 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___63 *part_tbl;
	struct hd_struct___63 part0;
	const struct block_device_operations___63 *fops;
	struct request_queue___63 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___263 lookup_sem;
	struct kobject___250 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___250 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___261 {
	struct dentry___262 * (*lookup)(struct inode___262 *, struct dentry___262 *, unsigned int);
	const char * (*get_link)(struct dentry___262 *, struct inode___262 *, struct delayed_call *);
	int (*permission)(struct inode___262 *, int);
	struct posix_acl * (*get_acl)(struct inode___262 *, int);
	int (*readlink)(struct dentry___262 *, char *, int);
	int (*create)(struct inode___262 *, struct dentry___262 *, umode_t, bool);
	int (*link)(struct dentry___262 *, struct inode___262 *, struct dentry___262 *);
	int (*unlink)(struct inode___262 *, struct dentry___262 *);
	int (*symlink)(struct inode___262 *, struct dentry___262 *, const char *);
	int (*mkdir)(struct inode___262 *, struct dentry___262 *, umode_t);
	int (*rmdir)(struct inode___262 *, struct dentry___262 *);
	int (*mknod)(struct inode___262 *, struct dentry___262 *, umode_t, dev_t);
	int (*rename)(struct inode___262 *, struct dentry___262 *, struct inode___262 *, struct dentry___262 *, unsigned int);
	int (*setattr)(struct dentry___262 *, struct iattr___261 *);
	int (*getattr)(const struct path___262 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___262 *, char *, size_t);
	int (*fiemap)(struct inode___262 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___262 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___262 *, struct dentry___262 *, struct file___262 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___262 *, struct dentry___262 *, umode_t);
	int (*set_acl)(struct inode___262 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___261 {
	void (*fl_copy_lock)(struct file_lock___262 *, struct file_lock___262 *);
	void (*fl_release_private)(struct file_lock___262 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___261;

struct lock_manager_operations___261;

struct file_lock___262 {
	struct file_lock___262 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___262 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___261 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___261 *fl_ops;
	const struct lock_manager_operations___261 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___261 {
	int (*lm_compare_owner)(struct file_lock___262 *, struct file_lock___262 *);
	long unsigned int (*lm_owner_key)(struct file_lock___262 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___262 *);
	int (*lm_grant)(struct file_lock___262 *, int);
	bool (*lm_break)(struct file_lock___262 *);
	int (*lm_change)(struct file_lock___262 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___262 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___261 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___261 *fa_next;
	struct file___262 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___261 {
	const char *name;
	int fs_flags;
	struct dentry___262 * (*mount)(struct file_system_type___261 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___261 *);
	struct module___215 *owner;
	struct file_system_type___261 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___261 {
	struct inode___262 * (*alloc_inode)(struct super_block___261 *);
	void (*destroy_inode)(struct inode___262 *);
	void (*dirty_inode)(struct inode___262 *, int);
	int (*write_inode)(struct inode___262 *, struct writeback_control___125 *);
	int (*drop_inode)(struct inode___262 *);
	void (*evict_inode)(struct inode___262 *);
	void (*put_super)(struct super_block___261 *);
	int (*sync_fs)(struct super_block___261 *, int);
	int (*freeze_super)(struct super_block___261 *);
	int (*freeze_fs)(struct super_block___261 *);
	int (*thaw_super)(struct super_block___261 *);
	int (*unfreeze_fs)(struct super_block___261 *);
	int (*statfs)(struct dentry___262 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___261 *, int *, char *);
	void (*umount_begin)(struct super_block___261 *);
	int (*show_options)(struct seq_file___233 *, struct dentry___262 *);
	int (*show_devname)(struct seq_file___233 *, struct dentry___262 *);
	int (*show_path)(struct seq_file___233 *, struct dentry___262 *);
	int (*show_stats)(struct seq_file___233 *, struct dentry___262 *);
	ssize_t (*quota_read)(struct super_block___261 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___261 *, int, const char *, size_t, loff_t);
	struct dquot___261 ** (*get_dquots)(struct inode___262 *);
	int (*bdev_try_to_free_page)(struct super_block___261 *, struct page___263 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___261 *, struct shrink_control___112 *);
	long int (*free_cached_objects)(struct super_block___261 *, struct shrink_control___112 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___131(struct bio___131 *);

struct bio_vec___131 {
	struct page___263 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___131;

struct bio___131 {
	struct bio___131 *bi_next;
	struct gendisk___63 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___131 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___50 *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___131 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___131 *bi_io_vec;
	struct bio_set___131 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___131 bi_inline_vecs[0];
};

struct bio_integrity_payload___131 {
	struct bio___131 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___131 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___131 bip_inline_vecs[0];
};

struct blkcg___50;

struct blkg_policy_data___50;

struct blkcg_gq___50 {
	struct request_queue___63 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___50 *blkcg;
	struct bdi_writeback_congested___131 *wb_congested;
	struct blkcg_gq___50 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_rwstat stat_bytes;
	struct blkg_rwstat stat_ios;
	struct blkg_policy_data___50 *pd[5];
	struct callback_head callback_head;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
};

struct dev_pm_ops___225;

struct device_type___225 {
	const char *name;
	const struct attribute_group___227 **groups;
	int (*uevent)(struct device___225 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___225 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___225 *);
	const struct dev_pm_ops___225 *pm;
};

struct class___225 {
	const char *name;
	struct module___215 *owner;
	const struct attribute_group___227 **class_groups;
	const struct attribute_group___227 **dev_groups;
	struct kobject___250 *dev_kobj;
	int (*dev_uevent)(struct device___225 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___225 *, umode_t *);
	void (*class_release)(struct class___225 *);
	void (*dev_release)(struct device___225 *);
	int (*shutdown_pre)(struct device___225 *);
	const struct kobj_ns_type_operations___24 *ns_type;
	const void * (*namespace)(struct device___225 *);
	const struct dev_pm_ops___225 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dev_pm_ops___225 {
	int (*prepare)(struct device___225 *);
	void (*complete)(struct device___225 *);
	int (*suspend)(struct device___225 *);
	int (*resume)(struct device___225 *);
	int (*freeze)(struct device___225 *);
	int (*thaw)(struct device___225 *);
	int (*poweroff)(struct device___225 *);
	int (*restore)(struct device___225 *);
	int (*suspend_late)(struct device___225 *);
	int (*resume_early)(struct device___225 *);
	int (*freeze_late)(struct device___225 *);
	int (*thaw_early)(struct device___225 *);
	int (*poweroff_late)(struct device___225 *);
	int (*restore_early)(struct device___225 *);
	int (*suspend_noirq)(struct device___225 *);
	int (*resume_noirq)(struct device___225 *);
	int (*freeze_noirq)(struct device___225 *);
	int (*thaw_noirq)(struct device___225 *);
	int (*poweroff_noirq)(struct device___225 *);
	int (*restore_noirq)(struct device___225 *);
	int (*runtime_suspend)(struct device___225 *);
	int (*runtime_resume)(struct device___225 *);
	int (*runtime_idle)(struct device___225 *);
};

struct dev_pm_domain___225 {
	struct dev_pm_ops___225 ops;
	void (*detach)(struct device___225 *, bool);
	int (*activate)(struct device___225 *);
	void (*sync)(struct device___225 *);
	void (*dismiss)(struct device___225 *);
};

struct bus_type___225 {
	const char *name;
	const char *dev_name;
	struct device___225 *dev_root;
	const struct attribute_group___227 **bus_groups;
	const struct attribute_group___227 **dev_groups;
	const struct attribute_group___227 **drv_groups;
	int (*match)(struct device___225 *, struct device_driver___225 *);
	int (*uevent)(struct device___225 *, struct kobj_uevent_env *);
	int (*probe)(struct device___225 *);
	int (*remove)(struct device___225 *);
	void (*shutdown)(struct device___225 *);
	int (*online)(struct device___225 *);
	int (*offline)(struct device___225 *);
	int (*suspend)(struct device___225 *, pm_message_t);
	int (*resume)(struct device___225 *);
	int (*num_vf)(struct device___225 *);
	int (*dma_configure)(struct device___225 *);
	const struct dev_pm_ops___225 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___225 {
	const char *name;
	struct bus_type___225 *bus;
	struct module___215 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___225 *);
	int (*remove)(struct device___225 *);
	void (*shutdown)(struct device___225 *);
	int (*suspend)(struct device___225 *, pm_message_t);
	int (*resume)(struct device___225 *);
	const struct attribute_group___227 **groups;
	const struct dev_pm_ops___225 *pm;
	void (*coredump)(struct device___225 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct fwnode_operations___160;

struct fwnode_handle___160 {
	struct fwnode_handle___160 *secondary;
	const struct fwnode_operations___160 *ops;
};

struct disk_part_tbl___63 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___63 *last_lookup;
	struct hd_struct___63 *part[0];
};

struct block_device_operations___63 {
	int (*open)(struct block_device___262 *, fmode_t);
	void (*release)(struct gendisk___63 *, fmode_t);
	int (*rw_page)(struct block_device___262 *, sector_t, struct page___263 *, unsigned int);
	int (*ioctl)(struct block_device___262 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___262 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___63 *, unsigned int);
	int (*media_changed)(struct gendisk___63 *);
	void (*unlock_native_capacity)(struct gendisk___63 *);
	int (*revalidate_disk)(struct gendisk___63 *);
	int (*getgeo)(struct block_device___262 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___262 *, long unsigned int);
	int (*report_zones)(struct gendisk___63 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___215 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___251(struct page___263 *);

struct bdi_writeback_congested___131 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___131 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct cgroup_subsys___199;

struct cgroup_subsys_state___199 {
	struct cgroup___199 *cgroup;
	struct cgroup_subsys___199 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___199 *parent;
};

struct bsg_ops___62 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___63 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___63 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___63 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___62(struct request___63 *, blk_status_t);

struct request___63 {
	struct request_queue___63 *q;
	struct blk_mq_ctx___8 *mq_ctx;
	struct blk_mq_hw_ctx___8 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___131 *bio;
	struct bio___131 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___131 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___66 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___62 *saved_end_io;
		} flush;
	};
	struct gendisk___63 *rq_disk;
	struct hd_struct___63 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___62 *end_io;
	void *end_io_data;
	struct request___63 *next_rq;
};

struct fwnode_reference_args___160;

struct fwnode_endpoint___160;

struct fwnode_operations___160 {
	struct fwnode_handle___160 * (*get)(struct fwnode_handle___160 *);
	void (*put)(struct fwnode_handle___160 *);
	bool (*device_is_available)(const struct fwnode_handle___160 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___160 *, const struct device___225 *);
	bool (*property_present)(const struct fwnode_handle___160 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___160 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___160 *, const char *, const char **, size_t);
	struct fwnode_handle___160 * (*get_parent)(const struct fwnode_handle___160 *);
	struct fwnode_handle___160 * (*get_next_child_node)(const struct fwnode_handle___160 *, struct fwnode_handle___160 *);
	struct fwnode_handle___160 * (*get_named_child_node)(const struct fwnode_handle___160 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___160 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___160 *);
	struct fwnode_handle___160 * (*graph_get_next_endpoint)(const struct fwnode_handle___160 *, struct fwnode_handle___160 *);
	struct fwnode_handle___160 * (*graph_get_remote_endpoint)(const struct fwnode_handle___160 *);
	struct fwnode_handle___160 * (*graph_get_port_parent)(struct fwnode_handle___160 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___160 *, struct fwnode_endpoint___160 *);
};

struct fwnode_endpoint___160 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___160 *local_fwnode;
};

struct fwnode_reference_args___160 {
	struct fwnode_handle___160 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct blk_mq_ctxs___7;

struct blk_mq_ctx___8 {
	struct {
		spinlock_t lock;
		struct list_head rq_lists[3];
		long: 64;
	};
	unsigned int cpu;
	short unsigned int index_hw[3];
	struct blk_mq_hw_ctx___8 *hctxs[3];
	long unsigned int rq_dispatched[2];
	long unsigned int rq_merged;
	long unsigned int rq_completed[2];
	struct request_queue___63 *queue;
	struct blk_mq_ctxs___7 *ctxs;
	struct kobject___250 kobj;
};

struct blk_mq_tags___7;

struct blk_mq_hw_ctx___8 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___63 *queue;
	struct blk_flush_queue___8 *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx___8 *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx___8 **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags___7 *tags;
	struct blk_mq_tags___7 *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	unsigned int rh_reserved_nr_expired;
	struct hlist_node cpuhp_dead;
	struct kobject___250 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___262 *debugfs_dir;
	struct dentry___262 *sched_debugfs_dir;
	struct list_head hctx_list;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___62;

struct blk_mq_alloc_data___8;

struct elevator_mq_ops___62 {
	int (*init_sched)(struct request_queue___63 *, struct elevator_type___62 *);
	void (*exit_sched)(struct elevator_queue___62 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___8 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___8 *, unsigned int);
	bool (*allow_merge)(struct request_queue___63 *, struct request___63 *, struct bio___131 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx___8 *, struct bio___131 *);
	int (*request_merge)(struct request_queue___63 *, struct request___63 **, struct bio___131 *);
	void (*request_merged)(struct request_queue___63 *, struct request___63 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___63 *, struct request___63 *, struct request___63 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data___8 *);
	void (*prepare_request)(struct request___63 *, struct bio___131 *);
	void (*finish_request)(struct request___63 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___8 *, struct list_head *, bool);
	struct request___63 * (*dispatch_request)(struct blk_mq_hw_ctx___8 *);
	bool (*has_work)(struct blk_mq_hw_ctx___8 *);
	void (*completed_request)(struct request___63 *, u64);
	void (*started_request)(struct request___63 *);
	void (*requeue_request)(struct request___63 *);
	struct request___63 * (*former_request)(struct request_queue___63 *, struct request___63 *);
	struct request___63 * (*next_request)(struct request_queue___63 *, struct request___63 *);
	void (*init_icq)(struct io_cq___66 *);
	void (*exit_icq)(struct io_cq___66 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx___8 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___62;

struct blk_mq_debugfs_attr___2;

struct elevator_type___62 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___62 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___62 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___215 *elevator_owner;
	const struct blk_mq_debugfs_attr___2 *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr___2 *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___62 {
	struct elevator_type___62 *type;
	void *elevator_data;
	struct kobject___250 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct blk_mq_alloc_data___8 {
	struct request_queue___63 *q;
	blk_mq_req_flags_t flags;
	unsigned int shallow_depth;
	unsigned int cmd_flags;
	struct blk_mq_ctx___8 *ctx;
	struct blk_mq_hw_ctx___8 *hctx;
};

struct elv_fs_entry___62 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___62 *, char *);
	ssize_t (*store)(struct elevator_queue___62 *, const char *, size_t);
};

struct blk_mq_debugfs_attr___2 {
	const char *name;
	umode_t mode;
	int (*show)(void *, struct seq_file___233 *);
	ssize_t (*write)(void *, const char *, size_t, loff_t *);
	const struct seq_operations___231 *seq_ops;
};

struct rq_qos_ops___5;

struct rq_qos___5 {
	struct rq_qos_ops___5 *ops;
	struct request_queue___63 *q;
	enum rq_qos_id id;
	struct rq_qos___5 *next;
};

struct blk_mq_queue_data___8;

typedef blk_status_t queue_rq_fn___8(struct blk_mq_hw_ctx___8 *, const struct blk_mq_queue_data___8 *);

typedef void commit_rqs_fn___8(struct blk_mq_hw_ctx___8 *);

typedef bool get_budget_fn___8(struct blk_mq_hw_ctx___8 *);

typedef void put_budget_fn___8(struct blk_mq_hw_ctx___8 *);

typedef enum blk_eh_timer_return timeout_fn___8(struct request___63 *, bool);

typedef int poll_fn___8(struct blk_mq_hw_ctx___8 *);

typedef void complete_fn___8(struct request___63 *);

typedef int init_hctx_fn___8(struct blk_mq_hw_ctx___8 *, void *, unsigned int);

typedef void exit_hctx_fn___8(struct blk_mq_hw_ctx___8 *, unsigned int);

typedef int init_request_fn___8(struct blk_mq_tag_set___8 *, struct request___63 *, unsigned int, unsigned int);

typedef void exit_request_fn___8(struct blk_mq_tag_set___8 *, struct request___63 *, unsigned int);

typedef bool busy_fn___8(struct request_queue___63 *);

typedef int map_queues_fn___8(struct blk_mq_tag_set___8 *);

typedef void cleanup_rq_fn___8(struct request___63 *);

struct blk_mq_ops___8 {
	queue_rq_fn___8 *queue_rq;
	commit_rqs_fn___8 *commit_rqs;
	get_budget_fn___8 *get_budget;
	put_budget_fn___8 *put_budget;
	timeout_fn___8 *timeout;
	poll_fn___8 *poll;
	complete_fn___8 *complete;
	init_hctx_fn___8 *init_hctx;
	exit_hctx_fn___8 *exit_hctx;
	init_request_fn___8 *init_request;
	exit_request_fn___8 *exit_request;
	void (*initialize_rq_fn)(struct request___63 *);
	busy_fn___8 *busy;
	map_queues_fn___8 *map_queues;
	void (*show_rq)(struct seq_file___233 *, struct request___63 *);
	union {
		cleanup_rq_fn___8 *cleanup_rq;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide47;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct blk_stat_callback___8 {
	struct list_head list;
	struct timer_list timer;
	struct blk_rq_stat *cpu_stat;
	int (*bucket_fn)(const struct request___63 *);
	unsigned int buckets;
	struct blk_rq_stat *stat;
	void (*timer_fn)(struct blk_stat_callback___8 *);
	void *data;
	struct callback_head rcu;
};

struct rchan___8;

struct blk_trace___7 {
	int trace_state;
	struct rchan___8 *rchan;
	long unsigned int *sequence;
	unsigned char *msg_data;
	u16 act_mask;
	u64 start_lba;
	u64 end_lba;
	u32 pid;
	u32 dev;
	struct dentry___262 *dir;
	struct dentry___262 *dropped_file;
	struct dentry___262 *msg_file;
	struct list_head running_list;
	atomic_t dropped;
};

struct blk_flush_queue___8 {
	unsigned int flush_queue_delayed: 1;
	unsigned int flush_pending_idx: 1;
	unsigned int flush_running_idx: 1;
	long unsigned int flush_pending_since;
	struct list_head flush_queue[2];
	struct list_head flush_data_in_flight;
	struct request___63 *flush_rq;
	struct request___63 *orig_rq;
	spinlock_t mq_flush_lock;
};

struct blk_mq_tag_set___8 {
	struct blk_mq_queue_map map[6];
	unsigned int nr_maps;
	const struct blk_mq_ops___8 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	struct blk_mq_tags___7 **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef int (*key_restrict_link_func_t___254)(struct key___253 *, const struct key_type *, const union key_payload *, struct key___253 *);

struct key_restriction___253;

struct key___253 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___263 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key___6 index_key;
		struct {
			struct key_type___6 *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___253 *restrict_link;
};

struct key_restriction___253 {
	key_restrict_link_func_t___254 check;
	struct key___253 *key;
	struct key_type *keytype;
};

struct seq_operations___231 {
	void * (*start)(struct seq_file___233 *, loff_t *);
	void (*stop)(struct seq_file___233 *, void *);
	void * (*next)(struct seq_file___233 *, void *, loff_t *);
	int (*show)(struct seq_file___233 *, void *);
};

struct cgroup_namespace___199 {
	refcount_t count;
	struct ns_common___28 ns;
	struct user_namespace___214 *user_ns;
	struct ucounts___214 *ucounts;
	struct css_set___199 *root_cset;
};

struct ucounts___214 {
	struct hlist_node node;
	struct user_namespace___214 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___200;

struct bpf_map_ops___199 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___200 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___200 *, struct file___262 *);
	void (*map_free)(struct bpf_map___200 *);
	int (*map_get_next_key)(struct bpf_map___200 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___200 *);
	void * (*map_lookup_elem)(struct bpf_map___200 *, void *);
	int (*map_update_elem)(struct bpf_map___200 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___200 *, void *);
	int (*map_push_elem)(struct bpf_map___200 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___200 *, void *);
	int (*map_peek_elem)(struct bpf_map___200 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___200 *, struct file___262 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___200 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___200 *, void *, struct seq_file___233 *);
	int (*map_check_btf)(const struct bpf_map___200 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___200 {
	const struct bpf_map_ops___199 *ops;
	struct bpf_map___200 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___253 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___199;

typedef void (*kthread_work_func_t___199)(struct kthread_work___199 *);

struct kthread_worker___199;

struct kthread_work___199 {
	struct list_head node;
	kthread_work_func_t___199 func;
	struct kthread_worker___199 *worker;
	int canceling;
};

struct kthread_worker___199 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___263 *task;
	struct kthread_work___199 *current_work;
};

struct kthread_delayed_work___199 {
	struct kthread_work___199 work;
	struct timer_list timer;
};

struct psi_group___199 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___199 *poll_kworker;
	struct kthread_delayed_work___199 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___199 {
	struct kernfs_node___257 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_root___199;

struct cgroup_rstat_cpu___199;

struct cgroup___199 {
	struct cgroup_subsys_state___199 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___257 *kn;
	struct cgroup_file___199 procs_file;
	struct cgroup_file___199 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___199 *subsys[13];
	struct cgroup_root___199 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___199 *dom_cgrp;
	struct cgroup_rstat_cpu___199 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___34 bpf;
	atomic_t congestion_count;
	struct cgroup___199 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___199 psi;
	int ancestor_ids[0];
};

struct cftype___199;

struct cgroup_subsys___199 {
	struct cgroup_subsys_state___199 * (*css_alloc)(struct cgroup_subsys_state___199 *);
	int (*css_online)(struct cgroup_subsys_state___199 *);
	void (*css_offline)(struct cgroup_subsys_state___199 *);
	void (*css_released)(struct cgroup_subsys_state___199 *);
	void (*css_free)(struct cgroup_subsys_state___199 *);
	void (*css_reset)(struct cgroup_subsys_state___199 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___199 *, int);
	int (*css_extra_stat_show)(struct seq_file___233 *, struct cgroup_subsys_state___199 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___263 *);
	void (*cancel_fork)(struct task_struct___263 *);
	void (*fork)(struct task_struct___263 *);
	void (*exit)(struct task_struct___263 *);
	void (*free)(struct task_struct___263 *);
	void (*bind)(struct cgroup_subsys_state___199 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___199 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___199 *dfl_cftypes;
	struct cftype___199 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___199 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___199 *updated_children;
	struct cgroup___199 *updated_next;
};

struct cgroup_root___199 {
	struct kernfs_root___256 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___199 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___199 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___199 *ss;
	struct list_head node;
	struct kernfs_ops___256 *kf_ops;
	int (*open)(struct kernfs_open_file___256 *);
	void (*release)(struct kernfs_open_file___256 *);
	u64 (*read_u64)(struct cgroup_subsys_state___199 *, struct cftype___199 *);
	s64 (*read_s64)(struct cgroup_subsys_state___199 *, struct cftype___199 *);
	int (*seq_show)(struct seq_file___233 *, void *);
	void * (*seq_start)(struct seq_file___233 *, loff_t *);
	void * (*seq_next)(struct seq_file___233 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___233 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___199 *, struct cftype___199 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___199 *, struct cftype___199 *, s64);
	ssize_t (*write)(struct kernfs_open_file___256 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___256 *, struct poll_table_struct___162 *);
};

struct blkcg_policy_data___50;

struct blkcg___50 {
	struct cgroup_subsys_state___199 css;
	spinlock_t lock;
	struct xarray blkg_tree;
	struct blkcg_gq___50 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___50 *cpd[5];
	struct list_head all_blkcgs_node;
	struct list_head cgwb_list;
	refcount_t cgwb_refcnt;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct blkcg_policy_data___50 {
	struct blkcg___50 *blkcg;
	int plid;
};

struct blkg_policy_data___50 {
	struct blkcg_gq___50 *blkg;
	int plid;
};

struct node___172 {
	struct device___225 dev;
};

struct kimage___19;

typedef void *kexec_load_t___19(struct kimage___19 *, char *, long unsigned int, char *, long unsigned int, char *, long unsigned int);

struct kexec_file_ops___20 {
	kexec_probe_t *probe;
	kexec_load_t___19 *load;
	kexec_cleanup_t *cleanup;
};

struct kimage___19 {
	kimage_entry_t head;
	kimage_entry_t *entry;
	kimage_entry_t *last_entry;
	long unsigned int start;
	struct page___263 *control_code_page;
	struct page___263 *swap_page;
	void *vmcoreinfo_data_copy;
	long unsigned int nr_segments;
	struct kexec_segment segment[16];
	struct list_head control_pages;
	struct list_head dest_pages;
	struct list_head unusable_pages;
	long unsigned int control_page;
	unsigned int type: 1;
	unsigned int preserve_context: 1;
	unsigned int file_mode: 1;
	struct kimage_arch arch;
	void *kernel_buf;
	long unsigned int kernel_buf_len;
	void *initrd_buf;
	long unsigned int initrd_buf_len;
	char *cmdline_buf;
	long unsigned int cmdline_buf_len;
	const struct kexec_file_ops___20 *fops;
	void *image_loader_data;
	struct purgatory_info purgatory_info;
};

struct rchan_buf___8 {
	void *start;
	void *data;
	size_t offset;
	size_t subbufs_produced;
	size_t subbufs_consumed;
	struct rchan___8 *chan;
	wait_queue_head_t read_wait;
	struct irq_work wakeup_work;
	struct dentry___262 *dentry;
	struct kref kref;
	struct page___263 **page_array;
	unsigned int page_count;
	unsigned int finalized;
	size_t *padding;
	size_t prev_padding;
	size_t bytes_consumed;
	size_t early_bytes;
	unsigned int cpu;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
};

struct rchan_callbacks___8;

struct rchan___8 {
	u32 version;
	size_t subbuf_size;
	size_t n_subbufs;
	size_t alloc_size;
	struct rchan_callbacks___8 *cb;
	struct kref kref;
	void *private_data;
	size_t last_toobig;
	struct rchan_buf___8 **buf;
	int is_global;
	struct list_head list;
	struct dentry___262 *parent;
	int has_base_filename;
	char base_filename[255];
};

struct rchan_callbacks___8 {
	int (*subbuf_start)(struct rchan_buf___8 *, void *, void *, size_t);
	void (*buf_mapped)(struct rchan_buf___8 *, struct file___262 *);
	void (*buf_unmapped)(struct rchan_buf___8 *, struct file___262 *);
	struct dentry___262 * (*create_buf_file)(const char *, struct dentry___262 *, umode_t, struct rchan_buf___8 *, int *);
	int (*remove_buf_file)(struct dentry___262 *);
};

typedef bool (*sb_for_each_fn)(struct sbitmap *, unsigned int, void *);

struct blk_mq_tags___7 {
	unsigned int nr_tags;
	unsigned int nr_reserved_tags;
	atomic_t active_queues;
	struct sbitmap_queue bitmap_tags;
	struct sbitmap_queue breserved_tags;
	struct request___63 **rqs;
	struct request___63 **static_rqs;
	struct list_head page_list;
};

struct blk_mq_queue_data___8 {
	struct request___63 *rq;
	bool last;
	long unsigned int rh_reserved1;
};

enum {
	BLK_MQ_UNIQUE_TAG_BITS = 16,
	BLK_MQ_UNIQUE_TAG_MASK = 65535,
};

enum {
	BLK_MQ_TAG_FAIL = 4294967295,
	BLK_MQ_TAG_MIN = 1,
	BLK_MQ_TAG_MAX = 4294967294,
};

struct blk_mq_ctxs___7 {
	struct kobject___250 kobj;
	struct blk_mq_ctx___8 *queue_ctx;
};

struct rq_qos_ops___5 {
	void (*throttle)(struct rq_qos___5 *, struct bio___131 *);
	void (*track)(struct rq_qos___5 *, struct request___63 *, struct bio___131 *);
	void (*issue)(struct rq_qos___5 *, struct request___63 *);
	void (*requeue)(struct rq_qos___5 *, struct request___63 *);
	void (*done)(struct rq_qos___5 *, struct request___63 *);
	void (*done_bio)(struct rq_qos___5 *, struct bio___131 *);
	void (*cleanup)(struct rq_qos___5 *, struct bio___131 *);
	void (*exit)(struct rq_qos___5 *);
};

struct mq_inflight {
	struct hd_struct___63 *part;
	unsigned int *inflight;
};

struct flush_busy_ctx_data {
	struct blk_mq_hw_ctx___8 *hctx;
	struct list_head *list;
};

struct dispatch_rq_data {
	struct blk_mq_hw_ctx___8 *hctx;
	struct request___63 *rq;
};

struct blk_mq_qe_pair {
	struct list_head node;
	struct request_queue___63 *q;
	struct elevator_type___62 *type;
};

struct sbq_wait {
	struct sbitmap_queue *sbq;
	struct wait_queue_entry wait;
};

typedef bool busy_iter_fn(struct blk_mq_hw_ctx___5 *, struct request___60 *, void *, bool);

typedef bool busy_tag_iter_fn(struct request___60 *, void *, bool);

struct bt_iter_data {
	struct blk_mq_hw_ctx___5 *hctx;
	busy_iter_fn *fn;
	void *data;
	bool reserved;
};

struct bt_tags_iter_data {
	struct blk_mq_tags___4 *tags;
	busy_tag_iter_fn *fn;
	void *data;
	bool reserved;
};

struct file___263;

struct kiocb___263;

struct vm_area_struct___264;

struct inode___263;

struct file_lock___263;

struct page___264;

struct file_operations___263 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___263 *, loff_t, int);
	ssize_t (*read)(struct file___263 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___263 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___263 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___263 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___263 *, bool);
	int (*iterate)(struct file___263 *, struct dir_context *);
	int (*iterate_shared)(struct file___263 *, struct dir_context *);
	__poll_t (*poll)(struct file___263 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___263 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___263 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___263 *, struct vm_area_struct___264 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___263 *, struct file___263 *);
	int (*flush)(struct file___263 *, fl_owner_t);
	int (*release)(struct inode___263 *, struct file___263 *);
	int (*fsync)(struct file___263 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___263 *, int);
	int (*lock)(struct file___263 *, int, struct file_lock___263 *);
	ssize_t (*sendpage)(struct file___263 *, struct page___264 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___263 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___263 *, int, struct file_lock___263 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___263 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___263 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___263 *, long int, struct file_lock___263 **, void **);
	long int (*fallocate)(struct file___263 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___263 *);
	ssize_t (*copy_file_range)(struct file___263 *, loff_t, struct file___263 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___263 *, loff_t, struct file___263 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___263 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___263 {
	u64 seqnum;
	struct vm_area_struct___264 *vmas[4];
};

struct page_frag___263 {
	struct page___264 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___263;

struct bio_list___132;

struct backing_dev_info___132;

struct io_context___67;

struct request_queue___64;

struct vm_struct___179;

struct task_struct___264 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___264 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___263 *mm;
	struct mm_struct___263 *active_mm;
	struct vmacache___263 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___264 *real_parent;
	struct task_struct___264 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___264 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___190 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___190 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___190 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___2 *ptracer_cred;
	const struct cred___2 *real_cred;
	const struct cred___2 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___264 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___132 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___132 *backing_dev_info;
	struct io_context___67 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___263 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___64 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___264 *oom_reaper_list;
	struct vm_struct___179 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___128 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct secondary_data___264 {
	void *stack;
	struct task_struct___264 *task;
	long int status;
};

typedef struct page___264 *pgtable_t___263;

struct address_space___262;

struct dev_pagemap___252;

struct page___264 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___262 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___264 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___263 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___263 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___252 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct vm_operations_struct___252;

struct vm_area_struct___264 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___264 *vm_next;
	struct vm_area_struct___264 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___263 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___252 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___263 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct rw_semaphore___264 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___264 *owner;
};

struct core_state___263;

struct mm_struct___263 {
	struct {
		struct vm_area_struct___264 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___263 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___264 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___263 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___264 *owner;
		struct user_namespace___3 *user_ns;
		struct file___263 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___263 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct bio___132;

struct bio_list___132 {
	struct bio___132 *head;
	struct bio___132 *tail;
};

struct bdi_writeback_congested___132;

struct bdi_writeback___132 {
	struct backing_dev_info___132 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___132 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___157 *memcg_css;
	struct cgroup_subsys_state___157 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___226;

struct dentry___263;

struct backing_dev_info___132 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___132 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___226 *dev;
	struct device___226 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___263 *debug_dir;
	struct dentry___263 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___67;

struct io_context___67 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___67 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

typedef blk_qc_t make_request_fn___63(struct request_queue___64 *, struct bio___132 *);

struct request___64;

typedef int dma_drain_needed_fn___63(struct request___64 *);

struct kset___250;

struct kobj_type___250;

struct kernfs_node___258;

struct kobject___251 {
	const char *name;
	struct list_head entry;
	struct kobject___251 *parent;
	struct kset___250 *kset;
	struct kobj_type___250 *ktype;
	struct kernfs_node___258 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___63;

struct bsg_class_device___63 {
	struct device___226 *class_dev;
	int minor;
	struct request_queue___64 *queue;
	const struct bsg_ops___63 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___132 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___132 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___63;

struct blk_mq_ops___9;

struct blk_mq_ctx___9;

struct blk_mq_hw_ctx___9;

struct blk_stat_callback___9;

struct blk_flush_queue___9;

struct blk_mq_tag_set___9;

struct request_queue___64 {
	struct list_head queue_head;
	struct request___64 *last_merge;
	struct elevator_queue___63 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___63 *make_request_fn;
	dma_drain_needed_fn___63 *dma_drain_needed;
	const struct blk_mq_ops___9 *mq_ops;
	struct blk_mq_ctx___9 *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___9 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___132 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___251 kobj;
	struct kobject___251 *mq_kobj;
	struct blk_integrity integrity;
	struct device___226 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback___9 *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue___9 *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	struct bsg_class_device___63 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set___9 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___132 bio_split;
	struct dentry___263 *debugfs_dir;
	struct dentry___263 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___179 {
	struct vm_struct___179 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___264 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct pglist_data___263;

struct lruvec___263 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___263 *pgdat;
};

struct zone___263 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___263 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___263 {
	struct zone___263 *zone;
	int zone_idx;
};

struct zonelist___263 {
	struct zoneref___263 _zonerefs[25];
};

struct pglist_data___263 {
	struct zone___263 node_zones[3];
	struct zonelist___263 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___264 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___264 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___263 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___263 {
	struct rw_semaphore___264 rwsem;
	struct notifier_block *head;
};

struct bio_vec___132 {
	struct page___264 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

typedef void bio_end_io_t___132(struct bio___132 *);

struct gendisk___64;

struct bio_integrity_payload___132;

struct bio___132 {
	struct bio___132 *bi_next;
	struct gendisk___64 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___132 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___132 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___132 *bi_io_vec;
	struct bio_set___132 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___132 bi_inline_vecs[0];
};

struct bio_integrity_payload___132 {
	struct bio___132 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___132 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___132 bip_inline_vecs[0];
};

struct dev_pm_info___226 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___226 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___226;

struct bus_type___226;

struct device_driver___226;

struct dev_pm_domain___226;

struct fwnode_handle___161;

struct class___226;

struct attribute_group___228;

struct device___226 {
	struct device___226 *parent;
	struct device_private *p;
	struct kobject___251 kobj;
	const char *init_name;
	const struct device_type___226 *type;
	struct mutex mutex;
	struct bus_type___226 *bus;
	struct device_driver___226 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___226 power;
	struct dev_pm_domain___226 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___161 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___226 *class;
	const struct attribute_group___228 **groups;
	void (*release)(struct device___226 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___64 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___226 __dev;
	struct kobject___251 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___64;

struct block_device_operations___64;

struct gendisk___64 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___64 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___64 *part_tbl;
	struct hd_struct___64 part0;
	const struct block_device_operations___64 *fops;
	struct request_queue___64 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___264 lookup_sem;
	struct kobject___251 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___251 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_ops___226;

struct device_type___226 {
	const char *name;
	const struct attribute_group___228 **groups;
	int (*uevent)(struct device___226 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___226 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___226 *);
	const struct dev_pm_ops___226 *pm;
};

struct class___226 {
	const char *name;
	struct module___11 *owner;
	const struct attribute_group___228 **class_groups;
	const struct attribute_group___228 **dev_groups;
	struct kobject___251 *dev_kobj;
	int (*dev_uevent)(struct device___226 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___226 *, umode_t *);
	void (*class_release)(struct class___226 *);
	void (*dev_release)(struct device___226 *);
	int (*shutdown_pre)(struct device___226 *);
	const struct kobj_ns_type_operations___24 *ns_type;
	const void * (*namespace)(struct device___226 *);
	const struct dev_pm_ops___226 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct kernfs_root___257;

struct kernfs_elem_dir___257 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___257 *root;
};

struct kernfs_syscall_ops___257;

struct kernfs_root___257 {
	struct kernfs_node___258 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___257 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___257 {
	struct kernfs_node___258 *target_kn;
};

struct kernfs_ops___257;

struct kernfs_elem_attr___257 {
	const struct kernfs_ops___257 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___258 *notify_next;
};

struct kernfs_node___258 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___258 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___257 dir;
		struct kernfs_elem_symlink___257 symlink;
		struct kernfs_elem_attr___257 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___257;

struct kernfs_ops___257 {
	int (*open)(struct kernfs_open_file___257 *);
	void (*release)(struct kernfs_open_file___257 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___257 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___257 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___257 *, struct vm_area_struct___264 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___257 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___257 {
	int (*remount_fs)(struct kernfs_root___257 *, int *, char *);
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___257 *);
	int (*mkdir)(struct kernfs_node___258 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___258 *);
	int (*rename)(struct kernfs_node___258 *, struct kernfs_node___258 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___258 *, struct kernfs_root___257 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___257 {
	struct kernfs_node___258 *kn;
	struct file___263 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___252 *vm_ops;
};

struct path___263 {
	struct vfsmount *mnt;
	struct dentry___263 *dentry;
};

struct file___263 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___263 f_path;
	struct inode___263 *f_inode;
	const struct file_operations___263 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___190 f_owner;
	const struct cred___2 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___262 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___252;

struct vm_operations_struct___252 {
	void (*open)(struct vm_area_struct___264 *);
	void (*close)(struct vm_area_struct___264 *);
	int (*split)(struct vm_area_struct___264 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___264 *);
	vm_fault_t (*fault)(struct vm_fault___252 *);
	vm_fault_t (*huge_fault)(struct vm_fault___252 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___252 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___264 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___252 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___252 *);
	int (*access)(struct vm_area_struct___264 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___264 *);
	int (*set_policy)(struct vm_area_struct___264 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___264 *, long unsigned int);
	struct page___264 * (*find_special_page)(struct vm_area_struct___264 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___227;

struct attribute_group___228 {
	const char *name;
	umode_t (*is_visible)(struct kobject___251 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___251 *, struct bin_attribute___227 *, int);
	struct attribute **attrs;
	struct bin_attribute___227 **bin_attrs;
};

struct bin_attribute___227 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___263 *, struct kobject___251 *, struct bin_attribute___227 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___263 *, struct kobject___251 *, struct bin_attribute___227 *, char *, loff_t, size_t);
	int (*mmap)(struct file___263 *, struct kobject___251 *, struct bin_attribute___227 *, struct vm_area_struct___264 *);
};

struct sysfs_ops___250 {
	ssize_t (*show)(struct kobject___251 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___251 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___250;

struct kset___250 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___251 kobj;
	const struct kset_uevent_ops___250 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___250 {
	void (*release)(struct kobject___251 *);
	const struct sysfs_ops___250 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___24 * (*child_ns_type)(struct kobject___251 *);
	const void * (*namespace)(struct kobject___251 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___250 {
	int (* const filter)(struct kset___250 *, struct kobject___251 *);
	const char * (* const name)(struct kset___250 *, struct kobject___251 *);
	int (* const uevent)(struct kset___250 *, struct kobject___251 *, struct kobj_uevent_env *);
};

struct kobj_attribute___243 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___251 *, struct kobj_attribute___243 *, char *);
	ssize_t (*store)(struct kobject___251 *, struct kobj_attribute___243 *, const char *, size_t);
};

struct dev_pm_ops___226 {
	int (*prepare)(struct device___226 *);
	void (*complete)(struct device___226 *);
	int (*suspend)(struct device___226 *);
	int (*resume)(struct device___226 *);
	int (*freeze)(struct device___226 *);
	int (*thaw)(struct device___226 *);
	int (*poweroff)(struct device___226 *);
	int (*restore)(struct device___226 *);
	int (*suspend_late)(struct device___226 *);
	int (*resume_early)(struct device___226 *);
	int (*freeze_late)(struct device___226 *);
	int (*thaw_early)(struct device___226 *);
	int (*poweroff_late)(struct device___226 *);
	int (*restore_early)(struct device___226 *);
	int (*suspend_noirq)(struct device___226 *);
	int (*resume_noirq)(struct device___226 *);
	int (*freeze_noirq)(struct device___226 *);
	int (*thaw_noirq)(struct device___226 *);
	int (*poweroff_noirq)(struct device___226 *);
	int (*restore_noirq)(struct device___226 *);
	int (*runtime_suspend)(struct device___226 *);
	int (*runtime_resume)(struct device___226 *);
	int (*runtime_idle)(struct device___226 *);
};

struct dev_pm_domain___226 {
	struct dev_pm_ops___226 ops;
	void (*detach)(struct device___226 *, bool);
	int (*activate)(struct device___226 *);
	void (*sync)(struct device___226 *);
	void (*dismiss)(struct device___226 *);
};

struct bus_type___226 {
	const char *name;
	const char *dev_name;
	struct device___226 *dev_root;
	const struct attribute_group___228 **bus_groups;
	const struct attribute_group___228 **dev_groups;
	const struct attribute_group___228 **drv_groups;
	int (*match)(struct device___226 *, struct device_driver___226 *);
	int (*uevent)(struct device___226 *, struct kobj_uevent_env *);
	int (*probe)(struct device___226 *);
	int (*remove)(struct device___226 *);
	void (*shutdown)(struct device___226 *);
	int (*online)(struct device___226 *);
	int (*offline)(struct device___226 *);
	int (*suspend)(struct device___226 *, pm_message_t);
	int (*resume)(struct device___226 *);
	int (*num_vf)(struct device___226 *);
	int (*dma_configure)(struct device___226 *);
	const struct dev_pm_ops___226 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___226 {
	const char *name;
	struct bus_type___226 *bus;
	struct module___11 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___226 *);
	int (*remove)(struct device___226 *);
	void (*shutdown)(struct device___226 *);
	int (*suspend)(struct device___226 *, pm_message_t);
	int (*resume)(struct device___226 *);
	const struct attribute_group___228 **groups;
	const struct dev_pm_ops___226 *pm;
	void (*coredump)(struct device___226 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct fwnode_operations___161;

struct fwnode_handle___161 {
	struct fwnode_handle___161 *secondary;
	const struct fwnode_operations___161 *ops;
};

struct dentry_operations___262;

struct super_block___262;

struct dentry___263 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___263 *d_parent;
	struct qstr d_name;
	struct inode___263 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___262 *d_op;
	struct super_block___262 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___262;

struct address_space___262 {
	struct inode___263 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___264 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___262 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___262;

struct block_device___263;

struct inode___263 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___262 *i_op;
	struct super_block___262 *i_sb;
	struct address_space___262 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___264 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___132 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___263 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___262 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___263 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___262 {
	int (*d_revalidate)(struct dentry___263 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___263 *, unsigned int);
	int (*d_hash)(const struct dentry___263 *, struct qstr *);
	int (*d_compare)(const struct dentry___263 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___263 *);
	int (*d_init)(struct dentry___263 *);
	void (*d_release)(struct dentry___263 *);
	void (*d_prune)(struct dentry___263 *);
	void (*d_iput)(struct dentry___263 *, struct inode___263 *);
	char * (*d_dname)(struct dentry___263 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___263 *);
	int (*d_manage)(const struct path___263 *, bool);
	struct dentry___263 * (*d_real)(struct dentry___263 *, const struct inode___263 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___262;

struct mem_dqinfo___262 {
	struct quota_format_type___262 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___262;

struct quota_info___262 {
	unsigned int flags;
	struct rw_semaphore___264 dqio_sem;
	struct inode___263 *files[3];
	struct mem_dqinfo___262 info[3];
	const struct quota_format_ops___262 *ops[3];
};

struct rcuwait___262 {
	struct task_struct___264 *task;
};

struct percpu_rw_semaphore___262 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___264 rw_sem;
	struct rcuwait___262 writer;
	int readers_block;
};

struct sb_writers___262 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___262 rw_sem[3];
};

struct file_system_type___262;

struct super_operations___262;

struct dquot_operations___262;

struct quotactl_ops___262;

struct super_block___262 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___262 *s_type;
	const struct super_operations___262 *s_op;
	const struct dquot_operations___262 *dq_op;
	const struct quotactl_ops___262 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___263 *s_root;
	struct rw_semaphore___264 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___263 *s_bdev;
	struct backing_dev_info___132 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___262 s_dquot;
	struct sb_writers___262 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___262 *s_d_op;
	int cleancache_poolid;
	struct shrinker___112 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

typedef int (*dev_page_fault_t___252)(struct vm_area_struct___264 *, long unsigned int, const struct page___264 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___252)(struct page___264 *, void *);

struct dev_pagemap___252 {
	dev_page_fault_t___252 page_fault;
	dev_page_free_t___252 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___226 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___263 {
	struct task_struct___264 *task;
	struct core_thread___263 *next;
};

struct core_state___263 {
	atomic_t nr_threads;
	struct core_thread___263 dumper;
	struct completion startup;
};

struct vm_fault___252 {
	struct vm_area_struct___264 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___264 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___264 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___263 prealloc_pte;
};

struct io_cq___67 {
	struct request_queue___64 *q;
	struct io_context___67 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___6 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___263 {
	struct file___263 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___263 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___262 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___263 *ia_file;
};

struct dquot___262 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___262 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___262 {
	int qf_fmt_id;
	const struct quota_format_ops___262 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___262 *qf_next;
};

struct quota_format_ops___262 {
	int (*check_quota_file)(struct super_block___262 *, int);
	int (*read_file_info)(struct super_block___262 *, int);
	int (*write_file_info)(struct super_block___262 *, int);
	int (*free_file_info)(struct super_block___262 *, int);
	int (*read_dqblk)(struct dquot___262 *);
	int (*commit_dqblk)(struct dquot___262 *);
	int (*release_dqblk)(struct dquot___262 *);
	int (*get_next_id)(struct super_block___262 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___262 {
	int (*write_dquot)(struct dquot___262 *);
	struct dquot___262 * (*alloc_dquot)(struct super_block___262 *, int);
	void (*destroy_dquot)(struct dquot___262 *);
	int (*acquire_dquot)(struct dquot___262 *);
	int (*release_dquot)(struct dquot___262 *);
	int (*mark_dirty)(struct dquot___262 *);
	int (*write_info)(struct super_block___262 *, int);
	qsize_t * (*get_reserved_space)(struct inode___263 *);
	int (*get_projid)(struct inode___263 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___263 *, qsize_t *);
	int (*get_next_id)(struct super_block___262 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___262 {
	int (*quota_on)(struct super_block___262 *, int, int, const struct path___263 *);
	int (*quota_off)(struct super_block___262 *, int);
	int (*quota_enable)(struct super_block___262 *, unsigned int);
	int (*quota_disable)(struct super_block___262 *, unsigned int);
	int (*quota_sync)(struct super_block___262 *, int);
	int (*set_info)(struct super_block___262 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___262 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___262 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___262 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___262 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___262 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___262 {
	int (*writepage)(struct page___264 *, struct writeback_control___3 *);
	int (*readpage)(struct file___263 *, struct page___264 *);
	int (*writepages)(struct address_space___262 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___264 *);
	int (*readpages)(struct file___263 *, struct address_space___262 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___263 *, struct address_space___262 *, loff_t, unsigned int, unsigned int, struct page___264 **, void **);
	int (*write_end)(struct file___263 *, struct address_space___262 *, loff_t, unsigned int, unsigned int, struct page___264 *, void *);
	sector_t (*bmap)(struct address_space___262 *, sector_t);
	void (*invalidatepage)(struct page___264 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___264 *, gfp_t);
	void (*freepage)(struct page___264 *);
	ssize_t (*direct_IO)(struct kiocb___263 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___262 *, struct page___264 *, struct page___264 *, enum migrate_mode);
	bool (*isolate_page)(struct page___264 *, isolate_mode_t);
	void (*putback_page)(struct page___264 *);
	int (*launder_page)(struct page___264 *);
	int (*is_partially_uptodate)(struct page___264 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___264 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___262 *, struct page___264 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___263 *, sector_t *);
	void (*swap_deactivate)(struct file___263 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___263 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___263 *bd_inode;
	struct super_block___262 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___263 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___64 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___64 *bd_disk;
	struct request_queue___64 *bd_queue;
	struct backing_dev_info___132 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___262 {
	struct dentry___263 * (*lookup)(struct inode___263 *, struct dentry___263 *, unsigned int);
	const char * (*get_link)(struct dentry___263 *, struct inode___263 *, struct delayed_call *);
	int (*permission)(struct inode___263 *, int);
	struct posix_acl * (*get_acl)(struct inode___263 *, int);
	int (*readlink)(struct dentry___263 *, char *, int);
	int (*create)(struct inode___263 *, struct dentry___263 *, umode_t, bool);
	int (*link)(struct dentry___263 *, struct inode___263 *, struct dentry___263 *);
	int (*unlink)(struct inode___263 *, struct dentry___263 *);
	int (*symlink)(struct inode___263 *, struct dentry___263 *, const char *);
	int (*mkdir)(struct inode___263 *, struct dentry___263 *, umode_t);
	int (*rmdir)(struct inode___263 *, struct dentry___263 *);
	int (*mknod)(struct inode___263 *, struct dentry___263 *, umode_t, dev_t);
	int (*rename)(struct inode___263 *, struct dentry___263 *, struct inode___263 *, struct dentry___263 *, unsigned int);
	int (*setattr)(struct dentry___263 *, struct iattr___262 *);
	int (*getattr)(const struct path___263 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___263 *, char *, size_t);
	int (*fiemap)(struct inode___263 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___263 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___263 *, struct dentry___263 *, struct file___263 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___263 *, struct dentry___263 *, umode_t);
	int (*set_acl)(struct inode___263 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___262 {
	void (*fl_copy_lock)(struct file_lock___263 *, struct file_lock___263 *);
	void (*fl_release_private)(struct file_lock___263 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___262;

struct lock_manager_operations___262;

struct file_lock___263 {
	struct file_lock___263 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___263 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___262 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___262 *fl_ops;
	const struct lock_manager_operations___262 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___262 {
	int (*lm_compare_owner)(struct file_lock___263 *, struct file_lock___263 *);
	long unsigned int (*lm_owner_key)(struct file_lock___263 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___263 *);
	int (*lm_grant)(struct file_lock___263 *, int);
	bool (*lm_break)(struct file_lock___263 *);
	int (*lm_change)(struct file_lock___263 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___263 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___262 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___262 *fa_next;
	struct file___263 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___262 {
	const char *name;
	int fs_flags;
	struct dentry___263 * (*mount)(struct file_system_type___262 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___262 *);
	struct module___11 *owner;
	struct file_system_type___262 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___262 {
	struct inode___263 * (*alloc_inode)(struct super_block___262 *);
	void (*destroy_inode)(struct inode___263 *);
	void (*dirty_inode)(struct inode___263 *, int);
	int (*write_inode)(struct inode___263 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___263 *);
	void (*evict_inode)(struct inode___263 *);
	void (*put_super)(struct super_block___262 *);
	int (*sync_fs)(struct super_block___262 *, int);
	int (*freeze_super)(struct super_block___262 *);
	int (*freeze_fs)(struct super_block___262 *);
	int (*thaw_super)(struct super_block___262 *);
	int (*unfreeze_fs)(struct super_block___262 *);
	int (*statfs)(struct dentry___263 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___262 *, int *, char *);
	void (*umount_begin)(struct super_block___262 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___263 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___263 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___263 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___263 *);
	ssize_t (*quota_read)(struct super_block___262 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___262 *, int, const char *, size_t, loff_t);
	struct dquot___262 ** (*get_dquots)(struct inode___263 *);
	int (*bdev_try_to_free_page)(struct super_block___262 *, struct page___264 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___262 *, struct shrink_control___112 *);
	long int (*free_cached_objects)(struct super_block___262 *, struct shrink_control___112 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___64 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___64 *last_lookup;
	struct hd_struct___64 *part[0];
};

struct block_device_operations___64 {
	int (*open)(struct block_device___263 *, fmode_t);
	void (*release)(struct gendisk___64 *, fmode_t);
	int (*rw_page)(struct block_device___263 *, sector_t, struct page___264 *, unsigned int);
	int (*ioctl)(struct block_device___263 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___263 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___64 *, unsigned int);
	int (*media_changed)(struct gendisk___64 *);
	void (*unlock_native_capacity)(struct gendisk___64 *);
	int (*revalidate_disk)(struct gendisk___64 *);
	int (*getgeo)(struct block_device___263 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___263 *, long unsigned int);
	int (*report_zones)(struct gendisk___64 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___11 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___252(struct page___264 *);

struct bdi_writeback_congested___132 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___132 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bsg_ops___63 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___64 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___64 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___64 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___63(struct request___64 *, blk_status_t);

struct request___64 {
	struct request_queue___64 *q;
	struct blk_mq_ctx___9 *mq_ctx;
	struct blk_mq_hw_ctx___9 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___132 *bio;
	struct bio___132 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___132 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___67 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___63 *saved_end_io;
		} flush;
	};
	struct gendisk___64 *rq_disk;
	struct hd_struct___64 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___63 *end_io;
	void *end_io_data;
	struct request___64 *next_rq;
};

struct fwnode_reference_args___161;

struct fwnode_endpoint___161;

struct fwnode_operations___161 {
	struct fwnode_handle___161 * (*get)(struct fwnode_handle___161 *);
	void (*put)(struct fwnode_handle___161 *);
	bool (*device_is_available)(const struct fwnode_handle___161 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___161 *, const struct device___226 *);
	bool (*property_present)(const struct fwnode_handle___161 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___161 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___161 *, const char *, const char **, size_t);
	struct fwnode_handle___161 * (*get_parent)(const struct fwnode_handle___161 *);
	struct fwnode_handle___161 * (*get_next_child_node)(const struct fwnode_handle___161 *, struct fwnode_handle___161 *);
	struct fwnode_handle___161 * (*get_named_child_node)(const struct fwnode_handle___161 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___161 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___161 *);
	struct fwnode_handle___161 * (*graph_get_next_endpoint)(const struct fwnode_handle___161 *, struct fwnode_handle___161 *);
	struct fwnode_handle___161 * (*graph_get_remote_endpoint)(const struct fwnode_handle___161 *);
	struct fwnode_handle___161 * (*graph_get_port_parent)(struct fwnode_handle___161 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___161 *, struct fwnode_endpoint___161 *);
};

struct fwnode_endpoint___161 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___161 *local_fwnode;
};

struct fwnode_reference_args___161 {
	struct fwnode_handle___161 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct blk_mq_ctxs___8;

struct blk_mq_ctx___9 {
	struct {
		spinlock_t lock;
		struct list_head rq_lists[3];
		long: 64;
	};
	unsigned int cpu;
	short unsigned int index_hw[3];
	struct blk_mq_hw_ctx___9 *hctxs[3];
	long unsigned int rq_dispatched[2];
	long unsigned int rq_merged;
	long unsigned int rq_completed[2];
	struct request_queue___64 *queue;
	struct blk_mq_ctxs___8 *ctxs;
	struct kobject___251 kobj;
};

struct blk_mq_tags___8;

struct blk_mq_hw_ctx___9 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___64 *queue;
	struct blk_flush_queue___9 *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx___9 *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx___9 **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags___8 *tags;
	struct blk_mq_tags___8 *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	unsigned int rh_reserved_nr_expired;
	struct hlist_node cpuhp_dead;
	struct kobject___251 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___263 *debugfs_dir;
	struct dentry___263 *sched_debugfs_dir;
	struct list_head hctx_list;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___63;

struct blk_mq_alloc_data___9;

struct elevator_mq_ops___63 {
	int (*init_sched)(struct request_queue___64 *, struct elevator_type___63 *);
	void (*exit_sched)(struct elevator_queue___63 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___9 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___9 *, unsigned int);
	bool (*allow_merge)(struct request_queue___64 *, struct request___64 *, struct bio___132 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx___9 *, struct bio___132 *);
	int (*request_merge)(struct request_queue___64 *, struct request___64 **, struct bio___132 *);
	void (*request_merged)(struct request_queue___64 *, struct request___64 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___64 *, struct request___64 *, struct request___64 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data___9 *);
	void (*prepare_request)(struct request___64 *, struct bio___132 *);
	void (*finish_request)(struct request___64 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___9 *, struct list_head *, bool);
	struct request___64 * (*dispatch_request)(struct blk_mq_hw_ctx___9 *);
	bool (*has_work)(struct blk_mq_hw_ctx___9 *);
	void (*completed_request)(struct request___64 *, u64);
	void (*started_request)(struct request___64 *);
	void (*requeue_request)(struct request___64 *);
	struct request___64 * (*former_request)(struct request_queue___64 *, struct request___64 *);
	struct request___64 * (*next_request)(struct request_queue___64 *, struct request___64 *);
	void (*init_icq)(struct io_cq___67 *);
	void (*exit_icq)(struct io_cq___67 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx___9 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___63;

struct elevator_type___63 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___63 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___63 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___11 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___63 {
	struct elevator_type___63 *type;
	void *elevator_data;
	struct kobject___251 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct blk_mq_alloc_data___9 {
	struct request_queue___64 *q;
	blk_mq_req_flags_t flags;
	unsigned int shallow_depth;
	unsigned int cmd_flags;
	struct blk_mq_ctx___9 *ctx;
	struct blk_mq_hw_ctx___9 *hctx;
};

struct elv_fs_entry___63 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___63 *, char *);
	ssize_t (*store)(struct elevator_queue___63 *, const char *, size_t);
};

struct blk_queue_stats {
	struct list_head callbacks;
	spinlock_t lock;
	bool enable_accounting;
};

struct blk_mq_queue_data___9;

typedef blk_status_t queue_rq_fn___9(struct blk_mq_hw_ctx___9 *, const struct blk_mq_queue_data___9 *);

typedef void commit_rqs_fn___9(struct blk_mq_hw_ctx___9 *);

typedef bool get_budget_fn___9(struct blk_mq_hw_ctx___9 *);

typedef void put_budget_fn___9(struct blk_mq_hw_ctx___9 *);

typedef enum blk_eh_timer_return timeout_fn___9(struct request___64 *, bool);

typedef int poll_fn___9(struct blk_mq_hw_ctx___9 *);

typedef void complete_fn___9(struct request___64 *);

typedef int init_hctx_fn___9(struct blk_mq_hw_ctx___9 *, void *, unsigned int);

typedef void exit_hctx_fn___9(struct blk_mq_hw_ctx___9 *, unsigned int);

typedef int init_request_fn___9(struct blk_mq_tag_set___9 *, struct request___64 *, unsigned int, unsigned int);

typedef void exit_request_fn___9(struct blk_mq_tag_set___9 *, struct request___64 *, unsigned int);

typedef bool busy_fn___9(struct request_queue___64 *);

typedef int map_queues_fn___9(struct blk_mq_tag_set___9 *);

typedef void cleanup_rq_fn___9(struct request___64 *);

struct blk_mq_ops___9 {
	queue_rq_fn___9 *queue_rq;
	commit_rqs_fn___9 *commit_rqs;
	get_budget_fn___9 *get_budget;
	put_budget_fn___9 *put_budget;
	timeout_fn___9 *timeout;
	poll_fn___9 *poll;
	complete_fn___9 *complete;
	init_hctx_fn___9 *init_hctx;
	exit_hctx_fn___9 *exit_hctx;
	init_request_fn___9 *init_request;
	exit_request_fn___9 *exit_request;
	void (*initialize_rq_fn)(struct request___64 *);
	busy_fn___9 *busy;
	map_queues_fn___9 *map_queues;
	void (*show_rq)(struct seq_file___9 *, struct request___64 *);
	union {
		cleanup_rq_fn___9 *cleanup_rq;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide42;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct blk_stat_callback___9 {
	struct list_head list;
	struct timer_list timer;
	struct blk_rq_stat *cpu_stat;
	int (*bucket_fn)(const struct request___64 *);
	unsigned int buckets;
	struct blk_rq_stat *stat;
	void (*timer_fn)(struct blk_stat_callback___9 *);
	void *data;
	struct callback_head rcu;
};

struct blk_flush_queue___9 {
	unsigned int flush_queue_delayed: 1;
	unsigned int flush_pending_idx: 1;
	unsigned int flush_running_idx: 1;
	long unsigned int flush_pending_since;
	struct list_head flush_queue[2];
	struct list_head flush_data_in_flight;
	struct request___64 *flush_rq;
	struct request___64 *orig_rq;
	spinlock_t mq_flush_lock;
};

struct blk_mq_tag_set___9 {
	struct blk_mq_queue_map map[6];
	unsigned int nr_maps;
	const struct blk_mq_ops___9 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	struct blk_mq_tags___8 **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct blk_mq_tags___8 {
	unsigned int nr_tags;
	unsigned int nr_reserved_tags;
	atomic_t active_queues;
	struct sbitmap_queue bitmap_tags;
	struct sbitmap_queue breserved_tags;
	struct request___64 **rqs;
	struct request___64 **static_rqs;
	struct list_head page_list;
};

struct blk_mq_queue_data___9 {
	struct request___64 *rq;
	bool last;
	long unsigned int rh_reserved1;
};

struct blk_mq_ctxs___8 {
	struct kobject___251 kobj;
	struct blk_mq_ctx___9 *queue_ctx;
};

struct blk_mq_ctx_sysfs_entry {
	struct attribute attr;
	ssize_t (*show)(struct blk_mq_ctx___5 *, char *);
	ssize_t (*store)(struct blk_mq_ctx___5 *, const char *, size_t);
};

struct blk_mq_hw_ctx_sysfs_entry {
	struct attribute attr;
	ssize_t (*show)(struct blk_mq_hw_ctx___5 *, char *);
	ssize_t (*store)(struct blk_mq_hw_ctx___5 *, const char *, size_t);
};

struct module___216;

struct file___264;

struct kiocb___264;

struct iov_iter___129;

struct poll_table_struct___163;

struct vm_area_struct___265;

struct inode___264;

struct file_lock___264;

struct page___265;

struct file_operations___264 {
	struct module___216 *owner;
	loff_t (*llseek)(struct file___264 *, loff_t, int);
	ssize_t (*read)(struct file___264 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___264 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___264 *, struct iov_iter___129 *);
	ssize_t (*write_iter)(struct kiocb___264 *, struct iov_iter___129 *);
	int (*iopoll)(struct kiocb___264 *, bool);
	int (*iterate)(struct file___264 *, struct dir_context *);
	int (*iterate_shared)(struct file___264 *, struct dir_context *);
	__poll_t (*poll)(struct file___264 *, struct poll_table_struct___163 *);
	long int (*unlocked_ioctl)(struct file___264 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___264 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___264 *, struct vm_area_struct___265 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___264 *, struct file___264 *);
	int (*flush)(struct file___264 *, fl_owner_t);
	int (*release)(struct inode___264 *, struct file___264 *);
	int (*fsync)(struct file___264 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___264 *, int);
	int (*lock)(struct file___264 *, int, struct file_lock___264 *);
	ssize_t (*sendpage)(struct file___264 *, struct page___265 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___264 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___264 *, int, struct file_lock___264 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___264 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___264 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___264 *, long int, struct file_lock___264 **, void **);
	long int (*fallocate)(struct file___264 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___4 *, struct file___264 *);
	ssize_t (*copy_file_range)(struct file___264 *, loff_t, struct file___264 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___264 *, loff_t, struct file___264 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___264 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___264 {
	u64 seqnum;
	struct vm_area_struct___265 *vmas[4];
};

struct page_frag___264 {
	struct page___265 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___264;

struct cred___254;

struct bio_list___133;

struct backing_dev_info___133;

struct io_context___68;

struct vm_struct___180;

struct task_struct___265 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___265 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___264 *mm;
	struct mm_struct___264 *active_mm;
	struct vmacache___264 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___265 *real_parent;
	struct task_struct___265 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___265 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___190 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___190 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___190 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___254 *ptracer_cred;
	const struct cred___254 *real_cred;
	const struct cred___254 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___265 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___133 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___133 *backing_dev_info;
	struct io_context___68 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___264 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___2 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___265 *oom_reaper_list;
	struct vm_struct___180 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___128 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___265 *pgtable_t___264;

struct address_space___263;

struct dev_pagemap___253;

struct page___265 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___263 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___265 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___264 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___264 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___253 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___264;

struct lruvec___264 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___264 *pgdat;
};

struct zone___264 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___264 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___264 {
	struct zone___264 *zone;
	int zone_idx;
};

struct zonelist___264 {
	struct zoneref___264 _zonerefs[25];
};

struct pglist_data___264 {
	struct zone___264 node_zones[3];
	struct zonelist___264 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___265 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___265 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___264 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___265 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___265 *owner;
};

struct secondary_data___265 {
	void *stack;
	struct task_struct___265 *task;
	long int status;
};

struct blocking_notifier_head___264 {
	struct rw_semaphore___265 rwsem;
	struct notifier_block *head;
};

struct dentry___264;

struct path___264 {
	struct vfsmount *mnt;
	struct dentry___264 *dentry;
};

struct file___264 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___264 f_path;
	struct inode___264 *f_inode;
	const struct file_operations___264 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___190 f_owner;
	const struct cred___254 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___263 *f_mapping;
	errseq_t f_wb_err;
};

struct key___254;

struct user_struct___254;

struct cred___254 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___254 *session_keyring;
	struct key___254 *process_keyring;
	struct key___254 *thread_keyring;
	struct key___254 *request_key_auth;
	void *security;
	struct user_struct___254 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___258;

struct kernfs_elem_dir___258 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___258 *root;
};

struct kernfs_node___259;

struct kernfs_syscall_ops___258;

struct kernfs_root___258 {
	struct kernfs_node___259 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___258 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___258 {
	struct kernfs_node___259 *target_kn;
};

struct kernfs_ops___258;

struct kernfs_elem_attr___258 {
	const struct kernfs_ops___258 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___259 *notify_next;
};

struct kernfs_node___259 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___259 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___258 dir;
		struct kernfs_elem_symlink___258 symlink;
		struct kernfs_elem_attr___258 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___258;

struct kernfs_ops___258 {
	int (*open)(struct kernfs_open_file___258 *);
	void (*release)(struct kernfs_open_file___258 *);
	int (*seq_show)(struct seq_file___4 *, void *);
	void * (*seq_start)(struct seq_file___4 *, loff_t *);
	void * (*seq_next)(struct seq_file___4 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___4 *, void *);
	ssize_t (*read)(struct kernfs_open_file___258 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___258 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___258 *, struct vm_area_struct___265 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___258 *, struct poll_table_struct___163 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___258 {
	int (*remount_fs)(struct kernfs_root___258 *, int *, char *);
	int (*show_options)(struct seq_file___4 *, struct kernfs_root___258 *);
	int (*mkdir)(struct kernfs_node___259 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___259 *);
	int (*rename)(struct kernfs_node___259 *, struct kernfs_node___259 *, const char *);
	int (*show_path)(struct seq_file___4 *, struct kernfs_node___259 *, struct kernfs_root___258 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___232;

struct seq_file___4 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___232 *op;
	int poll_event;
	const struct file___264 *file;
	void *private;
};

struct vm_operations_struct___253;

struct kernfs_open_file___258 {
	struct kernfs_node___259 *kn;
	struct file___264 *file;
	struct seq_file___4 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___253 *vm_ops;
};

struct vm_fault___253;

struct vm_operations_struct___253 {
	void (*open)(struct vm_area_struct___265 *);
	void (*close)(struct vm_area_struct___265 *);
	int (*split)(struct vm_area_struct___265 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___265 *);
	vm_fault_t (*fault)(struct vm_fault___253 *);
	vm_fault_t (*huge_fault)(struct vm_fault___253 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___253 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___265 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___253 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___253 *);
	int (*access)(struct vm_area_struct___265 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___265 *);
	int (*set_policy)(struct vm_area_struct___265 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___265 *, long unsigned int);
	struct page___265 * (*find_special_page)(struct vm_area_struct___265 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___165)(struct file___264 *, wait_queue_head_t *, struct poll_table_struct___163 *);

struct poll_table_struct___163 {
	poll_queue_proc___165 _qproc;
	__poll_t _key;
};

struct vm_area_struct___265 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___265 *vm_next;
	struct vm_area_struct___265 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___264 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___253 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___264 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___252;

struct bin_attribute___228;

struct attribute_group___229 {
	const char *name;
	umode_t (*is_visible)(struct kobject___252 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___252 *, struct bin_attribute___228 *, int);
	struct attribute **attrs;
	struct bin_attribute___228 **bin_attrs;
};

struct kset___251;

struct kobj_type___251;

struct kobject___252 {
	const char *name;
	struct list_head entry;
	struct kobject___252 *parent;
	struct kset___251 *kset;
	struct kobj_type___251 *ktype;
	struct kernfs_node___259 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___228 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___264 *, struct kobject___252 *, struct bin_attribute___228 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___264 *, struct kobject___252 *, struct bin_attribute___228 *, char *, loff_t, size_t);
	int (*mmap)(struct file___264 *, struct kobject___252 *, struct bin_attribute___228 *, struct vm_area_struct___265 *);
};

struct sysfs_ops___251 {
	ssize_t (*show)(struct kobject___252 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___252 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___251;

struct kset___251 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___252 kobj;
	const struct kset_uevent_ops___251 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___251 {
	void (*release)(struct kobject___252 *);
	const struct sysfs_ops___251 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___24 * (*child_ns_type)(struct kobject___252 *);
	const void * (*namespace)(struct kobject___252 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___251 {
	int (* const filter)(struct kset___251 *, struct kobject___252 *);
	const char * (* const name)(struct kset___251 *, struct kobject___252 *);
	int (* const uevent)(struct kset___251 *, struct kobject___252 *, struct kobj_uevent_env *);
};

struct kobj_attribute___244 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___252 *, struct kobj_attribute___244 *, char *);
	ssize_t (*store)(struct kobject___252 *, struct kobj_attribute___244 *, const char *, size_t);
};

struct kernel_param___213;

struct kernel_param_ops___213 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___213 *);
	int (*get)(char *, const struct kernel_param___213 *);
	void (*free)(void *);
};

struct kparam_array___213;

struct kernel_param___213 {
	const char *name;
	struct module___216 *mod;
	const struct kernel_param_ops___213 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___213 *arr;
	};
};

struct kparam_array___213 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___213 *ops;
	void *elem;
};

struct module_kobject___213 {
	struct kobject___252 kobj;
	struct module___216 *mod;
	struct kobject___252 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___213 {
	struct module___216 *mod;
	struct latch_tree_node node;
};

struct module_layout___213 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___213 mtn;
};

struct module_attribute___213;

struct module___216 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___213 mkobj;
	struct module_attribute___213 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___252 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___213 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___213 core_layout;
	struct module_layout___213 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___213 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___213 *, struct module_kobject___213 *, char *);
	ssize_t (*store)(struct module_attribute___213 *, struct module_kobject___213 *, const char *, size_t);
	void (*setup)(struct module___216 *, const char *);
	int (*test)(struct module___216 *);
	void (*free)(struct module___216 *);
};

struct user_struct___254 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___254 *uid_keyring;
	struct key___254 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___264;

struct mm_struct___264 {
	struct {
		struct vm_area_struct___265 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___264 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___265 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___264 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___265 *owner;
		struct user_namespace___3 *user_ns;
		struct file___264 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___264 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct bio___133;

struct bio_list___133 {
	struct bio___133 *head;
	struct bio___133 *tail;
};

struct bdi_writeback_congested___133;

struct bdi_writeback___133 {
	struct backing_dev_info___133 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___133 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___157 *memcg_css;
	struct cgroup_subsys_state___157 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___227;

struct backing_dev_info___133 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___133 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___227 *dev;
	struct device___227 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___264 *debug_dir;
	struct dentry___264 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___68;

struct io_context___68 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___68 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

typedef blk_qc_t make_request_fn___64(struct request_queue___2 *, struct bio___133 *);

typedef int dma_drain_needed_fn___64(struct request___2 *);

struct bsg_ops___64;

struct bsg_class_device___64 {
	struct device___227 *class_dev;
	int minor;
	struct request_queue___2 *queue;
	const struct bsg_ops___64 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___133 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___133 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___64;

struct rq_qos___6;

struct blk_trace___8;

struct request_queue___2 {
	struct list_head queue_head;
	struct request___2 *last_merge;
	struct elevator_queue___64 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos___6 *rq_qos;
	make_request_fn___64 *make_request_fn;
	dma_drain_needed_fn___64 *dma_drain_needed;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___2 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___133 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___252 kobj;
	struct kobject___252 *mq_kobj;
	struct blk_integrity integrity;
	struct device___227 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace___8 *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	struct bsg_class_device___64 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___133 bio_split;
	struct dentry___264 *debugfs_dir;
	struct dentry___264 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___180 {
	struct vm_struct___180 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___265 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bio_vec___133 {
	struct page___265 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

typedef void bio_end_io_t___133(struct bio___133 *);

struct gendisk___65;

struct bio_integrity_payload___133;

struct bio___133 {
	struct bio___133 *bi_next;
	struct gendisk___65 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___133 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___133 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___133 *bi_io_vec;
	struct bio_set___133 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___133 bi_inline_vecs[0];
};

struct bio_integrity_payload___133 {
	struct bio___133 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___133 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___133 bip_inline_vecs[0];
};

struct dev_pm_info___227 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___227 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___227;

struct bus_type___227;

struct device_driver___227;

struct dev_pm_domain___227;

struct fwnode_handle___162;

struct class___227;

struct device___227 {
	struct device___227 *parent;
	struct device_private *p;
	struct kobject___252 kobj;
	const char *init_name;
	const struct device_type___227 *type;
	struct mutex mutex;
	struct bus_type___227 *bus;
	struct device_driver___227 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___227 power;
	struct dev_pm_domain___227 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___162 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___227 *class;
	const struct attribute_group___229 **groups;
	void (*release)(struct device___227 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___65 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___227 __dev;
	struct kobject___252 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___65;

struct block_device_operations___65;

struct gendisk___65 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___65 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___65 *part_tbl;
	struct hd_struct___65 part0;
	const struct block_device_operations___65 *fops;
	struct request_queue___2 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___265 lookup_sem;
	struct kobject___252 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___252 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_ops___227;

struct device_type___227 {
	const char *name;
	const struct attribute_group___229 **groups;
	int (*uevent)(struct device___227 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___227 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___227 *);
	const struct dev_pm_ops___227 *pm;
};

struct class___227 {
	const char *name;
	struct module___216 *owner;
	const struct attribute_group___229 **class_groups;
	const struct attribute_group___229 **dev_groups;
	struct kobject___252 *dev_kobj;
	int (*dev_uevent)(struct device___227 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___227 *, umode_t *);
	void (*class_release)(struct class___227 *);
	void (*dev_release)(struct device___227 *);
	int (*shutdown_pre)(struct device___227 *);
	const struct kobj_ns_type_operations___24 *ns_type;
	const void * (*namespace)(struct device___227 *);
	const struct dev_pm_ops___227 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dev_pm_ops___227 {
	int (*prepare)(struct device___227 *);
	void (*complete)(struct device___227 *);
	int (*suspend)(struct device___227 *);
	int (*resume)(struct device___227 *);
	int (*freeze)(struct device___227 *);
	int (*thaw)(struct device___227 *);
	int (*poweroff)(struct device___227 *);
	int (*restore)(struct device___227 *);
	int (*suspend_late)(struct device___227 *);
	int (*resume_early)(struct device___227 *);
	int (*freeze_late)(struct device___227 *);
	int (*thaw_early)(struct device___227 *);
	int (*poweroff_late)(struct device___227 *);
	int (*restore_early)(struct device___227 *);
	int (*suspend_noirq)(struct device___227 *);
	int (*resume_noirq)(struct device___227 *);
	int (*freeze_noirq)(struct device___227 *);
	int (*thaw_noirq)(struct device___227 *);
	int (*poweroff_noirq)(struct device___227 *);
	int (*restore_noirq)(struct device___227 *);
	int (*runtime_suspend)(struct device___227 *);
	int (*runtime_resume)(struct device___227 *);
	int (*runtime_idle)(struct device___227 *);
};

struct dev_pm_domain___227 {
	struct dev_pm_ops___227 ops;
	void (*detach)(struct device___227 *, bool);
	int (*activate)(struct device___227 *);
	void (*sync)(struct device___227 *);
	void (*dismiss)(struct device___227 *);
};

struct bus_type___227 {
	const char *name;
	const char *dev_name;
	struct device___227 *dev_root;
	const struct attribute_group___229 **bus_groups;
	const struct attribute_group___229 **dev_groups;
	const struct attribute_group___229 **drv_groups;
	int (*match)(struct device___227 *, struct device_driver___227 *);
	int (*uevent)(struct device___227 *, struct kobj_uevent_env *);
	int (*probe)(struct device___227 *);
	int (*remove)(struct device___227 *);
	void (*shutdown)(struct device___227 *);
	int (*online)(struct device___227 *);
	int (*offline)(struct device___227 *);
	int (*suspend)(struct device___227 *, pm_message_t);
	int (*resume)(struct device___227 *);
	int (*num_vf)(struct device___227 *);
	int (*dma_configure)(struct device___227 *);
	const struct dev_pm_ops___227 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___227 {
	const char *name;
	struct bus_type___227 *bus;
	struct module___216 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___227 *);
	int (*remove)(struct device___227 *);
	void (*shutdown)(struct device___227 *);
	int (*suspend)(struct device___227 *, pm_message_t);
	int (*resume)(struct device___227 *);
	const struct attribute_group___229 **groups;
	const struct dev_pm_ops___227 *pm;
	void (*coredump)(struct device___227 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct fwnode_operations___162;

struct fwnode_handle___162 {
	struct fwnode_handle___162 *secondary;
	const struct fwnode_operations___162 *ops;
};

struct dentry_operations___263;

struct super_block___263;

struct dentry___264 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___264 *d_parent;
	struct qstr d_name;
	struct inode___264 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___263 *d_op;
	struct super_block___263 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___263;

struct address_space___263 {
	struct inode___264 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___265 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___263 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___263;

struct block_device___264;

struct inode___264 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___263 *i_op;
	struct super_block___263 *i_sb;
	struct address_space___263 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___265 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___133 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___264 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___263 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___264 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___263 {
	int (*d_revalidate)(struct dentry___264 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___264 *, unsigned int);
	int (*d_hash)(const struct dentry___264 *, struct qstr *);
	int (*d_compare)(const struct dentry___264 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___264 *);
	int (*d_init)(struct dentry___264 *);
	void (*d_release)(struct dentry___264 *);
	void (*d_prune)(struct dentry___264 *);
	void (*d_iput)(struct dentry___264 *, struct inode___264 *);
	char * (*d_dname)(struct dentry___264 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___264 *);
	int (*d_manage)(const struct path___264 *, bool);
	struct dentry___264 * (*d_real)(struct dentry___264 *, const struct inode___264 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___263;

struct mem_dqinfo___263 {
	struct quota_format_type___263 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___263;

struct quota_info___263 {
	unsigned int flags;
	struct rw_semaphore___265 dqio_sem;
	struct inode___264 *files[3];
	struct mem_dqinfo___263 info[3];
	const struct quota_format_ops___263 *ops[3];
};

struct rcuwait___263 {
	struct task_struct___265 *task;
};

struct percpu_rw_semaphore___263 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___265 rw_sem;
	struct rcuwait___263 writer;
	int readers_block;
};

struct sb_writers___263 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___263 rw_sem[3];
};

struct file_system_type___263;

struct super_operations___263;

struct dquot_operations___263;

struct quotactl_ops___263;

struct super_block___263 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___263 *s_type;
	const struct super_operations___263 *s_op;
	const struct dquot_operations___263 *dq_op;
	const struct quotactl_ops___263 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___264 *s_root;
	struct rw_semaphore___265 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___264 *s_bdev;
	struct backing_dev_info___133 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___263 s_dquot;
	struct sb_writers___263 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___263 *s_d_op;
	int cleancache_poolid;
	struct shrinker___112 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

typedef int (*dev_page_fault_t___253)(struct vm_area_struct___265 *, long unsigned int, const struct page___265 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___253)(struct page___265 *, void *);

struct dev_pagemap___253 {
	dev_page_fault_t___253 page_fault;
	dev_page_free_t___253 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___227 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___264 {
	struct task_struct___265 *task;
	struct core_thread___264 *next;
};

struct core_state___264 {
	atomic_t nr_threads;
	struct core_thread___264 dumper;
	struct completion startup;
};

struct vm_fault___253 {
	struct vm_area_struct___265 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___265 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___265 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___264 prealloc_pte;
};

struct io_cq___68 {
	struct request_queue___2 *q;
	struct io_context___68 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___6 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___264 {
	struct file___264 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___264 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___263 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___264 *ia_file;
};

struct dquot___263 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___263 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___263 {
	int qf_fmt_id;
	const struct quota_format_ops___263 *qf_ops;
	struct module___216 *qf_owner;
	struct quota_format_type___263 *qf_next;
};

struct quota_format_ops___263 {
	int (*check_quota_file)(struct super_block___263 *, int);
	int (*read_file_info)(struct super_block___263 *, int);
	int (*write_file_info)(struct super_block___263 *, int);
	int (*free_file_info)(struct super_block___263 *, int);
	int (*read_dqblk)(struct dquot___263 *);
	int (*commit_dqblk)(struct dquot___263 *);
	int (*release_dqblk)(struct dquot___263 *);
	int (*get_next_id)(struct super_block___263 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___263 {
	int (*write_dquot)(struct dquot___263 *);
	struct dquot___263 * (*alloc_dquot)(struct super_block___263 *, int);
	void (*destroy_dquot)(struct dquot___263 *);
	int (*acquire_dquot)(struct dquot___263 *);
	int (*release_dquot)(struct dquot___263 *);
	int (*mark_dirty)(struct dquot___263 *);
	int (*write_info)(struct super_block___263 *, int);
	qsize_t * (*get_reserved_space)(struct inode___264 *);
	int (*get_projid)(struct inode___264 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___264 *, qsize_t *);
	int (*get_next_id)(struct super_block___263 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___263 {
	int (*quota_on)(struct super_block___263 *, int, int, const struct path___264 *);
	int (*quota_off)(struct super_block___263 *, int);
	int (*quota_enable)(struct super_block___263 *, unsigned int);
	int (*quota_disable)(struct super_block___263 *, unsigned int);
	int (*quota_sync)(struct super_block___263 *, int);
	int (*set_info)(struct super_block___263 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___263 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___263 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___263 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___263 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___263 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___263 {
	int (*writepage)(struct page___265 *, struct writeback_control___3 *);
	int (*readpage)(struct file___264 *, struct page___265 *);
	int (*writepages)(struct address_space___263 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___265 *);
	int (*readpages)(struct file___264 *, struct address_space___263 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___264 *, struct address_space___263 *, loff_t, unsigned int, unsigned int, struct page___265 **, void **);
	int (*write_end)(struct file___264 *, struct address_space___263 *, loff_t, unsigned int, unsigned int, struct page___265 *, void *);
	sector_t (*bmap)(struct address_space___263 *, sector_t);
	void (*invalidatepage)(struct page___265 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___265 *, gfp_t);
	void (*freepage)(struct page___265 *);
	ssize_t (*direct_IO)(struct kiocb___264 *, struct iov_iter___129 *);
	int (*migratepage)(struct address_space___263 *, struct page___265 *, struct page___265 *, enum migrate_mode);
	bool (*isolate_page)(struct page___265 *, isolate_mode_t);
	void (*putback_page)(struct page___265 *);
	int (*launder_page)(struct page___265 *);
	int (*is_partially_uptodate)(struct page___265 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___265 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___263 *, struct page___265 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___264 *, sector_t *);
	void (*swap_deactivate)(struct file___264 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct iov_iter___129 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___133 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___264 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___264 *bd_inode;
	struct super_block___263 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___264 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___65 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___65 *bd_disk;
	struct request_queue___2 *bd_queue;
	struct backing_dev_info___133 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___263 {
	struct dentry___264 * (*lookup)(struct inode___264 *, struct dentry___264 *, unsigned int);
	const char * (*get_link)(struct dentry___264 *, struct inode___264 *, struct delayed_call *);
	int (*permission)(struct inode___264 *, int);
	struct posix_acl * (*get_acl)(struct inode___264 *, int);
	int (*readlink)(struct dentry___264 *, char *, int);
	int (*create)(struct inode___264 *, struct dentry___264 *, umode_t, bool);
	int (*link)(struct dentry___264 *, struct inode___264 *, struct dentry___264 *);
	int (*unlink)(struct inode___264 *, struct dentry___264 *);
	int (*symlink)(struct inode___264 *, struct dentry___264 *, const char *);
	int (*mkdir)(struct inode___264 *, struct dentry___264 *, umode_t);
	int (*rmdir)(struct inode___264 *, struct dentry___264 *);
	int (*mknod)(struct inode___264 *, struct dentry___264 *, umode_t, dev_t);
	int (*rename)(struct inode___264 *, struct dentry___264 *, struct inode___264 *, struct dentry___264 *, unsigned int);
	int (*setattr)(struct dentry___264 *, struct iattr___263 *);
	int (*getattr)(const struct path___264 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___264 *, char *, size_t);
	int (*fiemap)(struct inode___264 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___264 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___264 *, struct dentry___264 *, struct file___264 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___264 *, struct dentry___264 *, umode_t);
	int (*set_acl)(struct inode___264 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___263 {
	void (*fl_copy_lock)(struct file_lock___264 *, struct file_lock___264 *);
	void (*fl_release_private)(struct file_lock___264 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___263;

struct lock_manager_operations___263;

struct file_lock___264 {
	struct file_lock___264 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___264 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___263 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___263 *fl_ops;
	const struct lock_manager_operations___263 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___263 {
	int (*lm_compare_owner)(struct file_lock___264 *, struct file_lock___264 *);
	long unsigned int (*lm_owner_key)(struct file_lock___264 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___264 *);
	int (*lm_grant)(struct file_lock___264 *, int);
	bool (*lm_break)(struct file_lock___264 *);
	int (*lm_change)(struct file_lock___264 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___264 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___263 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___263 *fa_next;
	struct file___264 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___263 {
	const char *name;
	int fs_flags;
	struct dentry___264 * (*mount)(struct file_system_type___263 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___263 *);
	struct module___216 *owner;
	struct file_system_type___263 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___263 {
	struct inode___264 * (*alloc_inode)(struct super_block___263 *);
	void (*destroy_inode)(struct inode___264 *);
	void (*dirty_inode)(struct inode___264 *, int);
	int (*write_inode)(struct inode___264 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___264 *);
	void (*evict_inode)(struct inode___264 *);
	void (*put_super)(struct super_block___263 *);
	int (*sync_fs)(struct super_block___263 *, int);
	int (*freeze_super)(struct super_block___263 *);
	int (*freeze_fs)(struct super_block___263 *);
	int (*thaw_super)(struct super_block___263 *);
	int (*unfreeze_fs)(struct super_block___263 *);
	int (*statfs)(struct dentry___264 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___263 *, int *, char *);
	void (*umount_begin)(struct super_block___263 *);
	int (*show_options)(struct seq_file___4 *, struct dentry___264 *);
	int (*show_devname)(struct seq_file___4 *, struct dentry___264 *);
	int (*show_path)(struct seq_file___4 *, struct dentry___264 *);
	int (*show_stats)(struct seq_file___4 *, struct dentry___264 *);
	ssize_t (*quota_read)(struct super_block___263 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___263 *, int, const char *, size_t, loff_t);
	struct dquot___263 ** (*get_dquots)(struct inode___264 *);
	int (*bdev_try_to_free_page)(struct super_block___263 *, struct page___265 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___263 *, struct shrink_control___112 *);
	long int (*free_cached_objects)(struct super_block___263 *, struct shrink_control___112 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___65 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___65 *last_lookup;
	struct hd_struct___65 *part[0];
};

struct block_device_operations___65 {
	int (*open)(struct block_device___264 *, fmode_t);
	void (*release)(struct gendisk___65 *, fmode_t);
	int (*rw_page)(struct block_device___264 *, sector_t, struct page___265 *, unsigned int);
	int (*ioctl)(struct block_device___264 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___264 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___65 *, unsigned int);
	int (*media_changed)(struct gendisk___65 *);
	void (*unlock_native_capacity)(struct gendisk___65 *);
	int (*revalidate_disk)(struct gendisk___65 *);
	int (*getgeo)(struct block_device___264 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___264 *, long unsigned int);
	int (*report_zones)(struct gendisk___65 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___216 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___253(struct page___265 *);

struct bdi_writeback_congested___133 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___133 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bsg_ops___64 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___2 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___2 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___2 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___64(struct request___2 *, blk_status_t);

struct request___2 {
	struct request_queue___2 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___2 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___133 *bio;
	struct bio___133 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___133 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___68 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___64 *saved_end_io;
		} flush;
	};
	struct gendisk___65 *rq_disk;
	struct hd_struct___65 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___64 *end_io;
	void *end_io_data;
	struct request___2 *next_rq;
};

struct fwnode_reference_args___162;

struct fwnode_endpoint___162;

struct fwnode_operations___162 {
	struct fwnode_handle___162 * (*get)(struct fwnode_handle___162 *);
	void (*put)(struct fwnode_handle___162 *);
	bool (*device_is_available)(const struct fwnode_handle___162 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___162 *, const struct device___227 *);
	bool (*property_present)(const struct fwnode_handle___162 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___162 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___162 *, const char *, const char **, size_t);
	struct fwnode_handle___162 * (*get_parent)(const struct fwnode_handle___162 *);
	struct fwnode_handle___162 * (*get_next_child_node)(const struct fwnode_handle___162 *, struct fwnode_handle___162 *);
	struct fwnode_handle___162 * (*get_named_child_node)(const struct fwnode_handle___162 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___162 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___162 *);
	struct fwnode_handle___162 * (*graph_get_next_endpoint)(const struct fwnode_handle___162 *, struct fwnode_handle___162 *);
	struct fwnode_handle___162 * (*graph_get_remote_endpoint)(const struct fwnode_handle___162 *);
	struct fwnode_handle___162 * (*graph_get_port_parent)(struct fwnode_handle___162 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___162 *, struct fwnode_endpoint___162 *);
};

struct fwnode_endpoint___162 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___162 *local_fwnode;
};

struct fwnode_reference_args___162 {
	struct fwnode_handle___162 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct blk_mq_ctxs___9;

struct blk_mq_ctx {
	struct {
		spinlock_t lock;
		struct list_head rq_lists[3];
		long: 64;
	};
	unsigned int cpu;
	short unsigned int index_hw[3];
	struct blk_mq_hw_ctx___2 *hctxs[3];
	long unsigned int rq_dispatched[2];
	long unsigned int rq_merged;
	long unsigned int rq_completed[2];
	struct request_queue___2 *queue;
	struct blk_mq_ctxs___9 *ctxs;
	struct kobject___252 kobj;
};

struct blk_mq_tags___9;

struct blk_mq_hw_ctx___2 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___2 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags___9 *tags;
	struct blk_mq_tags___9 *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	unsigned int rh_reserved_nr_expired;
	struct hlist_node cpuhp_dead;
	struct kobject___252 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___264 *debugfs_dir;
	struct dentry___264 *sched_debugfs_dir;
	struct list_head hctx_list;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___64;

struct elevator_mq_ops___64 {
	int (*init_sched)(struct request_queue___2 *, struct elevator_type___64 *);
	void (*exit_sched)(struct elevator_queue___64 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___2 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___2 *, unsigned int);
	bool (*allow_merge)(struct request_queue___2 *, struct request___2 *, struct bio___133 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx___2 *, struct bio___133 *);
	int (*request_merge)(struct request_queue___2 *, struct request___2 **, struct bio___133 *);
	void (*request_merged)(struct request_queue___2 *, struct request___2 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___2 *, struct request___2 *, struct request___2 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___2 *, struct bio___133 *);
	void (*finish_request)(struct request___2 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___2 *, struct list_head *, bool);
	struct request___2 * (*dispatch_request)(struct blk_mq_hw_ctx___2 *);
	bool (*has_work)(struct blk_mq_hw_ctx___2 *);
	void (*completed_request)(struct request___2 *, u64);
	void (*started_request)(struct request___2 *);
	void (*requeue_request)(struct request___2 *);
	struct request___2 * (*former_request)(struct request_queue___2 *, struct request___2 *);
	struct request___2 * (*next_request)(struct request_queue___2 *, struct request___2 *);
	void (*init_icq)(struct io_cq___68 *);
	void (*exit_icq)(struct io_cq___68 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx___2 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___64;

struct blk_mq_debugfs_attr___3;

struct elevator_type___64 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___64 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___64 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___216 *elevator_owner;
	const struct blk_mq_debugfs_attr___3 *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr___3 *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___64 {
	struct elevator_type___64 *type;
	void *elevator_data;
	struct kobject___252 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct blk_mq_alloc_data {
	struct request_queue___2 *q;
	blk_mq_req_flags_t flags;
	unsigned int shallow_depth;
	unsigned int cmd_flags;
	struct blk_mq_ctx *ctx;
	struct blk_mq_hw_ctx___2 *hctx;
};

struct elv_fs_entry___64 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___64 *, char *);
	ssize_t (*store)(struct elevator_queue___64 *, const char *, size_t);
};

struct blk_mq_debugfs_attr___3 {
	const char *name;
	umode_t mode;
	int (*show)(void *, struct seq_file___4 *);
	ssize_t (*write)(void *, const char *, size_t, loff_t *);
	const struct seq_operations___232 *seq_ops;
};

struct rq_qos_ops___6;

struct rq_qos___6 {
	struct rq_qos_ops___6 *ops;
	struct request_queue___2 *q;
	enum rq_qos_id id;
	struct rq_qos___6 *next;
};

struct blk_stat_callback {
	struct list_head list;
	struct timer_list timer;
	struct blk_rq_stat *cpu_stat;
	int (*bucket_fn)(const struct request___2 *);
	unsigned int buckets;
	struct blk_rq_stat *stat;
	void (*timer_fn)(struct blk_stat_callback *);
	void *data;
	struct callback_head rcu;
};

struct rchan___9;

struct blk_trace___8 {
	int trace_state;
	struct rchan___9 *rchan;
	long unsigned int *sequence;
	unsigned char *msg_data;
	u16 act_mask;
	u64 start_lba;
	u64 end_lba;
	u32 pid;
	u32 dev;
	struct dentry___264 *dir;
	struct dentry___264 *dropped_file;
	struct dentry___264 *msg_file;
	struct list_head running_list;
	atomic_t dropped;
};

struct blk_flush_queue {
	unsigned int flush_queue_delayed: 1;
	unsigned int flush_pending_idx: 1;
	unsigned int flush_running_idx: 1;
	long unsigned int flush_pending_since;
	struct list_head flush_queue[2];
	struct list_head flush_data_in_flight;
	struct request___2 *flush_rq;
	struct request___2 *orig_rq;
	spinlock_t mq_flush_lock;
};

struct blk_mq_tag_set {
	struct blk_mq_queue_map map[6];
	unsigned int nr_maps;
	const struct blk_mq_ops *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	struct blk_mq_tags___9 **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct blk_mq_tags___9 {
	unsigned int nr_tags;
	unsigned int nr_reserved_tags;
	atomic_t active_queues;
	struct sbitmap_queue bitmap_tags;
	struct sbitmap_queue breserved_tags;
	struct request___2 **rqs;
	struct request___2 **static_rqs;
	struct list_head page_list;
};

struct blk_mq_queue_data {
	struct request___2 *rq;
	bool last;
	long unsigned int rh_reserved1;
};

struct rchan_buf___9 {
	void *start;
	void *data;
	size_t offset;
	size_t subbufs_produced;
	size_t subbufs_consumed;
	struct rchan___9 *chan;
	wait_queue_head_t read_wait;
	struct irq_work wakeup_work;
	struct dentry___264 *dentry;
	struct kref kref;
	struct page___265 **page_array;
	unsigned int page_count;
	unsigned int finalized;
	size_t *padding;
	size_t prev_padding;
	size_t bytes_consumed;
	size_t early_bytes;
	unsigned int cpu;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
};

struct rchan_callbacks___9;

struct rchan___9 {
	u32 version;
	size_t subbuf_size;
	size_t n_subbufs;
	size_t alloc_size;
	struct rchan_callbacks___9 *cb;
	struct kref kref;
	void *private_data;
	size_t last_toobig;
	struct rchan_buf___9 **buf;
	int is_global;
	struct list_head list;
	struct dentry___264 *parent;
	int has_base_filename;
	char base_filename[255];
};

struct rchan_callbacks___9 {
	int (*subbuf_start)(struct rchan_buf___9 *, void *, void *, size_t);
	void (*buf_mapped)(struct rchan_buf___9 *, struct file___264 *);
	void (*buf_unmapped)(struct rchan_buf___9 *, struct file___264 *);
	struct dentry___264 * (*create_buf_file)(const char *, struct dentry___264 *, umode_t, struct rchan_buf___9 *, int *);
	int (*remove_buf_file)(struct dentry___264 *);
};

struct blk_mq_ctxs___9 {
	struct kobject___252 kobj;
	struct blk_mq_ctx *queue_ctx;
};

typedef int (*key_restrict_link_func_t___255)(struct key___254 *, const struct key_type *, const union key_payload *, struct key___254 *);

struct key_restriction___254;

struct key___254 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___265 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key___6 index_key;
		struct {
			struct key_type___6 *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___254 *restrict_link;
};

struct key_restriction___254 {
	key_restrict_link_func_t___255 check;
	struct key___254 *key;
	struct key_type *keytype;
};

struct seq_operations___232 {
	void * (*start)(struct seq_file___4 *, loff_t *);
	void (*stop)(struct seq_file___4 *, void *);
	void * (*next)(struct seq_file___4 *, void *, loff_t *);
	int (*show)(struct seq_file___4 *, void *);
};

struct rq_qos_ops___6 {
	void (*throttle)(struct rq_qos___6 *, struct bio___133 *);
	void (*track)(struct rq_qos___6 *, struct request___2 *, struct bio___133 *);
	void (*issue)(struct rq_qos___6 *, struct request___2 *);
	void (*requeue)(struct rq_qos___6 *, struct request___2 *);
	void (*done)(struct rq_qos___6 *, struct request___2 *);
	void (*done_bio)(struct rq_qos___6 *, struct bio___133 *);
	void (*cleanup)(struct rq_qos___6 *, struct bio___133 *);
	void (*exit)(struct rq_qos___6 *);
};

struct file___265;

struct kiocb___265;

struct iov_iter___130;

struct poll_table_struct___164;

struct vm_area_struct___266;

struct inode___265;

struct file_lock___265;

struct page___266;

struct seq_file___234;

struct file_operations___265 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___265 *, loff_t, int);
	ssize_t (*read)(struct file___265 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___265 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___265 *, struct iov_iter___130 *);
	ssize_t (*write_iter)(struct kiocb___265 *, struct iov_iter___130 *);
	int (*iopoll)(struct kiocb___265 *, bool);
	int (*iterate)(struct file___265 *, struct dir_context *);
	int (*iterate_shared)(struct file___265 *, struct dir_context *);
	__poll_t (*poll)(struct file___265 *, struct poll_table_struct___164 *);
	long int (*unlocked_ioctl)(struct file___265 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___265 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___265 *, struct vm_area_struct___266 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___265 *, struct file___265 *);
	int (*flush)(struct file___265 *, fl_owner_t);
	int (*release)(struct inode___265 *, struct file___265 *);
	int (*fsync)(struct file___265 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___265 *, int);
	int (*lock)(struct file___265 *, int, struct file_lock___265 *);
	ssize_t (*sendpage)(struct file___265 *, struct page___266 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___265 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___265 *, int, struct file_lock___265 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___265 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___265 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___265 *, long int, struct file_lock___265 **, void **);
	long int (*fallocate)(struct file___265 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___234 *, struct file___265 *);
	ssize_t (*copy_file_range)(struct file___265 *, loff_t, struct file___265 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___265 *, loff_t, struct file___265 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___265 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___265 {
	u64 seqnum;
	struct vm_area_struct___266 *vmas[4];
};

struct page_frag___265 {
	struct page___266 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___265;

struct cred___255;

struct nsproxy___235;

struct bio_list___134;

struct backing_dev_info___134;

struct io_context___69;

struct css_set___200;

struct request_queue___65;

struct vm_struct___181;

struct task_struct___266 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___266 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___265 *mm;
	struct mm_struct___265 *active_mm;
	struct vmacache___265 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___266 *real_parent;
	struct task_struct___266 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___266 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___190 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___190 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___190 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___255 *ptracer_cred;
	const struct cred___255 *real_cred;
	const struct cred___255 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___235 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___266 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___134 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___134 *backing_dev_info;
	struct io_context___69 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___200 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___265 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___65 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___266 *oom_reaper_list;
	struct vm_struct___181 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___128 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rw_semaphore___266 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___266 *owner;
};

struct key___255;

struct ucounts___215;

struct user_namespace___215 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___215 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___28 ns;
	long unsigned int flags;
	struct key___255 *persistent_keyring_register;
	struct rw_semaphore___266 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___215 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct secondary_data___266 {
	void *stack;
	struct task_struct___266 *task;
	long int status;
};

typedef struct page___266 *pgtable_t___265;

struct address_space___264;

struct dev_pagemap___254;

struct page___266 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___264 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___266 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___265 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___265 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___254 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct user_struct___255 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___255 *uid_keyring;
	struct key___255 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___254;

struct vm_area_struct___266 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___266 *vm_next;
	struct vm_area_struct___266 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___265 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___254 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___265 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___265;

struct mm_struct___265 {
	struct {
		struct vm_area_struct___266 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___265 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___266 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___265 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___266 *owner;
		struct user_namespace___215 *user_ns;
		struct file___265 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___265 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___255 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___255 *session_keyring;
	struct key___255 *process_keyring;
	struct key___255 *thread_keyring;
	struct key___255 *request_key_auth;
	void *security;
	struct user_struct___255 *user;
	struct user_namespace___215 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___200;

struct nsproxy___235 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___200 *cgroup_ns;
};

struct bio___134;

struct bio_list___134 {
	struct bio___134 *head;
	struct bio___134 *tail;
};

struct bdi_writeback_congested___134;

struct cgroup_subsys_state___200;

struct bdi_writeback___134 {
	struct backing_dev_info___134 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___134 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___200 *memcg_css;
	struct cgroup_subsys_state___200 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___228;

struct dentry___265;

struct backing_dev_info___134 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___134 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___228 *dev;
	struct device___228 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___265 *debug_dir;
	struct dentry___265 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___69;

struct io_context___69 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___69 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___200;

struct css_set___200 {
	struct cgroup_subsys_state___200 *subsys[13];
	refcount_t refcount;
	struct css_set___200 *dom_cset;
	struct cgroup___200 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___200 *mg_src_cgrp;
	struct cgroup___200 *mg_dst_cgrp;
	struct css_set___200 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

typedef blk_qc_t make_request_fn___65(struct request_queue___65 *, struct bio___134 *);

struct request___65;

typedef int dma_drain_needed_fn___65(struct request___65 *);

struct kset___252;

struct kobj_type___252;

struct kernfs_node___260;

struct kobject___253 {
	const char *name;
	struct list_head entry;
	struct kobject___253 *parent;
	struct kset___252 *kset;
	struct kobj_type___252 *ktype;
	struct kernfs_node___260 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___65;

struct bsg_class_device___65 {
	struct device___228 *class_dev;
	int minor;
	struct request_queue___65 *queue;
	const struct bsg_ops___65 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___134 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___134 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___65;

struct blkcg_gq___51;

struct blk_trace___9;

struct request_queue___65 {
	struct list_head queue_head;
	struct request___65 *last_merge;
	struct elevator_queue___65 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___65 *make_request_fn;
	dma_drain_needed_fn___65 *dma_drain_needed;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___134 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___253 kobj;
	struct kobject___253 *mq_kobj;
	struct blk_integrity integrity;
	struct device___228 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___51 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace___9 *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	struct bsg_class_device___65 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___134 bio_split;
	struct dentry___265 *debugfs_dir;
	struct dentry___265 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___181 {
	struct vm_struct___181 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___266 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct pglist_data___265;

struct lruvec___265 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___265 *pgdat;
};

struct zone___265 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___265 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___265 {
	struct zone___265 *zone;
	int zone_idx;
};

struct zonelist___265 {
	struct zoneref___265 _zonerefs[25];
};

struct pglist_data___265 {
	struct zone___265 node_zones[3];
	struct zonelist___265 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___266 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___266 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___265 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___265 {
	struct rw_semaphore___266 rwsem;
	struct notifier_block *head;
};

struct bio_vec___134 {
	struct page___266 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

typedef void bio_end_io_t___134(struct bio___134 *);

struct gendisk___66;

struct bio_integrity_payload___134;

struct bio___134 {
	struct bio___134 *bi_next;
	struct gendisk___66 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___134 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___51 *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___134 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___134 *bi_io_vec;
	struct bio_set___134 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___134 bi_inline_vecs[0];
};

struct bio_integrity_payload___134 {
	struct bio___134 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___134 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___134 bip_inline_vecs[0];
};

struct dev_pm_info___228 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___228 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___228;

struct bus_type___228;

struct device_driver___228;

struct dev_pm_domain___228;

struct fwnode_handle___163;

struct class___228;

struct attribute_group___230;

struct device___228 {
	struct device___228 *parent;
	struct device_private *p;
	struct kobject___253 kobj;
	const char *init_name;
	const struct device_type___228 *type;
	struct mutex mutex;
	struct bus_type___228 *bus;
	struct device_driver___228 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___228 power;
	struct dev_pm_domain___228 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___163 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___228 *class;
	const struct attribute_group___230 **groups;
	void (*release)(struct device___228 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___66 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___228 __dev;
	struct kobject___253 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___66;

struct block_device_operations___66;

struct gendisk___66 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___66 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___66 *part_tbl;
	struct hd_struct___66 part0;
	const struct block_device_operations___66 *fops;
	struct request_queue___65 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___266 lookup_sem;
	struct kobject___253 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___253 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct blkcg___51;

struct blkg_policy_data___51;

struct blkcg_gq___51 {
	struct request_queue___65 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___51 *blkcg;
	struct bdi_writeback_congested___134 *wb_congested;
	struct blkcg_gq___51 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_rwstat stat_bytes;
	struct blkg_rwstat stat_ios;
	struct blkg_policy_data___51 *pd[5];
	struct callback_head callback_head;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
};

struct dev_pm_ops___228;

struct device_type___228 {
	const char *name;
	const struct attribute_group___230 **groups;
	int (*uevent)(struct device___228 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___228 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___228 *);
	const struct dev_pm_ops___228 *pm;
};

struct class___228 {
	const char *name;
	struct module___11 *owner;
	const struct attribute_group___230 **class_groups;
	const struct attribute_group___230 **dev_groups;
	struct kobject___253 *dev_kobj;
	int (*dev_uevent)(struct device___228 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___228 *, umode_t *);
	void (*class_release)(struct class___228 *);
	void (*dev_release)(struct device___228 *);
	int (*shutdown_pre)(struct device___228 *);
	const struct kobj_ns_type_operations___24 *ns_type;
	const void * (*namespace)(struct device___228 *);
	const struct dev_pm_ops___228 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct kernfs_root___259;

struct kernfs_elem_dir___259 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___259 *root;
};

struct kernfs_syscall_ops___259;

struct kernfs_root___259 {
	struct kernfs_node___260 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___259 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___259 {
	struct kernfs_node___260 *target_kn;
};

struct kernfs_ops___259;

struct kernfs_elem_attr___259 {
	const struct kernfs_ops___259 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___260 *notify_next;
};

struct kernfs_node___260 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___260 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___259 dir;
		struct kernfs_elem_symlink___259 symlink;
		struct kernfs_elem_attr___259 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___259;

struct kernfs_ops___259 {
	int (*open)(struct kernfs_open_file___259 *);
	void (*release)(struct kernfs_open_file___259 *);
	int (*seq_show)(struct seq_file___234 *, void *);
	void * (*seq_start)(struct seq_file___234 *, loff_t *);
	void * (*seq_next)(struct seq_file___234 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___234 *, void *);
	ssize_t (*read)(struct kernfs_open_file___259 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___259 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___259 *, struct vm_area_struct___266 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___259 *, struct poll_table_struct___164 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___259 {
	int (*remount_fs)(struct kernfs_root___259 *, int *, char *);
	int (*show_options)(struct seq_file___234 *, struct kernfs_root___259 *);
	int (*mkdir)(struct kernfs_node___260 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___260 *);
	int (*rename)(struct kernfs_node___260 *, struct kernfs_node___260 *, const char *);
	int (*show_path)(struct seq_file___234 *, struct kernfs_node___260 *, struct kernfs_root___259 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___233;

struct seq_file___234 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___233 *op;
	int poll_event;
	const struct file___265 *file;
	void *private;
};

struct kernfs_open_file___259 {
	struct kernfs_node___260 *kn;
	struct file___265 *file;
	struct seq_file___234 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___254 *vm_ops;
};

struct path___265 {
	struct vfsmount *mnt;
	struct dentry___265 *dentry;
};

struct file___265 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___265 f_path;
	struct inode___265 *f_inode;
	const struct file_operations___265 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___190 f_owner;
	const struct cred___255 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___264 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___254;

struct vm_operations_struct___254 {
	void (*open)(struct vm_area_struct___266 *);
	void (*close)(struct vm_area_struct___266 *);
	int (*split)(struct vm_area_struct___266 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___266 *);
	vm_fault_t (*fault)(struct vm_fault___254 *);
	vm_fault_t (*huge_fault)(struct vm_fault___254 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___254 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___266 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___254 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___254 *);
	int (*access)(struct vm_area_struct___266 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___266 *);
	int (*set_policy)(struct vm_area_struct___266 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___266 *, long unsigned int);
	struct page___266 * (*find_special_page)(struct vm_area_struct___266 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___166)(struct file___265 *, wait_queue_head_t *, struct poll_table_struct___164 *);

struct poll_table_struct___164 {
	poll_queue_proc___166 _qproc;
	__poll_t _key;
};

struct bin_attribute___229;

struct attribute_group___230 {
	const char *name;
	umode_t (*is_visible)(struct kobject___253 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___253 *, struct bin_attribute___229 *, int);
	struct attribute **attrs;
	struct bin_attribute___229 **bin_attrs;
};

struct bin_attribute___229 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___265 *, struct kobject___253 *, struct bin_attribute___229 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___265 *, struct kobject___253 *, struct bin_attribute___229 *, char *, loff_t, size_t);
	int (*mmap)(struct file___265 *, struct kobject___253 *, struct bin_attribute___229 *, struct vm_area_struct___266 *);
};

struct sysfs_ops___252 {
	ssize_t (*show)(struct kobject___253 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___253 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___252;

struct kset___252 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___253 kobj;
	const struct kset_uevent_ops___252 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___252 {
	void (*release)(struct kobject___253 *);
	const struct sysfs_ops___252 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___24 * (*child_ns_type)(struct kobject___253 *);
	const void * (*namespace)(struct kobject___253 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___252 {
	int (* const filter)(struct kset___252 *, struct kobject___253 *);
	const char * (* const name)(struct kset___252 *, struct kobject___253 *);
	int (* const uevent)(struct kset___252 *, struct kobject___253 *, struct kobj_uevent_env *);
};

struct kobj_attribute___245 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___253 *, struct kobj_attribute___245 *, char *);
	ssize_t (*store)(struct kobject___253 *, struct kobj_attribute___245 *, const char *, size_t);
};

struct dev_pm_ops___228 {
	int (*prepare)(struct device___228 *);
	void (*complete)(struct device___228 *);
	int (*suspend)(struct device___228 *);
	int (*resume)(struct device___228 *);
	int (*freeze)(struct device___228 *);
	int (*thaw)(struct device___228 *);
	int (*poweroff)(struct device___228 *);
	int (*restore)(struct device___228 *);
	int (*suspend_late)(struct device___228 *);
	int (*resume_early)(struct device___228 *);
	int (*freeze_late)(struct device___228 *);
	int (*thaw_early)(struct device___228 *);
	int (*poweroff_late)(struct device___228 *);
	int (*restore_early)(struct device___228 *);
	int (*suspend_noirq)(struct device___228 *);
	int (*resume_noirq)(struct device___228 *);
	int (*freeze_noirq)(struct device___228 *);
	int (*thaw_noirq)(struct device___228 *);
	int (*poweroff_noirq)(struct device___228 *);
	int (*restore_noirq)(struct device___228 *);
	int (*runtime_suspend)(struct device___228 *);
	int (*runtime_resume)(struct device___228 *);
	int (*runtime_idle)(struct device___228 *);
};

struct dev_pm_domain___228 {
	struct dev_pm_ops___228 ops;
	void (*detach)(struct device___228 *, bool);
	int (*activate)(struct device___228 *);
	void (*sync)(struct device___228 *);
	void (*dismiss)(struct device___228 *);
};

struct bus_type___228 {
	const char *name;
	const char *dev_name;
	struct device___228 *dev_root;
	const struct attribute_group___230 **bus_groups;
	const struct attribute_group___230 **dev_groups;
	const struct attribute_group___230 **drv_groups;
	int (*match)(struct device___228 *, struct device_driver___228 *);
	int (*uevent)(struct device___228 *, struct kobj_uevent_env *);
	int (*probe)(struct device___228 *);
	int (*remove)(struct device___228 *);
	void (*shutdown)(struct device___228 *);
	int (*online)(struct device___228 *);
	int (*offline)(struct device___228 *);
	int (*suspend)(struct device___228 *, pm_message_t);
	int (*resume)(struct device___228 *);
	int (*num_vf)(struct device___228 *);
	int (*dma_configure)(struct device___228 *);
	const struct dev_pm_ops___228 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___228 {
	const char *name;
	struct bus_type___228 *bus;
	struct module___11 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___228 *);
	int (*remove)(struct device___228 *);
	void (*shutdown)(struct device___228 *);
	int (*suspend)(struct device___228 *, pm_message_t);
	int (*resume)(struct device___228 *);
	const struct attribute_group___230 **groups;
	const struct dev_pm_ops___228 *pm;
	void (*coredump)(struct device___228 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct fwnode_operations___163;

struct fwnode_handle___163 {
	struct fwnode_handle___163 *secondary;
	const struct fwnode_operations___163 *ops;
};

struct dentry_operations___264;

struct super_block___264;

struct dentry___265 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___265 *d_parent;
	struct qstr d_name;
	struct inode___265 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___264 *d_op;
	struct super_block___264 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___264;

struct address_space___264 {
	struct inode___265 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___266 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___264 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___264;

struct inode___265 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___264 *i_op;
	struct super_block___264 *i_sb;
	struct address_space___264 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___266 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___134 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___265 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___264 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___2 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___264 {
	int (*d_revalidate)(struct dentry___265 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___265 *, unsigned int);
	int (*d_hash)(const struct dentry___265 *, struct qstr *);
	int (*d_compare)(const struct dentry___265 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___265 *);
	int (*d_init)(struct dentry___265 *);
	void (*d_release)(struct dentry___265 *);
	void (*d_prune)(struct dentry___265 *);
	void (*d_iput)(struct dentry___265 *, struct inode___265 *);
	char * (*d_dname)(struct dentry___265 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___265 *);
	int (*d_manage)(const struct path___265 *, bool);
	struct dentry___265 * (*d_real)(struct dentry___265 *, const struct inode___265 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___264;

struct mem_dqinfo___264 {
	struct quota_format_type___264 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___264;

struct quota_info___264 {
	unsigned int flags;
	struct rw_semaphore___266 dqio_sem;
	struct inode___265 *files[3];
	struct mem_dqinfo___264 info[3];
	const struct quota_format_ops___264 *ops[3];
};

struct rcuwait___264 {
	struct task_struct___266 *task;
};

struct percpu_rw_semaphore___264 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___266 rw_sem;
	struct rcuwait___264 writer;
	int readers_block;
};

struct sb_writers___264 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___264 rw_sem[3];
};

struct file_system_type___264;

struct super_operations___264;

struct dquot_operations___264;

struct quotactl_ops___264;

struct super_block___264 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___264 *s_type;
	const struct super_operations___264 *s_op;
	const struct dquot_operations___264 *dq_op;
	const struct quotactl_ops___264 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___265 *s_root;
	struct rw_semaphore___266 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___2 *s_bdev;
	struct backing_dev_info___134 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___264 s_dquot;
	struct sb_writers___264 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___264 *s_d_op;
	int cleancache_poolid;
	struct shrinker___112 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___215 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

typedef int (*dev_page_fault_t___254)(struct vm_area_struct___266 *, long unsigned int, const struct page___266 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___254)(struct page___266 *, void *);

struct dev_pagemap___254 {
	dev_page_fault_t___254 page_fault;
	dev_page_free_t___254 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___228 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___265 {
	struct task_struct___266 *task;
	struct core_thread___265 *next;
};

struct core_state___265 {
	atomic_t nr_threads;
	struct core_thread___265 dumper;
	struct completion startup;
};

struct vm_fault___254 {
	struct vm_area_struct___266 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___266 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___266 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___265 prealloc_pte;
};

struct io_cq___69 {
	struct request_queue___65 *q;
	struct io_context___69 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___6 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___265 {
	struct file___265 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___265 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___264 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___265 *ia_file;
};

struct dquot___264 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___264 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___264 {
	int qf_fmt_id;
	const struct quota_format_ops___264 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___264 *qf_next;
};

struct quota_format_ops___264 {
	int (*check_quota_file)(struct super_block___264 *, int);
	int (*read_file_info)(struct super_block___264 *, int);
	int (*write_file_info)(struct super_block___264 *, int);
	int (*free_file_info)(struct super_block___264 *, int);
	int (*read_dqblk)(struct dquot___264 *);
	int (*commit_dqblk)(struct dquot___264 *);
	int (*release_dqblk)(struct dquot___264 *);
	int (*get_next_id)(struct super_block___264 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___264 {
	int (*write_dquot)(struct dquot___264 *);
	struct dquot___264 * (*alloc_dquot)(struct super_block___264 *, int);
	void (*destroy_dquot)(struct dquot___264 *);
	int (*acquire_dquot)(struct dquot___264 *);
	int (*release_dquot)(struct dquot___264 *);
	int (*mark_dirty)(struct dquot___264 *);
	int (*write_info)(struct super_block___264 *, int);
	qsize_t * (*get_reserved_space)(struct inode___265 *);
	int (*get_projid)(struct inode___265 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___265 *, qsize_t *);
	int (*get_next_id)(struct super_block___264 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___264 {
	int (*quota_on)(struct super_block___264 *, int, int, const struct path___265 *);
	int (*quota_off)(struct super_block___264 *, int);
	int (*quota_enable)(struct super_block___264 *, unsigned int);
	int (*quota_disable)(struct super_block___264 *, unsigned int);
	int (*quota_sync)(struct super_block___264 *, int);
	int (*set_info)(struct super_block___264 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___264 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___264 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___264 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___264 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___264 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___126;

struct address_space_operations___264 {
	int (*writepage)(struct page___266 *, struct writeback_control___126 *);
	int (*readpage)(struct file___265 *, struct page___266 *);
	int (*writepages)(struct address_space___264 *, struct writeback_control___126 *);
	int (*set_page_dirty)(struct page___266 *);
	int (*readpages)(struct file___265 *, struct address_space___264 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___265 *, struct address_space___264 *, loff_t, unsigned int, unsigned int, struct page___266 **, void **);
	int (*write_end)(struct file___265 *, struct address_space___264 *, loff_t, unsigned int, unsigned int, struct page___266 *, void *);
	sector_t (*bmap)(struct address_space___264 *, sector_t);
	void (*invalidatepage)(struct page___266 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___266 *, gfp_t);
	void (*freepage)(struct page___266 *);
	ssize_t (*direct_IO)(struct kiocb___265 *, struct iov_iter___130 *);
	int (*migratepage)(struct address_space___264 *, struct page___266 *, struct page___266 *, enum migrate_mode);
	bool (*isolate_page)(struct page___266 *, isolate_mode_t);
	void (*putback_page)(struct page___266 *);
	int (*launder_page)(struct page___266 *);
	int (*is_partially_uptodate)(struct page___266 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___266 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___264 *, struct page___266 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___265 *, sector_t *);
	void (*swap_deactivate)(struct file___265 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___126 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___134 *wb;
	struct inode___265 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct iov_iter___130 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___134 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___2 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___265 *bd_inode;
	struct super_block___264 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___2 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___66 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___66 *bd_disk;
	struct request_queue___65 *bd_queue;
	struct backing_dev_info___134 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___264 {
	struct dentry___265 * (*lookup)(struct inode___265 *, struct dentry___265 *, unsigned int);
	const char * (*get_link)(struct dentry___265 *, struct inode___265 *, struct delayed_call *);
	int (*permission)(struct inode___265 *, int);
	struct posix_acl * (*get_acl)(struct inode___265 *, int);
	int (*readlink)(struct dentry___265 *, char *, int);
	int (*create)(struct inode___265 *, struct dentry___265 *, umode_t, bool);
	int (*link)(struct dentry___265 *, struct inode___265 *, struct dentry___265 *);
	int (*unlink)(struct inode___265 *, struct dentry___265 *);
	int (*symlink)(struct inode___265 *, struct dentry___265 *, const char *);
	int (*mkdir)(struct inode___265 *, struct dentry___265 *, umode_t);
	int (*rmdir)(struct inode___265 *, struct dentry___265 *);
	int (*mknod)(struct inode___265 *, struct dentry___265 *, umode_t, dev_t);
	int (*rename)(struct inode___265 *, struct dentry___265 *, struct inode___265 *, struct dentry___265 *, unsigned int);
	int (*setattr)(struct dentry___265 *, struct iattr___264 *);
	int (*getattr)(const struct path___265 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___265 *, char *, size_t);
	int (*fiemap)(struct inode___265 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___265 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___265 *, struct dentry___265 *, struct file___265 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___265 *, struct dentry___265 *, umode_t);
	int (*set_acl)(struct inode___265 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___264 {
	void (*fl_copy_lock)(struct file_lock___265 *, struct file_lock___265 *);
	void (*fl_release_private)(struct file_lock___265 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___264;

struct lock_manager_operations___264;

struct file_lock___265 {
	struct file_lock___265 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___265 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___264 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___264 *fl_ops;
	const struct lock_manager_operations___264 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___264 {
	int (*lm_compare_owner)(struct file_lock___265 *, struct file_lock___265 *);
	long unsigned int (*lm_owner_key)(struct file_lock___265 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___265 *);
	int (*lm_grant)(struct file_lock___265 *, int);
	bool (*lm_break)(struct file_lock___265 *);
	int (*lm_change)(struct file_lock___265 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___265 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___264 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___264 *fa_next;
	struct file___265 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___264 {
	const char *name;
	int fs_flags;
	struct dentry___265 * (*mount)(struct file_system_type___264 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___264 *);
	struct module___11 *owner;
	struct file_system_type___264 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___264 {
	struct inode___265 * (*alloc_inode)(struct super_block___264 *);
	void (*destroy_inode)(struct inode___265 *);
	void (*dirty_inode)(struct inode___265 *, int);
	int (*write_inode)(struct inode___265 *, struct writeback_control___126 *);
	int (*drop_inode)(struct inode___265 *);
	void (*evict_inode)(struct inode___265 *);
	void (*put_super)(struct super_block___264 *);
	int (*sync_fs)(struct super_block___264 *, int);
	int (*freeze_super)(struct super_block___264 *);
	int (*freeze_fs)(struct super_block___264 *);
	int (*thaw_super)(struct super_block___264 *);
	int (*unfreeze_fs)(struct super_block___264 *);
	int (*statfs)(struct dentry___265 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___264 *, int *, char *);
	void (*umount_begin)(struct super_block___264 *);
	int (*show_options)(struct seq_file___234 *, struct dentry___265 *);
	int (*show_devname)(struct seq_file___234 *, struct dentry___265 *);
	int (*show_path)(struct seq_file___234 *, struct dentry___265 *);
	int (*show_stats)(struct seq_file___234 *, struct dentry___265 *);
	ssize_t (*quota_read)(struct super_block___264 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___264 *, int, const char *, size_t, loff_t);
	struct dquot___264 ** (*get_dquots)(struct inode___265 *);
	int (*bdev_try_to_free_page)(struct super_block___264 *, struct page___266 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___264 *, struct shrink_control___112 *);
	long int (*free_cached_objects)(struct super_block___264 *, struct shrink_control___112 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___66 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___66 *last_lookup;
	struct hd_struct___66 *part[0];
};

struct block_device_operations___66 {
	int (*open)(struct block_device___2 *, fmode_t);
	void (*release)(struct gendisk___66 *, fmode_t);
	int (*rw_page)(struct block_device___2 *, sector_t, struct page___266 *, unsigned int);
	int (*ioctl)(struct block_device___2 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___2 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___66 *, unsigned int);
	int (*media_changed)(struct gendisk___66 *);
	void (*unlock_native_capacity)(struct gendisk___66 *);
	int (*revalidate_disk)(struct gendisk___66 *);
	int (*getgeo)(struct block_device___2 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___2 *, long unsigned int);
	int (*report_zones)(struct gendisk___66 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___11 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_iter {
	struct gendisk___66 *disk;
	struct hd_struct___66 *part;
	int idx;
	unsigned int flags;
};

typedef void compound_page_dtor___254(struct page___266 *);

struct bdi_writeback_congested___134 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___134 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct cgroup_subsys___200;

struct cgroup_subsys_state___200 {
	struct cgroup___200 *cgroup;
	struct cgroup_subsys___200 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___200 *parent;
};

struct bsg_ops___65 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___65 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___65 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___65 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___65(struct request___65 *, blk_status_t);

struct request___65 {
	struct request_queue___65 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___134 *bio;
	struct bio___134 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___134 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___69 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___65 *saved_end_io;
		} flush;
	};
	struct gendisk___66 *rq_disk;
	struct hd_struct___66 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___65 *end_io;
	void *end_io_data;
	struct request___65 *next_rq;
};

struct fwnode_reference_args___163;

struct fwnode_endpoint___163;

struct fwnode_operations___163 {
	struct fwnode_handle___163 * (*get)(struct fwnode_handle___163 *);
	void (*put)(struct fwnode_handle___163 *);
	bool (*device_is_available)(const struct fwnode_handle___163 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___163 *, const struct device___228 *);
	bool (*property_present)(const struct fwnode_handle___163 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___163 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___163 *, const char *, const char **, size_t);
	struct fwnode_handle___163 * (*get_parent)(const struct fwnode_handle___163 *);
	struct fwnode_handle___163 * (*get_next_child_node)(const struct fwnode_handle___163 *, struct fwnode_handle___163 *);
	struct fwnode_handle___163 * (*get_named_child_node)(const struct fwnode_handle___163 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___163 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___163 *);
	struct fwnode_handle___163 * (*graph_get_next_endpoint)(const struct fwnode_handle___163 *, struct fwnode_handle___163 *);
	struct fwnode_handle___163 * (*graph_get_remote_endpoint)(const struct fwnode_handle___163 *);
	struct fwnode_handle___163 * (*graph_get_port_parent)(struct fwnode_handle___163 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___163 *, struct fwnode_endpoint___163 *);
};

struct fwnode_endpoint___163 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___163 *local_fwnode;
};

struct fwnode_reference_args___163 {
	struct fwnode_handle___163 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct elevator_type___65;

struct elevator_mq_ops___65 {
	int (*init_sched)(struct request_queue___65 *, struct elevator_type___65 *);
	void (*exit_sched)(struct elevator_queue___65 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	bool (*allow_merge)(struct request_queue___65 *, struct request___65 *, struct bio___134 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx *, struct bio___134 *);
	int (*request_merge)(struct request_queue___65 *, struct request___65 **, struct bio___134 *);
	void (*request_merged)(struct request_queue___65 *, struct request___65 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___65 *, struct request___65 *, struct request___65 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___65 *, struct bio___134 *);
	void (*finish_request)(struct request___65 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___65 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___65 *, u64);
	void (*started_request)(struct request___65 *);
	void (*requeue_request)(struct request___65 *);
	struct request___65 * (*former_request)(struct request_queue___65 *, struct request___65 *);
	struct request___65 * (*next_request)(struct request_queue___65 *, struct request___65 *);
	void (*init_icq)(struct io_cq___69 *);
	void (*exit_icq)(struct io_cq___69 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx___9 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___65;

struct elevator_type___65 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___65 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___65 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___11 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___65 {
	struct elevator_type___65 *type;
	void *elevator_data;
	struct kobject___253 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___65 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___65 *, char *);
	ssize_t (*store)(struct elevator_queue___65 *, const char *, size_t);
};

struct rchan___10;

struct blk_trace___9 {
	int trace_state;
	struct rchan___10 *rchan;
	long unsigned int *sequence;
	unsigned char *msg_data;
	u16 act_mask;
	u64 start_lba;
	u64 end_lba;
	u32 pid;
	u32 dev;
	struct dentry___265 *dir;
	struct dentry___265 *dropped_file;
	struct dentry___265 *msg_file;
	struct list_head running_list;
	atomic_t dropped;
};

struct hd_geometry {
	unsigned char heads;
	unsigned char sectors;
	short unsigned int cylinders;
	long unsigned int start;
};

struct blkpg_ioctl_arg {
	int op;
	int flags;
	int datalen;
	void *data;
};

struct blkpg_partition {
	long long int start;
	long long int length;
	int pno;
	char devname[64];
	char volname[64];
};

typedef int (*key_restrict_link_func_t___256)(struct key___255 *, const struct key_type *, const union key_payload *, struct key___255 *);

struct key_restriction___255;

struct key___255 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___266 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key___6 index_key;
		struct {
			struct key_type___6 *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___255 *restrict_link;
};

struct key_restriction___255 {
	key_restrict_link_func_t___256 check;
	struct key___255 *key;
	struct key_type *keytype;
};

struct seq_operations___233 {
	void * (*start)(struct seq_file___234 *, loff_t *);
	void (*stop)(struct seq_file___234 *, void *);
	void * (*next)(struct seq_file___234 *, void *, loff_t *);
	int (*show)(struct seq_file___234 *, void *);
};

struct cgroup_namespace___200 {
	refcount_t count;
	struct ns_common___28 ns;
	struct user_namespace___215 *user_ns;
	struct ucounts___215 *ucounts;
	struct css_set___200 *root_cset;
};

struct ucounts___215 {
	struct hlist_node node;
	struct user_namespace___215 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___201;

struct bpf_map_ops___200 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___201 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___201 *, struct file___265 *);
	void (*map_free)(struct bpf_map___201 *);
	int (*map_get_next_key)(struct bpf_map___201 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___201 *);
	void * (*map_lookup_elem)(struct bpf_map___201 *, void *);
	int (*map_update_elem)(struct bpf_map___201 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___201 *, void *);
	int (*map_push_elem)(struct bpf_map___201 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___201 *, void *);
	int (*map_peek_elem)(struct bpf_map___201 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___201 *, struct file___265 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___201 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___201 *, void *, struct seq_file___234 *);
	int (*map_check_btf)(const struct bpf_map___201 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___201 {
	const struct bpf_map_ops___200 *ops;
	struct bpf_map___201 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___255 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___200;

typedef void (*kthread_work_func_t___200)(struct kthread_work___200 *);

struct kthread_worker___200;

struct kthread_work___200 {
	struct list_head node;
	kthread_work_func_t___200 func;
	struct kthread_worker___200 *worker;
	int canceling;
};

struct kthread_worker___200 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___266 *task;
	struct kthread_work___200 *current_work;
};

struct kthread_delayed_work___200 {
	struct kthread_work___200 work;
	struct timer_list timer;
};

struct psi_group___200 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___200 *poll_kworker;
	struct kthread_delayed_work___200 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___200 {
	struct kernfs_node___260 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_root___200;

struct cgroup_rstat_cpu___200;

struct cgroup___200 {
	struct cgroup_subsys_state___200 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___260 *kn;
	struct cgroup_file___200 procs_file;
	struct cgroup_file___200 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___200 *subsys[13];
	struct cgroup_root___200 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___200 *dom_cgrp;
	struct cgroup_rstat_cpu___200 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___34 bpf;
	atomic_t congestion_count;
	struct cgroup___200 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___200 psi;
	int ancestor_ids[0];
};

struct cftype___200;

struct cgroup_subsys___200 {
	struct cgroup_subsys_state___200 * (*css_alloc)(struct cgroup_subsys_state___200 *);
	int (*css_online)(struct cgroup_subsys_state___200 *);
	void (*css_offline)(struct cgroup_subsys_state___200 *);
	void (*css_released)(struct cgroup_subsys_state___200 *);
	void (*css_free)(struct cgroup_subsys_state___200 *);
	void (*css_reset)(struct cgroup_subsys_state___200 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___200 *, int);
	int (*css_extra_stat_show)(struct seq_file___234 *, struct cgroup_subsys_state___200 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___266 *);
	void (*cancel_fork)(struct task_struct___266 *);
	void (*fork)(struct task_struct___266 *);
	void (*exit)(struct task_struct___266 *);
	void (*free)(struct task_struct___266 *);
	void (*bind)(struct cgroup_subsys_state___200 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___200 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___200 *dfl_cftypes;
	struct cftype___200 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___200 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___200 *updated_children;
	struct cgroup___200 *updated_next;
};

struct cgroup_root___200 {
	struct kernfs_root___259 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___200 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___200 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___200 *ss;
	struct list_head node;
	struct kernfs_ops___259 *kf_ops;
	int (*open)(struct kernfs_open_file___259 *);
	void (*release)(struct kernfs_open_file___259 *);
	u64 (*read_u64)(struct cgroup_subsys_state___200 *, struct cftype___200 *);
	s64 (*read_s64)(struct cgroup_subsys_state___200 *, struct cftype___200 *);
	int (*seq_show)(struct seq_file___234 *, void *);
	void * (*seq_start)(struct seq_file___234 *, loff_t *);
	void * (*seq_next)(struct seq_file___234 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___234 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___200 *, struct cftype___200 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___200 *, struct cftype___200 *, s64);
	ssize_t (*write)(struct kernfs_open_file___259 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___259 *, struct poll_table_struct___164 *);
};

struct blkcg_policy_data___51;

struct blkcg___51 {
	struct cgroup_subsys_state___200 css;
	spinlock_t lock;
	struct xarray blkg_tree;
	struct blkcg_gq___51 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___51 *cpd[5];
	struct list_head all_blkcgs_node;
	struct list_head cgwb_list;
	refcount_t cgwb_refcnt;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct blkcg_policy_data___51 {
	struct blkcg___51 *blkcg;
	int plid;
};

struct blkg_policy_data___51 {
	struct blkcg_gq___51 *blkg;
	int plid;
};

struct rchan_buf___10 {
	void *start;
	void *data;
	size_t offset;
	size_t subbufs_produced;
	size_t subbufs_consumed;
	struct rchan___10 *chan;
	wait_queue_head_t read_wait;
	struct irq_work wakeup_work;
	struct dentry___265 *dentry;
	struct kref kref;
	struct page___266 **page_array;
	unsigned int page_count;
	unsigned int finalized;
	size_t *padding;
	size_t prev_padding;
	size_t bytes_consumed;
	size_t early_bytes;
	unsigned int cpu;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
};

struct rchan_callbacks___10;

struct rchan___10 {
	u32 version;
	size_t subbuf_size;
	size_t n_subbufs;
	size_t alloc_size;
	struct rchan_callbacks___10 *cb;
	struct kref kref;
	void *private_data;
	size_t last_toobig;
	struct rchan_buf___10 **buf;
	int is_global;
	struct list_head list;
	struct dentry___265 *parent;
	int has_base_filename;
	char base_filename[255];
};

struct rchan_callbacks___10 {
	int (*subbuf_start)(struct rchan_buf___10 *, void *, void *, size_t);
	void (*buf_mapped)(struct rchan_buf___10 *, struct file___265 *);
	void (*buf_unmapped)(struct rchan_buf___10 *, struct file___265 *);
	struct dentry___265 * (*create_buf_file)(const char *, struct dentry___265 *, umode_t, struct rchan_buf___10 *, int *);
	int (*remove_buf_file)(struct dentry___265 *);
};

struct pr_reservation {
	__u64 key;
	__u32 type;
	__u32 flags;
};

struct pr_registration {
	__u64 old_key;
	__u64 new_key;
	__u32 flags;
	__u32 __pad;
};

struct pr_preempt {
	__u64 old_key;
	__u64 new_key;
	__u32 type;
	__u32 flags;
};

struct pr_clear {
	__u64 key;
	__u32 flags;
	__u32 __pad;
};

struct klist {
	spinlock_t k_lock;
	struct list_head k_list;
	void (*get)(struct klist_node *);
	void (*put)(struct klist_node *);
};

struct klist_iter {
	struct klist *i_klist;
	struct klist_node *i_cur;
};

struct class_dev_iter {
	struct klist_iter ki;
	const struct device_type___222 *type;
};

struct device_attribute___11 {
	struct attribute attr;
	ssize_t (*show)(struct device___222 *, struct device_attribute___11 *, char *);
	ssize_t (*store)(struct device___222 *, struct device_attribute___11 *, const char *, size_t);
};

struct disk_events {
	struct list_head node;
	struct gendisk___60 *disk;
	spinlock_t lock;
	struct mutex block_mutex;
	int block;
	unsigned int pending;
	unsigned int clearing;
	long int poll_msecs;
	struct delayed_work dwork;
};

struct badblocks {
	struct device___222 *dev;
	int count;
	int unacked_exist;
	int shift;
	u64 *page;
	int changed;
	seqlock_t lock;
	sector_t sector;
	sector_t size;
};

struct disk_part_iter___2 {
	struct gendisk___60 *disk;
	struct hd_struct___60 *part;
	int idx;
	unsigned int flags;
};

struct blk_major_name {
	struct blk_major_name *next;
	int major;
	char name[16];
};

struct device_attribute___12 {
	struct attribute attr;
	ssize_t (*show)(struct device___227 *, struct device_attribute___12 *, char *);
	ssize_t (*store)(struct device___227 *, struct device_attribute___12 *, const char *, size_t);
};

struct disk_part_iter___3 {
	struct gendisk___65 *disk;
	struct hd_struct___65 *part;
	int idx;
	unsigned int flags;
};

typedef int filler_t___7(void *, struct page___265 *);

typedef struct {
	struct page___265 *v;
} Sector;

struct parsed_partitions {
	struct block_device___264 *bdev;
	char name[32];
	struct {
		sector_t from;
		sector_t size;
		int flags;
		bool has_info;
		struct partition_meta_info info;
	} *parts;
	int next;
	int limit;
	bool access_beyond_eod;
	char *pp_buf;
};

enum {
	IOPRIO_WHO_PROCESS = 1,
	IOPRIO_WHO_PGRP = 2,
	IOPRIO_WHO_USER = 3,
};

struct syscall_metadata___63 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___3 *enter_event;
	struct trace_event_call___3 *exit_event;
};

struct badblocks___3 {
	struct device___46 *dev;
	int count;
	int unacked_exist;
	int shift;
	u64 *page;
	int changed;
	seqlock_t lock;
	sector_t sector;
	sector_t size;
};

struct file___266;

struct kiocb___266;

struct poll_table_struct___165;

struct vm_area_struct___267;

struct inode___266;

struct file_lock___266;

struct page___267;

struct seq_file___235;

struct file_operations___266 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___266 *, loff_t, int);
	ssize_t (*read)(struct file___266 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___266 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___266 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___266 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___266 *, bool);
	int (*iterate)(struct file___266 *, struct dir_context *);
	int (*iterate_shared)(struct file___266 *, struct dir_context *);
	__poll_t (*poll)(struct file___266 *, struct poll_table_struct___165 *);
	long int (*unlocked_ioctl)(struct file___266 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___266 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___266 *, struct vm_area_struct___267 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___266 *, struct file___266 *);
	int (*flush)(struct file___266 *, fl_owner_t);
	int (*release)(struct inode___266 *, struct file___266 *);
	int (*fsync)(struct file___266 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___266 *, int);
	int (*lock)(struct file___266 *, int, struct file_lock___266 *);
	ssize_t (*sendpage)(struct file___266 *, struct page___267 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___266 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___266 *, int, struct file_lock___266 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___266 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___266 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___266 *, long int, struct file_lock___266 **, void **);
	long int (*fallocate)(struct file___266 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___235 *, struct file___266 *);
	ssize_t (*copy_file_range)(struct file___266 *, loff_t, struct file___266 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___266 *, loff_t, struct file___266 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___266 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___266 {
	u64 seqnum;
	struct vm_area_struct___267 *vmas[4];
};

struct page_frag___266 {
	struct page___267 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___266;

struct cred___256;

struct bio_list___135;

struct backing_dev_info___135;

struct io_context___70;

struct request_queue___66;

struct vm_struct___182;

struct task_struct___267 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___267 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___266 *mm;
	struct mm_struct___266 *active_mm;
	struct vmacache___266 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___267 *real_parent;
	struct task_struct___267 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___267 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___190 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___190 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___190 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___256 *ptracer_cred;
	const struct cred___256 *real_cred;
	const struct cred___256 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___267 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___135 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___135 *backing_dev_info;
	struct io_context___70 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___266 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___66 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___267 *oom_reaper_list;
	struct vm_struct___182 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___128 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___267 *pgtable_t___266;

struct address_space___265;

struct dev_pagemap___255;

struct page___267 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___265 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___267 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___266 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___266 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___255 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___266;

struct lruvec___266 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___266 *pgdat;
};

struct zone___266 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___266 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___266 {
	struct zone___266 *zone;
	int zone_idx;
};

struct zonelist___266 {
	struct zoneref___266 _zonerefs[25];
};

struct pglist_data___266 {
	struct zone___266 node_zones[3];
	struct zonelist___266 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___267 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___267 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___266 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___267 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___267 *owner;
};

struct secondary_data___267 {
	void *stack;
	struct task_struct___267 *task;
	long int status;
};

struct blocking_notifier_head___266 {
	struct rw_semaphore___267 rwsem;
	struct notifier_block *head;
};

struct vm_struct___182 {
	struct vm_struct___182 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___267 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bio_vec___135 {
	struct page___267 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio___135;

typedef void bio_end_io_t___135(struct bio___135 *);

struct gendisk___67;

struct bio_integrity_payload___135;

struct bio_set___135;

struct bio___135 {
	struct bio___135 *bi_next;
	struct gendisk___67 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___135 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___135 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___135 *bi_io_vec;
	struct bio_set___135 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___135 bi_inline_vecs[0];
};

struct bio_integrity_payload___135 {
	struct bio___135 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___135 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___135 bip_inline_vecs[0];
};

struct kset___253;

struct kobj_type___253;

struct kernfs_node___261;

struct kobject___254 {
	const char *name;
	struct list_head entry;
	struct kobject___254 *parent;
	struct kset___253 *kset;
	struct kobj_type___253 *ktype;
	struct kernfs_node___261 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___229;

struct dev_pm_info___229 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___229 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___229;

struct bus_type___229;

struct device_driver___229;

struct dev_pm_domain___229;

struct fwnode_handle___164;

struct class___229;

struct attribute_group___231;

struct device___229 {
	struct device___229 *parent;
	struct device_private *p;
	struct kobject___254 kobj;
	const char *init_name;
	const struct device_type___229 *type;
	struct mutex mutex;
	struct bus_type___229 *bus;
	struct device_driver___229 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___229 power;
	struct dev_pm_domain___229 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___164 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___229 *class;
	const struct attribute_group___231 **groups;
	void (*release)(struct device___229 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___67 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___229 __dev;
	struct kobject___254 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___67;

struct block_device_operations___67;

struct gendisk___67 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___67 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___67 *part_tbl;
	struct hd_struct___67 part0;
	const struct block_device_operations___67 *fops;
	struct request_queue___66 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___267 lookup_sem;
	struct kobject___254 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___254 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio_list___135 {
	struct bio___135 *head;
	struct bio___135 *tail;
};

struct bio_set___135 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___135 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_ops___229;

struct device_type___229 {
	const char *name;
	const struct attribute_group___231 **groups;
	int (*uevent)(struct device___229 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___229 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___229 *);
	const struct dev_pm_ops___229 *pm;
};

struct class___229 {
	const char *name;
	struct module___11 *owner;
	const struct attribute_group___231 **class_groups;
	const struct attribute_group___231 **dev_groups;
	struct kobject___254 *dev_kobj;
	int (*dev_uevent)(struct device___229 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___229 *, umode_t *);
	void (*class_release)(struct class___229 *);
	void (*dev_release)(struct device___229 *);
	int (*shutdown_pre)(struct device___229 *);
	const struct kobj_ns_type_operations___24 *ns_type;
	const void * (*namespace)(struct device___229 *);
	const struct dev_pm_ops___229 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct kernfs_root___260;

struct kernfs_elem_dir___260 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___260 *root;
};

struct kernfs_syscall_ops___260;

struct kernfs_root___260 {
	struct kernfs_node___261 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___260 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___260 {
	struct kernfs_node___261 *target_kn;
};

struct kernfs_ops___260;

struct kernfs_elem_attr___260 {
	const struct kernfs_ops___260 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___261 *notify_next;
};

struct kernfs_node___261 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___261 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___260 dir;
		struct kernfs_elem_symlink___260 symlink;
		struct kernfs_elem_attr___260 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___260;

struct kernfs_ops___260 {
	int (*open)(struct kernfs_open_file___260 *);
	void (*release)(struct kernfs_open_file___260 *);
	int (*seq_show)(struct seq_file___235 *, void *);
	void * (*seq_start)(struct seq_file___235 *, loff_t *);
	void * (*seq_next)(struct seq_file___235 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___235 *, void *);
	ssize_t (*read)(struct kernfs_open_file___260 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___260 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___260 *, struct vm_area_struct___267 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___260 *, struct poll_table_struct___165 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___260 {
	int (*remount_fs)(struct kernfs_root___260 *, int *, char *);
	int (*show_options)(struct seq_file___235 *, struct kernfs_root___260 *);
	int (*mkdir)(struct kernfs_node___261 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___261 *);
	int (*rename)(struct kernfs_node___261 *, struct kernfs_node___261 *, const char *);
	int (*show_path)(struct seq_file___235 *, struct kernfs_node___261 *, struct kernfs_root___260 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___234;

struct seq_file___235 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___234 *op;
	int poll_event;
	const struct file___266 *file;
	void *private;
};

struct vm_operations_struct___255;

struct kernfs_open_file___260 {
	struct kernfs_node___261 *kn;
	struct file___266 *file;
	struct seq_file___235 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___255 *vm_ops;
};

struct dentry___266;

struct path___266 {
	struct vfsmount *mnt;
	struct dentry___266 *dentry;
};

struct file___266 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___266 f_path;
	struct inode___266 *f_inode;
	const struct file_operations___266 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___190 f_owner;
	const struct cred___256 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___265 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___255;

struct vm_operations_struct___255 {
	void (*open)(struct vm_area_struct___267 *);
	void (*close)(struct vm_area_struct___267 *);
	int (*split)(struct vm_area_struct___267 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___267 *);
	vm_fault_t (*fault)(struct vm_fault___255 *);
	vm_fault_t (*huge_fault)(struct vm_fault___255 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___255 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___267 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___255 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___255 *);
	int (*access)(struct vm_area_struct___267 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___267 *);
	int (*set_policy)(struct vm_area_struct___267 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___267 *, long unsigned int);
	struct page___267 * (*find_special_page)(struct vm_area_struct___267 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___167)(struct file___266 *, wait_queue_head_t *, struct poll_table_struct___165 *);

struct poll_table_struct___165 {
	poll_queue_proc___167 _qproc;
	__poll_t _key;
};

struct vm_area_struct___267 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___267 *vm_next;
	struct vm_area_struct___267 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___266 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___255 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___266 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___230;

struct attribute_group___231 {
	const char *name;
	umode_t (*is_visible)(struct kobject___254 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___254 *, struct bin_attribute___230 *, int);
	struct attribute **attrs;
	struct bin_attribute___230 **bin_attrs;
};

struct bin_attribute___230 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___266 *, struct kobject___254 *, struct bin_attribute___230 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___266 *, struct kobject___254 *, struct bin_attribute___230 *, char *, loff_t, size_t);
	int (*mmap)(struct file___266 *, struct kobject___254 *, struct bin_attribute___230 *, struct vm_area_struct___267 *);
};

struct sysfs_ops___253 {
	ssize_t (*show)(struct kobject___254 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___254 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___253;

struct kset___253 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___254 kobj;
	const struct kset_uevent_ops___253 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___253 {
	void (*release)(struct kobject___254 *);
	const struct sysfs_ops___253 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___24 * (*child_ns_type)(struct kobject___254 *);
	const void * (*namespace)(struct kobject___254 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___253 {
	int (* const filter)(struct kset___253 *, struct kobject___254 *);
	const char * (* const name)(struct kset___253 *, struct kobject___254 *);
	int (* const uevent)(struct kset___253 *, struct kobject___254 *, struct kobj_uevent_env *);
};

struct kobj_attribute___246 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___254 *, struct kobj_attribute___246 *, char *);
	ssize_t (*store)(struct kobject___254 *, struct kobj_attribute___246 *, const char *, size_t);
};

struct dev_pm_ops___229 {
	int (*prepare)(struct device___229 *);
	void (*complete)(struct device___229 *);
	int (*suspend)(struct device___229 *);
	int (*resume)(struct device___229 *);
	int (*freeze)(struct device___229 *);
	int (*thaw)(struct device___229 *);
	int (*poweroff)(struct device___229 *);
	int (*restore)(struct device___229 *);
	int (*suspend_late)(struct device___229 *);
	int (*resume_early)(struct device___229 *);
	int (*freeze_late)(struct device___229 *);
	int (*thaw_early)(struct device___229 *);
	int (*poweroff_late)(struct device___229 *);
	int (*restore_early)(struct device___229 *);
	int (*suspend_noirq)(struct device___229 *);
	int (*resume_noirq)(struct device___229 *);
	int (*freeze_noirq)(struct device___229 *);
	int (*thaw_noirq)(struct device___229 *);
	int (*poweroff_noirq)(struct device___229 *);
	int (*restore_noirq)(struct device___229 *);
	int (*runtime_suspend)(struct device___229 *);
	int (*runtime_resume)(struct device___229 *);
	int (*runtime_idle)(struct device___229 *);
};

struct dev_pm_domain___229 {
	struct dev_pm_ops___229 ops;
	void (*detach)(struct device___229 *, bool);
	int (*activate)(struct device___229 *);
	void (*sync)(struct device___229 *);
	void (*dismiss)(struct device___229 *);
};

struct key___256;

struct user_struct___256 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___256 *uid_keyring;
	struct key___256 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___266;

struct mm_struct___266 {
	struct {
		struct vm_area_struct___267 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___266 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___267 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___266 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___267 *owner;
		struct user_namespace___3 *user_ns;
		struct file___266 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___266 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___256 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___256 *session_keyring;
	struct key___256 *process_keyring;
	struct key___256 *thread_keyring;
	struct key___256 *request_key_auth;
	void *security;
	struct user_struct___256 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct bdi_writeback_congested___135;

struct bdi_writeback___135 {
	struct backing_dev_info___135 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___135 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___157 *memcg_css;
	struct cgroup_subsys_state___157 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___135 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___135 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___229 *dev;
	struct device___229 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___266 *debug_dir;
	struct dentry___266 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___70;

struct io_context___70 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___70 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

typedef blk_qc_t make_request_fn___66(struct request_queue___66 *, struct bio___135 *);

struct request___66;

typedef int dma_drain_needed_fn___66(struct request___66 *);

struct bsg_ops___66;

struct bsg_class_device___66 {
	struct device___229 *class_dev;
	int minor;
	struct request_queue___66 *queue;
	const struct bsg_ops___66 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct elevator_queue___66;

struct request_queue___66 {
	struct list_head queue_head;
	struct request___66 *last_merge;
	struct elevator_queue___66 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___66 *make_request_fn;
	dma_drain_needed_fn___66 *dma_drain_needed;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___135 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___254 kobj;
	struct kobject___254 *mq_kobj;
	struct blk_integrity integrity;
	struct device___229 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	struct bsg_class_device___66 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___135 bio_split;
	struct dentry___266 *debugfs_dir;
	struct dentry___266 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct bus_type___229 {
	const char *name;
	const char *dev_name;
	struct device___229 *dev_root;
	const struct attribute_group___231 **bus_groups;
	const struct attribute_group___231 **dev_groups;
	const struct attribute_group___231 **drv_groups;
	int (*match)(struct device___229 *, struct device_driver___229 *);
	int (*uevent)(struct device___229 *, struct kobj_uevent_env *);
	int (*probe)(struct device___229 *);
	int (*remove)(struct device___229 *);
	void (*shutdown)(struct device___229 *);
	int (*online)(struct device___229 *);
	int (*offline)(struct device___229 *);
	int (*suspend)(struct device___229 *, pm_message_t);
	int (*resume)(struct device___229 *);
	int (*num_vf)(struct device___229 *);
	int (*dma_configure)(struct device___229 *);
	const struct dev_pm_ops___229 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___229 {
	const char *name;
	struct bus_type___229 *bus;
	struct module___11 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___229 *);
	int (*remove)(struct device___229 *);
	void (*shutdown)(struct device___229 *);
	int (*suspend)(struct device___229 *, pm_message_t);
	int (*resume)(struct device___229 *);
	const struct attribute_group___231 **groups;
	const struct dev_pm_ops___229 *pm;
	void (*coredump)(struct device___229 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct fwnode_operations___164;

struct fwnode_handle___164 {
	struct fwnode_handle___164 *secondary;
	const struct fwnode_operations___164 *ops;
};

struct dentry_operations___265;

struct super_block___265;

struct dentry___266 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___266 *d_parent;
	struct qstr d_name;
	struct inode___266 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___265 *d_op;
	struct super_block___265 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___265;

struct address_space___265 {
	struct inode___266 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___267 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___265 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___265;

struct block_device___265;

struct cdev___40;

struct inode___266 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___265 *i_op;
	struct super_block___265 *i_sb;
	struct address_space___265 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___267 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___135 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___266 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___265 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___265 *i_bdev;
		struct cdev___40 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___265 {
	int (*d_revalidate)(struct dentry___266 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___266 *, unsigned int);
	int (*d_hash)(const struct dentry___266 *, struct qstr *);
	int (*d_compare)(const struct dentry___266 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___266 *);
	int (*d_init)(struct dentry___266 *);
	void (*d_release)(struct dentry___266 *);
	void (*d_prune)(struct dentry___266 *);
	void (*d_iput)(struct dentry___266 *, struct inode___266 *);
	char * (*d_dname)(struct dentry___266 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___266 *);
	int (*d_manage)(const struct path___266 *, bool);
	struct dentry___266 * (*d_real)(struct dentry___266 *, const struct inode___266 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___265;

struct mem_dqinfo___265 {
	struct quota_format_type___265 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___265;

struct quota_info___265 {
	unsigned int flags;
	struct rw_semaphore___267 dqio_sem;
	struct inode___266 *files[3];
	struct mem_dqinfo___265 info[3];
	const struct quota_format_ops___265 *ops[3];
};

struct rcuwait___265 {
	struct task_struct___267 *task;
};

struct percpu_rw_semaphore___265 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___267 rw_sem;
	struct rcuwait___265 writer;
	int readers_block;
};

struct sb_writers___265 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___265 rw_sem[3];
};

struct file_system_type___265;

struct super_operations___265;

struct dquot_operations___265;

struct quotactl_ops___265;

struct super_block___265 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___265 *s_type;
	const struct super_operations___265 *s_op;
	const struct dquot_operations___265 *dq_op;
	const struct quotactl_ops___265 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___266 *s_root;
	struct rw_semaphore___267 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___265 *s_bdev;
	struct backing_dev_info___135 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___265 s_dquot;
	struct sb_writers___265 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___265 *s_d_op;
	int cleancache_poolid;
	struct shrinker___112 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

typedef int (*dev_page_fault_t___255)(struct vm_area_struct___267 *, long unsigned int, const struct page___267 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___255)(struct page___267 *, void *);

struct dev_pagemap___255 {
	dev_page_fault_t___255 page_fault;
	dev_page_free_t___255 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___229 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___266 {
	struct task_struct___267 *task;
	struct core_thread___266 *next;
};

struct core_state___266 {
	atomic_t nr_threads;
	struct core_thread___266 dumper;
	struct completion startup;
};

struct vm_fault___255 {
	struct vm_area_struct___267 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___267 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___267 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___266 prealloc_pte;
};

struct io_cq___70 {
	struct request_queue___66 *q;
	struct io_context___70 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___6 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___266 {
	struct file___266 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___266 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___265 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___266 *ia_file;
};

struct dquot___265 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___265 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___265 {
	int qf_fmt_id;
	const struct quota_format_ops___265 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___265 *qf_next;
};

struct quota_format_ops___265 {
	int (*check_quota_file)(struct super_block___265 *, int);
	int (*read_file_info)(struct super_block___265 *, int);
	int (*write_file_info)(struct super_block___265 *, int);
	int (*free_file_info)(struct super_block___265 *, int);
	int (*read_dqblk)(struct dquot___265 *);
	int (*commit_dqblk)(struct dquot___265 *);
	int (*release_dqblk)(struct dquot___265 *);
	int (*get_next_id)(struct super_block___265 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___265 {
	int (*write_dquot)(struct dquot___265 *);
	struct dquot___265 * (*alloc_dquot)(struct super_block___265 *, int);
	void (*destroy_dquot)(struct dquot___265 *);
	int (*acquire_dquot)(struct dquot___265 *);
	int (*release_dquot)(struct dquot___265 *);
	int (*mark_dirty)(struct dquot___265 *);
	int (*write_info)(struct super_block___265 *, int);
	qsize_t * (*get_reserved_space)(struct inode___266 *);
	int (*get_projid)(struct inode___266 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___266 *, qsize_t *);
	int (*get_next_id)(struct super_block___265 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___265 {
	int (*quota_on)(struct super_block___265 *, int, int, const struct path___266 *);
	int (*quota_off)(struct super_block___265 *, int);
	int (*quota_enable)(struct super_block___265 *, unsigned int);
	int (*quota_disable)(struct super_block___265 *, unsigned int);
	int (*quota_sync)(struct super_block___265 *, int);
	int (*set_info)(struct super_block___265 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___265 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___265 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___265 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___265 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___265 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___265 {
	int (*writepage)(struct page___267 *, struct writeback_control___3 *);
	int (*readpage)(struct file___266 *, struct page___267 *);
	int (*writepages)(struct address_space___265 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___267 *);
	int (*readpages)(struct file___266 *, struct address_space___265 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___266 *, struct address_space___265 *, loff_t, unsigned int, unsigned int, struct page___267 **, void **);
	int (*write_end)(struct file___266 *, struct address_space___265 *, loff_t, unsigned int, unsigned int, struct page___267 *, void *);
	sector_t (*bmap)(struct address_space___265 *, sector_t);
	void (*invalidatepage)(struct page___267 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___267 *, gfp_t);
	void (*freepage)(struct page___267 *);
	ssize_t (*direct_IO)(struct kiocb___266 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___265 *, struct page___267 *, struct page___267 *, enum migrate_mode);
	bool (*isolate_page)(struct page___267 *, isolate_mode_t);
	void (*putback_page)(struct page___267 *);
	int (*launder_page)(struct page___267 *);
	int (*is_partially_uptodate)(struct page___267 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___267 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___265 *, struct page___267 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___266 *, sector_t *);
	void (*swap_deactivate)(struct file___266 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___265 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___266 *bd_inode;
	struct super_block___265 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___265 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___67 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___67 *bd_disk;
	struct request_queue___66 *bd_queue;
	struct backing_dev_info___135 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___40 {
	struct kobject___254 kobj;
	struct module___11 *owner;
	const struct file_operations___266 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___265 {
	struct dentry___266 * (*lookup)(struct inode___266 *, struct dentry___266 *, unsigned int);
	const char * (*get_link)(struct dentry___266 *, struct inode___266 *, struct delayed_call *);
	int (*permission)(struct inode___266 *, int);
	struct posix_acl * (*get_acl)(struct inode___266 *, int);
	int (*readlink)(struct dentry___266 *, char *, int);
	int (*create)(struct inode___266 *, struct dentry___266 *, umode_t, bool);
	int (*link)(struct dentry___266 *, struct inode___266 *, struct dentry___266 *);
	int (*unlink)(struct inode___266 *, struct dentry___266 *);
	int (*symlink)(struct inode___266 *, struct dentry___266 *, const char *);
	int (*mkdir)(struct inode___266 *, struct dentry___266 *, umode_t);
	int (*rmdir)(struct inode___266 *, struct dentry___266 *);
	int (*mknod)(struct inode___266 *, struct dentry___266 *, umode_t, dev_t);
	int (*rename)(struct inode___266 *, struct dentry___266 *, struct inode___266 *, struct dentry___266 *, unsigned int);
	int (*setattr)(struct dentry___266 *, struct iattr___265 *);
	int (*getattr)(const struct path___266 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___266 *, char *, size_t);
	int (*fiemap)(struct inode___266 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___266 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___266 *, struct dentry___266 *, struct file___266 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___266 *, struct dentry___266 *, umode_t);
	int (*set_acl)(struct inode___266 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___265 {
	void (*fl_copy_lock)(struct file_lock___266 *, struct file_lock___266 *);
	void (*fl_release_private)(struct file_lock___266 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___265;

struct lock_manager_operations___265;

struct file_lock___266 {
	struct file_lock___266 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___266 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___265 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___265 *fl_ops;
	const struct lock_manager_operations___265 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___265 {
	int (*lm_compare_owner)(struct file_lock___266 *, struct file_lock___266 *);
	long unsigned int (*lm_owner_key)(struct file_lock___266 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___266 *);
	int (*lm_grant)(struct file_lock___266 *, int);
	bool (*lm_break)(struct file_lock___266 *);
	int (*lm_change)(struct file_lock___266 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___266 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___265 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___265 *fa_next;
	struct file___266 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___265 {
	const char *name;
	int fs_flags;
	struct dentry___266 * (*mount)(struct file_system_type___265 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___265 *);
	struct module___11 *owner;
	struct file_system_type___265 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___265 {
	struct inode___266 * (*alloc_inode)(struct super_block___265 *);
	void (*destroy_inode)(struct inode___266 *);
	void (*dirty_inode)(struct inode___266 *, int);
	int (*write_inode)(struct inode___266 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___266 *);
	void (*evict_inode)(struct inode___266 *);
	void (*put_super)(struct super_block___265 *);
	int (*sync_fs)(struct super_block___265 *, int);
	int (*freeze_super)(struct super_block___265 *);
	int (*freeze_fs)(struct super_block___265 *);
	int (*thaw_super)(struct super_block___265 *);
	int (*unfreeze_fs)(struct super_block___265 *);
	int (*statfs)(struct dentry___266 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___265 *, int *, char *);
	void (*umount_begin)(struct super_block___265 *);
	int (*show_options)(struct seq_file___235 *, struct dentry___266 *);
	int (*show_devname)(struct seq_file___235 *, struct dentry___266 *);
	int (*show_path)(struct seq_file___235 *, struct dentry___266 *);
	int (*show_stats)(struct seq_file___235 *, struct dentry___266 *);
	ssize_t (*quota_read)(struct super_block___265 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___265 *, int, const char *, size_t, loff_t);
	struct dquot___265 ** (*get_dquots)(struct inode___266 *);
	int (*bdev_try_to_free_page)(struct super_block___265 *, struct page___267 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___265 *, struct shrink_control___112 *);
	long int (*free_cached_objects)(struct super_block___265 *, struct shrink_control___112 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___67 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___67 *last_lookup;
	struct hd_struct___67 *part[0];
};

struct block_device_operations___67 {
	int (*open)(struct block_device___265 *, fmode_t);
	void (*release)(struct gendisk___67 *, fmode_t);
	int (*rw_page)(struct block_device___265 *, sector_t, struct page___267 *, unsigned int);
	int (*ioctl)(struct block_device___265 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___265 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___67 *, unsigned int);
	int (*media_changed)(struct gendisk___67 *);
	void (*unlock_native_capacity)(struct gendisk___67 *);
	int (*revalidate_disk)(struct gendisk___67 *);
	int (*getgeo)(struct block_device___265 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___265 *, long unsigned int);
	int (*report_zones)(struct gendisk___67 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___11 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___255(struct page___267 *);

struct bdi_writeback_congested___135 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___135 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bsg_ops___66 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___66 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___66 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___66 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___66(struct request___66 *, blk_status_t);

struct request___66 {
	struct request_queue___66 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___135 *bio;
	struct bio___135 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___135 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___70 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___66 *saved_end_io;
		} flush;
	};
	struct gendisk___67 *rq_disk;
	struct hd_struct___67 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___66 *end_io;
	void *end_io_data;
	struct request___66 *next_rq;
};

struct fwnode_reference_args___164;

struct fwnode_endpoint___164;

struct fwnode_operations___164 {
	struct fwnode_handle___164 * (*get)(struct fwnode_handle___164 *);
	void (*put)(struct fwnode_handle___164 *);
	bool (*device_is_available)(const struct fwnode_handle___164 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___164 *, const struct device___229 *);
	bool (*property_present)(const struct fwnode_handle___164 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___164 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___164 *, const char *, const char **, size_t);
	struct fwnode_handle___164 * (*get_parent)(const struct fwnode_handle___164 *);
	struct fwnode_handle___164 * (*get_next_child_node)(const struct fwnode_handle___164 *, struct fwnode_handle___164 *);
	struct fwnode_handle___164 * (*get_named_child_node)(const struct fwnode_handle___164 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___164 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___164 *);
	struct fwnode_handle___164 * (*graph_get_next_endpoint)(const struct fwnode_handle___164 *, struct fwnode_handle___164 *);
	struct fwnode_handle___164 * (*graph_get_remote_endpoint)(const struct fwnode_handle___164 *);
	struct fwnode_handle___164 * (*graph_get_port_parent)(struct fwnode_handle___164 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___164 *, struct fwnode_endpoint___164 *);
};

struct fwnode_endpoint___164 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___164 *local_fwnode;
};

struct fwnode_reference_args___164 {
	struct fwnode_handle___164 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct elevator_type___66;

struct elevator_mq_ops___66 {
	int (*init_sched)(struct request_queue___66 *, struct elevator_type___66 *);
	void (*exit_sched)(struct elevator_queue___66 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	bool (*allow_merge)(struct request_queue___66 *, struct request___66 *, struct bio___135 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx *, struct bio___135 *);
	int (*request_merge)(struct request_queue___66 *, struct request___66 **, struct bio___135 *);
	void (*request_merged)(struct request_queue___66 *, struct request___66 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___66 *, struct request___66 *, struct request___66 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___66 *, struct bio___135 *);
	void (*finish_request)(struct request___66 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___66 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___66 *, u64);
	void (*started_request)(struct request___66 *);
	void (*requeue_request)(struct request___66 *);
	struct request___66 * (*former_request)(struct request_queue___66 *, struct request___66 *);
	struct request___66 * (*next_request)(struct request_queue___66 *, struct request___66 *);
	void (*init_icq)(struct io_cq___70 *);
	void (*exit_icq)(struct io_cq___70 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx___9 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___66;

struct elevator_type___66 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___66 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___66 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___11 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___66 {
	struct elevator_type___66 *type;
	void *elevator_data;
	struct kobject___254 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___66 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___66 *, char *);
	ssize_t (*store)(struct elevator_queue___66 *, const char *, size_t);
};

struct parsed_partitions___2 {
	struct block_device___265 *bdev;
	char name[32];
	struct {
		sector_t from;
		sector_t size;
		int flags;
		bool has_info;
		struct partition_meta_info info;
	} *parts;
	int next;
	int limit;
	bool access_beyond_eod;
	char *pp_buf;
};

typedef int (*key_restrict_link_func_t___257)(struct key___256 *, const struct key_type *, const union key_payload *, struct key___256 *);

struct key_restriction___256;

struct key___256 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___267 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key___6 index_key;
		struct {
			struct key_type___6 *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___256 *restrict_link;
};

struct key_restriction___256 {
	key_restrict_link_func_t___257 check;
	struct key___256 *key;
	struct key_type *keytype;
};

struct seq_operations___234 {
	void * (*start)(struct seq_file___235 *, loff_t *);
	void (*stop)(struct seq_file___235 *, void *);
	void * (*next)(struct seq_file___235 *, void *, loff_t *);
	int (*show)(struct seq_file___235 *, void *);
};

struct fat_boot_sector {
	__u8 ignored[3];
	__u8 system_id[8];
	__u8 sector_size[2];
	__u8 sec_per_clus;
	__le16 reserved;
	__u8 fats;
	__u8 dir_entries[2];
	__u8 sectors[2];
	__u8 media;
	__le16 fat_length;
	__le16 secs_track;
	__le16 heads;
	__le32 hidden;
	__le32 total_sect;
	union {
		struct {
			__u8 drive_number;
			__u8 state;
			__u8 signature;
			__u8 vol_id[4];
			__u8 vol_label[11];
			__u8 fs_type[8];
		} fat16;
		struct {
			__le32 length;
			__le16 flags;
			__u8 version[2];
			__le32 root_cluster;
			__le16 info_sector;
			__le16 backup_boot;
			__le16 reserved2[6];
			__u8 drive_number;
			__u8 state;
			__u8 signature;
			__u8 vol_id[4];
			__u8 vol_label[11];
			__u8 fs_type[8];
		} fat32;
	};
};

struct file___267;

struct kiocb___267;

struct poll_table_struct___166;

struct vm_area_struct___268;

struct inode___267;

struct file_lock___267;

struct page___268;

struct seq_file___236;

struct file_operations___267 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___267 *, loff_t, int);
	ssize_t (*read)(struct file___267 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___267 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___267 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___267 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___267 *, bool);
	int (*iterate)(struct file___267 *, struct dir_context *);
	int (*iterate_shared)(struct file___267 *, struct dir_context *);
	__poll_t (*poll)(struct file___267 *, struct poll_table_struct___166 *);
	long int (*unlocked_ioctl)(struct file___267 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___267 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___267 *, struct vm_area_struct___268 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___267 *, struct file___267 *);
	int (*flush)(struct file___267 *, fl_owner_t);
	int (*release)(struct inode___267 *, struct file___267 *);
	int (*fsync)(struct file___267 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___267 *, int);
	int (*lock)(struct file___267 *, int, struct file_lock___267 *);
	ssize_t (*sendpage)(struct file___267 *, struct page___268 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___267 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___267 *, int, struct file_lock___267 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___267 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___267 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___267 *, long int, struct file_lock___267 **, void **);
	long int (*fallocate)(struct file___267 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___236 *, struct file___267 *);
	ssize_t (*copy_file_range)(struct file___267 *, loff_t, struct file___267 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___267 *, loff_t, struct file___267 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___267 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___267 {
	u64 seqnum;
	struct vm_area_struct___268 *vmas[4];
};

struct page_frag___267 {
	struct page___268 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___267;

struct cred___257;

struct bio_list___136;

struct backing_dev_info___136;

struct io_context___71;

struct request_queue___67;

struct vm_struct___183;

struct task_struct___268 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___268 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___267 *mm;
	struct mm_struct___267 *active_mm;
	struct vmacache___267 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___268 *real_parent;
	struct task_struct___268 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___268 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___190 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___190 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___190 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___257 *ptracer_cred;
	const struct cred___257 *real_cred;
	const struct cred___257 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___268 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___136 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___136 *backing_dev_info;
	struct io_context___71 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___267 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___67 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___268 *oom_reaper_list;
	struct vm_struct___183 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___128 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___268 *pgtable_t___267;

struct address_space___266;

struct dev_pagemap___256;

struct page___268 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___266 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___268 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___267 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___267 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___256 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___267;

struct lruvec___267 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___267 *pgdat;
};

struct zone___267 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___267 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___267 {
	struct zone___267 *zone;
	int zone_idx;
};

struct zonelist___267 {
	struct zoneref___267 _zonerefs[25];
};

struct pglist_data___267 {
	struct zone___267 node_zones[3];
	struct zonelist___267 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___268 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___268 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___267 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___268 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___268 *owner;
};

struct secondary_data___268 {
	void *stack;
	struct task_struct___268 *task;
	long int status;
};

struct blocking_notifier_head___267 {
	struct rw_semaphore___268 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___256;

struct vm_area_struct___268 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___268 *vm_next;
	struct vm_area_struct___268 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___267 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___256 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___267 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___267;

struct mm_struct___267 {
	struct {
		struct vm_area_struct___268 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___267 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___268 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___267 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___268 *owner;
		struct user_namespace___3 *user_ns;
		struct file___267 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___267 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___266;

struct address_space___266 {
	struct inode___267 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___268 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___266 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___256)(struct vm_area_struct___268 *, long unsigned int, const struct page___268 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___256)(struct page___268 *, void *);

struct device___230;

struct dev_pagemap___256 {
	dev_page_fault_t___256 page_fault;
	dev_page_free_t___256 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___230 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct dentry___267;

struct path___267 {
	struct vfsmount *mnt;
	struct dentry___267 *dentry;
};

struct file___267 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___267 f_path;
	struct inode___267 *f_inode;
	const struct file_operations___267 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___190 f_owner;
	const struct cred___257 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___266 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___256;

struct vm_operations_struct___256 {
	void (*open)(struct vm_area_struct___268 *);
	void (*close)(struct vm_area_struct___268 *);
	int (*split)(struct vm_area_struct___268 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___268 *);
	vm_fault_t (*fault)(struct vm_fault___256 *);
	vm_fault_t (*huge_fault)(struct vm_fault___256 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___256 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___268 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___256 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___256 *);
	int (*access)(struct vm_area_struct___268 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___268 *);
	int (*set_policy)(struct vm_area_struct___268 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___268 *, long unsigned int);
	struct page___268 * (*find_special_page)(struct vm_area_struct___268 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___267 {
	struct task_struct___268 *task;
	struct core_thread___267 *next;
};

struct core_state___267 {
	atomic_t nr_threads;
	struct core_thread___267 dumper;
	struct completion startup;
};

struct vm_fault___256 {
	struct vm_area_struct___268 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___268 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___268 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___267 prealloc_pte;
};

struct key___257;

struct user_struct___257 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___257 *uid_keyring;
	struct key___257 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___257 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___257 *session_keyring;
	struct key___257 *process_keyring;
	struct key___257 *thread_keyring;
	struct key___257 *request_key_auth;
	void *security;
	struct user_struct___257 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct bio___136;

struct bio_list___136 {
	struct bio___136 *head;
	struct bio___136 *tail;
};

struct bdi_writeback_congested___136;

struct bdi_writeback___136 {
	struct backing_dev_info___136 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___136 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___157 *memcg_css;
	struct cgroup_subsys_state___157 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___136 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___136 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___230 *dev;
	struct device___230 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___267 *debug_dir;
	struct dentry___267 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___71;

struct io_context___71 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___71 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

typedef blk_qc_t make_request_fn___67(struct request_queue___67 *, struct bio___136 *);

struct request___67;

typedef int dma_drain_needed_fn___67(struct request___67 *);

struct kset___254;

struct kobj_type___254;

struct kernfs_node___262;

struct kobject___255 {
	const char *name;
	struct list_head entry;
	struct kobject___255 *parent;
	struct kset___254 *kset;
	struct kobj_type___254 *ktype;
	struct kernfs_node___262 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___67;

struct bsg_class_device___67 {
	struct device___230 *class_dev;
	int minor;
	struct request_queue___67 *queue;
	const struct bsg_ops___67 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___136 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___136 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___67;

struct request_queue___67 {
	struct list_head queue_head;
	struct request___67 *last_merge;
	struct elevator_queue___67 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___67 *make_request_fn;
	dma_drain_needed_fn___67 *dma_drain_needed;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___136 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___255 kobj;
	struct kobject___255 *mq_kobj;
	struct blk_integrity integrity;
	struct device___230 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	struct bsg_class_device___67 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___136 bio_split;
	struct dentry___267 *debugfs_dir;
	struct dentry___267 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___183 {
	struct vm_struct___183 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___268 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dev_pm_info___230 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___230 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___230;

struct bus_type___230;

struct device_driver___230;

struct dev_pm_domain___230;

struct fwnode_handle___165;

struct class___230;

struct attribute_group___232;

struct device___230 {
	struct device___230 *parent;
	struct device_private *p;
	struct kobject___255 kobj;
	const char *init_name;
	const struct device_type___230 *type;
	struct mutex mutex;
	struct bus_type___230 *bus;
	struct device_driver___230 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___230 power;
	struct dev_pm_domain___230 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___165 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___230 *class;
	const struct attribute_group___232 **groups;
	void (*release)(struct device___230 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___266;

struct super_block___266;

struct dentry___267 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___267 *d_parent;
	struct qstr d_name;
	struct inode___267 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___266 *d_op;
	struct super_block___266 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___266;

struct block_device___266;

struct cdev___41;

struct inode___267 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___266 *i_op;
	struct super_block___266 *i_sb;
	struct address_space___266 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___268 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___136 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___267 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___266 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___266 *i_bdev;
		struct cdev___41 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___266 {
	int (*d_revalidate)(struct dentry___267 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___267 *, unsigned int);
	int (*d_hash)(const struct dentry___267 *, struct qstr *);
	int (*d_compare)(const struct dentry___267 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___267 *);
	int (*d_init)(struct dentry___267 *);
	void (*d_release)(struct dentry___267 *);
	void (*d_prune)(struct dentry___267 *);
	void (*d_iput)(struct dentry___267 *, struct inode___267 *);
	char * (*d_dname)(struct dentry___267 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___267 *);
	int (*d_manage)(const struct path___267 *, bool);
	struct dentry___267 * (*d_real)(struct dentry___267 *, const struct inode___267 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___266;

struct mem_dqinfo___266 {
	struct quota_format_type___266 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___266;

struct quota_info___266 {
	unsigned int flags;
	struct rw_semaphore___268 dqio_sem;
	struct inode___267 *files[3];
	struct mem_dqinfo___266 info[3];
	const struct quota_format_ops___266 *ops[3];
};

struct rcuwait___266 {
	struct task_struct___268 *task;
};

struct percpu_rw_semaphore___266 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___268 rw_sem;
	struct rcuwait___266 writer;
	int readers_block;
};

struct sb_writers___266 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___266 rw_sem[3];
};

struct file_system_type___266;

struct super_operations___266;

struct dquot_operations___266;

struct quotactl_ops___266;

struct super_block___266 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___266 *s_type;
	const struct super_operations___266 *s_op;
	const struct dquot_operations___266 *dq_op;
	const struct quotactl_ops___266 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___267 *s_root;
	struct rw_semaphore___268 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___266 *s_bdev;
	struct backing_dev_info___136 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___266 s_dquot;
	struct sb_writers___266 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___266 *s_d_op;
	int cleancache_poolid;
	struct shrinker___112 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct io_cq___71 {
	struct request_queue___67 *q;
	struct io_context___71 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___6 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___267 {
	struct file___267 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___267 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___266 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___267 *ia_file;
};

struct dquot___266 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___266 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___266 {
	int qf_fmt_id;
	const struct quota_format_ops___266 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___266 *qf_next;
};

struct quota_format_ops___266 {
	int (*check_quota_file)(struct super_block___266 *, int);
	int (*read_file_info)(struct super_block___266 *, int);
	int (*write_file_info)(struct super_block___266 *, int);
	int (*free_file_info)(struct super_block___266 *, int);
	int (*read_dqblk)(struct dquot___266 *);
	int (*commit_dqblk)(struct dquot___266 *);
	int (*release_dqblk)(struct dquot___266 *);
	int (*get_next_id)(struct super_block___266 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___266 {
	int (*write_dquot)(struct dquot___266 *);
	struct dquot___266 * (*alloc_dquot)(struct super_block___266 *, int);
	void (*destroy_dquot)(struct dquot___266 *);
	int (*acquire_dquot)(struct dquot___266 *);
	int (*release_dquot)(struct dquot___266 *);
	int (*mark_dirty)(struct dquot___266 *);
	int (*write_info)(struct super_block___266 *, int);
	qsize_t * (*get_reserved_space)(struct inode___267 *);
	int (*get_projid)(struct inode___267 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___267 *, qsize_t *);
	int (*get_next_id)(struct super_block___266 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___266 {
	int (*quota_on)(struct super_block___266 *, int, int, const struct path___267 *);
	int (*quota_off)(struct super_block___266 *, int);
	int (*quota_enable)(struct super_block___266 *, unsigned int);
	int (*quota_disable)(struct super_block___266 *, unsigned int);
	int (*quota_sync)(struct super_block___266 *, int);
	int (*set_info)(struct super_block___266 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___266 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___266 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___266 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___266 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___266 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___266 {
	int (*writepage)(struct page___268 *, struct writeback_control___3 *);
	int (*readpage)(struct file___267 *, struct page___268 *);
	int (*writepages)(struct address_space___266 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___268 *);
	int (*readpages)(struct file___267 *, struct address_space___266 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___267 *, struct address_space___266 *, loff_t, unsigned int, unsigned int, struct page___268 **, void **);
	int (*write_end)(struct file___267 *, struct address_space___266 *, loff_t, unsigned int, unsigned int, struct page___268 *, void *);
	sector_t (*bmap)(struct address_space___266 *, sector_t);
	void (*invalidatepage)(struct page___268 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___268 *, gfp_t);
	void (*freepage)(struct page___268 *);
	ssize_t (*direct_IO)(struct kiocb___267 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___266 *, struct page___268 *, struct page___268 *, enum migrate_mode);
	bool (*isolate_page)(struct page___268 *, isolate_mode_t);
	void (*putback_page)(struct page___268 *);
	int (*launder_page)(struct page___268 *);
	int (*is_partially_uptodate)(struct page___268 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___268 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___266 *, struct page___268 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___267 *, sector_t *);
	void (*swap_deactivate)(struct file___267 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct hd_struct___68;

struct gendisk___68;

struct block_device___266 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___267 *bd_inode;
	struct super_block___266 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___266 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___68 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___68 *bd_disk;
	struct request_queue___67 *bd_queue;
	struct backing_dev_info___136 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct hd_struct___68 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___230 __dev;
	struct kobject___255 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___68;

struct block_device_operations___68;

struct gendisk___68 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___68 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___68 *part_tbl;
	struct hd_struct___68 part0;
	const struct block_device_operations___68 *fops;
	struct request_queue___67 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___268 lookup_sem;
	struct kobject___255 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___255 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___41 {
	struct kobject___255 kobj;
	struct module___11 *owner;
	const struct file_operations___267 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___266 {
	struct dentry___267 * (*lookup)(struct inode___267 *, struct dentry___267 *, unsigned int);
	const char * (*get_link)(struct dentry___267 *, struct inode___267 *, struct delayed_call *);
	int (*permission)(struct inode___267 *, int);
	struct posix_acl * (*get_acl)(struct inode___267 *, int);
	int (*readlink)(struct dentry___267 *, char *, int);
	int (*create)(struct inode___267 *, struct dentry___267 *, umode_t, bool);
	int (*link)(struct dentry___267 *, struct inode___267 *, struct dentry___267 *);
	int (*unlink)(struct inode___267 *, struct dentry___267 *);
	int (*symlink)(struct inode___267 *, struct dentry___267 *, const char *);
	int (*mkdir)(struct inode___267 *, struct dentry___267 *, umode_t);
	int (*rmdir)(struct inode___267 *, struct dentry___267 *);
	int (*mknod)(struct inode___267 *, struct dentry___267 *, umode_t, dev_t);
	int (*rename)(struct inode___267 *, struct dentry___267 *, struct inode___267 *, struct dentry___267 *, unsigned int);
	int (*setattr)(struct dentry___267 *, struct iattr___266 *);
	int (*getattr)(const struct path___267 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___267 *, char *, size_t);
	int (*fiemap)(struct inode___267 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___267 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___267 *, struct dentry___267 *, struct file___267 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___267 *, struct dentry___267 *, umode_t);
	int (*set_acl)(struct inode___267 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___266 {
	void (*fl_copy_lock)(struct file_lock___267 *, struct file_lock___267 *);
	void (*fl_release_private)(struct file_lock___267 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___266;

struct lock_manager_operations___266;

struct file_lock___267 {
	struct file_lock___267 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___267 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___266 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___266 *fl_ops;
	const struct lock_manager_operations___266 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___266 {
	int (*lm_compare_owner)(struct file_lock___267 *, struct file_lock___267 *);
	long unsigned int (*lm_owner_key)(struct file_lock___267 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___267 *);
	int (*lm_grant)(struct file_lock___267 *, int);
	bool (*lm_break)(struct file_lock___267 *);
	int (*lm_change)(struct file_lock___267 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___267 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___266 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___266 *fa_next;
	struct file___267 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___266 {
	const char *name;
	int fs_flags;
	struct dentry___267 * (*mount)(struct file_system_type___266 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___266 *);
	struct module___11 *owner;
	struct file_system_type___266 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___266 {
	struct inode___267 * (*alloc_inode)(struct super_block___266 *);
	void (*destroy_inode)(struct inode___267 *);
	void (*dirty_inode)(struct inode___267 *, int);
	int (*write_inode)(struct inode___267 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___267 *);
	void (*evict_inode)(struct inode___267 *);
	void (*put_super)(struct super_block___266 *);
	int (*sync_fs)(struct super_block___266 *, int);
	int (*freeze_super)(struct super_block___266 *);
	int (*freeze_fs)(struct super_block___266 *);
	int (*thaw_super)(struct super_block___266 *);
	int (*unfreeze_fs)(struct super_block___266 *);
	int (*statfs)(struct dentry___267 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___266 *, int *, char *);
	void (*umount_begin)(struct super_block___266 *);
	int (*show_options)(struct seq_file___236 *, struct dentry___267 *);
	int (*show_devname)(struct seq_file___236 *, struct dentry___267 *);
	int (*show_path)(struct seq_file___236 *, struct dentry___267 *);
	int (*show_stats)(struct seq_file___236 *, struct dentry___267 *);
	ssize_t (*quota_read)(struct super_block___266 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___266 *, int, const char *, size_t, loff_t);
	struct dquot___266 ** (*get_dquots)(struct inode___267 *);
	int (*bdev_try_to_free_page)(struct super_block___266 *, struct page___268 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___266 *, struct shrink_control___112 *);
	long int (*free_cached_objects)(struct super_block___266 *, struct shrink_control___112 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___168)(struct file___267 *, wait_queue_head_t *, struct poll_table_struct___166 *);

struct poll_table_struct___166 {
	poll_queue_proc___168 _qproc;
	__poll_t _key;
};

struct seq_operations___235;

struct seq_file___236 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___235 *op;
	int poll_event;
	const struct file___267 *file;
	void *private;
};

typedef void bio_end_io_t___136(struct bio___136 *);

struct bio_vec___136 {
	struct page___268 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___136;

struct bio___136 {
	struct bio___136 *bi_next;
	struct gendisk___68 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___136 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___136 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___136 *bi_io_vec;
	struct bio_set___136 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___136 bi_inline_vecs[0];
};

struct kobj_attribute___247 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___255 *, struct kobj_attribute___247 *, char *);
	ssize_t (*store)(struct kobject___255 *, struct kobj_attribute___247 *, const char *, size_t);
};

typedef void compound_page_dtor___256(struct page___268 *);

struct bio_integrity_payload___136 {
	struct bio___136 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___136 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___136 bip_inline_vecs[0];
};

struct dev_pm_ops___230;

struct device_type___230 {
	const char *name;
	const struct attribute_group___232 **groups;
	int (*uevent)(struct device___230 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___230 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___230 *);
	const struct dev_pm_ops___230 *pm;
};

struct class___230 {
	const char *name;
	struct module___11 *owner;
	const struct attribute_group___232 **class_groups;
	const struct attribute_group___232 **dev_groups;
	struct kobject___255 *dev_kobj;
	int (*dev_uevent)(struct device___230 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___230 *, umode_t *);
	void (*class_release)(struct class___230 *);
	void (*dev_release)(struct device___230 *);
	int (*shutdown_pre)(struct device___230 *);
	const struct kobj_ns_type_operations___24 *ns_type;
	const void * (*namespace)(struct device___230 *);
	const struct dev_pm_ops___230 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

enum {
	DOS_EXTENDED_PARTITION = 5,
	LINUX_EXTENDED_PARTITION = 133,
	WIN98_EXTENDED_PARTITION = 15,
	SUN_WHOLE_DISK = 5,
	LINUX_SWAP_PARTITION = 130,
	LINUX_DATA_PARTITION = 131,
	LINUX_LVM_PARTITION = 142,
	LINUX_RAID_PARTITION = 253,
	SOLARIS_X86_PARTITION = 130,
	NEW_SOLARIS_X86_PARTITION = 191,
	DM6_AUX1PARTITION = 81,
	DM6_AUX3PARTITION = 83,
	DM6_PARTITION = 84,
	EZD_PARTITION = 85,
	FREEBSD_PARTITION = 165,
	OPENBSD_PARTITION = 166,
	NETBSD_PARTITION = 169,
	BSDI_PARTITION = 183,
	MINIX_PARTITION = 129,
	UNIXWARE_PARTITION = 99,
};

struct kernfs_root___261;

struct kernfs_elem_dir___261 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___261 *root;
};

struct kernfs_syscall_ops___261;

struct kernfs_root___261 {
	struct kernfs_node___262 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___261 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___261 {
	struct kernfs_node___262 *target_kn;
};

struct kernfs_ops___261;

struct kernfs_elem_attr___261 {
	const struct kernfs_ops___261 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___262 *notify_next;
};

struct kernfs_node___262 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___262 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___261 dir;
		struct kernfs_elem_symlink___261 symlink;
		struct kernfs_elem_attr___261 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___261;

struct kernfs_ops___261 {
	int (*open)(struct kernfs_open_file___261 *);
	void (*release)(struct kernfs_open_file___261 *);
	int (*seq_show)(struct seq_file___236 *, void *);
	void * (*seq_start)(struct seq_file___236 *, loff_t *);
	void * (*seq_next)(struct seq_file___236 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___236 *, void *);
	ssize_t (*read)(struct kernfs_open_file___261 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___261 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___261 *, struct vm_area_struct___268 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___261 *, struct poll_table_struct___166 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___261 {
	int (*remount_fs)(struct kernfs_root___261 *, int *, char *);
	int (*show_options)(struct seq_file___236 *, struct kernfs_root___261 *);
	int (*mkdir)(struct kernfs_node___262 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___262 *);
	int (*rename)(struct kernfs_node___262 *, struct kernfs_node___262 *, const char *);
	int (*show_path)(struct seq_file___236 *, struct kernfs_node___262 *, struct kernfs_root___261 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___261 {
	struct kernfs_node___262 *kn;
	struct file___267 *file;
	struct seq_file___236 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___256 *vm_ops;
};

struct bin_attribute___231;

struct attribute_group___232 {
	const char *name;
	umode_t (*is_visible)(struct kobject___255 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___255 *, struct bin_attribute___231 *, int);
	struct attribute **attrs;
	struct bin_attribute___231 **bin_attrs;
};

struct bin_attribute___231 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___267 *, struct kobject___255 *, struct bin_attribute___231 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___267 *, struct kobject___255 *, struct bin_attribute___231 *, char *, loff_t, size_t);
	int (*mmap)(struct file___267 *, struct kobject___255 *, struct bin_attribute___231 *, struct vm_area_struct___268 *);
};

struct sysfs_ops___254 {
	ssize_t (*show)(struct kobject___255 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___255 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___254;

struct kset___254 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___255 kobj;
	const struct kset_uevent_ops___254 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___254 {
	void (*release)(struct kobject___255 *);
	const struct sysfs_ops___254 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___24 * (*child_ns_type)(struct kobject___255 *);
	const void * (*namespace)(struct kobject___255 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___254 {
	int (* const filter)(struct kset___254 *, struct kobject___255 *);
	const char * (* const name)(struct kset___254 *, struct kobject___255 *);
	int (* const uevent)(struct kset___254 *, struct kobject___255 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___230 {
	int (*prepare)(struct device___230 *);
	void (*complete)(struct device___230 *);
	int (*suspend)(struct device___230 *);
	int (*resume)(struct device___230 *);
	int (*freeze)(struct device___230 *);
	int (*thaw)(struct device___230 *);
	int (*poweroff)(struct device___230 *);
	int (*restore)(struct device___230 *);
	int (*suspend_late)(struct device___230 *);
	int (*resume_early)(struct device___230 *);
	int (*freeze_late)(struct device___230 *);
	int (*thaw_early)(struct device___230 *);
	int (*poweroff_late)(struct device___230 *);
	int (*restore_early)(struct device___230 *);
	int (*suspend_noirq)(struct device___230 *);
	int (*resume_noirq)(struct device___230 *);
	int (*freeze_noirq)(struct device___230 *);
	int (*thaw_noirq)(struct device___230 *);
	int (*poweroff_noirq)(struct device___230 *);
	int (*restore_noirq)(struct device___230 *);
	int (*runtime_suspend)(struct device___230 *);
	int (*runtime_resume)(struct device___230 *);
	int (*runtime_idle)(struct device___230 *);
};

struct dev_pm_domain___230 {
	struct dev_pm_ops___230 ops;
	void (*detach)(struct device___230 *, bool);
	int (*activate)(struct device___230 *);
	void (*sync)(struct device___230 *);
	void (*dismiss)(struct device___230 *);
};

struct bus_type___230 {
	const char *name;
	const char *dev_name;
	struct device___230 *dev_root;
	const struct attribute_group___232 **bus_groups;
	const struct attribute_group___232 **dev_groups;
	const struct attribute_group___232 **drv_groups;
	int (*match)(struct device___230 *, struct device_driver___230 *);
	int (*uevent)(struct device___230 *, struct kobj_uevent_env *);
	int (*probe)(struct device___230 *);
	int (*remove)(struct device___230 *);
	void (*shutdown)(struct device___230 *);
	int (*online)(struct device___230 *);
	int (*offline)(struct device___230 *);
	int (*suspend)(struct device___230 *, pm_message_t);
	int (*resume)(struct device___230 *);
	int (*num_vf)(struct device___230 *);
	int (*dma_configure)(struct device___230 *);
	const struct dev_pm_ops___230 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___230 {
	const char *name;
	struct bus_type___230 *bus;
	struct module___11 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___230 *);
	int (*remove)(struct device___230 *);
	void (*shutdown)(struct device___230 *);
	int (*suspend)(struct device___230 *, pm_message_t);
	int (*resume)(struct device___230 *);
	const struct attribute_group___232 **groups;
	const struct dev_pm_ops___230 *pm;
	void (*coredump)(struct device___230 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct fwnode_operations___165;

struct fwnode_handle___165 {
	struct fwnode_handle___165 *secondary;
	const struct fwnode_operations___165 *ops;
};

struct partition {
	unsigned char boot_ind;
	unsigned char head;
	unsigned char sector;
	unsigned char cyl;
	unsigned char sys_ind;
	unsigned char end_head;
	unsigned char end_sector;
	unsigned char end_cyl;
	__le32 start_sect;
	__le32 nr_sects;
};

struct disk_part_tbl___68 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___68 *last_lookup;
	struct hd_struct___68 *part[0];
};

struct block_device_operations___68 {
	int (*open)(struct block_device___266 *, fmode_t);
	void (*release)(struct gendisk___68 *, fmode_t);
	int (*rw_page)(struct block_device___266 *, sector_t, struct page___268 *, unsigned int);
	int (*ioctl)(struct block_device___266 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___266 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___68 *, unsigned int);
	int (*media_changed)(struct gendisk___68 *);
	void (*unlock_native_capacity)(struct gendisk___68 *);
	int (*revalidate_disk)(struct gendisk___68 *);
	int (*getgeo)(struct block_device___266 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___266 *, long unsigned int);
	int (*report_zones)(struct gendisk___68 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___11 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsd_partition {
	__le32 p_size;
	__le32 p_offset;
	__le32 p_fsize;
	__u8 p_fstype;
	__u8 p_frag;
	__le16 p_cpg;
};

struct bsd_disklabel {
	__le32 d_magic;
	__s16 d_type;
	__s16 d_subtype;
	char d_typename[16];
	char d_packname[16];
	__u32 d_secsize;
	__u32 d_nsectors;
	__u32 d_ntracks;
	__u32 d_ncylinders;
	__u32 d_secpercyl;
	__u32 d_secperunit;
	__u16 d_sparespertrack;
	__u16 d_sparespercyl;
	__u32 d_acylinders;
	__u16 d_rpm;
	__u16 d_interleave;
	__u16 d_trackskew;
	__u16 d_cylskew;
	__u32 d_headswitch;
	__u32 d_trkseek;
	__u32 d_flags;
	__u32 d_drivedata[5];
	__u32 d_spare[5];
	__le32 d_magic2;
	__le16 d_checksum;
	__le16 d_npartitions;
	__le32 d_bbsize;
	__le32 d_sbsize;
	struct bsd_partition d_partitions[16];
};

struct bdi_writeback_congested___136 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___136 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bsg_ops___67 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___67 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___67 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___67 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___67(struct request___67 *, blk_status_t);

struct request___67 {
	struct request_queue___67 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___136 *bio;
	struct bio___136 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___136 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___71 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___67 *saved_end_io;
		} flush;
	};
	struct gendisk___68 *rq_disk;
	struct hd_struct___68 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___67 *end_io;
	void *end_io_data;
	struct request___67 *next_rq;
};

struct fwnode_reference_args___165;

struct fwnode_endpoint___165;

struct fwnode_operations___165 {
	struct fwnode_handle___165 * (*get)(struct fwnode_handle___165 *);
	void (*put)(struct fwnode_handle___165 *);
	bool (*device_is_available)(const struct fwnode_handle___165 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___165 *, const struct device___230 *);
	bool (*property_present)(const struct fwnode_handle___165 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___165 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___165 *, const char *, const char **, size_t);
	struct fwnode_handle___165 * (*get_parent)(const struct fwnode_handle___165 *);
	struct fwnode_handle___165 * (*get_next_child_node)(const struct fwnode_handle___165 *, struct fwnode_handle___165 *);
	struct fwnode_handle___165 * (*get_named_child_node)(const struct fwnode_handle___165 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___165 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___165 *);
	struct fwnode_handle___165 * (*graph_get_next_endpoint)(const struct fwnode_handle___165 *, struct fwnode_handle___165 *);
	struct fwnode_handle___165 * (*graph_get_remote_endpoint)(const struct fwnode_handle___165 *);
	struct fwnode_handle___165 * (*graph_get_port_parent)(struct fwnode_handle___165 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___165 *, struct fwnode_endpoint___165 *);
};

struct fwnode_endpoint___165 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___165 *local_fwnode;
};

struct fwnode_reference_args___165 {
	struct fwnode_handle___165 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct elevator_type___67;

struct elevator_mq_ops___67 {
	int (*init_sched)(struct request_queue___67 *, struct elevator_type___67 *);
	void (*exit_sched)(struct elevator_queue___67 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	bool (*allow_merge)(struct request_queue___67 *, struct request___67 *, struct bio___136 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx *, struct bio___136 *);
	int (*request_merge)(struct request_queue___67 *, struct request___67 **, struct bio___136 *);
	void (*request_merged)(struct request_queue___67 *, struct request___67 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___67 *, struct request___67 *, struct request___67 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___67 *, struct bio___136 *);
	void (*finish_request)(struct request___67 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___67 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___67 *, u64);
	void (*started_request)(struct request___67 *);
	void (*requeue_request)(struct request___67 *);
	struct request___67 * (*former_request)(struct request_queue___67 *, struct request___67 *);
	struct request___67 * (*next_request)(struct request_queue___67 *, struct request___67 *);
	void (*init_icq)(struct io_cq___71 *);
	void (*exit_icq)(struct io_cq___71 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx___9 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___67;

struct elevator_type___67 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___67 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___67 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___11 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___67 {
	struct elevator_type___67 *type;
	void *elevator_data;
	struct kobject___255 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___67 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___67 *, char *);
	ssize_t (*store)(struct elevator_queue___67 *, const char *, size_t);
};

typedef struct {
	struct page___268 *v;
} Sector___2;

struct parsed_partitions___3 {
	struct block_device___266 *bdev;
	char name[32];
	struct {
		sector_t from;
		sector_t size;
		int flags;
		bool has_info;
		struct partition_meta_info info;
	} *parts;
	int next;
	int limit;
	bool access_beyond_eod;
	char *pp_buf;
};

typedef int (*key_restrict_link_func_t___258)(struct key___257 *, const struct key_type *, const union key_payload *, struct key___257 *);

struct key_restriction___257;

struct key___257 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___268 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key___6 index_key;
		struct {
			struct key_type___6 *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___257 *restrict_link;
};

struct key_restriction___257 {
	key_restrict_link_func_t___258 check;
	struct key___257 *key;
	struct key_type *keytype;
};

struct seq_operations___235 {
	void * (*start)(struct seq_file___236 *, loff_t *);
	void (*stop)(struct seq_file___236 *, void *);
	void * (*next)(struct seq_file___236 *, void *, loff_t *);
	int (*show)(struct seq_file___236 *, void *);
};

struct _gpt_header {
	__le64 signature;
	__le32 revision;
	__le32 header_size;
	__le32 header_crc32;
	__le32 reserved1;
	__le64 my_lba;
	__le64 alternate_lba;
	__le64 first_usable_lba;
	__le64 last_usable_lba;
	efi_guid_t disk_guid;
	__le64 partition_entry_lba;
	__le32 num_partition_entries;
	__le32 sizeof_partition_entry;
	__le32 partition_entry_array_crc32;
} __attribute__((packed));

typedef struct _gpt_header gpt_header;

struct _gpt_entry_attributes {
	u64 required_to_function: 1;
	u64 reserved: 47;
	u64 type_guid_specific: 16;
};

typedef struct _gpt_entry_attributes gpt_entry_attributes;

struct _gpt_entry {
	efi_guid_t partition_type_guid;
	efi_guid_t unique_partition_guid;
	__le64 starting_lba;
	__le64 ending_lba;
	gpt_entry_attributes attributes;
	efi_char16_t partition_name[36];
};

typedef struct _gpt_entry gpt_entry;

struct _gpt_mbr_record {
	u8 boot_indicator;
	u8 start_head;
	u8 start_sector;
	u8 start_track;
	u8 os_type;
	u8 end_head;
	u8 end_sector;
	u8 end_track;
	__le32 starting_lba;
	__le32 size_in_lba;
};

typedef struct _gpt_mbr_record gpt_mbr_record;

struct _legacy_mbr {
	u8 boot_code[440];
	__le32 unique_mbr_signature;
	__le16 unknown;
	gpt_mbr_record partition_record[4];
	__le16 signature;
} __attribute__((packed));

typedef struct _legacy_mbr legacy_mbr;

struct rq_wait {
	wait_queue_head_t wait;
	atomic_t inflight;
};

struct rq_depth {
	unsigned int max_depth;
	int scale_step;
	bool scaled_max;
	unsigned int queue_depth;
	unsigned int default_depth;
};

typedef bool acquire_inflight_cb_t(struct rq_wait *, void *);

typedef void cleanup_cb_t(struct rq_wait *, void *);

struct rq_qos_wait_data {
	struct wait_queue_entry wq;
	struct task_struct___259 *task;
	struct rq_wait *rqw;
	acquire_inflight_cb_t *cb;
	void *private_data;
	bool got_token;
};

struct module___217;

struct file___268;

struct kiocb___268;

struct iov_iter___131;

struct vm_area_struct___269;

struct inode___268;

struct file_lock___268;

struct page___269;

struct file_operations___268 {
	struct module___217 *owner;
	loff_t (*llseek)(struct file___268 *, loff_t, int);
	ssize_t (*read)(struct file___268 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___268 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___268 *, struct iov_iter___131 *);
	ssize_t (*write_iter)(struct kiocb___268 *, struct iov_iter___131 *);
	int (*iopoll)(struct kiocb___268 *, bool);
	int (*iterate)(struct file___268 *, struct dir_context *);
	int (*iterate_shared)(struct file___268 *, struct dir_context *);
	__poll_t (*poll)(struct file___268 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___268 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___268 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___268 *, struct vm_area_struct___269 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___268 *, struct file___268 *);
	int (*flush)(struct file___268 *, fl_owner_t);
	int (*release)(struct inode___268 *, struct file___268 *);
	int (*fsync)(struct file___268 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___268 *, int);
	int (*lock)(struct file___268 *, int, struct file_lock___268 *);
	ssize_t (*sendpage)(struct file___268 *, struct page___269 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___268 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___268 *, int, struct file_lock___268 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___268 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___268 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___268 *, long int, struct file_lock___268 **, void **);
	long int (*fallocate)(struct file___268 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___268 *);
	ssize_t (*copy_file_range)(struct file___268 *, loff_t, struct file___268 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___268 *, loff_t, struct file___268 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___268 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___268 {
	u64 seqnum;
	struct vm_area_struct___269 *vmas[4];
};

struct page_frag___268 {
	struct page___269 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___268;

struct bio_list___137;

struct backing_dev_info___137;

struct io_context___72;

struct request_queue___68;

struct vm_struct___184;

struct task_struct___269 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___269 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___268 *mm;
	struct mm_struct___268 *active_mm;
	struct vmacache___268 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___269 *real_parent;
	struct task_struct___269 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___269 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___190 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___190 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___190 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___2 *ptracer_cred;
	const struct cred___2 *real_cred;
	const struct cred___2 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___269 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___137 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___137 *backing_dev_info;
	struct io_context___72 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___268 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___68 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___269 *oom_reaper_list;
	struct vm_struct___184 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___128 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___269 *pgtable_t___268;

struct address_space___267;

struct dev_pagemap___257;

struct page___269 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___267 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___269 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___268 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___268 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___257 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___268;

struct lruvec___268 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___268 *pgdat;
};

struct zone___268 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___268 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___268 {
	struct zone___268 *zone;
	int zone_idx;
};

struct zonelist___268 {
	struct zoneref___268 _zonerefs[25];
};

struct pglist_data___268 {
	struct zone___268 node_zones[3];
	struct zonelist___268 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___269 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___269 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___268 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___269 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___269 *owner;
};

struct secondary_data___269 {
	void *stack;
	struct task_struct___269 *task;
	long int status;
};

struct blocking_notifier_head___268 {
	struct rw_semaphore___269 rwsem;
	struct notifier_block *head;
};

struct dentry___268;

struct path___268 {
	struct vfsmount *mnt;
	struct dentry___268 *dentry;
};

struct file___268 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___268 f_path;
	struct inode___268 *f_inode;
	const struct file_operations___268 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___190 f_owner;
	const struct cred___2 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___267 *f_mapping;
	errseq_t f_wb_err;
};

struct kernfs_root___262;

struct kernfs_elem_dir___262 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___262 *root;
};

struct kernfs_node___263;

struct kernfs_syscall_ops___262;

struct kernfs_root___262 {
	struct kernfs_node___263 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___262 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___262 {
	struct kernfs_node___263 *target_kn;
};

struct kernfs_ops___262;

struct kernfs_elem_attr___262 {
	const struct kernfs_ops___262 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___263 *notify_next;
};

struct kernfs_node___263 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___263 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___262 dir;
		struct kernfs_elem_symlink___262 symlink;
		struct kernfs_elem_attr___262 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___262;

struct kernfs_ops___262 {
	int (*open)(struct kernfs_open_file___262 *);
	void (*release)(struct kernfs_open_file___262 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___262 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___262 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___262 *, struct vm_area_struct___269 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___262 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___262 {
	int (*remount_fs)(struct kernfs_root___262 *, int *, char *);
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___262 *);
	int (*mkdir)(struct kernfs_node___263 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___263 *);
	int (*rename)(struct kernfs_node___263 *, struct kernfs_node___263 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___263 *, struct kernfs_root___262 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_operations_struct___257;

struct kernfs_open_file___262 {
	struct kernfs_node___263 *kn;
	struct file___268 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___257 *vm_ops;
};

struct vm_fault___257;

struct vm_operations_struct___257 {
	void (*open)(struct vm_area_struct___269 *);
	void (*close)(struct vm_area_struct___269 *);
	int (*split)(struct vm_area_struct___269 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___269 *);
	vm_fault_t (*fault)(struct vm_fault___257 *);
	vm_fault_t (*huge_fault)(struct vm_fault___257 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___257 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___269 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___257 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___257 *);
	int (*access)(struct vm_area_struct___269 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___269 *);
	int (*set_policy)(struct vm_area_struct___269 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___269 *, long unsigned int);
	struct page___269 * (*find_special_page)(struct vm_area_struct___269 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_area_struct___269 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___269 *vm_next;
	struct vm_area_struct___269 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___268 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___257 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___268 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___256;

struct bin_attribute___232;

struct attribute_group___233 {
	const char *name;
	umode_t (*is_visible)(struct kobject___256 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___256 *, struct bin_attribute___232 *, int);
	struct attribute **attrs;
	struct bin_attribute___232 **bin_attrs;
};

struct kset___255;

struct kobj_type___255;

struct kobject___256 {
	const char *name;
	struct list_head entry;
	struct kobject___256 *parent;
	struct kset___255 *kset;
	struct kobj_type___255 *ktype;
	struct kernfs_node___263 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___232 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___268 *, struct kobject___256 *, struct bin_attribute___232 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___268 *, struct kobject___256 *, struct bin_attribute___232 *, char *, loff_t, size_t);
	int (*mmap)(struct file___268 *, struct kobject___256 *, struct bin_attribute___232 *, struct vm_area_struct___269 *);
};

struct sysfs_ops___255 {
	ssize_t (*show)(struct kobject___256 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___256 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___255;

struct kset___255 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___256 kobj;
	const struct kset_uevent_ops___255 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___255 {
	void (*release)(struct kobject___256 *);
	const struct sysfs_ops___255 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___24 * (*child_ns_type)(struct kobject___256 *);
	const void * (*namespace)(struct kobject___256 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___255 {
	int (* const filter)(struct kset___255 *, struct kobject___256 *);
	const char * (* const name)(struct kset___255 *, struct kobject___256 *);
	int (* const uevent)(struct kset___255 *, struct kobject___256 *, struct kobj_uevent_env *);
};

struct kobj_attribute___248 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___256 *, struct kobj_attribute___248 *, char *);
	ssize_t (*store)(struct kobject___256 *, struct kobj_attribute___248 *, const char *, size_t);
};

struct kernel_param___214;

struct kernel_param_ops___214 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___214 *);
	int (*get)(char *, const struct kernel_param___214 *);
	void (*free)(void *);
};

struct kparam_array___214;

struct kernel_param___214 {
	const char *name;
	struct module___217 *mod;
	const struct kernel_param_ops___214 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___214 *arr;
	};
};

struct kparam_array___214 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___214 *ops;
	void *elem;
};

struct module_kobject___214 {
	struct kobject___256 kobj;
	struct module___217 *mod;
	struct kobject___256 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___214 {
	struct module___217 *mod;
	struct latch_tree_node node;
};

struct module_layout___214 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___214 mtn;
};

struct module_attribute___214;

struct module___217 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___214 mkobj;
	struct module_attribute___214 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___256 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___214 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___214 core_layout;
	struct module_layout___214 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___214 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___214 *, struct module_kobject___214 *, char *);
	ssize_t (*store)(struct module_attribute___214 *, struct module_kobject___214 *, const char *, size_t);
	void (*setup)(struct module___217 *, const char *);
	int (*test)(struct module___217 *);
	void (*free)(struct module___217 *);
};

struct core_state___268;

struct mm_struct___268 {
	struct {
		struct vm_area_struct___269 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___268 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___269 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___268 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___269 *owner;
		struct user_namespace___3 *user_ns;
		struct file___268 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___268 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct bio___137;

struct bio_list___137 {
	struct bio___137 *head;
	struct bio___137 *tail;
};

struct bdi_writeback_congested___137;

struct bdi_writeback___137 {
	struct backing_dev_info___137 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___137 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___157 *memcg_css;
	struct cgroup_subsys_state___157 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___231;

struct backing_dev_info___137 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___137 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___231 *dev;
	struct device___231 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___268 *debug_dir;
	struct dentry___268 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___72;

struct io_context___72 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___72 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

typedef blk_qc_t make_request_fn___68(struct request_queue___68 *, struct bio___137 *);

struct request___68;

typedef int dma_drain_needed_fn___68(struct request___68 *);

struct bsg_ops___68;

struct bsg_class_device___68 {
	struct device___231 *class_dev;
	int minor;
	struct request_queue___68 *queue;
	const struct bsg_ops___68 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___137 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___137 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___68;

struct blk_mq_ops___10;

struct blk_mq_hw_ctx___10;

struct blk_mq_tag_set___10;

struct request_queue___68 {
	struct list_head queue_head;
	struct request___68 *last_merge;
	struct elevator_queue___68 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___68 *make_request_fn;
	dma_drain_needed_fn___68 *dma_drain_needed;
	const struct blk_mq_ops___10 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___10 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___137 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___256 kobj;
	struct kobject___256 *mq_kobj;
	struct blk_integrity integrity;
	struct device___231 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	struct bsg_class_device___68 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set___10 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___137 bio_split;
	struct dentry___268 *debugfs_dir;
	struct dentry___268 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___184 {
	struct vm_struct___184 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___269 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bio_vec___137 {
	struct page___269 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

typedef void bio_end_io_t___137(struct bio___137 *);

struct gendisk___69;

struct bio_integrity_payload___137;

struct bio___137 {
	struct bio___137 *bi_next;
	struct gendisk___69 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___137 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___137 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___137 *bi_io_vec;
	struct bio_set___137 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___137 bi_inline_vecs[0];
};

struct bio_integrity_payload___137 {
	struct bio___137 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___137 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___137 bip_inline_vecs[0];
};

struct dev_pm_info___231 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___231 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___231;

struct bus_type___231;

struct device_driver___231;

struct dev_pm_domain___231;

struct dma_map_ops___63;

struct fwnode_handle___166;

struct class___231;

struct device___231 {
	struct device___231 *parent;
	struct device_private *p;
	struct kobject___256 kobj;
	const char *init_name;
	const struct device_type___231 *type;
	struct mutex mutex;
	struct bus_type___231 *bus;
	struct device_driver___231 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___231 power;
	struct dev_pm_domain___231 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___63 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___166 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___231 *class;
	const struct attribute_group___233 **groups;
	void (*release)(struct device___231 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___69 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___231 __dev;
	struct kobject___256 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___69;

struct block_device_operations___69;

struct gendisk___69 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___69 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___69 *part_tbl;
	struct hd_struct___69 part0;
	const struct block_device_operations___69 *fops;
	struct request_queue___68 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___269 lookup_sem;
	struct kobject___256 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___256 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_ops___231;

struct device_type___231 {
	const char *name;
	const struct attribute_group___233 **groups;
	int (*uevent)(struct device___231 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___231 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___231 *);
	const struct dev_pm_ops___231 *pm;
};

struct class___231 {
	const char *name;
	struct module___217 *owner;
	const struct attribute_group___233 **class_groups;
	const struct attribute_group___233 **dev_groups;
	struct kobject___256 *dev_kobj;
	int (*dev_uevent)(struct device___231 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___231 *, umode_t *);
	void (*class_release)(struct class___231 *);
	void (*dev_release)(struct device___231 *);
	int (*shutdown_pre)(struct device___231 *);
	const struct kobj_ns_type_operations___24 *ns_type;
	const void * (*namespace)(struct device___231 *);
	const struct dev_pm_ops___231 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dev_pm_ops___231 {
	int (*prepare)(struct device___231 *);
	void (*complete)(struct device___231 *);
	int (*suspend)(struct device___231 *);
	int (*resume)(struct device___231 *);
	int (*freeze)(struct device___231 *);
	int (*thaw)(struct device___231 *);
	int (*poweroff)(struct device___231 *);
	int (*restore)(struct device___231 *);
	int (*suspend_late)(struct device___231 *);
	int (*resume_early)(struct device___231 *);
	int (*freeze_late)(struct device___231 *);
	int (*thaw_early)(struct device___231 *);
	int (*poweroff_late)(struct device___231 *);
	int (*restore_early)(struct device___231 *);
	int (*suspend_noirq)(struct device___231 *);
	int (*resume_noirq)(struct device___231 *);
	int (*freeze_noirq)(struct device___231 *);
	int (*thaw_noirq)(struct device___231 *);
	int (*poweroff_noirq)(struct device___231 *);
	int (*restore_noirq)(struct device___231 *);
	int (*runtime_suspend)(struct device___231 *);
	int (*runtime_resume)(struct device___231 *);
	int (*runtime_idle)(struct device___231 *);
};

struct dev_pm_domain___231 {
	struct dev_pm_ops___231 ops;
	void (*detach)(struct device___231 *, bool);
	int (*activate)(struct device___231 *);
	void (*sync)(struct device___231 *);
	void (*dismiss)(struct device___231 *);
};

struct bus_type___231 {
	const char *name;
	const char *dev_name;
	struct device___231 *dev_root;
	const struct attribute_group___233 **bus_groups;
	const struct attribute_group___233 **dev_groups;
	const struct attribute_group___233 **drv_groups;
	int (*match)(struct device___231 *, struct device_driver___231 *);
	int (*uevent)(struct device___231 *, struct kobj_uevent_env *);
	int (*probe)(struct device___231 *);
	int (*remove)(struct device___231 *);
	void (*shutdown)(struct device___231 *);
	int (*online)(struct device___231 *);
	int (*offline)(struct device___231 *);
	int (*suspend)(struct device___231 *, pm_message_t);
	int (*resume)(struct device___231 *);
	int (*num_vf)(struct device___231 *);
	int (*dma_configure)(struct device___231 *);
	const struct dev_pm_ops___231 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___231 {
	const char *name;
	struct bus_type___231 *bus;
	struct module___217 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___231 *);
	int (*remove)(struct device___231 *);
	void (*shutdown)(struct device___231 *);
	int (*suspend)(struct device___231 *, pm_message_t);
	int (*resume)(struct device___231 *);
	const struct attribute_group___233 **groups;
	const struct dev_pm_ops___231 *pm;
	void (*coredump)(struct device___231 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct dma_map_ops___63 {
	void * (*alloc)(struct device___231 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___231 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___231 *, struct vm_area_struct___269 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___231 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___231 *, struct page___269 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___231 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___231 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___231 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___231 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___231 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___231 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide44;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___231 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___231 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___231 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___231 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___231 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___231 *, u64);
	u64 (*get_required_mask)(struct device___231 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___166;

struct fwnode_handle___166 {
	struct fwnode_handle___166 *secondary;
	const struct fwnode_operations___166 *ops;
};

struct dentry_operations___267;

struct super_block___267;

struct dentry___268 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___268 *d_parent;
	struct qstr d_name;
	struct inode___268 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___267 *d_op;
	struct super_block___267 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___267;

struct address_space___267 {
	struct inode___268 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___269 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___267 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___267;

struct block_device___267;

struct inode___268 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___267 *i_op;
	struct super_block___267 *i_sb;
	struct address_space___267 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___269 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___137 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___268 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___267 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___267 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___267 {
	int (*d_revalidate)(struct dentry___268 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___268 *, unsigned int);
	int (*d_hash)(const struct dentry___268 *, struct qstr *);
	int (*d_compare)(const struct dentry___268 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___268 *);
	int (*d_init)(struct dentry___268 *);
	void (*d_release)(struct dentry___268 *);
	void (*d_prune)(struct dentry___268 *);
	void (*d_iput)(struct dentry___268 *, struct inode___268 *);
	char * (*d_dname)(struct dentry___268 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___268 *);
	int (*d_manage)(const struct path___268 *, bool);
	struct dentry___268 * (*d_real)(struct dentry___268 *, const struct inode___268 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___267;

struct mem_dqinfo___267 {
	struct quota_format_type___267 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___267;

struct quota_info___267 {
	unsigned int flags;
	struct rw_semaphore___269 dqio_sem;
	struct inode___268 *files[3];
	struct mem_dqinfo___267 info[3];
	const struct quota_format_ops___267 *ops[3];
};

struct rcuwait___267 {
	struct task_struct___269 *task;
};

struct percpu_rw_semaphore___267 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___269 rw_sem;
	struct rcuwait___267 writer;
	int readers_block;
};

struct sb_writers___267 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___267 rw_sem[3];
};

struct file_system_type___267;

struct super_operations___267;

struct dquot_operations___267;

struct quotactl_ops___267;

struct super_block___267 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___267 *s_type;
	const struct super_operations___267 *s_op;
	const struct dquot_operations___267 *dq_op;
	const struct quotactl_ops___267 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___268 *s_root;
	struct rw_semaphore___269 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___267 *s_bdev;
	struct backing_dev_info___137 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___267 s_dquot;
	struct sb_writers___267 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___267 *s_d_op;
	int cleancache_poolid;
	struct shrinker___112 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

typedef int (*dev_page_fault_t___257)(struct vm_area_struct___269 *, long unsigned int, const struct page___269 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___257)(struct page___269 *, void *);

struct dev_pagemap___257 {
	dev_page_fault_t___257 page_fault;
	dev_page_free_t___257 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___231 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___268 {
	struct task_struct___269 *task;
	struct core_thread___268 *next;
};

struct core_state___268 {
	atomic_t nr_threads;
	struct core_thread___268 dumper;
	struct completion startup;
};

struct vm_fault___257 {
	struct vm_area_struct___269 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___269 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___269 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___268 prealloc_pte;
};

struct io_cq___72 {
	struct request_queue___68 *q;
	struct io_context___72 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___6 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___268 {
	struct file___268 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___268 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___267 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___268 *ia_file;
};

struct dquot___267 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___267 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___267 {
	int qf_fmt_id;
	const struct quota_format_ops___267 *qf_ops;
	struct module___217 *qf_owner;
	struct quota_format_type___267 *qf_next;
};

struct quota_format_ops___267 {
	int (*check_quota_file)(struct super_block___267 *, int);
	int (*read_file_info)(struct super_block___267 *, int);
	int (*write_file_info)(struct super_block___267 *, int);
	int (*free_file_info)(struct super_block___267 *, int);
	int (*read_dqblk)(struct dquot___267 *);
	int (*commit_dqblk)(struct dquot___267 *);
	int (*release_dqblk)(struct dquot___267 *);
	int (*get_next_id)(struct super_block___267 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___267 {
	int (*write_dquot)(struct dquot___267 *);
	struct dquot___267 * (*alloc_dquot)(struct super_block___267 *, int);
	void (*destroy_dquot)(struct dquot___267 *);
	int (*acquire_dquot)(struct dquot___267 *);
	int (*release_dquot)(struct dquot___267 *);
	int (*mark_dirty)(struct dquot___267 *);
	int (*write_info)(struct super_block___267 *, int);
	qsize_t * (*get_reserved_space)(struct inode___268 *);
	int (*get_projid)(struct inode___268 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___268 *, qsize_t *);
	int (*get_next_id)(struct super_block___267 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___267 {
	int (*quota_on)(struct super_block___267 *, int, int, const struct path___268 *);
	int (*quota_off)(struct super_block___267 *, int);
	int (*quota_enable)(struct super_block___267 *, unsigned int);
	int (*quota_disable)(struct super_block___267 *, unsigned int);
	int (*quota_sync)(struct super_block___267 *, int);
	int (*set_info)(struct super_block___267 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___267 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___267 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___267 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___267 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___267 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___267 {
	int (*writepage)(struct page___269 *, struct writeback_control___3 *);
	int (*readpage)(struct file___268 *, struct page___269 *);
	int (*writepages)(struct address_space___267 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___269 *);
	int (*readpages)(struct file___268 *, struct address_space___267 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___268 *, struct address_space___267 *, loff_t, unsigned int, unsigned int, struct page___269 **, void **);
	int (*write_end)(struct file___268 *, struct address_space___267 *, loff_t, unsigned int, unsigned int, struct page___269 *, void *);
	sector_t (*bmap)(struct address_space___267 *, sector_t);
	void (*invalidatepage)(struct page___269 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___269 *, gfp_t);
	void (*freepage)(struct page___269 *);
	ssize_t (*direct_IO)(struct kiocb___268 *, struct iov_iter___131 *);
	int (*migratepage)(struct address_space___267 *, struct page___269 *, struct page___269 *, enum migrate_mode);
	bool (*isolate_page)(struct page___269 *, isolate_mode_t);
	void (*putback_page)(struct page___269 *);
	int (*launder_page)(struct page___269 *);
	int (*is_partially_uptodate)(struct page___269 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___269 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___267 *, struct page___269 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___268 *, sector_t *);
	void (*swap_deactivate)(struct file___268 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct iov_iter___131 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___137 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___267 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___268 *bd_inode;
	struct super_block___267 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___267 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___69 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___69 *bd_disk;
	struct request_queue___68 *bd_queue;
	struct backing_dev_info___137 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___267 {
	struct dentry___268 * (*lookup)(struct inode___268 *, struct dentry___268 *, unsigned int);
	const char * (*get_link)(struct dentry___268 *, struct inode___268 *, struct delayed_call *);
	int (*permission)(struct inode___268 *, int);
	struct posix_acl * (*get_acl)(struct inode___268 *, int);
	int (*readlink)(struct dentry___268 *, char *, int);
	int (*create)(struct inode___268 *, struct dentry___268 *, umode_t, bool);
	int (*link)(struct dentry___268 *, struct inode___268 *, struct dentry___268 *);
	int (*unlink)(struct inode___268 *, struct dentry___268 *);
	int (*symlink)(struct inode___268 *, struct dentry___268 *, const char *);
	int (*mkdir)(struct inode___268 *, struct dentry___268 *, umode_t);
	int (*rmdir)(struct inode___268 *, struct dentry___268 *);
	int (*mknod)(struct inode___268 *, struct dentry___268 *, umode_t, dev_t);
	int (*rename)(struct inode___268 *, struct dentry___268 *, struct inode___268 *, struct dentry___268 *, unsigned int);
	int (*setattr)(struct dentry___268 *, struct iattr___267 *);
	int (*getattr)(const struct path___268 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___268 *, char *, size_t);
	int (*fiemap)(struct inode___268 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___268 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___268 *, struct dentry___268 *, struct file___268 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___268 *, struct dentry___268 *, umode_t);
	int (*set_acl)(struct inode___268 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___267 {
	void (*fl_copy_lock)(struct file_lock___268 *, struct file_lock___268 *);
	void (*fl_release_private)(struct file_lock___268 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___267;

struct lock_manager_operations___267;

struct file_lock___268 {
	struct file_lock___268 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___268 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___267 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___267 *fl_ops;
	const struct lock_manager_operations___267 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___267 {
	int (*lm_compare_owner)(struct file_lock___268 *, struct file_lock___268 *);
	long unsigned int (*lm_owner_key)(struct file_lock___268 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___268 *);
	int (*lm_grant)(struct file_lock___268 *, int);
	bool (*lm_break)(struct file_lock___268 *);
	int (*lm_change)(struct file_lock___268 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___268 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___267 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___267 *fa_next;
	struct file___268 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___267 {
	const char *name;
	int fs_flags;
	struct dentry___268 * (*mount)(struct file_system_type___267 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___267 *);
	struct module___217 *owner;
	struct file_system_type___267 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___267 {
	struct inode___268 * (*alloc_inode)(struct super_block___267 *);
	void (*destroy_inode)(struct inode___268 *);
	void (*dirty_inode)(struct inode___268 *, int);
	int (*write_inode)(struct inode___268 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___268 *);
	void (*evict_inode)(struct inode___268 *);
	void (*put_super)(struct super_block___267 *);
	int (*sync_fs)(struct super_block___267 *, int);
	int (*freeze_super)(struct super_block___267 *);
	int (*freeze_fs)(struct super_block___267 *);
	int (*thaw_super)(struct super_block___267 *);
	int (*unfreeze_fs)(struct super_block___267 *);
	int (*statfs)(struct dentry___268 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___267 *, int *, char *);
	void (*umount_begin)(struct super_block___267 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___268 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___268 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___268 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___268 *);
	ssize_t (*quota_read)(struct super_block___267 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___267 *, int, const char *, size_t, loff_t);
	struct dquot___267 ** (*get_dquots)(struct inode___268 *);
	int (*bdev_try_to_free_page)(struct super_block___267 *, struct page___269 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___267 *, struct shrink_control___112 *);
	long int (*free_cached_objects)(struct super_block___267 *, struct shrink_control___112 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___69 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___69 *last_lookup;
	struct hd_struct___69 *part[0];
};

struct block_device_operations___69 {
	int (*open)(struct block_device___267 *, fmode_t);
	void (*release)(struct gendisk___69 *, fmode_t);
	int (*rw_page)(struct block_device___267 *, sector_t, struct page___269 *, unsigned int);
	int (*ioctl)(struct block_device___267 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___267 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___69 *, unsigned int);
	int (*media_changed)(struct gendisk___69 *);
	void (*unlock_native_capacity)(struct gendisk___69 *);
	int (*revalidate_disk)(struct gendisk___69 *);
	int (*getgeo)(struct block_device___267 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___267 *, long unsigned int);
	int (*report_zones)(struct gendisk___69 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___217 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___257(struct page___269 *);

struct bdi_writeback_congested___137 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___137 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bsg_ops___68 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___68 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___68 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___68 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___68(struct request___68 *, blk_status_t);

struct request___68 {
	struct request_queue___68 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___10 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___137 *bio;
	struct bio___137 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___137 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___72 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___68 *saved_end_io;
		} flush;
	};
	struct gendisk___69 *rq_disk;
	struct hd_struct___69 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___68 *end_io;
	void *end_io_data;
	struct request___68 *next_rq;
};

struct fwnode_reference_args___166;

struct fwnode_endpoint___166;

struct fwnode_operations___166 {
	struct fwnode_handle___166 * (*get)(struct fwnode_handle___166 *);
	void (*put)(struct fwnode_handle___166 *);
	bool (*device_is_available)(const struct fwnode_handle___166 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___166 *, const struct device___231 *);
	bool (*property_present)(const struct fwnode_handle___166 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___166 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___166 *, const char *, const char **, size_t);
	struct fwnode_handle___166 * (*get_parent)(const struct fwnode_handle___166 *);
	struct fwnode_handle___166 * (*get_next_child_node)(const struct fwnode_handle___166 *, struct fwnode_handle___166 *);
	struct fwnode_handle___166 * (*get_named_child_node)(const struct fwnode_handle___166 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___166 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___166 *);
	struct fwnode_handle___166 * (*graph_get_next_endpoint)(const struct fwnode_handle___166 *, struct fwnode_handle___166 *);
	struct fwnode_handle___166 * (*graph_get_remote_endpoint)(const struct fwnode_handle___166 *);
	struct fwnode_handle___166 * (*graph_get_port_parent)(struct fwnode_handle___166 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___166 *, struct fwnode_endpoint___166 *);
};

struct fwnode_endpoint___166 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___166 *local_fwnode;
};

struct fwnode_reference_args___166 {
	struct fwnode_handle___166 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct blk_mq_hw_ctx___10 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___68 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags___4 *tags;
	struct blk_mq_tags___4 *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	unsigned int rh_reserved_nr_expired;
	struct hlist_node cpuhp_dead;
	struct kobject___256 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___268 *debugfs_dir;
	struct dentry___268 *sched_debugfs_dir;
	struct list_head hctx_list;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___68;

struct elevator_mq_ops___68 {
	int (*init_sched)(struct request_queue___68 *, struct elevator_type___68 *);
	void (*exit_sched)(struct elevator_queue___68 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___10 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___10 *, unsigned int);
	bool (*allow_merge)(struct request_queue___68 *, struct request___68 *, struct bio___137 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx___10 *, struct bio___137 *);
	int (*request_merge)(struct request_queue___68 *, struct request___68 **, struct bio___137 *);
	void (*request_merged)(struct request_queue___68 *, struct request___68 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___68 *, struct request___68 *, struct request___68 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___68 *, struct bio___137 *);
	void (*finish_request)(struct request___68 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___10 *, struct list_head *, bool);
	struct request___68 * (*dispatch_request)(struct blk_mq_hw_ctx___10 *);
	bool (*has_work)(struct blk_mq_hw_ctx___10 *);
	void (*completed_request)(struct request___68 *, u64);
	void (*started_request)(struct request___68 *);
	void (*requeue_request)(struct request___68 *);
	struct request___68 * (*former_request)(struct request_queue___68 *, struct request___68 *);
	struct request___68 * (*next_request)(struct request_queue___68 *, struct request___68 *);
	void (*init_icq)(struct io_cq___72 *);
	void (*exit_icq)(struct io_cq___72 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx___10 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___68;

struct elevator_type___68 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___68 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___68 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___217 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___68 {
	struct elevator_type___68 *type;
	void *elevator_data;
	struct kobject___256 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___68 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___68 *, char *);
	ssize_t (*store)(struct elevator_queue___68 *, const char *, size_t);
};

struct blk_mq_queue_data___10;

typedef blk_status_t queue_rq_fn___10(struct blk_mq_hw_ctx___10 *, const struct blk_mq_queue_data___10 *);

typedef void commit_rqs_fn___10(struct blk_mq_hw_ctx___10 *);

typedef bool get_budget_fn___10(struct blk_mq_hw_ctx___10 *);

typedef void put_budget_fn___10(struct blk_mq_hw_ctx___10 *);

typedef enum blk_eh_timer_return timeout_fn___10(struct request___68 *, bool);

typedef int poll_fn___10(struct blk_mq_hw_ctx___10 *);

typedef void complete_fn___10(struct request___68 *);

typedef int init_hctx_fn___10(struct blk_mq_hw_ctx___10 *, void *, unsigned int);

typedef void exit_hctx_fn___10(struct blk_mq_hw_ctx___10 *, unsigned int);

typedef int init_request_fn___10(struct blk_mq_tag_set___10 *, struct request___68 *, unsigned int, unsigned int);

typedef void exit_request_fn___10(struct blk_mq_tag_set___10 *, struct request___68 *, unsigned int);

typedef bool busy_fn___10(struct request_queue___68 *);

typedef int map_queues_fn___10(struct blk_mq_tag_set___10 *);

typedef void cleanup_rq_fn___10(struct request___68 *);

struct blk_mq_ops___10 {
	queue_rq_fn___10 *queue_rq;
	commit_rqs_fn___10 *commit_rqs;
	get_budget_fn___10 *get_budget;
	put_budget_fn___10 *put_budget;
	timeout_fn___10 *timeout;
	poll_fn___10 *poll;
	complete_fn___10 *complete;
	init_hctx_fn___10 *init_hctx;
	exit_hctx_fn___10 *exit_hctx;
	init_request_fn___10 *init_request;
	exit_request_fn___10 *exit_request;
	void (*initialize_rq_fn)(struct request___68 *);
	busy_fn___10 *busy;
	map_queues_fn___10 *map_queues;
	void (*show_rq)(struct seq_file___9 *, struct request___68 *);
	union {
		cleanup_rq_fn___10 *cleanup_rq;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide49;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct blk_mq_tag_set___10 {
	struct blk_mq_queue_map map[6];
	unsigned int nr_maps;
	const struct blk_mq_ops___10 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	struct blk_mq_tags___4 **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct request_sense;

struct cdrom_generic_command {
	unsigned char cmd[12];
	unsigned char *buffer;
	unsigned int buflen;
	int stat;
	struct request_sense *sense;
	unsigned char data_direction;
	int quiet;
	int timeout;
	void *reserved[1];
};

struct request_sense {
	__u8 error_code: 7;
	__u8 valid: 1;
	__u8 segment_number;
	__u8 sense_key: 4;
	__u8 reserved2: 1;
	__u8 ili: 1;
	__u8 reserved1: 2;
	__u8 information[4];
	__u8 add_sense_len;
	__u8 command_info[4];
	__u8 asc;
	__u8 ascq;
	__u8 fruc;
	__u8 sks[3];
	__u8 asb[46];
};

struct scsi_ioctl_command {
	unsigned int inlen;
	unsigned int outlen;
	unsigned char data[0];
};

enum scsi_device_event {
	SDEV_EVT_MEDIA_CHANGE = 1,
	SDEV_EVT_INQUIRY_CHANGE_REPORTED = 2,
	SDEV_EVT_CAPACITY_CHANGE_REPORTED = 3,
	SDEV_EVT_SOFT_THRESHOLD_REACHED_REPORTED = 4,
	SDEV_EVT_MODE_PARAMETER_CHANGE_REPORTED = 5,
	SDEV_EVT_LUN_CHANGE_REPORTED = 6,
	SDEV_EVT_ALUA_STATE_CHANGE_REPORTED = 7,
	SDEV_EVT_POWER_ON_RESET_OCCURRED = 8,
	SDEV_EVT_FIRST = 1,
	SDEV_EVT_LAST = 8,
	SDEV_EVT_MAXBITS = 9,
};

struct blk_mq_queue_data___10 {
	struct request___68 *rq;
	bool last;
	long unsigned int rh_reserved1;
};

struct scsi_request {
	unsigned char __cmd[16];
	unsigned char *cmd;
	short unsigned int cmd_len;
	int result;
	unsigned int sense_len;
	unsigned int resid_len;
	int retries;
	void *sense;
};

struct blk_cmd_filter {
	long unsigned int read_ok[4];
	long unsigned int write_ok[4];
};

struct sg_io_hdr {
	int interface_id;
	int dxfer_direction;
	unsigned char cmd_len;
	unsigned char mx_sb_len;
	short unsigned int iovec_count;
	unsigned int dxfer_len;
	void *dxferp;
	unsigned char *cmdp;
	void *sbp;
	unsigned int timeout;
	unsigned int flags;
	int pack_id;
	void *usr_ptr;
	unsigned char status;
	unsigned char masked_status;
	unsigned char msg_status;
	unsigned char sb_len_wr;
	short unsigned int host_status;
	short unsigned int driver_status;
	int resid;
	unsigned int duration;
	unsigned int info;
};

enum {
	OMAX_SB_LEN = 16,
};

struct module___218;

struct file___269;

struct kiocb___269;

struct vm_area_struct___270;

struct inode___269;

struct file_lock___269;

struct page___270;

struct file_operations___269 {
	struct module___218 *owner;
	loff_t (*llseek)(struct file___269 *, loff_t, int);
	ssize_t (*read)(struct file___269 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___269 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___269 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___269 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___269 *, bool);
	int (*iterate)(struct file___269 *, struct dir_context *);
	int (*iterate_shared)(struct file___269 *, struct dir_context *);
	__poll_t (*poll)(struct file___269 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___269 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___269 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___269 *, struct vm_area_struct___270 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___269 *, struct file___269 *);
	int (*flush)(struct file___269 *, fl_owner_t);
	int (*release)(struct inode___269 *, struct file___269 *);
	int (*fsync)(struct file___269 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___269 *, int);
	int (*lock)(struct file___269 *, int, struct file_lock___269 *);
	ssize_t (*sendpage)(struct file___269 *, struct page___270 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___269 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___269 *, int, struct file_lock___269 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___269 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___269 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___269 *, long int, struct file_lock___269 **, void **);
	long int (*fallocate)(struct file___269 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___269 *);
	ssize_t (*copy_file_range)(struct file___269 *, loff_t, struct file___269 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___269 *, loff_t, struct file___269 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___269 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___269 {
	u64 seqnum;
	struct vm_area_struct___270 *vmas[4];
};

struct page_frag___269 {
	struct page___270 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___269;

struct bio_list___138;

struct backing_dev_info___138;

struct io_context___73;

struct request_queue___69;

struct vm_struct___185;

struct task_struct___270 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___270 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___269 *mm;
	struct mm_struct___269 *active_mm;
	struct vmacache___269 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___270 *real_parent;
	struct task_struct___270 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___270 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___190 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___190 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___190 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___2 *ptracer_cred;
	const struct cred___2 *real_cred;
	const struct cred___2 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___270 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___138 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___138 *backing_dev_info;
	struct io_context___73 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___269 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___69 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___270 *oom_reaper_list;
	struct vm_struct___185 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___128 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___270 *pgtable_t___269;

struct address_space___268;

struct dev_pagemap___258;

struct page___270 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___268 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___270 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___269 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___269 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___258 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___269;

struct lruvec___269 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___269 *pgdat;
};

struct zone___269 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___269 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___269 {
	struct zone___269 *zone;
	int zone_idx;
};

struct zonelist___269 {
	struct zoneref___269 _zonerefs[25];
};

struct pglist_data___269 {
	struct zone___269 node_zones[3];
	struct zonelist___269 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___270 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___270 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___269 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___270 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___270 *owner;
};

struct secondary_data___270 {
	void *stack;
	struct task_struct___270 *task;
	long int status;
};

struct blocking_notifier_head___269 {
	struct rw_semaphore___270 rwsem;
	struct notifier_block *head;
};

struct dentry___269;

struct path___269 {
	struct vfsmount *mnt;
	struct dentry___269 *dentry;
};

struct file___269 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___269 f_path;
	struct inode___269 *f_inode;
	const struct file_operations___269 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___190 f_owner;
	const struct cred___2 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___268 *f_mapping;
	errseq_t f_wb_err;
};

struct kernfs_root___263;

struct kernfs_elem_dir___263 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___263 *root;
};

struct kernfs_node___264;

struct kernfs_syscall_ops___263;

struct kernfs_root___263 {
	struct kernfs_node___264 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___263 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___263 {
	struct kernfs_node___264 *target_kn;
};

struct kernfs_ops___263;

struct kernfs_elem_attr___263 {
	const struct kernfs_ops___263 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___264 *notify_next;
};

struct kernfs_node___264 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___264 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___263 dir;
		struct kernfs_elem_symlink___263 symlink;
		struct kernfs_elem_attr___263 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___263;

struct kernfs_ops___263 {
	int (*open)(struct kernfs_open_file___263 *);
	void (*release)(struct kernfs_open_file___263 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___263 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___263 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___263 *, struct vm_area_struct___270 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___263 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___263 {
	int (*remount_fs)(struct kernfs_root___263 *, int *, char *);
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___263 *);
	int (*mkdir)(struct kernfs_node___264 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___264 *);
	int (*rename)(struct kernfs_node___264 *, struct kernfs_node___264 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___264 *, struct kernfs_root___263 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_operations_struct___258;

struct kernfs_open_file___263 {
	struct kernfs_node___264 *kn;
	struct file___269 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___258 *vm_ops;
};

struct vm_fault___258;

struct vm_operations_struct___258 {
	void (*open)(struct vm_area_struct___270 *);
	void (*close)(struct vm_area_struct___270 *);
	int (*split)(struct vm_area_struct___270 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___270 *);
	vm_fault_t (*fault)(struct vm_fault___258 *);
	vm_fault_t (*huge_fault)(struct vm_fault___258 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___258 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___270 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___258 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___258 *);
	int (*access)(struct vm_area_struct___270 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___270 *);
	int (*set_policy)(struct vm_area_struct___270 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___270 *, long unsigned int);
	struct page___270 * (*find_special_page)(struct vm_area_struct___270 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_area_struct___270 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___270 *vm_next;
	struct vm_area_struct___270 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___269 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___258 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___269 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___257;

struct bin_attribute___233;

struct attribute_group___234 {
	const char *name;
	umode_t (*is_visible)(struct kobject___257 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___257 *, struct bin_attribute___233 *, int);
	struct attribute **attrs;
	struct bin_attribute___233 **bin_attrs;
};

struct kset___256;

struct kobj_type___256;

struct kobject___257 {
	const char *name;
	struct list_head entry;
	struct kobject___257 *parent;
	struct kset___256 *kset;
	struct kobj_type___256 *ktype;
	struct kernfs_node___264 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___233 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___269 *, struct kobject___257 *, struct bin_attribute___233 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___269 *, struct kobject___257 *, struct bin_attribute___233 *, char *, loff_t, size_t);
	int (*mmap)(struct file___269 *, struct kobject___257 *, struct bin_attribute___233 *, struct vm_area_struct___270 *);
};

struct sysfs_ops___256 {
	ssize_t (*show)(struct kobject___257 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___257 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___256;

struct kset___256 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___257 kobj;
	const struct kset_uevent_ops___256 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___256 {
	void (*release)(struct kobject___257 *);
	const struct sysfs_ops___256 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___24 * (*child_ns_type)(struct kobject___257 *);
	const void * (*namespace)(struct kobject___257 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___256 {
	int (* const filter)(struct kset___256 *, struct kobject___257 *);
	const char * (* const name)(struct kset___256 *, struct kobject___257 *);
	int (* const uevent)(struct kset___256 *, struct kobject___257 *, struct kobj_uevent_env *);
};

struct kobj_attribute___249 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___257 *, struct kobj_attribute___249 *, char *);
	ssize_t (*store)(struct kobject___257 *, struct kobj_attribute___249 *, const char *, size_t);
};

struct kernel_param___215;

struct kernel_param_ops___215 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___215 *);
	int (*get)(char *, const struct kernel_param___215 *);
	void (*free)(void *);
};

struct kparam_array___215;

struct kernel_param___215 {
	const char *name;
	struct module___218 *mod;
	const struct kernel_param_ops___215 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___215 *arr;
	};
};

struct kparam_array___215 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___215 *ops;
	void *elem;
};

struct module_kobject___215 {
	struct kobject___257 kobj;
	struct module___218 *mod;
	struct kobject___257 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___215 {
	struct module___218 *mod;
	struct latch_tree_node node;
};

struct module_layout___215 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___215 mtn;
};

struct module_attribute___215;

struct module___218 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___215 mkobj;
	struct module_attribute___215 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___257 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___215 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___215 core_layout;
	struct module_layout___215 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___215 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___215 *, struct module_kobject___215 *, char *);
	ssize_t (*store)(struct module_attribute___215 *, struct module_kobject___215 *, const char *, size_t);
	void (*setup)(struct module___218 *, const char *);
	int (*test)(struct module___218 *);
	void (*free)(struct module___218 *);
};

struct core_state___269;

struct mm_struct___269 {
	struct {
		struct vm_area_struct___270 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___269 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___270 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___269 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___270 *owner;
		struct user_namespace___3 *user_ns;
		struct file___269 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___269 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct bio___138;

struct bio_list___138 {
	struct bio___138 *head;
	struct bio___138 *tail;
};

struct bdi_writeback_congested___138;

struct bdi_writeback___138 {
	struct backing_dev_info___138 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___138 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___157 *memcg_css;
	struct cgroup_subsys_state___157 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___232;

struct backing_dev_info___138 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___138 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___232 *dev;
	struct device___232 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___269 *debug_dir;
	struct dentry___269 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___73;

struct io_context___73 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___73 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

typedef blk_qc_t make_request_fn___69(struct request_queue___69 *, struct bio___138 *);

struct request___69;

typedef int dma_drain_needed_fn___69(struct request___69 *);

struct bsg_ops___69;

struct bsg_class_device___69 {
	struct device___232 *class_dev;
	int minor;
	struct request_queue___69 *queue;
	const struct bsg_ops___69 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___138 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___138 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___69;

struct blk_mq_ops___11;

struct blk_mq_hw_ctx___11;

struct blk_mq_tag_set___11;

struct request_queue___69 {
	struct list_head queue_head;
	struct request___69 *last_merge;
	struct elevator_queue___69 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___69 *make_request_fn;
	dma_drain_needed_fn___69 *dma_drain_needed;
	const struct blk_mq_ops___11 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___11 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___138 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___257 kobj;
	struct kobject___257 *mq_kobj;
	struct blk_integrity integrity;
	struct device___232 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	struct bsg_class_device___69 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set___11 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___138 bio_split;
	struct dentry___269 *debugfs_dir;
	struct dentry___269 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___185 {
	struct vm_struct___185 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___270 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bio_vec___138 {
	struct page___270 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

typedef void bio_end_io_t___138(struct bio___138 *);

struct gendisk___70;

struct bio_integrity_payload___138;

struct bio___138 {
	struct bio___138 *bi_next;
	struct gendisk___70 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___138 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___138 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___138 *bi_io_vec;
	struct bio_set___138 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___138 bi_inline_vecs[0];
};

struct bio_integrity_payload___138 {
	struct bio___138 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___138 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___138 bip_inline_vecs[0];
};

struct dev_pm_info___232 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___232 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___232;

struct bus_type___232;

struct device_driver___232;

struct dev_pm_domain___232;

struct dma_map_ops___64;

struct fwnode_handle___167;

struct class___232;

struct device___232 {
	struct device___232 *parent;
	struct device_private *p;
	struct kobject___257 kobj;
	const char *init_name;
	const struct device_type___232 *type;
	struct mutex mutex;
	struct bus_type___232 *bus;
	struct device_driver___232 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___232 power;
	struct dev_pm_domain___232 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___64 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___167 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___232 *class;
	const struct attribute_group___234 **groups;
	void (*release)(struct device___232 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___70 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___232 __dev;
	struct kobject___257 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___70;

struct block_device_operations___70;

struct gendisk___70 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___70 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___70 *part_tbl;
	struct hd_struct___70 part0;
	const struct block_device_operations___70 *fops;
	struct request_queue___69 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___270 lookup_sem;
	struct kobject___257 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___257 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_ops___232;

struct device_type___232 {
	const char *name;
	const struct attribute_group___234 **groups;
	int (*uevent)(struct device___232 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___232 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___232 *);
	const struct dev_pm_ops___232 *pm;
};

struct class___232 {
	const char *name;
	struct module___218 *owner;
	const struct attribute_group___234 **class_groups;
	const struct attribute_group___234 **dev_groups;
	struct kobject___257 *dev_kobj;
	int (*dev_uevent)(struct device___232 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___232 *, umode_t *);
	void (*class_release)(struct class___232 *);
	void (*dev_release)(struct device___232 *);
	int (*shutdown_pre)(struct device___232 *);
	const struct kobj_ns_type_operations___24 *ns_type;
	const void * (*namespace)(struct device___232 *);
	const struct dev_pm_ops___232 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dev_pm_ops___232 {
	int (*prepare)(struct device___232 *);
	void (*complete)(struct device___232 *);
	int (*suspend)(struct device___232 *);
	int (*resume)(struct device___232 *);
	int (*freeze)(struct device___232 *);
	int (*thaw)(struct device___232 *);
	int (*poweroff)(struct device___232 *);
	int (*restore)(struct device___232 *);
	int (*suspend_late)(struct device___232 *);
	int (*resume_early)(struct device___232 *);
	int (*freeze_late)(struct device___232 *);
	int (*thaw_early)(struct device___232 *);
	int (*poweroff_late)(struct device___232 *);
	int (*restore_early)(struct device___232 *);
	int (*suspend_noirq)(struct device___232 *);
	int (*resume_noirq)(struct device___232 *);
	int (*freeze_noirq)(struct device___232 *);
	int (*thaw_noirq)(struct device___232 *);
	int (*poweroff_noirq)(struct device___232 *);
	int (*restore_noirq)(struct device___232 *);
	int (*runtime_suspend)(struct device___232 *);
	int (*runtime_resume)(struct device___232 *);
	int (*runtime_idle)(struct device___232 *);
};

struct dev_pm_domain___232 {
	struct dev_pm_ops___232 ops;
	void (*detach)(struct device___232 *, bool);
	int (*activate)(struct device___232 *);
	void (*sync)(struct device___232 *);
	void (*dismiss)(struct device___232 *);
};

struct bus_type___232 {
	const char *name;
	const char *dev_name;
	struct device___232 *dev_root;
	const struct attribute_group___234 **bus_groups;
	const struct attribute_group___234 **dev_groups;
	const struct attribute_group___234 **drv_groups;
	int (*match)(struct device___232 *, struct device_driver___232 *);
	int (*uevent)(struct device___232 *, struct kobj_uevent_env *);
	int (*probe)(struct device___232 *);
	int (*remove)(struct device___232 *);
	void (*shutdown)(struct device___232 *);
	int (*online)(struct device___232 *);
	int (*offline)(struct device___232 *);
	int (*suspend)(struct device___232 *, pm_message_t);
	int (*resume)(struct device___232 *);
	int (*num_vf)(struct device___232 *);
	int (*dma_configure)(struct device___232 *);
	const struct dev_pm_ops___232 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___232 {
	const char *name;
	struct bus_type___232 *bus;
	struct module___218 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___232 *);
	int (*remove)(struct device___232 *);
	void (*shutdown)(struct device___232 *);
	int (*suspend)(struct device___232 *, pm_message_t);
	int (*resume)(struct device___232 *);
	const struct attribute_group___234 **groups;
	const struct dev_pm_ops___232 *pm;
	void (*coredump)(struct device___232 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct dma_map_ops___64 {
	void * (*alloc)(struct device___232 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___232 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___232 *, struct vm_area_struct___270 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___232 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___232 *, struct page___270 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___232 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___232 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___232 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___232 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___232 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___232 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide42;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___232 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___232 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___232 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___232 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___232 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___232 *, u64);
	u64 (*get_required_mask)(struct device___232 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___167;

struct fwnode_handle___167 {
	struct fwnode_handle___167 *secondary;
	const struct fwnode_operations___167 *ops;
};

struct dentry_operations___268;

struct super_block___268;

struct dentry___269 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___269 *d_parent;
	struct qstr d_name;
	struct inode___269 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___268 *d_op;
	struct super_block___268 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___268;

struct address_space___268 {
	struct inode___269 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___270 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___268 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___268;

struct block_device___268;

struct cdev___42;

struct inode___269 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___268 *i_op;
	struct super_block___268 *i_sb;
	struct address_space___268 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___270 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___138 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___269 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___268 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___268 *i_bdev;
		struct cdev___42 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___268 {
	int (*d_revalidate)(struct dentry___269 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___269 *, unsigned int);
	int (*d_hash)(const struct dentry___269 *, struct qstr *);
	int (*d_compare)(const struct dentry___269 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___269 *);
	int (*d_init)(struct dentry___269 *);
	void (*d_release)(struct dentry___269 *);
	void (*d_prune)(struct dentry___269 *);
	void (*d_iput)(struct dentry___269 *, struct inode___269 *);
	char * (*d_dname)(struct dentry___269 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___269 *);
	int (*d_manage)(const struct path___269 *, bool);
	struct dentry___269 * (*d_real)(struct dentry___269 *, const struct inode___269 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___268;

struct mem_dqinfo___268 {
	struct quota_format_type___268 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___268;

struct quota_info___268 {
	unsigned int flags;
	struct rw_semaphore___270 dqio_sem;
	struct inode___269 *files[3];
	struct mem_dqinfo___268 info[3];
	const struct quota_format_ops___268 *ops[3];
};

struct rcuwait___268 {
	struct task_struct___270 *task;
};

struct percpu_rw_semaphore___268 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___270 rw_sem;
	struct rcuwait___268 writer;
	int readers_block;
};

struct sb_writers___268 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___268 rw_sem[3];
};

struct file_system_type___268;

struct super_operations___268;

struct dquot_operations___268;

struct quotactl_ops___268;

struct super_block___268 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___268 *s_type;
	const struct super_operations___268 *s_op;
	const struct dquot_operations___268 *dq_op;
	const struct quotactl_ops___268 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___269 *s_root;
	struct rw_semaphore___270 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___268 *s_bdev;
	struct backing_dev_info___138 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___268 s_dquot;
	struct sb_writers___268 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___268 *s_d_op;
	int cleancache_poolid;
	struct shrinker___112 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

typedef int (*dev_page_fault_t___258)(struct vm_area_struct___270 *, long unsigned int, const struct page___270 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___258)(struct page___270 *, void *);

struct dev_pagemap___258 {
	dev_page_fault_t___258 page_fault;
	dev_page_free_t___258 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___232 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___269 {
	struct task_struct___270 *task;
	struct core_thread___269 *next;
};

struct core_state___269 {
	atomic_t nr_threads;
	struct core_thread___269 dumper;
	struct completion startup;
};

struct vm_fault___258 {
	struct vm_area_struct___270 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___270 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___270 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___269 prealloc_pte;
};

struct io_cq___73 {
	struct request_queue___69 *q;
	struct io_context___73 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___6 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___269 {
	struct file___269 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___269 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___268 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___269 *ia_file;
};

struct dquot___268 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___268 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___268 {
	int qf_fmt_id;
	const struct quota_format_ops___268 *qf_ops;
	struct module___218 *qf_owner;
	struct quota_format_type___268 *qf_next;
};

struct quota_format_ops___268 {
	int (*check_quota_file)(struct super_block___268 *, int);
	int (*read_file_info)(struct super_block___268 *, int);
	int (*write_file_info)(struct super_block___268 *, int);
	int (*free_file_info)(struct super_block___268 *, int);
	int (*read_dqblk)(struct dquot___268 *);
	int (*commit_dqblk)(struct dquot___268 *);
	int (*release_dqblk)(struct dquot___268 *);
	int (*get_next_id)(struct super_block___268 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___268 {
	int (*write_dquot)(struct dquot___268 *);
	struct dquot___268 * (*alloc_dquot)(struct super_block___268 *, int);
	void (*destroy_dquot)(struct dquot___268 *);
	int (*acquire_dquot)(struct dquot___268 *);
	int (*release_dquot)(struct dquot___268 *);
	int (*mark_dirty)(struct dquot___268 *);
	int (*write_info)(struct super_block___268 *, int);
	qsize_t * (*get_reserved_space)(struct inode___269 *);
	int (*get_projid)(struct inode___269 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___269 *, qsize_t *);
	int (*get_next_id)(struct super_block___268 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___268 {
	int (*quota_on)(struct super_block___268 *, int, int, const struct path___269 *);
	int (*quota_off)(struct super_block___268 *, int);
	int (*quota_enable)(struct super_block___268 *, unsigned int);
	int (*quota_disable)(struct super_block___268 *, unsigned int);
	int (*quota_sync)(struct super_block___268 *, int);
	int (*set_info)(struct super_block___268 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___268 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___268 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___268 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___268 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___268 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___268 {
	int (*writepage)(struct page___270 *, struct writeback_control___3 *);
	int (*readpage)(struct file___269 *, struct page___270 *);
	int (*writepages)(struct address_space___268 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___270 *);
	int (*readpages)(struct file___269 *, struct address_space___268 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___269 *, struct address_space___268 *, loff_t, unsigned int, unsigned int, struct page___270 **, void **);
	int (*write_end)(struct file___269 *, struct address_space___268 *, loff_t, unsigned int, unsigned int, struct page___270 *, void *);
	sector_t (*bmap)(struct address_space___268 *, sector_t);
	void (*invalidatepage)(struct page___270 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___270 *, gfp_t);
	void (*freepage)(struct page___270 *);
	ssize_t (*direct_IO)(struct kiocb___269 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___268 *, struct page___270 *, struct page___270 *, enum migrate_mode);
	bool (*isolate_page)(struct page___270 *, isolate_mode_t);
	void (*putback_page)(struct page___270 *);
	int (*launder_page)(struct page___270 *);
	int (*is_partially_uptodate)(struct page___270 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___270 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___268 *, struct page___270 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___269 *, sector_t *);
	void (*swap_deactivate)(struct file___269 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___268 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___269 *bd_inode;
	struct super_block___268 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___268 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___70 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___70 *bd_disk;
	struct request_queue___69 *bd_queue;
	struct backing_dev_info___138 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___42 {
	struct kobject___257 kobj;
	struct module___218 *owner;
	const struct file_operations___269 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___268 {
	struct dentry___269 * (*lookup)(struct inode___269 *, struct dentry___269 *, unsigned int);
	const char * (*get_link)(struct dentry___269 *, struct inode___269 *, struct delayed_call *);
	int (*permission)(struct inode___269 *, int);
	struct posix_acl * (*get_acl)(struct inode___269 *, int);
	int (*readlink)(struct dentry___269 *, char *, int);
	int (*create)(struct inode___269 *, struct dentry___269 *, umode_t, bool);
	int (*link)(struct dentry___269 *, struct inode___269 *, struct dentry___269 *);
	int (*unlink)(struct inode___269 *, struct dentry___269 *);
	int (*symlink)(struct inode___269 *, struct dentry___269 *, const char *);
	int (*mkdir)(struct inode___269 *, struct dentry___269 *, umode_t);
	int (*rmdir)(struct inode___269 *, struct dentry___269 *);
	int (*mknod)(struct inode___269 *, struct dentry___269 *, umode_t, dev_t);
	int (*rename)(struct inode___269 *, struct dentry___269 *, struct inode___269 *, struct dentry___269 *, unsigned int);
	int (*setattr)(struct dentry___269 *, struct iattr___268 *);
	int (*getattr)(const struct path___269 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___269 *, char *, size_t);
	int (*fiemap)(struct inode___269 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___269 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___269 *, struct dentry___269 *, struct file___269 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___269 *, struct dentry___269 *, umode_t);
	int (*set_acl)(struct inode___269 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___268 {
	void (*fl_copy_lock)(struct file_lock___269 *, struct file_lock___269 *);
	void (*fl_release_private)(struct file_lock___269 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___268;

struct lock_manager_operations___268;

struct file_lock___269 {
	struct file_lock___269 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___269 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___268 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___268 *fl_ops;
	const struct lock_manager_operations___268 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___268 {
	int (*lm_compare_owner)(struct file_lock___269 *, struct file_lock___269 *);
	long unsigned int (*lm_owner_key)(struct file_lock___269 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___269 *);
	int (*lm_grant)(struct file_lock___269 *, int);
	bool (*lm_break)(struct file_lock___269 *);
	int (*lm_change)(struct file_lock___269 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___269 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___268 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___268 *fa_next;
	struct file___269 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___268 {
	const char *name;
	int fs_flags;
	struct dentry___269 * (*mount)(struct file_system_type___268 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___268 *);
	struct module___218 *owner;
	struct file_system_type___268 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___268 {
	struct inode___269 * (*alloc_inode)(struct super_block___268 *);
	void (*destroy_inode)(struct inode___269 *);
	void (*dirty_inode)(struct inode___269 *, int);
	int (*write_inode)(struct inode___269 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___269 *);
	void (*evict_inode)(struct inode___269 *);
	void (*put_super)(struct super_block___268 *);
	int (*sync_fs)(struct super_block___268 *, int);
	int (*freeze_super)(struct super_block___268 *);
	int (*freeze_fs)(struct super_block___268 *);
	int (*thaw_super)(struct super_block___268 *);
	int (*unfreeze_fs)(struct super_block___268 *);
	int (*statfs)(struct dentry___269 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___268 *, int *, char *);
	void (*umount_begin)(struct super_block___268 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___269 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___269 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___269 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___269 *);
	ssize_t (*quota_read)(struct super_block___268 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___268 *, int, const char *, size_t, loff_t);
	struct dquot___268 ** (*get_dquots)(struct inode___269 *);
	int (*bdev_try_to_free_page)(struct super_block___268 *, struct page___270 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___268 *, struct shrink_control___112 *);
	long int (*free_cached_objects)(struct super_block___268 *, struct shrink_control___112 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___70 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___70 *last_lookup;
	struct hd_struct___70 *part[0];
};

struct block_device_operations___70 {
	int (*open)(struct block_device___268 *, fmode_t);
	void (*release)(struct gendisk___70 *, fmode_t);
	int (*rw_page)(struct block_device___268 *, sector_t, struct page___270 *, unsigned int);
	int (*ioctl)(struct block_device___268 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___268 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___70 *, unsigned int);
	int (*media_changed)(struct gendisk___70 *);
	void (*unlock_native_capacity)(struct gendisk___70 *);
	int (*revalidate_disk)(struct gendisk___70 *);
	int (*getgeo)(struct block_device___268 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___268 *, long unsigned int);
	int (*report_zones)(struct gendisk___70 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___218 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___258(struct page___270 *);

struct bdi_writeback_congested___138 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___138 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bsg_ops___69 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___69 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___69 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___69 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___69(struct request___69 *, blk_status_t);

struct request___69 {
	struct request_queue___69 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___11 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___138 *bio;
	struct bio___138 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___138 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___73 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___69 *saved_end_io;
		} flush;
	};
	struct gendisk___70 *rq_disk;
	struct hd_struct___70 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___69 *end_io;
	void *end_io_data;
	struct request___69 *next_rq;
};

struct fwnode_reference_args___167;

struct fwnode_endpoint___167;

struct fwnode_operations___167 {
	struct fwnode_handle___167 * (*get)(struct fwnode_handle___167 *);
	void (*put)(struct fwnode_handle___167 *);
	bool (*device_is_available)(const struct fwnode_handle___167 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___167 *, const struct device___232 *);
	bool (*property_present)(const struct fwnode_handle___167 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___167 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___167 *, const char *, const char **, size_t);
	struct fwnode_handle___167 * (*get_parent)(const struct fwnode_handle___167 *);
	struct fwnode_handle___167 * (*get_next_child_node)(const struct fwnode_handle___167 *, struct fwnode_handle___167 *);
	struct fwnode_handle___167 * (*get_named_child_node)(const struct fwnode_handle___167 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___167 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___167 *);
	struct fwnode_handle___167 * (*graph_get_next_endpoint)(const struct fwnode_handle___167 *, struct fwnode_handle___167 *);
	struct fwnode_handle___167 * (*graph_get_remote_endpoint)(const struct fwnode_handle___167 *);
	struct fwnode_handle___167 * (*graph_get_port_parent)(struct fwnode_handle___167 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___167 *, struct fwnode_endpoint___167 *);
};

struct fwnode_endpoint___167 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___167 *local_fwnode;
};

struct fwnode_reference_args___167 {
	struct fwnode_handle___167 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct blk_mq_hw_ctx___11 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___69 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags___4 *tags;
	struct blk_mq_tags___4 *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	unsigned int rh_reserved_nr_expired;
	struct hlist_node cpuhp_dead;
	struct kobject___257 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___269 *debugfs_dir;
	struct dentry___269 *sched_debugfs_dir;
	struct list_head hctx_list;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___69;

struct elevator_mq_ops___69 {
	int (*init_sched)(struct request_queue___69 *, struct elevator_type___69 *);
	void (*exit_sched)(struct elevator_queue___69 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___11 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___11 *, unsigned int);
	bool (*allow_merge)(struct request_queue___69 *, struct request___69 *, struct bio___138 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx___11 *, struct bio___138 *);
	int (*request_merge)(struct request_queue___69 *, struct request___69 **, struct bio___138 *);
	void (*request_merged)(struct request_queue___69 *, struct request___69 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___69 *, struct request___69 *, struct request___69 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___69 *, struct bio___138 *);
	void (*finish_request)(struct request___69 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___11 *, struct list_head *, bool);
	struct request___69 * (*dispatch_request)(struct blk_mq_hw_ctx___11 *);
	bool (*has_work)(struct blk_mq_hw_ctx___11 *);
	void (*completed_request)(struct request___69 *, u64);
	void (*started_request)(struct request___69 *);
	void (*requeue_request)(struct request___69 *);
	struct request___69 * (*former_request)(struct request_queue___69 *, struct request___69 *);
	struct request___69 * (*next_request)(struct request_queue___69 *, struct request___69 *);
	void (*init_icq)(struct io_cq___73 *);
	void (*exit_icq)(struct io_cq___73 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx___11 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___69;

struct elevator_type___69 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___69 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___69 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___218 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___69 {
	struct elevator_type___69 *type;
	void *elevator_data;
	struct kobject___257 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___69 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___69 *, char *);
	ssize_t (*store)(struct elevator_queue___69 *, const char *, size_t);
};

struct blk_mq_queue_data___11;

typedef blk_status_t queue_rq_fn___11(struct blk_mq_hw_ctx___11 *, const struct blk_mq_queue_data___11 *);

typedef void commit_rqs_fn___11(struct blk_mq_hw_ctx___11 *);

typedef bool get_budget_fn___11(struct blk_mq_hw_ctx___11 *);

typedef void put_budget_fn___11(struct blk_mq_hw_ctx___11 *);

typedef enum blk_eh_timer_return timeout_fn___11(struct request___69 *, bool);

typedef int poll_fn___11(struct blk_mq_hw_ctx___11 *);

typedef void complete_fn___11(struct request___69 *);

typedef int init_hctx_fn___11(struct blk_mq_hw_ctx___11 *, void *, unsigned int);

typedef void exit_hctx_fn___11(struct blk_mq_hw_ctx___11 *, unsigned int);

typedef int init_request_fn___11(struct blk_mq_tag_set___11 *, struct request___69 *, unsigned int, unsigned int);

typedef void exit_request_fn___11(struct blk_mq_tag_set___11 *, struct request___69 *, unsigned int);

typedef bool busy_fn___11(struct request_queue___69 *);

typedef int map_queues_fn___11(struct blk_mq_tag_set___11 *);

typedef void cleanup_rq_fn___11(struct request___69 *);

struct blk_mq_ops___11 {
	queue_rq_fn___11 *queue_rq;
	commit_rqs_fn___11 *commit_rqs;
	get_budget_fn___11 *get_budget;
	put_budget_fn___11 *put_budget;
	timeout_fn___11 *timeout;
	poll_fn___11 *poll;
	complete_fn___11 *complete;
	init_hctx_fn___11 *init_hctx;
	exit_hctx_fn___11 *exit_hctx;
	init_request_fn___11 *init_request;
	exit_request_fn___11 *exit_request;
	void (*initialize_rq_fn)(struct request___69 *);
	busy_fn___11 *busy;
	map_queues_fn___11 *map_queues;
	void (*show_rq)(struct seq_file___9 *, struct request___69 *);
	union {
		cleanup_rq_fn___11 *cleanup_rq;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide47;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct blk_mq_tag_set___11 {
	struct blk_mq_queue_map map[6];
	unsigned int nr_maps;
	const struct blk_mq_ops___11 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	struct blk_mq_tags___4 **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct blk_mq_queue_data___11 {
	struct request___69 *rq;
	bool last;
	long unsigned int rh_reserved1;
};

struct bsg_device {
	struct request_queue___69 *queue;
	spinlock_t lock;
	struct hlist_node dev_list;
	atomic_t ref_count;
	char name[20];
	int max_queue;
};

struct file___270;

struct kiocb___270;

struct vm_area_struct___271;

struct inode___270;

struct file_lock___270;

struct page___271;

struct file_operations___270 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___270 *, loff_t, int);
	ssize_t (*read)(struct file___270 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___270 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___270 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___270 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___270 *, bool);
	int (*iterate)(struct file___270 *, struct dir_context *);
	int (*iterate_shared)(struct file___270 *, struct dir_context *);
	__poll_t (*poll)(struct file___270 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___270 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___270 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___270 *, struct vm_area_struct___271 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___270 *, struct file___270 *);
	int (*flush)(struct file___270 *, fl_owner_t);
	int (*release)(struct inode___270 *, struct file___270 *);
	int (*fsync)(struct file___270 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___270 *, int);
	int (*lock)(struct file___270 *, int, struct file_lock___270 *);
	ssize_t (*sendpage)(struct file___270 *, struct page___271 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___270 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___270 *, int, struct file_lock___270 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___270 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___270 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___270 *, long int, struct file_lock___270 **, void **);
	long int (*fallocate)(struct file___270 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___270 *);
	ssize_t (*copy_file_range)(struct file___270 *, loff_t, struct file___270 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___270 *, loff_t, struct file___270 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___270 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___270 {
	u64 seqnum;
	struct vm_area_struct___271 *vmas[4];
};

struct page_frag___270 {
	struct page___271 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___270;

struct bio_list___139;

struct backing_dev_info___139;

struct io_context___74;

struct request_queue___70;

struct vm_struct___186;

struct task_struct___271 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___271 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___270 *mm;
	struct mm_struct___270 *active_mm;
	struct vmacache___270 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___271 *real_parent;
	struct task_struct___271 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___271 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___190 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___190 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___190 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___2 *ptracer_cred;
	const struct cred___2 *real_cred;
	const struct cred___2 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___271 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___139 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___139 *backing_dev_info;
	struct io_context___74 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___270 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___70 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___271 *oom_reaper_list;
	struct vm_struct___186 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___128 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___271 *pgtable_t___270;

struct address_space___269;

struct dev_pagemap___259;

struct page___271 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___269 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___271 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___270 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___270 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___259 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___270;

struct lruvec___270 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___270 *pgdat;
};

struct zone___270 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___270 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___270 {
	struct zone___270 *zone;
	int zone_idx;
};

struct zonelist___270 {
	struct zoneref___270 _zonerefs[25];
};

struct pglist_data___270 {
	struct zone___270 node_zones[3];
	struct zonelist___270 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___271 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___271 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___270 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___271 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___271 *owner;
};

struct secondary_data___271 {
	void *stack;
	struct task_struct___271 *task;
	long int status;
};

struct blocking_notifier_head___270 {
	struct rw_semaphore___271 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___259;

struct vm_area_struct___271 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___271 *vm_next;
	struct vm_area_struct___271 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___270 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___259 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___270 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___270;

struct mm_struct___270 {
	struct {
		struct vm_area_struct___271 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___270 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___271 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___270 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___271 *owner;
		struct user_namespace___3 *user_ns;
		struct file___270 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___270 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct bio___139;

struct bio_list___139 {
	struct bio___139 *head;
	struct bio___139 *tail;
};

struct bdi_writeback_congested___139;

struct bdi_writeback___139 {
	struct backing_dev_info___139 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___139 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___157 *memcg_css;
	struct cgroup_subsys_state___157 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___233;

struct dentry___270;

struct backing_dev_info___139 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___139 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___233 *dev;
	struct device___233 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___270 *debug_dir;
	struct dentry___270 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___74;

struct io_context___74 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___74 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

typedef blk_qc_t make_request_fn___70(struct request_queue___70 *, struct bio___139 *);

struct request___70;

typedef int dma_drain_needed_fn___70(struct request___70 *);

struct kset___257;

struct kobj_type___257;

struct kernfs_node___265;

struct kobject___258 {
	const char *name;
	struct list_head entry;
	struct kobject___258 *parent;
	struct kset___257 *kset;
	struct kobj_type___257 *ktype;
	struct kernfs_node___265 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___70;

struct bsg_class_device___70 {
	struct device___233 *class_dev;
	int minor;
	struct request_queue___70 *queue;
	const struct bsg_ops___70 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___139 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___139 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___70;

struct blk_mq_ops___12;

struct blk_mq_hw_ctx___12;

struct blk_mq_tag_set___12;

struct request_queue___70 {
	struct list_head queue_head;
	struct request___70 *last_merge;
	struct elevator_queue___70 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___70 *make_request_fn;
	dma_drain_needed_fn___70 *dma_drain_needed;
	const struct blk_mq_ops___12 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___12 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___139 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___258 kobj;
	struct kobject___258 *mq_kobj;
	struct blk_integrity integrity;
	struct device___233 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	struct bsg_class_device___70 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set___12 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___139 bio_split;
	struct dentry___270 *debugfs_dir;
	struct dentry___270 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___186 {
	struct vm_struct___186 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___271 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bio_vec___139 {
	struct page___271 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

typedef void bio_end_io_t___139(struct bio___139 *);

struct gendisk___71;

struct bio_integrity_payload___139;

struct bio___139 {
	struct bio___139 *bi_next;
	struct gendisk___71 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___139 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___139 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___139 *bi_io_vec;
	struct bio_set___139 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___139 bi_inline_vecs[0];
};

struct bio_integrity_payload___139 {
	struct bio___139 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___139 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___139 bip_inline_vecs[0];
};

struct dev_pm_info___233 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___233 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___233;

struct bus_type___233;

struct device_driver___233;

struct dev_pm_domain___233;

struct dma_map_ops___65;

struct fwnode_handle___168;

struct class___233;

struct attribute_group___235;

struct device___233 {
	struct device___233 *parent;
	struct device_private *p;
	struct kobject___258 kobj;
	const char *init_name;
	const struct device_type___233 *type;
	struct mutex mutex;
	struct bus_type___233 *bus;
	struct device_driver___233 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___233 power;
	struct dev_pm_domain___233 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___65 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___168 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___233 *class;
	const struct attribute_group___235 **groups;
	void (*release)(struct device___233 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___71 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___233 __dev;
	struct kobject___258 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___71;

struct block_device_operations___71;

struct gendisk___71 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___71 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___71 *part_tbl;
	struct hd_struct___71 part0;
	const struct block_device_operations___71 *fops;
	struct request_queue___70 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___271 lookup_sem;
	struct kobject___258 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___258 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_ops___233;

struct device_type___233 {
	const char *name;
	const struct attribute_group___235 **groups;
	int (*uevent)(struct device___233 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___233 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___233 *);
	const struct dev_pm_ops___233 *pm;
};

struct class___233 {
	const char *name;
	struct module___11 *owner;
	const struct attribute_group___235 **class_groups;
	const struct attribute_group___235 **dev_groups;
	struct kobject___258 *dev_kobj;
	int (*dev_uevent)(struct device___233 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___233 *, umode_t *);
	void (*class_release)(struct class___233 *);
	void (*dev_release)(struct device___233 *);
	int (*shutdown_pre)(struct device___233 *);
	const struct kobj_ns_type_operations___24 *ns_type;
	const void * (*namespace)(struct device___233 *);
	const struct dev_pm_ops___233 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct kernfs_root___264;

struct kernfs_elem_dir___264 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___264 *root;
};

struct kernfs_syscall_ops___264;

struct kernfs_root___264 {
	struct kernfs_node___265 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___264 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___264 {
	struct kernfs_node___265 *target_kn;
};

struct kernfs_ops___264;

struct kernfs_elem_attr___264 {
	const struct kernfs_ops___264 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___265 *notify_next;
};

struct kernfs_node___265 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___265 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___264 dir;
		struct kernfs_elem_symlink___264 symlink;
		struct kernfs_elem_attr___264 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___264;

struct kernfs_ops___264 {
	int (*open)(struct kernfs_open_file___264 *);
	void (*release)(struct kernfs_open_file___264 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___264 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___264 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___264 *, struct vm_area_struct___271 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___264 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___264 {
	int (*remount_fs)(struct kernfs_root___264 *, int *, char *);
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___264 *);
	int (*mkdir)(struct kernfs_node___265 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___265 *);
	int (*rename)(struct kernfs_node___265 *, struct kernfs_node___265 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___265 *, struct kernfs_root___264 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___264 {
	struct kernfs_node___265 *kn;
	struct file___270 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___259 *vm_ops;
};

struct path___270 {
	struct vfsmount *mnt;
	struct dentry___270 *dentry;
};

struct file___270 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___270 f_path;
	struct inode___270 *f_inode;
	const struct file_operations___270 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___190 f_owner;
	const struct cred___2 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___269 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___259;

struct vm_operations_struct___259 {
	void (*open)(struct vm_area_struct___271 *);
	void (*close)(struct vm_area_struct___271 *);
	int (*split)(struct vm_area_struct___271 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___271 *);
	vm_fault_t (*fault)(struct vm_fault___259 *);
	vm_fault_t (*huge_fault)(struct vm_fault___259 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___259 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___271 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___259 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___259 *);
	int (*access)(struct vm_area_struct___271 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___271 *);
	int (*set_policy)(struct vm_area_struct___271 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___271 *, long unsigned int);
	struct page___271 * (*find_special_page)(struct vm_area_struct___271 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___234;

struct attribute_group___235 {
	const char *name;
	umode_t (*is_visible)(struct kobject___258 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___258 *, struct bin_attribute___234 *, int);
	struct attribute **attrs;
	struct bin_attribute___234 **bin_attrs;
};

struct bin_attribute___234 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___270 *, struct kobject___258 *, struct bin_attribute___234 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___270 *, struct kobject___258 *, struct bin_attribute___234 *, char *, loff_t, size_t);
	int (*mmap)(struct file___270 *, struct kobject___258 *, struct bin_attribute___234 *, struct vm_area_struct___271 *);
};

struct sysfs_ops___257 {
	ssize_t (*show)(struct kobject___258 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___258 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___257;

struct kset___257 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___258 kobj;
	const struct kset_uevent_ops___257 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___257 {
	void (*release)(struct kobject___258 *);
	const struct sysfs_ops___257 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___24 * (*child_ns_type)(struct kobject___258 *);
	const void * (*namespace)(struct kobject___258 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___257 {
	int (* const filter)(struct kset___257 *, struct kobject___258 *);
	const char * (* const name)(struct kset___257 *, struct kobject___258 *);
	int (* const uevent)(struct kset___257 *, struct kobject___258 *, struct kobj_uevent_env *);
};

struct kobj_attribute___250 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___258 *, struct kobj_attribute___250 *, char *);
	ssize_t (*store)(struct kobject___258 *, struct kobj_attribute___250 *, const char *, size_t);
};

struct dev_pm_ops___233 {
	int (*prepare)(struct device___233 *);
	void (*complete)(struct device___233 *);
	int (*suspend)(struct device___233 *);
	int (*resume)(struct device___233 *);
	int (*freeze)(struct device___233 *);
	int (*thaw)(struct device___233 *);
	int (*poweroff)(struct device___233 *);
	int (*restore)(struct device___233 *);
	int (*suspend_late)(struct device___233 *);
	int (*resume_early)(struct device___233 *);
	int (*freeze_late)(struct device___233 *);
	int (*thaw_early)(struct device___233 *);
	int (*poweroff_late)(struct device___233 *);
	int (*restore_early)(struct device___233 *);
	int (*suspend_noirq)(struct device___233 *);
	int (*resume_noirq)(struct device___233 *);
	int (*freeze_noirq)(struct device___233 *);
	int (*thaw_noirq)(struct device___233 *);
	int (*poweroff_noirq)(struct device___233 *);
	int (*restore_noirq)(struct device___233 *);
	int (*runtime_suspend)(struct device___233 *);
	int (*runtime_resume)(struct device___233 *);
	int (*runtime_idle)(struct device___233 *);
};

struct dev_pm_domain___233 {
	struct dev_pm_ops___233 ops;
	void (*detach)(struct device___233 *, bool);
	int (*activate)(struct device___233 *);
	void (*sync)(struct device___233 *);
	void (*dismiss)(struct device___233 *);
};

struct bus_type___233 {
	const char *name;
	const char *dev_name;
	struct device___233 *dev_root;
	const struct attribute_group___235 **bus_groups;
	const struct attribute_group___235 **dev_groups;
	const struct attribute_group___235 **drv_groups;
	int (*match)(struct device___233 *, struct device_driver___233 *);
	int (*uevent)(struct device___233 *, struct kobj_uevent_env *);
	int (*probe)(struct device___233 *);
	int (*remove)(struct device___233 *);
	void (*shutdown)(struct device___233 *);
	int (*online)(struct device___233 *);
	int (*offline)(struct device___233 *);
	int (*suspend)(struct device___233 *, pm_message_t);
	int (*resume)(struct device___233 *);
	int (*num_vf)(struct device___233 *);
	int (*dma_configure)(struct device___233 *);
	const struct dev_pm_ops___233 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___233 {
	const char *name;
	struct bus_type___233 *bus;
	struct module___11 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___233 *);
	int (*remove)(struct device___233 *);
	void (*shutdown)(struct device___233 *);
	int (*suspend)(struct device___233 *, pm_message_t);
	int (*resume)(struct device___233 *);
	const struct attribute_group___235 **groups;
	const struct dev_pm_ops___233 *pm;
	void (*coredump)(struct device___233 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct dma_map_ops___65 {
	void * (*alloc)(struct device___233 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___233 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___233 *, struct vm_area_struct___271 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___233 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___233 *, struct page___271 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___233 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___233 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___233 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___233 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___233 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___233 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide43;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___233 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___233 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___233 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___233 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___233 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___233 *, u64);
	u64 (*get_required_mask)(struct device___233 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___168;

struct fwnode_handle___168 {
	struct fwnode_handle___168 *secondary;
	const struct fwnode_operations___168 *ops;
};

struct dentry_operations___269;

struct super_block___269;

struct dentry___270 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___270 *d_parent;
	struct qstr d_name;
	struct inode___270 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___269 *d_op;
	struct super_block___269 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___269;

struct address_space___269 {
	struct inode___270 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___271 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___269 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___269;

struct block_device___269;

struct inode___270 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___269 *i_op;
	struct super_block___269 *i_sb;
	struct address_space___269 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___271 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___139 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___270 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___269 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___269 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___269 {
	int (*d_revalidate)(struct dentry___270 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___270 *, unsigned int);
	int (*d_hash)(const struct dentry___270 *, struct qstr *);
	int (*d_compare)(const struct dentry___270 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___270 *);
	int (*d_init)(struct dentry___270 *);
	void (*d_release)(struct dentry___270 *);
	void (*d_prune)(struct dentry___270 *);
	void (*d_iput)(struct dentry___270 *, struct inode___270 *);
	char * (*d_dname)(struct dentry___270 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___270 *);
	int (*d_manage)(const struct path___270 *, bool);
	struct dentry___270 * (*d_real)(struct dentry___270 *, const struct inode___270 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___269;

struct mem_dqinfo___269 {
	struct quota_format_type___269 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___269;

struct quota_info___269 {
	unsigned int flags;
	struct rw_semaphore___271 dqio_sem;
	struct inode___270 *files[3];
	struct mem_dqinfo___269 info[3];
	const struct quota_format_ops___269 *ops[3];
};

struct rcuwait___269 {
	struct task_struct___271 *task;
};

struct percpu_rw_semaphore___269 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___271 rw_sem;
	struct rcuwait___269 writer;
	int readers_block;
};

struct sb_writers___269 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___269 rw_sem[3];
};

struct file_system_type___269;

struct super_operations___269;

struct dquot_operations___269;

struct quotactl_ops___269;

struct super_block___269 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___269 *s_type;
	const struct super_operations___269 *s_op;
	const struct dquot_operations___269 *dq_op;
	const struct quotactl_ops___269 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___270 *s_root;
	struct rw_semaphore___271 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___269 *s_bdev;
	struct backing_dev_info___139 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___269 s_dquot;
	struct sb_writers___269 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___269 *s_d_op;
	int cleancache_poolid;
	struct shrinker___112 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

typedef int (*dev_page_fault_t___259)(struct vm_area_struct___271 *, long unsigned int, const struct page___271 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___259)(struct page___271 *, void *);

struct dev_pagemap___259 {
	dev_page_fault_t___259 page_fault;
	dev_page_free_t___259 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___233 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___270 {
	struct task_struct___271 *task;
	struct core_thread___270 *next;
};

struct core_state___270 {
	atomic_t nr_threads;
	struct core_thread___270 dumper;
	struct completion startup;
};

struct vm_fault___259 {
	struct vm_area_struct___271 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___271 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___271 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___270 prealloc_pte;
};

struct io_cq___74 {
	struct request_queue___70 *q;
	struct io_context___74 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___6 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___270 {
	struct file___270 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___270 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___269 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___270 *ia_file;
};

struct dquot___269 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___269 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___269 {
	int qf_fmt_id;
	const struct quota_format_ops___269 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___269 *qf_next;
};

struct quota_format_ops___269 {
	int (*check_quota_file)(struct super_block___269 *, int);
	int (*read_file_info)(struct super_block___269 *, int);
	int (*write_file_info)(struct super_block___269 *, int);
	int (*free_file_info)(struct super_block___269 *, int);
	int (*read_dqblk)(struct dquot___269 *);
	int (*commit_dqblk)(struct dquot___269 *);
	int (*release_dqblk)(struct dquot___269 *);
	int (*get_next_id)(struct super_block___269 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___269 {
	int (*write_dquot)(struct dquot___269 *);
	struct dquot___269 * (*alloc_dquot)(struct super_block___269 *, int);
	void (*destroy_dquot)(struct dquot___269 *);
	int (*acquire_dquot)(struct dquot___269 *);
	int (*release_dquot)(struct dquot___269 *);
	int (*mark_dirty)(struct dquot___269 *);
	int (*write_info)(struct super_block___269 *, int);
	qsize_t * (*get_reserved_space)(struct inode___270 *);
	int (*get_projid)(struct inode___270 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___270 *, qsize_t *);
	int (*get_next_id)(struct super_block___269 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___269 {
	int (*quota_on)(struct super_block___269 *, int, int, const struct path___270 *);
	int (*quota_off)(struct super_block___269 *, int);
	int (*quota_enable)(struct super_block___269 *, unsigned int);
	int (*quota_disable)(struct super_block___269 *, unsigned int);
	int (*quota_sync)(struct super_block___269 *, int);
	int (*set_info)(struct super_block___269 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___269 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___269 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___269 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___269 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___269 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___269 {
	int (*writepage)(struct page___271 *, struct writeback_control___3 *);
	int (*readpage)(struct file___270 *, struct page___271 *);
	int (*writepages)(struct address_space___269 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___271 *);
	int (*readpages)(struct file___270 *, struct address_space___269 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___270 *, struct address_space___269 *, loff_t, unsigned int, unsigned int, struct page___271 **, void **);
	int (*write_end)(struct file___270 *, struct address_space___269 *, loff_t, unsigned int, unsigned int, struct page___271 *, void *);
	sector_t (*bmap)(struct address_space___269 *, sector_t);
	void (*invalidatepage)(struct page___271 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___271 *, gfp_t);
	void (*freepage)(struct page___271 *);
	ssize_t (*direct_IO)(struct kiocb___270 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___269 *, struct page___271 *, struct page___271 *, enum migrate_mode);
	bool (*isolate_page)(struct page___271 *, isolate_mode_t);
	void (*putback_page)(struct page___271 *);
	int (*launder_page)(struct page___271 *);
	int (*is_partially_uptodate)(struct page___271 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___271 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___269 *, struct page___271 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___270 *, sector_t *);
	void (*swap_deactivate)(struct file___270 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___269 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___270 *bd_inode;
	struct super_block___269 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___269 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___71 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___71 *bd_disk;
	struct request_queue___70 *bd_queue;
	struct backing_dev_info___139 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___269 {
	struct dentry___270 * (*lookup)(struct inode___270 *, struct dentry___270 *, unsigned int);
	const char * (*get_link)(struct dentry___270 *, struct inode___270 *, struct delayed_call *);
	int (*permission)(struct inode___270 *, int);
	struct posix_acl * (*get_acl)(struct inode___270 *, int);
	int (*readlink)(struct dentry___270 *, char *, int);
	int (*create)(struct inode___270 *, struct dentry___270 *, umode_t, bool);
	int (*link)(struct dentry___270 *, struct inode___270 *, struct dentry___270 *);
	int (*unlink)(struct inode___270 *, struct dentry___270 *);
	int (*symlink)(struct inode___270 *, struct dentry___270 *, const char *);
	int (*mkdir)(struct inode___270 *, struct dentry___270 *, umode_t);
	int (*rmdir)(struct inode___270 *, struct dentry___270 *);
	int (*mknod)(struct inode___270 *, struct dentry___270 *, umode_t, dev_t);
	int (*rename)(struct inode___270 *, struct dentry___270 *, struct inode___270 *, struct dentry___270 *, unsigned int);
	int (*setattr)(struct dentry___270 *, struct iattr___269 *);
	int (*getattr)(const struct path___270 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___270 *, char *, size_t);
	int (*fiemap)(struct inode___270 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___270 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___270 *, struct dentry___270 *, struct file___270 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___270 *, struct dentry___270 *, umode_t);
	int (*set_acl)(struct inode___270 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___269 {
	void (*fl_copy_lock)(struct file_lock___270 *, struct file_lock___270 *);
	void (*fl_release_private)(struct file_lock___270 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___269;

struct lock_manager_operations___269;

struct file_lock___270 {
	struct file_lock___270 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___270 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___269 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___269 *fl_ops;
	const struct lock_manager_operations___269 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___269 {
	int (*lm_compare_owner)(struct file_lock___270 *, struct file_lock___270 *);
	long unsigned int (*lm_owner_key)(struct file_lock___270 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___270 *);
	int (*lm_grant)(struct file_lock___270 *, int);
	bool (*lm_break)(struct file_lock___270 *);
	int (*lm_change)(struct file_lock___270 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___270 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___269 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___269 *fa_next;
	struct file___270 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___269 {
	const char *name;
	int fs_flags;
	struct dentry___270 * (*mount)(struct file_system_type___269 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___269 *);
	struct module___11 *owner;
	struct file_system_type___269 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___269 {
	struct inode___270 * (*alloc_inode)(struct super_block___269 *);
	void (*destroy_inode)(struct inode___270 *);
	void (*dirty_inode)(struct inode___270 *, int);
	int (*write_inode)(struct inode___270 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___270 *);
	void (*evict_inode)(struct inode___270 *);
	void (*put_super)(struct super_block___269 *);
	int (*sync_fs)(struct super_block___269 *, int);
	int (*freeze_super)(struct super_block___269 *);
	int (*freeze_fs)(struct super_block___269 *);
	int (*thaw_super)(struct super_block___269 *);
	int (*unfreeze_fs)(struct super_block___269 *);
	int (*statfs)(struct dentry___270 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___269 *, int *, char *);
	void (*umount_begin)(struct super_block___269 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___270 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___270 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___270 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___270 *);
	ssize_t (*quota_read)(struct super_block___269 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___269 *, int, const char *, size_t, loff_t);
	struct dquot___269 ** (*get_dquots)(struct inode___270 *);
	int (*bdev_try_to_free_page)(struct super_block___269 *, struct page___271 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___269 *, struct shrink_control___112 *);
	long int (*free_cached_objects)(struct super_block___269 *, struct shrink_control___112 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___71 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___71 *last_lookup;
	struct hd_struct___71 *part[0];
};

struct block_device_operations___71 {
	int (*open)(struct block_device___269 *, fmode_t);
	void (*release)(struct gendisk___71 *, fmode_t);
	int (*rw_page)(struct block_device___269 *, sector_t, struct page___271 *, unsigned int);
	int (*ioctl)(struct block_device___269 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___269 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___71 *, unsigned int);
	int (*media_changed)(struct gendisk___71 *);
	void (*unlock_native_capacity)(struct gendisk___71 *);
	int (*revalidate_disk)(struct gendisk___71 *);
	int (*getgeo)(struct block_device___269 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___269 *, long unsigned int);
	int (*report_zones)(struct gendisk___71 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___11 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___259(struct page___271 *);

struct bdi_writeback_congested___139 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___139 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bsg_ops___70 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___70 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___70 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___70 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___70(struct request___70 *, blk_status_t);

struct request___70 {
	struct request_queue___70 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___12 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___139 *bio;
	struct bio___139 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___139 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___74 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___70 *saved_end_io;
		} flush;
	};
	struct gendisk___71 *rq_disk;
	struct hd_struct___71 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___70 *end_io;
	void *end_io_data;
	struct request___70 *next_rq;
};

struct fwnode_reference_args___168;

struct fwnode_endpoint___168;

struct fwnode_operations___168 {
	struct fwnode_handle___168 * (*get)(struct fwnode_handle___168 *);
	void (*put)(struct fwnode_handle___168 *);
	bool (*device_is_available)(const struct fwnode_handle___168 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___168 *, const struct device___233 *);
	bool (*property_present)(const struct fwnode_handle___168 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___168 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___168 *, const char *, const char **, size_t);
	struct fwnode_handle___168 * (*get_parent)(const struct fwnode_handle___168 *);
	struct fwnode_handle___168 * (*get_next_child_node)(const struct fwnode_handle___168 *, struct fwnode_handle___168 *);
	struct fwnode_handle___168 * (*get_named_child_node)(const struct fwnode_handle___168 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___168 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___168 *);
	struct fwnode_handle___168 * (*graph_get_next_endpoint)(const struct fwnode_handle___168 *, struct fwnode_handle___168 *);
	struct fwnode_handle___168 * (*graph_get_remote_endpoint)(const struct fwnode_handle___168 *);
	struct fwnode_handle___168 * (*graph_get_port_parent)(struct fwnode_handle___168 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___168 *, struct fwnode_endpoint___168 *);
};

struct fwnode_endpoint___168 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___168 *local_fwnode;
};

struct fwnode_reference_args___168 {
	struct fwnode_handle___168 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct blk_mq_hw_ctx___12 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___70 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags___4 *tags;
	struct blk_mq_tags___4 *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	unsigned int rh_reserved_nr_expired;
	struct hlist_node cpuhp_dead;
	struct kobject___258 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___270 *debugfs_dir;
	struct dentry___270 *sched_debugfs_dir;
	struct list_head hctx_list;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___70;

struct elevator_mq_ops___70 {
	int (*init_sched)(struct request_queue___70 *, struct elevator_type___70 *);
	void (*exit_sched)(struct elevator_queue___70 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___12 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___12 *, unsigned int);
	bool (*allow_merge)(struct request_queue___70 *, struct request___70 *, struct bio___139 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx___12 *, struct bio___139 *);
	int (*request_merge)(struct request_queue___70 *, struct request___70 **, struct bio___139 *);
	void (*request_merged)(struct request_queue___70 *, struct request___70 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___70 *, struct request___70 *, struct request___70 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___70 *, struct bio___139 *);
	void (*finish_request)(struct request___70 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___12 *, struct list_head *, bool);
	struct request___70 * (*dispatch_request)(struct blk_mq_hw_ctx___12 *);
	bool (*has_work)(struct blk_mq_hw_ctx___12 *);
	void (*completed_request)(struct request___70 *, u64);
	void (*started_request)(struct request___70 *);
	void (*requeue_request)(struct request___70 *);
	struct request___70 * (*former_request)(struct request_queue___70 *, struct request___70 *);
	struct request___70 * (*next_request)(struct request_queue___70 *, struct request___70 *);
	void (*init_icq)(struct io_cq___74 *);
	void (*exit_icq)(struct io_cq___74 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx___12 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___70;

struct elevator_type___70 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___70 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___70 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___11 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___70 {
	struct elevator_type___70 *type;
	void *elevator_data;
	struct kobject___258 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___70 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___70 *, char *);
	ssize_t (*store)(struct elevator_queue___70 *, const char *, size_t);
};

struct blk_mq_queue_data___12;

typedef blk_status_t queue_rq_fn___12(struct blk_mq_hw_ctx___12 *, const struct blk_mq_queue_data___12 *);

typedef void commit_rqs_fn___12(struct blk_mq_hw_ctx___12 *);

typedef bool get_budget_fn___12(struct blk_mq_hw_ctx___12 *);

typedef void put_budget_fn___12(struct blk_mq_hw_ctx___12 *);

typedef enum blk_eh_timer_return timeout_fn___12(struct request___70 *, bool);

typedef int poll_fn___12(struct blk_mq_hw_ctx___12 *);

typedef void complete_fn___12(struct request___70 *);

typedef int init_hctx_fn___12(struct blk_mq_hw_ctx___12 *, void *, unsigned int);

typedef void exit_hctx_fn___12(struct blk_mq_hw_ctx___12 *, unsigned int);

typedef int init_request_fn___12(struct blk_mq_tag_set___12 *, struct request___70 *, unsigned int, unsigned int);

typedef void exit_request_fn___12(struct blk_mq_tag_set___12 *, struct request___70 *, unsigned int);

typedef bool busy_fn___12(struct request_queue___70 *);

typedef int map_queues_fn___12(struct blk_mq_tag_set___12 *);

typedef void cleanup_rq_fn___12(struct request___70 *);

struct blk_mq_ops___12 {
	queue_rq_fn___12 *queue_rq;
	commit_rqs_fn___12 *commit_rqs;
	get_budget_fn___12 *get_budget;
	put_budget_fn___12 *put_budget;
	timeout_fn___12 *timeout;
	poll_fn___12 *poll;
	complete_fn___12 *complete;
	init_hctx_fn___12 *init_hctx;
	exit_hctx_fn___12 *exit_hctx;
	init_request_fn___12 *init_request;
	exit_request_fn___12 *exit_request;
	void (*initialize_rq_fn)(struct request___70 *);
	busy_fn___12 *busy;
	map_queues_fn___12 *map_queues;
	void (*show_rq)(struct seq_file___9 *, struct request___70 *);
	union {
		cleanup_rq_fn___12 *cleanup_rq;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide42;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct blk_mq_tag_set___12 {
	struct blk_mq_queue_map map[6];
	unsigned int nr_maps;
	const struct blk_mq_ops___12 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	struct blk_mq_tags___4 **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct blk_mq_queue_data___12 {
	struct request___70 *rq;
	bool last;
	long unsigned int rh_reserved1;
};

struct bsg_job;

typedef int bsg_job_fn(struct bsg_job *);

struct bsg_buffer {
	unsigned int payload_len;
	int sg_cnt;
	struct scatterlist *sg_list;
};

struct bsg_job {
	struct device___233 *dev;
	struct kref kref;
	unsigned int timeout;
	void *request;
	void *reply;
	unsigned int request_len;
	unsigned int reply_len;
	struct bsg_buffer request_payload;
	struct bsg_buffer reply_payload;
	int result;
	unsigned int reply_payload_rcv_len;
	void *dd_data;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef enum blk_eh_timer_return bsg_timeout_fn(struct request___70 *);

struct bsg_set {
	struct blk_mq_tag_set___12 tag_set;
	bsg_job_fn *job_fn;
	bsg_timeout_fn *timeout_fn;
};

struct module___219;

struct file___271;

struct kiocb___271;

struct vm_area_struct___272;

struct inode___271;

struct file_lock___271;

struct page___272;

struct seq_file___237;

struct file_operations___271 {
	struct module___219 *owner;
	loff_t (*llseek)(struct file___271 *, loff_t, int);
	ssize_t (*read)(struct file___271 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___271 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___271 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___271 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___271 *, bool);
	int (*iterate)(struct file___271 *, struct dir_context *);
	int (*iterate_shared)(struct file___271 *, struct dir_context *);
	__poll_t (*poll)(struct file___271 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___271 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___271 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___271 *, struct vm_area_struct___272 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___271 *, struct file___271 *);
	int (*flush)(struct file___271 *, fl_owner_t);
	int (*release)(struct inode___271 *, struct file___271 *);
	int (*fsync)(struct file___271 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___271 *, int);
	int (*lock)(struct file___271 *, int, struct file_lock___271 *);
	ssize_t (*sendpage)(struct file___271 *, struct page___272 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___271 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___271 *, int, struct file_lock___271 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___271 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___271 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___271 *, long int, struct file_lock___271 **, void **);
	long int (*fallocate)(struct file___271 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___237 *, struct file___271 *);
	ssize_t (*copy_file_range)(struct file___271 *, loff_t, struct file___271 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___271 *, loff_t, struct file___271 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___271 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___271 {
	u64 seqnum;
	struct vm_area_struct___272 *vmas[4];
};

struct page_frag___271 {
	struct page___272 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___271;

struct mem_cgroup___113;

struct pid___191;

struct cred___258;

struct nsproxy___236;

struct signal_struct___215;

struct bio_list___140;

struct backing_dev_info___140;

struct io_context___75;

struct css_set___201;

struct request_queue___71;

struct vm_struct___187;

struct task_struct___272 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___272 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___271 *mm;
	struct mm_struct___271 *active_mm;
	struct vmacache___271 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___272 *real_parent;
	struct task_struct___272 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___272 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___113 *active_memcg;
	long int rh_reserved2;
	struct pid___191 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___191 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___191 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___258 *ptracer_cred;
	const struct cred___258 *real_cred;
	const struct cred___258 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___236 *nsproxy;
	struct signal_struct___215 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___272 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___140 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___140 *backing_dev_info;
	struct io_context___75 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___201 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___271 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___113 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___71 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___272 *oom_reaper_list;
	struct vm_struct___187 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___128 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___191;

struct upid___191 {
	int nr;
	struct pid_namespace___191 *ns;
};

struct dentry___271;

struct user_namespace___216;

struct ucounts___216;

struct pid_namespace___191 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___272 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___191 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___271 *proc_self;
	struct dentry___271 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___216 *user_ns;
	struct ucounts___216 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___28 ns;
};

struct pid___191 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___191 numbers[1];
};

struct rw_semaphore___272 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___272 *owner;
};

struct key___258;

struct user_namespace___216 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___216 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___28 ns;
	long unsigned int flags;
	struct key___258 *persistent_keyring_register;
	struct rw_semaphore___272 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___216 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct secondary_data___272 {
	void *stack;
	struct task_struct___272 *task;
	long int status;
};

typedef struct page___272 *pgtable_t___271;

struct address_space___270;

struct dev_pagemap___260;

struct page___272 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___270 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___272 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___271 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___271 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___260 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___113 *mem_cgroup;
};

struct user_struct___258 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___258 *uid_keyring;
	struct key___258 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___260;

struct vm_area_struct___272 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___272 *vm_next;
	struct vm_area_struct___272 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___271 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___260 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___271 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___271;

struct mm_struct___271 {
	struct {
		struct vm_area_struct___272 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___271 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___272 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___271 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___272 *owner;
		struct user_namespace___216 *user_ns;
		struct file___271 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___271 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup___201;

struct cgroup_subsys___201;

struct cgroup_subsys_state___201 {
	struct cgroup___201 *cgroup;
	struct cgroup_subsys___201 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___201 *parent;
};

struct mem_cgroup_id___24 {
	int id;
	union {
		refcount_t ref;
		struct {
			atomic_t ref;
		} __UNIQUE_ID_rh_kabi_hide43;
		union {		};
	};
};

struct kernfs_node___266;

struct cgroup_file___201 {
	struct kernfs_node___266 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___113;

struct mem_cgroup___113 {
	struct cgroup_subsys_state___201 css;
	struct mem_cgroup_id___24 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___201 events_file;
	struct cgroup_file___201 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___272 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___113 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cred___258 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___258 *session_keyring;
	struct key___258 *process_keyring;
	struct key___258 *thread_keyring;
	struct key___258 *request_key_auth;
	void *security;
	struct user_struct___258 *user;
	struct user_namespace___216 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___201;

struct nsproxy___236 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___191 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___201 *cgroup_ns;
};

struct signal_struct___215 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___272 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___272 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___191 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___191 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___271 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___191 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___140;

struct bio_list___140 {
	struct bio___140 *head;
	struct bio___140 *tail;
};

struct bdi_writeback_congested___140;

struct bdi_writeback___140 {
	struct backing_dev_info___140 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___140 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___201 *memcg_css;
	struct cgroup_subsys_state___201 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___234;

struct backing_dev_info___140 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___140 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___234 *dev;
	struct device___234 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___271 *debug_dir;
	struct dentry___271 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___75;

struct io_context___75 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___75 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___201 {
	struct cgroup_subsys_state___201 *subsys[13];
	refcount_t refcount;
	struct css_set___201 *dom_cset;
	struct cgroup___201 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___201 *mg_src_cgrp;
	struct cgroup___201 *mg_dst_cgrp;
	struct css_set___201 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

typedef blk_qc_t make_request_fn___71(struct request_queue___71 *, struct bio___140 *);

struct request___71;

typedef int dma_drain_needed_fn___71(struct request___71 *);

struct kset___258;

struct kobj_type___258;

struct kobject___259 {
	const char *name;
	struct list_head entry;
	struct kobject___259 *parent;
	struct kset___258 *kset;
	struct kobj_type___258 *ktype;
	struct kernfs_node___266 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___71;

struct bsg_class_device___71 {
	struct device___234 *class_dev;
	int minor;
	struct request_queue___71 *queue;
	const struct bsg_ops___71 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___140 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___140 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___71;

struct blk_mq_ops___13;

struct blk_mq_ctx___10;

struct blk_mq_hw_ctx___13;

struct blk_stat_callback___10;

struct blkcg_gq___52;

struct blk_flush_queue___10;

struct blk_mq_tag_set___13;

struct request_queue___71 {
	struct list_head queue_head;
	struct request___71 *last_merge;
	struct elevator_queue___71 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___71 *make_request_fn;
	dma_drain_needed_fn___71 *dma_drain_needed;
	const struct blk_mq_ops___13 *mq_ops;
	struct blk_mq_ctx___10 *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___13 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___140 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___259 kobj;
	struct kobject___259 *mq_kobj;
	struct blk_integrity integrity;
	struct device___234 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback___10 *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___52 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue___10 *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	struct bsg_class_device___71 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set___13 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___140 bio_split;
	struct dentry___271 *debugfs_dir;
	struct dentry___271 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___187 {
	struct vm_struct___187 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___272 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___227 {
	struct task_struct___272 task;
	long unsigned int stack[8192];
};

struct pglist_data___271;

struct lruvec___271 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___271 *pgdat;
};

struct zone___271 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___271 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___271 {
	struct zone___271 *zone;
	int zone_idx;
};

struct zonelist___271 {
	struct zoneref___271 _zonerefs[25];
};

struct pglist_data___271 {
	struct zone___271 node_zones[3];
	struct zonelist___271 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___272 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___272 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___271 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___271 {
	struct rw_semaphore___272 rwsem;
	struct notifier_block *head;
};

struct io_cq___75 {
	struct request_queue___71 *q;
	struct io_context___75 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___6 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct path___271 {
	struct vfsmount *mnt;
	struct dentry___271 *dentry;
};

struct fown_struct___191 {
	rwlock_t lock;
	struct pid___191 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___271 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___271 f_path;
	struct inode___271 *f_inode;
	const struct file_operations___271 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___191 f_owner;
	const struct cred___258 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___270 *f_mapping;
	errseq_t f_wb_err;
};

struct kernfs_root___265;

struct kernfs_elem_dir___265 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___265 *root;
};

struct kernfs_syscall_ops___265;

struct kernfs_root___265 {
	struct kernfs_node___266 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___265 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___265 {
	struct kernfs_node___266 *target_kn;
};

struct kernfs_ops___265;

struct kernfs_elem_attr___265 {
	const struct kernfs_ops___265 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___266 *notify_next;
};

struct kernfs_node___266 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___266 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___265 dir;
		struct kernfs_elem_symlink___265 symlink;
		struct kernfs_elem_attr___265 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___265;

struct kernfs_ops___265 {
	int (*open)(struct kernfs_open_file___265 *);
	void (*release)(struct kernfs_open_file___265 *);
	int (*seq_show)(struct seq_file___237 *, void *);
	void * (*seq_start)(struct seq_file___237 *, loff_t *);
	void * (*seq_next)(struct seq_file___237 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___237 *, void *);
	ssize_t (*read)(struct kernfs_open_file___265 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___265 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___265 *, struct vm_area_struct___272 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___265 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___265 {
	int (*remount_fs)(struct kernfs_root___265 *, int *, char *);
	int (*show_options)(struct seq_file___237 *, struct kernfs_root___265 *);
	int (*mkdir)(struct kernfs_node___266 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___266 *);
	int (*rename)(struct kernfs_node___266 *, struct kernfs_node___266 *, const char *);
	int (*show_path)(struct seq_file___237 *, struct kernfs_node___266 *, struct kernfs_root___265 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___236;

struct seq_file___237 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___236 *op;
	int poll_event;
	const struct file___271 *file;
	void *private;
};

struct kernfs_open_file___265 {
	struct kernfs_node___266 *kn;
	struct file___271 *file;
	struct seq_file___237 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___260 *vm_ops;
};

struct vm_fault___260;

struct vm_operations_struct___260 {
	void (*open)(struct vm_area_struct___272 *);
	void (*close)(struct vm_area_struct___272 *);
	int (*split)(struct vm_area_struct___272 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___272 *);
	vm_fault_t (*fault)(struct vm_fault___260 *);
	vm_fault_t (*huge_fault)(struct vm_fault___260 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___260 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___272 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___260 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___260 *);
	int (*access)(struct vm_area_struct___272 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___272 *);
	int (*set_policy)(struct vm_area_struct___272 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___272 *, long unsigned int);
	struct page___272 * (*find_special_page)(struct vm_area_struct___272 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___235;

struct attribute_group___236 {
	const char *name;
	umode_t (*is_visible)(struct kobject___259 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___259 *, struct bin_attribute___235 *, int);
	struct attribute **attrs;
	struct bin_attribute___235 **bin_attrs;
};

struct bin_attribute___235 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___271 *, struct kobject___259 *, struct bin_attribute___235 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___271 *, struct kobject___259 *, struct bin_attribute___235 *, char *, loff_t, size_t);
	int (*mmap)(struct file___271 *, struct kobject___259 *, struct bin_attribute___235 *, struct vm_area_struct___272 *);
};

struct sysfs_ops___258 {
	ssize_t (*show)(struct kobject___259 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___259 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___258;

struct kset___258 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___259 kobj;
	const struct kset_uevent_ops___258 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___258 {
	void (*release)(struct kobject___259 *);
	const struct sysfs_ops___258 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___24 * (*child_ns_type)(struct kobject___259 *);
	const void * (*namespace)(struct kobject___259 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___258 {
	int (* const filter)(struct kset___258 *, struct kobject___259 *);
	const char * (* const name)(struct kset___258 *, struct kobject___259 *);
	int (* const uevent)(struct kset___258 *, struct kobject___259 *, struct kobj_uevent_env *);
};

struct kobj_attribute___251 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___259 *, struct kobj_attribute___251 *, char *);
	ssize_t (*store)(struct kobject___259 *, struct kobj_attribute___251 *, const char *, size_t);
};

struct kernel_param___216;

struct kernel_param_ops___216 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___216 *);
	int (*get)(char *, const struct kernel_param___216 *);
	void (*free)(void *);
};

struct kparam_array___216;

struct kernel_param___216 {
	const char *name;
	struct module___219 *mod;
	const struct kernel_param_ops___216 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___216 *arr;
	};
};

struct kparam_array___216 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___216 *ops;
	void *elem;
};

struct module_kobject___216 {
	struct kobject___259 kobj;
	struct module___219 *mod;
	struct kobject___259 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___216 {
	struct module___219 *mod;
	struct latch_tree_node node;
};

struct module_layout___216 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___216 mtn;
};

struct module_attribute___216;

struct module___219 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___216 mkobj;
	struct module_attribute___216 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___259 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___216 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___216 core_layout;
	struct module_layout___216 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___216 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___216 *, struct module_kobject___216 *, char *);
	ssize_t (*store)(struct module_attribute___216 *, struct module_kobject___216 *, const char *, size_t);
	void (*setup)(struct module___219 *, const char *);
	int (*test)(struct module___219 *);
	void (*free)(struct module___219 *);
};

typedef int (*key_restrict_link_func_t___259)(struct key___258 *, const struct key_type *, const union key_payload *, struct key___258 *);

struct key_restriction___258;

struct key___258 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___272 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key___6 index_key;
		struct {
			struct key_type___6 *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___258 *restrict_link;
};

struct key_restriction___258 {
	key_restrict_link_func_t___259 check;
	struct key___258 *key;
	struct key_type *keytype;
};

struct bio_vec___140 {
	struct page___272 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

typedef void bio_end_io_t___140(struct bio___140 *);

struct gendisk___72;

struct bio_integrity_payload___140;

struct bio___140 {
	struct bio___140 *bi_next;
	struct gendisk___72 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___140 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___52 *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___140 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___140 *bi_io_vec;
	struct bio_set___140 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___140 bi_inline_vecs[0];
};

struct bio_integrity_payload___140 {
	struct bio___140 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___140 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___140 bip_inline_vecs[0];
};

struct dev_pm_info___234 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___234 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___234;

struct bus_type___234;

struct device_driver___234;

struct dev_pm_domain___234;

struct fwnode_handle___169;

struct class___234;

struct device___234 {
	struct device___234 *parent;
	struct device_private *p;
	struct kobject___259 kobj;
	const char *init_name;
	const struct device_type___234 *type;
	struct mutex mutex;
	struct bus_type___234 *bus;
	struct device_driver___234 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___234 power;
	struct dev_pm_domain___234 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___169 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___234 *class;
	const struct attribute_group___236 **groups;
	void (*release)(struct device___234 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___72 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___234 __dev;
	struct kobject___259 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___72;

struct block_device_operations___72;

struct gendisk___72 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___72 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___72 *part_tbl;
	struct hd_struct___72 part0;
	const struct block_device_operations___72 *fops;
	struct request_queue___71 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___272 lookup_sem;
	struct kobject___259 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___259 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct blkcg___52;

struct blkg_policy_data___52;

struct blkcg_gq___52 {
	struct request_queue___71 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___52 *blkcg;
	struct bdi_writeback_congested___140 *wb_congested;
	struct blkcg_gq___52 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_rwstat stat_bytes;
	struct blkg_rwstat stat_ios;
	struct blkg_policy_data___52 *pd[5];
	struct callback_head callback_head;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
};

struct dev_pm_ops___234;

struct device_type___234 {
	const char *name;
	const struct attribute_group___236 **groups;
	int (*uevent)(struct device___234 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___234 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___234 *);
	const struct dev_pm_ops___234 *pm;
};

struct class___234 {
	const char *name;
	struct module___219 *owner;
	const struct attribute_group___236 **class_groups;
	const struct attribute_group___236 **dev_groups;
	struct kobject___259 *dev_kobj;
	int (*dev_uevent)(struct device___234 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___234 *, umode_t *);
	void (*class_release)(struct class___234 *);
	void (*dev_release)(struct device___234 *);
	int (*shutdown_pre)(struct device___234 *);
	const struct kobj_ns_type_operations___24 *ns_type;
	const void * (*namespace)(struct device___234 *);
	const struct dev_pm_ops___234 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dev_pm_ops___234 {
	int (*prepare)(struct device___234 *);
	void (*complete)(struct device___234 *);
	int (*suspend)(struct device___234 *);
	int (*resume)(struct device___234 *);
	int (*freeze)(struct device___234 *);
	int (*thaw)(struct device___234 *);
	int (*poweroff)(struct device___234 *);
	int (*restore)(struct device___234 *);
	int (*suspend_late)(struct device___234 *);
	int (*resume_early)(struct device___234 *);
	int (*freeze_late)(struct device___234 *);
	int (*thaw_early)(struct device___234 *);
	int (*poweroff_late)(struct device___234 *);
	int (*restore_early)(struct device___234 *);
	int (*suspend_noirq)(struct device___234 *);
	int (*resume_noirq)(struct device___234 *);
	int (*freeze_noirq)(struct device___234 *);
	int (*thaw_noirq)(struct device___234 *);
	int (*poweroff_noirq)(struct device___234 *);
	int (*restore_noirq)(struct device___234 *);
	int (*runtime_suspend)(struct device___234 *);
	int (*runtime_resume)(struct device___234 *);
	int (*runtime_idle)(struct device___234 *);
};

struct dev_pm_domain___234 {
	struct dev_pm_ops___234 ops;
	void (*detach)(struct device___234 *, bool);
	int (*activate)(struct device___234 *);
	void (*sync)(struct device___234 *);
	void (*dismiss)(struct device___234 *);
};

struct bus_type___234 {
	const char *name;
	const char *dev_name;
	struct device___234 *dev_root;
	const struct attribute_group___236 **bus_groups;
	const struct attribute_group___236 **dev_groups;
	const struct attribute_group___236 **drv_groups;
	int (*match)(struct device___234 *, struct device_driver___234 *);
	int (*uevent)(struct device___234 *, struct kobj_uevent_env *);
	int (*probe)(struct device___234 *);
	int (*remove)(struct device___234 *);
	void (*shutdown)(struct device___234 *);
	int (*online)(struct device___234 *);
	int (*offline)(struct device___234 *);
	int (*suspend)(struct device___234 *, pm_message_t);
	int (*resume)(struct device___234 *);
	int (*num_vf)(struct device___234 *);
	int (*dma_configure)(struct device___234 *);
	const struct dev_pm_ops___234 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___234 {
	const char *name;
	struct bus_type___234 *bus;
	struct module___219 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___234 *);
	int (*remove)(struct device___234 *);
	void (*shutdown)(struct device___234 *);
	int (*suspend)(struct device___234 *, pm_message_t);
	int (*resume)(struct device___234 *);
	const struct attribute_group___236 **groups;
	const struct dev_pm_ops___234 *pm;
	void (*coredump)(struct device___234 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct fwnode_operations___169;

struct fwnode_handle___169 {
	struct fwnode_handle___169 *secondary;
	const struct fwnode_operations___169 *ops;
};

struct dentry_operations___270;

struct super_block___270;

struct dentry___271 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___271 *d_parent;
	struct qstr d_name;
	struct inode___271 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___270 *d_op;
	struct super_block___270 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___270;

struct address_space___270 {
	struct inode___271 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___272 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___270 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___270;

struct block_device___270;

struct inode___271 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___270 *i_op;
	struct super_block___270 *i_sb;
	struct address_space___270 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___272 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___140 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___271 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___270 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___270 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___270 {
	int (*d_revalidate)(struct dentry___271 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___271 *, unsigned int);
	int (*d_hash)(const struct dentry___271 *, struct qstr *);
	int (*d_compare)(const struct dentry___271 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___271 *);
	int (*d_init)(struct dentry___271 *);
	void (*d_release)(struct dentry___271 *);
	void (*d_prune)(struct dentry___271 *);
	void (*d_iput)(struct dentry___271 *, struct inode___271 *);
	char * (*d_dname)(struct dentry___271 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___271 *);
	int (*d_manage)(const struct path___271 *, bool);
	struct dentry___271 * (*d_real)(struct dentry___271 *, const struct inode___271 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___270;

struct mem_dqinfo___270 {
	struct quota_format_type___270 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___270;

struct quota_info___270 {
	unsigned int flags;
	struct rw_semaphore___272 dqio_sem;
	struct inode___271 *files[3];
	struct mem_dqinfo___270 info[3];
	const struct quota_format_ops___270 *ops[3];
};

struct rcuwait___270 {
	struct task_struct___272 *task;
};

struct percpu_rw_semaphore___270 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___272 rw_sem;
	struct rcuwait___270 writer;
	int readers_block;
};

struct sb_writers___270 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___270 rw_sem[3];
};

struct shrink_control___113;

struct shrinker___113 {
	long unsigned int (*count_objects)(struct shrinker___113 *, struct shrink_control___113 *);
	long unsigned int (*scan_objects)(struct shrinker___113 *, struct shrink_control___113 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___270;

struct super_operations___270;

struct dquot_operations___270;

struct quotactl_ops___270;

struct super_block___270 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___270 *s_type;
	const struct super_operations___270 *s_op;
	const struct dquot_operations___270 *dq_op;
	const struct quotactl_ops___270 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___271 *s_root;
	struct rw_semaphore___272 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___270 *s_bdev;
	struct backing_dev_info___140 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___270 s_dquot;
	struct sb_writers___270 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___270 *s_d_op;
	int cleancache_poolid;
	struct shrinker___113 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___216 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___113 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___113 *memcg;
};

typedef int (*dev_page_fault_t___260)(struct vm_area_struct___272 *, long unsigned int, const struct page___272 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___260)(struct page___272 *, void *);

struct dev_pagemap___260 {
	dev_page_fault_t___260 page_fault;
	dev_page_free_t___260 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___234 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___271 {
	struct task_struct___272 *task;
	struct core_thread___271 *next;
};

struct core_state___271 {
	atomic_t nr_threads;
	struct core_thread___271 dumper;
	struct completion startup;
};

struct vm_fault___260 {
	struct vm_area_struct___272 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___272 *cow_page;
	struct mem_cgroup___113 *memcg;
	struct page___272 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___271 prealloc_pte;
};

struct kiocb___271 {
	struct file___271 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___271 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___270 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___271 *ia_file;
};

struct dquot___270 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___270 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___270 {
	int qf_fmt_id;
	const struct quota_format_ops___270 *qf_ops;
	struct module___219 *qf_owner;
	struct quota_format_type___270 *qf_next;
};

struct quota_format_ops___270 {
	int (*check_quota_file)(struct super_block___270 *, int);
	int (*read_file_info)(struct super_block___270 *, int);
	int (*write_file_info)(struct super_block___270 *, int);
	int (*free_file_info)(struct super_block___270 *, int);
	int (*read_dqblk)(struct dquot___270 *);
	int (*commit_dqblk)(struct dquot___270 *);
	int (*release_dqblk)(struct dquot___270 *);
	int (*get_next_id)(struct super_block___270 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___270 {
	int (*write_dquot)(struct dquot___270 *);
	struct dquot___270 * (*alloc_dquot)(struct super_block___270 *, int);
	void (*destroy_dquot)(struct dquot___270 *);
	int (*acquire_dquot)(struct dquot___270 *);
	int (*release_dquot)(struct dquot___270 *);
	int (*mark_dirty)(struct dquot___270 *);
	int (*write_info)(struct super_block___270 *, int);
	qsize_t * (*get_reserved_space)(struct inode___271 *);
	int (*get_projid)(struct inode___271 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___271 *, qsize_t *);
	int (*get_next_id)(struct super_block___270 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___270 {
	int (*quota_on)(struct super_block___270 *, int, int, const struct path___271 *);
	int (*quota_off)(struct super_block___270 *, int);
	int (*quota_enable)(struct super_block___270 *, unsigned int);
	int (*quota_disable)(struct super_block___270 *, unsigned int);
	int (*quota_sync)(struct super_block___270 *, int);
	int (*set_info)(struct super_block___270 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___270 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___270 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___270 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___270 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___270 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___127;

struct address_space_operations___270 {
	int (*writepage)(struct page___272 *, struct writeback_control___127 *);
	int (*readpage)(struct file___271 *, struct page___272 *);
	int (*writepages)(struct address_space___270 *, struct writeback_control___127 *);
	int (*set_page_dirty)(struct page___272 *);
	int (*readpages)(struct file___271 *, struct address_space___270 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___271 *, struct address_space___270 *, loff_t, unsigned int, unsigned int, struct page___272 **, void **);
	int (*write_end)(struct file___271 *, struct address_space___270 *, loff_t, unsigned int, unsigned int, struct page___272 *, void *);
	sector_t (*bmap)(struct address_space___270 *, sector_t);
	void (*invalidatepage)(struct page___272 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___272 *, gfp_t);
	void (*freepage)(struct page___272 *);
	ssize_t (*direct_IO)(struct kiocb___271 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___270 *, struct page___272 *, struct page___272 *, enum migrate_mode);
	bool (*isolate_page)(struct page___272 *, isolate_mode_t);
	void (*putback_page)(struct page___272 *);
	int (*launder_page)(struct page___272 *);
	int (*is_partially_uptodate)(struct page___272 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___272 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___270 *, struct page___272 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___271 *, sector_t *);
	void (*swap_deactivate)(struct file___271 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___127 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___140 *wb;
	struct inode___271 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___270 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___271 *bd_inode;
	struct super_block___270 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___270 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___72 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___72 *bd_disk;
	struct request_queue___71 *bd_queue;
	struct backing_dev_info___140 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___270 {
	struct dentry___271 * (*lookup)(struct inode___271 *, struct dentry___271 *, unsigned int);
	const char * (*get_link)(struct dentry___271 *, struct inode___271 *, struct delayed_call *);
	int (*permission)(struct inode___271 *, int);
	struct posix_acl * (*get_acl)(struct inode___271 *, int);
	int (*readlink)(struct dentry___271 *, char *, int);
	int (*create)(struct inode___271 *, struct dentry___271 *, umode_t, bool);
	int (*link)(struct dentry___271 *, struct inode___271 *, struct dentry___271 *);
	int (*unlink)(struct inode___271 *, struct dentry___271 *);
	int (*symlink)(struct inode___271 *, struct dentry___271 *, const char *);
	int (*mkdir)(struct inode___271 *, struct dentry___271 *, umode_t);
	int (*rmdir)(struct inode___271 *, struct dentry___271 *);
	int (*mknod)(struct inode___271 *, struct dentry___271 *, umode_t, dev_t);
	int (*rename)(struct inode___271 *, struct dentry___271 *, struct inode___271 *, struct dentry___271 *, unsigned int);
	int (*setattr)(struct dentry___271 *, struct iattr___270 *);
	int (*getattr)(const struct path___271 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___271 *, char *, size_t);
	int (*fiemap)(struct inode___271 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___271 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___271 *, struct dentry___271 *, struct file___271 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___271 *, struct dentry___271 *, umode_t);
	int (*set_acl)(struct inode___271 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___270 {
	void (*fl_copy_lock)(struct file_lock___271 *, struct file_lock___271 *);
	void (*fl_release_private)(struct file_lock___271 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___270;

struct lock_manager_operations___270;

struct file_lock___271 {
	struct file_lock___271 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___271 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___270 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___270 *fl_ops;
	const struct lock_manager_operations___270 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___270 {
	int (*lm_compare_owner)(struct file_lock___271 *, struct file_lock___271 *);
	long unsigned int (*lm_owner_key)(struct file_lock___271 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___271 *);
	int (*lm_grant)(struct file_lock___271 *, int);
	bool (*lm_break)(struct file_lock___271 *);
	int (*lm_change)(struct file_lock___271 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___271 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___270 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___270 *fa_next;
	struct file___271 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___270 {
	const char *name;
	int fs_flags;
	struct dentry___271 * (*mount)(struct file_system_type___270 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___270 *);
	struct module___219 *owner;
	struct file_system_type___270 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___270 {
	struct inode___271 * (*alloc_inode)(struct super_block___270 *);
	void (*destroy_inode)(struct inode___271 *);
	void (*dirty_inode)(struct inode___271 *, int);
	int (*write_inode)(struct inode___271 *, struct writeback_control___127 *);
	int (*drop_inode)(struct inode___271 *);
	void (*evict_inode)(struct inode___271 *);
	void (*put_super)(struct super_block___270 *);
	int (*sync_fs)(struct super_block___270 *, int);
	int (*freeze_super)(struct super_block___270 *);
	int (*freeze_fs)(struct super_block___270 *);
	int (*thaw_super)(struct super_block___270 *);
	int (*unfreeze_fs)(struct super_block___270 *);
	int (*statfs)(struct dentry___271 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___270 *, int *, char *);
	void (*umount_begin)(struct super_block___270 *);
	int (*show_options)(struct seq_file___237 *, struct dentry___271 *);
	int (*show_devname)(struct seq_file___237 *, struct dentry___271 *);
	int (*show_path)(struct seq_file___237 *, struct dentry___271 *);
	int (*show_stats)(struct seq_file___237 *, struct dentry___271 *);
	ssize_t (*quota_read)(struct super_block___270 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___270 *, int, const char *, size_t, loff_t);
	struct dquot___270 ** (*get_dquots)(struct inode___271 *);
	int (*bdev_try_to_free_page)(struct super_block___270 *, struct page___272 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___270 *, struct shrink_control___113 *);
	long int (*free_cached_objects)(struct super_block___270 *, struct shrink_control___113 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___72 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___72 *last_lookup;
	struct hd_struct___72 *part[0];
};

struct block_device_operations___72 {
	int (*open)(struct block_device___270 *, fmode_t);
	void (*release)(struct gendisk___72 *, fmode_t);
	int (*rw_page)(struct block_device___270 *, sector_t, struct page___272 *, unsigned int);
	int (*ioctl)(struct block_device___270 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___270 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___72 *, unsigned int);
	int (*media_changed)(struct gendisk___72 *);
	void (*unlock_native_capacity)(struct gendisk___72 *);
	int (*revalidate_disk)(struct gendisk___72 *);
	int (*getgeo)(struct block_device___270 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___270 *, long unsigned int);
	int (*report_zones)(struct gendisk___72 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___219 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___260(struct page___272 *);

struct bdi_writeback_congested___140 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___140 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bsg_ops___71 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___71 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___71 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___71 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___71(struct request___71 *, blk_status_t);

struct request___71 {
	struct request_queue___71 *q;
	struct blk_mq_ctx___10 *mq_ctx;
	struct blk_mq_hw_ctx___13 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___140 *bio;
	struct bio___140 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___140 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___75 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___71 *saved_end_io;
		} flush;
	};
	struct gendisk___72 *rq_disk;
	struct hd_struct___72 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___71 *end_io;
	void *end_io_data;
	struct request___71 *next_rq;
};

struct fwnode_reference_args___169;

struct fwnode_endpoint___169;

struct fwnode_operations___169 {
	struct fwnode_handle___169 * (*get)(struct fwnode_handle___169 *);
	void (*put)(struct fwnode_handle___169 *);
	bool (*device_is_available)(const struct fwnode_handle___169 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___169 *, const struct device___234 *);
	bool (*property_present)(const struct fwnode_handle___169 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___169 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___169 *, const char *, const char **, size_t);
	struct fwnode_handle___169 * (*get_parent)(const struct fwnode_handle___169 *);
	struct fwnode_handle___169 * (*get_next_child_node)(const struct fwnode_handle___169 *, struct fwnode_handle___169 *);
	struct fwnode_handle___169 * (*get_named_child_node)(const struct fwnode_handle___169 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___169 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___169 *);
	struct fwnode_handle___169 * (*graph_get_next_endpoint)(const struct fwnode_handle___169 *, struct fwnode_handle___169 *);
	struct fwnode_handle___169 * (*graph_get_remote_endpoint)(const struct fwnode_handle___169 *);
	struct fwnode_handle___169 * (*graph_get_port_parent)(struct fwnode_handle___169 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___169 *, struct fwnode_endpoint___169 *);
};

struct fwnode_endpoint___169 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___169 *local_fwnode;
};

struct fwnode_reference_args___169 {
	struct fwnode_handle___169 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct blk_mq_ctxs___10;

struct blk_mq_ctx___10 {
	struct {
		spinlock_t lock;
		struct list_head rq_lists[3];
		long: 64;
	};
	unsigned int cpu;
	short unsigned int index_hw[3];
	struct blk_mq_hw_ctx___13 *hctxs[3];
	long unsigned int rq_dispatched[2];
	long unsigned int rq_merged;
	long unsigned int rq_completed[2];
	struct request_queue___71 *queue;
	struct blk_mq_ctxs___10 *ctxs;
	struct kobject___259 kobj;
};

struct blk_mq_tags___10;

struct blk_mq_hw_ctx___13 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___71 *queue;
	struct blk_flush_queue___10 *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx___10 *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx___10 **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags___10 *tags;
	struct blk_mq_tags___10 *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	unsigned int rh_reserved_nr_expired;
	struct hlist_node cpuhp_dead;
	struct kobject___259 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___271 *debugfs_dir;
	struct dentry___271 *sched_debugfs_dir;
	struct list_head hctx_list;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___71;

struct blk_mq_alloc_data___10;

struct elevator_mq_ops___71 {
	int (*init_sched)(struct request_queue___71 *, struct elevator_type___71 *);
	void (*exit_sched)(struct elevator_queue___71 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___13 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___13 *, unsigned int);
	bool (*allow_merge)(struct request_queue___71 *, struct request___71 *, struct bio___140 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx___13 *, struct bio___140 *);
	int (*request_merge)(struct request_queue___71 *, struct request___71 **, struct bio___140 *);
	void (*request_merged)(struct request_queue___71 *, struct request___71 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___71 *, struct request___71 *, struct request___71 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data___10 *);
	void (*prepare_request)(struct request___71 *, struct bio___140 *);
	void (*finish_request)(struct request___71 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___13 *, struct list_head *, bool);
	struct request___71 * (*dispatch_request)(struct blk_mq_hw_ctx___13 *);
	bool (*has_work)(struct blk_mq_hw_ctx___13 *);
	void (*completed_request)(struct request___71 *, u64);
	void (*started_request)(struct request___71 *);
	void (*requeue_request)(struct request___71 *);
	struct request___71 * (*former_request)(struct request_queue___71 *, struct request___71 *);
	struct request___71 * (*next_request)(struct request_queue___71 *, struct request___71 *);
	void (*init_icq)(struct io_cq___75 *);
	void (*exit_icq)(struct io_cq___75 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx___13 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___71;

struct elevator_type___71 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___71 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___71 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___219 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___71 {
	struct elevator_type___71 *type;
	void *elevator_data;
	struct kobject___259 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct blk_mq_alloc_data___10 {
	struct request_queue___71 *q;
	blk_mq_req_flags_t flags;
	unsigned int shallow_depth;
	unsigned int cmd_flags;
	struct blk_mq_ctx___10 *ctx;
	struct blk_mq_hw_ctx___13 *hctx;
};

struct elv_fs_entry___71 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___71 *, char *);
	ssize_t (*store)(struct elevator_queue___71 *, const char *, size_t);
};

struct blk_mq_queue_data___13;

typedef blk_status_t queue_rq_fn___13(struct blk_mq_hw_ctx___13 *, const struct blk_mq_queue_data___13 *);

typedef void commit_rqs_fn___13(struct blk_mq_hw_ctx___13 *);

typedef bool get_budget_fn___13(struct blk_mq_hw_ctx___13 *);

typedef void put_budget_fn___13(struct blk_mq_hw_ctx___13 *);

typedef enum blk_eh_timer_return timeout_fn___13(struct request___71 *, bool);

typedef int poll_fn___13(struct blk_mq_hw_ctx___13 *);

typedef void complete_fn___13(struct request___71 *);

typedef int init_hctx_fn___13(struct blk_mq_hw_ctx___13 *, void *, unsigned int);

typedef void exit_hctx_fn___13(struct blk_mq_hw_ctx___13 *, unsigned int);

typedef int init_request_fn___13(struct blk_mq_tag_set___13 *, struct request___71 *, unsigned int, unsigned int);

typedef void exit_request_fn___13(struct blk_mq_tag_set___13 *, struct request___71 *, unsigned int);

typedef bool busy_fn___13(struct request_queue___71 *);

typedef int map_queues_fn___13(struct blk_mq_tag_set___13 *);

typedef void cleanup_rq_fn___13(struct request___71 *);

struct blk_mq_ops___13 {
	queue_rq_fn___13 *queue_rq;
	commit_rqs_fn___13 *commit_rqs;
	get_budget_fn___13 *get_budget;
	put_budget_fn___13 *put_budget;
	timeout_fn___13 *timeout;
	poll_fn___13 *poll;
	complete_fn___13 *complete;
	init_hctx_fn___13 *init_hctx;
	exit_hctx_fn___13 *exit_hctx;
	init_request_fn___13 *init_request;
	exit_request_fn___13 *exit_request;
	void (*initialize_rq_fn)(struct request___71 *);
	busy_fn___13 *busy;
	map_queues_fn___13 *map_queues;
	void (*show_rq)(struct seq_file___237 *, struct request___71 *);
	union {
		cleanup_rq_fn___13 *cleanup_rq;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide46;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct blk_stat_callback___10 {
	struct list_head list;
	struct timer_list timer;
	struct blk_rq_stat *cpu_stat;
	int (*bucket_fn)(const struct request___71 *);
	unsigned int buckets;
	struct blk_rq_stat *stat;
	void (*timer_fn)(struct blk_stat_callback___10 *);
	void *data;
	struct callback_head rcu;
};

struct blk_flush_queue___10 {
	unsigned int flush_queue_delayed: 1;
	unsigned int flush_pending_idx: 1;
	unsigned int flush_running_idx: 1;
	long unsigned int flush_pending_since;
	struct list_head flush_queue[2];
	struct list_head flush_data_in_flight;
	struct request___71 *flush_rq;
	struct request___71 *orig_rq;
	spinlock_t mq_flush_lock;
};

struct blk_mq_tag_set___13 {
	struct blk_mq_queue_map map[6];
	unsigned int nr_maps;
	const struct blk_mq_ops___13 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	struct blk_mq_tags___10 **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct seq_operations___236 {
	void * (*start)(struct seq_file___237 *, loff_t *);
	void (*stop)(struct seq_file___237 *, void *);
	void * (*next)(struct seq_file___237 *, void *, loff_t *);
	int (*show)(struct seq_file___237 *, void *);
};

struct cgroup_namespace___201 {
	refcount_t count;
	struct ns_common___28 ns;
	struct user_namespace___216 *user_ns;
	struct ucounts___216 *ucounts;
	struct css_set___201 *root_cset;
};

struct ucounts___216 {
	struct hlist_node node;
	struct user_namespace___216 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___202;

struct bpf_map_ops___201 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___202 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___202 *, struct file___271 *);
	void (*map_free)(struct bpf_map___202 *);
	int (*map_get_next_key)(struct bpf_map___202 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___202 *);
	void * (*map_lookup_elem)(struct bpf_map___202 *, void *);
	int (*map_update_elem)(struct bpf_map___202 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___202 *, void *);
	int (*map_push_elem)(struct bpf_map___202 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___202 *, void *);
	int (*map_peek_elem)(struct bpf_map___202 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___202 *, struct file___271 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___202 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___202 *, void *, struct seq_file___237 *);
	int (*map_check_btf)(const struct bpf_map___202 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___202 {
	const struct bpf_map_ops___201 *ops;
	struct bpf_map___202 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___258 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___201;

typedef void (*kthread_work_func_t___201)(struct kthread_work___201 *);

struct kthread_worker___201;

struct kthread_work___201 {
	struct list_head node;
	kthread_work_func_t___201 func;
	struct kthread_worker___201 *worker;
	int canceling;
};

struct kthread_worker___201 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___272 *task;
	struct kthread_work___201 *current_work;
};

struct kthread_delayed_work___201 {
	struct kthread_work___201 work;
	struct timer_list timer;
};

struct psi_group___201 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___201 *poll_kworker;
	struct kthread_delayed_work___201 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___201;

struct cgroup_rstat_cpu___201;

struct cgroup___201 {
	struct cgroup_subsys_state___201 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___266 *kn;
	struct cgroup_file___201 procs_file;
	struct cgroup_file___201 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___201 *subsys[13];
	struct cgroup_root___201 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___201 *dom_cgrp;
	struct cgroup_rstat_cpu___201 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___34 bpf;
	atomic_t congestion_count;
	struct cgroup___201 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___201 psi;
	int ancestor_ids[0];
};

struct cftype___201;

struct cgroup_subsys___201 {
	struct cgroup_subsys_state___201 * (*css_alloc)(struct cgroup_subsys_state___201 *);
	int (*css_online)(struct cgroup_subsys_state___201 *);
	void (*css_offline)(struct cgroup_subsys_state___201 *);
	void (*css_released)(struct cgroup_subsys_state___201 *);
	void (*css_free)(struct cgroup_subsys_state___201 *);
	void (*css_reset)(struct cgroup_subsys_state___201 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___201 *, int);
	int (*css_extra_stat_show)(struct seq_file___237 *, struct cgroup_subsys_state___201 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___272 *);
	void (*cancel_fork)(struct task_struct___272 *);
	void (*fork)(struct task_struct___272 *);
	void (*exit)(struct task_struct___272 *);
	void (*free)(struct task_struct___272 *);
	void (*bind)(struct cgroup_subsys_state___201 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___201 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___201 *dfl_cftypes;
	struct cftype___201 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___201 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___201 *updated_children;
	struct cgroup___201 *updated_next;
};

struct cgroup_root___201 {
	struct kernfs_root___265 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___201 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___201 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___201 *ss;
	struct list_head node;
	struct kernfs_ops___265 *kf_ops;
	int (*open)(struct kernfs_open_file___265 *);
	void (*release)(struct kernfs_open_file___265 *);
	u64 (*read_u64)(struct cgroup_subsys_state___201 *, struct cftype___201 *);
	s64 (*read_s64)(struct cgroup_subsys_state___201 *, struct cftype___201 *);
	int (*seq_show)(struct seq_file___237 *, void *);
	void * (*seq_start)(struct seq_file___237 *, loff_t *);
	void * (*seq_next)(struct seq_file___237 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___237 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___201 *, struct cftype___201 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___201 *, struct cftype___201 *, s64);
	ssize_t (*write)(struct kernfs_open_file___265 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___265 *, struct poll_table_struct___6 *);
};

struct blkcg_policy_data___52;

struct blkcg___52 {
	struct cgroup_subsys_state___201 css;
	spinlock_t lock;
	struct xarray blkg_tree;
	struct blkcg_gq___52 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___52 *cpd[5];
	struct list_head all_blkcgs_node;
	struct list_head cgwb_list;
	refcount_t cgwb_refcnt;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct blkcg_policy_data___52 {
	struct blkcg___52 *blkcg;
	int plid;
};

struct blkg_stat {
	struct percpu_counter cpu_cnt;
	atomic64_t aux_cnt;
};

struct blkg_policy_data___52 {
	struct blkcg_gq___52 *blkg;
	int plid;
};

typedef struct blkcg_policy_data___52 *blkcg_pol_alloc_cpd_fn(gfp_t);

typedef void blkcg_pol_init_cpd_fn(struct blkcg_policy_data___52 *);

typedef void blkcg_pol_free_cpd_fn(struct blkcg_policy_data___52 *);

typedef void blkcg_pol_bind_cpd_fn(struct blkcg_policy_data___52 *);

typedef struct blkg_policy_data___52 *blkcg_pol_alloc_pd_fn(gfp_t, int);

typedef void blkcg_pol_init_pd_fn(struct blkg_policy_data___52 *);

typedef void blkcg_pol_online_pd_fn(struct blkg_policy_data___52 *);

typedef void blkcg_pol_offline_pd_fn(struct blkg_policy_data___52 *);

typedef void blkcg_pol_free_pd_fn(struct blkg_policy_data___52 *);

typedef void blkcg_pol_reset_pd_stats_fn(struct blkg_policy_data___52 *);

typedef size_t blkcg_pol_stat_pd_fn(struct blkg_policy_data___52 *, char *, size_t);

struct blkcg_policy {
	int plid;
	struct cftype___201 *dfl_cftypes;
	struct cftype___201 *legacy_cftypes;
	blkcg_pol_alloc_cpd_fn *cpd_alloc_fn;
	blkcg_pol_init_cpd_fn *cpd_init_fn;
	blkcg_pol_free_cpd_fn *cpd_free_fn;
	blkcg_pol_bind_cpd_fn *cpd_bind_fn;
	blkcg_pol_alloc_pd_fn *pd_alloc_fn;
	blkcg_pol_init_pd_fn *pd_init_fn;
	blkcg_pol_online_pd_fn *pd_online_fn;
	blkcg_pol_offline_pd_fn *pd_offline_fn;
	blkcg_pol_free_pd_fn *pd_free_fn;
	blkcg_pol_reset_pd_stats_fn *pd_reset_stats_fn;
	blkcg_pol_stat_pd_fn *pd_stat_fn;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct blkg_conf_ctx {
	struct gendisk___72 *disk;
	struct blkcg_gq___52 *blkg;
	char *body;
};

struct mem_cgroup_reclaim_iter___113 {
	struct mem_cgroup___113 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___113 {
	struct lruvec___271 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___113 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___113 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct blk_mq_tags___10 {
	unsigned int nr_tags;
	unsigned int nr_reserved_tags;
	atomic_t active_queues;
	struct sbitmap_queue bitmap_tags;
	struct sbitmap_queue breserved_tags;
	struct request___71 **rqs;
	struct request___71 **static_rqs;
	struct list_head page_list;
};

struct blk_mq_queue_data___13 {
	struct request___71 *rq;
	bool last;
	long unsigned int rh_reserved1;
};

struct blk_mq_ctxs___10 {
	struct kobject___259 kobj;
	struct blk_mq_ctx___10 *queue_ctx;
};

struct throtl_service_queue {
	struct throtl_service_queue *parent_sq;
	struct list_head queued[2];
	unsigned int nr_queued[2];
	struct rb_root_cached pending_tree;
	unsigned int nr_pending;
	long unsigned int first_pending_disptime;
	struct timer_list pending_timer;
};

struct latency_bucket {
	long unsigned int total_latency;
	int samples;
};

struct avg_latency_bucket {
	long unsigned int latency;
	bool valid;
};

struct throtl_data {
	struct throtl_service_queue service_queue;
	struct request_queue___61 *queue;
	unsigned int nr_queued[2];
	unsigned int throtl_slice;
	struct work_struct dispatch_work;
	unsigned int limit_index;
	bool limit_valid[2];
	long unsigned int low_upgrade_time;
	long unsigned int low_downgrade_time;
	unsigned int scale;
	struct latency_bucket tmp_buckets[18];
	struct avg_latency_bucket avg_buckets[18];
	struct latency_bucket *latency_buckets[2];
	long unsigned int last_calculate_time;
	long unsigned int filtered_latency;
	bool track_bio_latency;
};

typedef struct blkcg_policy_data___49 *blkcg_pol_alloc_cpd_fn___2(gfp_t);

typedef void blkcg_pol_init_cpd_fn___2(struct blkcg_policy_data___49 *);

typedef void blkcg_pol_free_cpd_fn___2(struct blkcg_policy_data___49 *);

typedef void blkcg_pol_bind_cpd_fn___2(struct blkcg_policy_data___49 *);

typedef struct blkg_policy_data___49 *blkcg_pol_alloc_pd_fn___2(gfp_t, int);

typedef void blkcg_pol_init_pd_fn___2(struct blkg_policy_data___49 *);

typedef void blkcg_pol_online_pd_fn___2(struct blkg_policy_data___49 *);

typedef void blkcg_pol_offline_pd_fn___2(struct blkg_policy_data___49 *);

typedef void blkcg_pol_free_pd_fn___2(struct blkg_policy_data___49 *);

typedef void blkcg_pol_reset_pd_stats_fn___2(struct blkg_policy_data___49 *);

typedef size_t blkcg_pol_stat_pd_fn___2(struct blkg_policy_data___49 *, char *, size_t);

struct blkcg_policy___2 {
	int plid;
	struct cftype___198 *dfl_cftypes;
	struct cftype___198 *legacy_cftypes;
	blkcg_pol_alloc_cpd_fn___2 *cpd_alloc_fn;
	blkcg_pol_init_cpd_fn___2 *cpd_init_fn;
	blkcg_pol_free_cpd_fn___2 *cpd_free_fn;
	blkcg_pol_bind_cpd_fn___2 *cpd_bind_fn;
	blkcg_pol_alloc_pd_fn___2 *pd_alloc_fn;
	blkcg_pol_init_pd_fn___2 *pd_init_fn;
	blkcg_pol_online_pd_fn___2 *pd_online_fn;
	blkcg_pol_offline_pd_fn___2 *pd_offline_fn;
	blkcg_pol_free_pd_fn___2 *pd_free_fn;
	blkcg_pol_reset_pd_stats_fn___2 *pd_reset_stats_fn;
	blkcg_pol_stat_pd_fn___2 *pd_stat_fn;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct blkg_conf_ctx___2 {
	struct gendisk___61 *disk;
	struct blkcg_gq___49 *blkg;
	char *body;
};

struct throtl_grp;

struct throtl_qnode {
	struct list_head node;
	struct bio_list___129 bios;
	struct throtl_grp *tg;
};

struct throtl_grp {
	struct blkg_policy_data___49 pd;
	struct rb_node rb_node;
	struct throtl_data *td;
	struct throtl_service_queue service_queue;
	struct throtl_qnode qnode_on_self[2];
	struct throtl_qnode qnode_on_parent[2];
	long unsigned int disptime;
	unsigned int flags;
	bool has_rules[2];
	uint64_t bps[4];
	uint64_t bps_conf[4];
	unsigned int iops[4];
	unsigned int iops_conf[4];
	uint64_t bytes_disp[2];
	unsigned int io_disp[2];
	long unsigned int last_low_overflow_time[2];
	uint64_t last_bytes_disp[2];
	unsigned int last_io_disp[2];
	long unsigned int last_check_time;
	long unsigned int latency_target;
	long unsigned int latency_target_conf;
	long unsigned int slice_start[2];
	long unsigned int slice_end[2];
	long unsigned int last_finish_time;
	long unsigned int checked_last_finish_time;
	long unsigned int avg_idletime;
	long unsigned int idletime_threshold;
	long unsigned int idletime_threshold_conf;
	unsigned int bio_cnt;
	unsigned int bad_bio_cnt;
	long unsigned int bio_cnt_reset_time;
};

enum tg_state_flags {
	THROTL_TG_PENDING = 1,
	THROTL_TG_WAS_EMPTY = 2,
};

enum {
	LIMIT_LOW = 0,
	LIMIT_MAX = 1,
	LIMIT_CNT = 2,
};

struct module___220;

struct file___272;

struct kiocb___272;

struct vm_area_struct___273;

struct inode___272;

struct file_lock___272;

struct page___273;

struct seq_file___238;

struct file_operations___272 {
	struct module___220 *owner;
	loff_t (*llseek)(struct file___272 *, loff_t, int);
	ssize_t (*read)(struct file___272 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___272 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___272 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___272 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___272 *, bool);
	int (*iterate)(struct file___272 *, struct dir_context *);
	int (*iterate_shared)(struct file___272 *, struct dir_context *);
	__poll_t (*poll)(struct file___272 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___272 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___272 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___272 *, struct vm_area_struct___273 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___272 *, struct file___272 *);
	int (*flush)(struct file___272 *, fl_owner_t);
	int (*release)(struct inode___272 *, struct file___272 *);
	int (*fsync)(struct file___272 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___272 *, int);
	int (*lock)(struct file___272 *, int, struct file_lock___272 *);
	ssize_t (*sendpage)(struct file___272 *, struct page___273 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___272 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___272 *, int, struct file_lock___272 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___272 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___272 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___272 *, long int, struct file_lock___272 **, void **);
	long int (*fallocate)(struct file___272 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___238 *, struct file___272 *);
	ssize_t (*copy_file_range)(struct file___272 *, loff_t, struct file___272 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___272 *, loff_t, struct file___272 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___272 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___272 {
	u64 seqnum;
	struct vm_area_struct___273 *vmas[4];
};

struct page_frag___272 {
	struct page___273 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___272;

struct cred___259;

struct bio_list___141;

struct backing_dev_info___141;

struct io_context___76;

struct request_queue___72;

struct vm_struct___188;

struct task_struct___273 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___273 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___272 *mm;
	struct mm_struct___272 *active_mm;
	struct vmacache___272 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___273 *real_parent;
	struct task_struct___273 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___273 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___191 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___191 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___191 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___259 *ptracer_cred;
	const struct cred___259 *real_cred;
	const struct cred___259 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___273 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___141 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___141 *backing_dev_info;
	struct io_context___76 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___272 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___72 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___273 *oom_reaper_list;
	struct vm_struct___188 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___128 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___271;

struct super_block___271;

struct dentry___272 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___272 *d_parent;
	struct qstr d_name;
	struct inode___272 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___271 *d_op;
	struct super_block___271 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct rw_semaphore___273 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___273 *owner;
};

struct address_space_operations___271;

struct address_space___271 {
	struct inode___272 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___273 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___271 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___271;

struct bdi_writeback___141;

struct block_device___271;

struct inode___272 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___271 *i_op;
	struct super_block___271 *i_sb;
	struct address_space___271 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___273 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___141 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___272 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___271 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___271 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___272;

struct dentry_operations___271 {
	int (*d_revalidate)(struct dentry___272 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___272 *, unsigned int);
	int (*d_hash)(const struct dentry___272 *, struct qstr *);
	int (*d_compare)(const struct dentry___272 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___272 *);
	int (*d_init)(struct dentry___272 *);
	void (*d_release)(struct dentry___272 *);
	void (*d_prune)(struct dentry___272 *);
	void (*d_iput)(struct dentry___272 *, struct inode___272 *);
	char * (*d_dname)(struct dentry___272 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___272 *);
	int (*d_manage)(const struct path___272 *, bool);
	struct dentry___272 * (*d_real)(struct dentry___272 *, const struct inode___272 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___271;

struct mem_dqinfo___271 {
	struct quota_format_type___271 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___271;

struct quota_info___271 {
	unsigned int flags;
	struct rw_semaphore___273 dqio_sem;
	struct inode___272 *files[3];
	struct mem_dqinfo___271 info[3];
	const struct quota_format_ops___271 *ops[3];
};

struct rcuwait___271 {
	struct task_struct___273 *task;
};

struct percpu_rw_semaphore___271 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___273 rw_sem;
	struct rcuwait___271 writer;
	int readers_block;
};

struct sb_writers___271 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___271 rw_sem[3];
};

struct file_system_type___271;

struct super_operations___271;

struct dquot_operations___271;

struct quotactl_ops___271;

struct super_block___271 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___271 *s_type;
	const struct super_operations___271 *s_op;
	const struct dquot_operations___271 *dq_op;
	const struct quotactl_ops___271 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___272 *s_root;
	struct rw_semaphore___273 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___271 *s_bdev;
	struct backing_dev_info___141 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___271 s_dquot;
	struct sb_writers___271 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___271 *s_d_op;
	int cleancache_poolid;
	struct shrinker___113 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct path___272 {
	struct vfsmount *mnt;
	struct dentry___272 *dentry;
};

typedef struct page___273 *pgtable_t___272;

struct dev_pagemap___261;

struct page___273 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___271 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___273 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___272 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___272 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___261 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___272;

struct lruvec___272 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___272 *pgdat;
};

struct zone___272 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___272 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___272 {
	struct zone___272 *zone;
	int zone_idx;
};

struct zonelist___272 {
	struct zoneref___272 _zonerefs[25];
};

struct pglist_data___272 {
	struct zone___272 node_zones[3];
	struct zonelist___272 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___273 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___273 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___272 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___273 {
	void *stack;
	struct task_struct___273 *task;
	long int status;
};

struct blocking_notifier_head___272 {
	struct rw_semaphore___273 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___261;

struct vm_area_struct___273 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___273 *vm_next;
	struct vm_area_struct___273 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___272 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___261 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___272 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___272;

struct mm_struct___272 {
	struct {
		struct vm_area_struct___273 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___272 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___273 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___272 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___273 *owner;
		struct user_namespace___3 *user_ns;
		struct file___272 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___272 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___261)(struct vm_area_struct___273 *, long unsigned int, const struct page___273 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___261)(struct page___273 *, void *);

struct device___235;

struct dev_pagemap___261 {
	dev_page_fault_t___261 page_fault;
	dev_page_free_t___261 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___235 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct file___272 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___272 f_path;
	struct inode___272 *f_inode;
	const struct file_operations___272 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___191 f_owner;
	const struct cred___259 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___271 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___261;

struct vm_operations_struct___261 {
	void (*open)(struct vm_area_struct___273 *);
	void (*close)(struct vm_area_struct___273 *);
	int (*split)(struct vm_area_struct___273 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___273 *);
	vm_fault_t (*fault)(struct vm_fault___261 *);
	vm_fault_t (*huge_fault)(struct vm_fault___261 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___261 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___273 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___261 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___261 *);
	int (*access)(struct vm_area_struct___273 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___273 *);
	int (*set_policy)(struct vm_area_struct___273 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___273 *, long unsigned int);
	struct page___273 * (*find_special_page)(struct vm_area_struct___273 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___272 {
	struct task_struct___273 *task;
	struct core_thread___272 *next;
};

struct core_state___272 {
	atomic_t nr_threads;
	struct core_thread___272 dumper;
	struct completion startup;
};

struct vm_fault___261 {
	struct vm_area_struct___273 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___273 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___273 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___272 prealloc_pte;
};

struct key___259;

struct user_struct___259 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___259 *uid_keyring;
	struct key___259 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___259 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___259 *session_keyring;
	struct key___259 *process_keyring;
	struct key___259 *thread_keyring;
	struct key___259 *request_key_auth;
	void *security;
	struct user_struct___259 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct bio___141;

struct bio_list___141 {
	struct bio___141 *head;
	struct bio___141 *tail;
};

struct bdi_writeback_congested___141;

struct bdi_writeback___141 {
	struct backing_dev_info___141 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___141 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___157 *memcg_css;
	struct cgroup_subsys_state___157 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___141 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___141 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___235 *dev;
	struct device___235 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___272 *debug_dir;
	struct dentry___272 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___76;

struct io_context___76 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___76 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

typedef blk_qc_t make_request_fn___72(struct request_queue___72 *, struct bio___141 *);

struct request___72;

typedef int dma_drain_needed_fn___72(struct request___72 *);

struct kset___259;

struct kobj_type___259;

struct kernfs_node___267;

struct kobject___260 {
	const char *name;
	struct list_head entry;
	struct kobject___260 *parent;
	struct kset___259 *kset;
	struct kobj_type___259 *ktype;
	struct kernfs_node___267 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___72;

struct bsg_class_device___72 {
	struct device___235 *class_dev;
	int minor;
	struct request_queue___72 *queue;
	const struct bsg_ops___72 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___141 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___141 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___72;

struct blk_mq_ops___14;

struct blk_mq_ctx___11;

struct blk_mq_hw_ctx___14;

struct blk_stat_callback___11;

struct blk_flush_queue___11;

struct blk_mq_tag_set___14;

struct request_queue___72 {
	struct list_head queue_head;
	struct request___72 *last_merge;
	struct elevator_queue___72 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___72 *make_request_fn;
	dma_drain_needed_fn___72 *dma_drain_needed;
	const struct blk_mq_ops___14 *mq_ops;
	struct blk_mq_ctx___11 *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___14 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___141 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___260 kobj;
	struct kobject___260 *mq_kobj;
	struct blk_integrity integrity;
	struct device___235 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback___11 *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue___11 *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	struct bsg_class_device___72 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set___14 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___141 bio_split;
	struct dentry___272 *debugfs_dir;
	struct dentry___272 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___188 {
	struct vm_struct___188 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___273 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct io_cq___76 {
	struct request_queue___72 *q;
	struct io_context___76 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___6 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___272 {
	struct file___272 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___272 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___271 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___272 *ia_file;
};

struct dquot___271 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___271 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___271 {
	int qf_fmt_id;
	const struct quota_format_ops___271 *qf_ops;
	struct module___220 *qf_owner;
	struct quota_format_type___271 *qf_next;
};

struct quota_format_ops___271 {
	int (*check_quota_file)(struct super_block___271 *, int);
	int (*read_file_info)(struct super_block___271 *, int);
	int (*write_file_info)(struct super_block___271 *, int);
	int (*free_file_info)(struct super_block___271 *, int);
	int (*read_dqblk)(struct dquot___271 *);
	int (*commit_dqblk)(struct dquot___271 *);
	int (*release_dqblk)(struct dquot___271 *);
	int (*get_next_id)(struct super_block___271 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___271 {
	int (*write_dquot)(struct dquot___271 *);
	struct dquot___271 * (*alloc_dquot)(struct super_block___271 *, int);
	void (*destroy_dquot)(struct dquot___271 *);
	int (*acquire_dquot)(struct dquot___271 *);
	int (*release_dquot)(struct dquot___271 *);
	int (*mark_dirty)(struct dquot___271 *);
	int (*write_info)(struct super_block___271 *, int);
	qsize_t * (*get_reserved_space)(struct inode___272 *);
	int (*get_projid)(struct inode___272 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___272 *, qsize_t *);
	int (*get_next_id)(struct super_block___271 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___271 {
	int (*quota_on)(struct super_block___271 *, int, int, const struct path___272 *);
	int (*quota_off)(struct super_block___271 *, int);
	int (*quota_enable)(struct super_block___271 *, unsigned int);
	int (*quota_disable)(struct super_block___271 *, unsigned int);
	int (*quota_sync)(struct super_block___271 *, int);
	int (*set_info)(struct super_block___271 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___271 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___271 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___271 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___271 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___271 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___217 {
	struct kobject___260 kobj;
	struct module___220 *mod;
	struct kobject___260 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___217 {
	struct module___220 *mod;
	struct latch_tree_node node;
};

struct module_layout___217 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___217 mtn;
};

struct module_attribute___217;

struct kernel_param___217;

struct module___220 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___217 mkobj;
	struct module_attribute___217 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___260 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___217 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___217 core_layout;
	struct module_layout___217 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide43;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide44;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___271 {
	int (*writepage)(struct page___273 *, struct writeback_control___3 *);
	int (*readpage)(struct file___272 *, struct page___273 *);
	int (*writepages)(struct address_space___271 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___273 *);
	int (*readpages)(struct file___272 *, struct address_space___271 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___272 *, struct address_space___271 *, loff_t, unsigned int, unsigned int, struct page___273 **, void **);
	int (*write_end)(struct file___272 *, struct address_space___271 *, loff_t, unsigned int, unsigned int, struct page___273 *, void *);
	sector_t (*bmap)(struct address_space___271 *, sector_t);
	void (*invalidatepage)(struct page___273 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___273 *, gfp_t);
	void (*freepage)(struct page___273 *);
	ssize_t (*direct_IO)(struct kiocb___272 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___271 *, struct page___273 *, struct page___273 *, enum migrate_mode);
	bool (*isolate_page)(struct page___273 *, isolate_mode_t);
	void (*putback_page)(struct page___273 *);
	int (*launder_page)(struct page___273 *);
	int (*is_partially_uptodate)(struct page___273 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___273 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___271 *, struct page___273 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___272 *, sector_t *);
	void (*swap_deactivate)(struct file___272 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct hd_struct___73;

struct gendisk___73;

struct block_device___271 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___272 *bd_inode;
	struct super_block___271 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___271 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___73 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___73 *bd_disk;
	struct request_queue___72 *bd_queue;
	struct backing_dev_info___141 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___235 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___235 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___235;

struct bus_type___235;

struct device_driver___235;

struct dev_pm_domain___235;

struct fwnode_handle___170;

struct class___235;

struct attribute_group___237;

struct device___235 {
	struct device___235 *parent;
	struct device_private *p;
	struct kobject___260 kobj;
	const char *init_name;
	const struct device_type___235 *type;
	struct mutex mutex;
	struct bus_type___235 *bus;
	struct device_driver___235 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___235 power;
	struct dev_pm_domain___235 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___170 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___235 *class;
	const struct attribute_group___237 **groups;
	void (*release)(struct device___235 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___73 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___235 __dev;
	struct kobject___260 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___73;

struct block_device_operations___73;

struct gendisk___73 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___73 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___73 *part_tbl;
	struct hd_struct___73 part0;
	const struct block_device_operations___73 *fops;
	struct request_queue___72 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___273 lookup_sem;
	struct kobject___260 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___260 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___271 {
	struct dentry___272 * (*lookup)(struct inode___272 *, struct dentry___272 *, unsigned int);
	const char * (*get_link)(struct dentry___272 *, struct inode___272 *, struct delayed_call *);
	int (*permission)(struct inode___272 *, int);
	struct posix_acl * (*get_acl)(struct inode___272 *, int);
	int (*readlink)(struct dentry___272 *, char *, int);
	int (*create)(struct inode___272 *, struct dentry___272 *, umode_t, bool);
	int (*link)(struct dentry___272 *, struct inode___272 *, struct dentry___272 *);
	int (*unlink)(struct inode___272 *, struct dentry___272 *);
	int (*symlink)(struct inode___272 *, struct dentry___272 *, const char *);
	int (*mkdir)(struct inode___272 *, struct dentry___272 *, umode_t);
	int (*rmdir)(struct inode___272 *, struct dentry___272 *);
	int (*mknod)(struct inode___272 *, struct dentry___272 *, umode_t, dev_t);
	int (*rename)(struct inode___272 *, struct dentry___272 *, struct inode___272 *, struct dentry___272 *, unsigned int);
	int (*setattr)(struct dentry___272 *, struct iattr___271 *);
	int (*getattr)(const struct path___272 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___272 *, char *, size_t);
	int (*fiemap)(struct inode___272 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___272 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___272 *, struct dentry___272 *, struct file___272 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___272 *, struct dentry___272 *, umode_t);
	int (*set_acl)(struct inode___272 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___271 {
	void (*fl_copy_lock)(struct file_lock___272 *, struct file_lock___272 *);
	void (*fl_release_private)(struct file_lock___272 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___271;

struct lock_manager_operations___271;

struct file_lock___272 {
	struct file_lock___272 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___272 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___271 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___271 *fl_ops;
	const struct lock_manager_operations___271 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___271 {
	int (*lm_compare_owner)(struct file_lock___272 *, struct file_lock___272 *);
	long unsigned int (*lm_owner_key)(struct file_lock___272 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___272 *);
	int (*lm_grant)(struct file_lock___272 *, int);
	bool (*lm_break)(struct file_lock___272 *);
	int (*lm_change)(struct file_lock___272 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___272 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___271 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___271 *fa_next;
	struct file___272 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___271 {
	const char *name;
	int fs_flags;
	struct dentry___272 * (*mount)(struct file_system_type___271 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___271 *);
	struct module___220 *owner;
	struct file_system_type___271 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___271 {
	struct inode___272 * (*alloc_inode)(struct super_block___271 *);
	void (*destroy_inode)(struct inode___272 *);
	void (*dirty_inode)(struct inode___272 *, int);
	int (*write_inode)(struct inode___272 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___272 *);
	void (*evict_inode)(struct inode___272 *);
	void (*put_super)(struct super_block___271 *);
	int (*sync_fs)(struct super_block___271 *, int);
	int (*freeze_super)(struct super_block___271 *);
	int (*freeze_fs)(struct super_block___271 *);
	int (*thaw_super)(struct super_block___271 *);
	int (*unfreeze_fs)(struct super_block___271 *);
	int (*statfs)(struct dentry___272 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___271 *, int *, char *);
	void (*umount_begin)(struct super_block___271 *);
	int (*show_options)(struct seq_file___238 *, struct dentry___272 *);
	int (*show_devname)(struct seq_file___238 *, struct dentry___272 *);
	int (*show_path)(struct seq_file___238 *, struct dentry___272 *);
	int (*show_stats)(struct seq_file___238 *, struct dentry___272 *);
	ssize_t (*quota_read)(struct super_block___271 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___271 *, int, const char *, size_t, loff_t);
	struct dquot___271 ** (*get_dquots)(struct inode___272 *);
	int (*bdev_try_to_free_page)(struct super_block___271 *, struct page___273 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___271 *, struct shrink_control___113 *);
	long int (*free_cached_objects)(struct super_block___271 *, struct shrink_control___113 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___237;

struct seq_file___238 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___237 *op;
	int poll_event;
	const struct file___272 *file;
	void *private;
};

typedef void bio_end_io_t___141(struct bio___141 *);

struct bio_vec___141 {
	struct page___273 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___141;

struct bio___141 {
	struct bio___141 *bi_next;
	struct gendisk___73 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___141 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___141 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___141 *bi_io_vec;
	struct bio_set___141 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___141 bi_inline_vecs[0];
};

struct bio_integrity_payload___141 {
	struct bio___141 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___141 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___141 bip_inline_vecs[0];
};

struct dev_pm_ops___235;

struct device_type___235 {
	const char *name;
	const struct attribute_group___237 **groups;
	int (*uevent)(struct device___235 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___235 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___235 *);
	const struct dev_pm_ops___235 *pm;
};

struct class___235 {
	const char *name;
	struct module___220 *owner;
	const struct attribute_group___237 **class_groups;
	const struct attribute_group___237 **dev_groups;
	struct kobject___260 *dev_kobj;
	int (*dev_uevent)(struct device___235 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___235 *, umode_t *);
	void (*class_release)(struct class___235 *);
	void (*dev_release)(struct device___235 *);
	int (*shutdown_pre)(struct device___235 *);
	const struct kobj_ns_type_operations___24 *ns_type;
	const void * (*namespace)(struct device___235 *);
	const struct dev_pm_ops___235 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct kernfs_root___266;

struct kernfs_elem_dir___266 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___266 *root;
};

struct kernfs_syscall_ops___266;

struct kernfs_root___266 {
	struct kernfs_node___267 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___266 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___266 {
	struct kernfs_node___267 *target_kn;
};

struct kernfs_ops___266;

struct kernfs_elem_attr___266 {
	const struct kernfs_ops___266 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___267 *notify_next;
};

struct kernfs_node___267 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___267 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___266 dir;
		struct kernfs_elem_symlink___266 symlink;
		struct kernfs_elem_attr___266 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___266;

struct kernfs_ops___266 {
	int (*open)(struct kernfs_open_file___266 *);
	void (*release)(struct kernfs_open_file___266 *);
	int (*seq_show)(struct seq_file___238 *, void *);
	void * (*seq_start)(struct seq_file___238 *, loff_t *);
	void * (*seq_next)(struct seq_file___238 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___238 *, void *);
	ssize_t (*read)(struct kernfs_open_file___266 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___266 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___266 *, struct vm_area_struct___273 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___266 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___266 {
	int (*remount_fs)(struct kernfs_root___266 *, int *, char *);
	int (*show_options)(struct seq_file___238 *, struct kernfs_root___266 *);
	int (*mkdir)(struct kernfs_node___267 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___267 *);
	int (*rename)(struct kernfs_node___267 *, struct kernfs_node___267 *, const char *);
	int (*show_path)(struct seq_file___238 *, struct kernfs_node___267 *, struct kernfs_root___266 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___266 {
	struct kernfs_node___267 *kn;
	struct file___272 *file;
	struct seq_file___238 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___261 *vm_ops;
};

struct bin_attribute___236;

struct attribute_group___237 {
	const char *name;
	umode_t (*is_visible)(struct kobject___260 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___260 *, struct bin_attribute___236 *, int);
	struct attribute **attrs;
	struct bin_attribute___236 **bin_attrs;
};

struct bin_attribute___236 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___272 *, struct kobject___260 *, struct bin_attribute___236 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___272 *, struct kobject___260 *, struct bin_attribute___236 *, char *, loff_t, size_t);
	int (*mmap)(struct file___272 *, struct kobject___260 *, struct bin_attribute___236 *, struct vm_area_struct___273 *);
};

struct sysfs_ops___259 {
	ssize_t (*show)(struct kobject___260 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___260 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___259;

struct kset___259 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___260 kobj;
	const struct kset_uevent_ops___259 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___259 {
	void (*release)(struct kobject___260 *);
	const struct sysfs_ops___259 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___24 * (*child_ns_type)(struct kobject___260 *);
	const void * (*namespace)(struct kobject___260 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___259 {
	int (* const filter)(struct kset___259 *, struct kobject___260 *);
	const char * (* const name)(struct kset___259 *, struct kobject___260 *);
	int (* const uevent)(struct kset___259 *, struct kobject___260 *, struct kobj_uevent_env *);
};

struct kobj_attribute___252 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___260 *, struct kobj_attribute___252 *, char *);
	ssize_t (*store)(struct kobject___260 *, struct kobj_attribute___252 *, const char *, size_t);
};

struct dev_pm_ops___235 {
	int (*prepare)(struct device___235 *);
	void (*complete)(struct device___235 *);
	int (*suspend)(struct device___235 *);
	int (*resume)(struct device___235 *);
	int (*freeze)(struct device___235 *);
	int (*thaw)(struct device___235 *);
	int (*poweroff)(struct device___235 *);
	int (*restore)(struct device___235 *);
	int (*suspend_late)(struct device___235 *);
	int (*resume_early)(struct device___235 *);
	int (*freeze_late)(struct device___235 *);
	int (*thaw_early)(struct device___235 *);
	int (*poweroff_late)(struct device___235 *);
	int (*restore_early)(struct device___235 *);
	int (*suspend_noirq)(struct device___235 *);
	int (*resume_noirq)(struct device___235 *);
	int (*freeze_noirq)(struct device___235 *);
	int (*thaw_noirq)(struct device___235 *);
	int (*poweroff_noirq)(struct device___235 *);
	int (*restore_noirq)(struct device___235 *);
	int (*runtime_suspend)(struct device___235 *);
	int (*runtime_resume)(struct device___235 *);
	int (*runtime_idle)(struct device___235 *);
};

struct dev_pm_domain___235 {
	struct dev_pm_ops___235 ops;
	void (*detach)(struct device___235 *, bool);
	int (*activate)(struct device___235 *);
	void (*sync)(struct device___235 *);
	void (*dismiss)(struct device___235 *);
};

struct bus_type___235 {
	const char *name;
	const char *dev_name;
	struct device___235 *dev_root;
	const struct attribute_group___237 **bus_groups;
	const struct attribute_group___237 **dev_groups;
	const struct attribute_group___237 **drv_groups;
	int (*match)(struct device___235 *, struct device_driver___235 *);
	int (*uevent)(struct device___235 *, struct kobj_uevent_env *);
	int (*probe)(struct device___235 *);
	int (*remove)(struct device___235 *);
	void (*shutdown)(struct device___235 *);
	int (*online)(struct device___235 *);
	int (*offline)(struct device___235 *);
	int (*suspend)(struct device___235 *, pm_message_t);
	int (*resume)(struct device___235 *);
	int (*num_vf)(struct device___235 *);
	int (*dma_configure)(struct device___235 *);
	const struct dev_pm_ops___235 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___235 {
	const char *name;
	struct bus_type___235 *bus;
	struct module___220 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___235 *);
	int (*remove)(struct device___235 *);
	void (*shutdown)(struct device___235 *);
	int (*suspend)(struct device___235 *, pm_message_t);
	int (*resume)(struct device___235 *);
	const struct attribute_group___237 **groups;
	const struct dev_pm_ops___235 *pm;
	void (*coredump)(struct device___235 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct fwnode_operations___170;

struct fwnode_handle___170 {
	struct fwnode_handle___170 *secondary;
	const struct fwnode_operations___170 *ops;
};

struct disk_part_tbl___73 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___73 *last_lookup;
	struct hd_struct___73 *part[0];
};

struct block_device_operations___73 {
	int (*open)(struct block_device___271 *, fmode_t);
	void (*release)(struct gendisk___73 *, fmode_t);
	int (*rw_page)(struct block_device___271 *, sector_t, struct page___273 *, unsigned int);
	int (*ioctl)(struct block_device___271 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___271 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___73 *, unsigned int);
	int (*media_changed)(struct gendisk___73 *);
	void (*unlock_native_capacity)(struct gendisk___73 *);
	int (*revalidate_disk)(struct gendisk___73 *);
	int (*getgeo)(struct block_device___271 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___271 *, long unsigned int);
	int (*report_zones)(struct gendisk___73 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___220 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___261(struct page___273 *);

struct bdi_writeback_congested___141 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___141 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bsg_ops___72 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___72 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___72 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___72 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___72(struct request___72 *, blk_status_t);

struct request___72 {
	struct request_queue___72 *q;
	struct blk_mq_ctx___11 *mq_ctx;
	struct blk_mq_hw_ctx___14 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___141 *bio;
	struct bio___141 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___141 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___76 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___72 *saved_end_io;
		} flush;
	};
	struct gendisk___73 *rq_disk;
	struct hd_struct___73 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___72 *end_io;
	void *end_io_data;
	struct request___72 *next_rq;
};

struct fwnode_reference_args___170;

struct fwnode_endpoint___170;

struct fwnode_operations___170 {
	struct fwnode_handle___170 * (*get)(struct fwnode_handle___170 *);
	void (*put)(struct fwnode_handle___170 *);
	bool (*device_is_available)(const struct fwnode_handle___170 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___170 *, const struct device___235 *);
	bool (*property_present)(const struct fwnode_handle___170 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___170 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___170 *, const char *, const char **, size_t);
	struct fwnode_handle___170 * (*get_parent)(const struct fwnode_handle___170 *);
	struct fwnode_handle___170 * (*get_next_child_node)(const struct fwnode_handle___170 *, struct fwnode_handle___170 *);
	struct fwnode_handle___170 * (*get_named_child_node)(const struct fwnode_handle___170 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___170 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___170 *);
	struct fwnode_handle___170 * (*graph_get_next_endpoint)(const struct fwnode_handle___170 *, struct fwnode_handle___170 *);
	struct fwnode_handle___170 * (*graph_get_remote_endpoint)(const struct fwnode_handle___170 *);
	struct fwnode_handle___170 * (*graph_get_port_parent)(struct fwnode_handle___170 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___170 *, struct fwnode_endpoint___170 *);
};

struct fwnode_endpoint___170 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___170 *local_fwnode;
};

struct fwnode_reference_args___170 {
	struct fwnode_handle___170 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct blk_mq_ctxs___11;

struct blk_mq_ctx___11 {
	struct {
		spinlock_t lock;
		struct list_head rq_lists[3];
		long: 64;
	};
	unsigned int cpu;
	short unsigned int index_hw[3];
	struct blk_mq_hw_ctx___14 *hctxs[3];
	long unsigned int rq_dispatched[2];
	long unsigned int rq_merged;
	long unsigned int rq_completed[2];
	struct request_queue___72 *queue;
	struct blk_mq_ctxs___11 *ctxs;
	struct kobject___260 kobj;
};

struct blk_mq_tags___11;

struct blk_mq_hw_ctx___14 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___72 *queue;
	struct blk_flush_queue___11 *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx___11 *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx___11 **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags___11 *tags;
	struct blk_mq_tags___11 *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	unsigned int rh_reserved_nr_expired;
	struct hlist_node cpuhp_dead;
	struct kobject___260 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___272 *debugfs_dir;
	struct dentry___272 *sched_debugfs_dir;
	struct list_head hctx_list;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___72;

struct blk_mq_alloc_data___11;

struct elevator_mq_ops___72 {
	int (*init_sched)(struct request_queue___72 *, struct elevator_type___72 *);
	void (*exit_sched)(struct elevator_queue___72 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___14 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___14 *, unsigned int);
	bool (*allow_merge)(struct request_queue___72 *, struct request___72 *, struct bio___141 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx___14 *, struct bio___141 *);
	int (*request_merge)(struct request_queue___72 *, struct request___72 **, struct bio___141 *);
	void (*request_merged)(struct request_queue___72 *, struct request___72 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___72 *, struct request___72 *, struct request___72 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data___11 *);
	void (*prepare_request)(struct request___72 *, struct bio___141 *);
	void (*finish_request)(struct request___72 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___14 *, struct list_head *, bool);
	struct request___72 * (*dispatch_request)(struct blk_mq_hw_ctx___14 *);
	bool (*has_work)(struct blk_mq_hw_ctx___14 *);
	void (*completed_request)(struct request___72 *, u64);
	void (*started_request)(struct request___72 *);
	void (*requeue_request)(struct request___72 *);
	struct request___72 * (*former_request)(struct request_queue___72 *, struct request___72 *);
	struct request___72 * (*next_request)(struct request_queue___72 *, struct request___72 *);
	void (*init_icq)(struct io_cq___76 *);
	void (*exit_icq)(struct io_cq___76 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx___14 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___72;

struct blk_mq_debugfs_attr___4;

struct elevator_type___72 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___72 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___72 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___220 *elevator_owner;
	const struct blk_mq_debugfs_attr___4 *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr___4 *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___72 {
	struct elevator_type___72 *type;
	void *elevator_data;
	struct kobject___260 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct blk_mq_alloc_data___11 {
	struct request_queue___72 *q;
	blk_mq_req_flags_t flags;
	unsigned int shallow_depth;
	unsigned int cmd_flags;
	struct blk_mq_ctx___11 *ctx;
	struct blk_mq_hw_ctx___14 *hctx;
};

struct elv_fs_entry___72 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___72 *, char *);
	ssize_t (*store)(struct elevator_queue___72 *, const char *, size_t);
};

struct blk_mq_debugfs_attr___4 {
	const char *name;
	umode_t mode;
	int (*show)(void *, struct seq_file___238 *);
	ssize_t (*write)(void *, const char *, size_t, loff_t *);
	const struct seq_operations___237 *seq_ops;
};

struct blk_mq_queue_data___14;

typedef blk_status_t queue_rq_fn___14(struct blk_mq_hw_ctx___14 *, const struct blk_mq_queue_data___14 *);

typedef void commit_rqs_fn___14(struct blk_mq_hw_ctx___14 *);

typedef bool get_budget_fn___14(struct blk_mq_hw_ctx___14 *);

typedef void put_budget_fn___14(struct blk_mq_hw_ctx___14 *);

typedef enum blk_eh_timer_return timeout_fn___14(struct request___72 *, bool);

typedef int poll_fn___14(struct blk_mq_hw_ctx___14 *);

typedef void complete_fn___14(struct request___72 *);

typedef int init_hctx_fn___14(struct blk_mq_hw_ctx___14 *, void *, unsigned int);

typedef void exit_hctx_fn___14(struct blk_mq_hw_ctx___14 *, unsigned int);

typedef int init_request_fn___14(struct blk_mq_tag_set___14 *, struct request___72 *, unsigned int, unsigned int);

typedef void exit_request_fn___14(struct blk_mq_tag_set___14 *, struct request___72 *, unsigned int);

typedef bool busy_fn___14(struct request_queue___72 *);

typedef int map_queues_fn___14(struct blk_mq_tag_set___14 *);

typedef void cleanup_rq_fn___14(struct request___72 *);

struct blk_mq_ops___14 {
	queue_rq_fn___14 *queue_rq;
	commit_rqs_fn___14 *commit_rqs;
	get_budget_fn___14 *get_budget;
	put_budget_fn___14 *put_budget;
	timeout_fn___14 *timeout;
	poll_fn___14 *poll;
	complete_fn___14 *complete;
	init_hctx_fn___14 *init_hctx;
	exit_hctx_fn___14 *exit_hctx;
	init_request_fn___14 *init_request;
	exit_request_fn___14 *exit_request;
	void (*initialize_rq_fn)(struct request___72 *);
	busy_fn___14 *busy;
	map_queues_fn___14 *map_queues;
	void (*show_rq)(struct seq_file___238 *, struct request___72 *);
	union {
		cleanup_rq_fn___14 *cleanup_rq;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide42;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct blk_stat_callback___11 {
	struct list_head list;
	struct timer_list timer;
	struct blk_rq_stat *cpu_stat;
	int (*bucket_fn)(const struct request___72 *);
	unsigned int buckets;
	struct blk_rq_stat *stat;
	void (*timer_fn)(struct blk_stat_callback___11 *);
	void *data;
	struct callback_head rcu;
};

struct blk_flush_queue___11 {
	unsigned int flush_queue_delayed: 1;
	unsigned int flush_pending_idx: 1;
	unsigned int flush_running_idx: 1;
	long unsigned int flush_pending_since;
	struct list_head flush_queue[2];
	struct list_head flush_data_in_flight;
	struct request___72 *flush_rq;
	struct request___72 *orig_rq;
	spinlock_t mq_flush_lock;
};

struct blk_mq_tag_set___14 {
	struct blk_mq_queue_map map[6];
	unsigned int nr_maps;
	const struct blk_mq_ops___14 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	struct blk_mq_tags___11 **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct blk_mq_tags___11 {
	unsigned int nr_tags;
	unsigned int nr_reserved_tags;
	atomic_t active_queues;
	struct sbitmap_queue bitmap_tags;
	struct sbitmap_queue breserved_tags;
	struct request___72 **rqs;
	struct request___72 **static_rqs;
	struct list_head page_list;
};

struct blk_mq_queue_data___14 {
	struct request___72 *rq;
	bool last;
	long unsigned int rh_reserved1;
};

struct kernel_param_ops___217 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___217 *);
	int (*get)(char *, const struct kernel_param___217 *);
	void (*free)(void *);
};

struct kparam_array___217;

struct kernel_param___217 {
	const char *name;
	struct module___220 *mod;
	const struct kernel_param_ops___217 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___217 *arr;
	};
};

struct kparam_array___217 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___217 *ops;
	void *elem;
};

struct module_attribute___217 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___217 *, struct module_kobject___217 *, char *);
	ssize_t (*store)(struct module_attribute___217 *, struct module_kobject___217 *, const char *, size_t);
	void (*setup)(struct module___220 *, const char *);
	int (*test)(struct module___220 *);
	void (*free)(struct module___220 *);
};

struct blk_mq_ctxs___11 {
	struct kobject___260 kobj;
	struct blk_mq_ctx___11 *queue_ctx;
};

typedef int (*key_restrict_link_func_t___260)(struct key___259 *, const struct key_type *, const union key_payload *, struct key___259 *);

struct key_restriction___259;

struct key___259 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___273 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key___6 index_key;
		struct {
			struct key_type___6 *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___259 *restrict_link;
};

struct key_restriction___259 {
	key_restrict_link_func_t___260 check;
	struct key___259 *key;
	struct key_type *keytype;
};

struct seq_operations___237 {
	void * (*start)(struct seq_file___238 *, loff_t *);
	void (*stop)(struct seq_file___238 *, void *);
	void * (*next)(struct seq_file___238 *, void *, loff_t *);
	int (*show)(struct seq_file___238 *, void *);
};

struct deadline_data {
	struct rb_root sort_list[2];
	struct list_head fifo_list[2];
	struct request___72 *next_rq[2];
	unsigned int batching;
	unsigned int starved;
	int fifo_expire[2];
	int fifo_batch;
	int writes_starved;
	int front_merges;
	spinlock_t lock;
	spinlock_t zone_lock;
	struct list_head dispatch;
};

struct module___221;

struct file___273;

struct kiocb___273;

struct iov_iter___132;

struct poll_table_struct___167;

struct vm_area_struct___274;

struct inode___273;

struct file_lock___273;

struct page___274;

struct seq_file___239;

struct file_operations___273 {
	struct module___221 *owner;
	loff_t (*llseek)(struct file___273 *, loff_t, int);
	ssize_t (*read)(struct file___273 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___273 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___273 *, struct iov_iter___132 *);
	ssize_t (*write_iter)(struct kiocb___273 *, struct iov_iter___132 *);
	int (*iopoll)(struct kiocb___273 *, bool);
	int (*iterate)(struct file___273 *, struct dir_context *);
	int (*iterate_shared)(struct file___273 *, struct dir_context *);
	__poll_t (*poll)(struct file___273 *, struct poll_table_struct___167 *);
	long int (*unlocked_ioctl)(struct file___273 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___273 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___273 *, struct vm_area_struct___274 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___273 *, struct file___273 *);
	int (*flush)(struct file___273 *, fl_owner_t);
	int (*release)(struct inode___273 *, struct file___273 *);
	int (*fsync)(struct file___273 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___273 *, int);
	int (*lock)(struct file___273 *, int, struct file_lock___273 *);
	ssize_t (*sendpage)(struct file___273 *, struct page___274 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___273 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___273 *, int, struct file_lock___273 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___273 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___273 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___273 *, long int, struct file_lock___273 **, void **);
	long int (*fallocate)(struct file___273 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___239 *, struct file___273 *);
	ssize_t (*copy_file_range)(struct file___273 *, loff_t, struct file___273 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___273 *, loff_t, struct file___273 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___273 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___273 {
	u64 seqnum;
	struct vm_area_struct___274 *vmas[4];
};

struct page_frag___273 {
	struct page___274 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___129;

struct debug_info___129 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___129 *hbp_break[16];
	struct perf_event___129 *hbp_watch[16];
};

struct thread_struct___129 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___129 debug;
	long: 64;
};

struct mm_struct___273;

struct pid___192;

struct cred___260;

struct nsproxy___237;

struct signal_struct___216;

struct bio_list___142;

struct backing_dev_info___142;

struct io_context___77;

struct css_set___202;

struct perf_event_context___129;

struct request_queue___73;

struct vm_struct___189;

struct task_struct___274 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___274 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___273 *mm;
	struct mm_struct___273 *active_mm;
	struct vmacache___273 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___274 *real_parent;
	struct task_struct___274 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___274 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___192 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___192 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___192 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___260 *ptracer_cred;
	const struct cred___260 *real_cred;
	const struct cred___260 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___237 *nsproxy;
	struct signal_struct___216 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___274 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___142 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___142 *backing_dev_info;
	struct io_context___77 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___202 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___129 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___273 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___73 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___274 *oom_reaper_list;
	struct vm_struct___189 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___129 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___129 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___274 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___129)(struct perf_event___129 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___129;

struct fasync_struct___272;

struct pid_namespace___192;

struct trace_event_call___122;

struct perf_cgroup___129;

struct perf_event___129 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___129 *group_leader;
	struct pmu___129 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___129 hw;
	struct perf_event_context___129 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___129 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___274 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___272 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___129 *);
	struct callback_head callback_head;
	struct pid_namespace___192 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___129 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___129 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___122 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___129 *cgrp;
	struct list_head sb_list;
};

struct upid___192 {
	int nr;
	struct pid_namespace___192 *ns;
};

struct dentry___273;

struct user_namespace___217;

struct ucounts___217;

struct pid_namespace___192 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___274 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___192 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___273 *proc_self;
	struct dentry___273 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___217 *user_ns;
	struct ucounts___217 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___28 ns;
};

struct pid___192 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___192 numbers[1];
};

struct rw_semaphore___274 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___274 *owner;
};

struct key___260;

struct user_namespace___217 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___217 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___28 ns;
	long unsigned int flags;
	struct key___260 *persistent_keyring_register;
	struct rw_semaphore___274 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___217 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct secondary_data___274 {
	void *stack;
	struct task_struct___274 *task;
	long int status;
};

typedef struct page___274 *pgtable_t___273;

struct address_space___272;

struct dev_pagemap___262;

struct page___274 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___272 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___274 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___273 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___273 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___262 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct user_struct___260 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___260 *uid_keyring;
	struct key___260 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___262;

struct vm_area_struct___274 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___274 *vm_next;
	struct vm_area_struct___274 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___273 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___262 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___273 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___273;

struct mm_struct___273 {
	struct {
		struct vm_area_struct___274 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___273 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___274 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___273 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___274 *owner;
		struct user_namespace___217 *user_ns;
		struct file___273 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___273 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___260 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___260 *session_keyring;
	struct key___260 *process_keyring;
	struct key___260 *thread_keyring;
	struct key___260 *request_key_auth;
	void *security;
	struct user_struct___260 *user;
	struct user_namespace___217 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___202;

struct nsproxy___237 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___192 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___202 *cgroup_ns;
};

struct signal_struct___216 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___274 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___274 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___192 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___192 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___273 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___192 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide47;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___142;

struct bio_list___142 {
	struct bio___142 *head;
	struct bio___142 *tail;
};

struct bdi_writeback_congested___142;

struct cgroup_subsys_state___202;

struct bdi_writeback___142 {
	struct backing_dev_info___142 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___142 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___202 *memcg_css;
	struct cgroup_subsys_state___202 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___236;

struct backing_dev_info___142 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___142 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___236 *dev;
	struct device___236 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___273 *debug_dir;
	struct dentry___273 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___77;

struct io_context___77 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___77 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___202;

struct css_set___202 {
	struct cgroup_subsys_state___202 *subsys[13];
	refcount_t refcount;
	struct css_set___202 *dom_cset;
	struct cgroup___202 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___202 *mg_src_cgrp;
	struct cgroup___202 *mg_dst_cgrp;
	struct css_set___202 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___129 {
	struct pmu___129 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___274 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___129 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

typedef blk_qc_t make_request_fn___73(struct request_queue___73 *, struct bio___142 *);

struct request___73;

typedef int dma_drain_needed_fn___73(struct request___73 *);

struct kset___260;

struct kobj_type___260;

struct kernfs_node___268;

struct kobject___261 {
	const char *name;
	struct list_head entry;
	struct kobject___261 *parent;
	struct kset___260 *kset;
	struct kobj_type___260 *ktype;
	struct kernfs_node___268 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___73;

struct bsg_class_device___73 {
	struct device___236 *class_dev;
	int minor;
	struct request_queue___73 *queue;
	const struct bsg_ops___73 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___142 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___142 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___73;

struct blk_mq_ops___15;

struct blk_mq_ctx___12;

struct blk_mq_hw_ctx___15;

struct blk_stat_callback___12;

struct blk_flush_queue___12;

struct blk_mq_tag_set___15;

struct request_queue___73 {
	struct list_head queue_head;
	struct request___73 *last_merge;
	struct elevator_queue___73 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___73 *make_request_fn;
	dma_drain_needed_fn___73 *dma_drain_needed;
	const struct blk_mq_ops___15 *mq_ops;
	struct blk_mq_ctx___12 *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___15 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___142 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___261 kobj;
	struct kobject___261 *mq_kobj;
	struct blk_integrity integrity;
	struct device___236 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback___12 *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue___12 *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	struct bsg_class_device___73 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set___15 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___142 bio_split;
	struct dentry___273 *debugfs_dir;
	struct dentry___273 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___189 {
	struct vm_struct___189 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___274 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___228 {
	struct task_struct___274 task;
	long unsigned int stack[8192];
};

struct pglist_data___273;

struct lruvec___273 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___273 *pgdat;
};

struct zone___273 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___273 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___273 {
	struct zone___273 *zone;
	int zone_idx;
};

struct zonelist___273 {
	struct zoneref___273 _zonerefs[25];
};

struct pglist_data___273 {
	struct zone___273 node_zones[3];
	struct zonelist___273 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___274 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___274 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___273 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___273 {
	struct rw_semaphore___274 rwsem;
	struct notifier_block *head;
};

struct bio_vec___142 {
	struct page___274 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

typedef void bio_end_io_t___142(struct bio___142 *);

struct gendisk___74;

struct bio_integrity_payload___142;

struct bio___142 {
	struct bio___142 *bi_next;
	struct gendisk___74 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___142 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___142 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___142 *bi_io_vec;
	struct bio_set___142 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___142 bi_inline_vecs[0];
};

struct bio_integrity_payload___142 {
	struct bio___142 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___142 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___142 bip_inline_vecs[0];
};

struct dev_pm_info___236 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___236 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___236;

struct bus_type___236;

struct device_driver___236;

struct dev_pm_domain___236;

struct fwnode_handle___171;

struct class___236;

struct attribute_group___238;

struct device___236 {
	struct device___236 *parent;
	struct device_private *p;
	struct kobject___261 kobj;
	const char *init_name;
	const struct device_type___236 *type;
	struct mutex mutex;
	struct bus_type___236 *bus;
	struct device_driver___236 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___236 power;
	struct dev_pm_domain___236 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___171 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___236 *class;
	const struct attribute_group___238 **groups;
	void (*release)(struct device___236 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___74 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___236 __dev;
	struct kobject___261 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___74;

struct block_device_operations___74;

struct gendisk___74 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___74 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___74 *part_tbl;
	struct hd_struct___74 part0;
	const struct block_device_operations___74 *fops;
	struct request_queue___73 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___274 lookup_sem;
	struct kobject___261 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___261 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_ops___236;

struct device_type___236 {
	const char *name;
	const struct attribute_group___238 **groups;
	int (*uevent)(struct device___236 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___236 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___236 *);
	const struct dev_pm_ops___236 *pm;
};

struct class___236 {
	const char *name;
	struct module___221 *owner;
	const struct attribute_group___238 **class_groups;
	const struct attribute_group___238 **dev_groups;
	struct kobject___261 *dev_kobj;
	int (*dev_uevent)(struct device___236 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___236 *, umode_t *);
	void (*class_release)(struct class___236 *);
	void (*dev_release)(struct device___236 *);
	int (*shutdown_pre)(struct device___236 *);
	const struct kobj_ns_type_operations___24 *ns_type;
	const void * (*namespace)(struct device___236 *);
	const struct dev_pm_ops___236 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct kernfs_root___267;

struct kernfs_elem_dir___267 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___267 *root;
};

struct kernfs_syscall_ops___267;

struct kernfs_root___267 {
	struct kernfs_node___268 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___267 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___267 {
	struct kernfs_node___268 *target_kn;
};

struct kernfs_ops___267;

struct kernfs_elem_attr___267 {
	const struct kernfs_ops___267 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___268 *notify_next;
};

struct kernfs_node___268 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___268 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___267 dir;
		struct kernfs_elem_symlink___267 symlink;
		struct kernfs_elem_attr___267 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___267;

struct kernfs_ops___267 {
	int (*open)(struct kernfs_open_file___267 *);
	void (*release)(struct kernfs_open_file___267 *);
	int (*seq_show)(struct seq_file___239 *, void *);
	void * (*seq_start)(struct seq_file___239 *, loff_t *);
	void * (*seq_next)(struct seq_file___239 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___239 *, void *);
	ssize_t (*read)(struct kernfs_open_file___267 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___267 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___267 *, struct vm_area_struct___274 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___267 *, struct poll_table_struct___167 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___267 {
	int (*remount_fs)(struct kernfs_root___267 *, int *, char *);
	int (*show_options)(struct seq_file___239 *, struct kernfs_root___267 *);
	int (*mkdir)(struct kernfs_node___268 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___268 *);
	int (*rename)(struct kernfs_node___268 *, struct kernfs_node___268 *, const char *);
	int (*show_path)(struct seq_file___239 *, struct kernfs_node___268 *, struct kernfs_root___267 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___238;

struct seq_file___239 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___238 *op;
	int poll_event;
	const struct file___273 *file;
	void *private;
};

struct kernfs_open_file___267 {
	struct kernfs_node___268 *kn;
	struct file___273 *file;
	struct seq_file___239 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___262 *vm_ops;
};

struct path___273 {
	struct vfsmount *mnt;
	struct dentry___273 *dentry;
};

struct fown_struct___192 {
	rwlock_t lock;
	struct pid___192 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___273 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___273 f_path;
	struct inode___273 *f_inode;
	const struct file_operations___273 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___192 f_owner;
	const struct cred___260 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___272 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___262;

struct vm_operations_struct___262 {
	void (*open)(struct vm_area_struct___274 *);
	void (*close)(struct vm_area_struct___274 *);
	int (*split)(struct vm_area_struct___274 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___274 *);
	vm_fault_t (*fault)(struct vm_fault___262 *);
	vm_fault_t (*huge_fault)(struct vm_fault___262 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___262 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___274 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___262 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___262 *);
	int (*access)(struct vm_area_struct___274 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___274 *);
	int (*set_policy)(struct vm_area_struct___274 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___274 *, long unsigned int);
	struct page___274 * (*find_special_page)(struct vm_area_struct___274 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___169)(struct file___273 *, wait_queue_head_t *, struct poll_table_struct___167 *);

struct poll_table_struct___167 {
	poll_queue_proc___169 _qproc;
	__poll_t _key;
};

struct bin_attribute___237;

struct attribute_group___238 {
	const char *name;
	umode_t (*is_visible)(struct kobject___261 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___261 *, struct bin_attribute___237 *, int);
	struct attribute **attrs;
	struct bin_attribute___237 **bin_attrs;
};

struct bin_attribute___237 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___273 *, struct kobject___261 *, struct bin_attribute___237 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___273 *, struct kobject___261 *, struct bin_attribute___237 *, char *, loff_t, size_t);
	int (*mmap)(struct file___273 *, struct kobject___261 *, struct bin_attribute___237 *, struct vm_area_struct___274 *);
};

struct sysfs_ops___260 {
	ssize_t (*show)(struct kobject___261 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___261 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___260;

struct kset___260 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___261 kobj;
	const struct kset_uevent_ops___260 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___260 {
	void (*release)(struct kobject___261 *);
	const struct sysfs_ops___260 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___24 * (*child_ns_type)(struct kobject___261 *);
	const void * (*namespace)(struct kobject___261 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___260 {
	int (* const filter)(struct kset___260 *, struct kobject___261 *);
	const char * (* const name)(struct kset___260 *, struct kobject___261 *);
	int (* const uevent)(struct kset___260 *, struct kobject___261 *, struct kobj_uevent_env *);
};

struct kobj_attribute___253 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___261 *, struct kobj_attribute___253 *, char *);
	ssize_t (*store)(struct kobject___261 *, struct kobj_attribute___253 *, const char *, size_t);
};

struct dev_pm_ops___236 {
	int (*prepare)(struct device___236 *);
	void (*complete)(struct device___236 *);
	int (*suspend)(struct device___236 *);
	int (*resume)(struct device___236 *);
	int (*freeze)(struct device___236 *);
	int (*thaw)(struct device___236 *);
	int (*poweroff)(struct device___236 *);
	int (*restore)(struct device___236 *);
	int (*suspend_late)(struct device___236 *);
	int (*resume_early)(struct device___236 *);
	int (*freeze_late)(struct device___236 *);
	int (*thaw_early)(struct device___236 *);
	int (*poweroff_late)(struct device___236 *);
	int (*restore_early)(struct device___236 *);
	int (*suspend_noirq)(struct device___236 *);
	int (*resume_noirq)(struct device___236 *);
	int (*freeze_noirq)(struct device___236 *);
	int (*thaw_noirq)(struct device___236 *);
	int (*poweroff_noirq)(struct device___236 *);
	int (*restore_noirq)(struct device___236 *);
	int (*runtime_suspend)(struct device___236 *);
	int (*runtime_resume)(struct device___236 *);
	int (*runtime_idle)(struct device___236 *);
};

struct dev_pm_domain___236 {
	struct dev_pm_ops___236 ops;
	void (*detach)(struct device___236 *, bool);
	int (*activate)(struct device___236 *);
	void (*sync)(struct device___236 *);
	void (*dismiss)(struct device___236 *);
};

struct bus_type___236 {
	const char *name;
	const char *dev_name;
	struct device___236 *dev_root;
	const struct attribute_group___238 **bus_groups;
	const struct attribute_group___238 **dev_groups;
	const struct attribute_group___238 **drv_groups;
	int (*match)(struct device___236 *, struct device_driver___236 *);
	int (*uevent)(struct device___236 *, struct kobj_uevent_env *);
	int (*probe)(struct device___236 *);
	int (*remove)(struct device___236 *);
	void (*shutdown)(struct device___236 *);
	int (*online)(struct device___236 *);
	int (*offline)(struct device___236 *);
	int (*suspend)(struct device___236 *, pm_message_t);
	int (*resume)(struct device___236 *);
	int (*num_vf)(struct device___236 *);
	int (*dma_configure)(struct device___236 *);
	const struct dev_pm_ops___236 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___236 {
	const char *name;
	struct bus_type___236 *bus;
	struct module___221 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___236 *);
	int (*remove)(struct device___236 *);
	void (*shutdown)(struct device___236 *);
	int (*suspend)(struct device___236 *, pm_message_t);
	int (*resume)(struct device___236 *);
	const struct attribute_group___238 **groups;
	const struct dev_pm_ops___236 *pm;
	void (*coredump)(struct device___236 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct module_kobject___218 {
	struct kobject___261 kobj;
	struct module___221 *mod;
	struct kobject___261 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___218 {
	struct module___221 *mod;
	struct latch_tree_node node;
};

struct module_layout___218 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___218 mtn;
};

struct module_attribute___218;

struct kernel_param___218;

struct module___221 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___218 mkobj;
	struct module_attribute___218 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___261 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___218 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___218 core_layout;
	struct module_layout___218 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___122 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide43;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide44;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_operations___171;

struct fwnode_handle___171 {
	struct fwnode_handle___171 *secondary;
	const struct fwnode_operations___171 *ops;
};

struct dentry_operations___272;

struct super_block___272;

struct dentry___273 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___273 *d_parent;
	struct qstr d_name;
	struct inode___273 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___272 *d_op;
	struct super_block___272 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___272;

struct address_space___272 {
	struct inode___273 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___274 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___272 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___272;

struct block_device___272;

struct inode___273 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___272 *i_op;
	struct super_block___272 *i_sb;
	struct address_space___272 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___274 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___142 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___273 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___272 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___272 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___272 {
	int (*d_revalidate)(struct dentry___273 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___273 *, unsigned int);
	int (*d_hash)(const struct dentry___273 *, struct qstr *);
	int (*d_compare)(const struct dentry___273 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___273 *);
	int (*d_init)(struct dentry___273 *);
	void (*d_release)(struct dentry___273 *);
	void (*d_prune)(struct dentry___273 *);
	void (*d_iput)(struct dentry___273 *, struct inode___273 *);
	char * (*d_dname)(struct dentry___273 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___273 *);
	int (*d_manage)(const struct path___273 *, bool);
	struct dentry___273 * (*d_real)(struct dentry___273 *, const struct inode___273 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___272;

struct mem_dqinfo___272 {
	struct quota_format_type___272 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___272;

struct quota_info___272 {
	unsigned int flags;
	struct rw_semaphore___274 dqio_sem;
	struct inode___273 *files[3];
	struct mem_dqinfo___272 info[3];
	const struct quota_format_ops___272 *ops[3];
};

struct rcuwait___272 {
	struct task_struct___274 *task;
};

struct percpu_rw_semaphore___272 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___274 rw_sem;
	struct rcuwait___272 writer;
	int readers_block;
};

struct sb_writers___272 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___272 rw_sem[3];
};

struct file_system_type___272;

struct super_operations___272;

struct dquot_operations___272;

struct quotactl_ops___272;

struct super_block___272 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___272 *s_type;
	const struct super_operations___272 *s_op;
	const struct dquot_operations___272 *dq_op;
	const struct quotactl_ops___272 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___273 *s_root;
	struct rw_semaphore___274 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___272 *s_bdev;
	struct backing_dev_info___142 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___272 s_dquot;
	struct sb_writers___272 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___272 *s_d_op;
	int cleancache_poolid;
	struct shrinker___113 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___217 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

typedef int (*dev_page_fault_t___262)(struct vm_area_struct___274 *, long unsigned int, const struct page___274 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___262)(struct page___274 *, void *);

struct dev_pagemap___262 {
	dev_page_fault_t___262 page_fault;
	dev_page_free_t___262 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___236 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___273 {
	struct task_struct___274 *task;
	struct core_thread___273 *next;
};

struct core_state___273 {
	atomic_t nr_threads;
	struct core_thread___273 dumper;
	struct completion startup;
};

struct vm_fault___262 {
	struct vm_area_struct___274 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___274 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___274 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___273 prealloc_pte;
};

struct io_cq___77 {
	struct request_queue___73 *q;
	struct io_context___77 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___6 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___273 {
	struct file___273 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___273 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___272 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___273 *ia_file;
};

struct dquot___272 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___272 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___272 {
	int qf_fmt_id;
	const struct quota_format_ops___272 *qf_ops;
	struct module___221 *qf_owner;
	struct quota_format_type___272 *qf_next;
};

struct quota_format_ops___272 {
	int (*check_quota_file)(struct super_block___272 *, int);
	int (*read_file_info)(struct super_block___272 *, int);
	int (*write_file_info)(struct super_block___272 *, int);
	int (*free_file_info)(struct super_block___272 *, int);
	int (*read_dqblk)(struct dquot___272 *);
	int (*commit_dqblk)(struct dquot___272 *);
	int (*release_dqblk)(struct dquot___272 *);
	int (*get_next_id)(struct super_block___272 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___272 {
	int (*write_dquot)(struct dquot___272 *);
	struct dquot___272 * (*alloc_dquot)(struct super_block___272 *, int);
	void (*destroy_dquot)(struct dquot___272 *);
	int (*acquire_dquot)(struct dquot___272 *);
	int (*release_dquot)(struct dquot___272 *);
	int (*mark_dirty)(struct dquot___272 *);
	int (*write_info)(struct super_block___272 *, int);
	qsize_t * (*get_reserved_space)(struct inode___273 *);
	int (*get_projid)(struct inode___273 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___273 *, qsize_t *);
	int (*get_next_id)(struct super_block___272 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___272 {
	int (*quota_on)(struct super_block___272 *, int, int, const struct path___273 *);
	int (*quota_off)(struct super_block___272 *, int);
	int (*quota_enable)(struct super_block___272 *, unsigned int);
	int (*quota_disable)(struct super_block___272 *, unsigned int);
	int (*quota_sync)(struct super_block___272 *, int);
	int (*set_info)(struct super_block___272 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___272 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___272 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___272 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___272 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___272 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___272 {
	int (*writepage)(struct page___274 *, struct writeback_control___3 *);
	int (*readpage)(struct file___273 *, struct page___274 *);
	int (*writepages)(struct address_space___272 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___274 *);
	int (*readpages)(struct file___273 *, struct address_space___272 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___273 *, struct address_space___272 *, loff_t, unsigned int, unsigned int, struct page___274 **, void **);
	int (*write_end)(struct file___273 *, struct address_space___272 *, loff_t, unsigned int, unsigned int, struct page___274 *, void *);
	sector_t (*bmap)(struct address_space___272 *, sector_t);
	void (*invalidatepage)(struct page___274 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___274 *, gfp_t);
	void (*freepage)(struct page___274 *);
	ssize_t (*direct_IO)(struct kiocb___273 *, struct iov_iter___132 *);
	int (*migratepage)(struct address_space___272 *, struct page___274 *, struct page___274 *, enum migrate_mode);
	bool (*isolate_page)(struct page___274 *, isolate_mode_t);
	void (*putback_page)(struct page___274 *);
	int (*launder_page)(struct page___274 *);
	int (*is_partially_uptodate)(struct page___274 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___274 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___272 *, struct page___274 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___273 *, sector_t *);
	void (*swap_deactivate)(struct file___273 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct iov_iter___132 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___142 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___272 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___273 *bd_inode;
	struct super_block___272 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___272 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___74 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___74 *bd_disk;
	struct request_queue___73 *bd_queue;
	struct backing_dev_info___142 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___272 {
	struct dentry___273 * (*lookup)(struct inode___273 *, struct dentry___273 *, unsigned int);
	const char * (*get_link)(struct dentry___273 *, struct inode___273 *, struct delayed_call *);
	int (*permission)(struct inode___273 *, int);
	struct posix_acl * (*get_acl)(struct inode___273 *, int);
	int (*readlink)(struct dentry___273 *, char *, int);
	int (*create)(struct inode___273 *, struct dentry___273 *, umode_t, bool);
	int (*link)(struct dentry___273 *, struct inode___273 *, struct dentry___273 *);
	int (*unlink)(struct inode___273 *, struct dentry___273 *);
	int (*symlink)(struct inode___273 *, struct dentry___273 *, const char *);
	int (*mkdir)(struct inode___273 *, struct dentry___273 *, umode_t);
	int (*rmdir)(struct inode___273 *, struct dentry___273 *);
	int (*mknod)(struct inode___273 *, struct dentry___273 *, umode_t, dev_t);
	int (*rename)(struct inode___273 *, struct dentry___273 *, struct inode___273 *, struct dentry___273 *, unsigned int);
	int (*setattr)(struct dentry___273 *, struct iattr___272 *);
	int (*getattr)(const struct path___273 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___273 *, char *, size_t);
	int (*fiemap)(struct inode___273 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___273 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___273 *, struct dentry___273 *, struct file___273 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___273 *, struct dentry___273 *, umode_t);
	int (*set_acl)(struct inode___273 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___272 {
	void (*fl_copy_lock)(struct file_lock___273 *, struct file_lock___273 *);
	void (*fl_release_private)(struct file_lock___273 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___272;

struct file_lock___273 {
	struct file_lock___273 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___273 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___272 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___272 *fl_ops;
	const struct lock_manager_operations___272 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___272 {
	int (*lm_compare_owner)(struct file_lock___273 *, struct file_lock___273 *);
	long unsigned int (*lm_owner_key)(struct file_lock___273 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___273 *);
	int (*lm_grant)(struct file_lock___273 *, int);
	bool (*lm_break)(struct file_lock___273 *);
	int (*lm_change)(struct file_lock___273 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___273 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___272 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___272 *fa_next;
	struct file___273 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___272 {
	const char *name;
	int fs_flags;
	struct dentry___273 * (*mount)(struct file_system_type___272 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___272 *);
	struct module___221 *owner;
	struct file_system_type___272 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___272 {
	struct inode___273 * (*alloc_inode)(struct super_block___272 *);
	void (*destroy_inode)(struct inode___273 *);
	void (*dirty_inode)(struct inode___273 *, int);
	int (*write_inode)(struct inode___273 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___273 *);
	void (*evict_inode)(struct inode___273 *);
	void (*put_super)(struct super_block___272 *);
	int (*sync_fs)(struct super_block___272 *, int);
	int (*freeze_super)(struct super_block___272 *);
	int (*freeze_fs)(struct super_block___272 *);
	int (*thaw_super)(struct super_block___272 *);
	int (*unfreeze_fs)(struct super_block___272 *);
	int (*statfs)(struct dentry___273 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___272 *, int *, char *);
	void (*umount_begin)(struct super_block___272 *);
	int (*show_options)(struct seq_file___239 *, struct dentry___273 *);
	int (*show_devname)(struct seq_file___239 *, struct dentry___273 *);
	int (*show_path)(struct seq_file___239 *, struct dentry___273 *);
	int (*show_stats)(struct seq_file___239 *, struct dentry___273 *);
	ssize_t (*quota_read)(struct super_block___272 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___272 *, int, const char *, size_t, loff_t);
	struct dquot___272 ** (*get_dquots)(struct inode___273 *);
	int (*bdev_try_to_free_page)(struct super_block___272 *, struct page___274 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___272 *, struct shrink_control___113 *);
	long int (*free_cached_objects)(struct super_block___272 *, struct shrink_control___113 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___74 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___74 *last_lookup;
	struct hd_struct___74 *part[0];
};

struct block_device_operations___74 {
	int (*open)(struct block_device___272 *, fmode_t);
	void (*release)(struct gendisk___74 *, fmode_t);
	int (*rw_page)(struct block_device___272 *, sector_t, struct page___274 *, unsigned int);
	int (*ioctl)(struct block_device___272 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___272 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___74 *, unsigned int);
	int (*media_changed)(struct gendisk___74 *);
	void (*unlock_native_capacity)(struct gendisk___74 *);
	int (*revalidate_disk)(struct gendisk___74 *);
	int (*getgeo)(struct block_device___272 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___272 *, long unsigned int);
	int (*report_zones)(struct gendisk___74 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___221 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___262(struct page___274 *);

struct bdi_writeback_congested___142 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___142 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct cgroup_subsys___202;

struct cgroup_subsys_state___202 {
	struct cgroup___202 *cgroup;
	struct cgroup_subsys___202 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___202 *parent;
};

struct bsg_ops___73 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___73 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___73 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___73 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___73(struct request___73 *, blk_status_t);

struct request___73 {
	struct request_queue___73 *q;
	struct blk_mq_ctx___12 *mq_ctx;
	struct blk_mq_hw_ctx___15 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___142 *bio;
	struct bio___142 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___142 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___77 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___73 *saved_end_io;
		} flush;
	};
	struct gendisk___74 *rq_disk;
	struct hd_struct___74 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___73 *end_io;
	void *end_io_data;
	struct request___73 *next_rq;
};

struct fwnode_reference_args___171;

struct fwnode_endpoint___171;

struct fwnode_operations___171 {
	struct fwnode_handle___171 * (*get)(struct fwnode_handle___171 *);
	void (*put)(struct fwnode_handle___171 *);
	bool (*device_is_available)(const struct fwnode_handle___171 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___171 *, const struct device___236 *);
	bool (*property_present)(const struct fwnode_handle___171 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___171 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___171 *, const char *, const char **, size_t);
	struct fwnode_handle___171 * (*get_parent)(const struct fwnode_handle___171 *);
	struct fwnode_handle___171 * (*get_next_child_node)(const struct fwnode_handle___171 *, struct fwnode_handle___171 *);
	struct fwnode_handle___171 * (*get_named_child_node)(const struct fwnode_handle___171 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___171 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___171 *);
	struct fwnode_handle___171 * (*graph_get_next_endpoint)(const struct fwnode_handle___171 *, struct fwnode_handle___171 *);
	struct fwnode_handle___171 * (*graph_get_remote_endpoint)(const struct fwnode_handle___171 *);
	struct fwnode_handle___171 * (*graph_get_port_parent)(struct fwnode_handle___171 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___171 *, struct fwnode_endpoint___171 *);
};

struct fwnode_endpoint___171 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___171 *local_fwnode;
};

struct fwnode_reference_args___171 {
	struct fwnode_handle___171 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct blk_mq_ctxs___12;

struct blk_mq_ctx___12 {
	struct {
		spinlock_t lock;
		struct list_head rq_lists[3];
		long: 64;
	};
	unsigned int cpu;
	short unsigned int index_hw[3];
	struct blk_mq_hw_ctx___15 *hctxs[3];
	long unsigned int rq_dispatched[2];
	long unsigned int rq_merged;
	long unsigned int rq_completed[2];
	struct request_queue___73 *queue;
	struct blk_mq_ctxs___12 *ctxs;
	struct kobject___261 kobj;
};

struct blk_mq_tags___12;

struct blk_mq_hw_ctx___15 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___73 *queue;
	struct blk_flush_queue___12 *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx___12 *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx___12 **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags___12 *tags;
	struct blk_mq_tags___12 *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	unsigned int rh_reserved_nr_expired;
	struct hlist_node cpuhp_dead;
	struct kobject___261 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___273 *debugfs_dir;
	struct dentry___273 *sched_debugfs_dir;
	struct list_head hctx_list;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___73;

struct blk_mq_alloc_data___12;

struct elevator_mq_ops___73 {
	int (*init_sched)(struct request_queue___73 *, struct elevator_type___73 *);
	void (*exit_sched)(struct elevator_queue___73 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___15 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___15 *, unsigned int);
	bool (*allow_merge)(struct request_queue___73 *, struct request___73 *, struct bio___142 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx___15 *, struct bio___142 *);
	int (*request_merge)(struct request_queue___73 *, struct request___73 **, struct bio___142 *);
	void (*request_merged)(struct request_queue___73 *, struct request___73 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___73 *, struct request___73 *, struct request___73 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data___12 *);
	void (*prepare_request)(struct request___73 *, struct bio___142 *);
	void (*finish_request)(struct request___73 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___15 *, struct list_head *, bool);
	struct request___73 * (*dispatch_request)(struct blk_mq_hw_ctx___15 *);
	bool (*has_work)(struct blk_mq_hw_ctx___15 *);
	void (*completed_request)(struct request___73 *, u64);
	void (*started_request)(struct request___73 *);
	void (*requeue_request)(struct request___73 *);
	struct request___73 * (*former_request)(struct request_queue___73 *, struct request___73 *);
	struct request___73 * (*next_request)(struct request_queue___73 *, struct request___73 *);
	void (*init_icq)(struct io_cq___77 *);
	void (*exit_icq)(struct io_cq___77 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx___15 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___73;

struct blk_mq_debugfs_attr___5;

struct elevator_type___73 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___73 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___73 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___221 *elevator_owner;
	const struct blk_mq_debugfs_attr___5 *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr___5 *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___73 {
	struct elevator_type___73 *type;
	void *elevator_data;
	struct kobject___261 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct blk_mq_alloc_data___12 {
	struct request_queue___73 *q;
	blk_mq_req_flags_t flags;
	unsigned int shallow_depth;
	unsigned int cmd_flags;
	struct blk_mq_ctx___12 *ctx;
	struct blk_mq_hw_ctx___15 *hctx;
};

struct elv_fs_entry___73 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___73 *, char *);
	ssize_t (*store)(struct elevator_queue___73 *, const char *, size_t);
};

struct blk_mq_debugfs_attr___5 {
	const char *name;
	umode_t mode;
	int (*show)(void *, struct seq_file___239 *);
	ssize_t (*write)(void *, const char *, size_t, loff_t *);
	const struct seq_operations___238 *seq_ops;
};

struct blk_mq_queue_data___15;

typedef blk_status_t queue_rq_fn___15(struct blk_mq_hw_ctx___15 *, const struct blk_mq_queue_data___15 *);

typedef void commit_rqs_fn___15(struct blk_mq_hw_ctx___15 *);

typedef bool get_budget_fn___15(struct blk_mq_hw_ctx___15 *);

typedef void put_budget_fn___15(struct blk_mq_hw_ctx___15 *);

typedef enum blk_eh_timer_return timeout_fn___15(struct request___73 *, bool);

typedef int poll_fn___15(struct blk_mq_hw_ctx___15 *);

typedef void complete_fn___15(struct request___73 *);

typedef int init_hctx_fn___15(struct blk_mq_hw_ctx___15 *, void *, unsigned int);

typedef void exit_hctx_fn___15(struct blk_mq_hw_ctx___15 *, unsigned int);

typedef int init_request_fn___15(struct blk_mq_tag_set___15 *, struct request___73 *, unsigned int, unsigned int);

typedef void exit_request_fn___15(struct blk_mq_tag_set___15 *, struct request___73 *, unsigned int);

typedef bool busy_fn___15(struct request_queue___73 *);

typedef int map_queues_fn___15(struct blk_mq_tag_set___15 *);

typedef void cleanup_rq_fn___15(struct request___73 *);

struct blk_mq_ops___15 {
	queue_rq_fn___15 *queue_rq;
	commit_rqs_fn___15 *commit_rqs;
	get_budget_fn___15 *get_budget;
	put_budget_fn___15 *put_budget;
	timeout_fn___15 *timeout;
	poll_fn___15 *poll;
	complete_fn___15 *complete;
	init_hctx_fn___15 *init_hctx;
	exit_hctx_fn___15 *exit_hctx;
	init_request_fn___15 *init_request;
	exit_request_fn___15 *exit_request;
	void (*initialize_rq_fn)(struct request___73 *);
	busy_fn___15 *busy;
	map_queues_fn___15 *map_queues;
	void (*show_rq)(struct seq_file___239 *, struct request___73 *);
	union {
		cleanup_rq_fn___15 *cleanup_rq;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide42;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct blk_stat_callback___12 {
	struct list_head list;
	struct timer_list timer;
	struct blk_rq_stat *cpu_stat;
	int (*bucket_fn)(const struct request___73 *);
	unsigned int buckets;
	struct blk_rq_stat *stat;
	void (*timer_fn)(struct blk_stat_callback___12 *);
	void *data;
	struct callback_head rcu;
};

struct blk_flush_queue___12 {
	unsigned int flush_queue_delayed: 1;
	unsigned int flush_pending_idx: 1;
	unsigned int flush_running_idx: 1;
	long unsigned int flush_pending_since;
	struct list_head flush_queue[2];
	struct list_head flush_data_in_flight;
	struct request___73 *flush_rq;
	struct request___73 *orig_rq;
	spinlock_t mq_flush_lock;
};

struct blk_mq_tag_set___15 {
	struct blk_mq_queue_map map[6];
	unsigned int nr_maps;
	const struct blk_mq_ops___15 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	struct blk_mq_tags___12 **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct blk_mq_tags___12 {
	unsigned int nr_tags;
	unsigned int nr_reserved_tags;
	atomic_t active_queues;
	struct sbitmap_queue bitmap_tags;
	struct sbitmap_queue breserved_tags;
	struct request___73 **rqs;
	struct request___73 **static_rqs;
	struct list_head page_list;
};

struct blk_mq_queue_data___15 {
	struct request___73 *rq;
	bool last;
	long unsigned int rh_reserved1;
};

struct kernel_param_ops___218 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___218 *);
	int (*get)(char *, const struct kernel_param___218 *);
	void (*free)(void *);
};

struct kparam_array___218;

struct kernel_param___218 {
	const char *name;
	struct module___221 *mod;
	const struct kernel_param_ops___218 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___218 *arr;
	};
};

struct kparam_array___218 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___218 *ops;
	void *elem;
};

struct module_attribute___218 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___218 *, struct module_kobject___218 *, char *);
	ssize_t (*store)(struct module_attribute___218 *, struct module_kobject___218 *, const char *, size_t);
	void (*setup)(struct module___221 *, const char *);
	int (*test)(struct module___221 *);
	void (*free)(struct module___221 *);
};

struct trace_event_class___122;

struct trace_event_call___122 {
	struct list_head list;
	struct trace_event_class___122 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___34 *prog_array;
	int (*perf_perm)(struct trace_event_call___122 *, struct perf_event___129 *);
};

struct blk_mq_ctxs___12 {
	struct kobject___261 kobj;
	struct blk_mq_ctx___12 *queue_ctx;
};

typedef int (*key_restrict_link_func_t___261)(struct key___260 *, const struct key_type *, const union key_payload *, struct key___260 *);

struct key_restriction___260;

struct key___260 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___274 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key___6 index_key;
		struct {
			struct key_type___6 *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___260 *restrict_link;
};

struct key_restriction___260 {
	key_restrict_link_func_t___261 check;
	struct key___260 *key;
	struct key_type *keytype;
};

struct seq_operations___238 {
	void * (*start)(struct seq_file___239 *, loff_t *);
	void (*stop)(struct seq_file___239 *, void *);
	void * (*next)(struct seq_file___239 *, void *, loff_t *);
	int (*show)(struct seq_file___239 *, void *);
};

struct cgroup_namespace___202 {
	refcount_t count;
	struct ns_common___28 ns;
	struct user_namespace___217 *user_ns;
	struct ucounts___217 *ucounts;
	struct css_set___202 *root_cset;
};

struct ucounts___217 {
	struct hlist_node node;
	struct user_namespace___217 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct node___173 {
	struct device___236 dev;
};

struct bpf_map___203;

struct bpf_map_ops___202 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___203 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___203 *, struct file___273 *);
	void (*map_free)(struct bpf_map___203 *);
	int (*map_get_next_key)(struct bpf_map___203 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___203 *);
	void * (*map_lookup_elem)(struct bpf_map___203 *, void *);
	int (*map_update_elem)(struct bpf_map___203 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___203 *, void *);
	int (*map_push_elem)(struct bpf_map___203 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___203 *, void *);
	int (*map_peek_elem)(struct bpf_map___203 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___203 *, struct file___273 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___203 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___203 *, void *, struct seq_file___239 *);
	int (*map_check_btf)(const struct bpf_map___203 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___203 {
	const struct bpf_map_ops___202 *ops;
	struct bpf_map___203 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___260 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___202;

typedef void (*kthread_work_func_t___202)(struct kthread_work___202 *);

struct kthread_worker___202;

struct kthread_work___202 {
	struct list_head node;
	kthread_work_func_t___202 func;
	struct kthread_worker___202 *worker;
	int canceling;
};

struct kthread_worker___202 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___274 *task;
	struct kthread_work___202 *current_work;
};

struct kthread_delayed_work___202 {
	struct kthread_work___202 work;
	struct timer_list timer;
};

struct psi_group___202 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___202 *poll_kworker;
	struct kthread_delayed_work___202 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___202 {
	struct kernfs_node___268 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_root___202;

struct cgroup_rstat_cpu___202;

struct cgroup___202 {
	struct cgroup_subsys_state___202 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___268 *kn;
	struct cgroup_file___202 procs_file;
	struct cgroup_file___202 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___202 *subsys[13];
	struct cgroup_root___202 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___202 *dom_cgrp;
	struct cgroup_rstat_cpu___202 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___34 bpf;
	atomic_t congestion_count;
	struct cgroup___202 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___202 psi;
	int ancestor_ids[0];
};

struct cftype___202;

struct cgroup_subsys___202 {
	struct cgroup_subsys_state___202 * (*css_alloc)(struct cgroup_subsys_state___202 *);
	int (*css_online)(struct cgroup_subsys_state___202 *);
	void (*css_offline)(struct cgroup_subsys_state___202 *);
	void (*css_released)(struct cgroup_subsys_state___202 *);
	void (*css_free)(struct cgroup_subsys_state___202 *);
	void (*css_reset)(struct cgroup_subsys_state___202 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___202 *, int);
	int (*css_extra_stat_show)(struct seq_file___239 *, struct cgroup_subsys_state___202 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___274 *);
	void (*cancel_fork)(struct task_struct___274 *);
	void (*fork)(struct task_struct___274 *);
	void (*exit)(struct task_struct___274 *);
	void (*free)(struct task_struct___274 *);
	void (*bind)(struct cgroup_subsys_state___202 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___202 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___202 *dfl_cftypes;
	struct cftype___202 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___202 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___202 *updated_children;
	struct cgroup___202 *updated_next;
};

struct cgroup_root___202 {
	struct kernfs_root___267 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___202 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___202 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___202 *ss;
	struct list_head node;
	struct kernfs_ops___267 *kf_ops;
	int (*open)(struct kernfs_open_file___267 *);
	void (*release)(struct kernfs_open_file___267 *);
	u64 (*read_u64)(struct cgroup_subsys_state___202 *, struct cftype___202 *);
	s64 (*read_s64)(struct cgroup_subsys_state___202 *, struct cftype___202 *);
	int (*seq_show)(struct seq_file___239 *, void *);
	void * (*seq_start)(struct seq_file___239 *, loff_t *);
	void * (*seq_next)(struct seq_file___239 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___239 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___202 *, struct cftype___202 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___202 *, struct cftype___202 *, s64);
	ssize_t (*write)(struct kernfs_open_file___267 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___267 *, struct poll_table_struct___167 *);
};

struct perf_cpu_context___129;

struct pmu___129 {
	struct list_head entry;
	struct module___221 *module;
	struct device___236 *dev;
	const struct attribute_group___238 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___129 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___129 *);
	void (*pmu_disable)(struct pmu___129 *);
	int (*event_init)(struct perf_event___129 *);
	void (*event_mapped)(struct perf_event___129 *, struct mm_struct___273 *);
	void (*event_unmapped)(struct perf_event___129 *, struct mm_struct___273 *);
	int (*add)(struct perf_event___129 *, int);
	void (*del)(struct perf_event___129 *, int);
	void (*start)(struct perf_event___129 *, int);
	void (*stop)(struct perf_event___129 *, int);
	void (*read)(struct perf_event___129 *);
	void (*start_txn)(struct pmu___129 *, unsigned int);
	int (*commit_txn)(struct pmu___129 *);
	void (*cancel_txn)(struct pmu___129 *);
	int (*event_idx)(struct perf_event___129 *);
	void (*sched_task)(struct perf_event_context___129 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___129 *);
	int (*filter_match)(struct perf_event___129 *);
	int (*check_period)(struct perf_event___129 *, u64);
};

struct perf_cpu_context___129 {
	struct perf_event_context___129 ctx;
	struct perf_event_context___129 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___129 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___129 {
	struct cgroup_subsys_state___202 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___122 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___122 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___122 *);
	struct list_head * (*get_fields)(struct trace_event_call___122 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___122 *);
};

struct trace_event_file___47;

struct trace_event_buffer___39 {
	struct ring_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___47 *trace_file;
	void *entry;
	long unsigned int flags;
	int pc;
};

struct trace_event_file___47 {
	struct list_head list;
	struct trace_event_call___122 *event_call;
	struct event_filter *filter;
	struct dentry___273 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_kyber_latency {
	struct trace_entry ent;
	dev_t dev;
	char domain[16];
	char type[8];
	u8 percentile;
	u8 numerator;
	u8 denominator;
	unsigned int samples;
	char __data[0];
};

struct trace_event_raw_kyber_adjust {
	struct trace_entry ent;
	dev_t dev;
	char domain[16];
	unsigned int depth;
	char __data[0];
};

struct trace_event_raw_kyber_throttled {
	struct trace_entry ent;
	dev_t dev;
	char domain[16];
	char __data[0];
};

struct trace_event_data_offsets_kyber_latency {};

struct trace_event_data_offsets_kyber_adjust {};

struct trace_event_data_offsets_kyber_throttled {};

enum {
	KYBER_READ = 0,
	KYBER_WRITE = 1,
	KYBER_DISCARD = 2,
	KYBER_OTHER = 3,
	KYBER_NUM_DOMAINS = 4,
};

enum {
	KYBER_ASYNC_PERCENT = 75,
};

enum {
	KYBER_LATENCY_SHIFT = 2,
	KYBER_GOOD_BUCKETS = 4,
	KYBER_LATENCY_BUCKETS = 8,
};

enum {
	KYBER_TOTAL_LATENCY = 0,
	KYBER_IO_LATENCY = 1,
};

struct kyber_cpu_latency {
	atomic_t buckets[48];
};

struct kyber_ctx_queue {
	spinlock_t lock;
	struct list_head rq_list[4];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kyber_queue_data {
	struct request_queue___73 *q;
	struct sbitmap_queue domain_tokens[4];
	unsigned int async_depth;
	struct kyber_cpu_latency *cpu_latency;
	struct timer_list timer;
	unsigned int latency_buckets[48];
	long unsigned int latency_timeout[3];
	int domain_p99[3];
	u64 latency_targets[3];
};

struct kyber_hctx_data {
	spinlock_t lock;
	struct list_head rqs[4];
	unsigned int cur_domain;
	unsigned int batching;
	struct kyber_ctx_queue *kcqs;
	struct sbitmap kcq_map[4];
	struct sbq_wait domain_wait[4];
	struct sbq_wait_state *domain_ws[4];
	atomic_t wait_index[4];
};

struct flush_kcq_data {
	struct kyber_hctx_data *khd;
	unsigned int sched_domain;
	struct list_head *list;
};

typedef struct blkcg_policy_data___48 *blkcg_pol_alloc_cpd_fn___3(gfp_t);

typedef void blkcg_pol_init_cpd_fn___3(struct blkcg_policy_data___48 *);

typedef void blkcg_pol_free_cpd_fn___3(struct blkcg_policy_data___48 *);

typedef void blkcg_pol_bind_cpd_fn___3(struct blkcg_policy_data___48 *);

typedef struct blkg_policy_data___48 *blkcg_pol_alloc_pd_fn___3(gfp_t, int);

typedef void blkcg_pol_init_pd_fn___3(struct blkg_policy_data___48 *);

typedef void blkcg_pol_online_pd_fn___3(struct blkg_policy_data___48 *);

typedef void blkcg_pol_offline_pd_fn___3(struct blkg_policy_data___48 *);

typedef void blkcg_pol_free_pd_fn___3(struct blkg_policy_data___48 *);

typedef void blkcg_pol_reset_pd_stats_fn___3(struct blkg_policy_data___48 *);

typedef size_t blkcg_pol_stat_pd_fn___3(struct blkg_policy_data___48 *, char *, size_t);

struct blkcg_policy___3 {
	int plid;
	struct cftype___197 *dfl_cftypes;
	struct cftype___197 *legacy_cftypes;
	blkcg_pol_alloc_cpd_fn___3 *cpd_alloc_fn;
	blkcg_pol_init_cpd_fn___3 *cpd_init_fn;
	blkcg_pol_free_cpd_fn___3 *cpd_free_fn;
	blkcg_pol_bind_cpd_fn___3 *cpd_bind_fn;
	blkcg_pol_alloc_pd_fn___3 *pd_alloc_fn;
	blkcg_pol_init_pd_fn___3 *pd_init_fn;
	blkcg_pol_online_pd_fn___3 *pd_online_fn;
	blkcg_pol_offline_pd_fn___3 *pd_offline_fn;
	blkcg_pol_free_pd_fn___3 *pd_free_fn;
	blkcg_pol_reset_pd_stats_fn___3 *pd_reset_stats_fn;
	blkcg_pol_stat_pd_fn___3 *pd_stat_fn;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bfq_entity;

struct bfq_service_tree {
	struct rb_root active;
	struct rb_root idle;
	struct bfq_entity *first_idle;
	struct bfq_entity *last_idle;
	u64 vtime;
	long unsigned int wsum;
};

struct bfq_sched_data;

struct bfq_entity {
	struct rb_node rb_node;
	bool on_st;
	u64 start;
	u64 finish;
	struct rb_root *tree;
	u64 min_start;
	int service;
	int budget;
	int weight;
	int new_weight;
	int orig_weight;
	struct bfq_entity *parent;
	struct bfq_sched_data *my_sched_data;
	struct bfq_sched_data *sched_data;
	int prio_changed;
	bool in_groups_with_pending_reqs;
};

struct bfq_sched_data {
	struct bfq_entity *in_service_entity;
	struct bfq_entity *next_in_service;
	struct bfq_service_tree service_tree[3];
	long unsigned int bfq_class_idle_last_service;
};

struct bfq_weight_counter {
	unsigned int weight;
	unsigned int num_active;
	struct rb_node weights_node;
};

struct bfq_ttime {
	u64 last_end_request;
	u64 ttime_total;
	long unsigned int ttime_samples;
	u64 ttime_mean;
};

struct bfq_data;

struct bfq_io_cq;

struct bfq_queue {
	int ref;
	struct bfq_data *bfqd;
	short unsigned int ioprio;
	short unsigned int ioprio_class;
	short unsigned int new_ioprio;
	short unsigned int new_ioprio_class;
	u64 last_serv_time_ns;
	unsigned int inject_limit;
	long unsigned int decrease_time_jif;
	struct bfq_queue *new_bfqq;
	struct rb_node pos_node;
	struct rb_root *pos_root;
	struct rb_root sort_list;
	struct request___60 *next_rq;
	int queued[2];
	int allocated;
	int meta_pending;
	struct list_head fifo;
	struct bfq_entity entity;
	struct bfq_weight_counter *weight_counter;
	int max_budget;
	long unsigned int budget_timeout;
	int dispatched;
	long unsigned int flags;
	struct list_head bfqq_list;
	struct bfq_ttime ttime;
	u32 seek_history;
	struct hlist_node burst_list_node;
	sector_t last_request_pos;
	unsigned int requests_within_timer;
	pid_t pid;
	struct bfq_io_cq *bic;
	long unsigned int wr_cur_max_time;
	long unsigned int soft_rt_next_start;
	long unsigned int last_wr_start_finish;
	unsigned int wr_coeff;
	long unsigned int last_idle_bklogged;
	long unsigned int service_from_backlogged;
	long unsigned int service_from_wr;
	long unsigned int wr_start_at_switch_to_srt;
	long unsigned int split_time;
	long unsigned int first_IO_time;
	u32 max_service_rate;
};

struct bfq_group;

struct bfq_data {
	struct request_queue___60 *queue;
	struct list_head dispatch;
	struct bfq_group *root_group;
	struct rb_root_cached queue_weights_tree;
	unsigned int num_groups_with_pending_reqs;
	unsigned int busy_queues[3];
	int wr_busy_queues;
	int queued;
	int rq_in_driver;
	bool nonrot_with_queueing;
	int max_rq_in_driver;
	int hw_tag_samples;
	int hw_tag;
	int budgets_assigned;
	struct hrtimer idle_slice_timer;
	struct bfq_queue *in_service_queue;
	sector_t last_position;
	sector_t in_serv_last_pos;
	u64 last_completion;
	u64 last_empty_occupied_ns;
	bool wait_dispatch;
	struct request___60 *waited_rq;
	bool rqs_injected;
	u64 first_dispatch;
	u64 last_dispatch;
	ktime_t last_budget_start;
	ktime_t last_idling_start;
	long unsigned int last_idling_start_jiffies;
	int peak_rate_samples;
	u32 sequential_samples;
	u64 tot_sectors_dispatched;
	u32 last_rq_max_size;
	u64 delta_from_first;
	u32 peak_rate;
	int bfq_max_budget;
	struct list_head active_list;
	struct list_head idle_list;
	u64 bfq_fifo_expire[2];
	unsigned int bfq_back_penalty;
	unsigned int bfq_back_max;
	u32 bfq_slice_idle;
	int bfq_user_max_budget;
	unsigned int bfq_timeout;
	unsigned int bfq_requests_within_timer;
	bool strict_guarantees;
	long unsigned int last_ins_in_burst;
	long unsigned int bfq_burst_interval;
	int burst_size;
	struct bfq_entity *burst_parent_entity;
	long unsigned int bfq_large_burst_thresh;
	bool large_burst;
	struct hlist_head burst_list;
	bool low_latency;
	unsigned int bfq_wr_coeff;
	unsigned int bfq_wr_max_time;
	unsigned int bfq_wr_rt_max_time;
	unsigned int bfq_wr_min_idle_time;
	long unsigned int bfq_wr_min_inter_arr_async;
	unsigned int bfq_wr_max_softrt_rate;
	u64 rate_dur_prod;
	struct bfq_queue oom_bfqq;
	spinlock_t lock;
	struct bfq_io_cq *bio_bic;
	struct bfq_queue *bio_bfqq;
	unsigned int word_depths[4];
};

struct bfq_io_cq {
	struct io_cq___63 icq;
	struct bfq_queue *bfqq[2];
	int ioprio;
	uint64_t blkcg_serial_nr;
	bool saved_has_short_ttime;
	bool saved_IO_bound;
	bool saved_in_large_burst;
	bool was_in_burst_list;
	unsigned int saved_weight;
	long unsigned int saved_wr_coeff;
	long unsigned int saved_last_wr_start_finish;
	long unsigned int saved_wr_start_at_switch_to_srt;
	unsigned int saved_wr_cur_max_time;
	struct bfq_ttime saved_ttime;
};

struct bfqg_stats {};

struct bfq_group {
	struct blkg_policy_data___48 pd;
	char blkg_path[128];
	int ref;
	struct bfq_entity entity;
	struct bfq_sched_data sched_data;
	void *bfqd;
	struct bfq_queue *async_bfqq[16];
	struct bfq_queue *async_idle_bfqq;
	struct bfq_entity *my_entity;
	int active_entities;
	struct rb_root rq_pos_tree;
	struct bfqg_stats stats;
};

enum bfqq_state_flags {
	BFQQF_just_created = 0,
	BFQQF_busy = 1,
	BFQQF_wait_request = 2,
	BFQQF_non_blocking_wait_rq = 3,
	BFQQF_fifo_expire = 4,
	BFQQF_has_short_ttime = 5,
	BFQQF_sync = 6,
	BFQQF_IO_bound = 7,
	BFQQF_in_large_burst = 8,
	BFQQF_softrt_update = 9,
	BFQQF_coop = 10,
	BFQQF_split_coop = 11,
};

enum bfqq_expiration {
	BFQQE_TOO_IDLE = 0,
	BFQQE_BUDGET_TIMEOUT = 1,
	BFQQE_BUDGET_EXHAUSTED = 2,
	BFQQE_NO_MORE_REQUESTS = 3,
	BFQQE_PREEMPTED = 4,
};

typedef struct blkcg_policy_data___51 *blkcg_pol_alloc_cpd_fn___4(gfp_t);

typedef void blkcg_pol_init_cpd_fn___4(struct blkcg_policy_data___51 *);

typedef void blkcg_pol_free_cpd_fn___4(struct blkcg_policy_data___51 *);

typedef void blkcg_pol_bind_cpd_fn___4(struct blkcg_policy_data___51 *);

typedef struct blkg_policy_data___51 *blkcg_pol_alloc_pd_fn___4(gfp_t, int);

typedef void blkcg_pol_init_pd_fn___4(struct blkg_policy_data___51 *);

typedef void blkcg_pol_online_pd_fn___4(struct blkg_policy_data___51 *);

typedef void blkcg_pol_offline_pd_fn___4(struct blkg_policy_data___51 *);

typedef void blkcg_pol_free_pd_fn___4(struct blkg_policy_data___51 *);

typedef void blkcg_pol_reset_pd_stats_fn___4(struct blkg_policy_data___51 *);

typedef size_t blkcg_pol_stat_pd_fn___4(struct blkg_policy_data___51 *, char *, size_t);

struct blkcg_policy___4 {
	int plid;
	struct cftype___200 *dfl_cftypes;
	struct cftype___200 *legacy_cftypes;
	blkcg_pol_alloc_cpd_fn___4 *cpd_alloc_fn;
	blkcg_pol_init_cpd_fn___4 *cpd_init_fn;
	blkcg_pol_free_cpd_fn___4 *cpd_free_fn;
	blkcg_pol_bind_cpd_fn___4 *cpd_bind_fn;
	blkcg_pol_alloc_pd_fn___4 *pd_alloc_fn;
	blkcg_pol_init_pd_fn___4 *pd_init_fn;
	blkcg_pol_online_pd_fn___4 *pd_online_fn;
	blkcg_pol_offline_pd_fn___4 *pd_offline_fn;
	blkcg_pol_free_pd_fn___4 *pd_free_fn;
	blkcg_pol_reset_pd_stats_fn___4 *pd_reset_stats_fn;
	blkcg_pol_stat_pd_fn___4 *pd_stat_fn;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bfq_data___2;

struct bfq_io_cq___2;

struct bfq_queue___2 {
	int ref;
	struct bfq_data___2 *bfqd;
	short unsigned int ioprio;
	short unsigned int ioprio_class;
	short unsigned int new_ioprio;
	short unsigned int new_ioprio_class;
	u64 last_serv_time_ns;
	unsigned int inject_limit;
	long unsigned int decrease_time_jif;
	struct bfq_queue___2 *new_bfqq;
	struct rb_node pos_node;
	struct rb_root *pos_root;
	struct rb_root sort_list;
	struct request___65 *next_rq;
	int queued[2];
	int allocated;
	int meta_pending;
	struct list_head fifo;
	struct bfq_entity entity;
	struct bfq_weight_counter *weight_counter;
	int max_budget;
	long unsigned int budget_timeout;
	int dispatched;
	long unsigned int flags;
	struct list_head bfqq_list;
	struct bfq_ttime ttime;
	u32 seek_history;
	struct hlist_node burst_list_node;
	sector_t last_request_pos;
	unsigned int requests_within_timer;
	pid_t pid;
	struct bfq_io_cq___2 *bic;
	long unsigned int wr_cur_max_time;
	long unsigned int soft_rt_next_start;
	long unsigned int last_wr_start_finish;
	unsigned int wr_coeff;
	long unsigned int last_idle_bklogged;
	long unsigned int service_from_backlogged;
	long unsigned int service_from_wr;
	long unsigned int wr_start_at_switch_to_srt;
	long unsigned int split_time;
	long unsigned int first_IO_time;
	u32 max_service_rate;
};

struct bfq_group___2;

struct bfq_data___2 {
	struct request_queue___65 *queue;
	struct list_head dispatch;
	struct bfq_group___2 *root_group;
	struct rb_root_cached queue_weights_tree;
	unsigned int num_groups_with_pending_reqs;
	unsigned int busy_queues[3];
	int wr_busy_queues;
	int queued;
	int rq_in_driver;
	bool nonrot_with_queueing;
	int max_rq_in_driver;
	int hw_tag_samples;
	int hw_tag;
	int budgets_assigned;
	struct hrtimer idle_slice_timer;
	struct bfq_queue___2 *in_service_queue;
	sector_t last_position;
	sector_t in_serv_last_pos;
	u64 last_completion;
	u64 last_empty_occupied_ns;
	bool wait_dispatch;
	struct request___65 *waited_rq;
	bool rqs_injected;
	u64 first_dispatch;
	u64 last_dispatch;
	ktime_t last_budget_start;
	ktime_t last_idling_start;
	long unsigned int last_idling_start_jiffies;
	int peak_rate_samples;
	u32 sequential_samples;
	u64 tot_sectors_dispatched;
	u32 last_rq_max_size;
	u64 delta_from_first;
	u32 peak_rate;
	int bfq_max_budget;
	struct list_head active_list;
	struct list_head idle_list;
	u64 bfq_fifo_expire[2];
	unsigned int bfq_back_penalty;
	unsigned int bfq_back_max;
	u32 bfq_slice_idle;
	int bfq_user_max_budget;
	unsigned int bfq_timeout;
	unsigned int bfq_requests_within_timer;
	bool strict_guarantees;
	long unsigned int last_ins_in_burst;
	long unsigned int bfq_burst_interval;
	int burst_size;
	struct bfq_entity *burst_parent_entity;
	long unsigned int bfq_large_burst_thresh;
	bool large_burst;
	struct hlist_head burst_list;
	bool low_latency;
	unsigned int bfq_wr_coeff;
	unsigned int bfq_wr_max_time;
	unsigned int bfq_wr_rt_max_time;
	unsigned int bfq_wr_min_idle_time;
	long unsigned int bfq_wr_min_inter_arr_async;
	unsigned int bfq_wr_max_softrt_rate;
	u64 rate_dur_prod;
	struct bfq_queue___2 oom_bfqq;
	spinlock_t lock;
	struct bfq_io_cq___2 *bio_bic;
	struct bfq_queue___2 *bio_bfqq;
	unsigned int word_depths[4];
};

struct bfq_io_cq___2 {
	struct io_cq___69 icq;
	struct bfq_queue___2 *bfqq[2];
	int ioprio;
	uint64_t blkcg_serial_nr;
	bool saved_has_short_ttime;
	bool saved_IO_bound;
	bool saved_in_large_burst;
	bool was_in_burst_list;
	unsigned int saved_weight;
	long unsigned int saved_wr_coeff;
	long unsigned int saved_last_wr_start_finish;
	long unsigned int saved_wr_start_at_switch_to_srt;
	unsigned int saved_wr_cur_max_time;
	struct bfq_ttime saved_ttime;
};

struct bfq_group___2 {
	struct blkg_policy_data___51 pd;
	char blkg_path[128];
	int ref;
	struct bfq_entity entity;
	struct bfq_sched_data sched_data;
	void *bfqd;
	struct bfq_queue___2 *async_bfqq[16];
	struct bfq_queue___2 *async_idle_bfqq;
	struct bfq_entity *my_entity;
	int active_entities;
	struct rb_root rq_pos_tree;
	struct bfqg_stats stats;
};

typedef struct blkcg_policy_data___50 *blkcg_pol_alloc_cpd_fn___5(gfp_t);

typedef void blkcg_pol_init_cpd_fn___5(struct blkcg_policy_data___50 *);

typedef void blkcg_pol_free_cpd_fn___5(struct blkcg_policy_data___50 *);

typedef void blkcg_pol_bind_cpd_fn___5(struct blkcg_policy_data___50 *);

typedef struct blkg_policy_data___50 *blkcg_pol_alloc_pd_fn___5(gfp_t, int);

typedef void blkcg_pol_init_pd_fn___5(struct blkg_policy_data___50 *);

typedef void blkcg_pol_online_pd_fn___5(struct blkg_policy_data___50 *);

typedef void blkcg_pol_offline_pd_fn___5(struct blkg_policy_data___50 *);

typedef void blkcg_pol_free_pd_fn___5(struct blkg_policy_data___50 *);

typedef void blkcg_pol_reset_pd_stats_fn___5(struct blkg_policy_data___50 *);

typedef size_t blkcg_pol_stat_pd_fn___5(struct blkg_policy_data___50 *, char *, size_t);

struct bfq_group_data {
	struct blkcg_policy_data___50 pd;
	unsigned int weight;
};

enum bip_flags {
	BIP_BLOCK_INTEGRITY = 1,
	BIP_MAPPED_INTEGRITY = 2,
	BIP_CTRL_NOCHECK = 4,
	BIP_DISK_NOCHECK = 8,
	BIP_IP_CHECKSUM = 16,
};

enum blk_integrity_flags {
	BLK_INTEGRITY_VERIFY = 1,
	BLK_INTEGRITY_GENERATE = 2,
	BLK_INTEGRITY_DEVICE_CAPABLE = 4,
	BLK_INTEGRITY_IP_CHECKSUM = 8,
};

struct file___274;

struct kiocb___274;

struct vm_area_struct___275;

struct inode___274;

struct file_lock___274;

struct page___275;

struct seq_file___240;

struct file_operations___274 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___274 *, loff_t, int);
	ssize_t (*read)(struct file___274 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___274 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___274 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___274 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___274 *, bool);
	int (*iterate)(struct file___274 *, struct dir_context *);
	int (*iterate_shared)(struct file___274 *, struct dir_context *);
	__poll_t (*poll)(struct file___274 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___274 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___274 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___274 *, struct vm_area_struct___275 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___274 *, struct file___274 *);
	int (*flush)(struct file___274 *, fl_owner_t);
	int (*release)(struct inode___274 *, struct file___274 *);
	int (*fsync)(struct file___274 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___274 *, int);
	int (*lock)(struct file___274 *, int, struct file_lock___274 *);
	ssize_t (*sendpage)(struct file___274 *, struct page___275 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___274 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___274 *, int, struct file_lock___274 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___274 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___274 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___274 *, long int, struct file_lock___274 **, void **);
	long int (*fallocate)(struct file___274 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___240 *, struct file___274 *);
	ssize_t (*copy_file_range)(struct file___274 *, loff_t, struct file___274 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___274 *, loff_t, struct file___274 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___274 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___274 {
	u64 seqnum;
	struct vm_area_struct___275 *vmas[4];
};

struct page_frag___274 {
	struct page___275 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___274;

struct cred___261;

struct nsproxy___238;

struct bio_list___143;

struct backing_dev_info___143;

struct io_context___78;

struct css_set___203;

struct request_queue___74;

struct vm_struct___190;

struct task_struct___275 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___275 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity___2 rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___274 *mm;
	struct mm_struct___274 *active_mm;
	struct vmacache___274 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___275 *real_parent;
	struct task_struct___275 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___275 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___192 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___192 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___192 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___261 *ptracer_cred;
	const struct cred___261 *real_cred;
	const struct cred___261 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___238 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___275 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___143 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___143 *backing_dev_info;
	struct io_context___78 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___203 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___274 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___74 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___275 *oom_reaper_list;
	struct vm_struct___190 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___129 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rw_semaphore___275 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___275 *owner;
};

struct key___261;

struct ucounts___218;

struct user_namespace___218 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___218 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___9 ns;
	long unsigned int flags;
	struct key___261 *persistent_keyring_register;
	struct rw_semaphore___275 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___218 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct secondary_data___275 {
	void *stack;
	struct task_struct___275 *task;
	long int status;
};

typedef struct page___275 *pgtable_t___274;

struct address_space___273;

struct dev_pagemap___263;

struct page___275 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___273 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___275 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___274 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___274 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___263 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct user_struct___261 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___261 *uid_keyring;
	struct key___261 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___263;

struct vm_area_struct___275 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___275 *vm_next;
	struct vm_area_struct___275 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___274 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___263 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___274 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___274;

struct mm_struct___274 {
	struct {
		struct vm_area_struct___275 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___274 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___275 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___274 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___275 *owner;
		struct user_namespace___218 *user_ns;
		struct file___274 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___274 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___261 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___261 *session_keyring;
	struct key___261 *process_keyring;
	struct key___261 *thread_keyring;
	struct key___261 *request_key_auth;
	void *security;
	struct user_struct___261 *user;
	struct user_namespace___218 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___203;

struct nsproxy___238 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___203 *cgroup_ns;
};

struct bio___143;

struct bio_list___143 {
	struct bio___143 *head;
	struct bio___143 *tail;
};

struct bdi_writeback_congested___143;

struct cgroup_subsys_state___203;

struct bdi_writeback___143 {
	struct backing_dev_info___143 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___143 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___203 *memcg_css;
	struct cgroup_subsys_state___203 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___237;

struct dentry___274;

struct backing_dev_info___143 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___143 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___237 *dev;
	struct device___237 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___274 *debug_dir;
	struct dentry___274 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___78;

struct io_context___78 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___78 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___203;

struct css_set___203 {
	struct cgroup_subsys_state___203 *subsys[13];
	refcount_t refcount;
	struct css_set___203 *dom_cset;
	struct cgroup___203 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___203 *mg_src_cgrp;
	struct cgroup___203 *mg_dst_cgrp;
	struct css_set___203 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

typedef blk_qc_t make_request_fn___74(struct request_queue___74 *, struct bio___143 *);

struct request___74;

typedef int dma_drain_needed_fn___74(struct request___74 *);

struct kset___261;

struct kobj_type___261;

struct kernfs_node___269;

struct kobject___262 {
	const char *name;
	struct list_head entry;
	struct kobject___262 *parent;
	struct kset___261 *kset;
	struct kobj_type___261 *ktype;
	struct kernfs_node___269 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___74;

struct bsg_class_device___74 {
	struct device___237 *class_dev;
	int minor;
	struct request_queue___74 *queue;
	const struct bsg_ops___74 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___143 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___143 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___74;

struct blk_mq_ops___16;

struct blk_mq_ctx___13;

struct blk_mq_hw_ctx___16;

struct blk_stat_callback___13;

struct blkcg_gq___53;

struct blk_flush_queue___13;

struct blk_mq_tag_set___16;

struct request_queue___74 {
	struct list_head queue_head;
	struct request___74 *last_merge;
	struct elevator_queue___74 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___74 *make_request_fn;
	dma_drain_needed_fn___74 *dma_drain_needed;
	const struct blk_mq_ops___16 *mq_ops;
	struct blk_mq_ctx___13 *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___16 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___143 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___262 kobj;
	struct kobject___262 *mq_kobj;
	struct blk_integrity integrity;
	struct device___237 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback___13 *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___53 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue___13 *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	struct bsg_class_device___74 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set___16 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___143 bio_split;
	struct dentry___274 *debugfs_dir;
	struct dentry___274 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___190 {
	struct vm_struct___190 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___275 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct pglist_data___274;

struct lruvec___274 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___274 *pgdat;
};

struct zone___274 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___274 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___274 {
	struct zone___274 *zone;
	int zone_idx;
};

struct zonelist___274 {
	struct zoneref___274 _zonerefs[25];
};

struct pglist_data___274 {
	struct zone___274 node_zones[3];
	struct zonelist___274 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___275 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___275 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___274 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___274 {
	struct rw_semaphore___275 rwsem;
	struct notifier_block *head;
};

struct bio_vec___143 {
	struct page___275 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

typedef void bio_end_io_t___143(struct bio___143 *);

struct gendisk___75;

struct bio_integrity_payload___143;

struct bio___143 {
	struct bio___143 *bi_next;
	struct gendisk___75 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___143 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___53 *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___143 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___143 *bi_io_vec;
	struct bio_set___143 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___143 bi_inline_vecs[0];
};

struct bio_integrity_payload___143 {
	struct bio___143 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___143 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___143 bip_inline_vecs[0];
};

struct dev_pm_info___237 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___237 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___237;

struct bus_type___237;

struct device_driver___237;

struct dev_pm_domain___237;

struct fwnode_handle___172;

struct class___237;

struct attribute_group___239;

struct device___237 {
	struct device___237 *parent;
	struct device_private *p;
	struct kobject___262 kobj;
	const char *init_name;
	const struct device_type___237 *type;
	struct mutex mutex;
	struct bus_type___237 *bus;
	struct device_driver___237 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___237 power;
	struct dev_pm_domain___237 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___172 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___237 *class;
	const struct attribute_group___239 **groups;
	void (*release)(struct device___237 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___75 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___237 __dev;
	struct kobject___262 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___75;

struct block_device_operations___75;

struct gendisk___75 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___75 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___75 *part_tbl;
	struct hd_struct___75 part0;
	const struct block_device_operations___75 *fops;
	struct request_queue___74 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___275 lookup_sem;
	struct kobject___262 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___262 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct blkcg___53;

struct blkg_policy_data___53;

struct blkcg_gq___53 {
	struct request_queue___74 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___53 *blkcg;
	struct bdi_writeback_congested___143 *wb_congested;
	struct blkcg_gq___53 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_rwstat stat_bytes;
	struct blkg_rwstat stat_ios;
	struct blkg_policy_data___53 *pd[5];
	struct callback_head callback_head;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
};

struct dev_pm_ops___237;

struct device_type___237 {
	const char *name;
	const struct attribute_group___239 **groups;
	int (*uevent)(struct device___237 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___237 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___237 *);
	const struct dev_pm_ops___237 *pm;
};

struct class___237 {
	const char *name;
	struct module___11 *owner;
	const struct attribute_group___239 **class_groups;
	const struct attribute_group___239 **dev_groups;
	struct kobject___262 *dev_kobj;
	int (*dev_uevent)(struct device___237 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___237 *, umode_t *);
	void (*class_release)(struct class___237 *);
	void (*dev_release)(struct device___237 *);
	int (*shutdown_pre)(struct device___237 *);
	const struct kobj_ns_type_operations___24 *ns_type;
	const void * (*namespace)(struct device___237 *);
	const struct dev_pm_ops___237 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct kernfs_root___268;

struct kernfs_elem_dir___268 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___268 *root;
};

struct kernfs_syscall_ops___268;

struct kernfs_root___268 {
	struct kernfs_node___269 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___268 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___268 {
	struct kernfs_node___269 *target_kn;
};

struct kernfs_ops___268;

struct kernfs_elem_attr___268 {
	const struct kernfs_ops___268 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___269 *notify_next;
};

struct kernfs_node___269 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___269 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___268 dir;
		struct kernfs_elem_symlink___268 symlink;
		struct kernfs_elem_attr___268 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___268;

struct kernfs_ops___268 {
	int (*open)(struct kernfs_open_file___268 *);
	void (*release)(struct kernfs_open_file___268 *);
	int (*seq_show)(struct seq_file___240 *, void *);
	void * (*seq_start)(struct seq_file___240 *, loff_t *);
	void * (*seq_next)(struct seq_file___240 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___240 *, void *);
	ssize_t (*read)(struct kernfs_open_file___268 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___268 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___268 *, struct vm_area_struct___275 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___268 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___268 {
	int (*remount_fs)(struct kernfs_root___268 *, int *, char *);
	int (*show_options)(struct seq_file___240 *, struct kernfs_root___268 *);
	int (*mkdir)(struct kernfs_node___269 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___269 *);
	int (*rename)(struct kernfs_node___269 *, struct kernfs_node___269 *, const char *);
	int (*show_path)(struct seq_file___240 *, struct kernfs_node___269 *, struct kernfs_root___268 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___239;

struct seq_file___240 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___239 *op;
	int poll_event;
	const struct file___274 *file;
	void *private;
};

struct kernfs_open_file___268 {
	struct kernfs_node___269 *kn;
	struct file___274 *file;
	struct seq_file___240 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___263 *vm_ops;
};

struct path___274 {
	struct vfsmount *mnt;
	struct dentry___274 *dentry;
};

struct file___274 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___274 f_path;
	struct inode___274 *f_inode;
	const struct file_operations___274 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___102 f_owner;
	const struct cred___261 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___273 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___263;

struct vm_operations_struct___263 {
	void (*open)(struct vm_area_struct___275 *);
	void (*close)(struct vm_area_struct___275 *);
	int (*split)(struct vm_area_struct___275 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___275 *);
	vm_fault_t (*fault)(struct vm_fault___263 *);
	vm_fault_t (*huge_fault)(struct vm_fault___263 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___263 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___275 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___263 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___263 *);
	int (*access)(struct vm_area_struct___275 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___275 *);
	int (*set_policy)(struct vm_area_struct___275 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___275 *, long unsigned int);
	struct page___275 * (*find_special_page)(struct vm_area_struct___275 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___238;

struct attribute_group___239 {
	const char *name;
	umode_t (*is_visible)(struct kobject___262 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___262 *, struct bin_attribute___238 *, int);
	struct attribute **attrs;
	struct bin_attribute___238 **bin_attrs;
};

struct bin_attribute___238 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___274 *, struct kobject___262 *, struct bin_attribute___238 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___274 *, struct kobject___262 *, struct bin_attribute___238 *, char *, loff_t, size_t);
	int (*mmap)(struct file___274 *, struct kobject___262 *, struct bin_attribute___238 *, struct vm_area_struct___275 *);
};

struct sysfs_ops___261 {
	ssize_t (*show)(struct kobject___262 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___262 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___261;

struct kset___261 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___262 kobj;
	const struct kset_uevent_ops___261 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___261 {
	void (*release)(struct kobject___262 *);
	const struct sysfs_ops___261 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___24 * (*child_ns_type)(struct kobject___262 *);
	const void * (*namespace)(struct kobject___262 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___261 {
	int (* const filter)(struct kset___261 *, struct kobject___262 *);
	const char * (* const name)(struct kset___261 *, struct kobject___262 *);
	int (* const uevent)(struct kset___261 *, struct kobject___262 *, struct kobj_uevent_env *);
};

struct kobj_attribute___254 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___262 *, struct kobj_attribute___254 *, char *);
	ssize_t (*store)(struct kobject___262 *, struct kobj_attribute___254 *, const char *, size_t);
};

struct dev_pm_ops___237 {
	int (*prepare)(struct device___237 *);
	void (*complete)(struct device___237 *);
	int (*suspend)(struct device___237 *);
	int (*resume)(struct device___237 *);
	int (*freeze)(struct device___237 *);
	int (*thaw)(struct device___237 *);
	int (*poweroff)(struct device___237 *);
	int (*restore)(struct device___237 *);
	int (*suspend_late)(struct device___237 *);
	int (*resume_early)(struct device___237 *);
	int (*freeze_late)(struct device___237 *);
	int (*thaw_early)(struct device___237 *);
	int (*poweroff_late)(struct device___237 *);
	int (*restore_early)(struct device___237 *);
	int (*suspend_noirq)(struct device___237 *);
	int (*resume_noirq)(struct device___237 *);
	int (*freeze_noirq)(struct device___237 *);
	int (*thaw_noirq)(struct device___237 *);
	int (*poweroff_noirq)(struct device___237 *);
	int (*restore_noirq)(struct device___237 *);
	int (*runtime_suspend)(struct device___237 *);
	int (*runtime_resume)(struct device___237 *);
	int (*runtime_idle)(struct device___237 *);
};

struct dev_pm_domain___237 {
	struct dev_pm_ops___237 ops;
	void (*detach)(struct device___237 *, bool);
	int (*activate)(struct device___237 *);
	void (*sync)(struct device___237 *);
	void (*dismiss)(struct device___237 *);
};

struct bus_type___237 {
	const char *name;
	const char *dev_name;
	struct device___237 *dev_root;
	const struct attribute_group___239 **bus_groups;
	const struct attribute_group___239 **dev_groups;
	const struct attribute_group___239 **drv_groups;
	int (*match)(struct device___237 *, struct device_driver___237 *);
	int (*uevent)(struct device___237 *, struct kobj_uevent_env *);
	int (*probe)(struct device___237 *);
	int (*remove)(struct device___237 *);
	void (*shutdown)(struct device___237 *);
	int (*online)(struct device___237 *);
	int (*offline)(struct device___237 *);
	int (*suspend)(struct device___237 *, pm_message_t);
	int (*resume)(struct device___237 *);
	int (*num_vf)(struct device___237 *);
	int (*dma_configure)(struct device___237 *);
	const struct dev_pm_ops___237 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___237 {
	const char *name;
	struct bus_type___237 *bus;
	struct module___11 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___237 *);
	int (*remove)(struct device___237 *);
	void (*shutdown)(struct device___237 *);
	int (*suspend)(struct device___237 *, pm_message_t);
	int (*resume)(struct device___237 *);
	const struct attribute_group___239 **groups;
	const struct dev_pm_ops___237 *pm;
	void (*coredump)(struct device___237 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct fwnode_operations___172;

struct fwnode_handle___172 {
	struct fwnode_handle___172 *secondary;
	const struct fwnode_operations___172 *ops;
};

struct dentry_operations___273;

struct super_block___273;

struct dentry___274 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___274 *d_parent;
	struct qstr d_name;
	struct inode___274 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___273 *d_op;
	struct super_block___273 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___273;

struct address_space___273 {
	struct inode___274 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___275 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___273 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___273;

struct block_device___273;

struct inode___274 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___273 *i_op;
	struct super_block___273 *i_sb;
	struct address_space___273 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___275 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___143 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___274 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___273 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___273 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___273 {
	int (*d_revalidate)(struct dentry___274 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___274 *, unsigned int);
	int (*d_hash)(const struct dentry___274 *, struct qstr *);
	int (*d_compare)(const struct dentry___274 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___274 *);
	int (*d_init)(struct dentry___274 *);
	void (*d_release)(struct dentry___274 *);
	void (*d_prune)(struct dentry___274 *);
	void (*d_iput)(struct dentry___274 *, struct inode___274 *);
	char * (*d_dname)(struct dentry___274 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___274 *);
	int (*d_manage)(const struct path___274 *, bool);
	struct dentry___274 * (*d_real)(struct dentry___274 *, const struct inode___274 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___273;

struct mem_dqinfo___273 {
	struct quota_format_type___273 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___273;

struct quota_info___273 {
	unsigned int flags;
	struct rw_semaphore___275 dqio_sem;
	struct inode___274 *files[3];
	struct mem_dqinfo___273 info[3];
	const struct quota_format_ops___273 *ops[3];
};

struct rcuwait___273 {
	struct task_struct___275 *task;
};

struct percpu_rw_semaphore___273 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___275 rw_sem;
	struct rcuwait___273 writer;
	int readers_block;
};

struct sb_writers___273 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___273 rw_sem[3];
};

struct file_system_type___273;

struct super_operations___273;

struct dquot_operations___273;

struct quotactl_ops___273;

struct super_block___273 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___273 *s_type;
	const struct super_operations___273 *s_op;
	const struct dquot_operations___273 *dq_op;
	const struct quotactl_ops___273 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___274 *s_root;
	struct rw_semaphore___275 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___273 *s_bdev;
	struct backing_dev_info___143 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___273 s_dquot;
	struct sb_writers___273 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___273 *s_d_op;
	int cleancache_poolid;
	struct shrinker___113 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___218 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

typedef int (*dev_page_fault_t___263)(struct vm_area_struct___275 *, long unsigned int, const struct page___275 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___263)(struct page___275 *, void *);

struct dev_pagemap___263 {
	dev_page_fault_t___263 page_fault;
	dev_page_free_t___263 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___237 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___274 {
	struct task_struct___275 *task;
	struct core_thread___274 *next;
};

struct core_state___274 {
	atomic_t nr_threads;
	struct core_thread___274 dumper;
	struct completion startup;
};

struct vm_fault___263 {
	struct vm_area_struct___275 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___275 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___275 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___274 prealloc_pte;
};

struct io_cq___78 {
	struct request_queue___74 *q;
	struct io_context___78 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___274 {
	struct file___274 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___274 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___273 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___274 *ia_file;
};

struct dquot___273 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___273 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___273 {
	int qf_fmt_id;
	const struct quota_format_ops___273 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___273 *qf_next;
};

struct quota_format_ops___273 {
	int (*check_quota_file)(struct super_block___273 *, int);
	int (*read_file_info)(struct super_block___273 *, int);
	int (*write_file_info)(struct super_block___273 *, int);
	int (*free_file_info)(struct super_block___273 *, int);
	int (*read_dqblk)(struct dquot___273 *);
	int (*commit_dqblk)(struct dquot___273 *);
	int (*release_dqblk)(struct dquot___273 *);
	int (*get_next_id)(struct super_block___273 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___273 {
	int (*write_dquot)(struct dquot___273 *);
	struct dquot___273 * (*alloc_dquot)(struct super_block___273 *, int);
	void (*destroy_dquot)(struct dquot___273 *);
	int (*acquire_dquot)(struct dquot___273 *);
	int (*release_dquot)(struct dquot___273 *);
	int (*mark_dirty)(struct dquot___273 *);
	int (*write_info)(struct super_block___273 *, int);
	qsize_t * (*get_reserved_space)(struct inode___274 *);
	int (*get_projid)(struct inode___274 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___274 *, qsize_t *);
	int (*get_next_id)(struct super_block___273 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___273 {
	int (*quota_on)(struct super_block___273 *, int, int, const struct path___274 *);
	int (*quota_off)(struct super_block___273 *, int);
	int (*quota_enable)(struct super_block___273 *, unsigned int);
	int (*quota_disable)(struct super_block___273 *, unsigned int);
	int (*quota_sync)(struct super_block___273 *, int);
	int (*set_info)(struct super_block___273 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___273 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___273 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___273 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___273 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___273 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___128;

struct address_space_operations___273 {
	int (*writepage)(struct page___275 *, struct writeback_control___128 *);
	int (*readpage)(struct file___274 *, struct page___275 *);
	int (*writepages)(struct address_space___273 *, struct writeback_control___128 *);
	int (*set_page_dirty)(struct page___275 *);
	int (*readpages)(struct file___274 *, struct address_space___273 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___274 *, struct address_space___273 *, loff_t, unsigned int, unsigned int, struct page___275 **, void **);
	int (*write_end)(struct file___274 *, struct address_space___273 *, loff_t, unsigned int, unsigned int, struct page___275 *, void *);
	sector_t (*bmap)(struct address_space___273 *, sector_t);
	void (*invalidatepage)(struct page___275 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___275 *, gfp_t);
	void (*freepage)(struct page___275 *);
	ssize_t (*direct_IO)(struct kiocb___274 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___273 *, struct page___275 *, struct page___275 *, enum migrate_mode);
	bool (*isolate_page)(struct page___275 *, isolate_mode_t);
	void (*putback_page)(struct page___275 *);
	int (*launder_page)(struct page___275 *);
	int (*is_partially_uptodate)(struct page___275 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___275 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___273 *, struct page___275 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___274 *, sector_t *);
	void (*swap_deactivate)(struct file___274 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___128 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___143 *wb;
	struct inode___274 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___273 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___274 *bd_inode;
	struct super_block___273 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___273 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___75 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___75 *bd_disk;
	struct request_queue___74 *bd_queue;
	struct backing_dev_info___143 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___273 {
	struct dentry___274 * (*lookup)(struct inode___274 *, struct dentry___274 *, unsigned int);
	const char * (*get_link)(struct dentry___274 *, struct inode___274 *, struct delayed_call *);
	int (*permission)(struct inode___274 *, int);
	struct posix_acl * (*get_acl)(struct inode___274 *, int);
	int (*readlink)(struct dentry___274 *, char *, int);
	int (*create)(struct inode___274 *, struct dentry___274 *, umode_t, bool);
	int (*link)(struct dentry___274 *, struct inode___274 *, struct dentry___274 *);
	int (*unlink)(struct inode___274 *, struct dentry___274 *);
	int (*symlink)(struct inode___274 *, struct dentry___274 *, const char *);
	int (*mkdir)(struct inode___274 *, struct dentry___274 *, umode_t);
	int (*rmdir)(struct inode___274 *, struct dentry___274 *);
	int (*mknod)(struct inode___274 *, struct dentry___274 *, umode_t, dev_t);
	int (*rename)(struct inode___274 *, struct dentry___274 *, struct inode___274 *, struct dentry___274 *, unsigned int);
	int (*setattr)(struct dentry___274 *, struct iattr___273 *);
	int (*getattr)(const struct path___274 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___274 *, char *, size_t);
	int (*fiemap)(struct inode___274 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___274 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___274 *, struct dentry___274 *, struct file___274 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___274 *, struct dentry___274 *, umode_t);
	int (*set_acl)(struct inode___274 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___273 {
	void (*fl_copy_lock)(struct file_lock___274 *, struct file_lock___274 *);
	void (*fl_release_private)(struct file_lock___274 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___273;

struct lock_manager_operations___273;

struct file_lock___274 {
	struct file_lock___274 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___274 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___273 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___273 *fl_ops;
	const struct lock_manager_operations___273 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___273 {
	int (*lm_compare_owner)(struct file_lock___274 *, struct file_lock___274 *);
	long unsigned int (*lm_owner_key)(struct file_lock___274 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___274 *);
	int (*lm_grant)(struct file_lock___274 *, int);
	bool (*lm_break)(struct file_lock___274 *);
	int (*lm_change)(struct file_lock___274 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___274 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___273 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___273 *fa_next;
	struct file___274 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___273 {
	const char *name;
	int fs_flags;
	struct dentry___274 * (*mount)(struct file_system_type___273 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___273 *);
	struct module___11 *owner;
	struct file_system_type___273 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___273 {
	struct inode___274 * (*alloc_inode)(struct super_block___273 *);
	void (*destroy_inode)(struct inode___274 *);
	void (*dirty_inode)(struct inode___274 *, int);
	int (*write_inode)(struct inode___274 *, struct writeback_control___128 *);
	int (*drop_inode)(struct inode___274 *);
	void (*evict_inode)(struct inode___274 *);
	void (*put_super)(struct super_block___273 *);
	int (*sync_fs)(struct super_block___273 *, int);
	int (*freeze_super)(struct super_block___273 *);
	int (*freeze_fs)(struct super_block___273 *);
	int (*thaw_super)(struct super_block___273 *);
	int (*unfreeze_fs)(struct super_block___273 *);
	int (*statfs)(struct dentry___274 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___273 *, int *, char *);
	void (*umount_begin)(struct super_block___273 *);
	int (*show_options)(struct seq_file___240 *, struct dentry___274 *);
	int (*show_devname)(struct seq_file___240 *, struct dentry___274 *);
	int (*show_path)(struct seq_file___240 *, struct dentry___274 *);
	int (*show_stats)(struct seq_file___240 *, struct dentry___274 *);
	ssize_t (*quota_read)(struct super_block___273 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___273 *, int, const char *, size_t, loff_t);
	struct dquot___273 ** (*get_dquots)(struct inode___274 *);
	int (*bdev_try_to_free_page)(struct super_block___273 *, struct page___275 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___273 *, struct shrink_control___113 *);
	long int (*free_cached_objects)(struct super_block___273 *, struct shrink_control___113 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___75 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___75 *last_lookup;
	struct hd_struct___75 *part[0];
};

struct block_device_operations___75 {
	int (*open)(struct block_device___273 *, fmode_t);
	void (*release)(struct gendisk___75 *, fmode_t);
	int (*rw_page)(struct block_device___273 *, sector_t, struct page___275 *, unsigned int);
	int (*ioctl)(struct block_device___273 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___273 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___75 *, unsigned int);
	int (*media_changed)(struct gendisk___75 *);
	void (*unlock_native_capacity)(struct gendisk___75 *);
	int (*revalidate_disk)(struct gendisk___75 *);
	int (*getgeo)(struct block_device___273 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___273 *, long unsigned int);
	int (*report_zones)(struct gendisk___75 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___11 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___263(struct page___275 *);

struct bdi_writeback_congested___143 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___143 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct cgroup_subsys___203;

struct cgroup_subsys_state___203 {
	struct cgroup___203 *cgroup;
	struct cgroup_subsys___203 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___203 *parent;
};

struct bsg_ops___74 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___74 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___74 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___74 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___74(struct request___74 *, blk_status_t);

struct request___74 {
	struct request_queue___74 *q;
	struct blk_mq_ctx___13 *mq_ctx;
	struct blk_mq_hw_ctx___16 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___143 *bio;
	struct bio___143 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___143 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___78 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___74 *saved_end_io;
		} flush;
	};
	struct gendisk___75 *rq_disk;
	struct hd_struct___75 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___74 *end_io;
	void *end_io_data;
	struct request___74 *next_rq;
};

struct fwnode_reference_args___172;

struct fwnode_endpoint___172;

struct fwnode_operations___172 {
	struct fwnode_handle___172 * (*get)(struct fwnode_handle___172 *);
	void (*put)(struct fwnode_handle___172 *);
	bool (*device_is_available)(const struct fwnode_handle___172 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___172 *, const struct device___237 *);
	bool (*property_present)(const struct fwnode_handle___172 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___172 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___172 *, const char *, const char **, size_t);
	struct fwnode_handle___172 * (*get_parent)(const struct fwnode_handle___172 *);
	struct fwnode_handle___172 * (*get_next_child_node)(const struct fwnode_handle___172 *, struct fwnode_handle___172 *);
	struct fwnode_handle___172 * (*get_named_child_node)(const struct fwnode_handle___172 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___172 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___172 *);
	struct fwnode_handle___172 * (*graph_get_next_endpoint)(const struct fwnode_handle___172 *, struct fwnode_handle___172 *);
	struct fwnode_handle___172 * (*graph_get_remote_endpoint)(const struct fwnode_handle___172 *);
	struct fwnode_handle___172 * (*graph_get_port_parent)(struct fwnode_handle___172 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___172 *, struct fwnode_endpoint___172 *);
};

struct fwnode_endpoint___172 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___172 *local_fwnode;
};

struct fwnode_reference_args___172 {
	struct fwnode_handle___172 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct blk_mq_ctxs___13;

struct blk_mq_ctx___13 {
	struct {
		spinlock_t lock;
		struct list_head rq_lists[3];
		long: 64;
	};
	unsigned int cpu;
	short unsigned int index_hw[3];
	struct blk_mq_hw_ctx___16 *hctxs[3];
	long unsigned int rq_dispatched[2];
	long unsigned int rq_merged;
	long unsigned int rq_completed[2];
	struct request_queue___74 *queue;
	struct blk_mq_ctxs___13 *ctxs;
	struct kobject___262 kobj;
};

struct blk_mq_tags___13;

struct blk_mq_hw_ctx___16 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___74 *queue;
	struct blk_flush_queue___13 *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx___13 *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx___13 **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags___13 *tags;
	struct blk_mq_tags___13 *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	unsigned int rh_reserved_nr_expired;
	struct hlist_node cpuhp_dead;
	struct kobject___262 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___274 *debugfs_dir;
	struct dentry___274 *sched_debugfs_dir;
	struct list_head hctx_list;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___74;

struct blk_mq_alloc_data___13;

struct elevator_mq_ops___74 {
	int (*init_sched)(struct request_queue___74 *, struct elevator_type___74 *);
	void (*exit_sched)(struct elevator_queue___74 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___16 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___16 *, unsigned int);
	bool (*allow_merge)(struct request_queue___74 *, struct request___74 *, struct bio___143 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx___16 *, struct bio___143 *);
	int (*request_merge)(struct request_queue___74 *, struct request___74 **, struct bio___143 *);
	void (*request_merged)(struct request_queue___74 *, struct request___74 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___74 *, struct request___74 *, struct request___74 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data___13 *);
	void (*prepare_request)(struct request___74 *, struct bio___143 *);
	void (*finish_request)(struct request___74 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___16 *, struct list_head *, bool);
	struct request___74 * (*dispatch_request)(struct blk_mq_hw_ctx___16 *);
	bool (*has_work)(struct blk_mq_hw_ctx___16 *);
	void (*completed_request)(struct request___74 *, u64);
	void (*started_request)(struct request___74 *);
	void (*requeue_request)(struct request___74 *);
	struct request___74 * (*former_request)(struct request_queue___74 *, struct request___74 *);
	struct request___74 * (*next_request)(struct request_queue___74 *, struct request___74 *);
	void (*init_icq)(struct io_cq___78 *);
	void (*exit_icq)(struct io_cq___78 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx___16 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___74;

struct elevator_type___74 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___74 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___74 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___11 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___74 {
	struct elevator_type___74 *type;
	void *elevator_data;
	struct kobject___262 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct blk_mq_alloc_data___13 {
	struct request_queue___74 *q;
	blk_mq_req_flags_t flags;
	unsigned int shallow_depth;
	unsigned int cmd_flags;
	struct blk_mq_ctx___13 *ctx;
	struct blk_mq_hw_ctx___16 *hctx;
};

struct elv_fs_entry___74 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___74 *, char *);
	ssize_t (*store)(struct elevator_queue___74 *, const char *, size_t);
};

struct blk_mq_queue_data___16;

typedef blk_status_t queue_rq_fn___16(struct blk_mq_hw_ctx___16 *, const struct blk_mq_queue_data___16 *);

typedef void commit_rqs_fn___16(struct blk_mq_hw_ctx___16 *);

typedef bool get_budget_fn___16(struct blk_mq_hw_ctx___16 *);

typedef void put_budget_fn___16(struct blk_mq_hw_ctx___16 *);

typedef enum blk_eh_timer_return timeout_fn___16(struct request___74 *, bool);

typedef int poll_fn___16(struct blk_mq_hw_ctx___16 *);

typedef void complete_fn___16(struct request___74 *);

typedef int init_hctx_fn___16(struct blk_mq_hw_ctx___16 *, void *, unsigned int);

typedef void exit_hctx_fn___16(struct blk_mq_hw_ctx___16 *, unsigned int);

typedef int init_request_fn___16(struct blk_mq_tag_set___16 *, struct request___74 *, unsigned int, unsigned int);

typedef void exit_request_fn___16(struct blk_mq_tag_set___16 *, struct request___74 *, unsigned int);

typedef bool busy_fn___16(struct request_queue___74 *);

typedef int map_queues_fn___16(struct blk_mq_tag_set___16 *);

typedef void cleanup_rq_fn___16(struct request___74 *);

struct blk_mq_ops___16 {
	queue_rq_fn___16 *queue_rq;
	commit_rqs_fn___16 *commit_rqs;
	get_budget_fn___16 *get_budget;
	put_budget_fn___16 *put_budget;
	timeout_fn___16 *timeout;
	poll_fn___16 *poll;
	complete_fn___16 *complete;
	init_hctx_fn___16 *init_hctx;
	exit_hctx_fn___16 *exit_hctx;
	init_request_fn___16 *init_request;
	exit_request_fn___16 *exit_request;
	void (*initialize_rq_fn)(struct request___74 *);
	busy_fn___16 *busy;
	map_queues_fn___16 *map_queues;
	void (*show_rq)(struct seq_file___240 *, struct request___74 *);
	union {
		cleanup_rq_fn___16 *cleanup_rq;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide42;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct blk_stat_callback___13 {
	struct list_head list;
	struct timer_list timer;
	struct blk_rq_stat *cpu_stat;
	int (*bucket_fn)(const struct request___74 *);
	unsigned int buckets;
	struct blk_rq_stat *stat;
	void (*timer_fn)(struct blk_stat_callback___13 *);
	void *data;
	struct callback_head rcu;
};

struct blk_flush_queue___13 {
	unsigned int flush_queue_delayed: 1;
	unsigned int flush_pending_idx: 1;
	unsigned int flush_running_idx: 1;
	long unsigned int flush_pending_since;
	struct list_head flush_queue[2];
	struct list_head flush_data_in_flight;
	struct request___74 *flush_rq;
	struct request___74 *orig_rq;
	spinlock_t mq_flush_lock;
};

struct blk_mq_tag_set___16 {
	struct blk_mq_queue_map map[6];
	unsigned int nr_maps;
	const struct blk_mq_ops___16 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	struct blk_mq_tags___13 **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef int (*key_restrict_link_func_t___262)(struct key___261 *, const struct key_type *, const union key_payload *, struct key___261 *);

struct key_restriction___261;

struct key___261 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___275 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___261 *restrict_link;
};

struct key_restriction___261 {
	key_restrict_link_func_t___262 check;
	struct key___261 *key;
	struct key_type *keytype;
};

struct seq_operations___239 {
	void * (*start)(struct seq_file___240 *, loff_t *);
	void (*stop)(struct seq_file___240 *, void *);
	void * (*next)(struct seq_file___240 *, void *, loff_t *);
	int (*show)(struct seq_file___240 *, void *);
};

struct cgroup_namespace___203 {
	refcount_t count;
	struct ns_common___9 ns;
	struct user_namespace___218 *user_ns;
	struct ucounts___218 *ucounts;
	struct css_set___203 *root_cset;
};

struct ucounts___218 {
	struct hlist_node node;
	struct user_namespace___218 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___204;

struct bpf_map_ops___203 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___204 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___204 *, struct file___274 *);
	void (*map_free)(struct bpf_map___204 *);
	int (*map_get_next_key)(struct bpf_map___204 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___204 *);
	void * (*map_lookup_elem)(struct bpf_map___204 *, void *);
	int (*map_update_elem)(struct bpf_map___204 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___204 *, void *);
	int (*map_push_elem)(struct bpf_map___204 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___204 *, void *);
	int (*map_peek_elem)(struct bpf_map___204 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___204 *, struct file___274 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___204 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___204 *, void *, struct seq_file___240 *);
	int (*map_check_btf)(const struct bpf_map___204 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___204 {
	const struct bpf_map_ops___203 *ops;
	struct bpf_map___204 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___261 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___203;

typedef void (*kthread_work_func_t___203)(struct kthread_work___203 *);

struct kthread_worker___203;

struct kthread_work___203 {
	struct list_head node;
	kthread_work_func_t___203 func;
	struct kthread_worker___203 *worker;
	int canceling;
};

struct kthread_worker___203 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___275 *task;
	struct kthread_work___203 *current_work;
};

struct kthread_delayed_work___203 {
	struct kthread_work___203 work;
	struct timer_list timer;
};

struct psi_group___203 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___203 *poll_kworker;
	struct kthread_delayed_work___203 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___203 {
	struct kernfs_node___269 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_root___203;

struct cgroup_rstat_cpu___203;

struct cgroup___203 {
	struct cgroup_subsys_state___203 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___269 *kn;
	struct cgroup_file___203 procs_file;
	struct cgroup_file___203 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___203 *subsys[13];
	struct cgroup_root___203 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___203 *dom_cgrp;
	struct cgroup_rstat_cpu___203 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___19 bpf;
	atomic_t congestion_count;
	struct cgroup___203 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___203 psi;
	int ancestor_ids[0];
};

struct cftype___203;

struct cgroup_subsys___203 {
	struct cgroup_subsys_state___203 * (*css_alloc)(struct cgroup_subsys_state___203 *);
	int (*css_online)(struct cgroup_subsys_state___203 *);
	void (*css_offline)(struct cgroup_subsys_state___203 *);
	void (*css_released)(struct cgroup_subsys_state___203 *);
	void (*css_free)(struct cgroup_subsys_state___203 *);
	void (*css_reset)(struct cgroup_subsys_state___203 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___203 *, int);
	int (*css_extra_stat_show)(struct seq_file___240 *, struct cgroup_subsys_state___203 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___275 *);
	void (*cancel_fork)(struct task_struct___275 *);
	void (*fork)(struct task_struct___275 *);
	void (*exit)(struct task_struct___275 *);
	void (*free)(struct task_struct___275 *);
	void (*bind)(struct cgroup_subsys_state___203 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___203 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___203 *dfl_cftypes;
	struct cftype___203 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___203 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___203 *updated_children;
	struct cgroup___203 *updated_next;
};

struct cgroup_root___203 {
	struct kernfs_root___268 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___203 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___203 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___203 *ss;
	struct list_head node;
	struct kernfs_ops___268 *kf_ops;
	int (*open)(struct kernfs_open_file___268 *);
	void (*release)(struct kernfs_open_file___268 *);
	u64 (*read_u64)(struct cgroup_subsys_state___203 *, struct cftype___203 *);
	s64 (*read_s64)(struct cgroup_subsys_state___203 *, struct cftype___203 *);
	int (*seq_show)(struct seq_file___240 *, void *);
	void * (*seq_start)(struct seq_file___240 *, loff_t *);
	void * (*seq_next)(struct seq_file___240 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___240 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___203 *, struct cftype___203 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___203 *, struct cftype___203 *, s64);
	ssize_t (*write)(struct kernfs_open_file___268 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___268 *, struct poll_table_struct___6 *);
};

struct blkcg_policy_data___53;

struct blkcg___53 {
	struct cgroup_subsys_state___203 css;
	spinlock_t lock;
	struct xarray blkg_tree;
	struct blkcg_gq___53 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___53 *cpd[5];
	struct list_head all_blkcgs_node;
	struct list_head cgwb_list;
	refcount_t cgwb_refcnt;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct blkcg_policy_data___53 {
	struct blkcg___53 *blkcg;
	int plid;
};

struct blkg_policy_data___53 {
	struct blkcg_gq___53 *blkg;
	int plid;
};

struct blk_mq_tags___13 {
	unsigned int nr_tags;
	unsigned int nr_reserved_tags;
	atomic_t active_queues;
	struct sbitmap_queue bitmap_tags;
	struct sbitmap_queue breserved_tags;
	struct request___74 **rqs;
	struct request___74 **static_rqs;
	struct list_head page_list;
};

struct blk_mq_queue_data___16 {
	struct request___74 *rq;
	bool last;
	long unsigned int rh_reserved1;
};

struct blk_mq_ctxs___13 {
	struct kobject___262 kobj;
	struct blk_mq_ctx___13 *queue_ctx;
};

struct integrity_sysfs_entry {
	struct attribute attr;
	ssize_t (*show)(struct blk_integrity *, char *);
	ssize_t (*store)(struct blk_integrity *, const char *, size_t);
};

enum t10_dif_type {
	T10_PI_TYPE0_PROTECTION = 0,
	T10_PI_TYPE1_PROTECTION = 1,
	T10_PI_TYPE2_PROTECTION = 2,
	T10_PI_TYPE3_PROTECTION = 3,
};

struct t10_pi_tuple {
	__be16 guard_tag;
	__be16 app_tag;
	__be32 ref_tag;
};

typedef __be16 csum_fn(void *, unsigned int);

struct module___222;

struct file___275;

struct kiocb___275;

struct vm_area_struct___276;

struct inode___275;

struct file_lock___275;

struct page___276;

struct file_operations___275 {
	struct module___222 *owner;
	loff_t (*llseek)(struct file___275 *, loff_t, int);
	ssize_t (*read)(struct file___275 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___275 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___275 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___275 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___275 *, bool);
	int (*iterate)(struct file___275 *, struct dir_context *);
	int (*iterate_shared)(struct file___275 *, struct dir_context *);
	__poll_t (*poll)(struct file___275 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___275 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___275 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___275 *, struct vm_area_struct___276 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___275 *, struct file___275 *);
	int (*flush)(struct file___275 *, fl_owner_t);
	int (*release)(struct inode___275 *, struct file___275 *);
	int (*fsync)(struct file___275 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___275 *, int);
	int (*lock)(struct file___275 *, int, struct file_lock___275 *);
	ssize_t (*sendpage)(struct file___275 *, struct page___276 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___275 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___275 *, int, struct file_lock___275 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___275 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___275 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___275 *, long int, struct file_lock___275 **, void **);
	long int (*fallocate)(struct file___275 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___275 *);
	ssize_t (*copy_file_range)(struct file___275 *, loff_t, struct file___275 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___275 *, loff_t, struct file___275 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___275 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___275 {
	u64 seqnum;
	struct vm_area_struct___276 *vmas[4];
};

struct page_frag___275 {
	struct page___276 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___275;

struct bio_list___144;

struct backing_dev_info___144;

struct io_context___79;

struct request_queue___75;

struct vm_struct___191;

struct task_struct___276 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___276 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___275 *mm;
	struct mm_struct___275 *active_mm;
	struct vmacache___275 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___276 *real_parent;
	struct task_struct___276 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___276 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___103 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___103 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___103 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___2 *ptracer_cred;
	const struct cred___2 *real_cred;
	const struct cred___2 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___276 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___144 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___144 *backing_dev_info;
	struct io_context___79 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___275 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___75 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___276 *oom_reaper_list;
	struct vm_struct___191 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___78 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___276 *pgtable_t___275;

struct address_space___274;

struct dev_pagemap___264;

struct page___276 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___274 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___276 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___275 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___275 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___264 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___275;

struct lruvec___275 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___275 *pgdat;
};

struct zone___275 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___275 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___275 {
	struct zone___275 *zone;
	int zone_idx;
};

struct zonelist___275 {
	struct zoneref___275 _zonerefs[25];
};

struct pglist_data___275 {
	struct zone___275 node_zones[3];
	struct zonelist___275 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___276 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___276 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___275 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___276 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___276 *owner;
};

struct secondary_data___276 {
	void *stack;
	struct task_struct___276 *task;
	long int status;
};

struct blocking_notifier_head___275 {
	struct rw_semaphore___276 rwsem;
	struct notifier_block *head;
};

struct kernfs_root___269;

struct kernfs_elem_dir___269 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___269 *root;
};

struct kernfs_node___270;

struct kernfs_syscall_ops___269;

struct kernfs_root___269 {
	struct kernfs_node___270 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___269 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___269 {
	struct kernfs_node___270 *target_kn;
};

struct kernfs_ops___269;

struct kernfs_elem_attr___269 {
	const struct kernfs_ops___269 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___270 *notify_next;
};

struct kernfs_node___270 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___270 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___269 dir;
		struct kernfs_elem_symlink___269 symlink;
		struct kernfs_elem_attr___269 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___269;

struct kernfs_ops___269 {
	int (*open)(struct kernfs_open_file___269 *);
	void (*release)(struct kernfs_open_file___269 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___269 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___269 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___269 *, struct vm_area_struct___276 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___269 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___269 {
	int (*remount_fs)(struct kernfs_root___269 *, int *, char *);
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___269 *);
	int (*mkdir)(struct kernfs_node___270 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___270 *);
	int (*rename)(struct kernfs_node___270 *, struct kernfs_node___270 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___270 *, struct kernfs_root___269 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_operations_struct___264;

struct kernfs_open_file___269 {
	struct kernfs_node___270 *kn;
	struct file___275 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___264 *vm_ops;
};

struct dentry___275;

struct path___275 {
	struct vfsmount *mnt;
	struct dentry___275 *dentry;
};

struct file___275 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___275 f_path;
	struct inode___275 *f_inode;
	const struct file_operations___275 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___102 f_owner;
	const struct cred___2 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___274 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___264;

struct vm_operations_struct___264 {
	void (*open)(struct vm_area_struct___276 *);
	void (*close)(struct vm_area_struct___276 *);
	int (*split)(struct vm_area_struct___276 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___276 *);
	vm_fault_t (*fault)(struct vm_fault___264 *);
	vm_fault_t (*huge_fault)(struct vm_fault___264 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___264 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___276 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___264 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___264 *);
	int (*access)(struct vm_area_struct___276 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___276 *);
	int (*set_policy)(struct vm_area_struct___276 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___276 *, long unsigned int);
	struct page___276 * (*find_special_page)(struct vm_area_struct___276 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_area_struct___276 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___276 *vm_next;
	struct vm_area_struct___276 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___275 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___264 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___275 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___263;

struct bin_attribute___239;

struct attribute_group___240 {
	const char *name;
	umode_t (*is_visible)(struct kobject___263 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___263 *, struct bin_attribute___239 *, int);
	struct attribute **attrs;
	struct bin_attribute___239 **bin_attrs;
};

struct kset___262;

struct kobj_type___262;

struct kobject___263 {
	const char *name;
	struct list_head entry;
	struct kobject___263 *parent;
	struct kset___262 *kset;
	struct kobj_type___262 *ktype;
	struct kernfs_node___270 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___239 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___275 *, struct kobject___263 *, struct bin_attribute___239 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___275 *, struct kobject___263 *, struct bin_attribute___239 *, char *, loff_t, size_t);
	int (*mmap)(struct file___275 *, struct kobject___263 *, struct bin_attribute___239 *, struct vm_area_struct___276 *);
};

struct sysfs_ops___262 {
	ssize_t (*show)(struct kobject___263 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___263 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___262;

struct kset___262 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___263 kobj;
	const struct kset_uevent_ops___262 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___262 {
	void (*release)(struct kobject___263 *);
	const struct sysfs_ops___262 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___9 * (*child_ns_type)(struct kobject___263 *);
	const void * (*namespace)(struct kobject___263 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___262 {
	int (* const filter)(struct kset___262 *, struct kobject___263 *);
	const char * (* const name)(struct kset___262 *, struct kobject___263 *);
	int (* const uevent)(struct kset___262 *, struct kobject___263 *, struct kobj_uevent_env *);
};

struct kobj_attribute___255 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___263 *, struct kobj_attribute___255 *, char *);
	ssize_t (*store)(struct kobject___263 *, struct kobj_attribute___255 *, const char *, size_t);
};

struct core_state___275;

struct mm_struct___275 {
	struct {
		struct vm_area_struct___276 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___275 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___276 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___275 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___276 *owner;
		struct user_namespace___3 *user_ns;
		struct file___275 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___275 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct bio___144;

struct bio_list___144 {
	struct bio___144 *head;
	struct bio___144 *tail;
};

struct bdi_writeback_congested___144;

struct bdi_writeback___144 {
	struct backing_dev_info___144 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___144 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___157 *memcg_css;
	struct cgroup_subsys_state___157 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___238;

struct backing_dev_info___144 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___144 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___238 *dev;
	struct device___238 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___275 *debug_dir;
	struct dentry___275 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___79;

struct io_context___79 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___79 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

typedef blk_qc_t make_request_fn___75(struct request_queue___75 *, struct bio___144 *);

struct request___75;

typedef int dma_drain_needed_fn___75(struct request___75 *);

struct bsg_ops___75;

struct bsg_class_device___75 {
	struct device___238 *class_dev;
	int minor;
	struct request_queue___75 *queue;
	const struct bsg_ops___75 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___144 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___144 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___75;

struct blk_mq_ops___17;

struct blk_mq_ctx___14;

struct blk_mq_hw_ctx___17;

struct blk_stat_callback___14;

struct blk_mq_tag_set___17;

struct request_queue___75 {
	struct list_head queue_head;
	struct request___75 *last_merge;
	struct elevator_queue___75 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___75 *make_request_fn;
	dma_drain_needed_fn___75 *dma_drain_needed;
	const struct blk_mq_ops___17 *mq_ops;
	struct blk_mq_ctx___14 *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___17 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___144 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___263 kobj;
	struct kobject___263 *mq_kobj;
	struct blk_integrity integrity;
	struct device___238 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback___14 *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	struct bsg_class_device___75 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set___17 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___144 bio_split;
	struct dentry___275 *debugfs_dir;
	struct dentry___275 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___191 {
	struct vm_struct___191 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___276 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bio_vec___144 {
	struct page___276 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

typedef void bio_end_io_t___144(struct bio___144 *);

struct gendisk___76;

struct bio_integrity_payload___144;

struct bio___144 {
	struct bio___144 *bi_next;
	struct gendisk___76 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___144 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___144 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___144 *bi_io_vec;
	struct bio_set___144 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___144 bi_inline_vecs[0];
};

struct bio_integrity_payload___144 {
	struct bio___144 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___144 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___144 bip_inline_vecs[0];
};

struct dev_pm_info___238 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___238 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___238;

struct bus_type___238;

struct device_driver___238;

struct dev_pm_domain___238;

struct dma_map_ops___66;

struct fwnode_handle___173;

struct class___238;

struct device___238 {
	struct device___238 *parent;
	struct device_private *p;
	struct kobject___263 kobj;
	const char *init_name;
	const struct device_type___238 *type;
	struct mutex mutex;
	struct bus_type___238 *bus;
	struct device_driver___238 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___238 power;
	struct dev_pm_domain___238 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___66 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___173 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___238 *class;
	const struct attribute_group___240 **groups;
	void (*release)(struct device___238 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___76 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___238 __dev;
	struct kobject___263 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___76;

struct block_device_operations___76;

struct gendisk___76 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___76 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___76 *part_tbl;
	struct hd_struct___76 part0;
	const struct block_device_operations___76 *fops;
	struct request_queue___75 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___276 lookup_sem;
	struct kobject___263 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___263 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_ops___238;

struct device_type___238 {
	const char *name;
	const struct attribute_group___240 **groups;
	int (*uevent)(struct device___238 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___238 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___238 *);
	const struct dev_pm_ops___238 *pm;
};

struct class___238 {
	const char *name;
	struct module___222 *owner;
	const struct attribute_group___240 **class_groups;
	const struct attribute_group___240 **dev_groups;
	struct kobject___263 *dev_kobj;
	int (*dev_uevent)(struct device___238 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___238 *, umode_t *);
	void (*class_release)(struct class___238 *);
	void (*dev_release)(struct device___238 *);
	int (*shutdown_pre)(struct device___238 *);
	const struct kobj_ns_type_operations___9 *ns_type;
	const void * (*namespace)(struct device___238 *);
	const struct dev_pm_ops___238 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dev_pm_ops___238 {
	int (*prepare)(struct device___238 *);
	void (*complete)(struct device___238 *);
	int (*suspend)(struct device___238 *);
	int (*resume)(struct device___238 *);
	int (*freeze)(struct device___238 *);
	int (*thaw)(struct device___238 *);
	int (*poweroff)(struct device___238 *);
	int (*restore)(struct device___238 *);
	int (*suspend_late)(struct device___238 *);
	int (*resume_early)(struct device___238 *);
	int (*freeze_late)(struct device___238 *);
	int (*thaw_early)(struct device___238 *);
	int (*poweroff_late)(struct device___238 *);
	int (*restore_early)(struct device___238 *);
	int (*suspend_noirq)(struct device___238 *);
	int (*resume_noirq)(struct device___238 *);
	int (*freeze_noirq)(struct device___238 *);
	int (*thaw_noirq)(struct device___238 *);
	int (*poweroff_noirq)(struct device___238 *);
	int (*restore_noirq)(struct device___238 *);
	int (*runtime_suspend)(struct device___238 *);
	int (*runtime_resume)(struct device___238 *);
	int (*runtime_idle)(struct device___238 *);
};

struct dev_pm_domain___238 {
	struct dev_pm_ops___238 ops;
	void (*detach)(struct device___238 *, bool);
	int (*activate)(struct device___238 *);
	void (*sync)(struct device___238 *);
	void (*dismiss)(struct device___238 *);
};

struct bus_type___238 {
	const char *name;
	const char *dev_name;
	struct device___238 *dev_root;
	const struct attribute_group___240 **bus_groups;
	const struct attribute_group___240 **dev_groups;
	const struct attribute_group___240 **drv_groups;
	int (*match)(struct device___238 *, struct device_driver___238 *);
	int (*uevent)(struct device___238 *, struct kobj_uevent_env *);
	int (*probe)(struct device___238 *);
	int (*remove)(struct device___238 *);
	void (*shutdown)(struct device___238 *);
	int (*online)(struct device___238 *);
	int (*offline)(struct device___238 *);
	int (*suspend)(struct device___238 *, pm_message_t);
	int (*resume)(struct device___238 *);
	int (*num_vf)(struct device___238 *);
	int (*dma_configure)(struct device___238 *);
	const struct dev_pm_ops___238 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___238 {
	const char *name;
	struct bus_type___238 *bus;
	struct module___222 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___238 *);
	int (*remove)(struct device___238 *);
	void (*shutdown)(struct device___238 *);
	int (*suspend)(struct device___238 *, pm_message_t);
	int (*resume)(struct device___238 *);
	const struct attribute_group___240 **groups;
	const struct dev_pm_ops___238 *pm;
	void (*coredump)(struct device___238 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct module_kobject___219 {
	struct kobject___263 kobj;
	struct module___222 *mod;
	struct kobject___263 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___219 {
	struct module___222 *mod;
	struct latch_tree_node node;
};

struct module_layout___219 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___219 mtn;
};

struct module_attribute___219;

struct kernel_param___219;

struct module___222 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___219 mkobj;
	struct module_attribute___219 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___263 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___219 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___219 core_layout;
	struct module_layout___219 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide46;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide47;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dma_map_ops___66 {
	void * (*alloc)(struct device___238 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___238 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___238 *, struct vm_area_struct___276 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___238 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___238 *, struct page___276 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___238 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___238 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___238 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___238 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___238 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___238 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide43;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___238 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___238 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___238 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___238 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___238 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___238 *, u64);
	u64 (*get_required_mask)(struct device___238 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___173;

struct fwnode_handle___173 {
	struct fwnode_handle___173 *secondary;
	const struct fwnode_operations___173 *ops;
};

struct dentry_operations___274;

struct super_block___274;

struct dentry___275 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___275 *d_parent;
	struct qstr d_name;
	struct inode___275 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___274 *d_op;
	struct super_block___274 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___274;

struct address_space___274 {
	struct inode___275 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___276 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___274 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___274;

struct block_device___274;

struct inode___275 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___274 *i_op;
	struct super_block___274 *i_sb;
	struct address_space___274 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___276 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___144 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___275 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___274 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___274 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___274 {
	int (*d_revalidate)(struct dentry___275 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___275 *, unsigned int);
	int (*d_hash)(const struct dentry___275 *, struct qstr *);
	int (*d_compare)(const struct dentry___275 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___275 *);
	int (*d_init)(struct dentry___275 *);
	void (*d_release)(struct dentry___275 *);
	void (*d_prune)(struct dentry___275 *);
	void (*d_iput)(struct dentry___275 *, struct inode___275 *);
	char * (*d_dname)(struct dentry___275 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___275 *);
	int (*d_manage)(const struct path___275 *, bool);
	struct dentry___275 * (*d_real)(struct dentry___275 *, const struct inode___275 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___274;

struct mem_dqinfo___274 {
	struct quota_format_type___274 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___274;

struct quota_info___274 {
	unsigned int flags;
	struct rw_semaphore___276 dqio_sem;
	struct inode___275 *files[3];
	struct mem_dqinfo___274 info[3];
	const struct quota_format_ops___274 *ops[3];
};

struct rcuwait___274 {
	struct task_struct___276 *task;
};

struct percpu_rw_semaphore___274 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___276 rw_sem;
	struct rcuwait___274 writer;
	int readers_block;
};

struct sb_writers___274 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___274 rw_sem[3];
};

struct file_system_type___274;

struct super_operations___274;

struct dquot_operations___274;

struct quotactl_ops___274;

struct super_block___274 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___274 *s_type;
	const struct super_operations___274 *s_op;
	const struct dquot_operations___274 *dq_op;
	const struct quotactl_ops___274 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___275 *s_root;
	struct rw_semaphore___276 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___274 *s_bdev;
	struct backing_dev_info___144 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___274 s_dquot;
	struct sb_writers___274 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___274 *s_d_op;
	int cleancache_poolid;
	struct shrinker___43 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

typedef int (*dev_page_fault_t___264)(struct vm_area_struct___276 *, long unsigned int, const struct page___276 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___264)(struct page___276 *, void *);

struct dev_pagemap___264 {
	dev_page_fault_t___264 page_fault;
	dev_page_free_t___264 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___238 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___275 {
	struct task_struct___276 *task;
	struct core_thread___275 *next;
};

struct core_state___275 {
	atomic_t nr_threads;
	struct core_thread___275 dumper;
	struct completion startup;
};

struct vm_fault___264 {
	struct vm_area_struct___276 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___276 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___276 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___275 prealloc_pte;
};

struct io_cq___79 {
	struct request_queue___75 *q;
	struct io_context___79 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___275 {
	struct file___275 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___275 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___274 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___275 *ia_file;
};

struct dquot___274 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___274 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___274 {
	int qf_fmt_id;
	const struct quota_format_ops___274 *qf_ops;
	struct module___222 *qf_owner;
	struct quota_format_type___274 *qf_next;
};

struct quota_format_ops___274 {
	int (*check_quota_file)(struct super_block___274 *, int);
	int (*read_file_info)(struct super_block___274 *, int);
	int (*write_file_info)(struct super_block___274 *, int);
	int (*free_file_info)(struct super_block___274 *, int);
	int (*read_dqblk)(struct dquot___274 *);
	int (*commit_dqblk)(struct dquot___274 *);
	int (*release_dqblk)(struct dquot___274 *);
	int (*get_next_id)(struct super_block___274 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___274 {
	int (*write_dquot)(struct dquot___274 *);
	struct dquot___274 * (*alloc_dquot)(struct super_block___274 *, int);
	void (*destroy_dquot)(struct dquot___274 *);
	int (*acquire_dquot)(struct dquot___274 *);
	int (*release_dquot)(struct dquot___274 *);
	int (*mark_dirty)(struct dquot___274 *);
	int (*write_info)(struct super_block___274 *, int);
	qsize_t * (*get_reserved_space)(struct inode___275 *);
	int (*get_projid)(struct inode___275 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___275 *, qsize_t *);
	int (*get_next_id)(struct super_block___274 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___274 {
	int (*quota_on)(struct super_block___274 *, int, int, const struct path___275 *);
	int (*quota_off)(struct super_block___274 *, int);
	int (*quota_enable)(struct super_block___274 *, unsigned int);
	int (*quota_disable)(struct super_block___274 *, unsigned int);
	int (*quota_sync)(struct super_block___274 *, int);
	int (*set_info)(struct super_block___274 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___274 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___274 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___274 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___274 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___274 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___274 {
	int (*writepage)(struct page___276 *, struct writeback_control___3 *);
	int (*readpage)(struct file___275 *, struct page___276 *);
	int (*writepages)(struct address_space___274 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___276 *);
	int (*readpages)(struct file___275 *, struct address_space___274 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___275 *, struct address_space___274 *, loff_t, unsigned int, unsigned int, struct page___276 **, void **);
	int (*write_end)(struct file___275 *, struct address_space___274 *, loff_t, unsigned int, unsigned int, struct page___276 *, void *);
	sector_t (*bmap)(struct address_space___274 *, sector_t);
	void (*invalidatepage)(struct page___276 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___276 *, gfp_t);
	void (*freepage)(struct page___276 *);
	ssize_t (*direct_IO)(struct kiocb___275 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___274 *, struct page___276 *, struct page___276 *, enum migrate_mode);
	bool (*isolate_page)(struct page___276 *, isolate_mode_t);
	void (*putback_page)(struct page___276 *);
	int (*launder_page)(struct page___276 *);
	int (*is_partially_uptodate)(struct page___276 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___276 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___274 *, struct page___276 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___275 *, sector_t *);
	void (*swap_deactivate)(struct file___275 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___274 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___275 *bd_inode;
	struct super_block___274 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___274 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___76 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___76 *bd_disk;
	struct request_queue___75 *bd_queue;
	struct backing_dev_info___144 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___274 {
	struct dentry___275 * (*lookup)(struct inode___275 *, struct dentry___275 *, unsigned int);
	const char * (*get_link)(struct dentry___275 *, struct inode___275 *, struct delayed_call *);
	int (*permission)(struct inode___275 *, int);
	struct posix_acl * (*get_acl)(struct inode___275 *, int);
	int (*readlink)(struct dentry___275 *, char *, int);
	int (*create)(struct inode___275 *, struct dentry___275 *, umode_t, bool);
	int (*link)(struct dentry___275 *, struct inode___275 *, struct dentry___275 *);
	int (*unlink)(struct inode___275 *, struct dentry___275 *);
	int (*symlink)(struct inode___275 *, struct dentry___275 *, const char *);
	int (*mkdir)(struct inode___275 *, struct dentry___275 *, umode_t);
	int (*rmdir)(struct inode___275 *, struct dentry___275 *);
	int (*mknod)(struct inode___275 *, struct dentry___275 *, umode_t, dev_t);
	int (*rename)(struct inode___275 *, struct dentry___275 *, struct inode___275 *, struct dentry___275 *, unsigned int);
	int (*setattr)(struct dentry___275 *, struct iattr___274 *);
	int (*getattr)(const struct path___275 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___275 *, char *, size_t);
	int (*fiemap)(struct inode___275 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___275 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___275 *, struct dentry___275 *, struct file___275 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___275 *, struct dentry___275 *, umode_t);
	int (*set_acl)(struct inode___275 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___274 {
	void (*fl_copy_lock)(struct file_lock___275 *, struct file_lock___275 *);
	void (*fl_release_private)(struct file_lock___275 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___274;

struct lock_manager_operations___274;

struct file_lock___275 {
	struct file_lock___275 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___275 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___274 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___274 *fl_ops;
	const struct lock_manager_operations___274 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___274 {
	int (*lm_compare_owner)(struct file_lock___275 *, struct file_lock___275 *);
	long unsigned int (*lm_owner_key)(struct file_lock___275 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___275 *);
	int (*lm_grant)(struct file_lock___275 *, int);
	bool (*lm_break)(struct file_lock___275 *);
	int (*lm_change)(struct file_lock___275 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___275 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___274 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___274 *fa_next;
	struct file___275 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___274 {
	const char *name;
	int fs_flags;
	struct dentry___275 * (*mount)(struct file_system_type___274 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___274 *);
	struct module___222 *owner;
	struct file_system_type___274 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___274 {
	struct inode___275 * (*alloc_inode)(struct super_block___274 *);
	void (*destroy_inode)(struct inode___275 *);
	void (*dirty_inode)(struct inode___275 *, int);
	int (*write_inode)(struct inode___275 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___275 *);
	void (*evict_inode)(struct inode___275 *);
	void (*put_super)(struct super_block___274 *);
	int (*sync_fs)(struct super_block___274 *, int);
	int (*freeze_super)(struct super_block___274 *);
	int (*freeze_fs)(struct super_block___274 *);
	int (*thaw_super)(struct super_block___274 *);
	int (*unfreeze_fs)(struct super_block___274 *);
	int (*statfs)(struct dentry___275 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___274 *, int *, char *);
	void (*umount_begin)(struct super_block___274 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___275 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___275 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___275 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___275 *);
	ssize_t (*quota_read)(struct super_block___274 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___274 *, int, const char *, size_t, loff_t);
	struct dquot___274 ** (*get_dquots)(struct inode___275 *);
	int (*bdev_try_to_free_page)(struct super_block___274 *, struct page___276 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___274 *, struct shrink_control___43 *);
	long int (*free_cached_objects)(struct super_block___274 *, struct shrink_control___43 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___76 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___76 *last_lookup;
	struct hd_struct___76 *part[0];
};

struct block_device_operations___76 {
	int (*open)(struct block_device___274 *, fmode_t);
	void (*release)(struct gendisk___76 *, fmode_t);
	int (*rw_page)(struct block_device___274 *, sector_t, struct page___276 *, unsigned int);
	int (*ioctl)(struct block_device___274 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___274 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___76 *, unsigned int);
	int (*media_changed)(struct gendisk___76 *);
	void (*unlock_native_capacity)(struct gendisk___76 *);
	int (*revalidate_disk)(struct gendisk___76 *);
	int (*getgeo)(struct block_device___274 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___274 *, long unsigned int);
	int (*report_zones)(struct gendisk___76 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___222 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___264(struct page___276 *);

struct bdi_writeback_congested___144 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___144 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bsg_ops___75 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___75 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___75 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___75 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___75(struct request___75 *, blk_status_t);

struct request___75 {
	struct request_queue___75 *q;
	struct blk_mq_ctx___14 *mq_ctx;
	struct blk_mq_hw_ctx___17 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___144 *bio;
	struct bio___144 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___144 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___79 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___75 *saved_end_io;
		} flush;
	};
	struct gendisk___76 *rq_disk;
	struct hd_struct___76 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___75 *end_io;
	void *end_io_data;
	struct request___75 *next_rq;
};

struct fwnode_reference_args___173;

struct fwnode_endpoint___173;

struct fwnode_operations___173 {
	struct fwnode_handle___173 * (*get)(struct fwnode_handle___173 *);
	void (*put)(struct fwnode_handle___173 *);
	bool (*device_is_available)(const struct fwnode_handle___173 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___173 *, const struct device___238 *);
	bool (*property_present)(const struct fwnode_handle___173 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___173 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___173 *, const char *, const char **, size_t);
	struct fwnode_handle___173 * (*get_parent)(const struct fwnode_handle___173 *);
	struct fwnode_handle___173 * (*get_next_child_node)(const struct fwnode_handle___173 *, struct fwnode_handle___173 *);
	struct fwnode_handle___173 * (*get_named_child_node)(const struct fwnode_handle___173 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___173 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___173 *);
	struct fwnode_handle___173 * (*graph_get_next_endpoint)(const struct fwnode_handle___173 *, struct fwnode_handle___173 *);
	struct fwnode_handle___173 * (*graph_get_remote_endpoint)(const struct fwnode_handle___173 *);
	struct fwnode_handle___173 * (*graph_get_port_parent)(struct fwnode_handle___173 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___173 *, struct fwnode_endpoint___173 *);
};

struct fwnode_endpoint___173 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___173 *local_fwnode;
};

struct fwnode_reference_args___173 {
	struct fwnode_handle___173 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct blk_mq_ctxs___14;

struct blk_mq_ctx___14 {
	struct {
		spinlock_t lock;
		struct list_head rq_lists[3];
		long: 64;
	};
	unsigned int cpu;
	short unsigned int index_hw[3];
	struct blk_mq_hw_ctx___17 *hctxs[3];
	long unsigned int rq_dispatched[2];
	long unsigned int rq_merged;
	long unsigned int rq_completed[2];
	struct request_queue___75 *queue;
	struct blk_mq_ctxs___14 *ctxs;
	struct kobject___263 kobj;
};

struct blk_mq_tags___14;

struct blk_mq_hw_ctx___17 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___75 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx___14 *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx___14 **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags___14 *tags;
	struct blk_mq_tags___14 *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	unsigned int rh_reserved_nr_expired;
	struct hlist_node cpuhp_dead;
	struct kobject___263 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___275 *debugfs_dir;
	struct dentry___275 *sched_debugfs_dir;
	struct list_head hctx_list;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___75;

struct blk_mq_alloc_data___14;

struct elevator_mq_ops___75 {
	int (*init_sched)(struct request_queue___75 *, struct elevator_type___75 *);
	void (*exit_sched)(struct elevator_queue___75 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___17 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___17 *, unsigned int);
	bool (*allow_merge)(struct request_queue___75 *, struct request___75 *, struct bio___144 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx___17 *, struct bio___144 *);
	int (*request_merge)(struct request_queue___75 *, struct request___75 **, struct bio___144 *);
	void (*request_merged)(struct request_queue___75 *, struct request___75 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___75 *, struct request___75 *, struct request___75 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data___14 *);
	void (*prepare_request)(struct request___75 *, struct bio___144 *);
	void (*finish_request)(struct request___75 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___17 *, struct list_head *, bool);
	struct request___75 * (*dispatch_request)(struct blk_mq_hw_ctx___17 *);
	bool (*has_work)(struct blk_mq_hw_ctx___17 *);
	void (*completed_request)(struct request___75 *, u64);
	void (*started_request)(struct request___75 *);
	void (*requeue_request)(struct request___75 *);
	struct request___75 * (*former_request)(struct request_queue___75 *, struct request___75 *);
	struct request___75 * (*next_request)(struct request_queue___75 *, struct request___75 *);
	void (*init_icq)(struct io_cq___79 *);
	void (*exit_icq)(struct io_cq___79 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx___17 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___75;

struct elevator_type___75 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___75 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___75 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___222 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___75 {
	struct elevator_type___75 *type;
	void *elevator_data;
	struct kobject___263 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct blk_mq_alloc_data___14 {
	struct request_queue___75 *q;
	blk_mq_req_flags_t flags;
	unsigned int shallow_depth;
	unsigned int cmd_flags;
	struct blk_mq_ctx___14 *ctx;
	struct blk_mq_hw_ctx___17 *hctx;
};

struct elv_fs_entry___75 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___75 *, char *);
	ssize_t (*store)(struct elevator_queue___75 *, const char *, size_t);
};

struct blk_mq_queue_data___17;

typedef blk_status_t queue_rq_fn___17(struct blk_mq_hw_ctx___17 *, const struct blk_mq_queue_data___17 *);

typedef void commit_rqs_fn___17(struct blk_mq_hw_ctx___17 *);

typedef bool get_budget_fn___17(struct blk_mq_hw_ctx___17 *);

typedef void put_budget_fn___17(struct blk_mq_hw_ctx___17 *);

typedef enum blk_eh_timer_return timeout_fn___17(struct request___75 *, bool);

typedef int poll_fn___17(struct blk_mq_hw_ctx___17 *);

typedef void complete_fn___17(struct request___75 *);

typedef int init_hctx_fn___17(struct blk_mq_hw_ctx___17 *, void *, unsigned int);

typedef void exit_hctx_fn___17(struct blk_mq_hw_ctx___17 *, unsigned int);

typedef int init_request_fn___17(struct blk_mq_tag_set___17 *, struct request___75 *, unsigned int, unsigned int);

typedef void exit_request_fn___17(struct blk_mq_tag_set___17 *, struct request___75 *, unsigned int);

typedef bool busy_fn___17(struct request_queue___75 *);

typedef int map_queues_fn___17(struct blk_mq_tag_set___17 *);

typedef void cleanup_rq_fn___17(struct request___75 *);

struct blk_mq_ops___17 {
	queue_rq_fn___17 *queue_rq;
	commit_rqs_fn___17 *commit_rqs;
	get_budget_fn___17 *get_budget;
	put_budget_fn___17 *put_budget;
	timeout_fn___17 *timeout;
	poll_fn___17 *poll;
	complete_fn___17 *complete;
	init_hctx_fn___17 *init_hctx;
	exit_hctx_fn___17 *exit_hctx;
	init_request_fn___17 *init_request;
	exit_request_fn___17 *exit_request;
	void (*initialize_rq_fn)(struct request___75 *);
	busy_fn___17 *busy;
	map_queues_fn___17 *map_queues;
	void (*show_rq)(struct seq_file___9 *, struct request___75 *);
	union {
		cleanup_rq_fn___17 *cleanup_rq;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide42;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct blk_stat_callback___14 {
	struct list_head list;
	struct timer_list timer;
	struct blk_rq_stat *cpu_stat;
	int (*bucket_fn)(const struct request___75 *);
	unsigned int buckets;
	struct blk_rq_stat *stat;
	void (*timer_fn)(struct blk_stat_callback___14 *);
	void *data;
	struct callback_head rcu;
};

struct blk_mq_tag_set___17 {
	struct blk_mq_queue_map map[6];
	unsigned int nr_maps;
	const struct blk_mq_ops___17 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	struct blk_mq_tags___14 **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct blk_mq_tags___14 {
	unsigned int nr_tags;
	unsigned int nr_reserved_tags;
	atomic_t active_queues;
	struct sbitmap_queue bitmap_tags;
	struct sbitmap_queue breserved_tags;
	struct request___75 **rqs;
	struct request___75 **static_rqs;
	struct list_head page_list;
};

struct blk_mq_queue_data___17 {
	struct request___75 *rq;
	bool last;
	long unsigned int rh_reserved1;
};

struct pci_bus___2;

struct pci_slot___2 {
	struct pci_bus___2 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject___263 kobj;
};

struct pci_dev___2;

struct pci_ops___2;

struct msi_controller___2;

struct pci_bus___2 {
	struct list_head node;
	struct pci_bus___2 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___2 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___2 *ops;
	struct msi_controller___2 *msi;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	int domain_nr;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___238 *bridge;
	struct device___238 dev;
	struct bin_attribute___239 *legacy_io;
	struct bin_attribute___239 *legacy_mem;
	unsigned int is_added: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
};

struct pci_driver___2;

struct pci_dev___2 {
	struct list_head bus_list;
	struct pci_bus___2 *bus;
	struct pci_bus___2 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___2 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u16 aer_cap;
	struct aer_stats *aer_stats;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	long unsigned int *dma_alias_mask;
	struct pci_driver___2 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	unsigned int imm_ready: 1;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int bridge_d3: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int hotplug_user_indicators: 1;
	unsigned int clear_retrain_link: 1;
	unsigned int d3_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	unsigned int ltr_path: 1;
	unsigned int eetlp_prefix_path: 1;
	pci_channel_state_t error_state;
	struct device___238 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int multifunction: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int ats_enabled: 1;
	unsigned int pasid_enabled: 1;
	unsigned int pri_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int reset_fn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int shpc_managed: 1;
	unsigned int is_thunderbolt: 1;
	unsigned int __aer_firmware_first_valid: 1;
	unsigned int __aer_firmware_first: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int irq_managed: 1;
	unsigned int has_secondary_link: 1;
	unsigned int non_compliant_bars: 1;
	unsigned int is_probed: 1;
	unsigned int link_active_reporting: 1;
	unsigned int untrusted: 1;
	unsigned int no_vf_scan: 1;
	unsigned int io_window: 1;
	unsigned int pref_window: 1;
	unsigned int pref_64_window: 1;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	struct bin_attribute___239 *rom_attr;
	int rom_attr_enabled;
	struct bin_attribute___239 *res_attr[17];
	struct bin_attribute___239 *res_attr_wc[17];
	unsigned int broken_cmd_compl: 1;
	const struct attribute_group___240 **msi_irq_groups;
	struct pci_vpd *vpd;
	union {
		struct pci_sriov *sriov;
		struct pci_dev___2 *physfn;
	};
	u16 ats_cap;
	u8 ats_stu;
	atomic_t ats_ref_cnt;
	u32 pri_reqs_alloc;
	u16 pasid_features;
	struct pci_p2pdma *p2pdma;
	phys_addr_t rom;
	size_t romlen;
	char *driver_override;
	long unsigned int priv_flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t pci_dev_extended_size_rh;
	struct pci_dev_extended_rh pci_dev_extended_rh;
};

struct pci_error_handlers___2;

struct pci_driver___2 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___2 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___2 *);
	int (*suspend)(struct pci_dev___2 *, pm_message_t);
	int (*suspend_late)(struct pci_dev___2 *, pm_message_t);
	int (*resume_early)(struct pci_dev___2 *);
	int (*resume)(struct pci_dev___2 *);
	void (*shutdown)(struct pci_dev___2 *);
	int (*sriov_configure)(struct pci_dev___2 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	const struct pci_error_handlers___2 *err_handler;
	const struct attribute_group___240 **groups;
	struct device_driver___238 driver;
	struct pci_dynids dynids;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct pci_ops___2 {
	int (*add_bus)(struct pci_bus___2 *);
	void (*remove_bus)(struct pci_bus___2 *);
	void * (*map_bus)(struct pci_bus___2 *, unsigned int, int);
	int (*read)(struct pci_bus___2 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___2 *, unsigned int, int, int, u32);
};

struct pci_error_handlers___2 {
	pci_ers_result_t (*error_detected)(struct pci_dev___2 *, enum pci_channel_state);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___2 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___2 *);
	void (*reset_prepare)(struct pci_dev___2 *);
	void (*reset_done)(struct pci_dev___2 *);
	void (*resume)(struct pci_dev___2 *);
};

struct kernel_param_ops___219 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___219 *);
	int (*get)(char *, const struct kernel_param___219 *);
	void (*free)(void *);
};

struct kparam_array___219;

struct kernel_param___219 {
	const char *name;
	struct module___222 *mod;
	const struct kernel_param_ops___219 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___219 *arr;
	};
};

struct kparam_array___219 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___219 *ops;
	void *elem;
};

struct module_attribute___219 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___219 *, struct module_kobject___219 *, char *);
	ssize_t (*store)(struct module_attribute___219 *, struct module_kobject___219 *, const char *, size_t);
	void (*setup)(struct module___222 *, const char *);
	int (*test)(struct module___222 *);
	void (*free)(struct module___222 *);
};

struct blk_mq_ctxs___14 {
	struct kobject___263 kobj;
	struct blk_mq_ctx___14 *queue_ctx;
};

struct module___223;

struct file___276;

struct kiocb___276;

struct iov_iter___133;

struct vm_area_struct___277;

struct inode___276;

struct file_lock___276;

struct page___277;

struct file_operations___276 {
	struct module___223 *owner;
	loff_t (*llseek)(struct file___276 *, loff_t, int);
	ssize_t (*read)(struct file___276 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___276 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___276 *, struct iov_iter___133 *);
	ssize_t (*write_iter)(struct kiocb___276 *, struct iov_iter___133 *);
	int (*iopoll)(struct kiocb___276 *, bool);
	int (*iterate)(struct file___276 *, struct dir_context *);
	int (*iterate_shared)(struct file___276 *, struct dir_context *);
	__poll_t (*poll)(struct file___276 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___276 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___276 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___276 *, struct vm_area_struct___277 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___276 *, struct file___276 *);
	int (*flush)(struct file___276 *, fl_owner_t);
	int (*release)(struct inode___276 *, struct file___276 *);
	int (*fsync)(struct file___276 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___276 *, int);
	int (*lock)(struct file___276 *, int, struct file_lock___276 *);
	ssize_t (*sendpage)(struct file___276 *, struct page___277 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___276 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___276 *, int, struct file_lock___276 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___276 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___276 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___276 *, long int, struct file_lock___276 **, void **);
	long int (*fallocate)(struct file___276 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___276 *);
	ssize_t (*copy_file_range)(struct file___276 *, loff_t, struct file___276 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___276 *, loff_t, struct file___276 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___276 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___276 {
	u64 seqnum;
	struct vm_area_struct___277 *vmas[4];
};

struct page_frag___276 {
	struct page___277 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___276;

struct bio_list___145;

struct backing_dev_info___145;

struct io_context___80;

struct request_queue___76;

struct vm_struct___192;

struct task_struct___277 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___277 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___276 *mm;
	struct mm_struct___276 *active_mm;
	struct vmacache___276 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___277 *real_parent;
	struct task_struct___277 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___277 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___103 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___103 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___103 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___2 *ptracer_cred;
	const struct cred___2 *real_cred;
	const struct cred___2 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___277 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___145 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___145 *backing_dev_info;
	struct io_context___80 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___276 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___76 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___277 *oom_reaper_list;
	struct vm_struct___192 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___78 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___277 *pgtable_t___276;

struct address_space___275;

struct dev_pagemap___265;

struct page___277 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___275 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___277 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___276 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___276 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___265 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___276;

struct lruvec___276 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___276 *pgdat;
};

struct zone___276 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___276 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___276 {
	struct zone___276 *zone;
	int zone_idx;
};

struct zonelist___276 {
	struct zoneref___276 _zonerefs[25];
};

struct pglist_data___276 {
	struct zone___276 node_zones[3];
	struct zonelist___276 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___277 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___277 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___276 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___277 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___277 *owner;
};

struct secondary_data___277 {
	void *stack;
	struct task_struct___277 *task;
	long int status;
};

struct blocking_notifier_head___276 {
	struct rw_semaphore___277 rwsem;
	struct notifier_block *head;
};

struct kernfs_root___270;

struct kernfs_elem_dir___270 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___270 *root;
};

struct kernfs_node___271;

struct kernfs_syscall_ops___270;

struct kernfs_root___270 {
	struct kernfs_node___271 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___270 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___270 {
	struct kernfs_node___271 *target_kn;
};

struct kernfs_ops___270;

struct kernfs_elem_attr___270 {
	const struct kernfs_ops___270 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___271 *notify_next;
};

struct kernfs_node___271 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___271 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___270 dir;
		struct kernfs_elem_symlink___270 symlink;
		struct kernfs_elem_attr___270 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___270;

struct kernfs_ops___270 {
	int (*open)(struct kernfs_open_file___270 *);
	void (*release)(struct kernfs_open_file___270 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___270 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___270 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___270 *, struct vm_area_struct___277 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___270 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___270 {
	int (*remount_fs)(struct kernfs_root___270 *, int *, char *);
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___270 *);
	int (*mkdir)(struct kernfs_node___271 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___271 *);
	int (*rename)(struct kernfs_node___271 *, struct kernfs_node___271 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___271 *, struct kernfs_root___270 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_operations_struct___265;

struct kernfs_open_file___270 {
	struct kernfs_node___271 *kn;
	struct file___276 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___265 *vm_ops;
};

struct dentry___276;

struct path___276 {
	struct vfsmount *mnt;
	struct dentry___276 *dentry;
};

struct file___276 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___276 f_path;
	struct inode___276 *f_inode;
	const struct file_operations___276 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___102 f_owner;
	const struct cred___2 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___275 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___265;

struct vm_operations_struct___265 {
	void (*open)(struct vm_area_struct___277 *);
	void (*close)(struct vm_area_struct___277 *);
	int (*split)(struct vm_area_struct___277 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___277 *);
	vm_fault_t (*fault)(struct vm_fault___265 *);
	vm_fault_t (*huge_fault)(struct vm_fault___265 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___265 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___277 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___265 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___265 *);
	int (*access)(struct vm_area_struct___277 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___277 *);
	int (*set_policy)(struct vm_area_struct___277 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___277 *, long unsigned int);
	struct page___277 * (*find_special_page)(struct vm_area_struct___277 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_area_struct___277 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___277 *vm_next;
	struct vm_area_struct___277 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___276 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___265 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___276 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___264;

struct bin_attribute___240;

struct attribute_group___241 {
	const char *name;
	umode_t (*is_visible)(struct kobject___264 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___264 *, struct bin_attribute___240 *, int);
	struct attribute **attrs;
	struct bin_attribute___240 **bin_attrs;
};

struct kset___263;

struct kobj_type___263;

struct kobject___264 {
	const char *name;
	struct list_head entry;
	struct kobject___264 *parent;
	struct kset___263 *kset;
	struct kobj_type___263 *ktype;
	struct kernfs_node___271 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___240 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___276 *, struct kobject___264 *, struct bin_attribute___240 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___276 *, struct kobject___264 *, struct bin_attribute___240 *, char *, loff_t, size_t);
	int (*mmap)(struct file___276 *, struct kobject___264 *, struct bin_attribute___240 *, struct vm_area_struct___277 *);
};

struct sysfs_ops___263 {
	ssize_t (*show)(struct kobject___264 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___264 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___263;

struct kset___263 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___264 kobj;
	const struct kset_uevent_ops___263 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___263 {
	void (*release)(struct kobject___264 *);
	const struct sysfs_ops___263 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___9 * (*child_ns_type)(struct kobject___264 *);
	const void * (*namespace)(struct kobject___264 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___263 {
	int (* const filter)(struct kset___263 *, struct kobject___264 *);
	const char * (* const name)(struct kset___263 *, struct kobject___264 *);
	int (* const uevent)(struct kset___263 *, struct kobject___264 *, struct kobj_uevent_env *);
};

struct kobj_attribute___256 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___264 *, struct kobj_attribute___256 *, char *);
	ssize_t (*store)(struct kobject___264 *, struct kobj_attribute___256 *, const char *, size_t);
};

struct device___239;

struct dev_pm_ops___239 {
	int (*prepare)(struct device___239 *);
	void (*complete)(struct device___239 *);
	int (*suspend)(struct device___239 *);
	int (*resume)(struct device___239 *);
	int (*freeze)(struct device___239 *);
	int (*thaw)(struct device___239 *);
	int (*poweroff)(struct device___239 *);
	int (*restore)(struct device___239 *);
	int (*suspend_late)(struct device___239 *);
	int (*resume_early)(struct device___239 *);
	int (*freeze_late)(struct device___239 *);
	int (*thaw_early)(struct device___239 *);
	int (*poweroff_late)(struct device___239 *);
	int (*restore_early)(struct device___239 *);
	int (*suspend_noirq)(struct device___239 *);
	int (*resume_noirq)(struct device___239 *);
	int (*freeze_noirq)(struct device___239 *);
	int (*thaw_noirq)(struct device___239 *);
	int (*poweroff_noirq)(struct device___239 *);
	int (*restore_noirq)(struct device___239 *);
	int (*runtime_suspend)(struct device___239 *);
	int (*runtime_resume)(struct device___239 *);
	int (*runtime_idle)(struct device___239 *);
};

struct dev_pm_info___239 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___239 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___239;

struct bus_type___239;

struct device_driver___239;

struct dev_pm_domain___239;

struct fwnode_handle___174;

struct class___239;

struct device___239 {
	struct device___239 *parent;
	struct device_private *p;
	struct kobject___264 kobj;
	const char *init_name;
	const struct device_type___239 *type;
	struct mutex mutex;
	struct bus_type___239 *bus;
	struct device_driver___239 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___239 power;
	struct dev_pm_domain___239 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___174 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___239 *class;
	const struct attribute_group___241 **groups;
	void (*release)(struct device___239 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___239 {
	struct dev_pm_ops___239 ops;
	void (*detach)(struct device___239 *, bool);
	int (*activate)(struct device___239 *);
	void (*sync)(struct device___239 *);
	void (*dismiss)(struct device___239 *);
};

struct core_state___276;

struct mm_struct___276 {
	struct {
		struct vm_area_struct___277 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___276 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___277 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___276 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___277 *owner;
		struct user_namespace___3 *user_ns;
		struct file___276 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___276 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct bio___145;

struct bio_list___145 {
	struct bio___145 *head;
	struct bio___145 *tail;
};

struct bdi_writeback_congested___145;

struct bdi_writeback___145 {
	struct backing_dev_info___145 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___145 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___157 *memcg_css;
	struct cgroup_subsys_state___157 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___145 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___145 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___239 *dev;
	struct device___239 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___276 *debug_dir;
	struct dentry___276 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___80;

struct io_context___80 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___80 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

typedef blk_qc_t make_request_fn___76(struct request_queue___76 *, struct bio___145 *);

struct request___76;

typedef int dma_drain_needed_fn___76(struct request___76 *);

struct bsg_ops___76;

struct bsg_class_device___76 {
	struct device___239 *class_dev;
	int minor;
	struct request_queue___76 *queue;
	const struct bsg_ops___76 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___145 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___145 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___76;

struct blk_mq_ops___18;

struct blk_mq_ctx___15;

struct blk_mq_hw_ctx___18;

struct blk_stat_callback___15;

struct blk_mq_tag_set___18;

struct request_queue___76 {
	struct list_head queue_head;
	struct request___76 *last_merge;
	struct elevator_queue___76 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___76 *make_request_fn;
	dma_drain_needed_fn___76 *dma_drain_needed;
	const struct blk_mq_ops___18 *mq_ops;
	struct blk_mq_ctx___15 *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___18 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___145 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___264 kobj;
	struct kobject___264 *mq_kobj;
	struct blk_integrity integrity;
	struct device___239 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback___15 *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	struct bsg_class_device___76 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set___18 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___145 bio_split;
	struct dentry___276 *debugfs_dir;
	struct dentry___276 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___192 {
	struct vm_struct___192 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___277 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bus_type___239 {
	const char *name;
	const char *dev_name;
	struct device___239 *dev_root;
	const struct attribute_group___241 **bus_groups;
	const struct attribute_group___241 **dev_groups;
	const struct attribute_group___241 **drv_groups;
	int (*match)(struct device___239 *, struct device_driver___239 *);
	int (*uevent)(struct device___239 *, struct kobj_uevent_env *);
	int (*probe)(struct device___239 *);
	int (*remove)(struct device___239 *);
	void (*shutdown)(struct device___239 *);
	int (*online)(struct device___239 *);
	int (*offline)(struct device___239 *);
	int (*suspend)(struct device___239 *, pm_message_t);
	int (*resume)(struct device___239 *);
	int (*num_vf)(struct device___239 *);
	int (*dma_configure)(struct device___239 *);
	const struct dev_pm_ops___239 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___239 {
	const char *name;
	struct bus_type___239 *bus;
	struct module___223 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___239 *);
	int (*remove)(struct device___239 *);
	void (*shutdown)(struct device___239 *);
	int (*suspend)(struct device___239 *, pm_message_t);
	int (*resume)(struct device___239 *);
	const struct attribute_group___241 **groups;
	const struct dev_pm_ops___239 *pm;
	void (*coredump)(struct device___239 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___239 {
	const char *name;
	const struct attribute_group___241 **groups;
	int (*uevent)(struct device___239 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___239 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___239 *);
	const struct dev_pm_ops___239 *pm;
};

struct module_kobject___220 {
	struct kobject___264 kobj;
	struct module___223 *mod;
	struct kobject___264 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___220 {
	struct module___223 *mod;
	struct latch_tree_node node;
};

struct module_layout___220 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___220 mtn;
};

struct module_attribute___220;

struct kernel_param___220;

struct module___223 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___220 mkobj;
	struct module_attribute___220 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___264 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___220 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___220 core_layout;
	struct module_layout___220 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide45;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide46;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct class___239 {
	const char *name;
	struct module___223 *owner;
	const struct attribute_group___241 **class_groups;
	const struct attribute_group___241 **dev_groups;
	struct kobject___264 *dev_kobj;
	int (*dev_uevent)(struct device___239 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___239 *, umode_t *);
	void (*class_release)(struct class___239 *);
	void (*dev_release)(struct device___239 *);
	int (*shutdown_pre)(struct device___239 *);
	const struct kobj_ns_type_operations___9 *ns_type;
	const void * (*namespace)(struct device___239 *);
	const struct dev_pm_ops___239 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct fwnode_operations___174;

struct fwnode_handle___174 {
	struct fwnode_handle___174 *secondary;
	const struct fwnode_operations___174 *ops;
};

struct bio_vec___145 {
	struct page___277 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

typedef void bio_end_io_t___145(struct bio___145 *);

struct gendisk___77;

struct bio_integrity_payload___145;

struct bio___145 {
	struct bio___145 *bi_next;
	struct gendisk___77 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___145 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___145 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___145 *bi_io_vec;
	struct bio_set___145 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___145 bi_inline_vecs[0];
};

struct bio_integrity_payload___145 {
	struct bio___145 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___145 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___145 bip_inline_vecs[0];
};

struct hd_struct___77 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___239 __dev;
	struct kobject___264 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___77;

struct block_device_operations___77;

struct gendisk___77 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___77 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___77 *part_tbl;
	struct hd_struct___77 part0;
	const struct block_device_operations___77 *fops;
	struct request_queue___76 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___277 lookup_sem;
	struct kobject___264 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___264 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dentry_operations___275;

struct super_block___275;

struct dentry___276 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___276 *d_parent;
	struct qstr d_name;
	struct inode___276 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___275 *d_op;
	struct super_block___275 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___275;

struct address_space___275 {
	struct inode___276 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___277 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___275 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___275;

struct block_device___275;

struct inode___276 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___275 *i_op;
	struct super_block___275 *i_sb;
	struct address_space___275 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___277 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___145 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___276 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___275 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___275 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___275 {
	int (*d_revalidate)(struct dentry___276 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___276 *, unsigned int);
	int (*d_hash)(const struct dentry___276 *, struct qstr *);
	int (*d_compare)(const struct dentry___276 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___276 *);
	int (*d_init)(struct dentry___276 *);
	void (*d_release)(struct dentry___276 *);
	void (*d_prune)(struct dentry___276 *);
	void (*d_iput)(struct dentry___276 *, struct inode___276 *);
	char * (*d_dname)(struct dentry___276 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___276 *);
	int (*d_manage)(const struct path___276 *, bool);
	struct dentry___276 * (*d_real)(struct dentry___276 *, const struct inode___276 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___275;

struct mem_dqinfo___275 {
	struct quota_format_type___275 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___275;

struct quota_info___275 {
	unsigned int flags;
	struct rw_semaphore___277 dqio_sem;
	struct inode___276 *files[3];
	struct mem_dqinfo___275 info[3];
	const struct quota_format_ops___275 *ops[3];
};

struct rcuwait___275 {
	struct task_struct___277 *task;
};

struct percpu_rw_semaphore___275 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___277 rw_sem;
	struct rcuwait___275 writer;
	int readers_block;
};

struct sb_writers___275 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___275 rw_sem[3];
};

struct file_system_type___275;

struct super_operations___275;

struct dquot_operations___275;

struct quotactl_ops___275;

struct super_block___275 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___275 *s_type;
	const struct super_operations___275 *s_op;
	const struct dquot_operations___275 *dq_op;
	const struct quotactl_ops___275 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___276 *s_root;
	struct rw_semaphore___277 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___275 *s_bdev;
	struct backing_dev_info___145 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___275 s_dquot;
	struct sb_writers___275 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___275 *s_d_op;
	int cleancache_poolid;
	struct shrinker___43 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

typedef int (*dev_page_fault_t___265)(struct vm_area_struct___277 *, long unsigned int, const struct page___277 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___265)(struct page___277 *, void *);

struct dev_pagemap___265 {
	dev_page_fault_t___265 page_fault;
	dev_page_free_t___265 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___239 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___276 {
	struct task_struct___277 *task;
	struct core_thread___276 *next;
};

struct core_state___276 {
	atomic_t nr_threads;
	struct core_thread___276 dumper;
	struct completion startup;
};

struct vm_fault___265 {
	struct vm_area_struct___277 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___277 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___277 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___276 prealloc_pte;
};

struct io_cq___80 {
	struct request_queue___76 *q;
	struct io_context___80 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___276 {
	struct file___276 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___276 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___275 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___276 *ia_file;
};

struct dquot___275 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___275 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___275 {
	int qf_fmt_id;
	const struct quota_format_ops___275 *qf_ops;
	struct module___223 *qf_owner;
	struct quota_format_type___275 *qf_next;
};

struct quota_format_ops___275 {
	int (*check_quota_file)(struct super_block___275 *, int);
	int (*read_file_info)(struct super_block___275 *, int);
	int (*write_file_info)(struct super_block___275 *, int);
	int (*free_file_info)(struct super_block___275 *, int);
	int (*read_dqblk)(struct dquot___275 *);
	int (*commit_dqblk)(struct dquot___275 *);
	int (*release_dqblk)(struct dquot___275 *);
	int (*get_next_id)(struct super_block___275 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___275 {
	int (*write_dquot)(struct dquot___275 *);
	struct dquot___275 * (*alloc_dquot)(struct super_block___275 *, int);
	void (*destroy_dquot)(struct dquot___275 *);
	int (*acquire_dquot)(struct dquot___275 *);
	int (*release_dquot)(struct dquot___275 *);
	int (*mark_dirty)(struct dquot___275 *);
	int (*write_info)(struct super_block___275 *, int);
	qsize_t * (*get_reserved_space)(struct inode___276 *);
	int (*get_projid)(struct inode___276 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___276 *, qsize_t *);
	int (*get_next_id)(struct super_block___275 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___275 {
	int (*quota_on)(struct super_block___275 *, int, int, const struct path___276 *);
	int (*quota_off)(struct super_block___275 *, int);
	int (*quota_enable)(struct super_block___275 *, unsigned int);
	int (*quota_disable)(struct super_block___275 *, unsigned int);
	int (*quota_sync)(struct super_block___275 *, int);
	int (*set_info)(struct super_block___275 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___275 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___275 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___275 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___275 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___275 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___275 {
	int (*writepage)(struct page___277 *, struct writeback_control___3 *);
	int (*readpage)(struct file___276 *, struct page___277 *);
	int (*writepages)(struct address_space___275 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___277 *);
	int (*readpages)(struct file___276 *, struct address_space___275 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___276 *, struct address_space___275 *, loff_t, unsigned int, unsigned int, struct page___277 **, void **);
	int (*write_end)(struct file___276 *, struct address_space___275 *, loff_t, unsigned int, unsigned int, struct page___277 *, void *);
	sector_t (*bmap)(struct address_space___275 *, sector_t);
	void (*invalidatepage)(struct page___277 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___277 *, gfp_t);
	void (*freepage)(struct page___277 *);
	ssize_t (*direct_IO)(struct kiocb___276 *, struct iov_iter___133 *);
	int (*migratepage)(struct address_space___275 *, struct page___277 *, struct page___277 *, enum migrate_mode);
	bool (*isolate_page)(struct page___277 *, isolate_mode_t);
	void (*putback_page)(struct page___277 *);
	int (*launder_page)(struct page___277 *);
	int (*is_partially_uptodate)(struct page___277 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___277 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___275 *, struct page___277 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___276 *, sector_t *);
	void (*swap_deactivate)(struct file___276 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct iov_iter___133 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___145 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___275 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___276 *bd_inode;
	struct super_block___275 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___275 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___77 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___77 *bd_disk;
	struct request_queue___76 *bd_queue;
	struct backing_dev_info___145 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___275 {
	struct dentry___276 * (*lookup)(struct inode___276 *, struct dentry___276 *, unsigned int);
	const char * (*get_link)(struct dentry___276 *, struct inode___276 *, struct delayed_call *);
	int (*permission)(struct inode___276 *, int);
	struct posix_acl * (*get_acl)(struct inode___276 *, int);
	int (*readlink)(struct dentry___276 *, char *, int);
	int (*create)(struct inode___276 *, struct dentry___276 *, umode_t, bool);
	int (*link)(struct dentry___276 *, struct inode___276 *, struct dentry___276 *);
	int (*unlink)(struct inode___276 *, struct dentry___276 *);
	int (*symlink)(struct inode___276 *, struct dentry___276 *, const char *);
	int (*mkdir)(struct inode___276 *, struct dentry___276 *, umode_t);
	int (*rmdir)(struct inode___276 *, struct dentry___276 *);
	int (*mknod)(struct inode___276 *, struct dentry___276 *, umode_t, dev_t);
	int (*rename)(struct inode___276 *, struct dentry___276 *, struct inode___276 *, struct dentry___276 *, unsigned int);
	int (*setattr)(struct dentry___276 *, struct iattr___275 *);
	int (*getattr)(const struct path___276 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___276 *, char *, size_t);
	int (*fiemap)(struct inode___276 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___276 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___276 *, struct dentry___276 *, struct file___276 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___276 *, struct dentry___276 *, umode_t);
	int (*set_acl)(struct inode___276 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___275 {
	void (*fl_copy_lock)(struct file_lock___276 *, struct file_lock___276 *);
	void (*fl_release_private)(struct file_lock___276 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___275;

struct lock_manager_operations___275;

struct file_lock___276 {
	struct file_lock___276 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___276 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___275 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___275 *fl_ops;
	const struct lock_manager_operations___275 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___275 {
	int (*lm_compare_owner)(struct file_lock___276 *, struct file_lock___276 *);
	long unsigned int (*lm_owner_key)(struct file_lock___276 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___276 *);
	int (*lm_grant)(struct file_lock___276 *, int);
	bool (*lm_break)(struct file_lock___276 *);
	int (*lm_change)(struct file_lock___276 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___276 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___275 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___275 *fa_next;
	struct file___276 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___275 {
	const char *name;
	int fs_flags;
	struct dentry___276 * (*mount)(struct file_system_type___275 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___275 *);
	struct module___223 *owner;
	struct file_system_type___275 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___275 {
	struct inode___276 * (*alloc_inode)(struct super_block___275 *);
	void (*destroy_inode)(struct inode___276 *);
	void (*dirty_inode)(struct inode___276 *, int);
	int (*write_inode)(struct inode___276 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___276 *);
	void (*evict_inode)(struct inode___276 *);
	void (*put_super)(struct super_block___275 *);
	int (*sync_fs)(struct super_block___275 *, int);
	int (*freeze_super)(struct super_block___275 *);
	int (*freeze_fs)(struct super_block___275 *);
	int (*thaw_super)(struct super_block___275 *);
	int (*unfreeze_fs)(struct super_block___275 *);
	int (*statfs)(struct dentry___276 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___275 *, int *, char *);
	void (*umount_begin)(struct super_block___275 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___276 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___276 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___276 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___276 *);
	ssize_t (*quota_read)(struct super_block___275 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___275 *, int, const char *, size_t, loff_t);
	struct dquot___275 ** (*get_dquots)(struct inode___276 *);
	int (*bdev_try_to_free_page)(struct super_block___275 *, struct page___277 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___275 *, struct shrink_control___43 *);
	long int (*free_cached_objects)(struct super_block___275 *, struct shrink_control___43 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___77 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___77 *last_lookup;
	struct hd_struct___77 *part[0];
};

struct block_device_operations___77 {
	int (*open)(struct block_device___275 *, fmode_t);
	void (*release)(struct gendisk___77 *, fmode_t);
	int (*rw_page)(struct block_device___275 *, sector_t, struct page___277 *, unsigned int);
	int (*ioctl)(struct block_device___275 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___275 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___77 *, unsigned int);
	int (*media_changed)(struct gendisk___77 *);
	void (*unlock_native_capacity)(struct gendisk___77 *);
	int (*revalidate_disk)(struct gendisk___77 *);
	int (*getgeo)(struct block_device___275 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___275 *, long unsigned int);
	int (*report_zones)(struct gendisk___77 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___223 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___265(struct page___277 *);

struct bdi_writeback_congested___145 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___145 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bsg_ops___76 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___76 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___76 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___76 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___76(struct request___76 *, blk_status_t);

struct request___76 {
	struct request_queue___76 *q;
	struct blk_mq_ctx___15 *mq_ctx;
	struct blk_mq_hw_ctx___18 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___145 *bio;
	struct bio___145 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___145 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___80 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___76 *saved_end_io;
		} flush;
	};
	struct gendisk___77 *rq_disk;
	struct hd_struct___77 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___76 *end_io;
	void *end_io_data;
	struct request___76 *next_rq;
};

struct fwnode_reference_args___174;

struct fwnode_endpoint___174;

struct fwnode_operations___174 {
	struct fwnode_handle___174 * (*get)(struct fwnode_handle___174 *);
	void (*put)(struct fwnode_handle___174 *);
	bool (*device_is_available)(const struct fwnode_handle___174 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___174 *, const struct device___239 *);
	bool (*property_present)(const struct fwnode_handle___174 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___174 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___174 *, const char *, const char **, size_t);
	struct fwnode_handle___174 * (*get_parent)(const struct fwnode_handle___174 *);
	struct fwnode_handle___174 * (*get_next_child_node)(const struct fwnode_handle___174 *, struct fwnode_handle___174 *);
	struct fwnode_handle___174 * (*get_named_child_node)(const struct fwnode_handle___174 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___174 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___174 *);
	struct fwnode_handle___174 * (*graph_get_next_endpoint)(const struct fwnode_handle___174 *, struct fwnode_handle___174 *);
	struct fwnode_handle___174 * (*graph_get_remote_endpoint)(const struct fwnode_handle___174 *);
	struct fwnode_handle___174 * (*graph_get_port_parent)(struct fwnode_handle___174 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___174 *, struct fwnode_endpoint___174 *);
};

struct fwnode_endpoint___174 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___174 *local_fwnode;
};

struct fwnode_reference_args___174 {
	struct fwnode_handle___174 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct blk_mq_ctxs___15;

struct blk_mq_ctx___15 {
	struct {
		spinlock_t lock;
		struct list_head rq_lists[3];
		long: 64;
	};
	unsigned int cpu;
	short unsigned int index_hw[3];
	struct blk_mq_hw_ctx___18 *hctxs[3];
	long unsigned int rq_dispatched[2];
	long unsigned int rq_merged;
	long unsigned int rq_completed[2];
	struct request_queue___76 *queue;
	struct blk_mq_ctxs___15 *ctxs;
	struct kobject___264 kobj;
};

struct blk_mq_tags___15;

struct blk_mq_hw_ctx___18 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___76 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx___15 *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx___15 **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags___15 *tags;
	struct blk_mq_tags___15 *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	unsigned int rh_reserved_nr_expired;
	struct hlist_node cpuhp_dead;
	struct kobject___264 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___276 *debugfs_dir;
	struct dentry___276 *sched_debugfs_dir;
	struct list_head hctx_list;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___76;

struct blk_mq_alloc_data___15;

struct elevator_mq_ops___76 {
	int (*init_sched)(struct request_queue___76 *, struct elevator_type___76 *);
	void (*exit_sched)(struct elevator_queue___76 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___18 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___18 *, unsigned int);
	bool (*allow_merge)(struct request_queue___76 *, struct request___76 *, struct bio___145 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx___18 *, struct bio___145 *);
	int (*request_merge)(struct request_queue___76 *, struct request___76 **, struct bio___145 *);
	void (*request_merged)(struct request_queue___76 *, struct request___76 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___76 *, struct request___76 *, struct request___76 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data___15 *);
	void (*prepare_request)(struct request___76 *, struct bio___145 *);
	void (*finish_request)(struct request___76 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___18 *, struct list_head *, bool);
	struct request___76 * (*dispatch_request)(struct blk_mq_hw_ctx___18 *);
	bool (*has_work)(struct blk_mq_hw_ctx___18 *);
	void (*completed_request)(struct request___76 *, u64);
	void (*started_request)(struct request___76 *);
	void (*requeue_request)(struct request___76 *);
	struct request___76 * (*former_request)(struct request_queue___76 *, struct request___76 *);
	struct request___76 * (*next_request)(struct request_queue___76 *, struct request___76 *);
	void (*init_icq)(struct io_cq___80 *);
	void (*exit_icq)(struct io_cq___80 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx___18 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___76;

struct elevator_type___76 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___76 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___76 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___223 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___76 {
	struct elevator_type___76 *type;
	void *elevator_data;
	struct kobject___264 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct blk_mq_alloc_data___15 {
	struct request_queue___76 *q;
	blk_mq_req_flags_t flags;
	unsigned int shallow_depth;
	unsigned int cmd_flags;
	struct blk_mq_ctx___15 *ctx;
	struct blk_mq_hw_ctx___18 *hctx;
};

struct elv_fs_entry___76 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___76 *, char *);
	ssize_t (*store)(struct elevator_queue___76 *, const char *, size_t);
};

struct blk_mq_queue_data___18;

typedef blk_status_t queue_rq_fn___18(struct blk_mq_hw_ctx___18 *, const struct blk_mq_queue_data___18 *);

typedef void commit_rqs_fn___18(struct blk_mq_hw_ctx___18 *);

typedef bool get_budget_fn___18(struct blk_mq_hw_ctx___18 *);

typedef void put_budget_fn___18(struct blk_mq_hw_ctx___18 *);

typedef enum blk_eh_timer_return timeout_fn___18(struct request___76 *, bool);

typedef int poll_fn___18(struct blk_mq_hw_ctx___18 *);

typedef void complete_fn___18(struct request___76 *);

typedef int init_hctx_fn___18(struct blk_mq_hw_ctx___18 *, void *, unsigned int);

typedef void exit_hctx_fn___18(struct blk_mq_hw_ctx___18 *, unsigned int);

typedef int init_request_fn___18(struct blk_mq_tag_set___18 *, struct request___76 *, unsigned int, unsigned int);

typedef void exit_request_fn___18(struct blk_mq_tag_set___18 *, struct request___76 *, unsigned int);

typedef bool busy_fn___18(struct request_queue___76 *);

typedef int map_queues_fn___18(struct blk_mq_tag_set___18 *);

typedef void cleanup_rq_fn___18(struct request___76 *);

struct blk_mq_ops___18 {
	queue_rq_fn___18 *queue_rq;
	commit_rqs_fn___18 *commit_rqs;
	get_budget_fn___18 *get_budget;
	put_budget_fn___18 *put_budget;
	timeout_fn___18 *timeout;
	poll_fn___18 *poll;
	complete_fn___18 *complete;
	init_hctx_fn___18 *init_hctx;
	exit_hctx_fn___18 *exit_hctx;
	init_request_fn___18 *init_request;
	exit_request_fn___18 *exit_request;
	void (*initialize_rq_fn)(struct request___76 *);
	busy_fn___18 *busy;
	map_queues_fn___18 *map_queues;
	void (*show_rq)(struct seq_file___9 *, struct request___76 *);
	union {
		cleanup_rq_fn___18 *cleanup_rq;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide42;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct blk_stat_callback___15 {
	struct list_head list;
	struct timer_list timer;
	struct blk_rq_stat *cpu_stat;
	int (*bucket_fn)(const struct request___76 *);
	unsigned int buckets;
	struct blk_rq_stat *stat;
	void (*timer_fn)(struct blk_stat_callback___15 *);
	void *data;
	struct callback_head rcu;
};

struct blk_mq_tag_set___18 {
	struct blk_mq_queue_map map[6];
	unsigned int nr_maps;
	const struct blk_mq_ops___18 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	struct blk_mq_tags___15 **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct blk_mq_tags___15 {
	unsigned int nr_tags;
	unsigned int nr_reserved_tags;
	atomic_t active_queues;
	struct sbitmap_queue bitmap_tags;
	struct sbitmap_queue breserved_tags;
	struct request___76 **rqs;
	struct request___76 **static_rqs;
	struct list_head page_list;
};

struct blk_mq_queue_data___18 {
	struct request___76 *rq;
	bool last;
	long unsigned int rh_reserved1;
};

struct virtio_device_id {
	__u32 device;
	__u32 vendor;
};

typedef __u16 __virtio16;

typedef __u32 __virtio32;

typedef __u64 __virtio64;

struct vring_desc {
	__virtio64 addr;
	__virtio32 len;
	__virtio16 flags;
	__virtio16 next;
};

struct vring_avail {
	__virtio16 flags;
	__virtio16 idx;
	__virtio16 ring[0];
};

struct vring_used_elem {
	__virtio32 id;
	__virtio32 len;
};

struct vring_used {
	__virtio16 flags;
	__virtio16 idx;
	struct vring_used_elem ring[0];
};

struct vring {
	unsigned int num;
	struct vring_desc *desc;
	struct vring_avail *avail;
	struct vring_used *used;
};

struct vringh {
	bool little_endian;
	bool event_indices;
	bool weak_barriers;
	u16 last_avail_idx;
	u16 last_used_idx;
	u32 completed;
	struct vring vring;
	void (*notify)(struct vringh *);
};

struct virtio_device;

typedef void vrh_callback_t(struct virtio_device *, struct vringh *);

struct virtio_config_ops;

struct vringh_config_ops;

struct virtio_device {
	int index;
	bool failed;
	bool config_enabled;
	bool config_change_pending;
	spinlock_t config_lock;
	struct device___239 dev;
	struct virtio_device_id id;
	const struct virtio_config_ops *config;
	const struct vringh_config_ops *vringh_config;
	struct list_head vqs;
	u64 features;
	void *priv;
};

struct vringh_config_ops {
	int (*find_vrhs)(struct virtio_device *, unsigned int, struct vringh **, vrh_callback_t **);
	void (*del_vrhs)(struct virtio_device *);
};

struct virtqueue {
	struct list_head list;
	void (*callback)(struct virtqueue *);
	const char *name;
	struct virtio_device *vdev;
	unsigned int index;
	unsigned int num_free;
	void *priv;
};

typedef void vq_callback_t(struct virtqueue *);

struct irq_affinity___2;

struct virtio_config_ops {
	void (*get)(struct virtio_device *, unsigned int, void *, unsigned int);
	void (*set)(struct virtio_device *, unsigned int, const void *, unsigned int);
	u32 (*generation)(struct virtio_device *);
	u8 (*get_status)(struct virtio_device *);
	void (*set_status)(struct virtio_device *, u8);
	void (*reset)(struct virtio_device *);
	int (*find_vqs)(struct virtio_device *, unsigned int, struct virtqueue **, vq_callback_t **, const char * const *, const bool *, struct irq_affinity___2 *);
	void (*del_vqs)(struct virtio_device *);
	u64 (*get_features)(struct virtio_device *);
	int (*finalize_features)(struct virtio_device *);
	const char * (*bus_name)(struct virtio_device *);
	int (*set_vq_affinity)(struct virtqueue *, int);
	const struct cpumask * (*get_vq_affinity)(struct virtio_device *, int);
};

struct kernel_param_ops___220 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___220 *);
	int (*get)(char *, const struct kernel_param___220 *);
	void (*free)(void *);
};

struct kparam_array___220;

struct kernel_param___220 {
	const char *name;
	struct module___223 *mod;
	const struct kernel_param_ops___220 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___220 *arr;
	};
};

struct kparam_array___220 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___220 *ops;
	void *elem;
};

struct module_attribute___220 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___220 *, struct module_kobject___220 *, char *);
	ssize_t (*store)(struct module_attribute___220 *, struct module_kobject___220 *, const char *, size_t);
	void (*setup)(struct module___223 *, const char *);
	int (*test)(struct module___223 *);
	void (*free)(struct module___223 *);
};

struct blk_mq_ctxs___15 {
	struct kobject___264 kobj;
	struct blk_mq_ctx___15 *queue_ctx;
};

struct module___224;

struct file___277;

struct kiocb___277;

struct iov_iter___134;

struct poll_table_struct___168;

struct vm_area_struct___278;

struct inode___277;

struct file_lock___277;

struct page___278;

struct pipe_inode_info___66;

struct seq_file___241;

struct file_operations___277 {
	struct module___224 *owner;
	loff_t (*llseek)(struct file___277 *, loff_t, int);
	ssize_t (*read)(struct file___277 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___277 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___277 *, struct iov_iter___134 *);
	ssize_t (*write_iter)(struct kiocb___277 *, struct iov_iter___134 *);
	int (*iopoll)(struct kiocb___277 *, bool);
	int (*iterate)(struct file___277 *, struct dir_context *);
	int (*iterate_shared)(struct file___277 *, struct dir_context *);
	__poll_t (*poll)(struct file___277 *, struct poll_table_struct___168 *);
	long int (*unlocked_ioctl)(struct file___277 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___277 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___277 *, struct vm_area_struct___278 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___277 *, struct file___277 *);
	int (*flush)(struct file___277 *, fl_owner_t);
	int (*release)(struct inode___277 *, struct file___277 *);
	int (*fsync)(struct file___277 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___277 *, int);
	int (*lock)(struct file___277 *, int, struct file_lock___277 *);
	ssize_t (*sendpage)(struct file___277 *, struct page___278 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___277 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___277 *, int, struct file_lock___277 *);
	ssize_t (*splice_write)(struct pipe_inode_info___66 *, struct file___277 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___277 *, loff_t *, struct pipe_inode_info___66 *, size_t, unsigned int);
	int (*setlease)(struct file___277 *, long int, struct file_lock___277 **, void **);
	long int (*fallocate)(struct file___277 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___241 *, struct file___277 *);
	ssize_t (*copy_file_range)(struct file___277 *, loff_t, struct file___277 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___277 *, loff_t, struct file___277 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___277 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___277 {
	u64 seqnum;
	struct vm_area_struct___278 *vmas[4];
};

struct page_frag___277 {
	struct page___278 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___277;

struct mem_cgroup___114;

struct cred___262;

struct nsproxy___239;

struct signal_struct___217;

struct bio_list___146;

struct backing_dev_info___146;

struct io_context___81;

struct css_set___204;

struct request_queue___77;

struct vm_struct___193;

struct task_struct___278 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___278 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___277 *mm;
	struct mm_struct___277 *active_mm;
	struct vmacache___277 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___278 *real_parent;
	struct task_struct___278 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___278 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___114 *active_memcg;
	long int rh_reserved2;
	struct pid___103 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___103 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___103 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___262 *ptracer_cred;
	const struct cred___262 *real_cred;
	const struct cred___262 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___239 *nsproxy;
	struct signal_struct___217 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___278 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___146 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___146 *backing_dev_info;
	struct io_context___81 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___204 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___66 *splice_pipe;
	struct page_frag___277 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___114 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___77 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___278 *oom_reaper_list;
	struct vm_struct___193 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___78 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rw_semaphore___278 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___278 *owner;
};

struct key___262;

struct ucounts___219;

struct user_namespace___219 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___219 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___9 ns;
	long unsigned int flags;
	struct key___262 *persistent_keyring_register;
	struct rw_semaphore___278 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___219 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct secondary_data___278 {
	void *stack;
	struct task_struct___278 *task;
	long int status;
};

typedef struct page___278 *pgtable_t___277;

struct address_space___276;

struct dev_pagemap___266;

struct page___278 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___276 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___278 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___277 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___277 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___266 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___114 *mem_cgroup;
};

struct user_struct___262 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___262 *uid_keyring;
	struct key___262 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___266;

struct vm_area_struct___278 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___278 *vm_next;
	struct vm_area_struct___278 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___277 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___266 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___277 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___277;

struct mm_struct___277 {
	struct {
		struct vm_area_struct___278 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___277 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___278 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___277 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___278 *owner;
		struct user_namespace___219 *user_ns;
		struct file___277 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___277 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup___204;

struct cgroup_subsys___204;

struct cgroup_subsys_state___204 {
	struct cgroup___204 *cgroup;
	struct cgroup_subsys___204 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___204 *parent;
};

struct mem_cgroup_id___25 {
	int id;
	union {
		refcount_t ref;
		struct {
			atomic_t ref;
		} __UNIQUE_ID_rh_kabi_hide67;
		union {		};
	};
};

struct kernfs_node___272;

struct cgroup_file___204 {
	struct kernfs_node___272 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___114;

struct mem_cgroup___114 {
	struct cgroup_subsys_state___204 css;
	struct mem_cgroup_id___25 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___204 events_file;
	struct cgroup_file___204 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___278 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___114 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cred___262 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___262 *session_keyring;
	struct key___262 *process_keyring;
	struct key___262 *thread_keyring;
	struct key___262 *request_key_auth;
	void *security;
	struct user_struct___262 *user;
	struct user_namespace___219 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___47;

struct cgroup_namespace___204;

struct nsproxy___239 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net___47 *net_ns;
	struct cgroup_namespace___204 *cgroup_ns;
};

struct signal_struct___217 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___278 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___278 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___103 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___103 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___277 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___103 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide55;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___146;

struct bio_list___146 {
	struct bio___146 *head;
	struct bio___146 *tail;
};

struct bdi_writeback_congested___146;

struct bdi_writeback___146 {
	struct backing_dev_info___146 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___146 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___204 *memcg_css;
	struct cgroup_subsys_state___204 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___240;

struct dentry___277;

struct backing_dev_info___146 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___146 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___240 *dev;
	struct device___240 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___277 *debug_dir;
	struct dentry___277 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___81;

struct io_context___81 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___81 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___204 {
	struct cgroup_subsys_state___204 *subsys[13];
	refcount_t refcount;
	struct css_set___204 *dom_cset;
	struct cgroup___204 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___204 *mg_src_cgrp;
	struct cgroup___204 *mg_dst_cgrp;
	struct css_set___204 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___276;

struct pipe_buffer___66;

struct pipe_inode_info___66 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___278 *tmp_page;
	struct fasync_struct___276 *fasync_readers;
	struct fasync_struct___276 *fasync_writers;
	struct pipe_buffer___66 *bufs;
	struct user_struct___262 *user;
};

typedef blk_qc_t make_request_fn___77(struct request_queue___77 *, struct bio___146 *);

struct request___77;

typedef int dma_drain_needed_fn___77(struct request___77 *);

struct kset___264;

struct kobj_type___264;

struct kobject___265 {
	const char *name;
	struct list_head entry;
	struct kobject___265 *parent;
	struct kset___264 *kset;
	struct kobj_type___264 *ktype;
	struct kernfs_node___272 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___77;

struct bsg_class_device___77 {
	struct device___240 *class_dev;
	int minor;
	struct request_queue___77 *queue;
	const struct bsg_ops___77 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___146 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___146 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___77;

struct blk_mq_ops___19;

struct blk_mq_hw_ctx___19;

struct blk_mq_tag_set___19;

struct request_queue___77 {
	struct list_head queue_head;
	struct request___77 *last_merge;
	struct elevator_queue___77 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___77 *make_request_fn;
	dma_drain_needed_fn___77 *dma_drain_needed;
	const struct blk_mq_ops___19 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___19 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___146 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___265 kobj;
	struct kobject___265 *mq_kobj;
	struct blk_integrity integrity;
	struct device___240 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	struct bsg_class_device___77 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set___19 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___146 bio_split;
	struct dentry___277 *debugfs_dir;
	struct dentry___277 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___193 {
	struct vm_struct___193 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___278 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___229 {
	struct task_struct___278 task;
	long unsigned int stack[8192];
};

struct pglist_data___277;

struct lruvec___277 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___277 *pgdat;
};

struct zone___277 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___277 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___277 {
	struct zone___277 *zone;
	int zone_idx;
};

struct zonelist___277 {
	struct zoneref___277 _zonerefs[25];
};

struct pglist_data___277 {
	struct zone___277 node_zones[3];
	struct zonelist___277 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___278 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___278 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___277 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___277 {
	struct rw_semaphore___278 rwsem;
	struct notifier_block *head;
};

struct bio_vec___146 {
	struct page___278 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

typedef void bio_end_io_t___146(struct bio___146 *);

struct gendisk___78;

struct bio_integrity_payload___146;

struct bio___146 {
	struct bio___146 *bi_next;
	struct gendisk___78 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___146 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___146 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___146 *bi_io_vec;
	struct bio_set___146 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___146 bi_inline_vecs[0];
};

struct bio_integrity_payload___146 {
	struct bio___146 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___146 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___146 bip_inline_vecs[0];
};

struct dev_pm_info___240 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___240 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___240;

struct bus_type___240;

struct device_driver___240;

struct dev_pm_domain___240;

struct dma_map_ops___67;

struct fwnode_handle___175;

struct class___240;

struct attribute_group___242;

struct device___240 {
	struct device___240 *parent;
	struct device_private *p;
	struct kobject___265 kobj;
	const char *init_name;
	const struct device_type___240 *type;
	struct mutex mutex;
	struct bus_type___240 *bus;
	struct device_driver___240 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___240 power;
	struct dev_pm_domain___240 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___67 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___175 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___240 *class;
	const struct attribute_group___242 **groups;
	void (*release)(struct device___240 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___78 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___240 __dev;
	struct kobject___265 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___78;

struct block_device_operations___78;

struct gendisk___78 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___78 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___78 *part_tbl;
	struct hd_struct___78 part0;
	const struct block_device_operations___78 *fops;
	struct request_queue___77 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___278 lookup_sem;
	struct kobject___265 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___265 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_ops___240;

struct device_type___240 {
	const char *name;
	const struct attribute_group___242 **groups;
	int (*uevent)(struct device___240 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___240 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___240 *);
	const struct dev_pm_ops___240 *pm;
};

struct kobj_ns_type_operations___25;

struct class___240 {
	const char *name;
	struct module___224 *owner;
	const struct attribute_group___242 **class_groups;
	const struct attribute_group___242 **dev_groups;
	struct kobject___265 *dev_kobj;
	int (*dev_uevent)(struct device___240 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___240 *, umode_t *);
	void (*class_release)(struct class___240 *);
	void (*dev_release)(struct device___240 *);
	int (*shutdown_pre)(struct device___240 *);
	const struct kobj_ns_type_operations___25 *ns_type;
	const void * (*namespace)(struct device___240 *);
	const struct dev_pm_ops___240 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct kernfs_root___271;

struct kernfs_elem_dir___271 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___271 *root;
};

struct kernfs_syscall_ops___271;

struct kernfs_root___271 {
	struct kernfs_node___272 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___271 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___271 {
	struct kernfs_node___272 *target_kn;
};

struct kernfs_ops___271;

struct kernfs_elem_attr___271 {
	const struct kernfs_ops___271 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___272 *notify_next;
};

struct kernfs_node___272 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___272 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___271 dir;
		struct kernfs_elem_symlink___271 symlink;
		struct kernfs_elem_attr___271 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___271;

struct kernfs_ops___271 {
	int (*open)(struct kernfs_open_file___271 *);
	void (*release)(struct kernfs_open_file___271 *);
	int (*seq_show)(struct seq_file___241 *, void *);
	void * (*seq_start)(struct seq_file___241 *, loff_t *);
	void * (*seq_next)(struct seq_file___241 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___241 *, void *);
	ssize_t (*read)(struct kernfs_open_file___271 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___271 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___271 *, struct vm_area_struct___278 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___271 *, struct poll_table_struct___168 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___271 {
	int (*remount_fs)(struct kernfs_root___271 *, int *, char *);
	int (*show_options)(struct seq_file___241 *, struct kernfs_root___271 *);
	int (*mkdir)(struct kernfs_node___272 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___272 *);
	int (*rename)(struct kernfs_node___272 *, struct kernfs_node___272 *, const char *);
	int (*show_path)(struct seq_file___241 *, struct kernfs_node___272 *, struct kernfs_root___271 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___240;

struct seq_file___241 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___240 *op;
	int poll_event;
	const struct file___277 *file;
	void *private;
};

struct kernfs_open_file___271 {
	struct kernfs_node___272 *kn;
	struct file___277 *file;
	struct seq_file___241 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___266 *vm_ops;
};

struct path___277 {
	struct vfsmount *mnt;
	struct dentry___277 *dentry;
};

struct file___277 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___277 f_path;
	struct inode___277 *f_inode;
	const struct file_operations___277 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___102 f_owner;
	const struct cred___262 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___276 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___266;

struct vm_operations_struct___266 {
	void (*open)(struct vm_area_struct___278 *);
	void (*close)(struct vm_area_struct___278 *);
	int (*split)(struct vm_area_struct___278 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___278 *);
	vm_fault_t (*fault)(struct vm_fault___266 *);
	vm_fault_t (*huge_fault)(struct vm_fault___266 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___266 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___278 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___266 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___266 *);
	int (*access)(struct vm_area_struct___278 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___278 *);
	int (*set_policy)(struct vm_area_struct___278 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___278 *, long unsigned int);
	struct page___278 * (*find_special_page)(struct vm_area_struct___278 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___170)(struct file___277 *, wait_queue_head_t *, struct poll_table_struct___168 *);

struct poll_table_struct___168 {
	poll_queue_proc___170 _qproc;
	__poll_t _key;
};

struct sock___26;

struct kobj_ns_type_operations___25 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___26 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___47 *net;
} possible_net_t___37;

struct proto___25;

struct sock_common___25 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___25 *skc_prot;
	possible_net_t___37 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___26 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___38;

struct sk_buff_head___36 {
	struct sk_buff___38 *next;
	struct sk_buff___38 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___25;

struct socket_wq___26;

struct dst_entry___25;

struct socket___27;

struct net_device___38;

struct sock___26 {
	struct sock_common___25 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___36 sk_error_queue;
	struct sk_buff_head___36 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___38 *head;
		struct sk_buff___38 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___25 *sk_filter;
	union {
		struct socket_wq___26 *sk_wq;
		struct socket_wq___26 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___25 *sk_rx_dst;
	struct dst_entry___25 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___38 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___36 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___277 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___25 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___103 *sk_peer_pid;
	const struct cred___262 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___27 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___114 *sk_memcg;
	void (*sk_state_change)(struct sock___26 *);
	void (*sk_data_ready)(struct sock___26 *);
	void (*sk_write_space)(struct sock___26 *);
	void (*sk_error_report)(struct sock___26 *);
	int (*sk_backlog_rcv)(struct sock___26 *, struct sk_buff___38 *);
	struct sk_buff___38 * (*sk_validate_xmit_skb)(struct sock___26 *, struct net_device___38 *, struct sk_buff___38 *);
	void (*sk_destruct)(struct sock___26 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct bin_attribute___241;

struct attribute_group___242 {
	const char *name;
	umode_t (*is_visible)(struct kobject___265 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___265 *, struct bin_attribute___241 *, int);
	struct attribute **attrs;
	struct bin_attribute___241 **bin_attrs;
};

struct bin_attribute___241 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___277 *, struct kobject___265 *, struct bin_attribute___241 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___277 *, struct kobject___265 *, struct bin_attribute___241 *, char *, loff_t, size_t);
	int (*mmap)(struct file___277 *, struct kobject___265 *, struct bin_attribute___241 *, struct vm_area_struct___278 *);
};

struct sysfs_ops___264 {
	ssize_t (*show)(struct kobject___265 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___265 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___264;

struct kset___264 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___265 kobj;
	const struct kset_uevent_ops___264 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___264 {
	void (*release)(struct kobject___265 *);
	const struct sysfs_ops___264 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___25 * (*child_ns_type)(struct kobject___265 *);
	const void * (*namespace)(struct kobject___265 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___264 {
	int (* const filter)(struct kset___264 *, struct kobject___265 *);
	const char * (* const name)(struct kset___264 *, struct kobject___265 *);
	int (* const uevent)(struct kset___264 *, struct kobject___265 *, struct kobj_uevent_env *);
};

struct kobj_attribute___257 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___265 *, struct kobj_attribute___257 *, char *);
	ssize_t (*store)(struct kobject___265 *, struct kobj_attribute___257 *, const char *, size_t);
};

struct dev_pm_ops___240 {
	int (*prepare)(struct device___240 *);
	void (*complete)(struct device___240 *);
	int (*suspend)(struct device___240 *);
	int (*resume)(struct device___240 *);
	int (*freeze)(struct device___240 *);
	int (*thaw)(struct device___240 *);
	int (*poweroff)(struct device___240 *);
	int (*restore)(struct device___240 *);
	int (*suspend_late)(struct device___240 *);
	int (*resume_early)(struct device___240 *);
	int (*freeze_late)(struct device___240 *);
	int (*thaw_early)(struct device___240 *);
	int (*poweroff_late)(struct device___240 *);
	int (*restore_early)(struct device___240 *);
	int (*suspend_noirq)(struct device___240 *);
	int (*resume_noirq)(struct device___240 *);
	int (*freeze_noirq)(struct device___240 *);
	int (*thaw_noirq)(struct device___240 *);
	int (*poweroff_noirq)(struct device___240 *);
	int (*restore_noirq)(struct device___240 *);
	int (*runtime_suspend)(struct device___240 *);
	int (*runtime_resume)(struct device___240 *);
	int (*runtime_idle)(struct device___240 *);
};

struct dev_pm_domain___240 {
	struct dev_pm_ops___240 ops;
	void (*detach)(struct device___240 *, bool);
	int (*activate)(struct device___240 *);
	void (*sync)(struct device___240 *);
	void (*dismiss)(struct device___240 *);
};

struct bus_type___240 {
	const char *name;
	const char *dev_name;
	struct device___240 *dev_root;
	const struct attribute_group___242 **bus_groups;
	const struct attribute_group___242 **dev_groups;
	const struct attribute_group___242 **drv_groups;
	int (*match)(struct device___240 *, struct device_driver___240 *);
	int (*uevent)(struct device___240 *, struct kobj_uevent_env *);
	int (*probe)(struct device___240 *);
	int (*remove)(struct device___240 *);
	void (*shutdown)(struct device___240 *);
	int (*online)(struct device___240 *);
	int (*offline)(struct device___240 *);
	int (*suspend)(struct device___240 *, pm_message_t);
	int (*resume)(struct device___240 *);
	int (*num_vf)(struct device___240 *);
	int (*dma_configure)(struct device___240 *);
	const struct dev_pm_ops___240 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___240 {
	const char *name;
	struct bus_type___240 *bus;
	struct module___224 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___240 *);
	int (*remove)(struct device___240 *);
	void (*shutdown)(struct device___240 *);
	int (*suspend)(struct device___240 *, pm_message_t);
	int (*resume)(struct device___240 *);
	const struct attribute_group___242 **groups;
	const struct dev_pm_ops___240 *pm;
	void (*coredump)(struct device___240 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct module_kobject___221 {
	struct kobject___265 kobj;
	struct module___224 *mod;
	struct kobject___265 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___221 {
	struct module___224 *mod;
	struct latch_tree_node node;
};

struct module_layout___221 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___221 mtn;
};

struct module_attribute___221;

struct kernel_param___221;

struct module___224 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___221 mkobj;
	struct module_attribute___221 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___265 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___221 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___221 core_layout;
	struct module_layout___221 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide68;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide69;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dma_map_ops___67 {
	void * (*alloc)(struct device___240 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___240 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___240 *, struct vm_area_struct___278 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___240 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___240 *, struct page___278 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___240 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___240 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___240 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___240 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___240 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___240 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide43;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___240 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___240 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___240 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___240 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___240 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___240 *, u64);
	u64 (*get_required_mask)(struct device___240 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___175;

struct fwnode_handle___175 {
	struct fwnode_handle___175 *secondary;
	const struct fwnode_operations___175 *ops;
};

struct dentry_operations___276;

struct super_block___276;

struct dentry___277 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___277 *d_parent;
	struct qstr d_name;
	struct inode___277 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___276 *d_op;
	struct super_block___276 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___276;

struct address_space___276 {
	struct inode___277 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___278 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___276 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___276;

struct block_device___276;

struct inode___277 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___276 *i_op;
	struct super_block___276 *i_sb;
	struct address_space___276 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___278 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___146 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___277 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___276 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___66 *i_pipe;
		struct block_device___276 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___276 {
	int (*d_revalidate)(struct dentry___277 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___277 *, unsigned int);
	int (*d_hash)(const struct dentry___277 *, struct qstr *);
	int (*d_compare)(const struct dentry___277 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___277 *);
	int (*d_init)(struct dentry___277 *);
	void (*d_release)(struct dentry___277 *);
	void (*d_prune)(struct dentry___277 *);
	void (*d_iput)(struct dentry___277 *, struct inode___277 *);
	char * (*d_dname)(struct dentry___277 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___277 *);
	int (*d_manage)(const struct path___277 *, bool);
	struct dentry___277 * (*d_real)(struct dentry___277 *, const struct inode___277 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___276;

struct mem_dqinfo___276 {
	struct quota_format_type___276 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___276;

struct quota_info___276 {
	unsigned int flags;
	struct rw_semaphore___278 dqio_sem;
	struct inode___277 *files[3];
	struct mem_dqinfo___276 info[3];
	const struct quota_format_ops___276 *ops[3];
};

struct rcuwait___276 {
	struct task_struct___278 *task;
};

struct percpu_rw_semaphore___276 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___278 rw_sem;
	struct rcuwait___276 writer;
	int readers_block;
};

struct sb_writers___276 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___276 rw_sem[3];
};

struct shrink_control___114;

struct shrinker___114 {
	long unsigned int (*count_objects)(struct shrinker___114 *, struct shrink_control___114 *);
	long unsigned int (*scan_objects)(struct shrinker___114 *, struct shrink_control___114 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___276;

struct super_operations___276;

struct dquot_operations___276;

struct quotactl_ops___276;

struct super_block___276 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___276 *s_type;
	const struct super_operations___276 *s_op;
	const struct dquot_operations___276 *dq_op;
	const struct quotactl_ops___276 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___277 *s_root;
	struct rw_semaphore___278 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___276 *s_bdev;
	struct backing_dev_info___146 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___276 s_dquot;
	struct sb_writers___276 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___276 *s_d_op;
	int cleancache_poolid;
	struct shrinker___114 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___219 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___114 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___114 *memcg;
};

typedef int (*dev_page_fault_t___266)(struct vm_area_struct___278 *, long unsigned int, const struct page___278 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___266)(struct page___278 *, void *);

struct dev_pagemap___266 {
	dev_page_fault_t___266 page_fault;
	dev_page_free_t___266 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___240 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___277 {
	struct task_struct___278 *task;
	struct core_thread___277 *next;
};

struct core_state___277 {
	atomic_t nr_threads;
	struct core_thread___277 dumper;
	struct completion startup;
};

struct vm_fault___266 {
	struct vm_area_struct___278 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___278 *cow_page;
	struct mem_cgroup___114 *memcg;
	struct page___278 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___277 prealloc_pte;
};

struct io_cq___81 {
	struct request_queue___77 *q;
	struct io_context___81 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___277 {
	struct file___277 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___277 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___276 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___277 *ia_file;
};

struct dquot___276 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___276 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___276 {
	int qf_fmt_id;
	const struct quota_format_ops___276 *qf_ops;
	struct module___224 *qf_owner;
	struct quota_format_type___276 *qf_next;
};

struct quota_format_ops___276 {
	int (*check_quota_file)(struct super_block___276 *, int);
	int (*read_file_info)(struct super_block___276 *, int);
	int (*write_file_info)(struct super_block___276 *, int);
	int (*free_file_info)(struct super_block___276 *, int);
	int (*read_dqblk)(struct dquot___276 *);
	int (*commit_dqblk)(struct dquot___276 *);
	int (*release_dqblk)(struct dquot___276 *);
	int (*get_next_id)(struct super_block___276 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___276 {
	int (*write_dquot)(struct dquot___276 *);
	struct dquot___276 * (*alloc_dquot)(struct super_block___276 *, int);
	void (*destroy_dquot)(struct dquot___276 *);
	int (*acquire_dquot)(struct dquot___276 *);
	int (*release_dquot)(struct dquot___276 *);
	int (*mark_dirty)(struct dquot___276 *);
	int (*write_info)(struct super_block___276 *, int);
	qsize_t * (*get_reserved_space)(struct inode___277 *);
	int (*get_projid)(struct inode___277 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___277 *, qsize_t *);
	int (*get_next_id)(struct super_block___276 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___276 {
	int (*quota_on)(struct super_block___276 *, int, int, const struct path___277 *);
	int (*quota_off)(struct super_block___276 *, int);
	int (*quota_enable)(struct super_block___276 *, unsigned int);
	int (*quota_disable)(struct super_block___276 *, unsigned int);
	int (*quota_sync)(struct super_block___276 *, int);
	int (*set_info)(struct super_block___276 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___276 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___276 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___276 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___276 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___276 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___129;

struct address_space_operations___276 {
	int (*writepage)(struct page___278 *, struct writeback_control___129 *);
	int (*readpage)(struct file___277 *, struct page___278 *);
	int (*writepages)(struct address_space___276 *, struct writeback_control___129 *);
	int (*set_page_dirty)(struct page___278 *);
	int (*readpages)(struct file___277 *, struct address_space___276 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___277 *, struct address_space___276 *, loff_t, unsigned int, unsigned int, struct page___278 **, void **);
	int (*write_end)(struct file___277 *, struct address_space___276 *, loff_t, unsigned int, unsigned int, struct page___278 *, void *);
	sector_t (*bmap)(struct address_space___276 *, sector_t);
	void (*invalidatepage)(struct page___278 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___278 *, gfp_t);
	void (*freepage)(struct page___278 *);
	ssize_t (*direct_IO)(struct kiocb___277 *, struct iov_iter___134 *);
	int (*migratepage)(struct address_space___276 *, struct page___278 *, struct page___278 *, enum migrate_mode);
	bool (*isolate_page)(struct page___278 *, isolate_mode_t);
	void (*putback_page)(struct page___278 *);
	int (*launder_page)(struct page___278 *);
	int (*is_partially_uptodate)(struct page___278 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___278 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___276 *, struct page___278 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___277 *, sector_t *);
	void (*swap_deactivate)(struct file___277 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___129 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___146 *wb;
	struct inode___277 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct iov_iter___134 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___146 *bvec;
		struct pipe_inode_info___66 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___276 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___277 *bd_inode;
	struct super_block___276 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___276 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___78 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___78 *bd_disk;
	struct request_queue___77 *bd_queue;
	struct backing_dev_info___146 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___276 {
	struct dentry___277 * (*lookup)(struct inode___277 *, struct dentry___277 *, unsigned int);
	const char * (*get_link)(struct dentry___277 *, struct inode___277 *, struct delayed_call *);
	int (*permission)(struct inode___277 *, int);
	struct posix_acl * (*get_acl)(struct inode___277 *, int);
	int (*readlink)(struct dentry___277 *, char *, int);
	int (*create)(struct inode___277 *, struct dentry___277 *, umode_t, bool);
	int (*link)(struct dentry___277 *, struct inode___277 *, struct dentry___277 *);
	int (*unlink)(struct inode___277 *, struct dentry___277 *);
	int (*symlink)(struct inode___277 *, struct dentry___277 *, const char *);
	int (*mkdir)(struct inode___277 *, struct dentry___277 *, umode_t);
	int (*rmdir)(struct inode___277 *, struct dentry___277 *);
	int (*mknod)(struct inode___277 *, struct dentry___277 *, umode_t, dev_t);
	int (*rename)(struct inode___277 *, struct dentry___277 *, struct inode___277 *, struct dentry___277 *, unsigned int);
	int (*setattr)(struct dentry___277 *, struct iattr___276 *);
	int (*getattr)(const struct path___277 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___277 *, char *, size_t);
	int (*fiemap)(struct inode___277 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___277 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___277 *, struct dentry___277 *, struct file___277 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___277 *, struct dentry___277 *, umode_t);
	int (*set_acl)(struct inode___277 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___276 {
	void (*fl_copy_lock)(struct file_lock___277 *, struct file_lock___277 *);
	void (*fl_release_private)(struct file_lock___277 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___276;

struct file_lock___277 {
	struct file_lock___277 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___277 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___276 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___276 *fl_ops;
	const struct lock_manager_operations___276 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___276 {
	int (*lm_compare_owner)(struct file_lock___277 *, struct file_lock___277 *);
	long unsigned int (*lm_owner_key)(struct file_lock___277 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___277 *);
	int (*lm_grant)(struct file_lock___277 *, int);
	bool (*lm_break)(struct file_lock___277 *);
	int (*lm_change)(struct file_lock___277 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___277 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___276 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___276 *fa_next;
	struct file___277 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___276 {
	const char *name;
	int fs_flags;
	struct dentry___277 * (*mount)(struct file_system_type___276 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___276 *);
	struct module___224 *owner;
	struct file_system_type___276 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___276 {
	struct inode___277 * (*alloc_inode)(struct super_block___276 *);
	void (*destroy_inode)(struct inode___277 *);
	void (*dirty_inode)(struct inode___277 *, int);
	int (*write_inode)(struct inode___277 *, struct writeback_control___129 *);
	int (*drop_inode)(struct inode___277 *);
	void (*evict_inode)(struct inode___277 *);
	void (*put_super)(struct super_block___276 *);
	int (*sync_fs)(struct super_block___276 *, int);
	int (*freeze_super)(struct super_block___276 *);
	int (*freeze_fs)(struct super_block___276 *);
	int (*thaw_super)(struct super_block___276 *);
	int (*unfreeze_fs)(struct super_block___276 *);
	int (*statfs)(struct dentry___277 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___276 *, int *, char *);
	void (*umount_begin)(struct super_block___276 *);
	int (*show_options)(struct seq_file___241 *, struct dentry___277 *);
	int (*show_devname)(struct seq_file___241 *, struct dentry___277 *);
	int (*show_path)(struct seq_file___241 *, struct dentry___277 *);
	int (*show_stats)(struct seq_file___241 *, struct dentry___277 *);
	ssize_t (*quota_read)(struct super_block___276 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___276 *, int, const char *, size_t, loff_t);
	struct dquot___276 ** (*get_dquots)(struct inode___277 *);
	int (*bdev_try_to_free_page)(struct super_block___276 *, struct page___278 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___276 *, struct shrink_control___114 *);
	long int (*free_cached_objects)(struct super_block___276 *, struct shrink_control___114 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___78 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___78 *last_lookup;
	struct hd_struct___78 *part[0];
};

struct block_device_operations___78 {
	int (*open)(struct block_device___276 *, fmode_t);
	void (*release)(struct gendisk___78 *, fmode_t);
	int (*rw_page)(struct block_device___276 *, sector_t, struct page___278 *, unsigned int);
	int (*ioctl)(struct block_device___276 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___276 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___78 *, unsigned int);
	int (*media_changed)(struct gendisk___78 *);
	void (*unlock_native_capacity)(struct gendisk___78 *);
	int (*revalidate_disk)(struct gendisk___78 *);
	int (*getgeo)(struct block_device___276 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___276 *, long unsigned int);
	int (*report_zones)(struct gendisk___78 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___224 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___266(struct page___278 *);

struct bdi_writeback_congested___146 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___146 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bsg_ops___77 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___77 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___77 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___77 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___77(struct request___77 *, blk_status_t);

struct request___77 {
	struct request_queue___77 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___19 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___146 *bio;
	struct bio___146 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___146 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___81 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___77 *saved_end_io;
		} flush;
	};
	struct gendisk___78 *rq_disk;
	struct hd_struct___78 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___77 *end_io;
	void *end_io_data;
	struct request___77 *next_rq;
};

struct fwnode_reference_args___175;

struct fwnode_endpoint___175;

struct fwnode_operations___175 {
	struct fwnode_handle___175 * (*get)(struct fwnode_handle___175 *);
	void (*put)(struct fwnode_handle___175 *);
	bool (*device_is_available)(const struct fwnode_handle___175 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___175 *, const struct device___240 *);
	bool (*property_present)(const struct fwnode_handle___175 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___175 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___175 *, const char *, const char **, size_t);
	struct fwnode_handle___175 * (*get_parent)(const struct fwnode_handle___175 *);
	struct fwnode_handle___175 * (*get_next_child_node)(const struct fwnode_handle___175 *, struct fwnode_handle___175 *);
	struct fwnode_handle___175 * (*get_named_child_node)(const struct fwnode_handle___175 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___175 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___175 *);
	struct fwnode_handle___175 * (*graph_get_next_endpoint)(const struct fwnode_handle___175 *, struct fwnode_handle___175 *);
	struct fwnode_handle___175 * (*graph_get_remote_endpoint)(const struct fwnode_handle___175 *);
	struct fwnode_handle___175 * (*graph_get_port_parent)(struct fwnode_handle___175 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___175 *, struct fwnode_endpoint___175 *);
};

struct fwnode_endpoint___175 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___175 *local_fwnode;
};

struct fwnode_reference_args___175 {
	struct fwnode_handle___175 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct blk_mq_hw_ctx___19 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___77 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags___4 *tags;
	struct blk_mq_tags___4 *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	unsigned int rh_reserved_nr_expired;
	struct hlist_node cpuhp_dead;
	struct kobject___265 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___277 *debugfs_dir;
	struct dentry___277 *sched_debugfs_dir;
	struct list_head hctx_list;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___77;

struct elevator_mq_ops___77 {
	int (*init_sched)(struct request_queue___77 *, struct elevator_type___77 *);
	void (*exit_sched)(struct elevator_queue___77 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___19 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___19 *, unsigned int);
	bool (*allow_merge)(struct request_queue___77 *, struct request___77 *, struct bio___146 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx___19 *, struct bio___146 *);
	int (*request_merge)(struct request_queue___77 *, struct request___77 **, struct bio___146 *);
	void (*request_merged)(struct request_queue___77 *, struct request___77 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___77 *, struct request___77 *, struct request___77 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___77 *, struct bio___146 *);
	void (*finish_request)(struct request___77 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___19 *, struct list_head *, bool);
	struct request___77 * (*dispatch_request)(struct blk_mq_hw_ctx___19 *);
	bool (*has_work)(struct blk_mq_hw_ctx___19 *);
	void (*completed_request)(struct request___77 *, u64);
	void (*started_request)(struct request___77 *);
	void (*requeue_request)(struct request___77 *);
	struct request___77 * (*former_request)(struct request_queue___77 *, struct request___77 *);
	struct request___77 * (*next_request)(struct request_queue___77 *, struct request___77 *);
	void (*init_icq)(struct io_cq___81 *);
	void (*exit_icq)(struct io_cq___81 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx___19 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___77;

struct elevator_type___77 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___77 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___77 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___224 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___77 {
	struct elevator_type___77 *type;
	void *elevator_data;
	struct kobject___265 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___77 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___77 *, char *);
	ssize_t (*store)(struct elevator_queue___77 *, const char *, size_t);
};

struct blk_mq_queue_data___19;

typedef blk_status_t queue_rq_fn___19(struct blk_mq_hw_ctx___19 *, const struct blk_mq_queue_data___19 *);

typedef void commit_rqs_fn___19(struct blk_mq_hw_ctx___19 *);

typedef bool get_budget_fn___19(struct blk_mq_hw_ctx___19 *);

typedef void put_budget_fn___19(struct blk_mq_hw_ctx___19 *);

typedef enum blk_eh_timer_return timeout_fn___19(struct request___77 *, bool);

typedef int poll_fn___19(struct blk_mq_hw_ctx___19 *);

typedef void complete_fn___19(struct request___77 *);

typedef int init_hctx_fn___19(struct blk_mq_hw_ctx___19 *, void *, unsigned int);

typedef void exit_hctx_fn___19(struct blk_mq_hw_ctx___19 *, unsigned int);

typedef int init_request_fn___19(struct blk_mq_tag_set___19 *, struct request___77 *, unsigned int, unsigned int);

typedef void exit_request_fn___19(struct blk_mq_tag_set___19 *, struct request___77 *, unsigned int);

typedef bool busy_fn___19(struct request_queue___77 *);

typedef int map_queues_fn___19(struct blk_mq_tag_set___19 *);

typedef void cleanup_rq_fn___19(struct request___77 *);

struct blk_mq_ops___19 {
	queue_rq_fn___19 *queue_rq;
	commit_rqs_fn___19 *commit_rqs;
	get_budget_fn___19 *get_budget;
	put_budget_fn___19 *put_budget;
	timeout_fn___19 *timeout;
	poll_fn___19 *poll;
	complete_fn___19 *complete;
	init_hctx_fn___19 *init_hctx;
	exit_hctx_fn___19 *exit_hctx;
	init_request_fn___19 *init_request;
	exit_request_fn___19 *exit_request;
	void (*initialize_rq_fn)(struct request___77 *);
	busy_fn___19 *busy;
	map_queues_fn___19 *map_queues;
	void (*show_rq)(struct seq_file___241 *, struct request___77 *);
	union {
		cleanup_rq_fn___19 *cleanup_rq;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide42;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct blk_mq_tag_set___19 {
	struct blk_mq_queue_map map[6];
	unsigned int nr_maps;
	const struct blk_mq_ops___19 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	struct blk_mq_tags___4 **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct blk_mq_queue_data___19 {
	struct request___77 *rq;
	bool last;
	long unsigned int rh_reserved1;
};

struct irq_poll;

typedef int irq_poll_fn(struct irq_poll *, int);

struct irq_poll {
	struct list_head list;
	long unsigned int state;
	int weight;
	irq_poll_fn *poll;
};

struct msghdr___28 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___134 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___277 *msg_iocb;
};

struct socket_wq___26 {
	wait_queue_head_t wait;
	struct fasync_struct___276 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___26;

struct socket___27 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___26 *wq;
	struct file___277 *file;
	struct sock___26 *sk;
	const struct proto_ops___26 *ops;
};

typedef int (*sk_read_actor_t___25)(read_descriptor_t *, struct sk_buff___38 *, unsigned int, size_t);

struct proto_ops___26 {
	int family;
	struct module___224 *owner;
	int (*release)(struct socket___27 *);
	int (*bind)(struct socket___27 *, struct sockaddr *, int);
	int (*connect)(struct socket___27 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___27 *, struct socket___27 *);
	int (*accept)(struct socket___27 *, struct socket___27 *, int, bool);
	int (*getname)(struct socket___27 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___277 *, struct socket___27 *, struct poll_table_struct___168 *);
	int (*ioctl)(struct socket___27 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___27 *, int);
	int (*shutdown)(struct socket___27 *, int);
	int (*setsockopt)(struct socket___27 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___27 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___27 *, struct msghdr___28 *, size_t);
	int (*recvmsg)(struct socket___27 *, struct msghdr___28 *, size_t, int);
	int (*mmap)(struct file___277 *, struct socket___27 *, struct vm_area_struct___278 *);
	ssize_t (*sendpage)(struct socket___27 *, struct page___278 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___27 *, loff_t *, struct pipe_inode_info___66 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___26 *, int);
	int (*peek_len)(struct socket___27 *);
	int (*read_sock)(struct sock___26 *, read_descriptor_t *, sk_read_actor_t___25);
	int (*sendpage_locked)(struct sock___26 *, struct page___278 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___26 *, struct msghdr___28 *, size_t);
	int (*set_rcvlowat)(struct sock___26 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct nf_bridge_info___36;

struct sk_buff___38 {
	union {
		struct {
			struct sk_buff___38 *next;
			struct sk_buff___38 *prev;
			union {
				struct net_device___38 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___26 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___38 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___36 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___36;

struct netns_frags___36 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___36 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ip_ra_chain___12;

struct fib_rules_ops___25;

struct fib_notifier_ops___25;

struct netns_ipv4___36 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___12 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___25 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___26 *fibnl;
	struct sock___26 **icmp_sk;
	struct sock___26 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___26 **tcp_sk;
	struct netns_frags___36 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___25 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___25 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___25 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___25;

struct dst_ops___46 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___46 *);
	struct dst_entry___25 * (*check)(struct dst_entry___25 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___25 *);
	unsigned int (*mtu)(const struct dst_entry___25 *);
	u32 * (*cow_metrics)(struct dst_entry___25 *, long unsigned int);
	void (*destroy)(struct dst_entry___25 *);
	void (*ifdown)(struct dst_entry___25 *, struct net_device___38 *, int);
	struct dst_entry___25 * (*negative_advice)(struct dst_entry___25 *);
	void (*link_failure)(struct sk_buff___38 *);
	void (*update_pmtu)(struct dst_entry___25 *, struct sock___26 *, struct sk_buff___38 *, u32);
	void (*redirect)(struct dst_entry___25 *, struct sock___26 *, struct sk_buff___38 *);
	int (*local_out)(struct net___47 *, struct sock___26 *, struct sk_buff___38 *);
	struct neighbour___25 * (*neigh_lookup)(const struct dst_entry___25 *, struct sk_buff___38 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___25 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___46 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___36 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___46 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___25 *fib6_rules_ops;
	struct sock___26 **icmp_sk;
	struct sock___26 *ndisc_sk;
	struct sock___26 *tcp_sk;
	struct sock___26 *igmp_sk;
	struct sock___26 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___25 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___25 *notifier_ops;
	struct fib_notifier_ops___25 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___26 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___26 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___36 {
	struct netns_frags___36 frags;
};

struct netns_xfrm___46 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___26 *nlsk;
	struct sock___26 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___46 xfrm4_dst_ops;
	struct dst_ops___46 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___35;

struct net___47 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___219 *user_ns;
	struct ucounts___219 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___9 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___26 *rtnl;
	struct sock___26 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___38 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___36 ipv4;
	struct netns_ipv6___46 ipv6;
	struct netns_sctp___26 sctp;
	struct netns_nf nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___36 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___26 *nfnl;
	struct sock___26 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___46 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___26 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___35 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pipe_buf_operations___66;

struct pipe_buffer___66 {
	struct page___278 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___66 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___66 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___66 *, struct pipe_buffer___66 *);
	void (*release)(struct pipe_inode_info___66 *, struct pipe_buffer___66 *);
	int (*steal)(struct pipe_inode_info___66 *, struct pipe_buffer___66 *);
	union {
		bool (*get)(struct pipe_inode_info___66 *, struct pipe_buffer___66 *);
		struct {
			void (*get)(struct pipe_inode_info___66 *, struct pipe_buffer___66 *);
		} __UNIQUE_ID_rh_kabi_hide48;
		union {		};
	};
};

struct nf_bridge_info___36 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___36 = 0,
		BRNF_PROTO_8021Q___36 = 1,
		BRNF_PROTO_PPPOE___36 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___38 *physindev;
	struct net_device___38 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___36(struct sk_buff___38 **);

struct net_device_ops___36;

struct ethtool_ops___36;

struct l3mdev_ops___25;

struct ndisc_ops___15;

struct xfrmdev_ops___36;

struct tlsdev_ops___36;

struct header_ops___36;

struct inet6_dev___15;

struct netdev_rx_queue___36;

struct mini_Qdisc___35;

struct netdev_queue___36;

struct Qdisc___35;

struct rtnl_link_ops___35;

struct dcbnl_rtnl_ops___36;

struct net_device___38 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___36 *netdev_ops;
	const struct ethtool_ops___36 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___25 *l3mdev_ops;
	const struct ndisc_ops___15 *ndisc_ops;
	const struct xfrmdev_ops___36 *xfrmdev_ops;
	const struct tlsdev_ops___36 *tlsdev_ops;
	const struct header_ops___36 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___264 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___15 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___36 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___35 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___36 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___35 *miniq_ingress;
	struct netdev_queue___36 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___36 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___35 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___35 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___36 = 0,
		NETREG_REGISTERED___36 = 1,
		NETREG_UNREGISTERING___36 = 2,
		NETREG_UNREGISTERED___36 = 3,
		NETREG_RELEASED___36 = 4,
		NETREG_DUMMY___36 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___36 = 0,
		RTNL_LINK_INITIALIZING___36 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___38 *);
	struct netpoll_info *npinfo;
	possible_net_t___37 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___240 dev;
	const struct attribute_group___242 *sysfs_groups[4];
	const struct attribute_group___242 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___35 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___36 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide62;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct ethtool_ops___36 {
	int (*get_settings)(struct net_device___38 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___38 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___38 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___38 *);
	void (*get_regs)(struct net_device___38 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___38 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___38 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___38 *);
	void (*set_msglevel)(struct net_device___38 *, u32);
	int (*nway_reset)(struct net_device___38 *);
	u32 (*get_link)(struct net_device___38 *);
	int (*get_eeprom_len)(struct net_device___38 *);
	int (*get_eeprom)(struct net_device___38 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___38 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___38 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___38 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___38 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___38 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___38 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___38 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___38 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___38 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___38 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___38 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___38 *);
	void (*complete)(struct net_device___38 *);
	u32 (*get_priv_flags)(struct net_device___38 *);
	int (*set_priv_flags)(struct net_device___38 *, u32);
	int (*get_sset_count)(struct net_device___38 *, int);
	int (*get_rxnfc)(struct net_device___38 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___38 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___38 *, struct ethtool_flash *);
	int (*reset)(struct net_device___38 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___38 *);
	u32 (*get_rxfh_indir_size)(struct net_device___38 *);
	int (*get_rxfh)(struct net_device___38 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___38 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___38 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___38 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___38 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___38 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___38 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___38 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___38 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___38 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___38 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___38 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___38 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___38 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___38 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___38 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___38 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___38 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___38 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___38 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide51;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___38 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___38 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide52;
		union {		};
	};
	int (*get_fecparam)(struct net_device___38 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___38 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___38 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___38 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide53;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___38 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide54;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___36;

struct inet_frags___36 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___36 *, const void *);
	void (*destructor)(struct inet_frag_queue___36 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___36 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___38 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___38 *fragments_tail;
	struct sk_buff___38 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___36 *net;
	struct callback_head rcu;
};

struct ip_ra_chain___12 {
	struct ip_ra_chain___12 *next;
	struct sock___26 *sk;
	union {
		void (*destructor)(struct sock___26 *);
		struct sock___26 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___25;

struct fib_lookup_arg___25;

struct fib_rules_ops___25 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___25 *, struct flowi *, int, struct fib_lookup_arg___25 *);
	bool (*suppress)(struct fib_rule___25 *, struct fib_lookup_arg___25 *);
	int (*match)(struct fib_rule___25 *, struct flowi *, int);
	int (*configure)(struct fib_rule___25 *, struct sk_buff___38 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___25 *);
	int (*compare)(struct fib_rule___25 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___25 *, struct sk_buff___38 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___25 *);
	void (*flush_cache)(struct fib_rules_ops___25 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___224 *owner;
	struct net___47 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___25 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___47 *);
	int (*fib_dump)(struct net___47 *, struct notifier_block *);
	struct module___224 *owner;
	struct callback_head rcu;
};

struct dst_entry___25 {
	struct net_device___38 *dev;
	struct dst_ops___46 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___38 *);
	int (*output)(struct net___47 *, struct sock___26 *, struct sk_buff___38 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___25;

struct neigh_parms___25;

struct neigh_ops___25;

struct neighbour___25 {
	struct neighbour___25 *next;
	struct neigh_table___25 *tbl;
	struct neigh_parms___25 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___36 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___25 *, struct sk_buff___38 *);
	const struct neigh_ops___25 *ops;
	struct callback_head rcu;
	struct net_device___38 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct ucounts___219 {
	struct hlist_node node;
	struct user_namespace___219 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_prog_aux___38;

struct bpf_prog___35 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___38 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

typedef int (*key_restrict_link_func_t___263)(struct key___262 *, const struct key_type *, const union key_payload *, struct key___262 *);

struct key_restriction___262;

struct key___262 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___278 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___262 *restrict_link;
};

struct key_restriction___262 {
	key_restrict_link_func_t___263 check;
	struct key___262 *key;
	struct key_type *keytype;
};

struct seq_operations___240 {
	void * (*start)(struct seq_file___241 *, loff_t *);
	void (*stop)(struct seq_file___241 *, void *);
	void * (*next)(struct seq_file___241 *, void *, loff_t *);
	int (*show)(struct seq_file___241 *, void *);
};

struct pernet_operations___37 {
	struct list_head list;
	int (*init)(struct net___47 *);
	void (*exit)(struct net___47 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___36 {
	int (*ieee_getets)(struct net_device___38 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___38 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___38 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___38 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___38 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___38 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___38 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___38 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___38 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___38 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___38 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___38 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___38 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___38 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___38 *);
	u8 (*setstate)(struct net_device___38 *, u8);
	void (*getpermhwaddr)(struct net_device___38 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___38 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___38 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___38 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___38 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___38 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___38 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___38 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___38 *, int, u8 *);
	void (*setpfccfg)(struct net_device___38 *, int, u8);
	void (*getpfccfg)(struct net_device___38 *, int, u8 *);
	u8 (*setall)(struct net_device___38 *);
	u8 (*getcap)(struct net_device___38 *, int, u8 *);
	int (*getnumtcs)(struct net_device___38 *, int, u8 *);
	int (*setnumtcs)(struct net_device___38 *, int, u8);
	u8 (*getpfcstate)(struct net_device___38 *);
	void (*setpfcstate)(struct net_device___38 *, u8);
	void (*getbcncfg)(struct net_device___38 *, int, u32 *);
	void (*setbcncfg)(struct net_device___38 *, int, u32);
	void (*getbcnrp)(struct net_device___38 *, int, u8 *);
	void (*setbcnrp)(struct net_device___38 *, int, u8);
	int (*setapp)(struct net_device___38 *, u8, u16, u8);
	int (*getapp)(struct net_device___38 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___38 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___38 *, int, u8);
	u8 (*getdcbx)(struct net_device___38 *);
	u8 (*setdcbx)(struct net_device___38 *, u8);
	int (*peer_getappinfo)(struct net_device___38 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___38 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___38 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___38 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___38 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___38 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___204 {
	refcount_t count;
	struct ns_common___9 ns;
	struct user_namespace___219 *user_ns;
	struct ucounts___219 *ucounts;
	struct css_set___204 *root_cset;
};

struct bpf_map___205;

struct bpf_map_ops___204 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___205 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___205 *, struct file___277 *);
	void (*map_free)(struct bpf_map___205 *);
	int (*map_get_next_key)(struct bpf_map___205 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___205 *);
	void * (*map_lookup_elem)(struct bpf_map___205 *, void *);
	int (*map_update_elem)(struct bpf_map___205 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___205 *, void *);
	int (*map_push_elem)(struct bpf_map___205 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___205 *, void *);
	int (*map_peek_elem)(struct bpf_map___205 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___205 *, struct file___277 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___205 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___205 *, void *, struct seq_file___241 *);
	int (*map_check_btf)(const struct bpf_map___205 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___205 {
	const struct bpf_map_ops___204 *ops;
	struct bpf_map___205 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___262 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___36;

struct bpf_map_dev_ops___36 {
	int (*map_get_next_key)(struct bpf_offloaded_map___36 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___36 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___36 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___36 *, void *);
};

struct bpf_offloaded_map___36 {
	struct bpf_map___205 map;
	struct net_device___38 *netdev;
	const struct bpf_map_dev_ops___36 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___35 {
	int (*test_run)(struct bpf_prog___35 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___35 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___35 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___35 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___35 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___35 *, u32 *);
};

struct bpf_prog_offload_ops___35 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___35 *);
	int (*translate)(struct bpf_prog___35 *);
	void (*destroy)(struct bpf_prog___35 *);
};

struct bpf_prog_offload___35 {
	struct bpf_prog___35 *prog;
	struct net_device___38 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___35 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___38 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___35 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___35 *ops;
	struct bpf_map___205 **used_maps;
	struct bpf_prog___35 *prog;
	struct user_struct___262 *user;
	u64 load_time;
	struct bpf_map___205 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___35 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___35 {
	struct bpf_prog___35 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___35 {
	struct callback_head rcu;
	struct bpf_prog_array_item___35 items[0];
};

struct cgroup_bpf___35 {
	struct bpf_prog_array___35 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___35 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___204;

typedef void (*kthread_work_func_t___204)(struct kthread_work___204 *);

struct kthread_worker___204;

struct kthread_work___204 {
	struct list_head node;
	kthread_work_func_t___204 func;
	struct kthread_worker___204 *worker;
	int canceling;
};

struct kthread_worker___204 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___278 *task;
	struct kthread_work___204 *current_work;
};

struct kthread_delayed_work___204 {
	struct kthread_work___204 work;
	struct timer_list timer;
};

struct psi_group___204 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___204 *poll_kworker;
	struct kthread_delayed_work___204 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___204;

struct cgroup_rstat_cpu___204;

struct cgroup___204 {
	struct cgroup_subsys_state___204 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___272 *kn;
	struct cgroup_file___204 procs_file;
	struct cgroup_file___204 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___204 *subsys[13];
	struct cgroup_root___204 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___204 *dom_cgrp;
	struct cgroup_rstat_cpu___204 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___35 bpf;
	atomic_t congestion_count;
	struct cgroup___204 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___204 psi;
	int ancestor_ids[0];
};

struct cftype___204;

struct cgroup_subsys___204 {
	struct cgroup_subsys_state___204 * (*css_alloc)(struct cgroup_subsys_state___204 *);
	int (*css_online)(struct cgroup_subsys_state___204 *);
	void (*css_offline)(struct cgroup_subsys_state___204 *);
	void (*css_released)(struct cgroup_subsys_state___204 *);
	void (*css_free)(struct cgroup_subsys_state___204 *);
	void (*css_reset)(struct cgroup_subsys_state___204 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___204 *, int);
	int (*css_extra_stat_show)(struct seq_file___241 *, struct cgroup_subsys_state___204 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___278 *);
	void (*cancel_fork)(struct task_struct___278 *);
	void (*fork)(struct task_struct___278 *);
	void (*exit)(struct task_struct___278 *);
	void (*free)(struct task_struct___278 *);
	void (*bind)(struct cgroup_subsys_state___204 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___204 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___204 *dfl_cftypes;
	struct cftype___204 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___204 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___204 *updated_children;
	struct cgroup___204 *updated_next;
};

struct cgroup_root___204 {
	struct kernfs_root___271 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___204 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___204 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___204 *ss;
	struct list_head node;
	struct kernfs_ops___271 *kf_ops;
	int (*open)(struct kernfs_open_file___271 *);
	void (*release)(struct kernfs_open_file___271 *);
	u64 (*read_u64)(struct cgroup_subsys_state___204 *, struct cftype___204 *);
	s64 (*read_s64)(struct cgroup_subsys_state___204 *, struct cftype___204 *);
	int (*seq_show)(struct seq_file___241 *, void *);
	void * (*seq_start)(struct seq_file___241 *, loff_t *);
	void * (*seq_next)(struct seq_file___241 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___241 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___204 *, struct cftype___204 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___204 *, struct cftype___204 *, s64);
	ssize_t (*write)(struct kernfs_open_file___271 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___271 *, struct poll_table_struct___168 *);
};

struct xdp_rxq_info___36 {
	struct net_device___38 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___36 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___38 *dev_rx;
};

struct netlink_callback___36 {
	struct sk_buff___38 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___36 *);
	int (*dump)(struct sk_buff___38 *, struct netlink_callback___36 *);
	int (*done)(struct netlink_callback___36 *);
	void *data;
	struct module___224 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___36 {
	int (*create)(struct sk_buff___38 *, struct net_device___38 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___38 *, unsigned char *);
	int (*cache)(const struct neighbour___25 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___38 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___36 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___36 *, int);
	int poll_owner;
	struct net_device___38 *dev;
	struct sk_buff___38 *gro_list;
	struct sk_buff___38 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___36 {
	struct net_device___38 *dev;
	struct Qdisc___35 *qdisc;
	struct Qdisc___35 *qdisc_sleeping;
	struct kobject___265 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___38 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide56;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___35 {
	struct sk_buff___38 *head;
	struct sk_buff___38 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___35;

struct Qdisc___35 {
	int (*enqueue)(struct sk_buff___38 *, struct Qdisc___35 *, struct sk_buff___38 **);
	struct sk_buff___38 * (*dequeue)(struct Qdisc___35 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___35 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___36 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___36 gso_skb;
	struct qdisc_skb_head___35 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___35 *next_sched;
	struct sk_buff_head___36 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___36 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___265 kobj;
	struct net_device___38 *dev;
	long: 64;
	struct xdp_rxq_info___36 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide57;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___36)(struct net_device___38 *, struct sk_buff___38 *, struct net_device___38 *);

struct netdev_bpf___36 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___35 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___35 *prog;
			const struct bpf_prog_offload_ops___35 *ops;
		} verifier;
		struct {
			struct bpf_prog___35 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___36 *offmap;
		};
		struct {
			struct xdp_umem *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___36 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___38 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___36 {
	int (*tls_dev_add)(struct net_device___38 *, struct sock___26 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___38 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___38 *, struct sock___26 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide58;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___36 {
	int (*ndo_init)(struct net_device___38 *);
	void (*ndo_uninit)(struct net_device___38 *);
	int (*ndo_open)(struct net_device___38 *);
	int (*ndo_stop)(struct net_device___38 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___38 *, struct net_device___38 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___38 *, struct net_device___38 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___38 *, struct sk_buff___38 *, struct net_device___38 *, select_queue_fallback_t___36);
	void (*ndo_change_rx_flags)(struct net_device___38 *, int);
	void (*ndo_set_rx_mode)(struct net_device___38 *);
	int (*ndo_set_mac_address)(struct net_device___38 *, void *);
	int (*ndo_validate_addr)(struct net_device___38 *);
	int (*ndo_do_ioctl)(struct net_device___38 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___38 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___38 *, int);
	int (*ndo_neigh_setup)(struct net_device___38 *, struct neigh_parms___25 *);
	void (*ndo_tx_timeout)(struct net_device___38 *);
	void (*ndo_get_stats64)(struct net_device___38 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___38 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___38 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___38 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___38 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___38 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___38 *);
	int (*ndo_netpoll_setup)(struct net_device___38 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___38 *);
	int (*ndo_set_vf_mac)(struct net_device___38 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___38 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___38 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___38 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___38 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___38 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___38 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___38 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___38 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___38 *, int, struct sk_buff___38 *);
	int (*ndo_set_vf_guid)(struct net_device___38 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___38 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___38 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___38 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___38 *, const struct sk_buff___38 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___38 *, struct net_device___38 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___38 *, struct net_device___38 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___38 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___38 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___38 *, struct neighbour___25 *);
	void (*ndo_neigh_destroy)(struct net_device___38 *, struct neighbour___25 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___38 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___38 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide59;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___38 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___38 *, struct netlink_callback___36 *, struct net_device___38 *, struct net_device___38 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___38 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___38 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide60;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___38 *, u32, u32, struct net_device___38 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___38 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___38 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___38 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___38 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___38 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___38 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___38 *, struct net_device___38 *);
	void (*ndo_dfwd_del_station)(struct net_device___38 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___38 *);
	int (*ndo_set_tx_maxrate)(struct net_device___38 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___38 *);
	int (*ndo_change_proto_down)(struct net_device___38 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___38 *, struct sk_buff___38 *);
	void (*ndo_set_rx_headroom)(struct net_device___38 *, int);
	int (*ndo_bpf)(struct net_device___38 *, struct netdev_bpf___36 *);
	int (*ndo_xdp_xmit)(struct net_device___38 *, int, struct xdp_frame___36 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___38 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___38 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide61;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___25 {
	possible_net_t___37 net;
	struct net_device___38 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___25 *);
	void (*neigh_cleanup)(struct neighbour___25 *);
	struct neigh_table___25 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___25 {
	u32 (*l3mdev_fib_table)(const struct net_device___38 *);
	struct sk_buff___38 * (*l3mdev_l3_rcv)(struct net_device___38 *, struct sk_buff___38 *, u16);
	struct sk_buff___38 * (*l3mdev_l3_out)(struct net_device___38 *, struct sock___26 *, struct sk_buff___38 *, u16);
	struct dst_entry___25 * (*l3mdev_link_scope_lookup)(const struct net_device___38 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct ndisc_ops___15 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___38 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___38 *, struct neighbour___25 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___38 *, u8, struct neighbour___25 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___38 *, struct sk_buff___38 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___47 *, struct net_device___38 *, const struct prefix_info *, struct inet6_dev___15 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___15;

struct inet6_dev___15 {
	struct net_device___38 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___15 *mc_list;
	struct ifmcaddr6___15 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	u8 rndid[8];
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___25 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
};

struct tcf_proto___35;

struct mini_Qdisc___35 {
	struct tcf_proto___35 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___35 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___38 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___47 *, struct net_device___38 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___38 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___38 *, struct list_head *);
	size_t (*get_size)(const struct net_device___38 *);
	int (*fill_info)(struct sk_buff___38 *, const struct net_device___38 *);
	size_t (*get_xstats_size)(const struct net_device___38 *);
	int (*fill_xstats)(struct sk_buff___38 *, const struct net_device___38 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___38 *, struct net_device___38 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___38 *, const struct net_device___38 *);
	int (*fill_slave_info)(struct sk_buff___38 *, const struct net_device___38 *, const struct net_device___38 *);
	struct net___47 * (*get_link_net)(const struct net_device___38 *);
	size_t (*get_linkxstats_size)(const struct net_device___38 *, int);
	int (*fill_linkxstats)(struct sk_buff___38 *, const struct net_device___38 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___36 {
	struct list_head poll_list;
	struct sk_buff_head___36 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___36 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___35 *output_queue;
	struct Qdisc___35 **output_queue_tailp;
	struct sk_buff___38 *completion_queue;
	struct sk_buff_head___36 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___36 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___36 input_pkt_queue;
	struct napi_struct___36 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct mem_cgroup_reclaim_iter___114 {
	struct mem_cgroup___114 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___114 {
	struct lruvec___277 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___114 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___114 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct kernel_param_ops___221 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___221 *);
	int (*get)(char *, const struct kernel_param___221 *);
	void (*free)(void *);
};

struct kparam_array___221;

struct kernel_param___221 {
	const char *name;
	struct module___224 *mod;
	const struct kernel_param_ops___221 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___221 *arr;
	};
};

struct kparam_array___221 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___221 *ops;
	void *elem;
};

struct module_attribute___221 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___221 *, struct module_kobject___221 *, char *);
	ssize_t (*store)(struct module_attribute___221 *, struct module_kobject___221 *, const char *, size_t);
	void (*setup)(struct module___224 *, const char *);
	int (*test)(struct module___224 *);
	void (*free)(struct module___224 *);
};

struct gnet_dump___35 {
	spinlock_t *lock;
	struct sk_buff___38 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___35;

struct Qdisc_ops___35 {
	struct Qdisc_ops___35 *next;
	const struct Qdisc_class_ops___35 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___38 *, struct Qdisc___35 *, struct sk_buff___38 **);
	struct sk_buff___38 * (*dequeue)(struct Qdisc___35 *);
	struct sk_buff___38 * (*peek)(struct Qdisc___35 *);
	int (*init)(struct Qdisc___35 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___35 *);
	void (*destroy)(struct Qdisc___35 *);
	int (*change)(struct Qdisc___35 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___35 *);
	int (*change_tx_queue_len)(struct Qdisc___35 *, unsigned int);
	int (*dump)(struct Qdisc___35 *, struct sk_buff___38 *);
	int (*dump_stats)(struct Qdisc___35 *, struct gnet_dump___35 *);
	void (*ingress_block_set)(struct Qdisc___35 *, u32);
	void (*egress_block_set)(struct Qdisc___35 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___35 *);
	u32 (*egress_block_get)(struct Qdisc___35 *);
	struct module___224 *owner;
};

struct tcf_block___35;

struct Qdisc_class_ops___35 {
	unsigned int flags;
	struct netdev_queue___36 * (*select_queue)(struct Qdisc___35 *, struct tcmsg *);
	int (*graft)(struct Qdisc___35 *, long unsigned int, struct Qdisc___35 *, struct Qdisc___35 **, struct netlink_ext_ack *);
	struct Qdisc___35 * (*leaf)(struct Qdisc___35 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___35 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___35 *, u32);
	int (*change)(struct Qdisc___35 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___35 *, long unsigned int);
	void (*walk)(struct Qdisc___35 *, struct qdisc_walker *);
	struct tcf_block___35 * (*tcf_block)(struct Qdisc___35 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___35 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___35 *, long unsigned int);
	int (*dump)(struct Qdisc___35 *, long unsigned int, struct sk_buff___38 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___35 *, long unsigned int, struct gnet_dump___35 *);
};

struct tcf_chain___35;

struct tcf_block___35 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___47 *net;
	struct Qdisc___35 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___35 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___35;

struct tcf_proto_ops___35;

struct tcf_proto___35 {
	struct tcf_proto___35 *next;
	void *root;
	int (*classify)(struct sk_buff___38 *, const struct tcf_proto___35 *, struct tcf_result___35 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___35 *ops;
	struct tcf_chain___35 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___35 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___35 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___35 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___38 *, const struct tcf_proto___35 *, struct tcf_result___35 *);
	int (*init)(struct tcf_proto___35 *);
	void (*destroy)(struct tcf_proto___35 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___35 *, u32);
	void (*put)(struct tcf_proto___35 *, void *);
	int (*change)(struct net___47 *, struct sk_buff___38 *, struct tcf_proto___35 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___35 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___35 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___35 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___47 *, struct tcf_chain___35 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___47 *, struct tcf_proto___35 *, void *, struct sk_buff___38 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___38 *, struct net___47 *, void *);
	struct module___224 *owner;
	int flags;
};

struct tcf_chain___35 {
	struct mutex filter_chain_lock;
	struct tcf_proto___35 *filter_chain;
	struct list_head list;
	struct tcf_block___35 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___35 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___25 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___35 *prog;
};

struct bpf_redirect_info___35 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___205 *map;
	struct bpf_map___205 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___25;

struct neigh_hash_table___25;

struct neigh_table___25 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___38 *, __u32 *);
	bool (*key_eq)(const struct neighbour___25 *, const void *);
	int (*constructor)(struct neighbour___25 *);
	int (*pconstructor)(struct pneigh_entry___25 *);
	void (*pdestructor)(struct pneigh_entry___25 *);
	void (*proxy_redo)(struct sk_buff___38 *);
	char *id;
	struct neigh_parms___25 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___36 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___25 *nht;
	struct pneigh_entry___25 **phash_buckets;
};

struct neigh_ops___25 {
	int family;
	void (*solicit)(struct neighbour___25 *, struct sk_buff___38 *);
	void (*error_report)(struct neighbour___25 *, struct sk_buff___38 *);
	int (*output)(struct neighbour___25 *, struct sk_buff___38 *);
	int (*connected_output)(struct neighbour___25 *, struct sk_buff___38 *);
};

struct pneigh_entry___25 {
	struct pneigh_entry___25 *next;
	possible_net_t___37 net;
	struct net_device___38 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___25 {
	struct neighbour___25 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___25 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___25 *ctarget;
	struct net___47 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___25 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___25 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___17;

struct timewait_sock_ops___15;

struct proto___25 {
	void (*close)(struct sock___26 *, long int);
	int (*pre_connect)(struct sock___26 *, struct sockaddr *, int);
	int (*connect)(struct sock___26 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___26 *, int);
	struct sock___26 * (*accept)(struct sock___26 *, int, int *, bool);
	int (*ioctl)(struct sock___26 *, int, long unsigned int);
	int (*init)(struct sock___26 *);
	void (*destroy)(struct sock___26 *);
	void (*shutdown)(struct sock___26 *, int);
	int (*setsockopt)(struct sock___26 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___26 *, int, int, char *, int *);
	void (*keepalive)(struct sock___26 *, int);
	int (*sendmsg)(struct sock___26 *, struct msghdr___28 *, size_t);
	int (*recvmsg)(struct sock___26 *, struct msghdr___28 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___26 *, struct page___278 *, int, size_t, int);
	int (*bind)(struct sock___26 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___26 *, struct sk_buff___38 *);
	void (*release_cb)(struct sock___26 *);
	int (*hash)(struct sock___26 *);
	void (*unhash)(struct sock___26 *);
	void (*rehash)(struct sock___26 *);
	int (*get_port)(struct sock___26 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___26 *);
	bool (*stream_memory_read)(const struct sock___26 *);
	void (*enter_memory_pressure)(struct sock___26 *);
	void (*leave_memory_pressure)(struct sock___26 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___17 *rsk_prot;
	struct timewait_sock_ops___15 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___224 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___26 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct request_sock___18;

struct request_sock_ops___17 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___26 *, struct request_sock___18 *);
	void (*send_ack)(const struct sock___26 *, struct sk_buff___38 *, struct request_sock___18 *);
	void (*send_reset)(const struct sock___26 *, struct sk_buff___38 *);
	void (*destructor)(struct request_sock___18 *);
	void (*syn_ack_timeout)(const struct request_sock___18 *);
};

struct timewait_sock_ops___15 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___26 *, struct sock___26 *, void *);
	void (*twsk_destructor)(struct sock___26 *);
};

struct request_sock___18 {
	struct sock_common___25 __req_common;
	struct request_sock___18 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___17 *rsk_ops;
	struct sock___26 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___15 {
	struct in6_addr mca_addr;
	struct inet6_dev___15 *idev;
	struct ifmcaddr6___15 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ip6_ra_chain___15 {
	struct ip6_ra_chain___15 *next;
	struct sock___26 *sk;
	int sel;
	void (*destructor)(struct sock___26 *);
};

struct rdma_cgroup___2 {
	struct cgroup_subsys_state___204 css;
	struct list_head rpools;
};

enum rdma_restrack_type {
	RDMA_RESTRACK_PD = 0,
	RDMA_RESTRACK_CQ = 1,
	RDMA_RESTRACK_QP = 2,
	RDMA_RESTRACK_CM_ID = 3,
	RDMA_RESTRACK_MR = 4,
	RDMA_RESTRACK_CTX = 5,
	RDMA_RESTRACK_MAX = 6,
};

struct rdma_restrack_entry;

struct rdma_restrack_root {
	struct rw_semaphore___278 rwsem;
	struct hlist_head hash[256];
	int (*fill_res_entry)(struct sk_buff___38 *, struct rdma_restrack_entry *);
};

struct rdma_restrack_entry {
	bool valid;
	struct kref kref;
	struct completion comp;
	struct task_struct___278 *task;
	const char *kern_name;
	struct hlist_node node;
	enum rdma_restrack_type type;
	bool user;
};

enum rdma_driver_id {
	RDMA_DRIVER_UNKNOWN = 0,
	RDMA_DRIVER_MLX5 = 1,
	RDMA_DRIVER_MLX4 = 2,
	RDMA_DRIVER_CXGB3 = 3,
	RDMA_DRIVER_CXGB4 = 4,
	RDMA_DRIVER_MTHCA = 5,
	RDMA_DRIVER_BNXT_RE = 6,
	RDMA_DRIVER_OCRDMA = 7,
	RDMA_DRIVER_NES = 8,
	RDMA_DRIVER_I40IW = 9,
	RDMA_DRIVER_VMW_PVRDMA = 10,
	RDMA_DRIVER_QEDR = 11,
	RDMA_DRIVER_HNS = 12,
	RDMA_DRIVER_USNIC = 13,
	RDMA_DRIVER_RXE = 14,
	RDMA_DRIVER_HFI1 = 15,
	RDMA_DRIVER_QIB = 16,
};

enum ib_uverbs_flow_action_esp_keymat {
	IB_UVERBS_FLOW_ACTION_ESP_KEYMAT_AES_GCM = 0,
};

struct ib_uverbs_flow_action_esp_keymat_aes_gcm {
	__u64 iv;
	__u32 iv_algo;
	__u32 salt;
	__u32 icv_len;
	__u32 key_len;
	__u32 aes_key[8];
};

enum ib_uverbs_flow_action_esp_replay {
	IB_UVERBS_FLOW_ACTION_ESP_REPLAY_NONE = 0,
	IB_UVERBS_FLOW_ACTION_ESP_REPLAY_BMP = 1,
};

struct ib_uverbs_flow_action_esp_replay_bmp {
	__u32 size;
};

enum ib_uverbs_advise_mr_advice {
	IB_UVERBS_ADVISE_MR_ADVICE_PREFETCH = 0,
	IB_UVERBS_ADVISE_MR_ADVICE_PREFETCH_WRITE = 1,
};

enum ib_gid_type {
	IB_GID_TYPE_IB = 0,
	IB_GID_TYPE_ROCE = 0,
	IB_GID_TYPE_ROCE_UDP_ENCAP = 1,
	IB_GID_TYPE_SIZE = 2,
};

struct ib_device;

struct ib_gid_attr {
	struct net_device___38 *ndev;
	struct ib_device *device;
	union ib_gid gid;
	enum ib_gid_type gid_type;
	u16 index;
	u8 port_num;
};

enum ib_cq_notify_flags {
	IB_CQ_SOLICITED = 1,
	IB_CQ_NEXT_COMP = 2,
	IB_CQ_SOLICITED_MASK = 3,
	IB_CQ_REPORT_MISSED_EVENTS = 4,
};

struct ib_mad_hdr;

enum rdma_link_layer {
	IB_LINK_LAYER_UNSPECIFIED = 0,
	IB_LINK_LAYER_INFINIBAND = 1,
	IB_LINK_LAYER_ETHERNET = 2,
};

enum rdma_netdev_t {
	RDMA_NETDEV_OPA_VNIC = 0,
	RDMA_NETDEV_IPOIB = 1,
};

enum ib_srq_attr_mask {
	IB_SRQ_MAX_WR = 1,
	IB_SRQ_LIMIT = 2,
};

enum ib_mr_type {
	IB_MR_TYPE_MEM_REG = 0,
	IB_MR_TYPE_SIGNATURE = 1,
	IB_MR_TYPE_SG_GAPS = 2,
};

struct uverbs_attr_bundle;

enum ib_mw_type {
	IB_MW_TYPE_1 = 1,
	IB_MW_TYPE_2 = 2,
};

struct ib_qp;

struct ib_send_wr;

struct ib_recv_wr;

struct ib_cq;

struct ib_wc;

struct ib_srq;

struct ib_grh;

struct ib_device_attr;

struct ib_udata;

struct ib_device_modify;

struct ib_port_attr;

struct ib_port_modify;

struct ib_port_immutable;

struct rdma_netdev_alloc_params;

struct ib_ucontext;

struct ib_pd;

struct ib_ah;

struct rdma_ah_attr;

struct ib_srq_init_attr;

struct ib_srq_attr;

struct ib_qp_init_attr;

struct ib_qp_attr;

struct ib_cq_init_attr;

struct ib_mr;

struct ib_sge;

struct ib_mr_status;

struct ib_mw;

struct ib_fmr;

struct ib_fmr_attr;

struct ib_xrcd;

struct ib_flow;

struct ib_flow_attr;

struct ib_flow_action;

struct ib_flow_action_attrs_esp;

struct ib_wq;

struct ib_wq_init_attr;

struct ib_wq_attr;

struct ib_rwq_ind_table;

struct ib_rwq_ind_table_init_attr;

struct ib_dm;

struct ib_dm_alloc_attr;

struct ib_dm_mr_attr;

struct ib_counters;

struct ib_counters_read_attr;

struct rdma_hw_stats;

struct ib_device_ops {
	int (*post_send)(struct ib_qp *, const struct ib_send_wr *, const struct ib_send_wr **);
	int (*post_recv)(struct ib_qp *, const struct ib_recv_wr *, const struct ib_recv_wr **);
	void (*drain_rq)(struct ib_qp *);
	void (*drain_sq)(struct ib_qp *);
	int (*poll_cq)(struct ib_cq *, int, struct ib_wc *);
	int (*peek_cq)(struct ib_cq *, int);
	int (*req_notify_cq)(struct ib_cq *, enum ib_cq_notify_flags);
	int (*req_ncomp_notif)(struct ib_cq *, int);
	int (*post_srq_recv)(struct ib_srq *, const struct ib_recv_wr *, const struct ib_recv_wr **);
	int (*process_mad)(struct ib_device *, int, u8, const struct ib_wc *, const struct ib_grh *, const struct ib_mad_hdr *, size_t, struct ib_mad_hdr *, size_t *, u16 *);
	int (*query_device)(struct ib_device *, struct ib_device_attr *, struct ib_udata *);
	int (*modify_device)(struct ib_device *, int, struct ib_device_modify *);
	void (*get_dev_fw_str)(struct ib_device *, char *);
	const struct cpumask * (*get_vector_affinity)(struct ib_device *, int);
	int (*query_port)(struct ib_device *, u8, struct ib_port_attr *);
	int (*modify_port)(struct ib_device *, u8, int, struct ib_port_modify *);
	int (*get_port_immutable)(struct ib_device *, u8, struct ib_port_immutable *);
	enum rdma_link_layer (*get_link_layer)(struct ib_device *, u8);
	struct net_device___38 * (*get_netdev)(struct ib_device *, u8);
	struct net_device___38 * (*alloc_rdma_netdev)(struct ib_device *, u8, enum rdma_netdev_t, const char *, unsigned char, void (*)(struct net_device___38 *));
	int (*rdma_netdev_get_params)(struct ib_device *, u8, enum rdma_netdev_t, struct rdma_netdev_alloc_params *);
	int (*query_gid)(struct ib_device *, u8, int, union ib_gid *);
	int (*add_gid)(const struct ib_gid_attr *, void **);
	int (*del_gid)(const struct ib_gid_attr *, void **);
	int (*query_pkey)(struct ib_device *, u8, u16, u16 *);
	struct ib_ucontext * (*alloc_ucontext)(struct ib_device *, struct ib_udata *);
	int (*dealloc_ucontext)(struct ib_ucontext *);
	int (*mmap)(struct ib_ucontext *, struct vm_area_struct___278 *);
	void (*disassociate_ucontext)(struct ib_ucontext *);
	struct ib_pd * (*alloc_pd)(struct ib_device *, struct ib_ucontext *, struct ib_udata *);
	int (*dealloc_pd)(struct ib_pd *);
	struct ib_ah * (*create_ah)(struct ib_pd *, struct rdma_ah_attr *, u32, struct ib_udata *);
	int (*modify_ah)(struct ib_ah *, struct rdma_ah_attr *);
	int (*query_ah)(struct ib_ah *, struct rdma_ah_attr *);
	int (*destroy_ah)(struct ib_ah *, u32);
	struct ib_srq * (*create_srq)(struct ib_pd *, struct ib_srq_init_attr *, struct ib_udata *);
	int (*modify_srq)(struct ib_srq *, struct ib_srq_attr *, enum ib_srq_attr_mask, struct ib_udata *);
	int (*query_srq)(struct ib_srq *, struct ib_srq_attr *);
	int (*destroy_srq)(struct ib_srq *);
	struct ib_qp * (*create_qp)(struct ib_pd *, struct ib_qp_init_attr *, struct ib_udata *);
	int (*modify_qp)(struct ib_qp *, struct ib_qp_attr *, int, struct ib_udata *);
	int (*query_qp)(struct ib_qp *, struct ib_qp_attr *, int, struct ib_qp_init_attr *);
	int (*destroy_qp)(struct ib_qp *);
	struct ib_cq * (*create_cq)(struct ib_device *, const struct ib_cq_init_attr *, struct ib_ucontext *, struct ib_udata *);
	int (*modify_cq)(struct ib_cq *, u16, u16);
	int (*destroy_cq)(struct ib_cq *);
	int (*resize_cq)(struct ib_cq *, int, struct ib_udata *);
	struct ib_mr * (*get_dma_mr)(struct ib_pd *, int);
	struct ib_mr * (*reg_user_mr)(struct ib_pd *, u64, u64, u64, int, struct ib_udata *);
	int (*rereg_user_mr)(struct ib_mr *, int, u64, u64, u64, int, struct ib_pd *, struct ib_udata *);
	int (*dereg_mr)(struct ib_mr *);
	struct ib_mr * (*alloc_mr)(struct ib_pd *, enum ib_mr_type, u32);
	int (*advise_mr)(struct ib_pd *, enum ib_uverbs_advise_mr_advice, u32, struct ib_sge *, u32, struct uverbs_attr_bundle *);
	int (*map_mr_sg)(struct ib_mr *, struct scatterlist *, int, unsigned int *);
	int (*check_mr_status)(struct ib_mr *, u32, struct ib_mr_status *);
	struct ib_mw * (*alloc_mw)(struct ib_pd *, enum ib_mw_type, struct ib_udata *);
	int (*dealloc_mw)(struct ib_mw *);
	struct ib_fmr * (*alloc_fmr)(struct ib_pd *, int, struct ib_fmr_attr *);
	int (*map_phys_fmr)(struct ib_fmr *, u64 *, int, u64);
	int (*unmap_fmr)(struct list_head *);
	int (*dealloc_fmr)(struct ib_fmr *);
	int (*attach_mcast)(struct ib_qp *, union ib_gid *, u16);
	int (*detach_mcast)(struct ib_qp *, union ib_gid *, u16);
	struct ib_xrcd * (*alloc_xrcd)(struct ib_device *, struct ib_ucontext *, struct ib_udata *);
	int (*dealloc_xrcd)(struct ib_xrcd *);
	struct ib_flow * (*create_flow)(struct ib_qp *, struct ib_flow_attr *, int, struct ib_udata *);
	int (*destroy_flow)(struct ib_flow *);
	struct ib_flow_action * (*create_flow_action_esp)(struct ib_device *, const struct ib_flow_action_attrs_esp *, struct uverbs_attr_bundle *);
	int (*destroy_flow_action)(struct ib_flow_action *);
	int (*modify_flow_action_esp)(struct ib_flow_action *, const struct ib_flow_action_attrs_esp *, struct uverbs_attr_bundle *);
	int (*set_vf_link_state)(struct ib_device *, int, u8, int);
	int (*get_vf_config)(struct ib_device *, int, u8, struct ifla_vf_info *);
	int (*get_vf_stats)(struct ib_device *, int, u8, struct ifla_vf_stats *);
	int (*set_vf_guid)(struct ib_device *, int, u8, u64, int);
	struct ib_wq * (*create_wq)(struct ib_pd *, struct ib_wq_init_attr *, struct ib_udata *);
	int (*destroy_wq)(struct ib_wq *);
	int (*modify_wq)(struct ib_wq *, struct ib_wq_attr *, u32, struct ib_udata *);
	struct ib_rwq_ind_table * (*create_rwq_ind_table)(struct ib_device *, struct ib_rwq_ind_table_init_attr *, struct ib_udata *);
	int (*destroy_rwq_ind_table)(struct ib_rwq_ind_table *);
	struct ib_dm * (*alloc_dm)(struct ib_device *, struct ib_ucontext *, struct ib_dm_alloc_attr *, struct uverbs_attr_bundle *);
	int (*dealloc_dm)(struct ib_dm *);
	struct ib_mr * (*reg_dm_mr)(struct ib_pd *, struct ib_dm *, struct ib_dm_mr_attr *, struct uverbs_attr_bundle *);
	struct ib_counters * (*create_counters)(struct ib_device *, struct uverbs_attr_bundle *);
	int (*destroy_counters)(struct ib_counters *);
	int (*read_counters)(struct ib_counters *, struct ib_counters_read_attr *, struct uverbs_attr_bundle *);
	struct rdma_hw_stats * (*alloc_hw_stats)(struct ib_device *, u8);
	int (*get_hw_stats)(struct ib_device *, struct rdma_hw_stats *, u8, int);
};

struct ib_event;

struct ib_event_handler {
	struct ib_device *device;
	void (*handler)(struct ib_event_handler *, struct ib_event *);
	struct list_head list;
};

struct ib_port_cache;

struct ib_cache {
	rwlock_t lock;
	struct ib_event_handler event_handler;
	struct ib_port_cache *ports;
};

struct iw_cm_verbs;

enum ib_atomic_cap {
	IB_ATOMIC_NONE = 0,
	IB_ATOMIC_HCA = 1,
	IB_ATOMIC_GLOB = 2,
};

struct ib_odp_caps {
	uint64_t general_caps;
	struct {
		uint32_t rc_odp_caps;
		uint32_t uc_odp_caps;
		uint32_t ud_odp_caps;
	} per_transport_caps;
};

struct ib_rss_caps {
	u32 supported_qpts;
	u32 max_rwq_indirection_tables;
	u32 max_rwq_indirection_table_size;
};

struct ib_tm_caps {
	u32 max_rndv_hdr_size;
	u32 max_num_tags;
	u32 flags;
	u32 max_ops;
	u32 max_sge;
};

struct ib_cq_caps {
	u16 max_cq_moderation_count;
	u16 max_cq_moderation_period;
};

struct ib_device_attr {
	u64 fw_ver;
	__be64 sys_image_guid;
	u64 max_mr_size;
	u64 page_size_cap;
	u32 vendor_id;
	u32 vendor_part_id;
	u32 hw_ver;
	int max_qp;
	int max_qp_wr;
	u64 device_cap_flags;
	int max_send_sge;
	int max_recv_sge;
	int max_sge_rd;
	int max_cq;
	int max_cqe;
	int max_mr;
	int max_pd;
	int max_qp_rd_atom;
	int max_ee_rd_atom;
	int max_res_rd_atom;
	int max_qp_init_rd_atom;
	int max_ee_init_rd_atom;
	enum ib_atomic_cap atomic_cap;
	enum ib_atomic_cap masked_atomic_cap;
	int max_ee;
	int max_rdd;
	int max_mw;
	int max_raw_ipv6_qp;
	int max_raw_ethy_qp;
	int max_mcast_grp;
	int max_mcast_qp_attach;
	int max_total_mcast_qp_attach;
	int max_ah;
	int max_fmr;
	int max_map_per_fmr;
	int max_srq;
	int max_srq_wr;
	int max_srq_sge;
	unsigned int max_fast_reg_page_list_len;
	u16 max_pkeys;
	u8 local_ca_ack_delay;
	int sig_prot_cap;
	int sig_guard_cap;
	struct ib_odp_caps odp_caps;
	uint64_t timestamp_mask;
	uint64_t hca_core_clock;
	struct ib_rss_caps rss_caps;
	u32 max_wq_type_rq;
	u32 raw_packet_caps;
	struct ib_tm_caps tm_caps;
	struct ib_cq_caps cq_caps;
	u64 max_dm_size;
};

struct uapi_definition;

struct ib_port_pkey_list;

struct ib_device {
	struct device___240 *dma_device;
	struct ib_device_ops ops;
	char name[64];
	struct list_head event_handler_list;
	spinlock_t event_handler_lock;
	rwlock_t client_data_lock;
	struct list_head core_list;
	struct list_head client_data_list;
	struct ib_cache cache;
	struct ib_port_immutable *port_immutable;
	int num_comp_vectors;
	struct ib_port_pkey_list *port_pkey_list;
	struct iw_cm_verbs *iwcm;
	struct module___224 *owner;
	struct device___240 dev;
	const struct attribute_group___242 *groups[3];
	struct kobject___265 *ports_kobj;
	struct list_head port_list;
	enum {
		IB_DEV_UNINITIALIZED = 0,
		IB_DEV_REGISTERED = 1,
		IB_DEV_UNREGISTERED = 2,
	} reg_state;
	int uverbs_abi_ver;
	u64 uverbs_cmd_mask;
	u64 uverbs_ex_cmd_mask;
	char node_desc[64];
	__be64 node_guid;
	u32 local_dma_lkey;
	u16 is_switch: 1;
	u8 node_type;
	u8 phys_port_cnt;
	struct ib_device_attr attrs;
	struct attribute_group___242 *hw_stats_ag;
	struct rdma_hw_stats *hw_stats;
	struct rdmacg_device cg_device;
	u32 index;
	struct rdma_restrack_root res;
	const struct uapi_definition *driver_def;
	enum rdma_driver_id driver_id;
	refcount_t refcount;
	struct completion unreg_completion;
};

struct ib_cq_init_attr {
	unsigned int cqe;
	int comp_vector;
	u32 flags;
};

struct ib_dm_mr_attr {
	u64 length;
	u64 offset;
	u32 access_flags;
};

struct ib_dm_alloc_attr {
	u64 length;
	u32 alignment;
	u32 flags;
};

enum ib_mtu {
	IB_MTU_256 = 1,
	IB_MTU_512 = 2,
	IB_MTU_1024 = 3,
	IB_MTU_2048 = 4,
	IB_MTU_4096 = 5,
};

enum ib_port_state {
	IB_PORT_NOP = 0,
	IB_PORT_DOWN = 1,
	IB_PORT_INIT = 2,
	IB_PORT_ARMED = 3,
	IB_PORT_ACTIVE = 4,
	IB_PORT_ACTIVE_DEFER = 5,
};

struct rdma_hw_stats {
	struct mutex lock;
	long unsigned int timestamp;
	long unsigned int lifespan;
	const char * const *names;
	int num_counters;
	u64 value[0];
};

struct ib_port_attr {
	u64 subnet_prefix;
	enum ib_port_state state;
	enum ib_mtu max_mtu;
	enum ib_mtu active_mtu;
	int gid_tbl_len;
	unsigned int ip_gids: 1;
	u32 port_cap_flags;
	u32 max_msg_sz;
	u32 bad_pkey_cntr;
	u32 qkey_viol_cntr;
	u16 pkey_tbl_len;
	u32 sm_lid;
	u32 lid;
	u8 lmc;
	u8 max_vl_num;
	u8 sm_sl;
	u8 subnet_timeout;
	u8 init_type_reply;
	u8 active_width;
	u8 active_speed;
	u8 phys_state;
	u16 port_cap_flags2;
};

struct ib_device_modify {
	u64 sys_image_guid;
	char node_desc[64];
};

struct ib_port_modify {
	u32 set_port_cap_mask;
	u32 clr_port_cap_mask;
	u8 init_type;
};

enum ib_event_type {
	IB_EVENT_CQ_ERR = 0,
	IB_EVENT_QP_FATAL = 1,
	IB_EVENT_QP_REQ_ERR = 2,
	IB_EVENT_QP_ACCESS_ERR = 3,
	IB_EVENT_COMM_EST = 4,
	IB_EVENT_SQ_DRAINED = 5,
	IB_EVENT_PATH_MIG = 6,
	IB_EVENT_PATH_MIG_ERR = 7,
	IB_EVENT_DEVICE_FATAL = 8,
	IB_EVENT_PORT_ACTIVE = 9,
	IB_EVENT_PORT_ERR = 10,
	IB_EVENT_LID_CHANGE = 11,
	IB_EVENT_PKEY_CHANGE = 12,
	IB_EVENT_SM_CHANGE = 13,
	IB_EVENT_SRQ_ERR = 14,
	IB_EVENT_SRQ_LIMIT_REACHED = 15,
	IB_EVENT_QP_LAST_WQE_REACHED = 16,
	IB_EVENT_CLIENT_REREGISTER = 17,
	IB_EVENT_GID_CHANGE = 18,
	IB_EVENT_WQ_FATAL = 19,
};

typedef void (*ib_comp_handler)(struct ib_cq *, void *);

enum ib_poll_context {
	IB_POLL_DIRECT = 0,
	IB_POLL_SOFTIRQ = 1,
	IB_POLL_WORKQUEUE = 2,
	IB_POLL_UNBOUND_WORKQUEUE = 3,
};

struct ib_uobject;

struct ib_cq {
	struct ib_device *device;
	struct ib_uobject *uobject;
	ib_comp_handler comp_handler;
	void (*event_handler)(struct ib_event *, void *);
	void *cq_context;
	int cqe;
	atomic_t usecnt;
	enum ib_poll_context poll_ctx;
	struct ib_wc *wc;
	union {
		struct irq_poll iop;
		struct work_struct work;
	};
	struct workqueue_struct *comp_wq;
	struct rdma_restrack_entry res;
};

enum ib_qp_type {
	IB_QPT_SMI = 0,
	IB_QPT_GSI = 1,
	IB_QPT_RC = 2,
	IB_QPT_UC = 3,
	IB_QPT_UD = 4,
	IB_QPT_RAW_IPV6 = 5,
	IB_QPT_RAW_ETHERTYPE = 6,
	IB_QPT_RAW_PACKET = 8,
	IB_QPT_XRC_INI = 9,
	IB_QPT_XRC_TGT = 10,
	IB_QPT_MAX = 11,
	IB_QPT_DRIVER = 255,
	IB_QPT_RESERVED1 = 4096,
	IB_QPT_RESERVED2 = 4097,
	IB_QPT_RESERVED3 = 4098,
	IB_QPT_RESERVED4 = 4099,
	IB_QPT_RESERVED5 = 4100,
	IB_QPT_RESERVED6 = 4101,
	IB_QPT_RESERVED7 = 4102,
	IB_QPT_RESERVED8 = 4103,
	IB_QPT_RESERVED9 = 4104,
	IB_QPT_RESERVED10 = 4105,
};

struct ib_qp_security;

struct ib_qp {
	struct ib_device *device;
	struct ib_pd *pd;
	struct ib_cq *send_cq;
	struct ib_cq *recv_cq;
	spinlock_t mr_lock;
	int mrs_used;
	struct list_head rdma_mrs;
	struct list_head sig_mrs;
	struct ib_srq *srq;
	struct ib_xrcd *xrcd;
	struct list_head xrcd_list;
	atomic_t usecnt;
	struct list_head open_list;
	struct ib_qp *real_qp;
	struct ib_uobject *uobject;
	void (*event_handler)(struct ib_event *, void *);
	void *qp_context;
	const struct ib_gid_attr *av_sgid_attr;
	const struct ib_gid_attr *alt_path_sgid_attr;
	u32 qp_num;
	u32 max_write_sge;
	u32 max_read_sge;
	enum ib_qp_type qp_type;
	struct ib_rwq_ind_table *rwq_ind_tbl;
	struct ib_qp_security *qp_sec;
	u8 port;
	struct rdma_restrack_entry res;
};

enum ib_srq_type {
	IB_SRQT_BASIC = 0,
	IB_SRQT_XRC = 1,
	IB_SRQT_TM = 2,
};

struct ib_srq {
	struct ib_device *device;
	struct ib_pd *pd;
	struct ib_uobject *uobject;
	void (*event_handler)(struct ib_event *, void *);
	void *srq_context;
	enum ib_srq_type srq_type;
	atomic_t usecnt;
	struct {
		struct ib_cq *cq;
		union {
			struct {
				struct ib_xrcd *xrcd;
				u32 srq_num;
			} xrc;
		};
	} ext;
};

enum ib_wq_state {
	IB_WQS_RESET = 0,
	IB_WQS_RDY = 1,
	IB_WQS_ERR = 2,
};

enum ib_wq_type {
	IB_WQT_RQ = 0,
};

struct ib_wq {
	struct ib_device *device;
	struct ib_uobject *uobject;
	void *wq_context;
	void (*event_handler)(struct ib_event *, void *);
	struct ib_pd *pd;
	struct ib_cq *cq;
	u32 wq_num;
	enum ib_wq_state state;
	enum ib_wq_type wq_type;
	atomic_t usecnt;
};

struct ib_event {
	struct ib_device *device;
	union {
		struct ib_cq *cq;
		struct ib_qp *qp;
		struct ib_srq *srq;
		struct ib_wq *wq;
		u8 port_num;
	} element;
	enum ib_event_type event;
};

struct ib_global_route {
	const struct ib_gid_attr *sgid_attr;
	union ib_gid dgid;
	u32 flow_label;
	u8 sgid_index;
	u8 hop_limit;
	u8 traffic_class;
};

struct ib_grh {
	__be32 version_tclass_flow;
	__be16 paylen;
	u8 next_hdr;
	u8 hop_limit;
	union ib_gid sgid;
	union ib_gid dgid;
};

enum ib_sig_err_type {
	IB_SIG_BAD_GUARD = 0,
	IB_SIG_BAD_REFTAG = 1,
	IB_SIG_BAD_APPTAG = 2,
};

struct ib_sig_err {
	enum ib_sig_err_type err_type;
	u32 expected;
	u32 actual;
	u64 sig_err_offset;
	u32 key;
};

struct ib_mr_status {
	u32 fail_status;
	struct ib_sig_err sig_err;
};

enum rdma_ah_attr_type {
	RDMA_AH_ATTR_TYPE_UNDEFINED = 0,
	RDMA_AH_ATTR_TYPE_IB = 1,
	RDMA_AH_ATTR_TYPE_ROCE = 2,
	RDMA_AH_ATTR_TYPE_OPA = 3,
};

struct ib_ah_attr {
	u16 dlid;
	u8 src_path_bits;
};

struct roce_ah_attr {
	u8 dmac[6];
};

struct opa_ah_attr {
	u32 dlid;
	u8 src_path_bits;
	bool make_grd;
};

struct rdma_ah_attr {
	struct ib_global_route grh;
	u8 sl;
	u8 static_rate;
	u8 port_num;
	u8 ah_flags;
	enum rdma_ah_attr_type type;
	union {
		struct ib_ah_attr ib;
		struct roce_ah_attr roce;
		struct opa_ah_attr opa;
	};
};

enum ib_wc_status {
	IB_WC_SUCCESS = 0,
	IB_WC_LOC_LEN_ERR = 1,
	IB_WC_LOC_QP_OP_ERR = 2,
	IB_WC_LOC_EEC_OP_ERR = 3,
	IB_WC_LOC_PROT_ERR = 4,
	IB_WC_WR_FLUSH_ERR = 5,
	IB_WC_MW_BIND_ERR = 6,
	IB_WC_BAD_RESP_ERR = 7,
	IB_WC_LOC_ACCESS_ERR = 8,
	IB_WC_REM_INV_REQ_ERR = 9,
	IB_WC_REM_ACCESS_ERR = 10,
	IB_WC_REM_OP_ERR = 11,
	IB_WC_RETRY_EXC_ERR = 12,
	IB_WC_RNR_RETRY_EXC_ERR = 13,
	IB_WC_LOC_RDD_VIOL_ERR = 14,
	IB_WC_REM_INV_RD_REQ_ERR = 15,
	IB_WC_REM_ABORT_ERR = 16,
	IB_WC_INV_EECN_ERR = 17,
	IB_WC_INV_EEC_STATE_ERR = 18,
	IB_WC_FATAL_ERR = 19,
	IB_WC_RESP_TIMEOUT_ERR = 20,
	IB_WC_GENERAL_ERR = 21,
};

enum ib_wc_opcode {
	IB_WC_SEND = 0,
	IB_WC_RDMA_WRITE = 1,
	IB_WC_RDMA_READ = 2,
	IB_WC_COMP_SWAP = 3,
	IB_WC_FETCH_ADD = 4,
	IB_WC_LSO = 5,
	IB_WC_LOCAL_INV = 6,
	IB_WC_REG_MR = 7,
	IB_WC_MASKED_COMP_SWAP = 8,
	IB_WC_MASKED_FETCH_ADD = 9,
	IB_WC_RECV = 128,
	IB_WC_RECV_RDMA_WITH_IMM = 129,
};

struct ib_cqe {
	void (*done)(struct ib_cq *, struct ib_wc *);
};

struct ib_wc {
	union {
		u64 wr_id;
		struct ib_cqe *wr_cqe;
	};
	enum ib_wc_status status;
	enum ib_wc_opcode opcode;
	u32 vendor_err;
	u32 byte_len;
	struct ib_qp *qp;
	union {
		__be32 imm_data;
		u32 invalidate_rkey;
	} ex;
	u32 src_qp;
	u32 slid;
	int wc_flags;
	u16 pkey_index;
	u8 sl;
	u8 dlid_path_bits;
	u8 port_num;
	u8 smac[6];
	u16 vlan_id;
	u8 network_hdr_type;
};

struct ib_srq_attr {
	u32 max_wr;
	u32 max_sge;
	u32 srq_limit;
};

struct ib_xrcd {
	struct ib_device *device;
	atomic_t usecnt;
	struct inode___277 *inode;
	struct mutex tgt_qp_mutex;
	struct list_head tgt_qp_list;
};

struct ib_srq_init_attr {
	void (*event_handler)(struct ib_event *, void *);
	void *srq_context;
	struct ib_srq_attr attr;
	enum ib_srq_type srq_type;
	struct {
		struct ib_cq *cq;
		union {
			struct {
				struct ib_xrcd *xrcd;
			} xrc;
			struct {
				u32 max_num_tags;
			} tag_matching;
		};
	} ext;
};

struct ib_qp_cap {
	u32 max_send_wr;
	u32 max_recv_wr;
	u32 max_send_sge;
	u32 max_recv_sge;
	u32 max_inline_data;
	u32 max_rdma_ctxs;
};

enum ib_sig_type {
	IB_SIGNAL_ALL_WR = 0,
	IB_SIGNAL_REQ_WR = 1,
};

struct ib_qp_init_attr {
	void (*event_handler)(struct ib_event *, void *);
	void *qp_context;
	struct ib_cq *send_cq;
	struct ib_cq *recv_cq;
	struct ib_srq *srq;
	struct ib_xrcd *xrcd;
	struct ib_qp_cap cap;
	enum ib_sig_type sq_sig_type;
	enum ib_qp_type qp_type;
	u32 create_flags;
	u8 port_num;
	struct ib_rwq_ind_table *rwq_ind_tbl;
	u32 source_qpn;
};

struct ib_rwq_ind_table {
	struct ib_device *device;
	struct ib_uobject *uobject;
	atomic_t usecnt;
	u32 ind_tbl_num;
	u32 log_ind_tbl_size;
	struct ib_wq **ind_tbl;
};

enum ib_qp_state {
	IB_QPS_RESET = 0,
	IB_QPS_INIT = 1,
	IB_QPS_RTR = 2,
	IB_QPS_RTS = 3,
	IB_QPS_SQD = 4,
	IB_QPS_SQE = 5,
	IB_QPS_ERR = 6,
};

enum ib_mig_state {
	IB_MIG_MIGRATED = 0,
	IB_MIG_REARM = 1,
	IB_MIG_ARMED = 2,
};

struct ib_qp_attr {
	enum ib_qp_state qp_state;
	enum ib_qp_state cur_qp_state;
	enum ib_mtu path_mtu;
	enum ib_mig_state path_mig_state;
	u32 qkey;
	u32 rq_psn;
	u32 sq_psn;
	u32 dest_qp_num;
	int qp_access_flags;
	struct ib_qp_cap cap;
	struct rdma_ah_attr ah_attr;
	struct rdma_ah_attr alt_ah_attr;
	u16 pkey_index;
	u16 alt_pkey_index;
	u8 en_sqd_async_notify;
	u8 sq_draining;
	u8 max_rd_atomic;
	u8 max_dest_rd_atomic;
	u8 min_rnr_timer;
	u8 port_num;
	u8 timeout;
	u8 retry_cnt;
	u8 rnr_retry;
	u8 alt_port_num;
	u8 alt_timeout;
	u32 rate_limit;
};

enum ib_wr_opcode {
	IB_WR_RDMA_WRITE = 0,
	IB_WR_RDMA_WRITE_WITH_IMM = 1,
	IB_WR_SEND = 2,
	IB_WR_SEND_WITH_IMM = 3,
	IB_WR_RDMA_READ = 4,
	IB_WR_ATOMIC_CMP_AND_SWP = 5,
	IB_WR_ATOMIC_FETCH_AND_ADD = 6,
	IB_WR_LSO = 10,
	IB_WR_SEND_WITH_INV = 9,
	IB_WR_RDMA_READ_WITH_INV = 11,
	IB_WR_LOCAL_INV = 7,
	IB_WR_MASKED_ATOMIC_CMP_AND_SWP = 12,
	IB_WR_MASKED_ATOMIC_FETCH_AND_ADD = 13,
	IB_WR_REG_MR = 32,
	IB_WR_REG_SIG_MR = 33,
	IB_WR_RESERVED1 = 240,
	IB_WR_RESERVED2 = 241,
	IB_WR_RESERVED3 = 242,
	IB_WR_RESERVED4 = 243,
	IB_WR_RESERVED5 = 244,
	IB_WR_RESERVED6 = 245,
	IB_WR_RESERVED7 = 246,
	IB_WR_RESERVED8 = 247,
	IB_WR_RESERVED9 = 248,
	IB_WR_RESERVED10 = 249,
};

struct ib_sge {
	u64 addr;
	u32 length;
	u32 lkey;
};

struct ib_send_wr {
	struct ib_send_wr *next;
	union {
		u64 wr_id;
		struct ib_cqe *wr_cqe;
	};
	struct ib_sge *sg_list;
	int num_sge;
	enum ib_wr_opcode opcode;
	int send_flags;
	union {
		__be32 imm_data;
		u32 invalidate_rkey;
	} ex;
};

struct ib_ah {
	struct ib_device *device;
	struct ib_pd *pd;
	struct ib_uobject *uobject;
	const struct ib_gid_attr *sgid_attr;
	enum rdma_ah_attr_type type;
};

struct ib_mr {
	struct ib_device *device;
	struct ib_pd *pd;
	u32 lkey;
	u32 rkey;
	u64 iova;
	u64 length;
	unsigned int page_size;
	bool need_inval;
	union {
		struct ib_uobject *uobject;
		struct list_head qp_entry;
	};
	struct ib_dm *dm;
	struct rdma_restrack_entry res;
};

struct ib_recv_wr {
	struct ib_recv_wr *next;
	union {
		u64 wr_id;
		struct ib_cqe *wr_cqe;
	};
	struct ib_sge *sg_list;
	int num_sge;
};

struct ib_fmr_attr {
	int max_pages;
	int max_maps;
	u8 page_shift;
};

struct ib_rdmacg_object {
	struct rdma_cgroup___2 *cg;
};

struct ib_uverbs_file;

struct ib_umem_odp;

struct ib_ucontext {
	struct ib_device *device;
	struct ib_uverbs_file *ufile;
	bool closing;
	bool cleanup_retryable;
	void (*invalidate_range)(struct ib_umem_odp *, long unsigned int, long unsigned int);
	struct mutex per_mm_list_lock;
	struct list_head per_mm_list;
	struct ib_rdmacg_object cg_obj;
	struct rdma_restrack_entry res;
};

struct uverbs_api_object;

struct ib_uobject {
	u64 user_handle;
	struct ib_uverbs_file *ufile;
	struct ib_ucontext *context;
	void *object;
	struct list_head list;
	struct ib_rdmacg_object cg_obj;
	int id;
	struct kref ref;
	atomic_t usecnt;
	struct callback_head rcu;
	const struct uverbs_api_object *uapi_object;
};

struct ib_udata {
	const void *inbuf;
	void *outbuf;
	size_t inlen;
	size_t outlen;
};

struct ib_pd {
	u32 local_dma_lkey;
	u32 flags;
	struct ib_device *device;
	struct ib_uobject *uobject;
	atomic_t usecnt;
	u32 unsafe_global_rkey;
	struct ib_mr *__internal_mr;
	struct rdma_restrack_entry res;
};

struct ib_wq_init_attr {
	void *wq_context;
	enum ib_wq_type wq_type;
	u32 max_wr;
	u32 max_sge;
	struct ib_cq *cq;
	void (*event_handler)(struct ib_event *, void *);
	u32 create_flags;
};

struct ib_wq_attr {
	enum ib_wq_state wq_state;
	enum ib_wq_state curr_wq_state;
	u32 flags;
	u32 flags_mask;
};

struct ib_rwq_ind_table_init_attr {
	u32 log_ind_tbl_size;
	struct ib_wq **ind_tbl;
};

enum port_pkey_state {
	IB_PORT_PKEY_NOT_VALID = 0,
	IB_PORT_PKEY_VALID = 1,
	IB_PORT_PKEY_LISTED = 2,
};

struct ib_port_pkey {
	enum port_pkey_state state;
	u16 pkey_index;
	u8 port_num;
	struct list_head qp_list;
	struct list_head to_error_list;
	struct ib_qp_security *sec;
};

struct ib_ports_pkeys;

struct ib_qp_security {
	struct ib_qp *qp;
	struct ib_device *dev;
	struct mutex mutex;
	struct ib_ports_pkeys *ports_pkeys;
	struct list_head shared_qp_list;
	void *security;
	bool destroying;
	atomic_t error_list_count;
	struct completion error_complete;
	int error_comps_pending;
};

struct ib_ports_pkeys {
	struct ib_port_pkey main;
	struct ib_port_pkey alt;
};

struct ib_dm {
	struct ib_device *device;
	u32 length;
	u32 flags;
	struct ib_uobject *uobject;
	atomic_t usecnt;
};

struct ib_mw {
	struct ib_device *device;
	struct ib_pd *pd;
	struct ib_uobject *uobject;
	u32 rkey;
	enum ib_mw_type type;
};

struct ib_fmr {
	struct ib_device *device;
	struct ib_pd *pd;
	struct list_head list;
	u32 lkey;
	u32 rkey;
};

enum ib_flow_attr_type {
	IB_FLOW_ATTR_NORMAL = 0,
	IB_FLOW_ATTR_ALL_DEFAULT = 1,
	IB_FLOW_ATTR_MC_DEFAULT = 2,
	IB_FLOW_ATTR_SNIFFER = 3,
};

enum ib_flow_spec_type {
	IB_FLOW_SPEC_ETH = 32,
	IB_FLOW_SPEC_IB = 34,
	IB_FLOW_SPEC_IPV4 = 48,
	IB_FLOW_SPEC_IPV6 = 49,
	IB_FLOW_SPEC_ESP = 52,
	IB_FLOW_SPEC_TCP = 64,
	IB_FLOW_SPEC_UDP = 65,
	IB_FLOW_SPEC_VXLAN_TUNNEL = 80,
	IB_FLOW_SPEC_GRE = 81,
	IB_FLOW_SPEC_MPLS = 96,
	IB_FLOW_SPEC_INNER = 256,
	IB_FLOW_SPEC_ACTION_TAG = 4096,
	IB_FLOW_SPEC_ACTION_DROP = 4097,
	IB_FLOW_SPEC_ACTION_HANDLE = 4098,
	IB_FLOW_SPEC_ACTION_COUNT = 4099,
};

struct ib_flow_eth_filter {
	u8 dst_mac[6];
	u8 src_mac[6];
	__be16 ether_type;
	__be16 vlan_tag;
	u8 real_sz[0];
};

struct ib_flow_spec_eth {
	u32 type;
	u16 size;
	struct ib_flow_eth_filter val;
	struct ib_flow_eth_filter mask;
};

struct ib_flow_ib_filter {
	__be16 dlid;
	__u8 sl;
	u8 real_sz[0];
};

struct ib_flow_spec_ib {
	u32 type;
	u16 size;
	struct ib_flow_ib_filter val;
	struct ib_flow_ib_filter mask;
};

struct ib_flow_ipv4_filter {
	__be32 src_ip;
	__be32 dst_ip;
	u8 proto;
	u8 tos;
	u8 ttl;
	u8 flags;
	u8 real_sz[0];
};

struct ib_flow_spec_ipv4 {
	u32 type;
	u16 size;
	struct ib_flow_ipv4_filter val;
	struct ib_flow_ipv4_filter mask;
};

struct ib_flow_ipv6_filter {
	u8 src_ip[16];
	u8 dst_ip[16];
	__be32 flow_label;
	u8 next_hdr;
	u8 traffic_class;
	u8 hop_limit;
	u8 real_sz[0];
};

struct ib_flow_spec_ipv6 {
	u32 type;
	u16 size;
	struct ib_flow_ipv6_filter val;
	struct ib_flow_ipv6_filter mask;
};

struct ib_flow_tcp_udp_filter {
	__be16 dst_port;
	__be16 src_port;
	u8 real_sz[0];
};

struct ib_flow_spec_tcp_udp {
	u32 type;
	u16 size;
	struct ib_flow_tcp_udp_filter val;
	struct ib_flow_tcp_udp_filter mask;
};

struct ib_flow_tunnel_filter {
	__be32 tunnel_id;
	u8 real_sz[0];
};

struct ib_flow_spec_tunnel {
	u32 type;
	u16 size;
	struct ib_flow_tunnel_filter val;
	struct ib_flow_tunnel_filter mask;
};

struct ib_flow_esp_filter {
	__be32 spi;
	__be32 seq;
	u8 real_sz[0];
};

struct ib_flow_spec_esp {
	u32 type;
	u16 size;
	struct ib_flow_esp_filter val;
	struct ib_flow_esp_filter mask;
};

struct ib_flow_gre_filter {
	__be16 c_ks_res0_ver;
	__be16 protocol;
	__be32 key;
	u8 real_sz[0];
};

struct ib_flow_spec_gre {
	u32 type;
	u16 size;
	struct ib_flow_gre_filter val;
	struct ib_flow_gre_filter mask;
};

struct ib_flow_mpls_filter {
	__be32 tag;
	u8 real_sz[0];
};

struct ib_flow_spec_mpls {
	u32 type;
	u16 size;
	struct ib_flow_mpls_filter val;
	struct ib_flow_mpls_filter mask;
};

struct ib_flow_spec_action_tag {
	enum ib_flow_spec_type type;
	u16 size;
	u32 tag_id;
};

struct ib_flow_spec_action_drop {
	enum ib_flow_spec_type type;
	u16 size;
};

struct ib_flow_spec_action_handle {
	enum ib_flow_spec_type type;
	u16 size;
	struct ib_flow_action *act;
};

enum ib_flow_action_type {
	IB_FLOW_ACTION_UNSPECIFIED = 0,
	IB_FLOW_ACTION_ESP = 1,
};

struct ib_flow_action {
	struct ib_device *device;
	struct ib_uobject *uobject;
	enum ib_flow_action_type type;
	atomic_t usecnt;
};

struct ib_flow_spec_action_count {
	enum ib_flow_spec_type type;
	u16 size;
	struct ib_counters *counters;
};

struct ib_counters {
	struct ib_device *device;
	struct ib_uobject *uobject;
	atomic_t usecnt;
};

union ib_flow_spec {
	struct {
		u32 type;
		u16 size;
	};
	struct ib_flow_spec_eth eth;
	struct ib_flow_spec_ib ib;
	struct ib_flow_spec_ipv4 ipv4;
	struct ib_flow_spec_tcp_udp tcp_udp;
	struct ib_flow_spec_ipv6 ipv6;
	struct ib_flow_spec_tunnel tunnel;
	struct ib_flow_spec_esp esp;
	struct ib_flow_spec_gre gre;
	struct ib_flow_spec_mpls mpls;
	struct ib_flow_spec_action_tag flow_tag;
	struct ib_flow_spec_action_drop drop;
	struct ib_flow_spec_action_handle action;
	struct ib_flow_spec_action_count flow_count;
};

struct ib_flow_attr {
	enum ib_flow_attr_type type;
	u16 size;
	u16 priority;
	u32 flags;
	u8 num_of_specs;
	u8 port;
	union ib_flow_spec flows[0];
};

struct ib_flow {
	struct ib_qp *qp;
	struct ib_device *device;
	struct ib_uobject *uobject;
};

struct ib_flow_action_attrs_esp_keymats {
	enum ib_uverbs_flow_action_esp_keymat protocol;
	union {
		struct ib_uverbs_flow_action_esp_keymat_aes_gcm aes_gcm;
	} keymat;
};

struct ib_flow_action_attrs_esp_replays {
	enum ib_uverbs_flow_action_esp_replay protocol;
	union {
		struct ib_uverbs_flow_action_esp_replay_bmp bmp;
	} replay;
};

struct ib_flow_spec_list {
	struct ib_flow_spec_list *next;
	union ib_flow_spec spec;
};

struct ib_flow_action_attrs_esp {
	struct ib_flow_action_attrs_esp_keymats *keymat;
	struct ib_flow_action_attrs_esp_replays *replay;
	struct ib_flow_spec_list *encap;
	u32 esn;
	u32 spi;
	u32 seq;
	u32 tfc_pad;
	u64 flags;
	u64 hard_limit_pkts;
};

struct ib_pkey_cache;

struct ib_gid_table;

struct ib_port_cache {
	u64 subnet_prefix;
	struct ib_pkey_cache *pkey;
	struct ib_gid_table *gid;
	u8 lmc;
	enum ib_port_state port_state;
};

struct ib_port_immutable {
	int pkey_tbl_len;
	int gid_tbl_len;
	u32 core_cap_flags;
	u32 max_mad_size;
};

struct rdma_netdev_alloc_params {
	size_t sizeof_priv;
	unsigned int txqs;
	unsigned int rxqs;
	void *param;
	int (*initialize_rdma_netdev)(struct ib_device *, u8, struct net_device___38 *, void *);
};

struct ib_port_pkey_list {
	spinlock_t list_lock;
	struct list_head pkey_list;
};

struct ib_counters_read_attr {
	u64 *counters_buff;
	u32 ncounters;
	u32 flags;
};

struct module___225;

struct file___278;

struct kiocb___278;

struct iov_iter___135;

struct poll_table_struct___169;

struct vm_area_struct___279;

struct inode___278;

struct file_lock___278;

struct page___279;

struct seq_file___242;

struct file_operations___278 {
	struct module___225 *owner;
	loff_t (*llseek)(struct file___278 *, loff_t, int);
	ssize_t (*read)(struct file___278 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___278 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___278 *, struct iov_iter___135 *);
	ssize_t (*write_iter)(struct kiocb___278 *, struct iov_iter___135 *);
	int (*iopoll)(struct kiocb___278 *, bool);
	int (*iterate)(struct file___278 *, struct dir_context *);
	int (*iterate_shared)(struct file___278 *, struct dir_context *);
	__poll_t (*poll)(struct file___278 *, struct poll_table_struct___169 *);
	long int (*unlocked_ioctl)(struct file___278 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___278 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___278 *, struct vm_area_struct___279 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___278 *, struct file___278 *);
	int (*flush)(struct file___278 *, fl_owner_t);
	int (*release)(struct inode___278 *, struct file___278 *);
	int (*fsync)(struct file___278 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___278 *, int);
	int (*lock)(struct file___278 *, int, struct file_lock___278 *);
	ssize_t (*sendpage)(struct file___278 *, struct page___279 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___278 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___278 *, int, struct file_lock___278 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___278 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___278 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___278 *, long int, struct file_lock___278 **, void **);
	long int (*fallocate)(struct file___278 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___242 *, struct file___278 *);
	ssize_t (*copy_file_range)(struct file___278 *, loff_t, struct file___278 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___278 *, loff_t, struct file___278 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___278 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio_vec___147 {
	struct page___279 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

typedef struct page___279 *pgtable_t___278;

struct address_space___277;

struct mm_struct___278;

struct dev_pagemap___267;

struct mem_cgroup___115;

struct page___279 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___277 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___279 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___278 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___278 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___267 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___115 *mem_cgroup;
};

struct vmacache___278 {
	u64 seqnum;
	struct vm_area_struct___279 *vmas[4];
};

struct page_frag___278 {
	struct page___279 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___130;

struct debug_info___130 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___130 *hbp_break[16];
	struct perf_event___130 *hbp_watch[16];
};

struct thread_struct___130 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___130 debug;
	long: 64;
};

struct pid___193;

struct cred___263;

struct nsproxy___240;

struct signal_struct___218;

struct bio_list___147;

struct backing_dev_info___147;

struct io_context___82;

struct css_set___205;

struct perf_event_context___130;

struct request_queue___78;

struct vm_struct___194;

struct task_struct___279 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___279 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___278 *mm;
	struct mm_struct___278 *active_mm;
	struct vmacache___278 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___279 *real_parent;
	struct task_struct___279 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___279 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___115 *active_memcg;
	long int rh_reserved2;
	struct pid___193 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___193 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___193 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___263 *ptracer_cred;
	const struct cred___263 *real_cred;
	const struct cred___263 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___240 *nsproxy;
	struct signal_struct___218 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___279 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___147 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___147 *backing_dev_info;
	struct io_context___82 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___205 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___130 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___278 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___115 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___78 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___279 *oom_reaper_list;
	struct vm_struct___194 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___130 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___130 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___279 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___130)(struct perf_event___130 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___130;

struct fasync_struct___277;

struct pid_namespace___193;

struct trace_event_call___123;

struct perf_cgroup___130;

struct perf_event___130 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___130 *group_leader;
	struct pmu___130 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___130 hw;
	struct perf_event_context___130 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___130 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___279 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___277 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___130 *);
	struct callback_head callback_head;
	struct pid_namespace___193 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___130 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___130 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___123 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___130 *cgrp;
	struct list_head sb_list;
};

struct secondary_data___279 {
	void *stack;
	struct task_struct___279 *task;
	long int status;
};

struct bio___147;

typedef void bio_end_io_t___147(struct bio___147 *);

struct gendisk___79;

struct blkcg_gq___54;

struct bio_integrity_payload___147;

struct bio_set___147;

struct bio___147 {
	struct bio___147 *bi_next;
	struct gendisk___79 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___147 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___54 *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___147 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___147 *bi_io_vec;
	struct bio_set___147 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___147 bi_inline_vecs[0];
};

struct bio_integrity_payload___147 {
	struct bio___147 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___147 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___147 bip_inline_vecs[0];
};

struct kset___265;

struct kobj_type___265;

struct kernfs_node___273;

struct kobject___266 {
	const char *name;
	struct list_head entry;
	struct kobject___266 *parent;
	struct kset___265 *kset;
	struct kobj_type___265 *ktype;
	struct kernfs_node___273 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___241;

struct dev_pm_info___241 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___241 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___241;

struct bus_type___241;

struct device_driver___241;

struct dev_pm_domain___241;

struct fwnode_handle___176;

struct class___241;

struct attribute_group___243;

struct device___241 {
	struct device___241 *parent;
	struct device_private *p;
	struct kobject___266 kobj;
	const char *init_name;
	const struct device_type___241 *type;
	struct mutex mutex;
	struct bus_type___241 *bus;
	struct device_driver___241 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___241 power;
	struct dev_pm_domain___241 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___176 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___241 *class;
	const struct attribute_group___243 **groups;
	void (*release)(struct device___241 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___79 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___241 __dev;
	struct kobject___266 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct rw_semaphore___279 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___279 *owner;
};

struct disk_part_tbl___79;

struct block_device_operations___79;

struct gendisk___79 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___79 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___79 *part_tbl;
	struct hd_struct___79 part0;
	const struct block_device_operations___79 *fops;
	struct request_queue___78 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___279 lookup_sem;
	struct kobject___266 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___266 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct blkcg___54;

struct bdi_writeback_congested___147;

struct blkg_policy_data___54;

struct blkcg_gq___54 {
	struct request_queue___78 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___54 *blkcg;
	struct bdi_writeback_congested___147 *wb_congested;
	struct blkcg_gq___54 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_rwstat stat_bytes;
	struct blkg_rwstat stat_ios;
	struct blkg_policy_data___54 *pd[5];
	struct callback_head callback_head;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
};

struct bio_list___147 {
	struct bio___147 *head;
	struct bio___147 *tail;
};

struct bio_set___147 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___147 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct pglist_data___278;

struct lruvec___278 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___278 *pgdat;
};

struct zone___278 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___278 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___278 {
	struct zone___278 *zone;
	int zone_idx;
};

struct zonelist___278 {
	struct zoneref___278 _zonerefs[25];
};

struct pglist_data___278 {
	struct zone___278 node_zones[3];
	struct zonelist___278 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___279 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___279 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___278 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___278 {
	struct rw_semaphore___279 rwsem;
	struct notifier_block *head;
};

struct cgroup___205;

struct cgroup_subsys___205;

struct cgroup_subsys_state___205 {
	struct cgroup___205 *cgroup;
	struct cgroup_subsys___205 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___205 *parent;
};

struct cgroup_file___205 {
	struct kernfs_node___273 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___115;

struct mem_cgroup___115 {
	struct cgroup_subsys_state___205 css;
	struct mem_cgroup_id___17 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___205 events_file;
	struct cgroup_file___205 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___279 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___115 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___277;

struct super_block___277;

struct dentry___278 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___278 *d_parent;
	struct qstr d_name;
	struct inode___278 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___277 *d_op;
	struct super_block___277 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___277;

struct address_space___277 {
	struct inode___278 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___279 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___277 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___277;

struct bdi_writeback___147;

struct block_device___277;

struct inode___278 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___277 *i_op;
	struct super_block___277 *i_sb;
	struct address_space___277 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___279 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___147 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___278 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___277 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___277 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___278;

struct dentry_operations___277 {
	int (*d_revalidate)(struct dentry___278 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___278 *, unsigned int);
	int (*d_hash)(const struct dentry___278 *, struct qstr *);
	int (*d_compare)(const struct dentry___278 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___278 *);
	int (*d_init)(struct dentry___278 *);
	void (*d_release)(struct dentry___278 *);
	void (*d_prune)(struct dentry___278 *);
	void (*d_iput)(struct dentry___278 *, struct inode___278 *);
	char * (*d_dname)(struct dentry___278 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___278 *);
	int (*d_manage)(const struct path___278 *, bool);
	struct dentry___278 * (*d_real)(struct dentry___278 *, const struct inode___278 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___277;

struct mem_dqinfo___277 {
	struct quota_format_type___277 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___277;

struct quota_info___277 {
	unsigned int flags;
	struct rw_semaphore___279 dqio_sem;
	struct inode___278 *files[3];
	struct mem_dqinfo___277 info[3];
	const struct quota_format_ops___277 *ops[3];
};

struct rcuwait___277 {
	struct task_struct___279 *task;
};

struct percpu_rw_semaphore___277 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___279 rw_sem;
	struct rcuwait___277 writer;
	int readers_block;
};

struct sb_writers___277 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___277 rw_sem[3];
};

struct shrink_control___115;

struct shrinker___115 {
	long unsigned int (*count_objects)(struct shrinker___115 *, struct shrink_control___115 *);
	long unsigned int (*scan_objects)(struct shrinker___115 *, struct shrink_control___115 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___277;

struct super_operations___277;

struct dquot_operations___277;

struct quotactl_ops___277;

struct user_namespace___220;

struct super_block___277 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___277 *s_type;
	const struct super_operations___277 *s_op;
	const struct dquot_operations___277 *dq_op;
	const struct quotactl_ops___277 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___278 *s_root;
	struct rw_semaphore___279 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___277 *s_bdev;
	struct backing_dev_info___147 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___277 s_dquot;
	struct sb_writers___277 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___277 *s_d_op;
	int cleancache_poolid;
	struct shrinker___115 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___220 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct path___278 {
	struct vfsmount *mnt;
	struct dentry___278 *dentry;
};

struct key___263;

struct ucounts___220;

struct user_namespace___220 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___220 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___9 ns;
	long unsigned int flags;
	struct key___263 *persistent_keyring_register;
	struct rw_semaphore___279 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___220 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct shrink_control___115 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___115 *memcg;
};

struct upid___193 {
	int nr;
	struct pid_namespace___193 *ns;
};

struct pid_namespace___193 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___279 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___193 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___278 *proc_self;
	struct dentry___278 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___220 *user_ns;
	struct ucounts___220 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___9 ns;
};

struct pid___193 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___193 numbers[1];
};

struct vm_operations_struct___267;

struct vm_area_struct___279 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___279 *vm_next;
	struct vm_area_struct___279 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___278 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___267 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___278 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___278;

struct mm_struct___278 {
	struct {
		struct vm_area_struct___279 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___278 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___279 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___278 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___279 *owner;
		struct user_namespace___220 *user_ns;
		struct file___278 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___278 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___267)(struct vm_area_struct___279 *, long unsigned int, const struct page___279 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___267)(struct page___279 *, void *);

struct dev_pagemap___267 {
	dev_page_fault_t___267 page_fault;
	dev_page_free_t___267 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___241 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct fown_struct___193 {
	rwlock_t lock;
	struct pid___193 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___278 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___278 f_path;
	struct inode___278 *f_inode;
	const struct file_operations___278 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___193 f_owner;
	const struct cred___263 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___277 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___267;

struct vm_operations_struct___267 {
	void (*open)(struct vm_area_struct___279 *);
	void (*close)(struct vm_area_struct___279 *);
	int (*split)(struct vm_area_struct___279 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___279 *);
	vm_fault_t (*fault)(struct vm_fault___267 *);
	vm_fault_t (*huge_fault)(struct vm_fault___267 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___267 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___279 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___267 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___267 *);
	int (*access)(struct vm_area_struct___279 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___279 *);
	int (*set_policy)(struct vm_area_struct___279 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___279 *, long unsigned int);
	struct page___279 * (*find_special_page)(struct vm_area_struct___279 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___278 {
	struct task_struct___279 *task;
	struct core_thread___278 *next;
};

struct core_state___278 {
	atomic_t nr_threads;
	struct core_thread___278 dumper;
	struct completion startup;
};

struct vm_fault___267 {
	struct vm_area_struct___279 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___279 *cow_page;
	struct mem_cgroup___115 *memcg;
	struct page___279 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___278 prealloc_pte;
};

struct user_struct___263 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___263 *uid_keyring;
	struct key___263 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___263 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___263 *session_keyring;
	struct key___263 *process_keyring;
	struct key___263 *thread_keyring;
	struct key___263 *request_key_auth;
	void *security;
	struct user_struct___263 *user;
	struct user_namespace___220 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___205;

struct nsproxy___240 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___193 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___205 *cgroup_ns;
};

struct signal_struct___218 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___279 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___279 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___193 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___193 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___278 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___193 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide45;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bdi_writeback___147 {
	struct backing_dev_info___147 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___147 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___205 *memcg_css;
	struct cgroup_subsys_state___205 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___147 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___147 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___241 *dev;
	struct device___241 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___278 *debug_dir;
	struct dentry___278 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___82;

struct io_context___82 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___82 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___205 {
	struct cgroup_subsys_state___205 *subsys[13];
	refcount_t refcount;
	struct css_set___205 *dom_cset;
	struct cgroup___205 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___205 *mg_src_cgrp;
	struct cgroup___205 *mg_dst_cgrp;
	struct css_set___205 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___130 {
	struct pmu___130 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___279 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___130 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

typedef blk_qc_t make_request_fn___78(struct request_queue___78 *, struct bio___147 *);

struct request___78;

typedef int dma_drain_needed_fn___78(struct request___78 *);

struct bsg_ops___78;

struct bsg_class_device___78 {
	struct device___241 *class_dev;
	int minor;
	struct request_queue___78 *queue;
	const struct bsg_ops___78 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct elevator_queue___78;

struct rq_qos___7;

struct blk_stat_callback___16;

struct request_queue___78 {
	struct list_head queue_head;
	struct request___78 *last_merge;
	struct elevator_queue___78 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos___7 *rq_qos;
	make_request_fn___78 *make_request_fn;
	dma_drain_needed_fn___78 *dma_drain_needed;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___147 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___266 kobj;
	struct kobject___266 *mq_kobj;
	struct blk_integrity integrity;
	struct device___241 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback___16 *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___54 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	struct bsg_class_device___78 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___147 bio_split;
	struct dentry___278 *debugfs_dir;
	struct dentry___278 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___194 {
	struct vm_struct___194 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___279 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___230 {
	struct task_struct___279 task;
	long unsigned int stack[8192];
};

struct io_cq___82 {
	struct request_queue___78 *q;
	struct io_context___82 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___278 {
	struct file___278 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___278 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___277 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___278 *ia_file;
};

struct dquot___277 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___277 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___277 {
	int qf_fmt_id;
	const struct quota_format_ops___277 *qf_ops;
	struct module___225 *qf_owner;
	struct quota_format_type___277 *qf_next;
};

struct quota_format_ops___277 {
	int (*check_quota_file)(struct super_block___277 *, int);
	int (*read_file_info)(struct super_block___277 *, int);
	int (*write_file_info)(struct super_block___277 *, int);
	int (*free_file_info)(struct super_block___277 *, int);
	int (*read_dqblk)(struct dquot___277 *);
	int (*commit_dqblk)(struct dquot___277 *);
	int (*release_dqblk)(struct dquot___277 *);
	int (*get_next_id)(struct super_block___277 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___277 {
	int (*write_dquot)(struct dquot___277 *);
	struct dquot___277 * (*alloc_dquot)(struct super_block___277 *, int);
	void (*destroy_dquot)(struct dquot___277 *);
	int (*acquire_dquot)(struct dquot___277 *);
	int (*release_dquot)(struct dquot___277 *);
	int (*mark_dirty)(struct dquot___277 *);
	int (*write_info)(struct super_block___277 *, int);
	qsize_t * (*get_reserved_space)(struct inode___278 *);
	int (*get_projid)(struct inode___278 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___278 *, qsize_t *);
	int (*get_next_id)(struct super_block___277 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___277 {
	int (*quota_on)(struct super_block___277 *, int, int, const struct path___278 *);
	int (*quota_off)(struct super_block___277 *, int);
	int (*quota_enable)(struct super_block___277 *, unsigned int);
	int (*quota_disable)(struct super_block___277 *, unsigned int);
	int (*quota_sync)(struct super_block___277 *, int);
	int (*set_info)(struct super_block___277 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___277 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___277 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___277 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___277 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___277 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___222 {
	struct kobject___266 kobj;
	struct module___225 *mod;
	struct kobject___266 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___222 {
	struct module___225 *mod;
	struct latch_tree_node node;
};

struct module_layout___222 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___222 mtn;
};

struct module_attribute___222;

struct kernel_param___222;

struct module___225 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___222 mkobj;
	struct module_attribute___222 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___266 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___222 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___222 core_layout;
	struct module_layout___222 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___123 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide43;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide44;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___130;

struct swap_info_struct___74;

struct address_space_operations___277 {
	int (*writepage)(struct page___279 *, struct writeback_control___130 *);
	int (*readpage)(struct file___278 *, struct page___279 *);
	int (*writepages)(struct address_space___277 *, struct writeback_control___130 *);
	int (*set_page_dirty)(struct page___279 *);
	int (*readpages)(struct file___278 *, struct address_space___277 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___278 *, struct address_space___277 *, loff_t, unsigned int, unsigned int, struct page___279 **, void **);
	int (*write_end)(struct file___278 *, struct address_space___277 *, loff_t, unsigned int, unsigned int, struct page___279 *, void *);
	sector_t (*bmap)(struct address_space___277 *, sector_t);
	void (*invalidatepage)(struct page___279 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___279 *, gfp_t);
	void (*freepage)(struct page___279 *);
	ssize_t (*direct_IO)(struct kiocb___278 *, struct iov_iter___135 *);
	int (*migratepage)(struct address_space___277 *, struct page___279 *, struct page___279 *, enum migrate_mode);
	bool (*isolate_page)(struct page___279 *, isolate_mode_t);
	void (*putback_page)(struct page___279 *);
	int (*launder_page)(struct page___279 *);
	int (*is_partially_uptodate)(struct page___279 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___279 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___277 *, struct page___279 *);
	int (*swap_activate)(struct swap_info_struct___74 *, struct file___278 *, sector_t *);
	void (*swap_deactivate)(struct file___278 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___130 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___147 *wb;
	struct inode___278 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct iov_iter___135 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___147 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct swap_info_struct___74 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___277 *bdev;
	struct file___278 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___277 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___278 *bd_inode;
	struct super_block___277 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___277 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___79 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___79 *bd_disk;
	struct request_queue___78 *bd_queue;
	struct backing_dev_info___147 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___277 {
	struct dentry___278 * (*lookup)(struct inode___278 *, struct dentry___278 *, unsigned int);
	const char * (*get_link)(struct dentry___278 *, struct inode___278 *, struct delayed_call *);
	int (*permission)(struct inode___278 *, int);
	struct posix_acl * (*get_acl)(struct inode___278 *, int);
	int (*readlink)(struct dentry___278 *, char *, int);
	int (*create)(struct inode___278 *, struct dentry___278 *, umode_t, bool);
	int (*link)(struct dentry___278 *, struct inode___278 *, struct dentry___278 *);
	int (*unlink)(struct inode___278 *, struct dentry___278 *);
	int (*symlink)(struct inode___278 *, struct dentry___278 *, const char *);
	int (*mkdir)(struct inode___278 *, struct dentry___278 *, umode_t);
	int (*rmdir)(struct inode___278 *, struct dentry___278 *);
	int (*mknod)(struct inode___278 *, struct dentry___278 *, umode_t, dev_t);
	int (*rename)(struct inode___278 *, struct dentry___278 *, struct inode___278 *, struct dentry___278 *, unsigned int);
	int (*setattr)(struct dentry___278 *, struct iattr___277 *);
	int (*getattr)(const struct path___278 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___278 *, char *, size_t);
	int (*fiemap)(struct inode___278 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___278 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___278 *, struct dentry___278 *, struct file___278 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___278 *, struct dentry___278 *, umode_t);
	int (*set_acl)(struct inode___278 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___277 {
	void (*fl_copy_lock)(struct file_lock___278 *, struct file_lock___278 *);
	void (*fl_release_private)(struct file_lock___278 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___277;

struct file_lock___278 {
	struct file_lock___278 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___278 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___277 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___277 *fl_ops;
	const struct lock_manager_operations___277 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___277 {
	int (*lm_compare_owner)(struct file_lock___278 *, struct file_lock___278 *);
	long unsigned int (*lm_owner_key)(struct file_lock___278 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___278 *);
	int (*lm_grant)(struct file_lock___278 *, int);
	bool (*lm_break)(struct file_lock___278 *);
	int (*lm_change)(struct file_lock___278 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___278 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___277 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___277 *fa_next;
	struct file___278 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___277 {
	const char *name;
	int fs_flags;
	struct dentry___278 * (*mount)(struct file_system_type___277 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___277 *);
	struct module___225 *owner;
	struct file_system_type___277 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___277 {
	struct inode___278 * (*alloc_inode)(struct super_block___277 *);
	void (*destroy_inode)(struct inode___278 *);
	void (*dirty_inode)(struct inode___278 *, int);
	int (*write_inode)(struct inode___278 *, struct writeback_control___130 *);
	int (*drop_inode)(struct inode___278 *);
	void (*evict_inode)(struct inode___278 *);
	void (*put_super)(struct super_block___277 *);
	int (*sync_fs)(struct super_block___277 *, int);
	int (*freeze_super)(struct super_block___277 *);
	int (*freeze_fs)(struct super_block___277 *);
	int (*thaw_super)(struct super_block___277 *);
	int (*unfreeze_fs)(struct super_block___277 *);
	int (*statfs)(struct dentry___278 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___277 *, int *, char *);
	void (*umount_begin)(struct super_block___277 *);
	int (*show_options)(struct seq_file___242 *, struct dentry___278 *);
	int (*show_devname)(struct seq_file___242 *, struct dentry___278 *);
	int (*show_path)(struct seq_file___242 *, struct dentry___278 *);
	int (*show_stats)(struct seq_file___242 *, struct dentry___278 *);
	ssize_t (*quota_read)(struct super_block___277 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___277 *, int, const char *, size_t, loff_t);
	struct dquot___277 ** (*get_dquots)(struct inode___278 *);
	int (*bdev_try_to_free_page)(struct super_block___277 *, struct page___279 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___277 *, struct shrink_control___115 *);
	long int (*free_cached_objects)(struct super_block___277 *, struct shrink_control___115 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___171)(struct file___278 *, wait_queue_head_t *, struct poll_table_struct___169 *);

struct poll_table_struct___169 {
	poll_queue_proc___171 _qproc;
	__poll_t _key;
};

struct seq_operations___241;

struct seq_file___242 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___241 *op;
	int poll_event;
	const struct file___278 *file;
	void *private;
};

struct dev_pm_ops___241;

struct device_type___241 {
	const char *name;
	const struct attribute_group___243 **groups;
	int (*uevent)(struct device___241 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___241 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___241 *);
	const struct dev_pm_ops___241 *pm;
};

struct class___241 {
	const char *name;
	struct module___225 *owner;
	const struct attribute_group___243 **class_groups;
	const struct attribute_group___243 **dev_groups;
	struct kobject___266 *dev_kobj;
	int (*dev_uevent)(struct device___241 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___241 *, umode_t *);
	void (*class_release)(struct class___241 *);
	void (*dev_release)(struct device___241 *);
	int (*shutdown_pre)(struct device___241 *);
	const struct kobj_ns_type_operations___25 *ns_type;
	const void * (*namespace)(struct device___241 *);
	const struct dev_pm_ops___241 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct kernfs_root___272;

struct kernfs_elem_dir___272 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___272 *root;
};

struct kernfs_syscall_ops___272;

struct kernfs_root___272 {
	struct kernfs_node___273 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___272 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___272 {
	struct kernfs_node___273 *target_kn;
};

struct kernfs_ops___272;

struct kernfs_elem_attr___272 {
	const struct kernfs_ops___272 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___273 *notify_next;
};

struct kernfs_node___273 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___273 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___272 dir;
		struct kernfs_elem_symlink___272 symlink;
		struct kernfs_elem_attr___272 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___272;

struct kernfs_ops___272 {
	int (*open)(struct kernfs_open_file___272 *);
	void (*release)(struct kernfs_open_file___272 *);
	int (*seq_show)(struct seq_file___242 *, void *);
	void * (*seq_start)(struct seq_file___242 *, loff_t *);
	void * (*seq_next)(struct seq_file___242 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___242 *, void *);
	ssize_t (*read)(struct kernfs_open_file___272 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___272 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___272 *, struct vm_area_struct___279 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___272 *, struct poll_table_struct___169 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___272 {
	int (*remount_fs)(struct kernfs_root___272 *, int *, char *);
	int (*show_options)(struct seq_file___242 *, struct kernfs_root___272 *);
	int (*mkdir)(struct kernfs_node___273 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___273 *);
	int (*rename)(struct kernfs_node___273 *, struct kernfs_node___273 *, const char *);
	int (*show_path)(struct seq_file___242 *, struct kernfs_node___273 *, struct kernfs_root___272 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___272 {
	struct kernfs_node___273 *kn;
	struct file___278 *file;
	struct seq_file___242 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___267 *vm_ops;
};

struct bin_attribute___242;

struct attribute_group___243 {
	const char *name;
	umode_t (*is_visible)(struct kobject___266 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___266 *, struct bin_attribute___242 *, int);
	struct attribute **attrs;
	struct bin_attribute___242 **bin_attrs;
};

struct bin_attribute___242 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___278 *, struct kobject___266 *, struct bin_attribute___242 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___278 *, struct kobject___266 *, struct bin_attribute___242 *, char *, loff_t, size_t);
	int (*mmap)(struct file___278 *, struct kobject___266 *, struct bin_attribute___242 *, struct vm_area_struct___279 *);
};

struct sysfs_ops___265 {
	ssize_t (*show)(struct kobject___266 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___266 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___265;

struct kset___265 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___266 kobj;
	const struct kset_uevent_ops___265 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___265 {
	void (*release)(struct kobject___266 *);
	const struct sysfs_ops___265 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___25 * (*child_ns_type)(struct kobject___266 *);
	const void * (*namespace)(struct kobject___266 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___265 {
	int (* const filter)(struct kset___265 *, struct kobject___266 *);
	const char * (* const name)(struct kset___265 *, struct kobject___266 *);
	int (* const uevent)(struct kset___265 *, struct kobject___266 *, struct kobj_uevent_env *);
};

struct kobj_attribute___258 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___266 *, struct kobj_attribute___258 *, char *);
	ssize_t (*store)(struct kobject___266 *, struct kobj_attribute___258 *, const char *, size_t);
};

struct dev_pm_ops___241 {
	int (*prepare)(struct device___241 *);
	void (*complete)(struct device___241 *);
	int (*suspend)(struct device___241 *);
	int (*resume)(struct device___241 *);
	int (*freeze)(struct device___241 *);
	int (*thaw)(struct device___241 *);
	int (*poweroff)(struct device___241 *);
	int (*restore)(struct device___241 *);
	int (*suspend_late)(struct device___241 *);
	int (*resume_early)(struct device___241 *);
	int (*freeze_late)(struct device___241 *);
	int (*thaw_early)(struct device___241 *);
	int (*poweroff_late)(struct device___241 *);
	int (*restore_early)(struct device___241 *);
	int (*suspend_noirq)(struct device___241 *);
	int (*resume_noirq)(struct device___241 *);
	int (*freeze_noirq)(struct device___241 *);
	int (*thaw_noirq)(struct device___241 *);
	int (*poweroff_noirq)(struct device___241 *);
	int (*restore_noirq)(struct device___241 *);
	int (*runtime_suspend)(struct device___241 *);
	int (*runtime_resume)(struct device___241 *);
	int (*runtime_idle)(struct device___241 *);
};

struct dev_pm_domain___241 {
	struct dev_pm_ops___241 ops;
	void (*detach)(struct device___241 *, bool);
	int (*activate)(struct device___241 *);
	void (*sync)(struct device___241 *);
	void (*dismiss)(struct device___241 *);
};

struct bus_type___241 {
	const char *name;
	const char *dev_name;
	struct device___241 *dev_root;
	const struct attribute_group___243 **bus_groups;
	const struct attribute_group___243 **dev_groups;
	const struct attribute_group___243 **drv_groups;
	int (*match)(struct device___241 *, struct device_driver___241 *);
	int (*uevent)(struct device___241 *, struct kobj_uevent_env *);
	int (*probe)(struct device___241 *);
	int (*remove)(struct device___241 *);
	void (*shutdown)(struct device___241 *);
	int (*online)(struct device___241 *);
	int (*offline)(struct device___241 *);
	int (*suspend)(struct device___241 *, pm_message_t);
	int (*resume)(struct device___241 *);
	int (*num_vf)(struct device___241 *);
	int (*dma_configure)(struct device___241 *);
	const struct dev_pm_ops___241 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___241 {
	const char *name;
	struct bus_type___241 *bus;
	struct module___225 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___241 *);
	int (*remove)(struct device___241 *);
	void (*shutdown)(struct device___241 *);
	int (*suspend)(struct device___241 *, pm_message_t);
	int (*resume)(struct device___241 *);
	const struct attribute_group___243 **groups;
	const struct dev_pm_ops___241 *pm;
	void (*coredump)(struct device___241 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct fwnode_operations___176;

struct fwnode_handle___176 {
	struct fwnode_handle___176 *secondary;
	const struct fwnode_operations___176 *ops;
};

struct disk_part_tbl___79 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___79 *last_lookup;
	struct hd_struct___79 *part[0];
};

struct block_device_operations___79 {
	int (*open)(struct block_device___277 *, fmode_t);
	void (*release)(struct gendisk___79 *, fmode_t);
	int (*rw_page)(struct block_device___277 *, sector_t, struct page___279 *, unsigned int);
	int (*ioctl)(struct block_device___277 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___277 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___79 *, unsigned int);
	int (*media_changed)(struct gendisk___79 *);
	void (*unlock_native_capacity)(struct gendisk___79 *);
	int (*revalidate_disk)(struct gendisk___79 *);
	int (*getgeo)(struct block_device___277 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___277 *, long unsigned int);
	int (*report_zones)(struct gendisk___79 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___225 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___267(struct page___279 *);

struct bdi_writeback_congested___147 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___147 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bsg_ops___78 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___78 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___78 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___78 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___78(struct request___78 *, blk_status_t);

struct request___78 {
	struct request_queue___78 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___147 *bio;
	struct bio___147 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___147 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___82 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___78 *saved_end_io;
		} flush;
	};
	struct gendisk___79 *rq_disk;
	struct hd_struct___79 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___78 *end_io;
	void *end_io_data;
	struct request___78 *next_rq;
};

struct fwnode_reference_args___176;

struct fwnode_endpoint___176;

struct fwnode_operations___176 {
	struct fwnode_handle___176 * (*get)(struct fwnode_handle___176 *);
	void (*put)(struct fwnode_handle___176 *);
	bool (*device_is_available)(const struct fwnode_handle___176 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___176 *, const struct device___241 *);
	bool (*property_present)(const struct fwnode_handle___176 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___176 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___176 *, const char *, const char **, size_t);
	struct fwnode_handle___176 * (*get_parent)(const struct fwnode_handle___176 *);
	struct fwnode_handle___176 * (*get_next_child_node)(const struct fwnode_handle___176 *, struct fwnode_handle___176 *);
	struct fwnode_handle___176 * (*get_named_child_node)(const struct fwnode_handle___176 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___176 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___176 *);
	struct fwnode_handle___176 * (*graph_get_next_endpoint)(const struct fwnode_handle___176 *, struct fwnode_handle___176 *);
	struct fwnode_handle___176 * (*graph_get_remote_endpoint)(const struct fwnode_handle___176 *);
	struct fwnode_handle___176 * (*graph_get_port_parent)(struct fwnode_handle___176 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___176 *, struct fwnode_endpoint___176 *);
};

struct fwnode_endpoint___176 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___176 *local_fwnode;
};

struct fwnode_reference_args___176 {
	struct fwnode_handle___176 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct elevator_type___78;

struct elevator_mq_ops___78 {
	int (*init_sched)(struct request_queue___78 *, struct elevator_type___78 *);
	void (*exit_sched)(struct elevator_queue___78 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	bool (*allow_merge)(struct request_queue___78 *, struct request___78 *, struct bio___147 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx *, struct bio___147 *);
	int (*request_merge)(struct request_queue___78 *, struct request___78 **, struct bio___147 *);
	void (*request_merged)(struct request_queue___78 *, struct request___78 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___78 *, struct request___78 *, struct request___78 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___78 *, struct bio___147 *);
	void (*finish_request)(struct request___78 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___78 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___78 *, u64);
	void (*started_request)(struct request___78 *);
	void (*requeue_request)(struct request___78 *);
	struct request___78 * (*former_request)(struct request_queue___78 *, struct request___78 *);
	struct request___78 * (*next_request)(struct request_queue___78 *, struct request___78 *);
	void (*init_icq)(struct io_cq___82 *);
	void (*exit_icq)(struct io_cq___82 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx___19 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___78;

struct elevator_type___78 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___78 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___78 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___225 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___78 {
	struct elevator_type___78 *type;
	void *elevator_data;
	struct kobject___266 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___78 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___78 *, char *);
	ssize_t (*store)(struct elevator_queue___78 *, const char *, size_t);
};

struct rq_qos_ops___7;

struct rq_qos___7 {
	struct rq_qos_ops___7 *ops;
	struct request_queue___78 *q;
	enum rq_qos_id id;
	struct rq_qos___7 *next;
};

struct blk_stat_callback___16 {
	struct list_head list;
	struct timer_list timer;
	struct blk_rq_stat *cpu_stat;
	int (*bucket_fn)(const struct request___78 *);
	unsigned int buckets;
	struct blk_rq_stat *stat;
	void (*timer_fn)(struct blk_stat_callback___16 *);
	void *data;
	struct callback_head rcu;
};

typedef int (*key_restrict_link_func_t___264)(struct key___263 *, const struct key_type *, const union key_payload *, struct key___263 *);

struct key_restriction___263;

struct key___263 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___279 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___263 *restrict_link;
};

struct key_restriction___263 {
	key_restrict_link_func_t___264 check;
	struct key___263 *key;
	struct key_type *keytype;
};

struct seq_operations___241 {
	void * (*start)(struct seq_file___242 *, loff_t *);
	void (*stop)(struct seq_file___242 *, void *);
	void * (*next)(struct seq_file___242 *, void *, loff_t *);
	int (*show)(struct seq_file___242 *, void *);
};

struct cgroup_namespace___205 {
	refcount_t count;
	struct ns_common___9 ns;
	struct user_namespace___220 *user_ns;
	struct ucounts___220 *ucounts;
	struct css_set___205 *root_cset;
};

struct ucounts___220 {
	struct hlist_node node;
	struct user_namespace___220 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___206;

struct bpf_map_ops___205 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___206 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___206 *, struct file___278 *);
	void (*map_free)(struct bpf_map___206 *);
	int (*map_get_next_key)(struct bpf_map___206 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___206 *);
	void * (*map_lookup_elem)(struct bpf_map___206 *, void *);
	int (*map_update_elem)(struct bpf_map___206 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___206 *, void *);
	int (*map_push_elem)(struct bpf_map___206 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___206 *, void *);
	int (*map_peek_elem)(struct bpf_map___206 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___206 *, struct file___278 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___206 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___206 *, void *, struct seq_file___242 *);
	int (*map_check_btf)(const struct bpf_map___206 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___206 {
	const struct bpf_map_ops___205 *ops;
	struct bpf_map___206 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___263 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___205;

typedef void (*kthread_work_func_t___205)(struct kthread_work___205 *);

struct kthread_worker___205;

struct kthread_work___205 {
	struct list_head node;
	kthread_work_func_t___205 func;
	struct kthread_worker___205 *worker;
	int canceling;
};

struct kthread_worker___205 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___279 *task;
	struct kthread_work___205 *current_work;
};

struct kthread_delayed_work___205 {
	struct kthread_work___205 work;
	struct timer_list timer;
};

struct psi_group___205 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___205 *poll_kworker;
	struct kthread_delayed_work___205 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___205;

struct cgroup_rstat_cpu___205;

struct cgroup___205 {
	struct cgroup_subsys_state___205 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___273 *kn;
	struct cgroup_file___205 procs_file;
	struct cgroup_file___205 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___205 *subsys[13];
	struct cgroup_root___205 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___205 *dom_cgrp;
	struct cgroup_rstat_cpu___205 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___35 bpf;
	atomic_t congestion_count;
	struct cgroup___205 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___205 psi;
	int ancestor_ids[0];
};

struct cftype___205;

struct cgroup_subsys___205 {
	struct cgroup_subsys_state___205 * (*css_alloc)(struct cgroup_subsys_state___205 *);
	int (*css_online)(struct cgroup_subsys_state___205 *);
	void (*css_offline)(struct cgroup_subsys_state___205 *);
	void (*css_released)(struct cgroup_subsys_state___205 *);
	void (*css_free)(struct cgroup_subsys_state___205 *);
	void (*css_reset)(struct cgroup_subsys_state___205 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___205 *, int);
	int (*css_extra_stat_show)(struct seq_file___242 *, struct cgroup_subsys_state___205 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___279 *);
	void (*cancel_fork)(struct task_struct___279 *);
	void (*fork)(struct task_struct___279 *);
	void (*exit)(struct task_struct___279 *);
	void (*free)(struct task_struct___279 *);
	void (*bind)(struct cgroup_subsys_state___205 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___205 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___205 *dfl_cftypes;
	struct cftype___205 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___205 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___205 *updated_children;
	struct cgroup___205 *updated_next;
};

struct cgroup_root___205 {
	struct kernfs_root___272 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___205 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___205 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___205 *ss;
	struct list_head node;
	struct kernfs_ops___272 *kf_ops;
	int (*open)(struct kernfs_open_file___272 *);
	void (*release)(struct kernfs_open_file___272 *);
	u64 (*read_u64)(struct cgroup_subsys_state___205 *, struct cftype___205 *);
	s64 (*read_s64)(struct cgroup_subsys_state___205 *, struct cftype___205 *);
	int (*seq_show)(struct seq_file___242 *, void *);
	void * (*seq_start)(struct seq_file___242 *, loff_t *);
	void * (*seq_next)(struct seq_file___242 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___242 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___205 *, struct cftype___205 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___205 *, struct cftype___205 *, s64);
	ssize_t (*write)(struct kernfs_open_file___272 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___272 *, struct poll_table_struct___169 *);
};

struct blkcg_policy_data___54;

struct blkcg___54 {
	struct cgroup_subsys_state___205 css;
	spinlock_t lock;
	struct xarray blkg_tree;
	struct blkcg_gq___54 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___54 *cpd[5];
	struct list_head all_blkcgs_node;
	struct list_head cgwb_list;
	refcount_t cgwb_refcnt;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct blkcg_policy_data___54 {
	struct blkcg___54 *blkcg;
	int plid;
};

struct blkg_policy_data___54 {
	struct blkcg_gq___54 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___115 {
	struct mem_cgroup___115 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___115 {
	struct lruvec___278 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___115 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___115 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct node___174 {
	struct device___241 dev;
};

struct rq_qos_ops___7 {
	void (*throttle)(struct rq_qos___7 *, struct bio___147 *);
	void (*track)(struct rq_qos___7 *, struct request___78 *, struct bio___147 *);
	void (*issue)(struct rq_qos___7 *, struct request___78 *);
	void (*requeue)(struct rq_qos___7 *, struct request___78 *);
	void (*done)(struct rq_qos___7 *, struct request___78 *);
	void (*done_bio)(struct rq_qos___7 *, struct bio___147 *);
	void (*cleanup)(struct rq_qos___7 *, struct bio___147 *);
	void (*exit)(struct rq_qos___7 *);
};

enum wbt_flags {
	WBT_TRACKED = 1,
	WBT_READ = 2,
	WBT_KSWAPD = 4,
	WBT_DISCARD = 8,
	WBT_NR_BITS = 4,
};

enum {
	WBT_STATE_ON_DEFAULT = 1,
	WBT_STATE_ON_MANUAL = 2,
};

struct rq_wb {
	unsigned int wb_background;
	unsigned int wb_normal;
	short int enable_state;
	unsigned int unknown_cnt;
	u64 win_nsec;
	u64 cur_win_nsec;
	struct blk_stat_callback___16 *cb;
	u64 sync_issue;
	void *sync_cookie;
	unsigned int wc;
	long unsigned int last_issue;
	long unsigned int last_comp;
	long unsigned int min_lat_nsec;
	struct rq_qos___7 rqos;
	struct rq_wait rq_wait[3];
	struct rq_depth rq_depth;
};

struct kernel_param_ops___222 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___222 *);
	int (*get)(char *, const struct kernel_param___222 *);
	void (*free)(void *);
};

struct kparam_array___222;

struct kernel_param___222 {
	const char *name;
	struct module___225 *mod;
	const struct kernel_param_ops___222 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___222 *arr;
	};
};

struct kparam_array___222 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___222 *ops;
	void *elem;
};

struct module_attribute___222 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___222 *, struct module_kobject___222 *, char *);
	ssize_t (*store)(struct module_attribute___222 *, struct module_kobject___222 *, const char *, size_t);
	void (*setup)(struct module___225 *, const char *);
	int (*test)(struct module___225 *);
	void (*free)(struct module___225 *);
};

struct trace_event_class___123;

struct trace_event_call___123 {
	struct list_head list;
	struct trace_event_class___123 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___13 event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___35 *prog_array;
	int (*perf_perm)(struct trace_event_call___123 *, struct perf_event___130 *);
};

struct perf_cpu_context___130;

struct pmu___130 {
	struct list_head entry;
	struct module___225 *module;
	struct device___241 *dev;
	const struct attribute_group___243 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___130 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___130 *);
	void (*pmu_disable)(struct pmu___130 *);
	int (*event_init)(struct perf_event___130 *);
	void (*event_mapped)(struct perf_event___130 *, struct mm_struct___278 *);
	void (*event_unmapped)(struct perf_event___130 *, struct mm_struct___278 *);
	int (*add)(struct perf_event___130 *, int);
	void (*del)(struct perf_event___130 *, int);
	void (*start)(struct perf_event___130 *, int);
	void (*stop)(struct perf_event___130 *, int);
	void (*read)(struct perf_event___130 *);
	void (*start_txn)(struct pmu___130 *, unsigned int);
	int (*commit_txn)(struct pmu___130 *);
	void (*cancel_txn)(struct pmu___130 *);
	int (*event_idx)(struct perf_event___130 *);
	void (*sched_task)(struct perf_event_context___130 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___130 *);
	int (*filter_match)(struct perf_event___130 *);
	int (*check_period)(struct perf_event___130 *, u64);
};

struct perf_cpu_context___130 {
	struct perf_event_context___130 ctx;
	struct perf_event_context___130 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___130 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___130 {
	struct cgroup_subsys_state___205 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___123 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___123 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___123 *);
	struct list_head * (*get_fields)(struct trace_event_call___123 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___123 *);
};

struct trace_event_file___48;

struct trace_event_buffer___40 {
	struct ring_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___48 *trace_file;
	void *entry;
	long unsigned int flags;
	int pc;
};

struct trace_event_file___48 {
	struct list_head list;
	struct trace_event_call___123 *event_call;
	struct event_filter *filter;
	struct dentry___278 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_wbt_stat {
	struct trace_entry ent;
	char name[32];
	s64 rmean;
	u64 rmin;
	u64 rmax;
	s64 rnr_samples;
	s64 rtime;
	s64 wmean;
	u64 wmin;
	u64 wmax;
	s64 wnr_samples;
	s64 wtime;
	char __data[0];
};

struct trace_event_raw_wbt_lat {
	struct trace_entry ent;
	char name[32];
	long unsigned int lat;
	char __data[0];
};

struct trace_event_raw_wbt_step {
	struct trace_entry ent;
	char name[32];
	const char *msg;
	int step;
	long unsigned int window;
	unsigned int bg;
	unsigned int normal;
	unsigned int max;
	char __data[0];
};

struct trace_event_raw_wbt_timer {
	struct trace_entry ent;
	char name[32];
	unsigned int status;
	int step;
	unsigned int inflight;
	char __data[0];
};

struct trace_event_data_offsets_wbt_stat {};

struct trace_event_data_offsets_wbt_lat {};

struct trace_event_data_offsets_wbt_step {};

struct trace_event_data_offsets_wbt_timer {};

enum {
	RWB_DEF_DEPTH = 16,
	RWB_WINDOW_NSEC = 100000000,
	RWB_MIN_WRITE_SAMPLES = 3,
	RWB_UNKNOWN_BUMP = 5,
};

enum {
	LAT_OK = 1,
	LAT_UNKNOWN = 2,
	LAT_UNKNOWN_WRITES = 3,
	LAT_EXCEEDED = 4,
};

struct wbt_wait_data {
	struct rq_wb *rwb;
	enum wbt_flags wb_acct;
	long unsigned int rw;
};

struct show_busy_params {
	struct seq_file___238 *m;
	struct blk_mq_hw_ctx___14 *hctx;
};

typedef __kernel_long_t __kernel_ptrdiff_t;

typedef __kernel_ptrdiff_t ptrdiff_t;

enum {
	REG_OP_ISFREE = 0,
	REG_OP_ALLOC = 1,
	REG_OP_RELEASE = 2,
};

typedef struct scatterlist *sg_alloc_fn(unsigned int, gfp_t);

typedef void sg_free_fn(struct scatterlist *, unsigned int);

struct sg_page_iter {
	struct scatterlist *sg;
	unsigned int sg_pgoffset;
	unsigned int __nents;
	int __pg_advance;
};

struct sg_dma_page_iter {
	struct sg_page_iter base;
};

struct sg_mapping_iter {
	struct page___278 *page;
	void *addr;
	size_t length;
	size_t consumed;
	struct sg_page_iter piter;
	unsigned int __offset;
	unsigned int __remaining;
	unsigned int __flags;
};

struct flex_array_part {
	char elements[65536];
};

struct file___279;

struct kiocb___279;

struct iov_iter___136;

struct vm_area_struct___280;

struct inode___279;

struct file_lock___279;

struct page___280;

struct pipe_inode_info___67;

struct file_operations___279 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___279 *, loff_t, int);
	ssize_t (*read)(struct file___279 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___279 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___279 *, struct iov_iter___136 *);
	ssize_t (*write_iter)(struct kiocb___279 *, struct iov_iter___136 *);
	int (*iopoll)(struct kiocb___279 *, bool);
	int (*iterate)(struct file___279 *, struct dir_context *);
	int (*iterate_shared)(struct file___279 *, struct dir_context *);
	__poll_t (*poll)(struct file___279 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___279 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___279 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___279 *, struct vm_area_struct___280 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___279 *, struct file___279 *);
	int (*flush)(struct file___279 *, fl_owner_t);
	int (*release)(struct inode___279 *, struct file___279 *);
	int (*fsync)(struct file___279 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___279 *, int);
	int (*lock)(struct file___279 *, int, struct file_lock___279 *);
	ssize_t (*sendpage)(struct file___279 *, struct page___280 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___279 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___279 *, int, struct file_lock___279 *);
	ssize_t (*splice_write)(struct pipe_inode_info___67 *, struct file___279 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___279 *, loff_t *, struct pipe_inode_info___67 *, size_t, unsigned int);
	int (*setlease)(struct file___279 *, long int, struct file_lock___279 **, void **);
	long int (*fallocate)(struct file___279 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___279 *);
	ssize_t (*copy_file_range)(struct file___279 *, loff_t, struct file___279 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___279 *, loff_t, struct file___279 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___279 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio_vec___148 {
	struct page___280 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

typedef struct page___280 *pgtable_t___279;

struct address_space___278;

struct mm_struct___279;

struct dev_pagemap___268;

struct page___280 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___278 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___280 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___279 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___279 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___268 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct vmacache___279 {
	u64 seqnum;
	struct vm_area_struct___280 *vmas[4];
};

struct page_frag___279 {
	struct page___280 *page;
	__u32 offset;
	__u32 size;
};

struct vm_struct___195;

struct task_struct___280 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___280 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___279 *mm;
	struct mm_struct___279 *active_mm;
	struct vmacache___279 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___280 *real_parent;
	struct task_struct___280 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___280 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___193 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___193 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___193 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___2 *ptracer_cred;
	const struct cred___2 *real_cred;
	const struct cred___2 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___280 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___82 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___67 *splice_pipe;
	struct page_frag___279 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___280 *oom_reaper_list;
	struct vm_struct___195 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___130 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pglist_data___279;

struct lruvec___279 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___279 *pgdat;
};

struct zone___279 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___279 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___279 {
	struct zone___279 *zone;
	int zone_idx;
};

struct zonelist___279 {
	struct zoneref___279 _zonerefs[25];
};

struct pglist_data___279 {
	struct zone___279 node_zones[3];
	struct zonelist___279 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___280 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___280 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___279 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___280 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___280 *owner;
};

struct secondary_data___280 {
	void *stack;
	struct task_struct___280 *task;
	long int status;
};

struct blocking_notifier_head___279 {
	struct rw_semaphore___280 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___268;

struct vm_area_struct___280 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___280 *vm_next;
	struct vm_area_struct___280 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___279 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___268 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___279 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___279;

struct mm_struct___279 {
	struct {
		struct vm_area_struct___280 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___279 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___280 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___279 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___280 *owner;
		struct user_namespace___3 *user_ns;
		struct file___279 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___279 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct fasync_struct___278;

struct pipe_buffer___67;

struct pipe_inode_info___67 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___280 *tmp_page;
	struct fasync_struct___278 *fasync_readers;
	struct fasync_struct___278 *fasync_writers;
	struct pipe_buffer___67 *bufs;
	struct user_struct___25 *user;
};

struct vm_struct___195 {
	struct vm_struct___195 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___280 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___278;

struct address_space___278 {
	struct inode___279 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___280 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___278 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___268)(struct vm_area_struct___280 *, long unsigned int, const struct page___280 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___268)(struct page___280 *, void *);

struct dev_pagemap___268 {
	dev_page_fault_t___268 page_fault;
	dev_page_free_t___268 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___6 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct dentry___279;

struct path___279 {
	struct vfsmount *mnt;
	struct dentry___279 *dentry;
};

struct file___279 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___279 f_path;
	struct inode___279 *f_inode;
	const struct file_operations___279 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___193 f_owner;
	const struct cred___2 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___278 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___268;

struct vm_operations_struct___268 {
	void (*open)(struct vm_area_struct___280 *);
	void (*close)(struct vm_area_struct___280 *);
	int (*split)(struct vm_area_struct___280 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___280 *);
	vm_fault_t (*fault)(struct vm_fault___268 *);
	vm_fault_t (*huge_fault)(struct vm_fault___268 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___268 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___280 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___268 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___268 *);
	int (*access)(struct vm_area_struct___280 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___280 *);
	int (*set_policy)(struct vm_area_struct___280 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___280 *, long unsigned int);
	struct page___280 * (*find_special_page)(struct vm_area_struct___280 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___279 {
	struct task_struct___280 *task;
	struct core_thread___279 *next;
};

struct core_state___279 {
	atomic_t nr_threads;
	struct core_thread___279 dumper;
	struct completion startup;
};

struct vm_fault___268 {
	struct vm_area_struct___280 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___280 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___280 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___279 prealloc_pte;
};

struct iov_iter___136 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___148 *bvec;
		struct pipe_inode_info___67 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct dentry_operations___278;

struct super_block___278;

struct dentry___279 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___279 *d_parent;
	struct qstr d_name;
	struct inode___279 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___278 *d_op;
	struct super_block___278 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___278;

struct block_device___278;

struct inode___279 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___278 *i_op;
	struct super_block___278 *i_sb;
	struct address_space___278 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___280 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___279 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___278 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___67 *i_pipe;
		struct block_device___278 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___278 {
	int (*d_revalidate)(struct dentry___279 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___279 *, unsigned int);
	int (*d_hash)(const struct dentry___279 *, struct qstr *);
	int (*d_compare)(const struct dentry___279 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___279 *);
	int (*d_init)(struct dentry___279 *);
	void (*d_release)(struct dentry___279 *);
	void (*d_prune)(struct dentry___279 *);
	void (*d_iput)(struct dentry___279 *, struct inode___279 *);
	char * (*d_dname)(struct dentry___279 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___279 *);
	int (*d_manage)(const struct path___279 *, bool);
	struct dentry___279 * (*d_real)(struct dentry___279 *, const struct inode___279 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___278;

struct mem_dqinfo___278 {
	struct quota_format_type___278 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___278;

struct quota_info___278 {
	unsigned int flags;
	struct rw_semaphore___280 dqio_sem;
	struct inode___279 *files[3];
	struct mem_dqinfo___278 info[3];
	const struct quota_format_ops___278 *ops[3];
};

struct rcuwait___278 {
	struct task_struct___280 *task;
};

struct percpu_rw_semaphore___278 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___280 rw_sem;
	struct rcuwait___278 writer;
	int readers_block;
};

struct sb_writers___278 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___278 rw_sem[3];
};

struct file_system_type___278;

struct super_operations___278;

struct dquot_operations___278;

struct quotactl_ops___278;

struct super_block___278 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___278 *s_type;
	const struct super_operations___278 *s_op;
	const struct dquot_operations___278 *dq_op;
	const struct quotactl_ops___278 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___279 *s_root;
	struct rw_semaphore___280 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___278 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___278 s_dquot;
	struct sb_writers___278 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___278 *s_d_op;
	int cleancache_poolid;
	struct shrinker___115 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___279 {
	struct file___279 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___279 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___278 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___279 *ia_file;
};

struct dquot___278 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___278 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___278 {
	int qf_fmt_id;
	const struct quota_format_ops___278 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___278 *qf_next;
};

struct quota_format_ops___278 {
	int (*check_quota_file)(struct super_block___278 *, int);
	int (*read_file_info)(struct super_block___278 *, int);
	int (*write_file_info)(struct super_block___278 *, int);
	int (*free_file_info)(struct super_block___278 *, int);
	int (*read_dqblk)(struct dquot___278 *);
	int (*commit_dqblk)(struct dquot___278 *);
	int (*release_dqblk)(struct dquot___278 *);
	int (*get_next_id)(struct super_block___278 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___278 {
	int (*write_dquot)(struct dquot___278 *);
	struct dquot___278 * (*alloc_dquot)(struct super_block___278 *, int);
	void (*destroy_dquot)(struct dquot___278 *);
	int (*acquire_dquot)(struct dquot___278 *);
	int (*release_dquot)(struct dquot___278 *);
	int (*mark_dirty)(struct dquot___278 *);
	int (*write_info)(struct super_block___278 *, int);
	qsize_t * (*get_reserved_space)(struct inode___279 *);
	int (*get_projid)(struct inode___279 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___279 *, qsize_t *);
	int (*get_next_id)(struct super_block___278 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___278 {
	int (*quota_on)(struct super_block___278 *, int, int, const struct path___279 *);
	int (*quota_off)(struct super_block___278 *, int);
	int (*quota_enable)(struct super_block___278 *, unsigned int);
	int (*quota_disable)(struct super_block___278 *, unsigned int);
	int (*quota_sync)(struct super_block___278 *, int);
	int (*set_info)(struct super_block___278 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___278 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___278 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___278 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___278 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___278 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___278 {
	int (*writepage)(struct page___280 *, struct writeback_control___3 *);
	int (*readpage)(struct file___279 *, struct page___280 *);
	int (*writepages)(struct address_space___278 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___280 *);
	int (*readpages)(struct file___279 *, struct address_space___278 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___279 *, struct address_space___278 *, loff_t, unsigned int, unsigned int, struct page___280 **, void **);
	int (*write_end)(struct file___279 *, struct address_space___278 *, loff_t, unsigned int, unsigned int, struct page___280 *, void *);
	sector_t (*bmap)(struct address_space___278 *, sector_t);
	void (*invalidatepage)(struct page___280 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___280 *, gfp_t);
	void (*freepage)(struct page___280 *);
	ssize_t (*direct_IO)(struct kiocb___279 *, struct iov_iter___136 *);
	int (*migratepage)(struct address_space___278 *, struct page___280 *, struct page___280 *, enum migrate_mode);
	bool (*isolate_page)(struct page___280 *, isolate_mode_t);
	void (*putback_page)(struct page___280 *);
	int (*launder_page)(struct page___280 *);
	int (*is_partially_uptodate)(struct page___280 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___280 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___278 *, struct page___280 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___279 *, sector_t *);
	void (*swap_deactivate)(struct file___279 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___278 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___279 *bd_inode;
	struct super_block___278 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___278 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___278 {
	struct dentry___279 * (*lookup)(struct inode___279 *, struct dentry___279 *, unsigned int);
	const char * (*get_link)(struct dentry___279 *, struct inode___279 *, struct delayed_call *);
	int (*permission)(struct inode___279 *, int);
	struct posix_acl * (*get_acl)(struct inode___279 *, int);
	int (*readlink)(struct dentry___279 *, char *, int);
	int (*create)(struct inode___279 *, struct dentry___279 *, umode_t, bool);
	int (*link)(struct dentry___279 *, struct inode___279 *, struct dentry___279 *);
	int (*unlink)(struct inode___279 *, struct dentry___279 *);
	int (*symlink)(struct inode___279 *, struct dentry___279 *, const char *);
	int (*mkdir)(struct inode___279 *, struct dentry___279 *, umode_t);
	int (*rmdir)(struct inode___279 *, struct dentry___279 *);
	int (*mknod)(struct inode___279 *, struct dentry___279 *, umode_t, dev_t);
	int (*rename)(struct inode___279 *, struct dentry___279 *, struct inode___279 *, struct dentry___279 *, unsigned int);
	int (*setattr)(struct dentry___279 *, struct iattr___278 *);
	int (*getattr)(const struct path___279 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___279 *, char *, size_t);
	int (*fiemap)(struct inode___279 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___279 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___279 *, struct dentry___279 *, struct file___279 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___279 *, struct dentry___279 *, umode_t);
	int (*set_acl)(struct inode___279 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___278 {
	void (*fl_copy_lock)(struct file_lock___279 *, struct file_lock___279 *);
	void (*fl_release_private)(struct file_lock___279 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___278;

struct file_lock___279 {
	struct file_lock___279 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___279 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___278 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___278 *fl_ops;
	const struct lock_manager_operations___278 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___278 {
	int (*lm_compare_owner)(struct file_lock___279 *, struct file_lock___279 *);
	long unsigned int (*lm_owner_key)(struct file_lock___279 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___279 *);
	int (*lm_grant)(struct file_lock___279 *, int);
	bool (*lm_break)(struct file_lock___279 *);
	int (*lm_change)(struct file_lock___279 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___279 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___278 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___278 *fa_next;
	struct file___279 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___278 {
	const char *name;
	int fs_flags;
	struct dentry___279 * (*mount)(struct file_system_type___278 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___278 *);
	struct module___11 *owner;
	struct file_system_type___278 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___278 {
	struct inode___279 * (*alloc_inode)(struct super_block___278 *);
	void (*destroy_inode)(struct inode___279 *);
	void (*dirty_inode)(struct inode___279 *, int);
	int (*write_inode)(struct inode___279 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___279 *);
	void (*evict_inode)(struct inode___279 *);
	void (*put_super)(struct super_block___278 *);
	int (*sync_fs)(struct super_block___278 *, int);
	int (*freeze_super)(struct super_block___278 *);
	int (*freeze_fs)(struct super_block___278 *);
	int (*thaw_super)(struct super_block___278 *);
	int (*unfreeze_fs)(struct super_block___278 *);
	int (*statfs)(struct dentry___279 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___278 *, int *, char *);
	void (*umount_begin)(struct super_block___278 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___279 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___279 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___279 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___279 *);
	ssize_t (*quota_read)(struct super_block___278 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___278 *, int, const char *, size_t, loff_t);
	struct dquot___278 ** (*get_dquots)(struct inode___279 *);
	int (*bdev_try_to_free_page)(struct super_block___278 *, struct page___280 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___278 *, struct shrink_control___115 *);
	long int (*free_cached_objects)(struct super_block___278 *, struct shrink_control___115 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___268(struct page___280 *);

struct pipe_buf_operations___67;

struct pipe_buffer___67 {
	struct page___280 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___67 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___67 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___67 *, struct pipe_buffer___67 *);
	void (*release)(struct pipe_inode_info___67 *, struct pipe_buffer___67 *);
	int (*steal)(struct pipe_inode_info___67 *, struct pipe_buffer___67 *);
	union {
		bool (*get)(struct pipe_inode_info___67 *, struct pipe_buffer___67 *);
		struct {
			void (*get)(struct pipe_inode_info___67 *, struct pipe_buffer___67 *);
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
};

struct rhashtable_walker {
	struct list_head list;
	struct bucket_table *tbl;
};

struct rhashtable_iter {
	struct rhashtable *ht;
	struct rhash_head *p;
	struct rhlist_head *list;
	struct rhashtable_walker walker;
	unsigned int slot;
	unsigned int skip;
	bool end_of_table;
};

union nested_table {
	union nested_table *table;
	struct rhash_head *bucket;
};

struct reciprocal_value_adv {
	u32 m;
	u8 sh;
	u8 exp;
	bool is_wide_m;
};

struct once_work {
	struct work_struct work;
	struct static_key_true *key;
};

struct test_fail {
	const char *str;
	unsigned int base;
};

struct test_s8 {
	const char *str;
	unsigned int base;
	s8 expected_res;
};

struct test_u8 {
	const char *str;
	unsigned int base;
	u8 expected_res;
};

struct test_s16 {
	const char *str;
	unsigned int base;
	s16 expected_res;
};

struct test_u16 {
	const char *str;
	unsigned int base;
	u16 expected_res;
};

struct test_s32 {
	const char *str;
	unsigned int base;
	s32 expected_res;
};

struct test_u32 {
	const char *str;
	unsigned int base;
	u32 expected_res;
};

struct test_s64 {
	const char *str;
	unsigned int base;
	s64 expected_res;
};

struct test_u64 {
	const char *str;
	unsigned int base;
	u64 expected_res;
};

struct test_ll {
	const char *str;
	unsigned int base;
	long long int expected_res;
};

struct test_ull {
	const char *str;
	unsigned int base;
	long long unsigned int expected_res;
};

struct pci_bus___3;

struct pci_slot___3 {
	struct pci_bus___3 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject___63 kobj;
};

struct pci_dev___3;

struct pci_ops___3;

struct pci_bus___3 {
	struct list_head node;
	struct pci_bus___3 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___3 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___3 *ops;
	struct msi_controller___2 *msi;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	int domain_nr;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___60 *bridge;
	struct device___60 dev;
	struct bin_attribute___60 *legacy_io;
	struct bin_attribute___60 *legacy_mem;
	unsigned int is_added: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
};

struct pci_driver___3;

struct pci_dev___3 {
	struct list_head bus_list;
	struct pci_bus___3 *bus;
	struct pci_bus___3 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___3 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u16 aer_cap;
	struct aer_stats *aer_stats;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	long unsigned int *dma_alias_mask;
	struct pci_driver___3 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	unsigned int imm_ready: 1;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int bridge_d3: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int hotplug_user_indicators: 1;
	unsigned int clear_retrain_link: 1;
	unsigned int d3_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	unsigned int ltr_path: 1;
	unsigned int eetlp_prefix_path: 1;
	pci_channel_state_t error_state;
	struct device___60 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int multifunction: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int ats_enabled: 1;
	unsigned int pasid_enabled: 1;
	unsigned int pri_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int reset_fn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int shpc_managed: 1;
	unsigned int is_thunderbolt: 1;
	unsigned int __aer_firmware_first_valid: 1;
	unsigned int __aer_firmware_first: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int irq_managed: 1;
	unsigned int has_secondary_link: 1;
	unsigned int non_compliant_bars: 1;
	unsigned int is_probed: 1;
	unsigned int link_active_reporting: 1;
	unsigned int untrusted: 1;
	unsigned int no_vf_scan: 1;
	unsigned int io_window: 1;
	unsigned int pref_window: 1;
	unsigned int pref_64_window: 1;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	struct bin_attribute___60 *rom_attr;
	int rom_attr_enabled;
	struct bin_attribute___60 *res_attr[17];
	struct bin_attribute___60 *res_attr_wc[17];
	unsigned int broken_cmd_compl: 1;
	const struct attribute_group___60 **msi_irq_groups;
	struct pci_vpd *vpd;
	union {
		struct pci_sriov *sriov;
		struct pci_dev___3 *physfn;
	};
	u16 ats_cap;
	u8 ats_stu;
	atomic_t ats_ref_cnt;
	u32 pri_reqs_alloc;
	u16 pasid_features;
	struct pci_p2pdma *p2pdma;
	phys_addr_t rom;
	size_t romlen;
	char *driver_override;
	long unsigned int priv_flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t pci_dev_extended_size_rh;
	struct pci_dev_extended_rh pci_dev_extended_rh;
};

struct pci_error_handlers___3;

struct pci_driver___3 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___3 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___3 *);
	int (*suspend)(struct pci_dev___3 *, pm_message_t);
	int (*suspend_late)(struct pci_dev___3 *, pm_message_t);
	int (*resume_early)(struct pci_dev___3 *);
	int (*resume)(struct pci_dev___3 *);
	void (*shutdown)(struct pci_dev___3 *);
	int (*sriov_configure)(struct pci_dev___3 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	const struct pci_error_handlers___3 *err_handler;
	const struct attribute_group___60 **groups;
	struct device_driver___60 driver;
	struct pci_dynids dynids;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct pci_ops___3 {
	int (*add_bus)(struct pci_bus___3 *);
	void (*remove_bus)(struct pci_bus___3 *);
	void * (*map_bus)(struct pci_bus___3 *, unsigned int, int);
	int (*read)(struct pci_bus___3 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___3 *, unsigned int, int, int, u32);
};

struct pci_error_handlers___3 {
	pci_ers_result_t (*error_detected)(struct pci_dev___3 *, enum pci_channel_state);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___3 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___3 *);
	void (*reset_prepare)(struct pci_dev___3 *);
	void (*reset_done)(struct pci_dev___3 *);
	void (*resume)(struct pci_dev___3 *);
};

typedef void (*dr_release_t___6)(struct device___60 *, void *);

enum devm_ioremap_type {
	DEVM_IOREMAP = 0,
	DEVM_IOREMAP_NC = 1,
	DEVM_IOREMAP_WC = 2,
};

struct pcim_iomap_devres {
	void *table[6];
};

enum {
	LOGIC_PIO_INDIRECT = 0,
	LOGIC_PIO_CPU_MMIO = 1,
};

struct logic_pio_host_ops;

struct logic_pio_hwaddr {
	struct list_head list;
	struct fwnode_handle___176 *fwnode;
	resource_size_t hw_start;
	resource_size_t io_start;
	resource_size_t size;
	long unsigned int flags;
	void *hostdata;
	const struct logic_pio_host_ops *ops;
};

struct logic_pio_host_ops {
	u32 (*in)(void *, long unsigned int, size_t);
	void (*out)(void *, long unsigned int, u32, size_t);
	u32 (*ins)(void *, long unsigned int, void *, size_t, unsigned int);
	void (*outs)(void *, long unsigned int, const void *, size_t, unsigned int);
};

struct btree_head {
	long unsigned int *node;
	mempool_t *mempool;
	int height;
};

struct btree_geo {
	int keylen;
	int no_pairs;
	int no_longs;
};

typedef void (*visitor128_t)(void *, long unsigned int, u64, u64, size_t);

typedef void (*visitorl_t)(void *, long unsigned int, long unsigned int, size_t);

typedef void (*visitor32_t)(void *, long unsigned int, u32, size_t);

typedef void (*visitor64_t)(void *, long unsigned int, u64, size_t);

struct interval_tree_node {
	struct rb_node rb;
	long unsigned int start;
	long unsigned int last;
	long unsigned int __subtree_last;
};

enum assoc_array_walk_status {
	assoc_array_walk_tree_empty = 0,
	assoc_array_walk_found_terminal_node = 1,
	assoc_array_walk_found_wrong_shortcut = 2,
};

struct assoc_array_walk_result {
	struct {
		struct assoc_array_node *node;
		int level;
		int slot;
	} terminal_node;
	struct {
		struct assoc_array_shortcut *shortcut;
		int level;
		int sc_level;
		long unsigned int sc_segments;
		long unsigned int dissimilarity;
	} wrong_shortcut;
};

struct assoc_array_delete_collapse_context {
	struct assoc_array_node *node;
	const void *skip_leaf;
	int slot;
};

struct gen_pool_chunk {
	struct list_head next_chunk;
	atomic_long_t avail;
	phys_addr_t phys_addr;
	void *owner;
	long unsigned int start_addr;
	long unsigned int end_addr;
	long unsigned int bits[0];
};

struct genpool_data_align {
	int align;
};

struct genpool_data_fixed {
	long unsigned int offset;
};

typedef void (*dr_release_t___7)(struct device___239 *, void *);

typedef struct z_stream_s z_stream;

typedef z_stream *z_streamp;

typedef struct {
	unsigned char op;
	unsigned char bits;
	short unsigned int val;
} code;

typedef enum {
	HEAD = 0,
	FLAGS = 1,
	TIME = 2,
	OS = 3,
	EXLEN = 4,
	EXTRA = 5,
	NAME = 6,
	COMMENT = 7,
	HCRC = 8,
	DICTID = 9,
	DICT = 10,
	TYPE = 11,
	TYPEDO = 12,
	STORED = 13,
	COPY = 14,
	TABLE = 15,
	LENLENS = 16,
	CODELENS = 17,
	LEN = 18,
	LENEXT = 19,
	DIST = 20,
	DISTEXT = 21,
	MATCH = 22,
	LIT = 23,
	CHECK = 24,
	LENGTH = 25,
	DONE = 26,
	BAD = 27,
	MEM = 28,
	SYNC = 29,
} inflate_mode;

struct inflate_state {
	inflate_mode mode;
	int last;
	int wrap;
	int havedict;
	int flags;
	unsigned int dmax;
	long unsigned int check;
	long unsigned int total;
	unsigned int wbits;
	unsigned int wsize;
	unsigned int whave;
	unsigned int write;
	unsigned char *window;
	long unsigned int hold;
	unsigned int bits;
	unsigned int length;
	unsigned int offset;
	unsigned int extra;
	const code *lencode;
	const code *distcode;
	unsigned int lenbits;
	unsigned int distbits;
	unsigned int ncode;
	unsigned int nlen;
	unsigned int ndist;
	unsigned int have;
	code *next;
	short unsigned int lens[320];
	short unsigned int work[288];
	code codes[2048];
};

union uu {
	short unsigned int us;
	unsigned char b[2];
};

typedef unsigned int uInt;

struct inflate_workspace {
	struct inflate_state inflate_state;
	unsigned char working_window[32768];
};

typedef enum {
	CODES = 0,
	LENS = 1,
	DISTS = 2,
} codetype;

typedef unsigned char uch;

typedef short unsigned int ush;

typedef long unsigned int ulg;

struct ct_data_s {
	union {
		ush freq;
		ush code;
	} fc;
	union {
		ush dad;
		ush len;
	} dl;
};

typedef struct ct_data_s ct_data;

struct static_tree_desc_s {
	const ct_data *static_tree;
	const int *extra_bits;
	int extra_base;
	int elems;
	int max_length;
};

typedef struct static_tree_desc_s static_tree_desc;

struct tree_desc_s {
	ct_data *dyn_tree;
	int max_code;
	static_tree_desc *stat_desc;
};

typedef ush Pos;

typedef unsigned int IPos;

struct deflate_state {
	z_streamp strm;
	int status;
	Byte *pending_buf;
	ulg pending_buf_size;
	Byte *pending_out;
	int pending;
	int noheader;
	Byte data_type;
	Byte method;
	int last_flush;
	uInt w_size;
	uInt w_bits;
	uInt w_mask;
	Byte *window;
	ulg window_size;
	Pos *prev;
	Pos *head;
	uInt ins_h;
	uInt hash_size;
	uInt hash_bits;
	uInt hash_mask;
	uInt hash_shift;
	long int block_start;
	uInt match_length;
	IPos prev_match;
	int match_available;
	uInt strstart;
	uInt match_start;
	uInt lookahead;
	uInt prev_length;
	uInt max_chain_length;
	uInt max_lazy_match;
	int level;
	int strategy;
	uInt good_match;
	int nice_match;
	struct ct_data_s dyn_ltree[573];
	struct ct_data_s dyn_dtree[61];
	struct ct_data_s bl_tree[39];
	struct tree_desc_s l_desc;
	struct tree_desc_s d_desc;
	struct tree_desc_s bl_desc;
	ush bl_count[16];
	int heap[573];
	int heap_len;
	int heap_max;
	uch depth[573];
	uch *l_buf;
	uInt lit_bufsize;
	uInt last_lit;
	ush *d_buf;
	ulg opt_len;
	ulg static_len;
	ulg compressed_len;
	uInt matches;
	int last_eob_len;
	ush bi_buf;
	int bi_valid;
};

typedef struct deflate_state deflate_state;

struct deflate_workspace {
	deflate_state deflate_memory;
	Byte *window_memory;
	Pos *prev_memory;
	Pos *head_memory;
	char *overlay_memory;
};

typedef struct deflate_workspace deflate_workspace;

typedef enum {
	need_more = 0,
	block_done = 1,
	finish_started = 2,
	finish_done = 3,
} block_state;

typedef block_state (*compress_func)(deflate_state *, int);

struct config_s {
	ush good_length;
	ush max_lazy;
	ush nice_length;
	ush max_chain;
	compress_func func;
};

typedef struct config_s config;

typedef struct tree_desc_s tree_desc;

typedef struct {
	const uint8_t *externalDict;
	size_t extDictSize;
	const uint8_t *prefixEnd;
	size_t prefixSize;
} LZ4_streamDecode_t_internal;

typedef union {
	long long unsigned int table[4];
	LZ4_streamDecode_t_internal internal_donotuse;
} LZ4_streamDecode_t;

typedef uint8_t BYTE;

typedef uint16_t U16;

typedef uint32_t U32;

typedef uint64_t U64;

enum {
	noDict = 0,
	withPrefix64k = 1,
	usingExtDict = 2,
};

enum {
	endOnOutputSize = 0,
	endOnInputSize = 1,
};

enum {
	full = 0,
	partial = 1,
};

enum xz_mode {
	XZ_SINGLE = 0,
	XZ_PREALLOC = 1,
	XZ_DYNALLOC = 2,
};

enum xz_ret {
	XZ_OK = 0,
	XZ_STREAM_END = 1,
	XZ_UNSUPPORTED_CHECK = 2,
	XZ_MEM_ERROR = 3,
	XZ_MEMLIMIT_ERROR = 4,
	XZ_FORMAT_ERROR = 5,
	XZ_OPTIONS_ERROR = 6,
	XZ_DATA_ERROR = 7,
	XZ_BUF_ERROR = 8,
};

struct xz_buf {
	const uint8_t *in;
	size_t in_pos;
	size_t in_size;
	uint8_t *out;
	size_t out_pos;
	size_t out_size;
};

typedef uint64_t vli_type;

enum xz_check {
	XZ_CHECK_NONE = 0,
	XZ_CHECK_CRC32 = 1,
	XZ_CHECK_CRC64 = 4,
	XZ_CHECK_SHA256 = 10,
};

struct xz_dec_hash {
	vli_type unpadded;
	vli_type uncompressed;
	uint32_t crc32;
};

struct xz_dec_lzma2;

struct xz_dec_bcj;

struct xz_dec {
	enum {
		SEQ_STREAM_HEADER = 0,
		SEQ_BLOCK_START = 1,
		SEQ_BLOCK_HEADER = 2,
		SEQ_BLOCK_UNCOMPRESS = 3,
		SEQ_BLOCK_PADDING = 4,
		SEQ_BLOCK_CHECK = 5,
		SEQ_INDEX = 6,
		SEQ_INDEX_PADDING = 7,
		SEQ_INDEX_CRC32 = 8,
		SEQ_STREAM_FOOTER = 9,
	} sequence;
	uint32_t pos;
	vli_type vli;
	size_t in_start;
	size_t out_start;
	uint32_t crc32;
	enum xz_check check_type;
	enum xz_mode mode;
	bool allow_buf_error;
	struct {
		vli_type compressed;
		vli_type uncompressed;
		uint32_t size;
	} block_header;
	struct {
		vli_type compressed;
		vli_type uncompressed;
		vli_type count;
		struct xz_dec_hash hash;
	} block;
	struct {
		enum {
			SEQ_INDEX_COUNT = 0,
			SEQ_INDEX_UNPADDED = 1,
			SEQ_INDEX_UNCOMPRESSED = 2,
		} sequence;
		vli_type size;
		vli_type count;
		struct xz_dec_hash hash;
	} index;
	struct {
		size_t pos;
		size_t size;
		uint8_t buf[1024];
	} temp;
	struct xz_dec_lzma2 *lzma2;
	struct xz_dec_bcj *bcj;
	bool bcj_active;
};

enum lzma_state {
	STATE_LIT_LIT = 0,
	STATE_MATCH_LIT_LIT = 1,
	STATE_REP_LIT_LIT = 2,
	STATE_SHORTREP_LIT_LIT = 3,
	STATE_MATCH_LIT = 4,
	STATE_REP_LIT = 5,
	STATE_SHORTREP_LIT = 6,
	STATE_LIT_MATCH = 7,
	STATE_LIT_LONGREP = 8,
	STATE_LIT_SHORTREP = 9,
	STATE_NONLIT_MATCH = 10,
	STATE_NONLIT_REP = 11,
};

struct dictionary {
	uint8_t *buf;
	size_t start;
	size_t pos;
	size_t full;
	size_t limit;
	size_t end;
	uint32_t size;
	uint32_t size_max;
	uint32_t allocated;
	enum xz_mode mode;
};

struct rc_dec {
	uint32_t range;
	uint32_t code;
	uint32_t init_bytes_left;
	const uint8_t *in;
	size_t in_pos;
	size_t in_limit;
};

struct lzma_len_dec {
	uint16_t choice;
	uint16_t choice2;
	uint16_t low[128];
	uint16_t mid[128];
	uint16_t high[256];
};

struct lzma_dec {
	uint32_t rep0;
	uint32_t rep1;
	uint32_t rep2;
	uint32_t rep3;
	enum lzma_state state;
	uint32_t len;
	uint32_t lc;
	uint32_t literal_pos_mask;
	uint32_t pos_mask;
	uint16_t is_match[192];
	uint16_t is_rep[12];
	uint16_t is_rep0[12];
	uint16_t is_rep1[12];
	uint16_t is_rep2[12];
	uint16_t is_rep0_long[192];
	uint16_t dist_slot[256];
	uint16_t dist_special[114];
	uint16_t dist_align[16];
	struct lzma_len_dec match_len_dec;
	struct lzma_len_dec rep_len_dec;
	uint16_t literal[12288];
};

enum lzma2_seq {
	SEQ_CONTROL = 0,
	SEQ_UNCOMPRESSED_1 = 1,
	SEQ_UNCOMPRESSED_2 = 2,
	SEQ_COMPRESSED_0 = 3,
	SEQ_COMPRESSED_1 = 4,
	SEQ_PROPERTIES = 5,
	SEQ_LZMA_PREPARE = 6,
	SEQ_LZMA_RUN = 7,
	SEQ_COPY = 8,
};

struct lzma2_dec {
	enum lzma2_seq sequence;
	enum lzma2_seq next_sequence;
	uint32_t uncompressed;
	uint32_t compressed;
	bool need_dict_reset;
	bool need_props;
};

struct xz_dec_lzma2___2 {
	struct rc_dec rc;
	struct dictionary dict;
	struct lzma2_dec lzma2;
	struct lzma_dec lzma;
	struct {
		uint32_t size;
		uint8_t buf[63];
	} temp;
};

struct xz_dec_bcj___2 {
	enum {
		BCJ_X86 = 4,
		BCJ_POWERPC = 5,
		BCJ_IA64 = 6,
		BCJ_ARM = 7,
		BCJ_ARMTHUMB = 8,
		BCJ_SPARC = 9,
	} type;
	enum xz_ret ret;
	bool single_call;
	uint32_t pos;
	uint32_t x86_prev_mask;
	uint8_t *out;
	size_t out_pos;
	size_t out_size;
	struct {
		size_t filtered;
		size_t size;
		uint8_t buf[16];
	} temp;
};

struct ts_state {
	unsigned int offset;
	char cb[40];
};

struct ts_config;

struct ts_ops {
	const char *name;
	struct ts_config * (*init)(const void *, unsigned int, gfp_t, int);
	unsigned int (*find)(struct ts_config *, struct ts_state *);
	void (*destroy)(struct ts_config *);
	void * (*get_pattern)(struct ts_config *);
	unsigned int (*get_pattern_len)(struct ts_config *);
	struct module___97 *owner;
	struct list_head list;
};

struct ts_config {
	struct ts_ops *ops;
	int flags;
	unsigned int (*get_next_block)(unsigned int, const u8 **, struct ts_config *, struct ts_state *);
	void (*finish)(struct ts_config *, struct ts_state *);
};

struct ts_linear_state {
	unsigned int len;
	const void *data;
};

struct ddebug_table {
	struct list_head link;
	const char *mod_name;
	unsigned int num_ddebugs;
	struct _ddebug *ddebugs;
};

struct ddebug_query {
	const char *filename;
	const char *module;
	const char *function;
	const char *format;
	unsigned int first_lineno;
	unsigned int last_lineno;
};

struct ddebug_iter {
	struct ddebug_table *table;
	unsigned int idx;
};

struct nla_bitfield32 {
	__u32 value;
	__u32 selector;
};

struct cpu_rmap___2 {
	struct kref refcount;
	u16 size;
	u16 used;
	void **obj;
	struct {
		u16 index;
		u16 dist;
	} near[0];
};

struct irq_glue {
	struct irq_affinity_notify notify;
	struct cpu_rmap___2 *rmap;
	u16 index;
};

typedef mpi_limb_t *mpi_ptr_t;

typedef int mpi_size_t;

typedef mpi_limb_t UWtype;

typedef unsigned int UHWtype;

struct sg_mapping_iter___2 {
	struct page___124 *page;
	void *addr;
	size_t length;
	size_t consumed;
	struct sg_page_iter piter;
	unsigned int __offset;
	unsigned int __remaining;
	unsigned int __flags;
};

struct karatsuba_ctx {
	struct karatsuba_ctx *next;
	mpi_ptr_t tspace;
	mpi_size_t tspace_size;
	mpi_ptr_t tp;
	mpi_size_t tp_size;
};

typedef long int mpi_limb_signed_t;

struct sg_pool {
	size_t size;
	char *name;
	struct kmem_cache *slab;
	mempool_t *pool;
};

enum {
	IRQ_POLL_F_SCHED = 0,
	IRQ_POLL_F_DISABLE = 1,
};

struct font_desc {
	int idx;
	const char *name;
	int width;
	int height;
	const void *data;
	int pref;
};

typedef u16 ucs2_char_t;

typedef void (*poll_queue_proc___172)(struct file___12 *, wait_queue_head_t *, struct poll_table_struct___12 *);

typedef int (*acpi_tbl_table_handler)(struct acpi_table_header *);

typedef int (*acpi_tbl_entry_handler)(struct acpi_subtable_header *, const long unsigned int);

struct acpi_probe_entry;

typedef bool (*acpi_probe_entry_validate_subtbl)(struct acpi_subtable_header *, struct acpi_probe_entry *);

struct acpi_probe_entry {
	__u8 id[5];
	__u8 type;
	acpi_probe_entry_validate_subtbl subtable_valid;
	union {
		acpi_tbl_table_handler probe_table;
		acpi_tbl_entry_handler probe_subtbl;
	};
	kernel_ulong_t driver_data;
};

struct module___226;

struct file___280;

struct kiocb___280;

struct poll_table_struct___170;

struct vm_area_struct___281;

struct inode___280;

struct file_lock___280;

struct page___281;

struct seq_file___243;

struct file_operations___280 {
	struct module___226 *owner;
	loff_t (*llseek)(struct file___280 *, loff_t, int);
	ssize_t (*read)(struct file___280 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___280 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___280 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___280 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___280 *, bool);
	int (*iterate)(struct file___280 *, struct dir_context *);
	int (*iterate_shared)(struct file___280 *, struct dir_context *);
	__poll_t (*poll)(struct file___280 *, struct poll_table_struct___170 *);
	long int (*unlocked_ioctl)(struct file___280 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___280 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___280 *, struct vm_area_struct___281 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___280 *, struct file___280 *);
	int (*flush)(struct file___280 *, fl_owner_t);
	int (*release)(struct inode___280 *, struct file___280 *);
	int (*fsync)(struct file___280 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___280 *, int);
	int (*lock)(struct file___280 *, int, struct file_lock___280 *);
	ssize_t (*sendpage)(struct file___280 *, struct page___281 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___280 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___280 *, int, struct file_lock___280 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___280 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___280 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___280 *, long int, struct file_lock___280 **, void **);
	long int (*fallocate)(struct file___280 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___243 *, struct file___280 *);
	ssize_t (*copy_file_range)(struct file___280 *, loff_t, struct file___280 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___280 *, loff_t, struct file___280 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___280 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___280 {
	u64 seqnum;
	struct vm_area_struct___281 *vmas[4];
};

struct page_frag___280 {
	struct page___281 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___280;

struct cred___264;

struct vm_struct___196;

struct task_struct___281 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___281 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___280 *mm;
	struct mm_struct___280 *active_mm;
	struct vmacache___280 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___281 *real_parent;
	struct task_struct___281 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___281 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___193 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___193 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___193 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___264 *ptracer_cred;
	const struct cred___264 *real_cred;
	const struct cred___264 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___281 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___82 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___280 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___281 *oom_reaper_list;
	struct vm_struct___196 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___130 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___281 *pgtable_t___280;

struct address_space___279;

struct dev_pagemap___269;

struct page___281 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___279 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___281 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___280 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___280 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___269 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___280;

struct lruvec___280 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___280 *pgdat;
};

struct zone___280 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___280 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___280 {
	struct zone___280 *zone;
	int zone_idx;
};

struct zonelist___280 {
	struct zoneref___280 _zonerefs[25];
};

struct pglist_data___280 {
	struct zone___280 node_zones[3];
	struct zonelist___280 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___281 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___281 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___280 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___281 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___281 *owner;
};

struct secondary_data___281 {
	void *stack;
	struct task_struct___281 *task;
	long int status;
};

struct blocking_notifier_head___280 {
	struct rw_semaphore___281 rwsem;
	struct notifier_block *head;
};

struct dentry___280;

struct path___280 {
	struct vfsmount *mnt;
	struct dentry___280 *dentry;
};

struct file___280 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___280 f_path;
	struct inode___280 *f_inode;
	const struct file_operations___280 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___193 f_owner;
	const struct cred___264 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___279 *f_mapping;
	errseq_t f_wb_err;
};

struct key___264;

struct user_struct___264;

struct cred___264 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___264 *session_keyring;
	struct key___264 *process_keyring;
	struct key___264 *thread_keyring;
	struct key___264 *request_key_auth;
	void *security;
	struct user_struct___264 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___273;

struct kernfs_elem_dir___273 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___273 *root;
};

struct kernfs_node___274;

struct kernfs_syscall_ops___273;

struct kernfs_root___273 {
	struct kernfs_node___274 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___273 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___273 {
	struct kernfs_node___274 *target_kn;
};

struct kernfs_ops___273;

struct kernfs_elem_attr___273 {
	const struct kernfs_ops___273 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___274 *notify_next;
};

struct kernfs_node___274 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___274 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___273 dir;
		struct kernfs_elem_symlink___273 symlink;
		struct kernfs_elem_attr___273 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___273;

struct kernfs_ops___273 {
	int (*open)(struct kernfs_open_file___273 *);
	void (*release)(struct kernfs_open_file___273 *);
	int (*seq_show)(struct seq_file___243 *, void *);
	void * (*seq_start)(struct seq_file___243 *, loff_t *);
	void * (*seq_next)(struct seq_file___243 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___243 *, void *);
	ssize_t (*read)(struct kernfs_open_file___273 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___273 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___273 *, struct vm_area_struct___281 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___273 *, struct poll_table_struct___170 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___273 {
	int (*remount_fs)(struct kernfs_root___273 *, int *, char *);
	int (*show_options)(struct seq_file___243 *, struct kernfs_root___273 *);
	int (*mkdir)(struct kernfs_node___274 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___274 *);
	int (*rename)(struct kernfs_node___274 *, struct kernfs_node___274 *, const char *);
	int (*show_path)(struct seq_file___243 *, struct kernfs_node___274 *, struct kernfs_root___273 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___242;

struct seq_file___243 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___242 *op;
	int poll_event;
	const struct file___280 *file;
	void *private;
};

struct vm_operations_struct___269;

struct kernfs_open_file___273 {
	struct kernfs_node___274 *kn;
	struct file___280 *file;
	struct seq_file___243 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___269 *vm_ops;
};

struct vm_fault___269;

struct vm_operations_struct___269 {
	void (*open)(struct vm_area_struct___281 *);
	void (*close)(struct vm_area_struct___281 *);
	int (*split)(struct vm_area_struct___281 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___281 *);
	vm_fault_t (*fault)(struct vm_fault___269 *);
	vm_fault_t (*huge_fault)(struct vm_fault___269 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___269 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___281 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___269 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___269 *);
	int (*access)(struct vm_area_struct___281 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___281 *);
	int (*set_policy)(struct vm_area_struct___281 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___281 *, long unsigned int);
	struct page___281 * (*find_special_page)(struct vm_area_struct___281 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___173)(struct file___280 *, wait_queue_head_t *, struct poll_table_struct___170 *);

struct poll_table_struct___170 {
	poll_queue_proc___173 _qproc;
	__poll_t _key;
};

struct vm_area_struct___281 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___281 *vm_next;
	struct vm_area_struct___281 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___280 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___269 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___280 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___267;

struct bin_attribute___243;

struct attribute_group___244 {
	const char *name;
	umode_t (*is_visible)(struct kobject___267 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___267 *, struct bin_attribute___243 *, int);
	struct attribute **attrs;
	struct bin_attribute___243 **bin_attrs;
};

struct kset___266;

struct kobj_type___266;

struct kobject___267 {
	const char *name;
	struct list_head entry;
	struct kobject___267 *parent;
	struct kset___266 *kset;
	struct kobj_type___266 *ktype;
	struct kernfs_node___274 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___243 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___280 *, struct kobject___267 *, struct bin_attribute___243 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___280 *, struct kobject___267 *, struct bin_attribute___243 *, char *, loff_t, size_t);
	int (*mmap)(struct file___280 *, struct kobject___267 *, struct bin_attribute___243 *, struct vm_area_struct___281 *);
};

struct sysfs_ops___266 {
	ssize_t (*show)(struct kobject___267 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___267 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___266;

struct kset___266 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___267 kobj;
	const struct kset_uevent_ops___266 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___266 {
	void (*release)(struct kobject___267 *);
	const struct sysfs_ops___266 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___25 * (*child_ns_type)(struct kobject___267 *);
	const void * (*namespace)(struct kobject___267 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___266 {
	int (* const filter)(struct kset___266 *, struct kobject___267 *);
	const char * (* const name)(struct kset___266 *, struct kobject___267 *);
	int (* const uevent)(struct kset___266 *, struct kobject___267 *, struct kobj_uevent_env *);
};

struct kobj_attribute___259 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___267 *, struct kobj_attribute___259 *, char *);
	ssize_t (*store)(struct kobject___267 *, struct kobj_attribute___259 *, const char *, size_t);
};

struct kernel_param___223;

struct kernel_param_ops___223 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___223 *);
	int (*get)(char *, const struct kernel_param___223 *);
	void (*free)(void *);
};

struct kparam_array___223;

struct kernel_param___223 {
	const char *name;
	struct module___226 *mod;
	const struct kernel_param_ops___223 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___223 *arr;
	};
};

struct kparam_array___223 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___223 *ops;
	void *elem;
};

struct module_kobject___223 {
	struct kobject___267 kobj;
	struct module___226 *mod;
	struct kobject___267 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___223 {
	struct module___226 *mod;
	struct latch_tree_node node;
};

struct module_layout___223 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___223 mtn;
};

struct module_attribute___223;

struct module___226 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___223 mkobj;
	struct module_attribute___223 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___267 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___223 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___223 core_layout;
	struct module_layout___223 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___223 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___223 *, struct module_kobject___223 *, char *);
	ssize_t (*store)(struct module_attribute___223 *, struct module_kobject___223 *, const char *, size_t);
	void (*setup)(struct module___226 *, const char *);
	int (*test)(struct module___226 *);
	void (*free)(struct module___226 *);
};

struct device___242;

struct dev_pm_ops___242 {
	int (*prepare)(struct device___242 *);
	void (*complete)(struct device___242 *);
	int (*suspend)(struct device___242 *);
	int (*resume)(struct device___242 *);
	int (*freeze)(struct device___242 *);
	int (*thaw)(struct device___242 *);
	int (*poweroff)(struct device___242 *);
	int (*restore)(struct device___242 *);
	int (*suspend_late)(struct device___242 *);
	int (*resume_early)(struct device___242 *);
	int (*freeze_late)(struct device___242 *);
	int (*thaw_early)(struct device___242 *);
	int (*poweroff_late)(struct device___242 *);
	int (*restore_early)(struct device___242 *);
	int (*suspend_noirq)(struct device___242 *);
	int (*resume_noirq)(struct device___242 *);
	int (*freeze_noirq)(struct device___242 *);
	int (*thaw_noirq)(struct device___242 *);
	int (*poweroff_noirq)(struct device___242 *);
	int (*restore_noirq)(struct device___242 *);
	int (*runtime_suspend)(struct device___242 *);
	int (*runtime_resume)(struct device___242 *);
	int (*runtime_idle)(struct device___242 *);
};

struct dev_pm_info___242 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___242 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___242;

struct bus_type___242;

struct device_driver___242;

struct dev_pm_domain___242;

struct irq_domain___5;

struct device_node___43;

struct fwnode_handle___177;

struct class___242;

struct device___242 {
	struct device___242 *parent;
	struct device_private *p;
	struct kobject___267 kobj;
	const char *init_name;
	const struct device_type___242 *type;
	struct mutex mutex;
	struct bus_type___242 *bus;
	struct device_driver___242 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___242 power;
	struct dev_pm_domain___242 *pm_domain;
	struct irq_domain___5 *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___43 *of_node;
	struct fwnode_handle___177 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___242 *class;
	const struct attribute_group___244 **groups;
	void (*release)(struct device___242 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___242 {
	struct dev_pm_ops___242 ops;
	void (*detach)(struct device___242 *, bool);
	int (*activate)(struct device___242 *);
	void (*sync)(struct device___242 *);
	void (*dismiss)(struct device___242 *);
};

struct user_struct___264 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___264 *uid_keyring;
	struct key___264 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___280;

struct mm_struct___280 {
	struct {
		struct vm_area_struct___281 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___280 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___281 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___280 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___281 *owner;
		struct user_namespace___3 *user_ns;
		struct file___280 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___280 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct vm_struct___196 {
	struct vm_struct___196 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___281 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bus_type___242 {
	const char *name;
	const char *dev_name;
	struct device___242 *dev_root;
	const struct attribute_group___244 **bus_groups;
	const struct attribute_group___244 **dev_groups;
	const struct attribute_group___244 **drv_groups;
	int (*match)(struct device___242 *, struct device_driver___242 *);
	int (*uevent)(struct device___242 *, struct kobj_uevent_env *);
	int (*probe)(struct device___242 *);
	int (*remove)(struct device___242 *);
	void (*shutdown)(struct device___242 *);
	int (*online)(struct device___242 *);
	int (*offline)(struct device___242 *);
	int (*suspend)(struct device___242 *, pm_message_t);
	int (*resume)(struct device___242 *);
	int (*num_vf)(struct device___242 *);
	int (*dma_configure)(struct device___242 *);
	const struct dev_pm_ops___242 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___242 {
	const char *name;
	struct bus_type___242 *bus;
	struct module___226 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___242 *);
	int (*remove)(struct device___242 *);
	void (*shutdown)(struct device___242 *);
	int (*suspend)(struct device___242 *, pm_message_t);
	int (*resume)(struct device___242 *);
	const struct attribute_group___244 **groups;
	const struct dev_pm_ops___242 *pm;
	void (*coredump)(struct device___242 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___242 {
	const char *name;
	const struct attribute_group___244 **groups;
	int (*uevent)(struct device___242 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___242 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___242 *);
	const struct dev_pm_ops___242 *pm;
};

struct class___242 {
	const char *name;
	struct module___226 *owner;
	const struct attribute_group___244 **class_groups;
	const struct attribute_group___244 **dev_groups;
	struct kobject___267 *dev_kobj;
	int (*dev_uevent)(struct device___242 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___242 *, umode_t *);
	void (*class_release)(struct class___242 *);
	void (*dev_release)(struct device___242 *);
	int (*shutdown_pre)(struct device___242 *);
	const struct kobj_ns_type_operations___25 *ns_type;
	const void * (*namespace)(struct device___242 *);
	const struct dev_pm_ops___242 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct irq_domain_ops___5;

struct irq_domain_chip_generic___5;

struct irq_domain___5 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___5 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___177 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___5 *gc;
	struct irq_domain___5 *parent;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_direct_max_irq;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_tree_mutex;
	unsigned int linear_revmap[0];
};

struct fwnode_operations___177;

struct fwnode_handle___177 {
	struct fwnode_handle___177 *secondary;
	const struct fwnode_operations___177 *ops;
};

struct property___42;

struct device_node___43 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___177 fwnode;
	struct property___42 *properties;
	struct property___42 *deadprops;
	struct device_node___43 *parent;
	struct device_node___43 *child;
	struct device_node___43 *sibling;
	struct kobject___267 kobj;
	long unsigned int _flags;
	void *data;
};

struct node___175 {
	struct device___242 dev;
};

struct address_space_operations___279;

struct address_space___279 {
	struct inode___280 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___281 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___279 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___269)(struct vm_area_struct___281 *, long unsigned int, const struct page___281 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___269)(struct page___281 *, void *);

struct dev_pagemap___269 {
	dev_page_fault_t___269 page_fault;
	dev_page_free_t___269 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___242 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___280 {
	struct task_struct___281 *task;
	struct core_thread___280 *next;
};

struct core_state___280 {
	atomic_t nr_threads;
	struct core_thread___280 dumper;
	struct completion startup;
};

struct vm_fault___269 {
	struct vm_area_struct___281 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___281 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___281 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___280 prealloc_pte;
};

struct fwnode_reference_args___177;

struct fwnode_endpoint___177;

struct fwnode_operations___177 {
	struct fwnode_handle___177 * (*get)(struct fwnode_handle___177 *);
	void (*put)(struct fwnode_handle___177 *);
	bool (*device_is_available)(const struct fwnode_handle___177 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___177 *, const struct device___242 *);
	bool (*property_present)(const struct fwnode_handle___177 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___177 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___177 *, const char *, const char **, size_t);
	struct fwnode_handle___177 * (*get_parent)(const struct fwnode_handle___177 *);
	struct fwnode_handle___177 * (*get_next_child_node)(const struct fwnode_handle___177 *, struct fwnode_handle___177 *);
	struct fwnode_handle___177 * (*get_named_child_node)(const struct fwnode_handle___177 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___177 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___177 *);
	struct fwnode_handle___177 * (*graph_get_next_endpoint)(const struct fwnode_handle___177 *, struct fwnode_handle___177 *);
	struct fwnode_handle___177 * (*graph_get_remote_endpoint)(const struct fwnode_handle___177 *);
	struct fwnode_handle___177 * (*graph_get_port_parent)(struct fwnode_handle___177 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___177 *, struct fwnode_endpoint___177 *);
};

struct fwnode_endpoint___177 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___177 *local_fwnode;
};

struct fwnode_reference_args___177 {
	struct fwnode_handle___177 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct property___42 {
	char *name;
	int length;
	void *value;
	struct property___42 *next;
	long unsigned int _flags;
	struct bin_attribute___243 attr;
};

typedef int (*of_init_fn_2)(struct device_node___43 *, struct device_node___43 *);

struct irq_desc___10;

typedef void (*irq_flow_handler_t___10)(struct irq_desc___10 *);

struct irq_chip___13;

struct irq_data___13 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___4 *common;
	struct irq_chip___13 *chip;
	struct irq_domain___5 *domain;
	struct irq_data___13 *parent_data;
	void *chip_data;
};

struct irqaction___8;

struct irq_desc___10 {
	struct irq_common_data___4 irq_common_data;
	struct irq_data___13 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___10 handle_irq;
	struct irqaction___8 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int irq_count;
	unsigned int tot_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___267 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___226 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip___13 {
	struct device___242 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___13 *);
	void (*irq_shutdown)(struct irq_data___13 *);
	void (*irq_enable)(struct irq_data___13 *);
	void (*irq_disable)(struct irq_data___13 *);
	void (*irq_ack)(struct irq_data___13 *);
	void (*irq_mask)(struct irq_data___13 *);
	void (*irq_mask_ack)(struct irq_data___13 *);
	void (*irq_unmask)(struct irq_data___13 *);
	void (*irq_eoi)(struct irq_data___13 *);
	int (*irq_set_affinity)(struct irq_data___13 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___13 *);
	int (*irq_set_type)(struct irq_data___13 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___13 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___13 *);
	void (*irq_bus_sync_unlock)(struct irq_data___13 *);
	void (*irq_cpu_online)(struct irq_data___13 *);
	void (*irq_cpu_offline)(struct irq_data___13 *);
	void (*irq_suspend)(struct irq_data___13 *);
	void (*irq_resume)(struct irq_data___13 *);
	void (*irq_pm_shutdown)(struct irq_data___13 *);
	void (*irq_calc_mask)(struct irq_data___13 *);
	void (*irq_print_chip)(struct irq_data___13 *, struct seq_file___243 *);
	int (*irq_request_resources)(struct irq_data___13 *);
	void (*irq_release_resources)(struct irq_data___13 *);
	void (*irq_compose_msi_msg)(struct irq_data___13 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___13 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___13 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___13 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___13 *, void *);
	void (*ipi_send_single)(struct irq_data___13 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___13 *, const struct cpumask *);
	long unsigned int flags;
};

struct irqaction___8 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___8 *next;
	irq_handler_t thread_fn;
	struct task_struct___281 *thread;
	struct irqaction___8 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip_type___6 {
	struct irq_chip___13 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___10 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___6 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___6 *);
	void (*resume)(struct irq_chip_generic___6 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___5 *domain;
	struct list_head list;
	struct irq_chip_type___6 chip_types[0];
};

struct irq_domain_chip_generic___5 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___6 *gc[0];
};

struct irq_fwspec___5 {
	struct fwnode_handle___177 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___5 {
	int (*match)(struct irq_domain___5 *, struct device_node___43 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___5 *, struct irq_fwspec___5 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___5 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___5 *, unsigned int);
	int (*xlate)(struct irq_domain___5 *, struct device_node___43 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___5 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___5 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___5 *, struct irq_data___13 *, bool);
	void (*deactivate)(struct irq_domain___5 *, struct irq_data___13 *);
	int (*translate)(struct irq_domain___5 *, struct irq_fwspec___5 *, long unsigned int *, unsigned int *);
};

struct acpi_madt_generic_distributor {
	struct acpi_subtable_header header;
	u16 reserved;
	u32 gic_id;
	u64 base_address;
	u32 global_irq_base;
	u8 version;
	u8 reserved2[3];
};

enum acpi_madt_gic_version {
	ACPI_MADT_GIC_VERSION_NONE = 0,
	ACPI_MADT_GIC_VERSION_V1 = 1,
	ACPI_MADT_GIC_VERSION_V2 = 2,
	ACPI_MADT_GIC_VERSION_V3 = 3,
	ACPI_MADT_GIC_VERSION_V4 = 4,
	ACPI_MADT_GIC_VERSION_RESERVED = 5,
};

struct dentry_operations___279;

struct super_block___279;

struct dentry___280 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___280 *d_parent;
	struct qstr d_name;
	struct inode___280 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___279 *d_op;
	struct super_block___279 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___279;

struct block_device___279;

struct cdev___43;

struct inode___280 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___279 *i_op;
	struct super_block___279 *i_sb;
	struct address_space___279 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___281 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___280 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___279 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___279 *i_bdev;
		struct cdev___43 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___279 {
	int (*d_revalidate)(struct dentry___280 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___280 *, unsigned int);
	int (*d_hash)(const struct dentry___280 *, struct qstr *);
	int (*d_compare)(const struct dentry___280 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___280 *);
	int (*d_init)(struct dentry___280 *);
	void (*d_release)(struct dentry___280 *);
	void (*d_prune)(struct dentry___280 *);
	void (*d_iput)(struct dentry___280 *, struct inode___280 *);
	char * (*d_dname)(struct dentry___280 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___280 *);
	int (*d_manage)(const struct path___280 *, bool);
	struct dentry___280 * (*d_real)(struct dentry___280 *, const struct inode___280 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___279;

struct mem_dqinfo___279 {
	struct quota_format_type___279 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___279;

struct quota_info___279 {
	unsigned int flags;
	struct rw_semaphore___281 dqio_sem;
	struct inode___280 *files[3];
	struct mem_dqinfo___279 info[3];
	const struct quota_format_ops___279 *ops[3];
};

struct rcuwait___279 {
	struct task_struct___281 *task;
};

struct percpu_rw_semaphore___279 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___281 rw_sem;
	struct rcuwait___279 writer;
	int readers_block;
};

struct sb_writers___279 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___279 rw_sem[3];
};

struct file_system_type___279;

struct super_operations___279;

struct dquot_operations___279;

struct quotactl_ops___279;

struct super_block___279 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___279 *s_type;
	const struct super_operations___279 *s_op;
	const struct dquot_operations___279 *dq_op;
	const struct quotactl_ops___279 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___280 *s_root;
	struct rw_semaphore___281 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___279 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___279 s_dquot;
	struct sb_writers___279 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___279 *s_d_op;
	int cleancache_poolid;
	struct shrinker___115 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___280 {
	struct file___280 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___280 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___279 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___280 *ia_file;
};

struct dquot___279 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___279 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___279 {
	int qf_fmt_id;
	const struct quota_format_ops___279 *qf_ops;
	struct module___226 *qf_owner;
	struct quota_format_type___279 *qf_next;
};

struct quota_format_ops___279 {
	int (*check_quota_file)(struct super_block___279 *, int);
	int (*read_file_info)(struct super_block___279 *, int);
	int (*write_file_info)(struct super_block___279 *, int);
	int (*free_file_info)(struct super_block___279 *, int);
	int (*read_dqblk)(struct dquot___279 *);
	int (*commit_dqblk)(struct dquot___279 *);
	int (*release_dqblk)(struct dquot___279 *);
	int (*get_next_id)(struct super_block___279 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___279 {
	int (*write_dquot)(struct dquot___279 *);
	struct dquot___279 * (*alloc_dquot)(struct super_block___279 *, int);
	void (*destroy_dquot)(struct dquot___279 *);
	int (*acquire_dquot)(struct dquot___279 *);
	int (*release_dquot)(struct dquot___279 *);
	int (*mark_dirty)(struct dquot___279 *);
	int (*write_info)(struct super_block___279 *, int);
	qsize_t * (*get_reserved_space)(struct inode___280 *);
	int (*get_projid)(struct inode___280 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___280 *, qsize_t *);
	int (*get_next_id)(struct super_block___279 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___279 {
	int (*quota_on)(struct super_block___279 *, int, int, const struct path___280 *);
	int (*quota_off)(struct super_block___279 *, int);
	int (*quota_enable)(struct super_block___279 *, unsigned int);
	int (*quota_disable)(struct super_block___279 *, unsigned int);
	int (*quota_sync)(struct super_block___279 *, int);
	int (*set_info)(struct super_block___279 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___279 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___279 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___279 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___279 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___279 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___279 {
	int (*writepage)(struct page___281 *, struct writeback_control___3 *);
	int (*readpage)(struct file___280 *, struct page___281 *);
	int (*writepages)(struct address_space___279 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___281 *);
	int (*readpages)(struct file___280 *, struct address_space___279 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___280 *, struct address_space___279 *, loff_t, unsigned int, unsigned int, struct page___281 **, void **);
	int (*write_end)(struct file___280 *, struct address_space___279 *, loff_t, unsigned int, unsigned int, struct page___281 *, void *);
	sector_t (*bmap)(struct address_space___279 *, sector_t);
	void (*invalidatepage)(struct page___281 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___281 *, gfp_t);
	void (*freepage)(struct page___281 *);
	ssize_t (*direct_IO)(struct kiocb___280 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___279 *, struct page___281 *, struct page___281 *, enum migrate_mode);
	bool (*isolate_page)(struct page___281 *, isolate_mode_t);
	void (*putback_page)(struct page___281 *);
	int (*launder_page)(struct page___281 *);
	int (*is_partially_uptodate)(struct page___281 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___281 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___279 *, struct page___281 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___280 *, sector_t *);
	void (*swap_deactivate)(struct file___280 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___279 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___280 *bd_inode;
	struct super_block___279 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___279 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___43 {
	struct kobject___267 kobj;
	struct module___226 *owner;
	const struct file_operations___280 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___279 {
	struct dentry___280 * (*lookup)(struct inode___280 *, struct dentry___280 *, unsigned int);
	const char * (*get_link)(struct dentry___280 *, struct inode___280 *, struct delayed_call *);
	int (*permission)(struct inode___280 *, int);
	struct posix_acl * (*get_acl)(struct inode___280 *, int);
	int (*readlink)(struct dentry___280 *, char *, int);
	int (*create)(struct inode___280 *, struct dentry___280 *, umode_t, bool);
	int (*link)(struct dentry___280 *, struct inode___280 *, struct dentry___280 *);
	int (*unlink)(struct inode___280 *, struct dentry___280 *);
	int (*symlink)(struct inode___280 *, struct dentry___280 *, const char *);
	int (*mkdir)(struct inode___280 *, struct dentry___280 *, umode_t);
	int (*rmdir)(struct inode___280 *, struct dentry___280 *);
	int (*mknod)(struct inode___280 *, struct dentry___280 *, umode_t, dev_t);
	int (*rename)(struct inode___280 *, struct dentry___280 *, struct inode___280 *, struct dentry___280 *, unsigned int);
	int (*setattr)(struct dentry___280 *, struct iattr___279 *);
	int (*getattr)(const struct path___280 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___280 *, char *, size_t);
	int (*fiemap)(struct inode___280 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___280 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___280 *, struct dentry___280 *, struct file___280 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___280 *, struct dentry___280 *, umode_t);
	int (*set_acl)(struct inode___280 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___279 {
	void (*fl_copy_lock)(struct file_lock___280 *, struct file_lock___280 *);
	void (*fl_release_private)(struct file_lock___280 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___279;

struct lock_manager_operations___279;

struct file_lock___280 {
	struct file_lock___280 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___280 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___279 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___279 *fl_ops;
	const struct lock_manager_operations___279 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___279 {
	int (*lm_compare_owner)(struct file_lock___280 *, struct file_lock___280 *);
	long unsigned int (*lm_owner_key)(struct file_lock___280 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___280 *);
	int (*lm_grant)(struct file_lock___280 *, int);
	bool (*lm_break)(struct file_lock___280 *);
	int (*lm_change)(struct file_lock___280 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___280 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___279 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___279 *fa_next;
	struct file___280 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___279 {
	const char *name;
	int fs_flags;
	struct dentry___280 * (*mount)(struct file_system_type___279 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___279 *);
	struct module___226 *owner;
	struct file_system_type___279 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___279 {
	struct inode___280 * (*alloc_inode)(struct super_block___279 *);
	void (*destroy_inode)(struct inode___280 *);
	void (*dirty_inode)(struct inode___280 *, int);
	int (*write_inode)(struct inode___280 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___280 *);
	void (*evict_inode)(struct inode___280 *);
	void (*put_super)(struct super_block___279 *);
	int (*sync_fs)(struct super_block___279 *, int);
	int (*freeze_super)(struct super_block___279 *);
	int (*freeze_fs)(struct super_block___279 *);
	int (*thaw_super)(struct super_block___279 *);
	int (*unfreeze_fs)(struct super_block___279 *);
	int (*statfs)(struct dentry___280 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___279 *, int *, char *);
	void (*umount_begin)(struct super_block___279 *);
	int (*show_options)(struct seq_file___243 *, struct dentry___280 *);
	int (*show_devname)(struct seq_file___243 *, struct dentry___280 *);
	int (*show_path)(struct seq_file___243 *, struct dentry___280 *);
	int (*show_stats)(struct seq_file___243 *, struct dentry___280 *);
	ssize_t (*quota_read)(struct super_block___279 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___279 *, int, const char *, size_t, loff_t);
	struct dquot___279 ** (*get_dquots)(struct inode___280 *);
	int (*bdev_try_to_free_page)(struct super_block___279 *, struct page___281 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___279 *, struct shrink_control___115 *);
	long int (*free_cached_objects)(struct super_block___279 *, struct shrink_control___115 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*key_restrict_link_func_t___265)(struct key___264 *, const struct key_type *, const union key_payload *, struct key___264 *);

struct key_restriction___264;

struct key___264 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___281 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___264 *restrict_link;
};

struct key_restriction___264 {
	key_restrict_link_func_t___265 check;
	struct key___264 *key;
	struct key_type *keytype;
};

struct seq_operations___242 {
	void * (*start)(struct seq_file___243 *, loff_t *);
	void (*stop)(struct seq_file___243 *, void *);
	void * (*next)(struct seq_file___243 *, void *, loff_t *);
	int (*show)(struct seq_file___243 *, void *);
};

typedef void compound_page_dtor___269(struct page___281 *);

union gic_base {
	void *common_base;
	void **percpu_base;
};

struct gic_chip_data {
	struct irq_chip___13 chip;
	union gic_base dist_base;
	union gic_base cpu_base;
	void *raw_dist_base;
	void *raw_cpu_base;
	u32 percpu_offset;
	u32 saved_spi_enable[32];
	u32 saved_spi_active[32];
	u32 saved_spi_conf[64];
	u32 saved_spi_target[255];
	u32 *saved_ppi_enable;
	u32 *saved_ppi_active;
	u32 *saved_ppi_conf;
	struct irq_domain___5 *domain;
	unsigned int gic_irqs;
};

struct gic_quirk {
	const char *desc;
	bool (*init)(void *);
	u32 iidr;
	u32 mask;
};

struct module___227;

struct file___281;

struct kiocb___281;

struct poll_table_struct___171;

struct vm_area_struct___282;

struct inode___281;

struct file_lock___281;

struct page___282;

struct seq_file___244;

struct file_operations___281 {
	struct module___227 *owner;
	loff_t (*llseek)(struct file___281 *, loff_t, int);
	ssize_t (*read)(struct file___281 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___281 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___281 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___281 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___281 *, bool);
	int (*iterate)(struct file___281 *, struct dir_context *);
	int (*iterate_shared)(struct file___281 *, struct dir_context *);
	__poll_t (*poll)(struct file___281 *, struct poll_table_struct___171 *);
	long int (*unlocked_ioctl)(struct file___281 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___281 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___281 *, struct vm_area_struct___282 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___281 *, struct file___281 *);
	int (*flush)(struct file___281 *, fl_owner_t);
	int (*release)(struct inode___281 *, struct file___281 *);
	int (*fsync)(struct file___281 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___281 *, int);
	int (*lock)(struct file___281 *, int, struct file_lock___281 *);
	ssize_t (*sendpage)(struct file___281 *, struct page___282 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___281 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___281 *, int, struct file_lock___281 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___281 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___281 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___281 *, long int, struct file_lock___281 **, void **);
	long int (*fallocate)(struct file___281 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___244 *, struct file___281 *);
	ssize_t (*copy_file_range)(struct file___281 *, loff_t, struct file___281 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___281 *, loff_t, struct file___281 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___281 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___281 {
	u64 seqnum;
	struct vm_area_struct___282 *vmas[4];
};

struct page_frag___281 {
	struct page___282 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___281;

struct cred___265;

struct vm_struct___197;

struct task_struct___282 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___282 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___281 *mm;
	struct mm_struct___281 *active_mm;
	struct vmacache___281 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___282 *real_parent;
	struct task_struct___282 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___282 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___193 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___193 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___193 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___265 *ptracer_cred;
	const struct cred___265 *real_cred;
	const struct cred___265 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___282 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___82 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___281 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___282 *oom_reaper_list;
	struct vm_struct___197 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___130 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___282 *pgtable_t___281;

struct address_space___280;

struct dev_pagemap___270;

struct page___282 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___280 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___282 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___281 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___281 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___270 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___281;

struct lruvec___281 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___281 *pgdat;
};

struct zone___281 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___281 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___281 {
	struct zone___281 *zone;
	int zone_idx;
};

struct zonelist___281 {
	struct zoneref___281 _zonerefs[25];
};

struct pglist_data___281 {
	struct zone___281 node_zones[3];
	struct zonelist___281 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___282 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___282 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___281 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___282 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___282 *owner;
};

struct secondary_data___282 {
	void *stack;
	struct task_struct___282 *task;
	long int status;
};

struct blocking_notifier_head___281 {
	struct rw_semaphore___282 rwsem;
	struct notifier_block *head;
};

struct kernfs_root___274;

struct kernfs_elem_dir___274 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___274 *root;
};

struct kernfs_node___275;

struct kernfs_syscall_ops___274;

struct kernfs_root___274 {
	struct kernfs_node___275 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___274 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___274 {
	struct kernfs_node___275 *target_kn;
};

struct kernfs_ops___274;

struct kernfs_elem_attr___274 {
	const struct kernfs_ops___274 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___275 *notify_next;
};

struct kernfs_node___275 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___275 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___274 dir;
		struct kernfs_elem_symlink___274 symlink;
		struct kernfs_elem_attr___274 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___274;

struct kernfs_ops___274 {
	int (*open)(struct kernfs_open_file___274 *);
	void (*release)(struct kernfs_open_file___274 *);
	int (*seq_show)(struct seq_file___244 *, void *);
	void * (*seq_start)(struct seq_file___244 *, loff_t *);
	void * (*seq_next)(struct seq_file___244 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___244 *, void *);
	ssize_t (*read)(struct kernfs_open_file___274 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___274 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___274 *, struct vm_area_struct___282 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___274 *, struct poll_table_struct___171 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___274 {
	int (*remount_fs)(struct kernfs_root___274 *, int *, char *);
	int (*show_options)(struct seq_file___244 *, struct kernfs_root___274 *);
	int (*mkdir)(struct kernfs_node___275 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___275 *);
	int (*rename)(struct kernfs_node___275 *, struct kernfs_node___275 *, const char *);
	int (*show_path)(struct seq_file___244 *, struct kernfs_node___275 *, struct kernfs_root___274 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___243;

struct seq_file___244 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___243 *op;
	int poll_event;
	const struct file___281 *file;
	void *private;
};

struct vm_operations_struct___270;

struct kernfs_open_file___274 {
	struct kernfs_node___275 *kn;
	struct file___281 *file;
	struct seq_file___244 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___270 *vm_ops;
};

struct dentry___281;

struct path___281 {
	struct vfsmount *mnt;
	struct dentry___281 *dentry;
};

struct file___281 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___281 f_path;
	struct inode___281 *f_inode;
	const struct file_operations___281 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___193 f_owner;
	const struct cred___265 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___280 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___270;

struct vm_operations_struct___270 {
	void (*open)(struct vm_area_struct___282 *);
	void (*close)(struct vm_area_struct___282 *);
	int (*split)(struct vm_area_struct___282 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___282 *);
	vm_fault_t (*fault)(struct vm_fault___270 *);
	vm_fault_t (*huge_fault)(struct vm_fault___270 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___270 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___282 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___270 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___270 *);
	int (*access)(struct vm_area_struct___282 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___282 *);
	int (*set_policy)(struct vm_area_struct___282 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___282 *, long unsigned int);
	struct page___282 * (*find_special_page)(struct vm_area_struct___282 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___174)(struct file___281 *, wait_queue_head_t *, struct poll_table_struct___171 *);

struct poll_table_struct___171 {
	poll_queue_proc___174 _qproc;
	__poll_t _key;
};

struct vm_area_struct___282 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___282 *vm_next;
	struct vm_area_struct___282 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___281 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___270 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___281 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___268;

struct bin_attribute___244;

struct attribute_group___245 {
	const char *name;
	umode_t (*is_visible)(struct kobject___268 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___268 *, struct bin_attribute___244 *, int);
	struct attribute **attrs;
	struct bin_attribute___244 **bin_attrs;
};

struct kset___267;

struct kobj_type___267;

struct kobject___268 {
	const char *name;
	struct list_head entry;
	struct kobject___268 *parent;
	struct kset___267 *kset;
	struct kobj_type___267 *ktype;
	struct kernfs_node___275 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___244 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___281 *, struct kobject___268 *, struct bin_attribute___244 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___281 *, struct kobject___268 *, struct bin_attribute___244 *, char *, loff_t, size_t);
	int (*mmap)(struct file___281 *, struct kobject___268 *, struct bin_attribute___244 *, struct vm_area_struct___282 *);
};

struct sysfs_ops___267 {
	ssize_t (*show)(struct kobject___268 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___268 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___267;

struct kset___267 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___268 kobj;
	const struct kset_uevent_ops___267 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___267 {
	void (*release)(struct kobject___268 *);
	const struct sysfs_ops___267 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___25 * (*child_ns_type)(struct kobject___268 *);
	const void * (*namespace)(struct kobject___268 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___267 {
	int (* const filter)(struct kset___267 *, struct kobject___268 *);
	const char * (* const name)(struct kset___267 *, struct kobject___268 *);
	int (* const uevent)(struct kset___267 *, struct kobject___268 *, struct kobj_uevent_env *);
};

struct kobj_attribute___260 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___268 *, struct kobj_attribute___260 *, char *);
	ssize_t (*store)(struct kobject___268 *, struct kobj_attribute___260 *, const char *, size_t);
};

struct device___243;

struct dev_pm_ops___243 {
	int (*prepare)(struct device___243 *);
	void (*complete)(struct device___243 *);
	int (*suspend)(struct device___243 *);
	int (*resume)(struct device___243 *);
	int (*freeze)(struct device___243 *);
	int (*thaw)(struct device___243 *);
	int (*poweroff)(struct device___243 *);
	int (*restore)(struct device___243 *);
	int (*suspend_late)(struct device___243 *);
	int (*resume_early)(struct device___243 *);
	int (*freeze_late)(struct device___243 *);
	int (*thaw_early)(struct device___243 *);
	int (*poweroff_late)(struct device___243 *);
	int (*restore_early)(struct device___243 *);
	int (*suspend_noirq)(struct device___243 *);
	int (*resume_noirq)(struct device___243 *);
	int (*freeze_noirq)(struct device___243 *);
	int (*thaw_noirq)(struct device___243 *);
	int (*poweroff_noirq)(struct device___243 *);
	int (*restore_noirq)(struct device___243 *);
	int (*runtime_suspend)(struct device___243 *);
	int (*runtime_resume)(struct device___243 *);
	int (*runtime_idle)(struct device___243 *);
};

struct dev_pm_info___243 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___243 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___243;

struct bus_type___243;

struct device_driver___243;

struct dev_pm_domain___243;

struct irq_domain___6;

struct dma_map_ops___68;

struct device_node___44;

struct fwnode_handle___178;

struct class___243;

struct iommu_fwspec___3;

struct device___243 {
	struct device___243 *parent;
	struct device_private *p;
	struct kobject___268 kobj;
	const char *init_name;
	const struct device_type___243 *type;
	struct mutex mutex;
	struct bus_type___243 *bus;
	struct device_driver___243 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___243 power;
	struct dev_pm_domain___243 *pm_domain;
	struct irq_domain___6 *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___68 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___44 *of_node;
	struct fwnode_handle___178 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___243 *class;
	const struct attribute_group___245 **groups;
	void (*release)(struct device___243 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec___3 *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___243 {
	struct dev_pm_ops___243 ops;
	void (*detach)(struct device___243 *, bool);
	int (*activate)(struct device___243 *);
	void (*sync)(struct device___243 *);
	void (*dismiss)(struct device___243 *);
};

struct key___265;

struct user_struct___265 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___265 *uid_keyring;
	struct key___265 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___281;

struct mm_struct___281 {
	struct {
		struct vm_area_struct___282 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___281 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___282 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___281 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___282 *owner;
		struct user_namespace___3 *user_ns;
		struct file___281 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___281 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___265 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___265 *session_keyring;
	struct key___265 *process_keyring;
	struct key___265 *thread_keyring;
	struct key___265 *request_key_auth;
	void *security;
	struct user_struct___265 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct vm_struct___197 {
	struct vm_struct___197 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___282 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct iommu_ops___3;

struct bus_type___243 {
	const char *name;
	const char *dev_name;
	struct device___243 *dev_root;
	const struct attribute_group___245 **bus_groups;
	const struct attribute_group___245 **dev_groups;
	const struct attribute_group___245 **drv_groups;
	int (*match)(struct device___243 *, struct device_driver___243 *);
	int (*uevent)(struct device___243 *, struct kobj_uevent_env *);
	int (*probe)(struct device___243 *);
	int (*remove)(struct device___243 *);
	void (*shutdown)(struct device___243 *);
	int (*online)(struct device___243 *);
	int (*offline)(struct device___243 *);
	int (*suspend)(struct device___243 *, pm_message_t);
	int (*resume)(struct device___243 *);
	int (*num_vf)(struct device___243 *);
	int (*dma_configure)(struct device___243 *);
	const struct dev_pm_ops___243 *pm;
	const struct iommu_ops___3 *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___243 {
	const char *name;
	struct bus_type___243 *bus;
	struct module___227 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___243 *);
	int (*remove)(struct device___243 *);
	void (*shutdown)(struct device___243 *);
	int (*suspend)(struct device___243 *, pm_message_t);
	int (*resume)(struct device___243 *);
	const struct attribute_group___245 **groups;
	const struct dev_pm_ops___243 *pm;
	void (*coredump)(struct device___243 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct iommu_domain___3;

struct of_phandle_args___3;

struct iommu_ops___3 {
	bool (*capable)(enum iommu_cap);
	struct iommu_domain___3 * (*domain_alloc)(unsigned int);
	void (*domain_free)(struct iommu_domain___3 *);
	int (*attach_dev)(struct iommu_domain___3 *, struct device___243 *);
	void (*detach_dev)(struct iommu_domain___3 *, struct device___243 *);
	int (*map)(struct iommu_domain___3 *, long unsigned int, phys_addr_t, size_t, int);
	size_t (*unmap)(struct iommu_domain___3 *, long unsigned int, size_t);
	void (*flush_iotlb_all)(struct iommu_domain___3 *);
	void (*iotlb_range_add)(struct iommu_domain___3 *, long unsigned int, size_t);
	void (*iotlb_sync)(struct iommu_domain___3 *);
	phys_addr_t (*iova_to_phys)(struct iommu_domain___3 *, dma_addr_t);
	int (*add_device)(struct device___243 *);
	void (*remove_device)(struct device___243 *);
	struct iommu_group * (*device_group)(struct device___243 *);
	int (*domain_get_attr)(struct iommu_domain___3 *, enum iommu_attr, void *);
	int (*domain_set_attr)(struct iommu_domain___3 *, enum iommu_attr, void *);
	void (*get_resv_regions)(struct device___243 *, struct list_head *);
	void (*put_resv_regions)(struct device___243 *, struct list_head *);
	void (*apply_resv_region)(struct device___243 *, struct iommu_domain___3 *, struct iommu_resv_region *);
	int (*domain_window_enable)(struct iommu_domain___3 *, u32, phys_addr_t, u64, int);
	void (*domain_window_disable)(struct iommu_domain___3 *, u32);
	int (*domain_set_windows)(struct iommu_domain___3 *, u32);
	u32 (*domain_get_windows)(struct iommu_domain___3 *);
	int (*of_xlate)(struct device___243 *, struct of_phandle_args___3 *);
	bool (*is_attach_deferred)(struct iommu_domain___3 *, struct device___243 *);
	long unsigned int pgsize_bitmap;
};

struct device_type___243 {
	const char *name;
	const struct attribute_group___245 **groups;
	int (*uevent)(struct device___243 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___243 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___243 *);
	const struct dev_pm_ops___243 *pm;
};

struct module_kobject___224 {
	struct kobject___268 kobj;
	struct module___227 *mod;
	struct kobject___268 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___224 {
	struct module___227 *mod;
	struct latch_tree_node node;
};

struct module_layout___224 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___224 mtn;
};

struct module_attribute___224;

struct kernel_param___224;

struct module___227 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___224 mkobj;
	struct module_attribute___224 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___268 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___224 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___224 core_layout;
	struct module_layout___224 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct class___243 {
	const char *name;
	struct module___227 *owner;
	const struct attribute_group___245 **class_groups;
	const struct attribute_group___245 **dev_groups;
	struct kobject___268 *dev_kobj;
	int (*dev_uevent)(struct device___243 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___243 *, umode_t *);
	void (*class_release)(struct class___243 *);
	void (*dev_release)(struct device___243 *);
	int (*shutdown_pre)(struct device___243 *);
	const struct kobj_ns_type_operations___25 *ns_type;
	const void * (*namespace)(struct device___243 *);
	const struct dev_pm_ops___243 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct irq_domain_ops___6;

struct irq_domain_chip_generic___6;

struct irq_domain___6 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___6 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___178 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___6 *gc;
	struct irq_domain___6 *parent;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_direct_max_irq;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_tree_mutex;
	unsigned int linear_revmap[0];
};

struct dma_map_ops___68 {
	void * (*alloc)(struct device___243 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___243 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___243 *, struct vm_area_struct___282 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___243 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___243 *, struct page___282 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___243 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___243 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___243 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___243 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___243 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___243 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___243 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___243 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___243 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___243 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___243 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___243 *, u64);
	u64 (*get_required_mask)(struct device___243 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___178;

struct fwnode_handle___178 {
	struct fwnode_handle___178 *secondary;
	const struct fwnode_operations___178 *ops;
};

struct property___43;

struct device_node___44 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___178 fwnode;
	struct property___43 *properties;
	struct property___43 *deadprops;
	struct device_node___44 *parent;
	struct device_node___44 *child;
	struct device_node___44 *sibling;
	struct kobject___268 kobj;
	long unsigned int _flags;
	void *data;
};

struct iommu_fwspec___3 {
	const struct iommu_ops___3 *ops;
	struct fwnode_handle___178 *iommu_fwnode;
	void *iommu_priv;
	unsigned int num_ids;
	u32 ids[1];
};

struct fwnode_reference_args___178;

struct fwnode_endpoint___178;

struct fwnode_operations___178 {
	struct fwnode_handle___178 * (*get)(struct fwnode_handle___178 *);
	void (*put)(struct fwnode_handle___178 *);
	bool (*device_is_available)(const struct fwnode_handle___178 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___178 *, const struct device___243 *);
	bool (*property_present)(const struct fwnode_handle___178 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___178 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___178 *, const char *, const char **, size_t);
	struct fwnode_handle___178 * (*get_parent)(const struct fwnode_handle___178 *);
	struct fwnode_handle___178 * (*get_next_child_node)(const struct fwnode_handle___178 *, struct fwnode_handle___178 *);
	struct fwnode_handle___178 * (*get_named_child_node)(const struct fwnode_handle___178 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___178 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___178 *);
	struct fwnode_handle___178 * (*graph_get_next_endpoint)(const struct fwnode_handle___178 *, struct fwnode_handle___178 *);
	struct fwnode_handle___178 * (*graph_get_remote_endpoint)(const struct fwnode_handle___178 *);
	struct fwnode_handle___178 * (*graph_get_port_parent)(struct fwnode_handle___178 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___178 *, struct fwnode_endpoint___178 *);
};

struct fwnode_endpoint___178 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___178 *local_fwnode;
};

struct fwnode_reference_args___178 {
	struct fwnode_handle___178 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct acpi_madt_generic_msi_frame {
	struct acpi_subtable_header header;
	u16 reserved;
	u32 msi_frame_id;
	u64 base_address;
	u32 flags;
	u16 spi_count;
	u16 spi_base;
};

struct kernel_param_ops___224 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___224 *);
	int (*get)(char *, const struct kernel_param___224 *);
	void (*free)(void *);
};

struct kparam_array___224;

struct kernel_param___224 {
	const char *name;
	struct module___227 *mod;
	const struct kernel_param_ops___224 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___224 *arr;
	};
};

struct kparam_array___224 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___224 *ops;
	void *elem;
};

struct module_attribute___224 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___224 *, struct module_kobject___224 *, char *);
	ssize_t (*store)(struct module_attribute___224 *, struct module_kobject___224 *, const char *, size_t);
	void (*setup)(struct module___227 *, const char *);
	int (*test)(struct module___227 *);
	void (*free)(struct module___227 *);
};

struct dentry_operations___280;

struct super_block___280;

struct dentry___281 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___281 *d_parent;
	struct qstr d_name;
	struct inode___281 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___280 *d_op;
	struct super_block___280 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___280;

struct address_space___280 {
	struct inode___281 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___282 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___280 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___280;

struct block_device___280;

struct cdev___44;

struct inode___281 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___280 *i_op;
	struct super_block___280 *i_sb;
	struct address_space___280 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___282 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___281 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___280 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___280 *i_bdev;
		struct cdev___44 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___280 {
	int (*d_revalidate)(struct dentry___281 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___281 *, unsigned int);
	int (*d_hash)(const struct dentry___281 *, struct qstr *);
	int (*d_compare)(const struct dentry___281 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___281 *);
	int (*d_init)(struct dentry___281 *);
	void (*d_release)(struct dentry___281 *);
	void (*d_prune)(struct dentry___281 *);
	void (*d_iput)(struct dentry___281 *, struct inode___281 *);
	char * (*d_dname)(struct dentry___281 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___281 *);
	int (*d_manage)(const struct path___281 *, bool);
	struct dentry___281 * (*d_real)(struct dentry___281 *, const struct inode___281 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___280;

struct mem_dqinfo___280 {
	struct quota_format_type___280 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___280;

struct quota_info___280 {
	unsigned int flags;
	struct rw_semaphore___282 dqio_sem;
	struct inode___281 *files[3];
	struct mem_dqinfo___280 info[3];
	const struct quota_format_ops___280 *ops[3];
};

struct rcuwait___280 {
	struct task_struct___282 *task;
};

struct percpu_rw_semaphore___280 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___282 rw_sem;
	struct rcuwait___280 writer;
	int readers_block;
};

struct sb_writers___280 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___280 rw_sem[3];
};

struct file_system_type___280;

struct super_operations___280;

struct dquot_operations___280;

struct quotactl_ops___280;

struct super_block___280 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___280 *s_type;
	const struct super_operations___280 *s_op;
	const struct dquot_operations___280 *dq_op;
	const struct quotactl_ops___280 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___281 *s_root;
	struct rw_semaphore___282 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___280 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___280 s_dquot;
	struct sb_writers___280 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___280 *s_d_op;
	int cleancache_poolid;
	struct shrinker___115 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

typedef int (*dev_page_fault_t___270)(struct vm_area_struct___282 *, long unsigned int, const struct page___282 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___270)(struct page___282 *, void *);

struct dev_pagemap___270 {
	dev_page_fault_t___270 page_fault;
	dev_page_free_t___270 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___243 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___281 {
	struct task_struct___282 *task;
	struct core_thread___281 *next;
};

struct core_state___281 {
	atomic_t nr_threads;
	struct core_thread___281 dumper;
	struct completion startup;
};

struct vm_fault___270 {
	struct vm_area_struct___282 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___282 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___282 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___281 prealloc_pte;
};

struct kiocb___281 {
	struct file___281 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___281 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___280 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___281 *ia_file;
};

struct dquot___280 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___280 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___280 {
	int qf_fmt_id;
	const struct quota_format_ops___280 *qf_ops;
	struct module___227 *qf_owner;
	struct quota_format_type___280 *qf_next;
};

struct quota_format_ops___280 {
	int (*check_quota_file)(struct super_block___280 *, int);
	int (*read_file_info)(struct super_block___280 *, int);
	int (*write_file_info)(struct super_block___280 *, int);
	int (*free_file_info)(struct super_block___280 *, int);
	int (*read_dqblk)(struct dquot___280 *);
	int (*commit_dqblk)(struct dquot___280 *);
	int (*release_dqblk)(struct dquot___280 *);
	int (*get_next_id)(struct super_block___280 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___280 {
	int (*write_dquot)(struct dquot___280 *);
	struct dquot___280 * (*alloc_dquot)(struct super_block___280 *, int);
	void (*destroy_dquot)(struct dquot___280 *);
	int (*acquire_dquot)(struct dquot___280 *);
	int (*release_dquot)(struct dquot___280 *);
	int (*mark_dirty)(struct dquot___280 *);
	int (*write_info)(struct super_block___280 *, int);
	qsize_t * (*get_reserved_space)(struct inode___281 *);
	int (*get_projid)(struct inode___281 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___281 *, qsize_t *);
	int (*get_next_id)(struct super_block___280 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___280 {
	int (*quota_on)(struct super_block___280 *, int, int, const struct path___281 *);
	int (*quota_off)(struct super_block___280 *, int);
	int (*quota_enable)(struct super_block___280 *, unsigned int);
	int (*quota_disable)(struct super_block___280 *, unsigned int);
	int (*quota_sync)(struct super_block___280 *, int);
	int (*set_info)(struct super_block___280 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___280 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___280 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___280 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___280 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___280 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___280 {
	int (*writepage)(struct page___282 *, struct writeback_control___3 *);
	int (*readpage)(struct file___281 *, struct page___282 *);
	int (*writepages)(struct address_space___280 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___282 *);
	int (*readpages)(struct file___281 *, struct address_space___280 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___281 *, struct address_space___280 *, loff_t, unsigned int, unsigned int, struct page___282 **, void **);
	int (*write_end)(struct file___281 *, struct address_space___280 *, loff_t, unsigned int, unsigned int, struct page___282 *, void *);
	sector_t (*bmap)(struct address_space___280 *, sector_t);
	void (*invalidatepage)(struct page___282 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___282 *, gfp_t);
	void (*freepage)(struct page___282 *);
	ssize_t (*direct_IO)(struct kiocb___281 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___280 *, struct page___282 *, struct page___282 *, enum migrate_mode);
	bool (*isolate_page)(struct page___282 *, isolate_mode_t);
	void (*putback_page)(struct page___282 *);
	int (*launder_page)(struct page___282 *);
	int (*is_partially_uptodate)(struct page___282 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___282 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___280 *, struct page___282 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___281 *, sector_t *);
	void (*swap_deactivate)(struct file___281 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___280 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___281 *bd_inode;
	struct super_block___280 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___280 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___44 {
	struct kobject___268 kobj;
	struct module___227 *owner;
	const struct file_operations___281 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___280 {
	struct dentry___281 * (*lookup)(struct inode___281 *, struct dentry___281 *, unsigned int);
	const char * (*get_link)(struct dentry___281 *, struct inode___281 *, struct delayed_call *);
	int (*permission)(struct inode___281 *, int);
	struct posix_acl * (*get_acl)(struct inode___281 *, int);
	int (*readlink)(struct dentry___281 *, char *, int);
	int (*create)(struct inode___281 *, struct dentry___281 *, umode_t, bool);
	int (*link)(struct dentry___281 *, struct inode___281 *, struct dentry___281 *);
	int (*unlink)(struct inode___281 *, struct dentry___281 *);
	int (*symlink)(struct inode___281 *, struct dentry___281 *, const char *);
	int (*mkdir)(struct inode___281 *, struct dentry___281 *, umode_t);
	int (*rmdir)(struct inode___281 *, struct dentry___281 *);
	int (*mknod)(struct inode___281 *, struct dentry___281 *, umode_t, dev_t);
	int (*rename)(struct inode___281 *, struct dentry___281 *, struct inode___281 *, struct dentry___281 *, unsigned int);
	int (*setattr)(struct dentry___281 *, struct iattr___280 *);
	int (*getattr)(const struct path___281 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___281 *, char *, size_t);
	int (*fiemap)(struct inode___281 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___281 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___281 *, struct dentry___281 *, struct file___281 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___281 *, struct dentry___281 *, umode_t);
	int (*set_acl)(struct inode___281 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___280 {
	void (*fl_copy_lock)(struct file_lock___281 *, struct file_lock___281 *);
	void (*fl_release_private)(struct file_lock___281 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___280;

struct lock_manager_operations___280;

struct file_lock___281 {
	struct file_lock___281 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___281 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___280 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___280 *fl_ops;
	const struct lock_manager_operations___280 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___280 {
	int (*lm_compare_owner)(struct file_lock___281 *, struct file_lock___281 *);
	long unsigned int (*lm_owner_key)(struct file_lock___281 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___281 *);
	int (*lm_grant)(struct file_lock___281 *, int);
	bool (*lm_break)(struct file_lock___281 *);
	int (*lm_change)(struct file_lock___281 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___281 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___280 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___280 *fa_next;
	struct file___281 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___280 {
	const char *name;
	int fs_flags;
	struct dentry___281 * (*mount)(struct file_system_type___280 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___280 *);
	struct module___227 *owner;
	struct file_system_type___280 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___280 {
	struct inode___281 * (*alloc_inode)(struct super_block___280 *);
	void (*destroy_inode)(struct inode___281 *);
	void (*dirty_inode)(struct inode___281 *, int);
	int (*write_inode)(struct inode___281 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___281 *);
	void (*evict_inode)(struct inode___281 *);
	void (*put_super)(struct super_block___280 *);
	int (*sync_fs)(struct super_block___280 *, int);
	int (*freeze_super)(struct super_block___280 *);
	int (*freeze_fs)(struct super_block___280 *);
	int (*thaw_super)(struct super_block___280 *);
	int (*unfreeze_fs)(struct super_block___280 *);
	int (*statfs)(struct dentry___281 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___280 *, int *, char *);
	void (*umount_begin)(struct super_block___280 *);
	int (*show_options)(struct seq_file___244 *, struct dentry___281 *);
	int (*show_devname)(struct seq_file___244 *, struct dentry___281 *);
	int (*show_path)(struct seq_file___244 *, struct dentry___281 *);
	int (*show_stats)(struct seq_file___244 *, struct dentry___281 *);
	ssize_t (*quota_read)(struct super_block___280 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___280 *, int, const char *, size_t, loff_t);
	struct dquot___280 ** (*get_dquots)(struct inode___281 *);
	int (*bdev_try_to_free_page)(struct super_block___280 *, struct page___282 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___280 *, struct shrink_control___115 *);
	long int (*free_cached_objects)(struct super_block___280 *, struct shrink_control___115 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct irqaction___9 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___9 *next;
	irq_handler_t thread_fn;
	struct task_struct___282 *thread;
	struct irqaction___9 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef int (*key_restrict_link_func_t___266)(struct key___265 *, const struct key_type *, const union key_payload *, struct key___265 *);

struct key_restriction___265;

struct key___265 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___282 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___265 *restrict_link;
};

struct key_restriction___265 {
	key_restrict_link_func_t___266 check;
	struct key___265 *key;
	struct key_type *keytype;
};

struct seq_operations___243 {
	void * (*start)(struct seq_file___244 *, loff_t *);
	void (*stop)(struct seq_file___244 *, void *);
	void * (*next)(struct seq_file___244 *, void *, loff_t *);
	int (*show)(struct seq_file___244 *, void *);
};

typedef void compound_page_dtor___270(struct page___282 *);

struct property___43 {
	char *name;
	int length;
	void *value;
	struct property___43 *next;
	long unsigned int _flags;
	struct bin_attribute___244 attr;
};

struct of_phandle_args___3 {
	struct device_node___44 *np;
	int args_count;
	uint32_t args[16];
};

typedef int (*iommu_fault_handler_t___3)(struct iommu_domain___3 *, struct device___243 *, long unsigned int, int, void *);

struct iommu_domain___3 {
	unsigned int type;
	const struct iommu_ops___3 *ops;
	long unsigned int pgsize_bitmap;
	iommu_fault_handler_t___3 handler;
	void *handler_token;
	struct iommu_domain_geometry geometry;
	void *iova_cookie;
};

struct msi_desc___6 {
	struct list_head list;
	unsigned int irq;
	unsigned int nvec_used;
	struct device___243 *dev;
	struct msi_msg msg;
	struct irq_affinity_desc *affinity;
	const void *iommu_cookie;
	union {
		struct {
			u32 masked;
			struct {
				u8 is_msix: 1;
				u8 multiple: 3;
				u8 multi_cap: 3;
				u8 maskbit: 1;
				u8 is_64: 1;
				u16 entry_nr;
				unsigned int default_irq;
			} msi_attrib;
			union {
				u8 mask_pos;
				void *mask_base;
			};
		};
		struct platform_msi_desc platform;
		struct fsl_mc_msi_desc fsl_mc;
	};
};

struct irq_desc___11;

typedef void (*irq_flow_handler_t___11)(struct irq_desc___11 *);

struct irq_common_data___5 {
	unsigned int state_use_accessors;
	unsigned int node;
	void *handler_data;
	struct msi_desc___6 *msi_desc;
	cpumask_var_t affinity;
	cpumask_var_t effective_affinity;
};

struct irq_chip___14;

struct irq_data___14 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___5 *common;
	struct irq_chip___14 *chip;
	struct irq_domain___6 *domain;
	struct irq_data___14 *parent_data;
	void *chip_data;
};

struct irq_desc___11 {
	struct irq_common_data___5 irq_common_data;
	struct irq_data___14 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___11 handle_irq;
	struct irqaction___9 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int irq_count;
	unsigned int tot_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___268 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___227 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct msi_alloc_info___2 {
	struct msi_desc___6 *desc;
	irq_hw_number_t hwirq;
	union {
		long unsigned int ul;
		void *ptr;
	} scratchpad[2];
};

typedef struct msi_alloc_info___2 msi_alloc_info_t___2;

struct msi_domain_info___2;

struct msi_domain_ops___2 {
	irq_hw_number_t (*get_hwirq)(struct msi_domain_info___2 *, msi_alloc_info_t___2 *);
	int (*msi_init)(struct irq_domain___6 *, struct msi_domain_info___2 *, unsigned int, irq_hw_number_t, msi_alloc_info_t___2 *);
	void (*msi_free)(struct irq_domain___6 *, struct msi_domain_info___2 *, unsigned int);
	int (*msi_check)(struct irq_domain___6 *, struct msi_domain_info___2 *, struct device___243 *);
	int (*msi_prepare)(struct irq_domain___6 *, struct device___243 *, int, msi_alloc_info_t___2 *);
	void (*msi_finish)(msi_alloc_info_t___2 *, int);
	void (*set_desc)(msi_alloc_info_t___2 *, struct msi_desc___6 *);
	int (*handle_error)(struct irq_domain___6 *, struct msi_desc___6 *, int);
};

struct msi_domain_info___2 {
	u32 flags;
	struct msi_domain_ops___2 *ops;
	struct irq_chip___14 *chip;
	void *chip_data;
	irq_flow_handler_t___11 handler;
	void *handler_data;
	const char *handler_name;
	void *data;
};

struct irq_chip___14 {
	struct device___243 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___14 *);
	void (*irq_shutdown)(struct irq_data___14 *);
	void (*irq_enable)(struct irq_data___14 *);
	void (*irq_disable)(struct irq_data___14 *);
	void (*irq_ack)(struct irq_data___14 *);
	void (*irq_mask)(struct irq_data___14 *);
	void (*irq_mask_ack)(struct irq_data___14 *);
	void (*irq_unmask)(struct irq_data___14 *);
	void (*irq_eoi)(struct irq_data___14 *);
	int (*irq_set_affinity)(struct irq_data___14 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___14 *);
	int (*irq_set_type)(struct irq_data___14 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___14 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___14 *);
	void (*irq_bus_sync_unlock)(struct irq_data___14 *);
	void (*irq_cpu_online)(struct irq_data___14 *);
	void (*irq_cpu_offline)(struct irq_data___14 *);
	void (*irq_suspend)(struct irq_data___14 *);
	void (*irq_resume)(struct irq_data___14 *);
	void (*irq_pm_shutdown)(struct irq_data___14 *);
	void (*irq_calc_mask)(struct irq_data___14 *);
	void (*irq_print_chip)(struct irq_data___14 *, struct seq_file___244 *);
	int (*irq_request_resources)(struct irq_data___14 *);
	void (*irq_release_resources)(struct irq_data___14 *);
	void (*irq_compose_msi_msg)(struct irq_data___14 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___14 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___14 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___14 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___14 *, void *);
	void (*ipi_send_single)(struct irq_data___14 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___14 *, const struct cpumask *);
	long unsigned int flags;
};

struct irq_chip_type___7 {
	struct irq_chip___14 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___11 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___7 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___7 *);
	void (*resume)(struct irq_chip_generic___7 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___6 *domain;
	struct list_head list;
	struct irq_chip_type___7 chip_types[0];
};

struct irq_domain_chip_generic___6 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___7 *gc[0];
};

struct irq_fwspec___6 {
	struct fwnode_handle___178 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___6 {
	int (*match)(struct irq_domain___6 *, struct device_node___44 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___6 *, struct irq_fwspec___6 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___6 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___6 *, unsigned int);
	int (*xlate)(struct irq_domain___6 *, struct device_node___44 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___6 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___6 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___6 *, struct irq_data___14 *, bool);
	void (*deactivate)(struct irq_domain___6 *, struct irq_data___14 *);
	int (*translate)(struct irq_domain___6 *, struct irq_fwspec___6 *, long unsigned int *, unsigned int *);
};

struct v2m_data {
	struct list_head entry;
	struct fwnode_handle___178 *fwnode;
	struct resource res;
	void *base;
	u32 spi_start;
	u32 nr_spis;
	u32 spi_offset;
	long unsigned int *bm;
	u32 flags;
};

struct acpi_madt_generic_redistributor {
	struct acpi_subtable_header header;
	u16 reserved;
	u64 base_address;
	u32 length;
} __attribute__((packed));

typedef int (*of_init_fn_2___2)(struct device_node___44 *, struct device_node___44 *);

struct rdists {
	struct {
		void *rd_base;
		struct page___282 *pend_page;
		phys_addr_t phys_base;
		bool lpi_enabled;
	} *rdist;
	phys_addr_t prop_table_pa;
	void *prop_table_va;
	u64 flags;
	u32 gicd_typer;
	bool has_vlpis;
	bool has_direct_lpi;
};

struct partition_affinity {
	cpumask_t mask;
	void *partition_id;
};

struct redist_region {
	void *redist_base;
	phys_addr_t phys_base;
	bool single_redist;
};

struct partition_desc;

struct gic_chip_data___2 {
	struct fwnode_handle___178 *fwnode;
	void *dist_base;
	struct redist_region *redist_regions;
	struct rdists rdists;
	struct irq_domain___6 *domain;
	u64 redist_stride;
	u32 nr_redist_regions;
	bool has_rss;
	unsigned int irq_nr;
	struct partition_desc *ppi_descs[16];
};

struct file___282;

struct kiocb___282;

struct vm_area_struct___283;

struct inode___282;

struct file_lock___282;

struct page___283;

struct file_operations___282 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___282 *, loff_t, int);
	ssize_t (*read)(struct file___282 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___282 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___282 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___282 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___282 *, bool);
	int (*iterate)(struct file___282 *, struct dir_context *);
	int (*iterate_shared)(struct file___282 *, struct dir_context *);
	__poll_t (*poll)(struct file___282 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___282 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___282 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___282 *, struct vm_area_struct___283 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___282 *, struct file___282 *);
	int (*flush)(struct file___282 *, fl_owner_t);
	int (*release)(struct inode___282 *, struct file___282 *);
	int (*fsync)(struct file___282 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___282 *, int);
	int (*lock)(struct file___282 *, int, struct file_lock___282 *);
	ssize_t (*sendpage)(struct file___282 *, struct page___283 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___282 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___282 *, int, struct file_lock___282 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___282 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___282 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___282 *, long int, struct file_lock___282 **, void **);
	long int (*fallocate)(struct file___282 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___282 *);
	ssize_t (*copy_file_range)(struct file___282 *, loff_t, struct file___282 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___282 *, loff_t, struct file___282 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___282 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___282 {
	u64 seqnum;
	struct vm_area_struct___283 *vmas[4];
};

struct page_frag___282 {
	struct page___283 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___282;

struct vm_struct___198;

struct task_struct___283 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___283 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___282 *mm;
	struct mm_struct___282 *active_mm;
	struct vmacache___282 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___283 *real_parent;
	struct task_struct___283 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___283 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___193 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___193 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___193 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___2 *ptracer_cred;
	const struct cred___2 *real_cred;
	const struct cred___2 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___283 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___82 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___282 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___283 *oom_reaper_list;
	struct vm_struct___198 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___130 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___283 *pgtable_t___282;

struct address_space___281;

struct dev_pagemap___271;

struct page___283 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___281 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___283 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___282 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___282 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___271 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___282;

struct lruvec___282 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___282 *pgdat;
};

struct zone___282 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___282 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___282 {
	struct zone___282 *zone;
	int zone_idx;
};

struct zonelist___282 {
	struct zoneref___282 _zonerefs[25];
};

struct pglist_data___282 {
	struct zone___282 node_zones[3];
	struct zonelist___282 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___283 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___283 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___282 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___283 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___283 *owner;
};

struct secondary_data___283 {
	void *stack;
	struct task_struct___283 *task;
	long int status;
};

struct blocking_notifier_head___282 {
	struct rw_semaphore___283 rwsem;
	struct notifier_block *head;
};

struct kernfs_root___275;

struct kernfs_elem_dir___275 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___275 *root;
};

struct kernfs_node___276;

struct kernfs_syscall_ops___275;

struct kernfs_root___275 {
	struct kernfs_node___276 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___275 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___275 {
	struct kernfs_node___276 *target_kn;
};

struct kernfs_ops___275;

struct kernfs_elem_attr___275 {
	const struct kernfs_ops___275 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___276 *notify_next;
};

struct kernfs_node___276 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___276 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___275 dir;
		struct kernfs_elem_symlink___275 symlink;
		struct kernfs_elem_attr___275 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___275;

struct kernfs_ops___275 {
	int (*open)(struct kernfs_open_file___275 *);
	void (*release)(struct kernfs_open_file___275 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___275 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___275 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___275 *, struct vm_area_struct___283 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___275 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___275 {
	int (*remount_fs)(struct kernfs_root___275 *, int *, char *);
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___275 *);
	int (*mkdir)(struct kernfs_node___276 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___276 *);
	int (*rename)(struct kernfs_node___276 *, struct kernfs_node___276 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___276 *, struct kernfs_root___275 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_operations_struct___271;

struct kernfs_open_file___275 {
	struct kernfs_node___276 *kn;
	struct file___282 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___271 *vm_ops;
};

struct dentry___282;

struct path___282 {
	struct vfsmount *mnt;
	struct dentry___282 *dentry;
};

struct file___282 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___282 f_path;
	struct inode___282 *f_inode;
	const struct file_operations___282 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___193 f_owner;
	const struct cred___2 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___281 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___271;

struct vm_operations_struct___271 {
	void (*open)(struct vm_area_struct___283 *);
	void (*close)(struct vm_area_struct___283 *);
	int (*split)(struct vm_area_struct___283 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___283 *);
	vm_fault_t (*fault)(struct vm_fault___271 *);
	vm_fault_t (*huge_fault)(struct vm_fault___271 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___271 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___283 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___271 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___271 *);
	int (*access)(struct vm_area_struct___283 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___283 *);
	int (*set_policy)(struct vm_area_struct___283 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___283 *, long unsigned int);
	struct page___283 * (*find_special_page)(struct vm_area_struct___283 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_area_struct___283 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___283 *vm_next;
	struct vm_area_struct___283 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___282 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___271 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___282 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___269;

struct bin_attribute___245;

struct attribute_group___246 {
	const char *name;
	umode_t (*is_visible)(struct kobject___269 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___269 *, struct bin_attribute___245 *, int);
	struct attribute **attrs;
	struct bin_attribute___245 **bin_attrs;
};

struct kset___268;

struct kobj_type___268;

struct kobject___269 {
	const char *name;
	struct list_head entry;
	struct kobject___269 *parent;
	struct kset___268 *kset;
	struct kobj_type___268 *ktype;
	struct kernfs_node___276 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___245 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___282 *, struct kobject___269 *, struct bin_attribute___245 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___282 *, struct kobject___269 *, struct bin_attribute___245 *, char *, loff_t, size_t);
	int (*mmap)(struct file___282 *, struct kobject___269 *, struct bin_attribute___245 *, struct vm_area_struct___283 *);
};

struct sysfs_ops___268 {
	ssize_t (*show)(struct kobject___269 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___269 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___268;

struct kset___268 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___269 kobj;
	const struct kset_uevent_ops___268 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___268 {
	void (*release)(struct kobject___269 *);
	const struct sysfs_ops___268 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___25 * (*child_ns_type)(struct kobject___269 *);
	const void * (*namespace)(struct kobject___269 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___268 {
	int (* const filter)(struct kset___268 *, struct kobject___269 *);
	const char * (* const name)(struct kset___268 *, struct kobject___269 *);
	int (* const uevent)(struct kset___268 *, struct kobject___269 *, struct kobj_uevent_env *);
};

struct kobj_attribute___261 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___269 *, struct kobj_attribute___261 *, char *);
	ssize_t (*store)(struct kobject___269 *, struct kobj_attribute___261 *, const char *, size_t);
};

struct device___244;

struct dev_pm_ops___244 {
	int (*prepare)(struct device___244 *);
	void (*complete)(struct device___244 *);
	int (*suspend)(struct device___244 *);
	int (*resume)(struct device___244 *);
	int (*freeze)(struct device___244 *);
	int (*thaw)(struct device___244 *);
	int (*poweroff)(struct device___244 *);
	int (*restore)(struct device___244 *);
	int (*suspend_late)(struct device___244 *);
	int (*resume_early)(struct device___244 *);
	int (*freeze_late)(struct device___244 *);
	int (*thaw_early)(struct device___244 *);
	int (*poweroff_late)(struct device___244 *);
	int (*restore_early)(struct device___244 *);
	int (*suspend_noirq)(struct device___244 *);
	int (*resume_noirq)(struct device___244 *);
	int (*freeze_noirq)(struct device___244 *);
	int (*thaw_noirq)(struct device___244 *);
	int (*poweroff_noirq)(struct device___244 *);
	int (*restore_noirq)(struct device___244 *);
	int (*runtime_suspend)(struct device___244 *);
	int (*runtime_resume)(struct device___244 *);
	int (*runtime_idle)(struct device___244 *);
};

struct dev_pm_info___244 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___244 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___244;

struct bus_type___244;

struct device_driver___244;

struct dev_pm_domain___244;

struct irq_domain___7;

struct dma_map_ops___69;

struct device_node___45;

struct fwnode_handle___179;

struct class___244;

struct iommu_fwspec___4;

struct device___244 {
	struct device___244 *parent;
	struct device_private *p;
	struct kobject___269 kobj;
	const char *init_name;
	const struct device_type___244 *type;
	struct mutex mutex;
	struct bus_type___244 *bus;
	struct device_driver___244 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___244 power;
	struct dev_pm_domain___244 *pm_domain;
	struct irq_domain___7 *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___69 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___45 *of_node;
	struct fwnode_handle___179 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___244 *class;
	const struct attribute_group___246 **groups;
	void (*release)(struct device___244 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec___4 *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___244 {
	struct dev_pm_ops___244 ops;
	void (*detach)(struct device___244 *, bool);
	int (*activate)(struct device___244 *);
	void (*sync)(struct device___244 *);
	void (*dismiss)(struct device___244 *);
};

struct core_state___282;

struct mm_struct___282 {
	struct {
		struct vm_area_struct___283 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___282 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___283 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___282 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___283 *owner;
		struct user_namespace___3 *user_ns;
		struct file___282 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___282 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct vm_struct___198 {
	struct vm_struct___198 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___283 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct iommu_ops___4;

struct bus_type___244 {
	const char *name;
	const char *dev_name;
	struct device___244 *dev_root;
	const struct attribute_group___246 **bus_groups;
	const struct attribute_group___246 **dev_groups;
	const struct attribute_group___246 **drv_groups;
	int (*match)(struct device___244 *, struct device_driver___244 *);
	int (*uevent)(struct device___244 *, struct kobj_uevent_env *);
	int (*probe)(struct device___244 *);
	int (*remove)(struct device___244 *);
	void (*shutdown)(struct device___244 *);
	int (*online)(struct device___244 *);
	int (*offline)(struct device___244 *);
	int (*suspend)(struct device___244 *, pm_message_t);
	int (*resume)(struct device___244 *);
	int (*num_vf)(struct device___244 *);
	int (*dma_configure)(struct device___244 *);
	const struct dev_pm_ops___244 *pm;
	const struct iommu_ops___4 *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___244 {
	const char *name;
	struct bus_type___244 *bus;
	struct module___11 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___244 *);
	int (*remove)(struct device___244 *);
	void (*shutdown)(struct device___244 *);
	int (*suspend)(struct device___244 *, pm_message_t);
	int (*resume)(struct device___244 *);
	const struct attribute_group___246 **groups;
	const struct dev_pm_ops___244 *pm;
	void (*coredump)(struct device___244 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct iommu_domain___4;

struct of_phandle_args___4;

struct iommu_ops___4 {
	bool (*capable)(enum iommu_cap);
	struct iommu_domain___4 * (*domain_alloc)(unsigned int);
	void (*domain_free)(struct iommu_domain___4 *);
	int (*attach_dev)(struct iommu_domain___4 *, struct device___244 *);
	void (*detach_dev)(struct iommu_domain___4 *, struct device___244 *);
	int (*map)(struct iommu_domain___4 *, long unsigned int, phys_addr_t, size_t, int);
	size_t (*unmap)(struct iommu_domain___4 *, long unsigned int, size_t);
	void (*flush_iotlb_all)(struct iommu_domain___4 *);
	void (*iotlb_range_add)(struct iommu_domain___4 *, long unsigned int, size_t);
	void (*iotlb_sync)(struct iommu_domain___4 *);
	phys_addr_t (*iova_to_phys)(struct iommu_domain___4 *, dma_addr_t);
	int (*add_device)(struct device___244 *);
	void (*remove_device)(struct device___244 *);
	struct iommu_group * (*device_group)(struct device___244 *);
	int (*domain_get_attr)(struct iommu_domain___4 *, enum iommu_attr, void *);
	int (*domain_set_attr)(struct iommu_domain___4 *, enum iommu_attr, void *);
	void (*get_resv_regions)(struct device___244 *, struct list_head *);
	void (*put_resv_regions)(struct device___244 *, struct list_head *);
	void (*apply_resv_region)(struct device___244 *, struct iommu_domain___4 *, struct iommu_resv_region *);
	int (*domain_window_enable)(struct iommu_domain___4 *, u32, phys_addr_t, u64, int);
	void (*domain_window_disable)(struct iommu_domain___4 *, u32);
	int (*domain_set_windows)(struct iommu_domain___4 *, u32);
	u32 (*domain_get_windows)(struct iommu_domain___4 *);
	int (*of_xlate)(struct device___244 *, struct of_phandle_args___4 *);
	bool (*is_attach_deferred)(struct iommu_domain___4 *, struct device___244 *);
	long unsigned int pgsize_bitmap;
};

struct device_type___244 {
	const char *name;
	const struct attribute_group___246 **groups;
	int (*uevent)(struct device___244 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___244 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___244 *);
	const struct dev_pm_ops___244 *pm;
};

struct class___244 {
	const char *name;
	struct module___11 *owner;
	const struct attribute_group___246 **class_groups;
	const struct attribute_group___246 **dev_groups;
	struct kobject___269 *dev_kobj;
	int (*dev_uevent)(struct device___244 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___244 *, umode_t *);
	void (*class_release)(struct class___244 *);
	void (*dev_release)(struct device___244 *);
	int (*shutdown_pre)(struct device___244 *);
	const struct kobj_ns_type_operations___25 *ns_type;
	const void * (*namespace)(struct device___244 *);
	const struct dev_pm_ops___244 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct irq_domain_ops___7;

struct irq_domain_chip_generic___7;

struct irq_domain___7 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___7 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___179 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___7 *gc;
	struct irq_domain___7 *parent;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_direct_max_irq;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_tree_mutex;
	unsigned int linear_revmap[0];
};

struct dma_map_ops___69 {
	void * (*alloc)(struct device___244 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___244 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___244 *, struct vm_area_struct___283 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___244 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___244 *, struct page___283 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___244 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___244 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___244 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___244 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___244 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___244 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___244 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___244 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___244 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___244 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___244 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___244 *, u64);
	u64 (*get_required_mask)(struct device___244 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___179;

struct fwnode_handle___179 {
	struct fwnode_handle___179 *secondary;
	const struct fwnode_operations___179 *ops;
};

struct property___44;

struct device_node___45 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___179 fwnode;
	struct property___44 *properties;
	struct property___44 *deadprops;
	struct device_node___45 *parent;
	struct device_node___45 *child;
	struct device_node___45 *sibling;
	struct kobject___269 kobj;
	long unsigned int _flags;
	void *data;
};

struct iommu_fwspec___4 {
	const struct iommu_ops___4 *ops;
	struct fwnode_handle___179 *iommu_fwnode;
	void *iommu_priv;
	unsigned int num_ids;
	u32 ids[1];
};

struct address_space_operations___281;

struct address_space___281 {
	struct inode___282 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___283 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___281 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___271)(struct vm_area_struct___283 *, long unsigned int, const struct page___283 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___271)(struct page___283 *, void *);

struct dev_pagemap___271 {
	dev_page_fault_t___271 page_fault;
	dev_page_free_t___271 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___244 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___282 {
	struct task_struct___283 *task;
	struct core_thread___282 *next;
};

struct core_state___282 {
	atomic_t nr_threads;
	struct core_thread___282 dumper;
	struct completion startup;
};

struct vm_fault___271 {
	struct vm_area_struct___283 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___283 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___283 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___282 prealloc_pte;
};

struct dentry_operations___281;

struct super_block___281;

struct dentry___282 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___282 *d_parent;
	struct qstr d_name;
	struct inode___282 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___281 *d_op;
	struct super_block___281 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___281;

struct block_device___281;

struct inode___282 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___281 *i_op;
	struct super_block___281 *i_sb;
	struct address_space___281 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___283 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___282 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___281 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___281 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___281 {
	int (*d_revalidate)(struct dentry___282 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___282 *, unsigned int);
	int (*d_hash)(const struct dentry___282 *, struct qstr *);
	int (*d_compare)(const struct dentry___282 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___282 *);
	int (*d_init)(struct dentry___282 *);
	void (*d_release)(struct dentry___282 *);
	void (*d_prune)(struct dentry___282 *);
	void (*d_iput)(struct dentry___282 *, struct inode___282 *);
	char * (*d_dname)(struct dentry___282 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___282 *);
	int (*d_manage)(const struct path___282 *, bool);
	struct dentry___282 * (*d_real)(struct dentry___282 *, const struct inode___282 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___281;

struct mem_dqinfo___281 {
	struct quota_format_type___281 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___281;

struct quota_info___281 {
	unsigned int flags;
	struct rw_semaphore___283 dqio_sem;
	struct inode___282 *files[3];
	struct mem_dqinfo___281 info[3];
	const struct quota_format_ops___281 *ops[3];
};

struct rcuwait___281 {
	struct task_struct___283 *task;
};

struct percpu_rw_semaphore___281 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___283 rw_sem;
	struct rcuwait___281 writer;
	int readers_block;
};

struct sb_writers___281 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___281 rw_sem[3];
};

struct file_system_type___281;

struct super_operations___281;

struct dquot_operations___281;

struct quotactl_ops___281;

struct super_block___281 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___281 *s_type;
	const struct super_operations___281 *s_op;
	const struct dquot_operations___281 *dq_op;
	const struct quotactl_ops___281 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___282 *s_root;
	struct rw_semaphore___283 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___281 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___281 s_dquot;
	struct sb_writers___281 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___281 *s_d_op;
	int cleancache_poolid;
	struct shrinker___115 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___282 {
	struct file___282 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___282 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___281 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___282 *ia_file;
};

struct dquot___281 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___281 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___281 {
	int qf_fmt_id;
	const struct quota_format_ops___281 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___281 *qf_next;
};

struct quota_format_ops___281 {
	int (*check_quota_file)(struct super_block___281 *, int);
	int (*read_file_info)(struct super_block___281 *, int);
	int (*write_file_info)(struct super_block___281 *, int);
	int (*free_file_info)(struct super_block___281 *, int);
	int (*read_dqblk)(struct dquot___281 *);
	int (*commit_dqblk)(struct dquot___281 *);
	int (*release_dqblk)(struct dquot___281 *);
	int (*get_next_id)(struct super_block___281 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___281 {
	int (*write_dquot)(struct dquot___281 *);
	struct dquot___281 * (*alloc_dquot)(struct super_block___281 *, int);
	void (*destroy_dquot)(struct dquot___281 *);
	int (*acquire_dquot)(struct dquot___281 *);
	int (*release_dquot)(struct dquot___281 *);
	int (*mark_dirty)(struct dquot___281 *);
	int (*write_info)(struct super_block___281 *, int);
	qsize_t * (*get_reserved_space)(struct inode___282 *);
	int (*get_projid)(struct inode___282 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___282 *, qsize_t *);
	int (*get_next_id)(struct super_block___281 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___281 {
	int (*quota_on)(struct super_block___281 *, int, int, const struct path___282 *);
	int (*quota_off)(struct super_block___281 *, int);
	int (*quota_enable)(struct super_block___281 *, unsigned int);
	int (*quota_disable)(struct super_block___281 *, unsigned int);
	int (*quota_sync)(struct super_block___281 *, int);
	int (*set_info)(struct super_block___281 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___281 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___281 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___281 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___281 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___281 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___281 {
	int (*writepage)(struct page___283 *, struct writeback_control___3 *);
	int (*readpage)(struct file___282 *, struct page___283 *);
	int (*writepages)(struct address_space___281 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___283 *);
	int (*readpages)(struct file___282 *, struct address_space___281 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___282 *, struct address_space___281 *, loff_t, unsigned int, unsigned int, struct page___283 **, void **);
	int (*write_end)(struct file___282 *, struct address_space___281 *, loff_t, unsigned int, unsigned int, struct page___283 *, void *);
	sector_t (*bmap)(struct address_space___281 *, sector_t);
	void (*invalidatepage)(struct page___283 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___283 *, gfp_t);
	void (*freepage)(struct page___283 *);
	ssize_t (*direct_IO)(struct kiocb___282 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___281 *, struct page___283 *, struct page___283 *, enum migrate_mode);
	bool (*isolate_page)(struct page___283 *, isolate_mode_t);
	void (*putback_page)(struct page___283 *);
	int (*launder_page)(struct page___283 *);
	int (*is_partially_uptodate)(struct page___283 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___283 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___281 *, struct page___283 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___282 *, sector_t *);
	void (*swap_deactivate)(struct file___282 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___281 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___282 *bd_inode;
	struct super_block___281 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___281 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___281 {
	struct dentry___282 * (*lookup)(struct inode___282 *, struct dentry___282 *, unsigned int);
	const char * (*get_link)(struct dentry___282 *, struct inode___282 *, struct delayed_call *);
	int (*permission)(struct inode___282 *, int);
	struct posix_acl * (*get_acl)(struct inode___282 *, int);
	int (*readlink)(struct dentry___282 *, char *, int);
	int (*create)(struct inode___282 *, struct dentry___282 *, umode_t, bool);
	int (*link)(struct dentry___282 *, struct inode___282 *, struct dentry___282 *);
	int (*unlink)(struct inode___282 *, struct dentry___282 *);
	int (*symlink)(struct inode___282 *, struct dentry___282 *, const char *);
	int (*mkdir)(struct inode___282 *, struct dentry___282 *, umode_t);
	int (*rmdir)(struct inode___282 *, struct dentry___282 *);
	int (*mknod)(struct inode___282 *, struct dentry___282 *, umode_t, dev_t);
	int (*rename)(struct inode___282 *, struct dentry___282 *, struct inode___282 *, struct dentry___282 *, unsigned int);
	int (*setattr)(struct dentry___282 *, struct iattr___281 *);
	int (*getattr)(const struct path___282 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___282 *, char *, size_t);
	int (*fiemap)(struct inode___282 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___282 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___282 *, struct dentry___282 *, struct file___282 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___282 *, struct dentry___282 *, umode_t);
	int (*set_acl)(struct inode___282 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___281 {
	void (*fl_copy_lock)(struct file_lock___282 *, struct file_lock___282 *);
	void (*fl_release_private)(struct file_lock___282 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___281;

struct lock_manager_operations___281;

struct file_lock___282 {
	struct file_lock___282 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___282 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___281 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___281 *fl_ops;
	const struct lock_manager_operations___281 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___281 {
	int (*lm_compare_owner)(struct file_lock___282 *, struct file_lock___282 *);
	long unsigned int (*lm_owner_key)(struct file_lock___282 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___282 *);
	int (*lm_grant)(struct file_lock___282 *, int);
	bool (*lm_break)(struct file_lock___282 *);
	int (*lm_change)(struct file_lock___282 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___282 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___281 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___281 *fa_next;
	struct file___282 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___281 {
	const char *name;
	int fs_flags;
	struct dentry___282 * (*mount)(struct file_system_type___281 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___281 *);
	struct module___11 *owner;
	struct file_system_type___281 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___281 {
	struct inode___282 * (*alloc_inode)(struct super_block___281 *);
	void (*destroy_inode)(struct inode___282 *);
	void (*dirty_inode)(struct inode___282 *, int);
	int (*write_inode)(struct inode___282 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___282 *);
	void (*evict_inode)(struct inode___282 *);
	void (*put_super)(struct super_block___281 *);
	int (*sync_fs)(struct super_block___281 *, int);
	int (*freeze_super)(struct super_block___281 *);
	int (*freeze_fs)(struct super_block___281 *);
	int (*thaw_super)(struct super_block___281 *);
	int (*unfreeze_fs)(struct super_block___281 *);
	int (*statfs)(struct dentry___282 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___281 *, int *, char *);
	void (*umount_begin)(struct super_block___281 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___282 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___282 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___282 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___282 *);
	ssize_t (*quota_read)(struct super_block___281 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___281 *, int, const char *, size_t, loff_t);
	struct dquot___281 ** (*get_dquots)(struct inode___282 *);
	int (*bdev_try_to_free_page)(struct super_block___281 *, struct page___283 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___281 *, struct shrink_control___115 *);
	long int (*free_cached_objects)(struct super_block___281 *, struct shrink_control___115 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___271(struct page___283 *);

struct fwnode_reference_args___179;

struct fwnode_endpoint___179;

struct fwnode_operations___179 {
	struct fwnode_handle___179 * (*get)(struct fwnode_handle___179 *);
	void (*put)(struct fwnode_handle___179 *);
	bool (*device_is_available)(const struct fwnode_handle___179 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___179 *, const struct device___244 *);
	bool (*property_present)(const struct fwnode_handle___179 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___179 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___179 *, const char *, const char **, size_t);
	struct fwnode_handle___179 * (*get_parent)(const struct fwnode_handle___179 *);
	struct fwnode_handle___179 * (*get_next_child_node)(const struct fwnode_handle___179 *, struct fwnode_handle___179 *);
	struct fwnode_handle___179 * (*get_named_child_node)(const struct fwnode_handle___179 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___179 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___179 *);
	struct fwnode_handle___179 * (*graph_get_next_endpoint)(const struct fwnode_handle___179 *, struct fwnode_handle___179 *);
	struct fwnode_handle___179 * (*graph_get_remote_endpoint)(const struct fwnode_handle___179 *);
	struct fwnode_handle___179 * (*graph_get_port_parent)(struct fwnode_handle___179 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___179 *, struct fwnode_endpoint___179 *);
};

struct fwnode_endpoint___179 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___179 *local_fwnode;
};

struct fwnode_reference_args___179 {
	struct fwnode_handle___179 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct property___44 {
	char *name;
	int length;
	void *value;
	struct property___44 *next;
	long unsigned int _flags;
	struct bin_attribute___245 attr;
};

struct of_phandle_args___4 {
	struct device_node___45 *np;
	int args_count;
	uint32_t args[16];
};

typedef int (*iommu_fault_handler_t___4)(struct iommu_domain___4 *, struct device___244 *, long unsigned int, int, void *);

struct iommu_domain___4 {
	unsigned int type;
	const struct iommu_ops___4 *ops;
	long unsigned int pgsize_bitmap;
	iommu_fault_handler_t___4 handler;
	void *handler_token;
	struct iommu_domain_geometry geometry;
	void *iova_cookie;
};

struct msi_desc___7 {
	struct list_head list;
	unsigned int irq;
	unsigned int nvec_used;
	struct device___244 *dev;
	struct msi_msg msg;
	struct irq_affinity_desc *affinity;
	const void *iommu_cookie;
	union {
		struct {
			u32 masked;
			struct {
				u8 is_msix: 1;
				u8 multiple: 3;
				u8 multi_cap: 3;
				u8 maskbit: 1;
				u8 is_64: 1;
				u16 entry_nr;
				unsigned int default_irq;
			} msi_attrib;
			union {
				u8 mask_pos;
				void *mask_base;
			};
		};
		struct platform_msi_desc platform;
		struct fsl_mc_msi_desc fsl_mc;
	};
};

struct irq_desc___12;

typedef void (*irq_flow_handler_t___12)(struct irq_desc___12 *);

struct irq_common_data___6 {
	unsigned int state_use_accessors;
	unsigned int node;
	void *handler_data;
	struct msi_desc___7 *msi_desc;
	cpumask_var_t affinity;
	cpumask_var_t effective_affinity;
};

struct irq_chip___15;

struct irq_data___15 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___6 *common;
	struct irq_chip___15 *chip;
	struct irq_domain___7 *domain;
	struct irq_data___15 *parent_data;
	void *chip_data;
};

struct irqaction___10;

struct irq_desc___12 {
	struct irq_common_data___6 irq_common_data;
	struct irq_data___15 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___12 handle_irq;
	struct irqaction___10 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int irq_count;
	unsigned int tot_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___269 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___11 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct msi_alloc_info___3 {
	struct msi_desc___7 *desc;
	irq_hw_number_t hwirq;
	union {
		long unsigned int ul;
		void *ptr;
	} scratchpad[2];
};

typedef struct msi_alloc_info___3 msi_alloc_info_t___3;

struct msi_domain_info___3;

struct msi_domain_ops___3 {
	irq_hw_number_t (*get_hwirq)(struct msi_domain_info___3 *, msi_alloc_info_t___3 *);
	int (*msi_init)(struct irq_domain___7 *, struct msi_domain_info___3 *, unsigned int, irq_hw_number_t, msi_alloc_info_t___3 *);
	void (*msi_free)(struct irq_domain___7 *, struct msi_domain_info___3 *, unsigned int);
	int (*msi_check)(struct irq_domain___7 *, struct msi_domain_info___3 *, struct device___244 *);
	int (*msi_prepare)(struct irq_domain___7 *, struct device___244 *, int, msi_alloc_info_t___3 *);
	void (*msi_finish)(msi_alloc_info_t___3 *, int);
	void (*set_desc)(msi_alloc_info_t___3 *, struct msi_desc___7 *);
	int (*handle_error)(struct irq_domain___7 *, struct msi_desc___7 *, int);
};

struct msi_domain_info___3 {
	u32 flags;
	struct msi_domain_ops___3 *ops;
	struct irq_chip___15 *chip;
	void *chip_data;
	irq_flow_handler_t___12 handler;
	void *handler_data;
	const char *handler_name;
	void *data;
};

struct irq_chip___15 {
	struct device___244 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___15 *);
	void (*irq_shutdown)(struct irq_data___15 *);
	void (*irq_enable)(struct irq_data___15 *);
	void (*irq_disable)(struct irq_data___15 *);
	void (*irq_ack)(struct irq_data___15 *);
	void (*irq_mask)(struct irq_data___15 *);
	void (*irq_mask_ack)(struct irq_data___15 *);
	void (*irq_unmask)(struct irq_data___15 *);
	void (*irq_eoi)(struct irq_data___15 *);
	int (*irq_set_affinity)(struct irq_data___15 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___15 *);
	int (*irq_set_type)(struct irq_data___15 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___15 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___15 *);
	void (*irq_bus_sync_unlock)(struct irq_data___15 *);
	void (*irq_cpu_online)(struct irq_data___15 *);
	void (*irq_cpu_offline)(struct irq_data___15 *);
	void (*irq_suspend)(struct irq_data___15 *);
	void (*irq_resume)(struct irq_data___15 *);
	void (*irq_pm_shutdown)(struct irq_data___15 *);
	void (*irq_calc_mask)(struct irq_data___15 *);
	void (*irq_print_chip)(struct irq_data___15 *, struct seq_file___9 *);
	int (*irq_request_resources)(struct irq_data___15 *);
	void (*irq_release_resources)(struct irq_data___15 *);
	void (*irq_compose_msi_msg)(struct irq_data___15 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___15 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___15 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___15 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___15 *, void *);
	void (*ipi_send_single)(struct irq_data___15 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___15 *, const struct cpumask *);
	long unsigned int flags;
};

struct irqaction___10 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___10 *next;
	irq_handler_t thread_fn;
	struct task_struct___283 *thread;
	struct irqaction___10 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip_type___8 {
	struct irq_chip___15 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___12 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___8 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___8 *);
	void (*resume)(struct irq_chip_generic___8 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___7 *domain;
	struct list_head list;
	struct irq_chip_type___8 chip_types[0];
};

struct irq_domain_chip_generic___7 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___8 *gc[0];
};

struct irq_fwspec___7 {
	struct fwnode_handle___179 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___7 {
	int (*match)(struct irq_domain___7 *, struct device_node___45 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___7 *, struct irq_fwspec___7 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___7 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___7 *, unsigned int);
	int (*xlate)(struct irq_domain___7 *, struct device_node___45 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___7 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___7 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___7 *, struct irq_data___15 *, bool);
	void (*deactivate)(struct irq_domain___7 *, struct irq_data___15 *);
	int (*translate)(struct irq_domain___7 *, struct irq_fwspec___7 *, long unsigned int *, unsigned int *);
};

struct mbi_range {
	u32 spi_start;
	u32 nr_spis;
	long unsigned int *bm;
};

struct module___228;

struct file___283;

struct kiocb___283;

struct poll_table_struct___172;

struct vm_area_struct___284;

struct inode___283;

struct file_lock___283;

struct page___284;

struct seq_file___245;

struct file_operations___283 {
	struct module___228 *owner;
	loff_t (*llseek)(struct file___283 *, loff_t, int);
	ssize_t (*read)(struct file___283 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___283 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___283 *, struct iov_iter___136 *);
	ssize_t (*write_iter)(struct kiocb___283 *, struct iov_iter___136 *);
	int (*iopoll)(struct kiocb___283 *, bool);
	int (*iterate)(struct file___283 *, struct dir_context *);
	int (*iterate_shared)(struct file___283 *, struct dir_context *);
	__poll_t (*poll)(struct file___283 *, struct poll_table_struct___172 *);
	long int (*unlocked_ioctl)(struct file___283 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___283 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___283 *, struct vm_area_struct___284 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___283 *, struct file___283 *);
	int (*flush)(struct file___283 *, fl_owner_t);
	int (*release)(struct inode___283 *, struct file___283 *);
	int (*fsync)(struct file___283 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___283 *, int);
	int (*lock)(struct file___283 *, int, struct file_lock___283 *);
	ssize_t (*sendpage)(struct file___283 *, struct page___284 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___283 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___283 *, int, struct file_lock___283 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___283 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___283 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___283 *, long int, struct file_lock___283 **, void **);
	long int (*fallocate)(struct file___283 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___245 *, struct file___283 *);
	ssize_t (*copy_file_range)(struct file___283 *, loff_t, struct file___283 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___283 *, loff_t, struct file___283 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___283 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___283 {
	u64 seqnum;
	struct vm_area_struct___284 *vmas[4];
};

struct page_frag___283 {
	struct page___284 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___283;

struct pid___194;

struct cred___266;

struct nsproxy___241;

struct signal_struct___219;

struct vm_struct___199;

struct task_struct___284 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___284 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___283 *mm;
	struct mm_struct___283 *active_mm;
	struct vmacache___283 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___284 *real_parent;
	struct task_struct___284 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___284 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___194 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___194 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___194 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___266 *ptracer_cred;
	const struct cred___266 *real_cred;
	const struct cred___266 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___241 *nsproxy;
	struct signal_struct___219 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___284 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___82 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___283 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___284 *oom_reaper_list;
	struct vm_struct___199 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___130 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___284 *pgtable_t___283;

struct address_space___282;

struct dev_pagemap___272;

struct page___284 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___282 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___284 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___283 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___283 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___272 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___283;

struct lruvec___283 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___283 *pgdat;
};

struct zone___283 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___283 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___283 {
	struct zone___283 *zone;
	int zone_idx;
};

struct zonelist___283 {
	struct zoneref___283 _zonerefs[25];
};

struct pglist_data___283 {
	struct zone___283 node_zones[3];
	struct zonelist___283 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___284 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___284 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___283 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___284 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___284 *owner;
};

struct secondary_data___284 {
	void *stack;
	struct task_struct___284 *task;
	long int status;
};

struct blocking_notifier_head___283 {
	struct rw_semaphore___284 rwsem;
	struct notifier_block *head;
};

struct kernfs_root___276;

struct kernfs_elem_dir___276 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___276 *root;
};

struct kernfs_node___277;

struct kernfs_syscall_ops___276;

struct kernfs_root___276 {
	struct kernfs_node___277 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___276 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___276 {
	struct kernfs_node___277 *target_kn;
};

struct kernfs_ops___276;

struct kernfs_elem_attr___276 {
	const struct kernfs_ops___276 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___277 *notify_next;
};

struct kernfs_node___277 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___277 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___276 dir;
		struct kernfs_elem_symlink___276 symlink;
		struct kernfs_elem_attr___276 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___276;

struct kernfs_ops___276 {
	int (*open)(struct kernfs_open_file___276 *);
	void (*release)(struct kernfs_open_file___276 *);
	int (*seq_show)(struct seq_file___245 *, void *);
	void * (*seq_start)(struct seq_file___245 *, loff_t *);
	void * (*seq_next)(struct seq_file___245 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___245 *, void *);
	ssize_t (*read)(struct kernfs_open_file___276 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___276 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___276 *, struct vm_area_struct___284 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___276 *, struct poll_table_struct___172 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___276 {
	int (*remount_fs)(struct kernfs_root___276 *, int *, char *);
	int (*show_options)(struct seq_file___245 *, struct kernfs_root___276 *);
	int (*mkdir)(struct kernfs_node___277 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___277 *);
	int (*rename)(struct kernfs_node___277 *, struct kernfs_node___277 *, const char *);
	int (*show_path)(struct seq_file___245 *, struct kernfs_node___277 *, struct kernfs_root___276 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___244;

struct seq_file___245 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___244 *op;
	int poll_event;
	const struct file___283 *file;
	void *private;
};

struct vm_operations_struct___272;

struct kernfs_open_file___276 {
	struct kernfs_node___277 *kn;
	struct file___283 *file;
	struct seq_file___245 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___272 *vm_ops;
};

struct dentry___283;

struct path___283 {
	struct vfsmount *mnt;
	struct dentry___283 *dentry;
};

struct fown_struct___194 {
	rwlock_t lock;
	struct pid___194 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___283 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___283 f_path;
	struct inode___283 *f_inode;
	const struct file_operations___283 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___194 f_owner;
	const struct cred___266 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___282 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___272;

struct vm_operations_struct___272 {
	void (*open)(struct vm_area_struct___284 *);
	void (*close)(struct vm_area_struct___284 *);
	int (*split)(struct vm_area_struct___284 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___284 *);
	vm_fault_t (*fault)(struct vm_fault___272 *);
	vm_fault_t (*huge_fault)(struct vm_fault___272 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___272 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___284 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___272 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___272 *);
	int (*access)(struct vm_area_struct___284 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___284 *);
	int (*set_policy)(struct vm_area_struct___284 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___284 *, long unsigned int);
	struct page___284 * (*find_special_page)(struct vm_area_struct___284 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___175)(struct file___283 *, wait_queue_head_t *, struct poll_table_struct___172 *);

struct poll_table_struct___172 {
	poll_queue_proc___175 _qproc;
	__poll_t _key;
};

struct vm_area_struct___284 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___284 *vm_next;
	struct vm_area_struct___284 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___283 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___272 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___283 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___270;

struct bin_attribute___246;

struct attribute_group___247 {
	const char *name;
	umode_t (*is_visible)(struct kobject___270 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___270 *, struct bin_attribute___246 *, int);
	struct attribute **attrs;
	struct bin_attribute___246 **bin_attrs;
};

struct kset___269;

struct kobj_type___269;

struct kobject___270 {
	const char *name;
	struct list_head entry;
	struct kobject___270 *parent;
	struct kset___269 *kset;
	struct kobj_type___269 *ktype;
	struct kernfs_node___277 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___246 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___283 *, struct kobject___270 *, struct bin_attribute___246 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___283 *, struct kobject___270 *, struct bin_attribute___246 *, char *, loff_t, size_t);
	int (*mmap)(struct file___283 *, struct kobject___270 *, struct bin_attribute___246 *, struct vm_area_struct___284 *);
};

struct sysfs_ops___269 {
	ssize_t (*show)(struct kobject___270 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___270 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___269;

struct kset___269 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___270 kobj;
	const struct kset_uevent_ops___269 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___269 {
	void (*release)(struct kobject___270 *);
	const struct sysfs_ops___269 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___25 * (*child_ns_type)(struct kobject___270 *);
	const void * (*namespace)(struct kobject___270 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___269 {
	int (* const filter)(struct kset___269 *, struct kobject___270 *);
	const char * (* const name)(struct kset___269 *, struct kobject___270 *);
	int (* const uevent)(struct kset___269 *, struct kobject___270 *, struct kobj_uevent_env *);
};

struct kobj_attribute___262 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___270 *, struct kobj_attribute___262 *, char *);
	ssize_t (*store)(struct kobject___270 *, struct kobj_attribute___262 *, const char *, size_t);
};

struct device___245;

struct dev_pm_ops___245 {
	int (*prepare)(struct device___245 *);
	void (*complete)(struct device___245 *);
	int (*suspend)(struct device___245 *);
	int (*resume)(struct device___245 *);
	int (*freeze)(struct device___245 *);
	int (*thaw)(struct device___245 *);
	int (*poweroff)(struct device___245 *);
	int (*restore)(struct device___245 *);
	int (*suspend_late)(struct device___245 *);
	int (*resume_early)(struct device___245 *);
	int (*freeze_late)(struct device___245 *);
	int (*thaw_early)(struct device___245 *);
	int (*poweroff_late)(struct device___245 *);
	int (*restore_early)(struct device___245 *);
	int (*suspend_noirq)(struct device___245 *);
	int (*resume_noirq)(struct device___245 *);
	int (*freeze_noirq)(struct device___245 *);
	int (*thaw_noirq)(struct device___245 *);
	int (*poweroff_noirq)(struct device___245 *);
	int (*restore_noirq)(struct device___245 *);
	int (*runtime_suspend)(struct device___245 *);
	int (*runtime_resume)(struct device___245 *);
	int (*runtime_idle)(struct device___245 *);
};

struct dev_pm_info___245 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___245 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___245;

struct bus_type___245;

struct device_driver___245;

struct dev_pm_domain___245;

struct irq_domain___8;

struct dma_map_ops___70;

struct device_node___46;

struct fwnode_handle___180;

struct class___245;

struct iommu_fwspec___5;

struct device___245 {
	struct device___245 *parent;
	struct device_private *p;
	struct kobject___270 kobj;
	const char *init_name;
	const struct device_type___245 *type;
	struct mutex mutex;
	struct bus_type___245 *bus;
	struct device_driver___245 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___245 power;
	struct dev_pm_domain___245 *pm_domain;
	struct irq_domain___8 *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___70 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___46 *of_node;
	struct fwnode_handle___180 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___245 *class;
	const struct attribute_group___247 **groups;
	void (*release)(struct device___245 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec___5 *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___245 {
	struct dev_pm_ops___245 ops;
	void (*detach)(struct device___245 *, bool);
	int (*activate)(struct device___245 *);
	void (*sync)(struct device___245 *);
	void (*dismiss)(struct device___245 *);
};

struct pid_namespace___194;

struct upid___194 {
	int nr;
	struct pid_namespace___194 *ns;
};

struct pid_namespace___194 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___284 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___194 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___283 *proc_self;
	struct dentry___283 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___3 *user_ns;
	struct ucounts___2 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___9 ns;
};

struct pid___194 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___194 numbers[1];
};

struct key___266;

struct user_struct___266 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___266 *uid_keyring;
	struct key___266 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___283;

struct mm_struct___283 {
	struct {
		struct vm_area_struct___284 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___283 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___284 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___283 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___284 *owner;
		struct user_namespace___3 *user_ns;
		struct file___283 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___283 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___266 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___266 *session_keyring;
	struct key___266 *process_keyring;
	struct key___266 *thread_keyring;
	struct key___266 *request_key_auth;
	void *security;
	struct user_struct___266 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct nsproxy___241 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___194 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct signal_struct___219 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___284 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___284 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___194 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___194 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___283 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___194 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_struct___199 {
	struct vm_struct___199 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___284 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___231 {
	struct task_struct___284 task;
	long unsigned int stack[8192];
};

struct iommu_ops___5;

struct bus_type___245 {
	const char *name;
	const char *dev_name;
	struct device___245 *dev_root;
	const struct attribute_group___247 **bus_groups;
	const struct attribute_group___247 **dev_groups;
	const struct attribute_group___247 **drv_groups;
	int (*match)(struct device___245 *, struct device_driver___245 *);
	int (*uevent)(struct device___245 *, struct kobj_uevent_env *);
	int (*probe)(struct device___245 *);
	int (*remove)(struct device___245 *);
	void (*shutdown)(struct device___245 *);
	int (*online)(struct device___245 *);
	int (*offline)(struct device___245 *);
	int (*suspend)(struct device___245 *, pm_message_t);
	int (*resume)(struct device___245 *);
	int (*num_vf)(struct device___245 *);
	int (*dma_configure)(struct device___245 *);
	const struct dev_pm_ops___245 *pm;
	const struct iommu_ops___5 *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___245 {
	const char *name;
	struct bus_type___245 *bus;
	struct module___228 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___245 *);
	int (*remove)(struct device___245 *);
	void (*shutdown)(struct device___245 *);
	int (*suspend)(struct device___245 *, pm_message_t);
	int (*resume)(struct device___245 *);
	const struct attribute_group___247 **groups;
	const struct dev_pm_ops___245 *pm;
	void (*coredump)(struct device___245 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct iommu_domain___5;

struct of_phandle_args___5;

struct iommu_ops___5 {
	bool (*capable)(enum iommu_cap);
	struct iommu_domain___5 * (*domain_alloc)(unsigned int);
	void (*domain_free)(struct iommu_domain___5 *);
	int (*attach_dev)(struct iommu_domain___5 *, struct device___245 *);
	void (*detach_dev)(struct iommu_domain___5 *, struct device___245 *);
	int (*map)(struct iommu_domain___5 *, long unsigned int, phys_addr_t, size_t, int);
	size_t (*unmap)(struct iommu_domain___5 *, long unsigned int, size_t);
	void (*flush_iotlb_all)(struct iommu_domain___5 *);
	void (*iotlb_range_add)(struct iommu_domain___5 *, long unsigned int, size_t);
	void (*iotlb_sync)(struct iommu_domain___5 *);
	phys_addr_t (*iova_to_phys)(struct iommu_domain___5 *, dma_addr_t);
	int (*add_device)(struct device___245 *);
	void (*remove_device)(struct device___245 *);
	struct iommu_group * (*device_group)(struct device___245 *);
	int (*domain_get_attr)(struct iommu_domain___5 *, enum iommu_attr, void *);
	int (*domain_set_attr)(struct iommu_domain___5 *, enum iommu_attr, void *);
	void (*get_resv_regions)(struct device___245 *, struct list_head *);
	void (*put_resv_regions)(struct device___245 *, struct list_head *);
	void (*apply_resv_region)(struct device___245 *, struct iommu_domain___5 *, struct iommu_resv_region *);
	int (*domain_window_enable)(struct iommu_domain___5 *, u32, phys_addr_t, u64, int);
	void (*domain_window_disable)(struct iommu_domain___5 *, u32);
	int (*domain_set_windows)(struct iommu_domain___5 *, u32);
	u32 (*domain_get_windows)(struct iommu_domain___5 *);
	int (*of_xlate)(struct device___245 *, struct of_phandle_args___5 *);
	bool (*is_attach_deferred)(struct iommu_domain___5 *, struct device___245 *);
	long unsigned int pgsize_bitmap;
};

struct device_type___245 {
	const char *name;
	const struct attribute_group___247 **groups;
	int (*uevent)(struct device___245 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___245 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___245 *);
	const struct dev_pm_ops___245 *pm;
};

struct module_kobject___225 {
	struct kobject___270 kobj;
	struct module___228 *mod;
	struct kobject___270 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___225 {
	struct module___228 *mod;
	struct latch_tree_node node;
};

struct module_layout___225 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___225 mtn;
};

struct module_attribute___225;

struct kernel_param___225;

struct module___228 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___225 mkobj;
	struct module_attribute___225 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___270 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___225 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___225 core_layout;
	struct module_layout___225 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct class___245 {
	const char *name;
	struct module___228 *owner;
	const struct attribute_group___247 **class_groups;
	const struct attribute_group___247 **dev_groups;
	struct kobject___270 *dev_kobj;
	int (*dev_uevent)(struct device___245 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___245 *, umode_t *);
	void (*class_release)(struct class___245 *);
	void (*dev_release)(struct device___245 *);
	int (*shutdown_pre)(struct device___245 *);
	const struct kobj_ns_type_operations___25 *ns_type;
	const void * (*namespace)(struct device___245 *);
	const struct dev_pm_ops___245 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct irq_domain_ops___8;

struct irq_domain_chip_generic___8;

struct irq_domain___8 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___8 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___180 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___8 *gc;
	struct irq_domain___8 *parent;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_direct_max_irq;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_tree_mutex;
	unsigned int linear_revmap[0];
};

struct dma_map_ops___70 {
	void * (*alloc)(struct device___245 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___245 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___245 *, struct vm_area_struct___284 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___245 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___245 *, struct page___284 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___245 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___245 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___245 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___245 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___245 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___245 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___245 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___245 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___245 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___245 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___245 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___245 *, u64);
	u64 (*get_required_mask)(struct device___245 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___180;

struct fwnode_handle___180 {
	struct fwnode_handle___180 *secondary;
	const struct fwnode_operations___180 *ops;
};

struct property___45;

struct device_node___46 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___180 fwnode;
	struct property___45 *properties;
	struct property___45 *deadprops;
	struct device_node___46 *parent;
	struct device_node___46 *child;
	struct device_node___46 *sibling;
	struct kobject___270 kobj;
	long unsigned int _flags;
	void *data;
};

struct iommu_fwspec___5 {
	const struct iommu_ops___5 *ops;
	struct fwnode_handle___180 *iommu_fwnode;
	void *iommu_priv;
	unsigned int num_ids;
	u32 ids[1];
};

struct fwnode_reference_args___180;

struct fwnode_endpoint___180;

struct fwnode_operations___180 {
	struct fwnode_handle___180 * (*get)(struct fwnode_handle___180 *);
	void (*put)(struct fwnode_handle___180 *);
	bool (*device_is_available)(const struct fwnode_handle___180 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___180 *, const struct device___245 *);
	bool (*property_present)(const struct fwnode_handle___180 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___180 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___180 *, const char *, const char **, size_t);
	struct fwnode_handle___180 * (*get_parent)(const struct fwnode_handle___180 *);
	struct fwnode_handle___180 * (*get_next_child_node)(const struct fwnode_handle___180 *, struct fwnode_handle___180 *);
	struct fwnode_handle___180 * (*get_named_child_node)(const struct fwnode_handle___180 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___180 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___180 *);
	struct fwnode_handle___180 * (*graph_get_next_endpoint)(const struct fwnode_handle___180 *, struct fwnode_handle___180 *);
	struct fwnode_handle___180 * (*graph_get_remote_endpoint)(const struct fwnode_handle___180 *);
	struct fwnode_handle___180 * (*graph_get_port_parent)(struct fwnode_handle___180 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___180 *, struct fwnode_endpoint___180 *);
};

struct fwnode_endpoint___180 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___180 *local_fwnode;
};

struct fwnode_reference_args___180 {
	struct fwnode_handle___180 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct acpi_madt_generic_translator {
	struct acpi_subtable_header header;
	u16 reserved;
	u32 translation_id;
	u64 base_address;
	u32 reserved2;
} __attribute__((packed));

enum acpi_srat_type {
	ACPI_SRAT_TYPE_CPU_AFFINITY = 0,
	ACPI_SRAT_TYPE_MEMORY_AFFINITY = 1,
	ACPI_SRAT_TYPE_X2APIC_CPU_AFFINITY = 2,
	ACPI_SRAT_TYPE_GICC_AFFINITY = 3,
	ACPI_SRAT_TYPE_GIC_ITS_AFFINITY = 4,
	ACPI_SRAT_TYPE_RESERVED = 5,
};

struct acpi_srat_gic_its_affinity {
	struct acpi_subtable_header header;
	u32 proximity_domain;
	u16 reserved;
	u32 its_id;
} __attribute__((packed));

struct kernel_param_ops___225 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___225 *);
	int (*get)(char *, const struct kernel_param___225 *);
	void (*free)(void *);
};

struct kparam_array___225;

struct kernel_param___225 {
	const char *name;
	struct module___228 *mod;
	const struct kernel_param_ops___225 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___225 *arr;
	};
};

struct kparam_array___225 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___225 *ops;
	void *elem;
};

struct module_attribute___225 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___225 *, struct module_kobject___225 *, char *);
	ssize_t (*store)(struct module_attribute___225 *, struct module_kobject___225 *, const char *, size_t);
	void (*setup)(struct module___228 *, const char *);
	int (*test)(struct module___228 *);
	void (*free)(struct module___228 *);
};

struct dentry_operations___282;

struct super_block___282;

struct dentry___283 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___283 *d_parent;
	struct qstr d_name;
	struct inode___283 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___282 *d_op;
	struct super_block___282 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___282;

struct address_space___282 {
	struct inode___283 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___284 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___282 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___282;

struct block_device___282;

struct cdev___45;

struct inode___283 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___282 *i_op;
	struct super_block___282 *i_sb;
	struct address_space___282 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___284 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___283 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___282 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___282 *i_bdev;
		struct cdev___45 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___282 {
	int (*d_revalidate)(struct dentry___283 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___283 *, unsigned int);
	int (*d_hash)(const struct dentry___283 *, struct qstr *);
	int (*d_compare)(const struct dentry___283 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___283 *);
	int (*d_init)(struct dentry___283 *);
	void (*d_release)(struct dentry___283 *);
	void (*d_prune)(struct dentry___283 *);
	void (*d_iput)(struct dentry___283 *, struct inode___283 *);
	char * (*d_dname)(struct dentry___283 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___283 *);
	int (*d_manage)(const struct path___283 *, bool);
	struct dentry___283 * (*d_real)(struct dentry___283 *, const struct inode___283 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___282;

struct mem_dqinfo___282 {
	struct quota_format_type___282 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___282;

struct quota_info___282 {
	unsigned int flags;
	struct rw_semaphore___284 dqio_sem;
	struct inode___283 *files[3];
	struct mem_dqinfo___282 info[3];
	const struct quota_format_ops___282 *ops[3];
};

struct rcuwait___282 {
	struct task_struct___284 *task;
};

struct percpu_rw_semaphore___282 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___284 rw_sem;
	struct rcuwait___282 writer;
	int readers_block;
};

struct sb_writers___282 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___282 rw_sem[3];
};

struct file_system_type___282;

struct super_operations___282;

struct dquot_operations___282;

struct quotactl_ops___282;

struct super_block___282 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___282 *s_type;
	const struct super_operations___282 *s_op;
	const struct dquot_operations___282 *dq_op;
	const struct quotactl_ops___282 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___283 *s_root;
	struct rw_semaphore___284 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___282 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___282 s_dquot;
	struct sb_writers___282 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___282 *s_d_op;
	int cleancache_poolid;
	struct shrinker___115 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

typedef int (*dev_page_fault_t___272)(struct vm_area_struct___284 *, long unsigned int, const struct page___284 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___272)(struct page___284 *, void *);

struct dev_pagemap___272 {
	dev_page_fault_t___272 page_fault;
	dev_page_free_t___272 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___245 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___283 {
	struct task_struct___284 *task;
	struct core_thread___283 *next;
};

struct core_state___283 {
	atomic_t nr_threads;
	struct core_thread___283 dumper;
	struct completion startup;
};

struct vm_fault___272 {
	struct vm_area_struct___284 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___284 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___284 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___283 prealloc_pte;
};

struct kiocb___283 {
	struct file___283 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___283 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___282 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___283 *ia_file;
};

struct dquot___282 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___282 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___282 {
	int qf_fmt_id;
	const struct quota_format_ops___282 *qf_ops;
	struct module___228 *qf_owner;
	struct quota_format_type___282 *qf_next;
};

struct quota_format_ops___282 {
	int (*check_quota_file)(struct super_block___282 *, int);
	int (*read_file_info)(struct super_block___282 *, int);
	int (*write_file_info)(struct super_block___282 *, int);
	int (*free_file_info)(struct super_block___282 *, int);
	int (*read_dqblk)(struct dquot___282 *);
	int (*commit_dqblk)(struct dquot___282 *);
	int (*release_dqblk)(struct dquot___282 *);
	int (*get_next_id)(struct super_block___282 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___282 {
	int (*write_dquot)(struct dquot___282 *);
	struct dquot___282 * (*alloc_dquot)(struct super_block___282 *, int);
	void (*destroy_dquot)(struct dquot___282 *);
	int (*acquire_dquot)(struct dquot___282 *);
	int (*release_dquot)(struct dquot___282 *);
	int (*mark_dirty)(struct dquot___282 *);
	int (*write_info)(struct super_block___282 *, int);
	qsize_t * (*get_reserved_space)(struct inode___283 *);
	int (*get_projid)(struct inode___283 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___283 *, qsize_t *);
	int (*get_next_id)(struct super_block___282 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___282 {
	int (*quota_on)(struct super_block___282 *, int, int, const struct path___283 *);
	int (*quota_off)(struct super_block___282 *, int);
	int (*quota_enable)(struct super_block___282 *, unsigned int);
	int (*quota_disable)(struct super_block___282 *, unsigned int);
	int (*quota_sync)(struct super_block___282 *, int);
	int (*set_info)(struct super_block___282 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___282 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___282 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___282 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___282 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___282 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___282 {
	int (*writepage)(struct page___284 *, struct writeback_control___3 *);
	int (*readpage)(struct file___283 *, struct page___284 *);
	int (*writepages)(struct address_space___282 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___284 *);
	int (*readpages)(struct file___283 *, struct address_space___282 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___283 *, struct address_space___282 *, loff_t, unsigned int, unsigned int, struct page___284 **, void **);
	int (*write_end)(struct file___283 *, struct address_space___282 *, loff_t, unsigned int, unsigned int, struct page___284 *, void *);
	sector_t (*bmap)(struct address_space___282 *, sector_t);
	void (*invalidatepage)(struct page___284 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___284 *, gfp_t);
	void (*freepage)(struct page___284 *);
	ssize_t (*direct_IO)(struct kiocb___283 *, struct iov_iter___136 *);
	int (*migratepage)(struct address_space___282 *, struct page___284 *, struct page___284 *, enum migrate_mode);
	bool (*isolate_page)(struct page___284 *, isolate_mode_t);
	void (*putback_page)(struct page___284 *);
	int (*launder_page)(struct page___284 *);
	int (*is_partially_uptodate)(struct page___284 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___284 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___282 *, struct page___284 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___283 *, sector_t *);
	void (*swap_deactivate)(struct file___283 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___282 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___283 *bd_inode;
	struct super_block___282 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___282 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___45 {
	struct kobject___270 kobj;
	struct module___228 *owner;
	const struct file_operations___283 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___282 {
	struct dentry___283 * (*lookup)(struct inode___283 *, struct dentry___283 *, unsigned int);
	const char * (*get_link)(struct dentry___283 *, struct inode___283 *, struct delayed_call *);
	int (*permission)(struct inode___283 *, int);
	struct posix_acl * (*get_acl)(struct inode___283 *, int);
	int (*readlink)(struct dentry___283 *, char *, int);
	int (*create)(struct inode___283 *, struct dentry___283 *, umode_t, bool);
	int (*link)(struct dentry___283 *, struct inode___283 *, struct dentry___283 *);
	int (*unlink)(struct inode___283 *, struct dentry___283 *);
	int (*symlink)(struct inode___283 *, struct dentry___283 *, const char *);
	int (*mkdir)(struct inode___283 *, struct dentry___283 *, umode_t);
	int (*rmdir)(struct inode___283 *, struct dentry___283 *);
	int (*mknod)(struct inode___283 *, struct dentry___283 *, umode_t, dev_t);
	int (*rename)(struct inode___283 *, struct dentry___283 *, struct inode___283 *, struct dentry___283 *, unsigned int);
	int (*setattr)(struct dentry___283 *, struct iattr___282 *);
	int (*getattr)(const struct path___283 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___283 *, char *, size_t);
	int (*fiemap)(struct inode___283 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___283 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___283 *, struct dentry___283 *, struct file___283 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___283 *, struct dentry___283 *, umode_t);
	int (*set_acl)(struct inode___283 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___282 {
	void (*fl_copy_lock)(struct file_lock___283 *, struct file_lock___283 *);
	void (*fl_release_private)(struct file_lock___283 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___282;

struct lock_manager_operations___282;

struct file_lock___283 {
	struct file_lock___283 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___283 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___282 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___282 *fl_ops;
	const struct lock_manager_operations___282 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___282 {
	int (*lm_compare_owner)(struct file_lock___283 *, struct file_lock___283 *);
	long unsigned int (*lm_owner_key)(struct file_lock___283 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___283 *);
	int (*lm_grant)(struct file_lock___283 *, int);
	bool (*lm_break)(struct file_lock___283 *);
	int (*lm_change)(struct file_lock___283 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___283 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___282 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___282 *fa_next;
	struct file___283 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___282 {
	const char *name;
	int fs_flags;
	struct dentry___283 * (*mount)(struct file_system_type___282 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___282 *);
	struct module___228 *owner;
	struct file_system_type___282 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___282 {
	struct inode___283 * (*alloc_inode)(struct super_block___282 *);
	void (*destroy_inode)(struct inode___283 *);
	void (*dirty_inode)(struct inode___283 *, int);
	int (*write_inode)(struct inode___283 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___283 *);
	void (*evict_inode)(struct inode___283 *);
	void (*put_super)(struct super_block___282 *);
	int (*sync_fs)(struct super_block___282 *, int);
	int (*freeze_super)(struct super_block___282 *);
	int (*freeze_fs)(struct super_block___282 *);
	int (*thaw_super)(struct super_block___282 *);
	int (*unfreeze_fs)(struct super_block___282 *);
	int (*statfs)(struct dentry___283 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___282 *, int *, char *);
	void (*umount_begin)(struct super_block___282 *);
	int (*show_options)(struct seq_file___245 *, struct dentry___283 *);
	int (*show_devname)(struct seq_file___245 *, struct dentry___283 *);
	int (*show_path)(struct seq_file___245 *, struct dentry___283 *);
	int (*show_stats)(struct seq_file___245 *, struct dentry___283 *);
	ssize_t (*quota_read)(struct super_block___282 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___282 *, int, const char *, size_t, loff_t);
	struct dquot___282 ** (*get_dquots)(struct inode___283 *);
	int (*bdev_try_to_free_page)(struct super_block___282 *, struct page___284 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___282 *, struct shrink_control___115 *);
	long int (*free_cached_objects)(struct super_block___282 *, struct shrink_control___115 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct irqaction___11 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___11 *next;
	irq_handler_t thread_fn;
	struct task_struct___284 *thread;
	struct irqaction___11 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef int (*key_restrict_link_func_t___267)(struct key___266 *, const struct key_type *, const union key_payload *, struct key___266 *);

struct key_restriction___266;

struct key___266 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___284 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___266 *restrict_link;
};

struct key_restriction___266 {
	key_restrict_link_func_t___267 check;
	struct key___266 *key;
	struct key_type *keytype;
};

struct seq_operations___244 {
	void * (*start)(struct seq_file___245 *, loff_t *);
	void (*stop)(struct seq_file___245 *, void *);
	void * (*next)(struct seq_file___245 *, void *, loff_t *);
	int (*show)(struct seq_file___245 *, void *);
};

typedef void compound_page_dtor___272(struct page___284 *);

struct irq_desc___13;

typedef void (*irq_flow_handler_t___13)(struct irq_desc___13 *);

struct msi_desc___8;

struct irq_common_data___7 {
	unsigned int state_use_accessors;
	unsigned int node;
	void *handler_data;
	struct msi_desc___8 *msi_desc;
	cpumask_var_t affinity;
	cpumask_var_t effective_affinity;
};

struct irq_chip___16;

struct irq_data___16 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___7 *common;
	struct irq_chip___16 *chip;
	struct irq_domain___8 *domain;
	struct irq_data___16 *parent_data;
	void *chip_data;
};

struct irq_desc___13 {
	struct irq_common_data___7 irq_common_data;
	struct irq_data___16 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___13 handle_irq;
	struct irqaction___11 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int irq_count;
	unsigned int tot_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___270 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___228 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct property___45 {
	char *name;
	int length;
	void *value;
	struct property___45 *next;
	long unsigned int _flags;
	struct bin_attribute___246 attr;
};

struct of_phandle_args___5 {
	struct device_node___46 *np;
	int args_count;
	uint32_t args[16];
};

struct irq_fwspec___8 {
	struct fwnode_handle___180 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___8 {
	int (*match)(struct irq_domain___8 *, struct device_node___46 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___8 *, struct irq_fwspec___8 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___8 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___8 *, unsigned int);
	int (*xlate)(struct irq_domain___8 *, struct device_node___46 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___8 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___8 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___8 *, struct irq_data___16 *, bool);
	void (*deactivate)(struct irq_domain___8 *, struct irq_data___16 *);
	int (*translate)(struct irq_domain___8 *, struct irq_fwspec___8 *, long unsigned int *, unsigned int *);
};

struct irq_chip_generic___9;

struct irq_domain_chip_generic___8 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___9 *gc[0];
};

struct node___176 {
	struct device___245 dev;
};

struct kimage___20;

typedef void *kexec_load_t___20(struct kimage___20 *, char *, long unsigned int, char *, long unsigned int, char *, long unsigned int);

struct kexec_file_ops___21 {
	kexec_probe_t *probe;
	kexec_load_t___20 *load;
	kexec_cleanup_t *cleanup;
};

struct kimage___20 {
	kimage_entry_t head;
	kimage_entry_t *entry;
	kimage_entry_t *last_entry;
	long unsigned int start;
	struct page___284 *control_code_page;
	struct page___284 *swap_page;
	void *vmcoreinfo_data_copy;
	long unsigned int nr_segments;
	struct kexec_segment segment[16];
	struct list_head control_pages;
	struct list_head dest_pages;
	struct list_head unusable_pages;
	long unsigned int control_page;
	unsigned int type: 1;
	unsigned int preserve_context: 1;
	unsigned int file_mode: 1;
	struct kimage_arch arch;
	void *kernel_buf;
	long unsigned int kernel_buf_len;
	void *initrd_buf;
	long unsigned int initrd_buf_len;
	char *cmdline_buf;
	long unsigned int cmdline_buf_len;
	const struct kexec_file_ops___21 *fops;
	void *image_loader_data;
	struct purgatory_info purgatory_info;
};

typedef int (*iommu_fault_handler_t___5)(struct iommu_domain___5 *, struct device___245 *, long unsigned int, int, void *);

struct iommu_domain___5 {
	unsigned int type;
	const struct iommu_ops___5 *ops;
	long unsigned int pgsize_bitmap;
	iommu_fault_handler_t___5 handler;
	void *handler_token;
	struct iommu_domain_geometry geometry;
	void *iova_cookie;
};

struct msi_desc___8 {
	struct list_head list;
	unsigned int irq;
	unsigned int nvec_used;
	struct device___245 *dev;
	struct msi_msg msg;
	struct irq_affinity_desc *affinity;
	const void *iommu_cookie;
	union {
		struct {
			u32 masked;
			struct {
				u8 is_msix: 1;
				u8 multiple: 3;
				u8 multi_cap: 3;
				u8 maskbit: 1;
				u8 is_64: 1;
				u16 entry_nr;
				unsigned int default_irq;
			} msi_attrib;
			union {
				u8 mask_pos;
				void *mask_base;
			};
		};
		struct platform_msi_desc platform;
		struct fsl_mc_msi_desc fsl_mc;
	};
};

struct msi_alloc_info___4 {
	struct msi_desc___8 *desc;
	irq_hw_number_t hwirq;
	union {
		long unsigned int ul;
		void *ptr;
	} scratchpad[2];
};

typedef struct msi_alloc_info___4 msi_alloc_info_t___4;

struct msi_domain_info___4;

struct msi_domain_ops___4 {
	irq_hw_number_t (*get_hwirq)(struct msi_domain_info___4 *, msi_alloc_info_t___4 *);
	int (*msi_init)(struct irq_domain___8 *, struct msi_domain_info___4 *, unsigned int, irq_hw_number_t, msi_alloc_info_t___4 *);
	void (*msi_free)(struct irq_domain___8 *, struct msi_domain_info___4 *, unsigned int);
	int (*msi_check)(struct irq_domain___8 *, struct msi_domain_info___4 *, struct device___245 *);
	int (*msi_prepare)(struct irq_domain___8 *, struct device___245 *, int, msi_alloc_info_t___4 *);
	void (*msi_finish)(msi_alloc_info_t___4 *, int);
	void (*set_desc)(msi_alloc_info_t___4 *, struct msi_desc___8 *);
	int (*handle_error)(struct irq_domain___8 *, struct msi_desc___8 *, int);
};

struct msi_domain_info___4 {
	u32 flags;
	struct msi_domain_ops___4 *ops;
	struct irq_chip___16 *chip;
	void *chip_data;
	irq_flow_handler_t___13 handler;
	void *handler_data;
	const char *handler_name;
	void *data;
};

struct irq_chip___16 {
	struct device___245 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___16 *);
	void (*irq_shutdown)(struct irq_data___16 *);
	void (*irq_enable)(struct irq_data___16 *);
	void (*irq_disable)(struct irq_data___16 *);
	void (*irq_ack)(struct irq_data___16 *);
	void (*irq_mask)(struct irq_data___16 *);
	void (*irq_mask_ack)(struct irq_data___16 *);
	void (*irq_unmask)(struct irq_data___16 *);
	void (*irq_eoi)(struct irq_data___16 *);
	int (*irq_set_affinity)(struct irq_data___16 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___16 *);
	int (*irq_set_type)(struct irq_data___16 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___16 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___16 *);
	void (*irq_bus_sync_unlock)(struct irq_data___16 *);
	void (*irq_cpu_online)(struct irq_data___16 *);
	void (*irq_cpu_offline)(struct irq_data___16 *);
	void (*irq_suspend)(struct irq_data___16 *);
	void (*irq_resume)(struct irq_data___16 *);
	void (*irq_pm_shutdown)(struct irq_data___16 *);
	void (*irq_calc_mask)(struct irq_data___16 *);
	void (*irq_print_chip)(struct irq_data___16 *, struct seq_file___245 *);
	int (*irq_request_resources)(struct irq_data___16 *);
	void (*irq_release_resources)(struct irq_data___16 *);
	void (*irq_compose_msi_msg)(struct irq_data___16 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___16 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___16 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___16 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___16 *, void *);
	void (*ipi_send_single)(struct irq_data___16 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___16 *, const struct cpumask *);
	long unsigned int flags;
};

struct irq_chip_type___9 {
	struct irq_chip___16 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___13 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___9 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___9 *);
	void (*resume)(struct irq_chip_generic___9 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___8 *domain;
	struct list_head list;
	struct irq_chip_type___9 chip_types[0];
};

struct rdists___2 {
	struct {
		void *rd_base;
		struct page___284 *pend_page;
		phys_addr_t phys_base;
		bool lpi_enabled;
	} *rdist;
	phys_addr_t prop_table_pa;
	void *prop_table_va;
	u64 flags;
	u32 gicd_typer;
	bool has_vlpis;
	bool has_direct_lpi;
};

struct its_vpe___7;

struct its_vm___7 {
	struct fwnode_handle___180 *fwnode;
	struct irq_domain___8 *domain;
	struct page___284 *vprop_page;
	struct its_vpe___7 **vpes;
	int nr_vpes;
	irq_hw_number_t db_lpi_base;
	long unsigned int *db_bitmap;
	int nr_db_lpis;
	u32 vlpi_count[16];
};

struct its_vpe___7 {
	struct page___284 *vpt_page;
	struct its_vm___7 *its_vm;
	int irq;
	irq_hw_number_t vpe_db_lpi;
	int vpe_proxy_event;
	u16 col_idx;
	u16 vpe_id;
	bool idai;
	bool pending_last;
};

struct its_vlpi_map___3 {
	struct its_vm___7 *vm;
	struct its_vpe___7 *vpe;
	u32 vintid;
	u8 properties;
	bool db_enabled;
};

enum its_vcpu_info_cmd_type {
	MAP_VLPI = 0,
	GET_VLPI = 1,
	PROP_UPDATE_VLPI = 2,
	PROP_UPDATE_AND_INV_VLPI = 3,
	SCHEDULE_VPE = 4,
	DESCHEDULE_VPE = 5,
	INVALL_VPE = 6,
};

struct its_cmd_info {
	enum its_vcpu_info_cmd_type cmd_type;
	union {
		struct its_vlpi_map___3 *map;
		u8 config;
	};
};

struct its_collection___2 {
	u64 target_address;
	u16 col_id;
};

struct its_baser {
	void *base;
	u64 val;
	u32 order;
	u32 psz;
};

struct its_cmd_block;

struct its_device___2;

struct its_node {
	raw_spinlock_t lock;
	struct list_head entry;
	void *base;
	phys_addr_t phys_base;
	struct its_cmd_block *cmd_base;
	struct its_cmd_block *cmd_write;
	struct its_baser tables[8];
	struct its_collection___2 *collections;
	struct fwnode_handle___180 *fwnode_handle;
	u64 (*get_msi_base)(struct its_device___2 *);
	u64 cbaser_save;
	u32 ctlr_save;
	struct list_head its_device_list;
	u64 flags;
	long unsigned int list_nr;
	u32 ite_size;
	u32 device_ids;
	int numa_node;
	unsigned int msi_domain_flags;
	u32 pre_its_base;
	bool is_v4;
	int vlpi_redist_offset;
};

struct its_cmd_block {
	u64 raw_cmd[4];
};

struct event_lpi_map {
	long unsigned int *lpi_map;
	u16 *col_map;
	irq_hw_number_t lpi_base;
	int nr_lpis;
	struct mutex vlpi_lock;
	struct its_vm___7 *vm;
	struct its_vlpi_map___3 *vlpi_maps;
	int nr_vlpis;
};

struct its_device___2 {
	struct list_head entry;
	struct its_node *its;
	struct event_lpi_map event_map;
	void *itt;
	u32 nr_ites;
	u32 device_id;
};

struct its_cmd_desc {
	union {
		struct {
			struct its_device___2 *dev;
			u32 event_id;
		} its_inv_cmd;
		struct {
			struct its_device___2 *dev;
			u32 event_id;
		} its_clear_cmd;
		struct {
			struct its_device___2 *dev;
			u32 event_id;
		} its_int_cmd;
		struct {
			struct its_device___2 *dev;
			int valid;
		} its_mapd_cmd;
		struct {
			struct its_collection___2 *col;
			int valid;
		} its_mapc_cmd;
		struct {
			struct its_device___2 *dev;
			u32 phys_id;
			u32 event_id;
		} its_mapti_cmd;
		struct {
			struct its_device___2 *dev;
			struct its_collection___2 *col;
			u32 event_id;
		} its_movi_cmd;
		struct {
			struct its_device___2 *dev;
			u32 event_id;
		} its_discard_cmd;
		struct {
			struct its_collection___2 *col;
		} its_invall_cmd;
		struct {
			struct its_vpe___7 *vpe;
		} its_vinvall_cmd;
		struct {
			struct its_vpe___7 *vpe;
			struct its_collection___2 *col;
			bool valid;
		} its_vmapp_cmd;
		struct {
			struct its_vpe___7 *vpe;
			struct its_device___2 *dev;
			u32 virt_id;
			u32 event_id;
			bool db_enabled;
		} its_vmapti_cmd;
		struct {
			struct its_vpe___7 *vpe;
			struct its_device___2 *dev;
			u32 event_id;
			bool db_enabled;
		} its_vmovi_cmd;
		struct {
			struct its_vpe___7 *vpe;
			struct its_collection___2 *col;
			u16 seq_num;
			u16 its_list;
		} its_vmovp_cmd;
	};
};

typedef struct its_collection___2 * (*its_cmd_builder_t)(struct its_node *, struct its_cmd_block *, struct its_cmd_desc *);

typedef struct its_vpe___7 * (*its_cmd_vbuilder_t)(struct its_node *, struct its_cmd_block *, struct its_cmd_desc *);

struct lpi_range {
	struct list_head entry;
	u32 base_id;
	u32 span;
};

struct its_srat_map {
	u32 numa_node;
	u32 its_id;
};

struct its_cmd_info___2 {
	enum its_vcpu_info_cmd_type cmd_type;
	union {
		struct its_vlpi_map *map;
		u8 config;
	};
};

struct pci_dev___4;

struct pci_ops___4;

struct msi_controller___3;

struct pci_bus___4 {
	struct list_head node;
	struct pci_bus___4 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___4 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___4 *ops;
	struct msi_controller___3 *msi;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	int domain_nr;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___243 *bridge;
	struct device___243 dev;
	struct bin_attribute___244 *legacy_io;
	struct bin_attribute___244 *legacy_mem;
	unsigned int is_added: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
};

struct msi_controller___3 {
	struct module___227 *owner;
	struct device___243 *dev;
	struct device_node___44 *of_node;
	struct list_head list;
	int (*setup_irq)(struct msi_controller___3 *, struct pci_dev___4 *, struct msi_desc___6 *);
	int (*setup_irqs)(struct msi_controller___3 *, struct pci_dev___4 *, int, int);
	void (*teardown_irq)(struct msi_controller___3 *, unsigned int);
};

struct pci_slot___4;

struct pci_driver___4;

struct pci_dev___4 {
	struct list_head bus_list;
	struct pci_bus___4 *bus;
	struct pci_bus___4 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___4 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u16 aer_cap;
	struct aer_stats *aer_stats;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	long unsigned int *dma_alias_mask;
	struct pci_driver___4 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	unsigned int imm_ready: 1;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int bridge_d3: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int hotplug_user_indicators: 1;
	unsigned int clear_retrain_link: 1;
	unsigned int d3_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	unsigned int ltr_path: 1;
	unsigned int eetlp_prefix_path: 1;
	pci_channel_state_t error_state;
	struct device___243 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int multifunction: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int ats_enabled: 1;
	unsigned int pasid_enabled: 1;
	unsigned int pri_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int reset_fn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int shpc_managed: 1;
	unsigned int is_thunderbolt: 1;
	unsigned int __aer_firmware_first_valid: 1;
	unsigned int __aer_firmware_first: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int irq_managed: 1;
	unsigned int has_secondary_link: 1;
	unsigned int non_compliant_bars: 1;
	unsigned int is_probed: 1;
	unsigned int link_active_reporting: 1;
	unsigned int untrusted: 1;
	unsigned int no_vf_scan: 1;
	unsigned int io_window: 1;
	unsigned int pref_window: 1;
	unsigned int pref_64_window: 1;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	struct bin_attribute___244 *rom_attr;
	int rom_attr_enabled;
	struct bin_attribute___244 *res_attr[17];
	struct bin_attribute___244 *res_attr_wc[17];
	unsigned int broken_cmd_compl: 1;
	const struct attribute_group___245 **msi_irq_groups;
	struct pci_vpd *vpd;
	union {
		struct pci_sriov *sriov;
		struct pci_dev___4 *physfn;
	};
	u16 ats_cap;
	u8 ats_stu;
	atomic_t ats_ref_cnt;
	u32 pri_reqs_alloc;
	u16 pasid_features;
	struct pci_p2pdma *p2pdma;
	phys_addr_t rom;
	size_t romlen;
	char *driver_override;
	long unsigned int priv_flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t pci_dev_extended_size_rh;
	struct pci_dev_extended_rh pci_dev_extended_rh;
};

struct pci_slot___4 {
	struct pci_bus___4 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject___268 kobj;
};

struct pci_error_handlers___4;

struct pci_driver___4 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___4 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___4 *);
	int (*suspend)(struct pci_dev___4 *, pm_message_t);
	int (*suspend_late)(struct pci_dev___4 *, pm_message_t);
	int (*resume_early)(struct pci_dev___4 *);
	int (*resume)(struct pci_dev___4 *);
	void (*shutdown)(struct pci_dev___4 *);
	int (*sriov_configure)(struct pci_dev___4 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	const struct pci_error_handlers___4 *err_handler;
	const struct attribute_group___245 **groups;
	struct device_driver___243 driver;
	struct pci_dynids dynids;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct pci_ops___4 {
	int (*add_bus)(struct pci_bus___4 *);
	void (*remove_bus)(struct pci_bus___4 *);
	void * (*map_bus)(struct pci_bus___4 *, unsigned int, int);
	int (*read)(struct pci_bus___4 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___4 *, unsigned int, int, int, u32);
};

struct pci_error_handlers___4 {
	pci_ers_result_t (*error_detected)(struct pci_dev___4 *, enum pci_channel_state);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___4 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___4 *);
	void (*reset_prepare)(struct pci_dev___4 *);
	void (*reset_done)(struct pci_dev___4 *);
	void (*resume)(struct pci_dev___4 *);
};

struct partition_desc___2 {
	int nr_parts;
	struct partition_affinity *parts;
	struct irq_domain___8 *domain;
	struct irq_desc___13 *chained_desc;
	long unsigned int *bitmap;
	struct irq_domain_ops___8 ops;
};

struct acpi_device___2;

struct acpi_hotplug_profile___2 {
	struct kobject___270 kobj;
	int (*scan_dependent)(struct acpi_device___2 *);
	void (*notify_online)(struct acpi_device___2 *);
	bool enabled: 1;
	bool demand_offline: 1;
};

struct acpi_device_wakeup_context___2 {
	void (*func)(struct acpi_device_wakeup_context___2 *);
	struct device___245 *dev;
};

struct acpi_device_wakeup___2 {
	acpi_handle gpe_device;
	u64 gpe_number;
	u64 sleep_state;
	struct list_head resources;
	struct acpi_device_wakeup_flags flags;
	struct acpi_device_wakeup_context___2 context;
	struct wakeup_source *ws;
	int prepare_count;
	int enable_count;
};

struct acpi_scan_handler___2;

struct acpi_hotplug_context___2;

struct acpi_driver___2;

struct acpi_device___2 {
	int device_type;
	acpi_handle handle;
	struct fwnode_handle___180 fwnode;
	struct acpi_device___2 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup___2 wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_device_data data;
	struct acpi_scan_handler___2 *handler;
	struct acpi_hotplug_context___2 *hp;
	struct acpi_driver___2 *driver;
	const struct acpi_gpio_mapping *driver_gpios;
	void *driver_data;
	struct device___245 dev;
	unsigned int physical_node_count;
	unsigned int dep_unmet;
	struct list_head physical_node_list;
	struct mutex physical_node_lock;
	void (*remove)(struct acpi_device___2 *);
};

struct acpi_scan_handler___2 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	bool (*match)(const char *, const struct acpi_device_id **);
	int (*attach)(struct acpi_device___2 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___2 *);
	void (*bind)(struct device___245 *);
	void (*unbind)(struct device___245 *);
	struct acpi_hotplug_profile___2 hotplug;
};

struct acpi_hotplug_context___2 {
	struct acpi_device___2 *self;
	int (*notify)(struct acpi_device___2 *, u32);
	void (*uevent)(struct acpi_device___2 *, u32);
	void (*fixup)(struct acpi_device___2 *);
};

typedef int (*acpi_op_add___2)(struct acpi_device___2 *);

typedef int (*acpi_op_remove___2)(struct acpi_device___2 *);

typedef void (*acpi_op_notify___2)(struct acpi_device___2 *, u32);

struct acpi_device_ops___2 {
	acpi_op_add___2 add;
	acpi_op_remove___2 remove;
	acpi_op_notify___2 notify;
};

struct acpi_driver___2 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___2 ops;
	struct device_driver___245 drv;
	struct module___228 *owner;
};

struct platform_device___3 {
	const char *name;
	int id;
	bool id_auto;
	struct device___245 dev;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct platform_driver___3 {
	int (*probe)(struct platform_device___3 *);
	int (*remove)(struct platform_device___3 *);
	void (*shutdown)(struct platform_device___3 *);
	int (*suspend)(struct platform_device___3 *, pm_message_t);
	int (*resume)(struct platform_device___3 *);
	struct device_driver___245 driver;
	const struct platform_device_id *id_table;
	bool prevent_deferred_probe;
};

struct mbigen_device {
	struct platform_device___3 *pdev;
	void *base;
};

struct acpi_resource_irq {
	u8 descriptor_length;
	u8 triggering;
	u8 polarity;
	u8 sharable;
	u8 wake_capable;
	u8 interrupt_count;
	u8 interrupts[1];
};

struct acpi_resource_dma {
	u8 type;
	u8 bus_master;
	u8 transfer;
	u8 channel_count;
	u8 channels[1];
};

struct acpi_resource_start_dependent {
	u8 descriptor_length;
	u8 compatibility_priority;
	u8 performance_robustness;
};

struct acpi_resource_io {
	u8 io_decode;
	u8 alignment;
	u8 address_length;
	u16 minimum;
	u16 maximum;
} __attribute__((packed));

struct acpi_resource_fixed_io {
	u16 address;
	u8 address_length;
} __attribute__((packed));

struct acpi_resource_fixed_dma {
	u16 request_lines;
	u16 channels;
	u8 width;
} __attribute__((packed));

struct acpi_resource_vendor {
	u16 byte_length;
	u8 byte_data[1];
} __attribute__((packed));

struct acpi_resource_vendor_typed {
	u16 byte_length;
	u8 uuid_subtype;
	u8 uuid[16];
	u8 byte_data[1];
};

struct acpi_resource_end_tag {
	u8 checksum;
};

struct acpi_resource_memory24 {
	u8 write_protect;
	u16 minimum;
	u16 maximum;
	u16 alignment;
	u16 address_length;
} __attribute__((packed));

struct acpi_resource_memory32 {
	u8 write_protect;
	u32 minimum;
	u32 maximum;
	u32 alignment;
	u32 address_length;
} __attribute__((packed));

struct acpi_resource_fixed_memory32 {
	u8 write_protect;
	u32 address;
	u32 address_length;
} __attribute__((packed));

struct acpi_memory_attribute {
	u8 write_protect;
	u8 caching;
	u8 range_type;
	u8 translation;
};

struct acpi_io_attribute {
	u8 range_type;
	u8 translation;
	u8 translation_type;
	u8 reserved1;
};

union acpi_resource_attribute {
	struct acpi_memory_attribute mem;
	struct acpi_io_attribute io;
	u8 type_specific;
};

struct acpi_resource_label {
	u16 string_length;
	char *string_ptr;
} __attribute__((packed));

struct acpi_resource_source {
	u8 index;
	u16 string_length;
	char *string_ptr;
} __attribute__((packed));

struct acpi_address16_attribute {
	u16 granularity;
	u16 minimum;
	u16 maximum;
	u16 translation_offset;
	u16 address_length;
};

struct acpi_address32_attribute {
	u32 granularity;
	u32 minimum;
	u32 maximum;
	u32 translation_offset;
	u32 address_length;
};

struct acpi_address64_attribute {
	u64 granularity;
	u64 minimum;
	u64 maximum;
	u64 translation_offset;
	u64 address_length;
};

struct acpi_resource_address {
	u8 resource_type;
	u8 producer_consumer;
	u8 decode;
	u8 min_address_fixed;
	u8 max_address_fixed;
	union acpi_resource_attribute info;
};

struct acpi_resource_address16 {
	u8 resource_type;
	u8 producer_consumer;
	u8 decode;
	u8 min_address_fixed;
	u8 max_address_fixed;
	union acpi_resource_attribute info;
	struct acpi_address16_attribute address;
	struct acpi_resource_source resource_source;
} __attribute__((packed));

struct acpi_resource_address32 {
	u8 resource_type;
	u8 producer_consumer;
	u8 decode;
	u8 min_address_fixed;
	u8 max_address_fixed;
	union acpi_resource_attribute info;
	struct acpi_address32_attribute address;
	struct acpi_resource_source resource_source;
} __attribute__((packed));

struct acpi_resource_address64 {
	u8 resource_type;
	u8 producer_consumer;
	u8 decode;
	u8 min_address_fixed;
	u8 max_address_fixed;
	union acpi_resource_attribute info;
	struct acpi_address64_attribute address;
	struct acpi_resource_source resource_source;
} __attribute__((packed));

struct acpi_resource_extended_address64 {
	u8 resource_type;
	u8 producer_consumer;
	u8 decode;
	u8 min_address_fixed;
	u8 max_address_fixed;
	union acpi_resource_attribute info;
	u8 revision_ID;
	struct acpi_address64_attribute address;
	u64 type_specific;
} __attribute__((packed));

struct acpi_resource_extended_irq {
	u8 producer_consumer;
	u8 triggering;
	u8 polarity;
	u8 sharable;
	u8 wake_capable;
	u8 interrupt_count;
	struct acpi_resource_source resource_source;
	u32 interrupts[1];
} __attribute__((packed));

struct acpi_resource_generic_register {
	u8 space_id;
	u8 bit_width;
	u8 bit_offset;
	u8 access_size;
	u64 address;
} __attribute__((packed));

struct acpi_resource_gpio {
	u8 revision_id;
	u8 connection_type;
	u8 producer_consumer;
	u8 pin_config;
	u8 sharable;
	u8 wake_capable;
	u8 io_restriction;
	u8 triggering;
	u8 polarity;
	u16 drive_strength;
	u16 debounce_timeout;
	u16 pin_table_length;
	u16 vendor_length;
	struct acpi_resource_source resource_source;
	u16 *pin_table;
	u8 *vendor_data;
} __attribute__((packed));

struct acpi_resource_common_serialbus {
	u8 revision_id;
	u8 type;
	u8 producer_consumer;
	u8 slave_mode;
	u8 connection_sharing;
	u8 type_revision_id;
	u16 type_data_length;
	u16 vendor_length;
	struct acpi_resource_source resource_source;
	u8 *vendor_data;
} __attribute__((packed));

struct acpi_resource_i2c_serialbus {
	u8 revision_id;
	u8 type;
	u8 producer_consumer;
	u8 slave_mode;
	u8 connection_sharing;
	u8 type_revision_id;
	u16 type_data_length;
	u16 vendor_length;
	struct acpi_resource_source resource_source;
	u8 *vendor_data;
	u8 access_mode;
	u16 slave_address;
	u32 connection_speed;
} __attribute__((packed));

struct acpi_resource_spi_serialbus {
	u8 revision_id;
	u8 type;
	u8 producer_consumer;
	u8 slave_mode;
	u8 connection_sharing;
	u8 type_revision_id;
	u16 type_data_length;
	u16 vendor_length;
	struct acpi_resource_source resource_source;
	u8 *vendor_data;
	u8 wire_mode;
	u8 device_polarity;
	u8 data_bit_length;
	u8 clock_phase;
	u8 clock_polarity;
	u16 device_selection;
	u32 connection_speed;
} __attribute__((packed));

struct acpi_resource_uart_serialbus {
	u8 revision_id;
	u8 type;
	u8 producer_consumer;
	u8 slave_mode;
	u8 connection_sharing;
	u8 type_revision_id;
	u16 type_data_length;
	u16 vendor_length;
	struct acpi_resource_source resource_source;
	u8 *vendor_data;
	u8 endian;
	u8 data_bits;
	u8 stop_bits;
	u8 flow_control;
	u8 parity;
	u8 lines_enabled;
	u16 rx_fifo_size;
	u16 tx_fifo_size;
	u32 default_baud_rate;
} __attribute__((packed));

struct acpi_resource_pin_function {
	u8 revision_id;
	u8 pin_config;
	u8 sharable;
	u16 function_number;
	u16 pin_table_length;
	u16 vendor_length;
	struct acpi_resource_source resource_source;
	u16 *pin_table;
	u8 *vendor_data;
} __attribute__((packed));

struct acpi_resource_pin_config {
	u8 revision_id;
	u8 producer_consumer;
	u8 sharable;
	u8 pin_config_type;
	u32 pin_config_value;
	u16 pin_table_length;
	u16 vendor_length;
	struct acpi_resource_source resource_source;
	u16 *pin_table;
	u8 *vendor_data;
} __attribute__((packed));

struct acpi_resource_pin_group {
	u8 revision_id;
	u8 producer_consumer;
	u16 pin_table_length;
	u16 vendor_length;
	u16 *pin_table;
	struct acpi_resource_label resource_label;
	u8 *vendor_data;
} __attribute__((packed));

struct acpi_resource_pin_group_function {
	u8 revision_id;
	u8 producer_consumer;
	u8 sharable;
	u16 function_number;
	u16 vendor_length;
	struct acpi_resource_source resource_source;
	struct acpi_resource_label resource_source_label;
	u8 *vendor_data;
} __attribute__((packed));

struct acpi_resource_pin_group_config {
	u8 revision_id;
	u8 producer_consumer;
	u8 sharable;
	u8 pin_config_type;
	u32 pin_config_value;
	u16 vendor_length;
	struct acpi_resource_source resource_source;
	struct acpi_resource_label resource_source_label;
	u8 *vendor_data;
} __attribute__((packed));

union acpi_resource_data {
	struct acpi_resource_irq irq;
	struct acpi_resource_dma dma;
	struct acpi_resource_start_dependent start_dpf;
	struct acpi_resource_io io;
	struct acpi_resource_fixed_io fixed_io;
	struct acpi_resource_fixed_dma fixed_dma;
	struct acpi_resource_vendor vendor;
	struct acpi_resource_vendor_typed vendor_typed;
	struct acpi_resource_end_tag end_tag;
	struct acpi_resource_memory24 memory24;
	struct acpi_resource_memory32 memory32;
	struct acpi_resource_fixed_memory32 fixed_memory32;
	struct acpi_resource_address16 address16;
	struct acpi_resource_address32 address32;
	struct acpi_resource_address64 address64;
	struct acpi_resource_extended_address64 ext_address64;
	struct acpi_resource_extended_irq extended_irq;
	struct acpi_resource_generic_register generic_reg;
	struct acpi_resource_gpio gpio;
	struct acpi_resource_i2c_serialbus i2c_serial_bus;
	struct acpi_resource_spi_serialbus spi_serial_bus;
	struct acpi_resource_uart_serialbus uart_serial_bus;
	struct acpi_resource_common_serialbus common_serial_bus;
	struct acpi_resource_pin_function pin_function;
	struct acpi_resource_pin_config pin_config;
	struct acpi_resource_pin_group pin_group;
	struct acpi_resource_pin_group_function pin_group_function;
	struct acpi_resource_pin_group_config pin_group_config;
	struct acpi_resource_address address;
};

struct acpi_resource {
	u32 type;
	u32 length;
	union acpi_resource_data data;
} __attribute__((packed));

struct combiner_reg {
	void *addr;
	long unsigned int enabled;
};

struct combiner {
	struct irq_domain___8 *domain;
	int parent_irq;
	u32 nirqs;
	u32 nregs;
	struct combiner_reg regs[0];
};

struct get_registers_context {
	struct device___245 *dev;
	struct combiner *combiner;
	int err;
};

struct logic_pio_hwaddr___2 {
	struct list_head list;
	struct fwnode_handle___178 *fwnode;
	resource_size_t hw_start;
	resource_size_t io_start;
	resource_size_t size;
	long unsigned int flags;
	void *hostdata;
	const struct logic_pio_host_ops *ops;
};

struct console___2 {
	char name[16];
	void (*write)(struct console___2 *, const char *, unsigned int);
	int (*read)(struct console___2 *, char *, unsigned int);
	struct tty_driver___3 * (*device)(struct console___2 *, int *);
	void (*unblank)();
	int (*setup)(struct console___2 *, char *);
	int (*match)(struct console___2 *, char *, int, char *);
	short int flags;
	short int index;
	int cflag;
	void *data;
	struct console___2 *next;
};

struct plat_serial8250_port {
	long unsigned int iobase;
	void *membase;
	resource_size_t mapbase;
	unsigned int irq;
	long unsigned int irqflags;
	unsigned int uartclk;
	void *private_data;
	unsigned char regshift;
	unsigned char iotype;
	unsigned char hub6;
	upf_t flags;
	unsigned int type;
	unsigned int (*serial_in)(struct uart_port *, int);
	void (*serial_out)(struct uart_port *, int, int);
	void (*set_termios)(struct uart_port *, struct ktermios *, struct ktermios *);
	void (*set_ldisc)(struct uart_port *, struct ktermios *);
	unsigned int (*get_mctrl)(struct uart_port *);
	int (*handle_irq)(struct uart_port *);
	void (*pm)(struct uart_port *, unsigned int, unsigned int);
	void (*handle_break)(struct uart_port *);
};

struct lpc_cycle_para {
	unsigned int opflags;
	unsigned int csize;
};

struct hisi_lpc_dev {
	spinlock_t cycle_lock;
	void *membase;
	struct logic_pio_hwaddr___2 *io_host;
};

struct hisi_lpc_acpi_cell {
	const char *hid;
	const char *name;
	void *pdata;
	size_t pdata_size;
};

typedef void (*dr_release_t___8)(struct device___245 *, void *);

struct regmap;

struct vexpress_config_bridge_ops {
	struct regmap * (*regmap_init)(struct device___245 *, void *);
	void (*regmap_exit)(struct regmap *, void *);
};

struct vexpress_config_bridge {
	struct vexpress_config_bridge_ops *ops;
	void *context;
};

struct class_dev_iter___2 {
	struct klist_iter ki;
	const struct device_type___242 *type;
};

typedef void (*dr_release_t___9)(struct device___242 *, void *);

struct of_phandle_args___6 {
	struct device_node___43 *np;
	int args_count;
	uint32_t args[16];
};

struct regulator;

enum phy_mode {
	PHY_MODE_INVALID = 0,
	PHY_MODE_USB_HOST = 1,
	PHY_MODE_USB_HOST_LS = 2,
	PHY_MODE_USB_HOST_FS = 3,
	PHY_MODE_USB_HOST_HS = 4,
	PHY_MODE_USB_HOST_SS = 5,
	PHY_MODE_USB_DEVICE = 6,
	PHY_MODE_USB_DEVICE_LS = 7,
	PHY_MODE_USB_DEVICE_FS = 8,
	PHY_MODE_USB_DEVICE_HS = 9,
	PHY_MODE_USB_DEVICE_SS = 10,
	PHY_MODE_USB_OTG = 11,
	PHY_MODE_SGMII = 12,
	PHY_MODE_2500SGMII = 13,
	PHY_MODE_10GKR = 14,
	PHY_MODE_UFS_HS_A = 15,
	PHY_MODE_UFS_HS_B = 16,
};

struct phy;

struct phy_ops {
	int (*init)(struct phy *);
	int (*exit)(struct phy *);
	int (*power_on)(struct phy *);
	int (*power_off)(struct phy *);
	int (*set_mode)(struct phy *, enum phy_mode);
	int (*reset)(struct phy *);
	int (*calibrate)(struct phy *);
	struct module___226 *owner;
};

struct phy_attrs {
	u32 bus_width;
	enum phy_mode mode;
};

struct phy {
	struct device___242 dev;
	int id;
	const struct phy_ops *ops;
	struct mutex mutex;
	int init_count;
	int power_count;
	struct phy_attrs attrs;
	struct regulator *pwr;
};

struct phy_provider {
	struct device___242 *dev;
	struct device_node___43 *children;
	struct module___226 *owner;
	struct list_head list;
	struct phy * (*of_xlate)(struct device___242 *, struct of_phandle_args___6 *);
};

struct phy_lookup {
	struct list_head node;
	const char *dev_id;
	const char *con_id;
	struct phy *phy;
};

struct platform_device___4 {
	const char *name;
	int id;
	bool id_auto;
	struct device___242 dev;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct platform_driver___4 {
	int (*probe)(struct platform_device___4 *);
	int (*remove)(struct platform_device___4 *);
	void (*shutdown)(struct platform_device___4 *);
	int (*suspend)(struct platform_device___4 *, pm_message_t);
	int (*resume)(struct platform_device___4 *);
	struct device_driver___242 driver;
	const struct platform_device_id *id_table;
	bool prevent_deferred_probe;
};

enum cmu_type_t {
	REF_CMU = 0,
	PHY_CMU = 1,
};

enum clk_type_t {
	CLK_EXT_DIFF = 0,
	CLK_INT_DIFF = 1,
	CLK_INT_SING = 2,
};

enum xgene_phy_mode {
	MODE_SATA = 0,
	MODE_SGMII = 1,
	MODE_PCIE = 2,
	MODE_USB = 3,
	MODE_XFI = 4,
	MODE_MAX = 5,
};

struct xgene_sata_override_param {
	u32 speed[2];
	u32 txspeed[3];
	u32 txboostgain[6];
	u32 txeyetuning[6];
	u32 txeyedirection[6];
	u32 txamplitude[6];
	u32 txprecursor_cn1[6];
	u32 txprecursor_cn2[6];
	u32 txpostcursor_cp1[6];
};

struct xgene_phy_ctx {
	struct device___242 *dev;
	struct phy *phy;
	enum xgene_phy_mode mode;
	enum clk_type_t clk_type;
	void *sds_base;
	struct clk *clk;
	struct xgene_sata_override_param sata_param;
};

struct pinctrl;

struct pinctrl_state;

struct dev_pin_info {
	struct pinctrl *p;
	struct pinctrl_state *default_state;
	struct pinctrl_state *init_state;
	struct pinctrl_state *sleep_state;
	struct pinctrl_state *idle_state;
};

struct extcon_dev;

struct gpio_desc;

enum gpiod_flags {
	GPIOD_ASIS = 0,
	GPIOD_IN = 1,
	GPIOD_OUT_LOW = 3,
	GPIOD_OUT_HIGH = 7,
	GPIOD_OUT_LOW_OPEN_DRAIN = 11,
	GPIOD_OUT_HIGH_OPEN_DRAIN = 15,
};

struct phy___2;

struct phy_ops___2 {
	int (*init)(struct phy___2 *);
	int (*exit)(struct phy___2 *);
	int (*power_on)(struct phy___2 *);
	int (*power_off)(struct phy___2 *);
	int (*set_mode)(struct phy___2 *, enum phy_mode);
	int (*reset)(struct phy___2 *);
	int (*calibrate)(struct phy___2 *);
	struct module___228 *owner;
};

struct phy___2 {
	struct device___245 dev;
	int id;
	const struct phy_ops___2 *ops;
	struct mutex mutex;
	int init_count;
	int power_count;
	struct phy_attrs attrs;
	struct regulator *pwr;
};

struct phy_provider___2 {
	struct device___245 *dev;
	struct device_node___46 *children;
	struct module___228 *owner;
	struct list_head list;
	struct phy___2 * (*of_xlate)(struct device___245 *, struct of_phandle_args___5 *);
};

struct ns2_phy_data;

struct ns2_phy_driver {
	void *icfgdrd_regs;
	void *idmdrd_rst_ctrl;
	void *crmu_usb2_ctrl;
	void *usb2h_strap_reg;
	struct ns2_phy_data *data;
	struct extcon_dev *edev;
	struct gpio_desc *vbus_gpiod;
	struct gpio_desc *id_gpiod;
	int id_irq;
	int vbus_irq;
	long unsigned int debounce_jiffies;
	struct delayed_work wq_extcon;
};

struct ns2_phy_data {
	struct ns2_phy_driver *driver;
	struct phy___2 *phy;
	int new_state;
};

enum brcm_sata_phy_version {
	BRCM_SATA_PHY_STB_28NM = 0,
	BRCM_SATA_PHY_STB_40NM = 1,
	BRCM_SATA_PHY_IPROC_NS2 = 2,
	BRCM_SATA_PHY_IPROC_NSP = 3,
	BRCM_SATA_PHY_IPROC_SR = 4,
};

enum brcm_sata_phy_rxaeq_mode {
	RXAEQ_MODE_OFF = 0,
	RXAEQ_MODE_AUTO = 1,
	RXAEQ_MODE_MANUAL = 2,
};

struct brcm_sata_phy;

struct brcm_sata_port {
	int portnum;
	struct phy___2 *phy;
	struct brcm_sata_phy *phy_priv;
	bool ssc_en;
	enum brcm_sata_phy_rxaeq_mode rxaeq_mode;
	u32 rxaeq_val;
};

struct brcm_sata_phy {
	struct device___245 *dev;
	void *phy_base;
	void *ctrl_base;
	enum brcm_sata_phy_version version;
	struct brcm_sata_port phys[2];
};

enum sata_phy_regs {
	BLOCK0_REG_BANK = 0,
	BLOCK0_XGXSSTATUS = 129,
	BLOCK0_XGXSSTATUS_PLL_LOCK = 4096,
	BLOCK0_SPARE = 141,
	BLOCK0_SPARE_OOB_CLK_SEL_MASK = 3,
	BLOCK0_SPARE_OOB_CLK_SEL_REFBY2 = 1,
	PLL_REG_BANK_0 = 80,
	PLL_REG_BANK_0_PLLCONTROL_0 = 129,
	PLLCONTROL_0_FREQ_DET_RESTART = 8192,
	PLLCONTROL_0_FREQ_MONITOR = 4096,
	PLLCONTROL_0_SEQ_START = 32768,
	PLL_CAP_CONTROL = 133,
	PLL_ACTRL2 = 139,
	PLL_ACTRL2_SELDIV_MASK = 31,
	PLL_ACTRL2_SELDIV_SHIFT = 9,
	PLL_ACTRL6 = 134,
	PLL1_REG_BANK = 96,
	PLL1_ACTRL2 = 130,
	PLL1_ACTRL3 = 131,
	PLL1_ACTRL4 = 132,
	TX_REG_BANK = 112,
	TX_ACTRL0 = 128,
	TX_ACTRL0_TXPOL_FLIP = 64,
	AEQRX_REG_BANK_0 = 208,
	AEQ_CONTROL1 = 129,
	AEQ_CONTROL1_ENABLE = 4,
	AEQ_CONTROL1_FREEZE = 8,
	AEQ_FRC_EQ = 131,
	AEQ_FRC_EQ_FORCE = 1,
	AEQ_FRC_EQ_FORCE_VAL = 2,
	AEQRX_REG_BANK_1 = 224,
	OOB_REG_BANK = 336,
	OOB1_REG_BANK = 352,
	OOB_CTRL1 = 128,
	OOB_CTRL1_BURST_MAX_MASK = 15,
	OOB_CTRL1_BURST_MAX_SHIFT = 12,
	OOB_CTRL1_BURST_MIN_MASK = 15,
	OOB_CTRL1_BURST_MIN_SHIFT = 8,
	OOB_CTRL1_WAKE_IDLE_MAX_MASK = 15,
	OOB_CTRL1_WAKE_IDLE_MAX_SHIFT = 4,
	OOB_CTRL1_WAKE_IDLE_MIN_MASK = 15,
	OOB_CTRL1_WAKE_IDLE_MIN_SHIFT = 0,
	OOB_CTRL2 = 129,
	OOB_CTRL2_SEL_ENA_SHIFT = 15,
	OOB_CTRL2_SEL_ENA_RC_SHIFT = 14,
	OOB_CTRL2_RESET_IDLE_MAX_MASK = 63,
	OOB_CTRL2_RESET_IDLE_MAX_SHIFT = 8,
	OOB_CTRL2_BURST_CNT_MASK = 3,
	OOB_CTRL2_BURST_CNT_SHIFT = 6,
	OOB_CTRL2_RESET_IDLE_MIN_MASK = 63,
	OOB_CTRL2_RESET_IDLE_MIN_SHIFT = 0,
	TXPMD_REG_BANK = 416,
	TXPMD_CONTROL1 = 129,
	TXPMD_CONTROL1_TX_SSC_EN_FRC = 1,
	TXPMD_CONTROL1_TX_SSC_EN_FRC_VAL = 2,
	TXPMD_TX_FREQ_CTRL_CONTROL1 = 130,
	TXPMD_TX_FREQ_CTRL_CONTROL2 = 131,
	TXPMD_TX_FREQ_CTRL_CONTROL2_FMIN_MASK = 1023,
	TXPMD_TX_FREQ_CTRL_CONTROL3 = 132,
	TXPMD_TX_FREQ_CTRL_CONTROL3_FMAX_MASK = 1023,
	RXPMD_REG_BANK = 448,
	RXPMD_RX_FREQ_MON_CONTROL1 = 135,
};

enum sata_phy_ctrl_regs {
	PHY_CTRL_1 = 0,
	PHY_CTRL_1_RESET = 1,
};

struct pinctrl {
	struct list_head node;
	struct device___245 *dev;
	struct list_head states;
	struct pinctrl_state *state;
	struct list_head dt_maps;
	struct kref users;
};

struct pinctrl_state {
	struct list_head node;
	const char *name;
	struct list_head settings;
};

struct pinctrl_pin_desc {
	unsigned int number;
	const char *name;
	void *drv_data;
};

struct gpio_chip;

struct pinctrl_gpio_range {
	struct list_head node;
	const char *name;
	unsigned int id;
	unsigned int base;
	unsigned int pin_base;
	const unsigned int *pins;
	unsigned int npins;
	struct gpio_chip *gc;
};

struct gpio_irq_chip {
	struct irq_chip___16 *chip;
	struct irq_domain___8 *domain;
	const struct irq_domain_ops___8 *domain_ops;
	irq_flow_handler_t___13 handler;
	unsigned int default_type;
	struct lock_class_key *lock_key;
	struct lock_class_key *request_key;
	irq_flow_handler_t___13 parent_handler;
	void *parent_handler_data;
	unsigned int num_parents;
	unsigned int *parents;
	unsigned int *map;
	bool threaded;
	bool need_valid_mask;
	long unsigned int *valid_mask;
	unsigned int first;
};

struct gpio_device;

struct gpio_chip {
	const char *label;
	struct gpio_device *gpiodev;
	struct device___245 *parent;
	struct module___11 *owner;
	int (*request)(struct gpio_chip *, unsigned int);
	void (*free)(struct gpio_chip *, unsigned int);
	int (*get_direction)(struct gpio_chip *, unsigned int);
	int (*direction_input)(struct gpio_chip *, unsigned int);
	int (*direction_output)(struct gpio_chip *, unsigned int, int);
	int (*get)(struct gpio_chip *, unsigned int);
	int (*get_multiple)(struct gpio_chip *, long unsigned int *, long unsigned int *);
	void (*set)(struct gpio_chip *, unsigned int, int);
	void (*set_multiple)(struct gpio_chip *, long unsigned int *, long unsigned int *);
	int (*set_config)(struct gpio_chip *, unsigned int, long unsigned int);
	int (*to_irq)(struct gpio_chip *, unsigned int);
	void (*dbg_show)(struct seq_file___245 *, struct gpio_chip *);
	int base;
	u16 ngpio;
	const char * const *names;
	bool can_sleep;
	long unsigned int (*read_reg)(void *);
	void (*write_reg)(void *, long unsigned int);
	bool be_bits;
	void *reg_dat;
	void *reg_set;
	void *reg_clr;
	void *reg_dir;
	int bgpio_bits;
	spinlock_t bgpio_lock;
	long unsigned int bgpio_data;
	long unsigned int bgpio_dir;
	struct gpio_irq_chip irq;
	bool need_valid_mask;
	long unsigned int *valid_mask;
	struct device_node___46 *of_node;
	unsigned int of_gpio_n_cells;
	int (*of_xlate)(struct gpio_chip *, const struct of_phandle_args___6 *, u32 *);
};

struct pinctrl_dev;

struct pinctrl_map;

struct pinctrl_ops {
	int (*get_groups_count)(struct pinctrl_dev *);
	const char * (*get_group_name)(struct pinctrl_dev *, unsigned int);
	int (*get_group_pins)(struct pinctrl_dev *, unsigned int, const unsigned int **, unsigned int *);
	void (*pin_dbg_show)(struct pinctrl_dev *, struct seq_file___245 *, unsigned int);
	int (*dt_node_to_map)(struct pinctrl_dev *, struct device_node___46 *, struct pinctrl_map **, unsigned int *);
	void (*dt_free_map)(struct pinctrl_dev *, struct pinctrl_map *, unsigned int);
};

struct pinctrl_desc;

struct pinctrl_dev {
	struct list_head node;
	struct pinctrl_desc *desc;
	struct xarray pin_desc_tree;
	struct list_head gpio_ranges;
	struct device___245 *dev;
	struct module___11 *owner;
	void *driver_data;
	struct pinctrl *p;
	struct pinctrl_state *hog_default;
	struct pinctrl_state *hog_sleep;
	struct mutex mutex;
	struct dentry___283 *device_root;
};

enum pinctrl_map_type {
	PIN_MAP_TYPE_INVALID = 0,
	PIN_MAP_TYPE_DUMMY_STATE = 1,
	PIN_MAP_TYPE_MUX_GROUP = 2,
	PIN_MAP_TYPE_CONFIGS_PIN = 3,
	PIN_MAP_TYPE_CONFIGS_GROUP = 4,
};

struct pinctrl_map_mux {
	const char *group;
	const char *function;
};

struct pinctrl_map_configs {
	const char *group_or_pin;
	long unsigned int *configs;
	unsigned int num_configs;
};

struct pinctrl_map {
	const char *dev_name;
	const char *name;
	enum pinctrl_map_type type;
	const char *ctrl_dev_name;
	union {
		struct pinctrl_map_mux mux;
		struct pinctrl_map_configs configs;
	} data;
};

struct pinmux_ops;

struct pinconf_ops;

struct pinconf_generic_params;

struct pin_config_item;

struct pinctrl_desc {
	const char *name;
	const struct pinctrl_pin_desc *pins;
	unsigned int npins;
	const struct pinctrl_ops *pctlops;
	const struct pinmux_ops *pmxops;
	const struct pinconf_ops *confops;
	struct module___11 *owner;
	unsigned int num_custom_params;
	const struct pinconf_generic_params *custom_params;
	const struct pin_config_item *custom_conf_items;
};

struct pinctrl_dev___2;

struct pinmux_ops {
	int (*request)(struct pinctrl_dev___2 *, unsigned int);
	int (*free)(struct pinctrl_dev___2 *, unsigned int);
	int (*get_functions_count)(struct pinctrl_dev___2 *);
	const char * (*get_function_name)(struct pinctrl_dev___2 *, unsigned int);
	int (*get_function_groups)(struct pinctrl_dev___2 *, unsigned int, const char * const **, unsigned int *);
	int (*set_mux)(struct pinctrl_dev___2 *, unsigned int, unsigned int);
	int (*gpio_request_enable)(struct pinctrl_dev___2 *, struct pinctrl_gpio_range *, unsigned int);
	void (*gpio_disable_free)(struct pinctrl_dev___2 *, struct pinctrl_gpio_range *, unsigned int);
	int (*gpio_set_direction)(struct pinctrl_dev___2 *, struct pinctrl_gpio_range *, unsigned int, bool);
	bool strict;
};

struct pinconf_ops {
	bool is_generic;
	int (*pin_config_get)(struct pinctrl_dev *, unsigned int, long unsigned int *);
	int (*pin_config_set)(struct pinctrl_dev *, unsigned int, long unsigned int *, unsigned int);
	int (*pin_config_group_get)(struct pinctrl_dev *, unsigned int, long unsigned int *);
	int (*pin_config_group_set)(struct pinctrl_dev *, unsigned int, long unsigned int *, unsigned int);
	int (*pin_config_dbg_parse_modify)(struct pinctrl_dev *, const char *, long unsigned int *);
	void (*pin_config_dbg_show)(struct pinctrl_dev *, struct seq_file___245 *, unsigned int);
	void (*pin_config_group_dbg_show)(struct pinctrl_dev *, struct seq_file___245 *, unsigned int);
	void (*pin_config_config_dbg_show)(struct pinctrl_dev *, struct seq_file___245 *, long unsigned int);
};

enum pin_config_param {
	PIN_CONFIG_BIAS_BUS_HOLD = 0,
	PIN_CONFIG_BIAS_DISABLE = 1,
	PIN_CONFIG_BIAS_HIGH_IMPEDANCE = 2,
	PIN_CONFIG_BIAS_PULL_DOWN = 3,
	PIN_CONFIG_BIAS_PULL_PIN_DEFAULT = 4,
	PIN_CONFIG_BIAS_PULL_UP = 5,
	PIN_CONFIG_DRIVE_OPEN_DRAIN = 6,
	PIN_CONFIG_DRIVE_OPEN_SOURCE = 7,
	PIN_CONFIG_DRIVE_PUSH_PULL = 8,
	PIN_CONFIG_DRIVE_STRENGTH = 9,
	PIN_CONFIG_INPUT_DEBOUNCE = 10,
	PIN_CONFIG_INPUT_ENABLE = 11,
	PIN_CONFIG_INPUT_SCHMITT = 12,
	PIN_CONFIG_INPUT_SCHMITT_ENABLE = 13,
	PIN_CONFIG_LOW_POWER_MODE = 14,
	PIN_CONFIG_OUTPUT_ENABLE = 15,
	PIN_CONFIG_OUTPUT = 16,
	PIN_CONFIG_POWER_SOURCE = 17,
	PIN_CONFIG_SLEEP_HARDWARE_STATE = 18,
	PIN_CONFIG_SLEW_RATE = 19,
	PIN_CONFIG_SKEW_DELAY = 20,
	PIN_CONFIG_PERSIST_STATE = 21,
	PIN_CONFIG_END = 127,
	PIN_CONFIG_MAX = 255,
};

struct pinconf_generic_params {
	const char * const property;
	enum pin_config_param param;
	u32 default_value;
};

struct pin_config_item {
	const enum pin_config_param param;
	const char * const display;
	const char * const format;
	bool has_arg;
};

struct pinctrl_setting_mux {
	unsigned int group;
	unsigned int func;
};

struct pinctrl_setting_configs {
	unsigned int group_or_pin;
	long unsigned int *configs;
	unsigned int num_configs;
};

struct pinctrl_setting {
	struct list_head node;
	enum pinctrl_map_type type;
	struct pinctrl_dev *pctldev;
	const char *dev_name;
	union {
		struct pinctrl_setting_mux mux;
		struct pinctrl_setting_configs configs;
	} data;
};

struct pin_desc {
	struct pinctrl_dev *pctldev;
	const char *name;
	bool dynamic_name;
	void *drv_data;
	unsigned int mux_usecount;
	const char *mux_owner;
	const struct pinctrl_setting_mux *mux_setting;
	const char *gpio_owner;
};

struct pinctrl_maps {
	struct list_head node;
	const struct pinctrl_map *maps;
	unsigned int num_maps;
};

struct pctldev;

struct device___246;

struct dev_pm_ops___246 {
	int (*prepare)(struct device___246 *);
	void (*complete)(struct device___246 *);
	int (*suspend)(struct device___246 *);
	int (*resume)(struct device___246 *);
	int (*freeze)(struct device___246 *);
	int (*thaw)(struct device___246 *);
	int (*poweroff)(struct device___246 *);
	int (*restore)(struct device___246 *);
	int (*suspend_late)(struct device___246 *);
	int (*resume_early)(struct device___246 *);
	int (*freeze_late)(struct device___246 *);
	int (*thaw_early)(struct device___246 *);
	int (*poweroff_late)(struct device___246 *);
	int (*restore_early)(struct device___246 *);
	int (*suspend_noirq)(struct device___246 *);
	int (*resume_noirq)(struct device___246 *);
	int (*freeze_noirq)(struct device___246 *);
	int (*thaw_noirq)(struct device___246 *);
	int (*poweroff_noirq)(struct device___246 *);
	int (*restore_noirq)(struct device___246 *);
	int (*runtime_suspend)(struct device___246 *);
	int (*runtime_resume)(struct device___246 *);
	int (*runtime_idle)(struct device___246 *);
};

struct dev_pm_info___246 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___246 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___246;

struct bus_type___246;

struct device_driver___246;

struct dev_pm_domain___246;

struct dev_pin_info___2;

struct class___246;

struct device___246 {
	struct device___246 *parent;
	struct device_private *p;
	struct kobject___267 kobj;
	const char *init_name;
	const struct device_type___246 *type;
	struct mutex mutex;
	struct bus_type___246 *bus;
	struct device_driver___246 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___246 power;
	struct dev_pm_domain___246 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info___2 *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___246 *class;
	const struct attribute_group___244 **groups;
	void (*release)(struct device___246 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___246 {
	struct dev_pm_ops___246 ops;
	void (*detach)(struct device___246 *, bool);
	int (*activate)(struct device___246 *);
	void (*sync)(struct device___246 *);
	void (*dismiss)(struct device___246 *);
};

struct bus_type___246 {
	const char *name;
	const char *dev_name;
	struct device___246 *dev_root;
	const struct attribute_group___244 **bus_groups;
	const struct attribute_group___244 **dev_groups;
	const struct attribute_group___244 **drv_groups;
	int (*match)(struct device___246 *, struct device_driver___246 *);
	int (*uevent)(struct device___246 *, struct kobj_uevent_env *);
	int (*probe)(struct device___246 *);
	int (*remove)(struct device___246 *);
	void (*shutdown)(struct device___246 *);
	int (*online)(struct device___246 *);
	int (*offline)(struct device___246 *);
	int (*suspend)(struct device___246 *, pm_message_t);
	int (*resume)(struct device___246 *);
	int (*num_vf)(struct device___246 *);
	int (*dma_configure)(struct device___246 *);
	const struct dev_pm_ops___246 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___246 {
	const char *name;
	struct bus_type___246 *bus;
	struct module___226 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___246 *);
	int (*remove)(struct device___246 *);
	void (*shutdown)(struct device___246 *);
	int (*suspend)(struct device___246 *, pm_message_t);
	int (*resume)(struct device___246 *);
	const struct attribute_group___244 **groups;
	const struct dev_pm_ops___246 *pm;
	void (*coredump)(struct device___246 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___246 {
	const char *name;
	const struct attribute_group___244 **groups;
	int (*uevent)(struct device___246 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___246 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___246 *);
	const struct dev_pm_ops___246 *pm;
};

struct class___246 {
	const char *name;
	struct module___226 *owner;
	const struct attribute_group___244 **class_groups;
	const struct attribute_group___244 **dev_groups;
	struct kobject___267 *dev_kobj;
	int (*dev_uevent)(struct device___246 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___246 *, umode_t *);
	void (*class_release)(struct class___246 *);
	void (*dev_release)(struct device___246 *);
	int (*shutdown_pre)(struct device___246 *);
	const struct kobj_ns_type_operations___25 *ns_type;
	const void * (*namespace)(struct device___246 *);
	const struct dev_pm_ops___246 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct pinctrl___2;

struct dev_pin_info___2 {
	struct pinctrl___2 *p;
	struct pinctrl_state *default_state;
	struct pinctrl_state *init_state;
	struct pinctrl_state *sleep_state;
	struct pinctrl_state *idle_state;
};

struct pinctrl___2 {
	struct list_head node;
	struct device___246 *dev;
	struct list_head states;
	struct pinctrl_state *state;
	struct list_head dt_maps;
	struct kref users;
};

struct pinctrl_ops___2 {
	int (*get_groups_count)(struct pinctrl_dev___2 *);
	const char * (*get_group_name)(struct pinctrl_dev___2 *, unsigned int);
	int (*get_group_pins)(struct pinctrl_dev___2 *, unsigned int, const unsigned int **, unsigned int *);
	void (*pin_dbg_show)(struct pinctrl_dev___2 *, struct seq_file___243 *, unsigned int);
	int (*dt_node_to_map)(struct pinctrl_dev___2 *, struct device_node___2 *, struct pinctrl_map **, unsigned int *);
	void (*dt_free_map)(struct pinctrl_dev___2 *, struct pinctrl_map *, unsigned int);
};

struct pinctrl_desc___2;

struct pinctrl_dev___2 {
	struct list_head node;
	struct pinctrl_desc___2 *desc;
	struct xarray pin_desc_tree;
	struct list_head gpio_ranges;
	struct device___246 *dev;
	struct module___226 *owner;
	void *driver_data;
	struct pinctrl___2 *p;
	struct pinctrl_state *hog_default;
	struct pinctrl_state *hog_sleep;
	struct mutex mutex;
	struct dentry___280 *device_root;
};

struct pinconf_ops___2;

struct pinctrl_desc___2 {
	const char *name;
	const struct pinctrl_pin_desc *pins;
	unsigned int npins;
	const struct pinctrl_ops___2 *pctlops;
	const struct pinmux_ops *pmxops;
	const struct pinconf_ops___2 *confops;
	struct module___226 *owner;
	unsigned int num_custom_params;
	const struct pinconf_generic_params *custom_params;
	const struct pin_config_item *custom_conf_items;
};

struct pinconf_ops___2 {
	bool is_generic;
	int (*pin_config_get)(struct pinctrl_dev___2 *, unsigned int, long unsigned int *);
	int (*pin_config_set)(struct pinctrl_dev___2 *, unsigned int, long unsigned int *, unsigned int);
	int (*pin_config_group_get)(struct pinctrl_dev___2 *, unsigned int, long unsigned int *);
	int (*pin_config_group_set)(struct pinctrl_dev___2 *, unsigned int, long unsigned int *, unsigned int);
	int (*pin_config_dbg_parse_modify)(struct pinctrl_dev___2 *, const char *, long unsigned int *);
	void (*pin_config_dbg_show)(struct pinctrl_dev___2 *, struct seq_file___243 *, unsigned int);
	void (*pin_config_group_dbg_show)(struct pinctrl_dev___2 *, struct seq_file___243 *, unsigned int);
	void (*pin_config_config_dbg_show)(struct pinctrl_dev___2 *, struct seq_file___243 *, long unsigned int);
};

struct pinctrl_setting___2 {
	struct list_head node;
	enum pinctrl_map_type type;
	struct pinctrl_dev___2 *pctldev;
	const char *dev_name;
	union {
		struct pinctrl_setting_mux mux;
		struct pinctrl_setting_configs configs;
	} data;
};

struct pin_desc___2 {
	struct pinctrl_dev___2 *pctldev;
	const char *name;
	bool dynamic_name;
	void *drv_data;
	unsigned int mux_usecount;
	const char *mux_owner;
	const struct pinctrl_setting_mux *mux_setting;
	const char *gpio_owner;
};

struct dbg_cfg {
	enum pinctrl_map_type map_type;
	char dev_name[16];
	char state_name[16];
	char pin_name[16];
};

struct pinctrl_dt_map {
	struct list_head node;
	struct pinctrl_dev *pctldev;
	struct pinctrl_map *map;
	unsigned int num_maps;
};

struct device___247;

struct dev_pm_ops___247 {
	int (*prepare)(struct device___247 *);
	void (*complete)(struct device___247 *);
	int (*suspend)(struct device___247 *);
	int (*resume)(struct device___247 *);
	int (*freeze)(struct device___247 *);
	int (*thaw)(struct device___247 *);
	int (*poweroff)(struct device___247 *);
	int (*restore)(struct device___247 *);
	int (*suspend_late)(struct device___247 *);
	int (*resume_early)(struct device___247 *);
	int (*freeze_late)(struct device___247 *);
	int (*thaw_early)(struct device___247 *);
	int (*poweroff_late)(struct device___247 *);
	int (*restore_early)(struct device___247 *);
	int (*suspend_noirq)(struct device___247 *);
	int (*resume_noirq)(struct device___247 *);
	int (*freeze_noirq)(struct device___247 *);
	int (*thaw_noirq)(struct device___247 *);
	int (*poweroff_noirq)(struct device___247 *);
	int (*restore_noirq)(struct device___247 *);
	int (*runtime_suspend)(struct device___247 *);
	int (*runtime_resume)(struct device___247 *);
	int (*runtime_idle)(struct device___247 *);
};

struct dev_pm_info___247 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___247 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___247;

struct bus_type___247;

struct device_driver___247;

struct dev_pm_domain___247;

struct dev_pin_info___3;

struct device_node___47;

struct fwnode_handle___181;

struct class___247;

struct device___247 {
	struct device___247 *parent;
	struct device_private *p;
	struct kobject___267 kobj;
	const char *init_name;
	const struct device_type___247 *type;
	struct mutex mutex;
	struct bus_type___247 *bus;
	struct device_driver___247 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___247 power;
	struct dev_pm_domain___247 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info___3 *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___47 *of_node;
	struct fwnode_handle___181 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___247 *class;
	const struct attribute_group___244 **groups;
	void (*release)(struct device___247 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___247 {
	struct dev_pm_ops___247 ops;
	void (*detach)(struct device___247 *, bool);
	int (*activate)(struct device___247 *);
	void (*sync)(struct device___247 *);
	void (*dismiss)(struct device___247 *);
};

struct bus_type___247 {
	const char *name;
	const char *dev_name;
	struct device___247 *dev_root;
	const struct attribute_group___244 **bus_groups;
	const struct attribute_group___244 **dev_groups;
	const struct attribute_group___244 **drv_groups;
	int (*match)(struct device___247 *, struct device_driver___247 *);
	int (*uevent)(struct device___247 *, struct kobj_uevent_env *);
	int (*probe)(struct device___247 *);
	int (*remove)(struct device___247 *);
	void (*shutdown)(struct device___247 *);
	int (*online)(struct device___247 *);
	int (*offline)(struct device___247 *);
	int (*suspend)(struct device___247 *, pm_message_t);
	int (*resume)(struct device___247 *);
	int (*num_vf)(struct device___247 *);
	int (*dma_configure)(struct device___247 *);
	const struct dev_pm_ops___247 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___247 {
	const char *name;
	struct bus_type___247 *bus;
	struct module___226 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___247 *);
	int (*remove)(struct device___247 *);
	void (*shutdown)(struct device___247 *);
	int (*suspend)(struct device___247 *, pm_message_t);
	int (*resume)(struct device___247 *);
	const struct attribute_group___244 **groups;
	const struct dev_pm_ops___247 *pm;
	void (*coredump)(struct device___247 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___247 {
	const char *name;
	const struct attribute_group___244 **groups;
	int (*uevent)(struct device___247 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___247 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___247 *);
	const struct dev_pm_ops___247 *pm;
};

struct class___247 {
	const char *name;
	struct module___226 *owner;
	const struct attribute_group___244 **class_groups;
	const struct attribute_group___244 **dev_groups;
	struct kobject___267 *dev_kobj;
	int (*dev_uevent)(struct device___247 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___247 *, umode_t *);
	void (*class_release)(struct class___247 *);
	void (*dev_release)(struct device___247 *);
	int (*shutdown_pre)(struct device___247 *);
	const struct kobj_ns_type_operations___25 *ns_type;
	const void * (*namespace)(struct device___247 *);
	const struct dev_pm_ops___247 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct pinctrl___3;

struct dev_pin_info___3 {
	struct pinctrl___3 *p;
	struct pinctrl_state *default_state;
	struct pinctrl_state *init_state;
	struct pinctrl_state *sleep_state;
	struct pinctrl_state *idle_state;
};

struct fwnode_operations___181;

struct fwnode_handle___181 {
	struct fwnode_handle___181 *secondary;
	const struct fwnode_operations___181 *ops;
};

struct device_node___47 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___181 fwnode;
	struct property___42 *properties;
	struct property___42 *deadprops;
	struct device_node___47 *parent;
	struct device_node___47 *child;
	struct device_node___47 *sibling;
	struct kobject___267 kobj;
	long unsigned int _flags;
	void *data;
};

struct pinctrl___3 {
	struct list_head node;
	struct device___247 *dev;
	struct list_head states;
	struct pinctrl_state *state;
	struct list_head dt_maps;
	struct kref users;
};

struct pinctrl_dev___3;

struct pinctrl_ops___3 {
	int (*get_groups_count)(struct pinctrl_dev___3 *);
	const char * (*get_group_name)(struct pinctrl_dev___3 *, unsigned int);
	int (*get_group_pins)(struct pinctrl_dev___3 *, unsigned int, const unsigned int **, unsigned int *);
	void (*pin_dbg_show)(struct pinctrl_dev___3 *, struct seq_file___243 *, unsigned int);
	int (*dt_node_to_map)(struct pinctrl_dev___3 *, struct device_node___47 *, struct pinctrl_map **, unsigned int *);
	void (*dt_free_map)(struct pinctrl_dev___3 *, struct pinctrl_map *, unsigned int);
};

struct pinctrl_desc___3;

struct pinctrl_dev___3 {
	struct list_head node;
	struct pinctrl_desc___3 *desc;
	struct xarray pin_desc_tree;
	struct list_head gpio_ranges;
	struct device___247 *dev;
	struct module___226 *owner;
	void *driver_data;
	struct pinctrl___3 *p;
	struct pinctrl_state *hog_default;
	struct pinctrl_state *hog_sleep;
	struct mutex mutex;
	struct dentry___280 *device_root;
};

struct pinconf_ops___3;

struct pinctrl_desc___3 {
	const char *name;
	const struct pinctrl_pin_desc *pins;
	unsigned int npins;
	const struct pinctrl_ops___3 *pctlops;
	const struct pinmux_ops *pmxops;
	const struct pinconf_ops___3 *confops;
	struct module___226 *owner;
	unsigned int num_custom_params;
	const struct pinconf_generic_params *custom_params;
	const struct pin_config_item *custom_conf_items;
};

struct pinconf_ops___3 {
	bool is_generic;
	int (*pin_config_get)(struct pinctrl_dev___3 *, unsigned int, long unsigned int *);
	int (*pin_config_set)(struct pinctrl_dev___3 *, unsigned int, long unsigned int *, unsigned int);
	int (*pin_config_group_get)(struct pinctrl_dev___3 *, unsigned int, long unsigned int *);
	int (*pin_config_group_set)(struct pinctrl_dev___3 *, unsigned int, long unsigned int *, unsigned int);
	int (*pin_config_dbg_parse_modify)(struct pinctrl_dev___3 *, const char *, long unsigned int *);
	void (*pin_config_dbg_show)(struct pinctrl_dev___3 *, struct seq_file___243 *, unsigned int);
	void (*pin_config_group_dbg_show)(struct pinctrl_dev___3 *, struct seq_file___243 *, unsigned int);
	void (*pin_config_config_dbg_show)(struct pinctrl_dev___3 *, struct seq_file___243 *, long unsigned int);
};

struct fwnode_reference_args___181;

struct fwnode_endpoint___181;

struct fwnode_operations___181 {
	struct fwnode_handle___181 * (*get)(struct fwnode_handle___181 *);
	void (*put)(struct fwnode_handle___181 *);
	bool (*device_is_available)(const struct fwnode_handle___181 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___181 *, const struct device___247 *);
	bool (*property_present)(const struct fwnode_handle___181 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___181 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___181 *, const char *, const char **, size_t);
	struct fwnode_handle___181 * (*get_parent)(const struct fwnode_handle___181 *);
	struct fwnode_handle___181 * (*get_next_child_node)(const struct fwnode_handle___181 *, struct fwnode_handle___181 *);
	struct fwnode_handle___181 * (*get_named_child_node)(const struct fwnode_handle___181 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___181 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___181 *);
	struct fwnode_handle___181 * (*graph_get_next_endpoint)(const struct fwnode_handle___181 *, struct fwnode_handle___181 *);
	struct fwnode_handle___181 * (*graph_get_remote_endpoint)(const struct fwnode_handle___181 *);
	struct fwnode_handle___181 * (*graph_get_port_parent)(struct fwnode_handle___181 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___181 *, struct fwnode_endpoint___181 *);
};

struct fwnode_endpoint___181 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___181 *local_fwnode;
};

struct fwnode_reference_args___181 {
	struct fwnode_handle___181 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct of_phandle_args___7 {
	struct device_node___17 *np;
	int args_count;
	uint32_t args[16];
};

struct gpio_irq_chip___2 {
	struct irq_chip___9 *chip;
	struct irq_domain___4 *domain;
	const struct irq_domain_ops___4 *domain_ops;
	irq_flow_handler_t___6 handler;
	unsigned int default_type;
	struct lock_class_key *lock_key;
	struct lock_class_key *request_key;
	irq_flow_handler_t___6 parent_handler;
	void *parent_handler_data;
	unsigned int num_parents;
	unsigned int *parents;
	unsigned int *map;
	bool threaded;
	bool need_valid_mask;
	long unsigned int *valid_mask;
	unsigned int first;
};

struct gpio_chip___2 {
	const char *label;
	struct gpio_device *gpiodev;
	struct device___53 *parent;
	struct module___11 *owner;
	int (*request)(struct gpio_chip___2 *, unsigned int);
	void (*free)(struct gpio_chip___2 *, unsigned int);
	int (*get_direction)(struct gpio_chip___2 *, unsigned int);
	int (*direction_input)(struct gpio_chip___2 *, unsigned int);
	int (*direction_output)(struct gpio_chip___2 *, unsigned int, int);
	int (*get)(struct gpio_chip___2 *, unsigned int);
	int (*get_multiple)(struct gpio_chip___2 *, long unsigned int *, long unsigned int *);
	void (*set)(struct gpio_chip___2 *, unsigned int, int);
	void (*set_multiple)(struct gpio_chip___2 *, long unsigned int *, long unsigned int *);
	int (*set_config)(struct gpio_chip___2 *, unsigned int, long unsigned int);
	int (*to_irq)(struct gpio_chip___2 *, unsigned int);
	void (*dbg_show)(struct seq_file___241 *, struct gpio_chip___2 *);
	int base;
	u16 ngpio;
	const char * const *names;
	bool can_sleep;
	long unsigned int (*read_reg)(void *);
	void (*write_reg)(void *, long unsigned int);
	bool be_bits;
	void *reg_dat;
	void *reg_set;
	void *reg_clr;
	void *reg_dir;
	int bgpio_bits;
	spinlock_t bgpio_lock;
	long unsigned int bgpio_data;
	long unsigned int bgpio_dir;
	struct gpio_irq_chip___2 irq;
	bool need_valid_mask;
	long unsigned int *valid_mask;
	struct device_node___17 *of_node;
	unsigned int of_gpio_n_cells;
	int (*of_xlate)(struct gpio_chip___2 *, const struct of_phandle_args___7 *, u32 *);
};

struct pinctrl_dev___4;

struct pinctrl_ops___4 {
	int (*get_groups_count)(struct pinctrl_dev___4 *);
	const char * (*get_group_name)(struct pinctrl_dev___4 *, unsigned int);
	int (*get_group_pins)(struct pinctrl_dev___4 *, unsigned int, const unsigned int **, unsigned int *);
	void (*pin_dbg_show)(struct pinctrl_dev___4 *, struct seq_file___241 *, unsigned int);
	int (*dt_node_to_map)(struct pinctrl_dev___4 *, struct device_node___17 *, struct pinctrl_map **, unsigned int *);
	void (*dt_free_map)(struct pinctrl_dev___4 *, struct pinctrl_map *, unsigned int);
};

struct pinconf_ops___4;

struct pinctrl_desc___4 {
	const char *name;
	const struct pinctrl_pin_desc *pins;
	unsigned int npins;
	const struct pinctrl_ops___4 *pctlops;
	const struct pinmux_ops *pmxops;
	const struct pinconf_ops___4 *confops;
	struct module___11 *owner;
	unsigned int num_custom_params;
	const struct pinconf_generic_params *custom_params;
	const struct pin_config_item *custom_conf_items;
};

struct pinconf_ops___4 {
	bool is_generic;
	int (*pin_config_get)(struct pinctrl_dev___4 *, unsigned int, long unsigned int *);
	int (*pin_config_set)(struct pinctrl_dev___4 *, unsigned int, long unsigned int *, unsigned int);
	int (*pin_config_group_get)(struct pinctrl_dev___4 *, unsigned int, long unsigned int *);
	int (*pin_config_group_set)(struct pinctrl_dev___4 *, unsigned int, long unsigned int *, unsigned int);
	int (*pin_config_dbg_parse_modify)(struct pinctrl_dev___4 *, const char *, long unsigned int *);
	void (*pin_config_dbg_show)(struct pinctrl_dev___4 *, struct seq_file___241 *, unsigned int);
	void (*pin_config_group_dbg_show)(struct pinctrl_dev___4 *, struct seq_file___241 *, unsigned int);
	void (*pin_config_config_dbg_show)(struct pinctrl_dev___4 *, struct seq_file___241 *, long unsigned int);
};

struct platform_device___5 {
	const char *name;
	int id;
	bool id_auto;
	struct device___53 dev;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct platform_driver___5 {
	int (*probe)(struct platform_device___5 *);
	int (*remove)(struct platform_device___5 *);
	void (*shutdown)(struct platform_device___5 *);
	int (*suspend)(struct platform_device___5 *, pm_message_t);
	int (*resume)(struct platform_device___5 *);
	struct device_driver___53 driver;
	const struct platform_device_id *id_table;
	bool prevent_deferred_probe;
};

enum iproc_pinconf_param {
	IPROC_PINCONF_DRIVE_STRENGTH = 0,
	IPROC_PINCONF_BIAS_DISABLE = 1,
	IPROC_PINCONF_BIAS_PULL_UP = 2,
	IPROC_PINCONF_BIAS_PULL_DOWN = 3,
	IPROC_PINCON_MAX = 4,
};

struct iproc_gpio {
	struct device___53 *dev;
	void *base;
	void *io_ctrl;
	raw_spinlock_t lock;
	struct gpio_chip___2 gc;
	unsigned int num_banks;
	bool pinmux_is_supported;
	enum pin_config_param *pinconf_disable;
	unsigned int nr_pinconf_disable;
	struct pinctrl_dev___4 *pctl;
	struct pinctrl_desc___4 pctldesc;
};

struct fwnode_operations___182;

struct fwnode_handle___182 {
	struct fwnode_handle___182 *secondary;
	const struct fwnode_operations___182 *ops;
};

struct device___248;

struct fwnode_reference_args___182;

struct fwnode_endpoint___182;

struct fwnode_operations___182 {
	struct fwnode_handle___182 * (*get)(struct fwnode_handle___182 *);
	void (*put)(struct fwnode_handle___182 *);
	bool (*device_is_available)(const struct fwnode_handle___182 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___182 *, const struct device___248 *);
	bool (*property_present)(const struct fwnode_handle___182 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___182 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___182 *, const char *, const char **, size_t);
	struct fwnode_handle___182 * (*get_parent)(const struct fwnode_handle___182 *);
	struct fwnode_handle___182 * (*get_next_child_node)(const struct fwnode_handle___182 *, struct fwnode_handle___182 *);
	struct fwnode_handle___182 * (*get_named_child_node)(const struct fwnode_handle___182 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___182 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___182 *);
	struct fwnode_handle___182 * (*graph_get_next_endpoint)(const struct fwnode_handle___182 *, struct fwnode_handle___182 *);
	struct fwnode_handle___182 * (*graph_get_remote_endpoint)(const struct fwnode_handle___182 *);
	struct fwnode_handle___182 * (*graph_get_port_parent)(struct fwnode_handle___182 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___182 *, struct fwnode_endpoint___182 *);
};

struct fwnode_endpoint___182 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___182 *local_fwnode;
};

struct fwnode_reference_args___182 {
	struct fwnode_handle___182 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct dev_pm_info___248 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___248 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___248;

struct bus_type___248;

struct device_driver___248;

struct dev_pm_domain___248;

struct irq_domain___9;

struct dev_pin_info___4;

struct device_node___48;

struct class___248;

struct device___248 {
	struct device___248 *parent;
	struct device_private *p;
	struct kobject___101 kobj;
	const char *init_name;
	const struct device_type___248 *type;
	struct mutex mutex;
	struct bus_type___248 *bus;
	struct device_driver___248 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___248 power;
	struct dev_pm_domain___248 *pm_domain;
	struct irq_domain___9 *msi_domain;
	struct dev_pin_info___4 *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___48 *of_node;
	struct fwnode_handle___182 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___248 *class;
	const struct attribute_group___97 **groups;
	void (*release)(struct device___248 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct device_node___48 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___182 fwnode;
	struct property___35 *properties;
	struct property___35 *deadprops;
	struct device_node___48 *parent;
	struct device_node___48 *child;
	struct device_node___48 *sibling;
	struct kobject___101 kobj;
	long unsigned int _flags;
	void *data;
};

struct of_phandle_args___8 {
	struct device_node___48 *np;
	int args_count;
	uint32_t args[16];
};

struct dev_pm_ops___248 {
	int (*prepare)(struct device___248 *);
	void (*complete)(struct device___248 *);
	int (*suspend)(struct device___248 *);
	int (*resume)(struct device___248 *);
	int (*freeze)(struct device___248 *);
	int (*thaw)(struct device___248 *);
	int (*poweroff)(struct device___248 *);
	int (*restore)(struct device___248 *);
	int (*suspend_late)(struct device___248 *);
	int (*resume_early)(struct device___248 *);
	int (*freeze_late)(struct device___248 *);
	int (*thaw_early)(struct device___248 *);
	int (*poweroff_late)(struct device___248 *);
	int (*restore_early)(struct device___248 *);
	int (*suspend_noirq)(struct device___248 *);
	int (*resume_noirq)(struct device___248 *);
	int (*freeze_noirq)(struct device___248 *);
	int (*thaw_noirq)(struct device___248 *);
	int (*poweroff_noirq)(struct device___248 *);
	int (*restore_noirq)(struct device___248 *);
	int (*runtime_suspend)(struct device___248 *);
	int (*runtime_resume)(struct device___248 *);
	int (*runtime_idle)(struct device___248 *);
};

struct dev_pm_domain___248 {
	struct dev_pm_ops___248 ops;
	void (*detach)(struct device___248 *, bool);
	int (*activate)(struct device___248 *);
	void (*sync)(struct device___248 *);
	void (*dismiss)(struct device___248 *);
};

struct bus_type___248 {
	const char *name;
	const char *dev_name;
	struct device___248 *dev_root;
	const struct attribute_group___97 **bus_groups;
	const struct attribute_group___97 **dev_groups;
	const struct attribute_group___97 **drv_groups;
	int (*match)(struct device___248 *, struct device_driver___248 *);
	int (*uevent)(struct device___248 *, struct kobj_uevent_env *);
	int (*probe)(struct device___248 *);
	int (*remove)(struct device___248 *);
	void (*shutdown)(struct device___248 *);
	int (*online)(struct device___248 *);
	int (*offline)(struct device___248 *);
	int (*suspend)(struct device___248 *, pm_message_t);
	int (*resume)(struct device___248 *);
	int (*num_vf)(struct device___248 *);
	int (*dma_configure)(struct device___248 *);
	const struct dev_pm_ops___248 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___248 {
	const char *name;
	struct bus_type___248 *bus;
	struct module___90 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___248 *);
	int (*remove)(struct device___248 *);
	void (*shutdown)(struct device___248 *);
	int (*suspend)(struct device___248 *, pm_message_t);
	int (*resume)(struct device___248 *);
	const struct attribute_group___97 **groups;
	const struct dev_pm_ops___248 *pm;
	void (*coredump)(struct device___248 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___248 {
	const char *name;
	const struct attribute_group___97 **groups;
	int (*uevent)(struct device___248 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___248 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___248 *);
	const struct dev_pm_ops___248 *pm;
};

struct class___248 {
	const char *name;
	struct module___90 *owner;
	const struct attribute_group___97 **class_groups;
	const struct attribute_group___97 **dev_groups;
	struct kobject___101 *dev_kobj;
	int (*dev_uevent)(struct device___248 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___248 *, umode_t *);
	void (*class_release)(struct class___248 *);
	void (*dev_release)(struct device___248 *);
	int (*shutdown_pre)(struct device___248 *);
	const struct kobj_ns_type_operations___5 *ns_type;
	const void * (*namespace)(struct device___248 *);
	const struct dev_pm_ops___248 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct irq_domain_ops___9;

struct irq_domain_chip_generic___9;

struct irq_domain___9 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___9 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___182 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___9 *gc;
	struct irq_domain___9 *parent;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_direct_max_irq;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_tree_mutex;
	unsigned int linear_revmap[0];
};

struct pinctrl___4;

struct dev_pin_info___4 {
	struct pinctrl___4 *p;
	struct pinctrl_state *default_state;
	struct pinctrl_state *init_state;
	struct pinctrl_state *sleep_state;
	struct pinctrl_state *idle_state;
};

struct platform_device___6 {
	const char *name;
	int id;
	bool id_auto;
	struct device___248 dev;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct pinctrl___4 {
	struct list_head node;
	struct device___248 *dev;
	struct list_head states;
	struct pinctrl_state *state;
	struct list_head dt_maps;
	struct kref users;
};

struct gpio_chip___3;

struct pinctrl_gpio_range___2 {
	struct list_head node;
	const char *name;
	unsigned int id;
	unsigned int base;
	unsigned int pin_base;
	const unsigned int *pins;
	unsigned int npins;
	struct gpio_chip___3 *gc;
};

struct irq_desc___14;

typedef void (*irq_flow_handler_t___14)(struct irq_desc___14 *);

struct irq_chip___17;

struct gpio_irq_chip___3 {
	struct irq_chip___17 *chip;
	struct irq_domain___9 *domain;
	const struct irq_domain_ops___9 *domain_ops;
	irq_flow_handler_t___14 handler;
	unsigned int default_type;
	struct lock_class_key *lock_key;
	struct lock_class_key *request_key;
	irq_flow_handler_t___14 parent_handler;
	void *parent_handler_data;
	unsigned int num_parents;
	unsigned int *parents;
	unsigned int *map;
	bool threaded;
	bool need_valid_mask;
	long unsigned int *valid_mask;
	unsigned int first;
};

struct gpio_chip___3 {
	const char *label;
	struct gpio_device *gpiodev;
	struct device___248 *parent;
	struct module___90 *owner;
	int (*request)(struct gpio_chip___3 *, unsigned int);
	void (*free)(struct gpio_chip___3 *, unsigned int);
	int (*get_direction)(struct gpio_chip___3 *, unsigned int);
	int (*direction_input)(struct gpio_chip___3 *, unsigned int);
	int (*direction_output)(struct gpio_chip___3 *, unsigned int, int);
	int (*get)(struct gpio_chip___3 *, unsigned int);
	int (*get_multiple)(struct gpio_chip___3 *, long unsigned int *, long unsigned int *);
	void (*set)(struct gpio_chip___3 *, unsigned int, int);
	void (*set_multiple)(struct gpio_chip___3 *, long unsigned int *, long unsigned int *);
	int (*set_config)(struct gpio_chip___3 *, unsigned int, long unsigned int);
	int (*to_irq)(struct gpio_chip___3 *, unsigned int);
	void (*dbg_show)(struct seq_file___97 *, struct gpio_chip___3 *);
	int base;
	u16 ngpio;
	const char * const *names;
	bool can_sleep;
	long unsigned int (*read_reg)(void *);
	void (*write_reg)(void *, long unsigned int);
	bool be_bits;
	void *reg_dat;
	void *reg_set;
	void *reg_clr;
	void *reg_dir;
	int bgpio_bits;
	spinlock_t bgpio_lock;
	long unsigned int bgpio_data;
	long unsigned int bgpio_dir;
	struct gpio_irq_chip___3 irq;
	bool need_valid_mask;
	long unsigned int *valid_mask;
	struct device_node___48 *of_node;
	unsigned int of_gpio_n_cells;
	int (*of_xlate)(struct gpio_chip___3 *, const struct of_phandle_args___8 *, u32 *);
};

struct pinctrl_dev___5;

struct pinctrl_ops___5 {
	int (*get_groups_count)(struct pinctrl_dev___5 *);
	const char * (*get_group_name)(struct pinctrl_dev___5 *, unsigned int);
	int (*get_group_pins)(struct pinctrl_dev___5 *, unsigned int, const unsigned int **, unsigned int *);
	void (*pin_dbg_show)(struct pinctrl_dev___5 *, struct seq_file___97 *, unsigned int);
	int (*dt_node_to_map)(struct pinctrl_dev___5 *, struct device_node___48 *, struct pinctrl_map **, unsigned int *);
	void (*dt_free_map)(struct pinctrl_dev___5 *, struct pinctrl_map *, unsigned int);
};

struct pinctrl_desc___5;

struct pinctrl_dev___5 {
	struct list_head node;
	struct pinctrl_desc___5 *desc;
	struct xarray pin_desc_tree;
	struct list_head gpio_ranges;
	struct device___248 *dev;
	struct module___90 *owner;
	void *driver_data;
	struct pinctrl___4 *p;
	struct pinctrl_state *hog_default;
	struct pinctrl_state *hog_sleep;
	struct mutex mutex;
	struct dentry___107 *device_root;
};

struct pinmux_ops___2;

struct pinconf_ops___5;

struct pinctrl_desc___5 {
	const char *name;
	const struct pinctrl_pin_desc *pins;
	unsigned int npins;
	const struct pinctrl_ops___5 *pctlops;
	const struct pinmux_ops___2 *pmxops;
	const struct pinconf_ops___5 *confops;
	struct module___90 *owner;
	unsigned int num_custom_params;
	const struct pinconf_generic_params *custom_params;
	const struct pin_config_item *custom_conf_items;
};

struct pinmux_ops___2 {
	int (*request)(struct pinctrl_dev___5 *, unsigned int);
	int (*free)(struct pinctrl_dev___5 *, unsigned int);
	int (*get_functions_count)(struct pinctrl_dev___5 *);
	const char * (*get_function_name)(struct pinctrl_dev___5 *, unsigned int);
	int (*get_function_groups)(struct pinctrl_dev___5 *, unsigned int, const char * const **, unsigned int *);
	int (*set_mux)(struct pinctrl_dev___5 *, unsigned int, unsigned int);
	int (*gpio_request_enable)(struct pinctrl_dev___5 *, struct pinctrl_gpio_range___2 *, unsigned int);
	void (*gpio_disable_free)(struct pinctrl_dev___5 *, struct pinctrl_gpio_range___2 *, unsigned int);
	int (*gpio_set_direction)(struct pinctrl_dev___5 *, struct pinctrl_gpio_range___2 *, unsigned int, bool);
	bool strict;
};

struct pinconf_ops___5 {
	bool is_generic;
	int (*pin_config_get)(struct pinctrl_dev___5 *, unsigned int, long unsigned int *);
	int (*pin_config_set)(struct pinctrl_dev___5 *, unsigned int, long unsigned int *, unsigned int);
	int (*pin_config_group_get)(struct pinctrl_dev___5 *, unsigned int, long unsigned int *);
	int (*pin_config_group_set)(struct pinctrl_dev___5 *, unsigned int, long unsigned int *, unsigned int);
	int (*pin_config_dbg_parse_modify)(struct pinctrl_dev___5 *, const char *, long unsigned int *);
	void (*pin_config_dbg_show)(struct pinctrl_dev___5 *, struct seq_file___97 *, unsigned int);
	void (*pin_config_group_dbg_show)(struct pinctrl_dev___5 *, struct seq_file___97 *, unsigned int);
	void (*pin_config_config_dbg_show)(struct pinctrl_dev___5 *, struct seq_file___97 *, long unsigned int);
};

struct irq_data___17 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___7 *common;
	struct irq_chip___17 *chip;
	struct irq_domain___9 *domain;
	struct irq_data___17 *parent_data;
	void *chip_data;
};

struct irq_desc___14 {
	struct irq_common_data___7 irq_common_data;
	struct irq_data___17 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___14 handle_irq;
	struct irqaction___7 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int irq_count;
	unsigned int tot_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___101 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___90 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip___17 {
	struct device___248 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___17 *);
	void (*irq_shutdown)(struct irq_data___17 *);
	void (*irq_enable)(struct irq_data___17 *);
	void (*irq_disable)(struct irq_data___17 *);
	void (*irq_ack)(struct irq_data___17 *);
	void (*irq_mask)(struct irq_data___17 *);
	void (*irq_mask_ack)(struct irq_data___17 *);
	void (*irq_unmask)(struct irq_data___17 *);
	void (*irq_eoi)(struct irq_data___17 *);
	int (*irq_set_affinity)(struct irq_data___17 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___17 *);
	int (*irq_set_type)(struct irq_data___17 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___17 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___17 *);
	void (*irq_bus_sync_unlock)(struct irq_data___17 *);
	void (*irq_cpu_online)(struct irq_data___17 *);
	void (*irq_cpu_offline)(struct irq_data___17 *);
	void (*irq_suspend)(struct irq_data___17 *);
	void (*irq_resume)(struct irq_data___17 *);
	void (*irq_pm_shutdown)(struct irq_data___17 *);
	void (*irq_calc_mask)(struct irq_data___17 *);
	void (*irq_print_chip)(struct irq_data___17 *, struct seq_file___97 *);
	int (*irq_request_resources)(struct irq_data___17 *);
	void (*irq_release_resources)(struct irq_data___17 *);
	void (*irq_compose_msi_msg)(struct irq_data___17 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___17 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___17 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___17 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___17 *, void *);
	void (*ipi_send_single)(struct irq_data___17 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___17 *, const struct cpumask *);
	long unsigned int flags;
};

struct irq_chip_type___10 {
	struct irq_chip___17 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___14 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___10 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___10 *);
	void (*resume)(struct irq_chip_generic___10 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___9 *domain;
	struct list_head list;
	struct irq_chip_type___10 chip_types[0];
};

struct irq_domain_chip_generic___9 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___10 *gc[0];
};

struct irq_fwspec___9 {
	struct fwnode_handle___182 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___9 {
	int (*match)(struct irq_domain___9 *, struct device_node___48 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___9 *, struct irq_fwspec___9 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___9 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___9 *, unsigned int);
	int (*xlate)(struct irq_domain___9 *, struct device_node___48 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___9 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___9 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___9 *, struct irq_data___17 *, bool);
	void (*deactivate)(struct irq_domain___9 *, struct irq_data___17 *);
	int (*translate)(struct irq_domain___9 *, struct irq_fwspec___9 *, long unsigned int *, unsigned int *);
};

struct msm_function {
	const char *name;
	const char * const *groups;
	unsigned int ngroups;
};

struct msm_pingroup {
	const char *name;
	const unsigned int *pins;
	unsigned int npins;
	unsigned int *funcs;
	unsigned int nfuncs;
	u32 ctl_reg;
	u32 io_reg;
	u32 intr_cfg_reg;
	u32 intr_status_reg;
	u32 intr_target_reg;
	unsigned int mux_bit: 5;
	unsigned int pull_bit: 5;
	unsigned int drv_bit: 5;
	unsigned int oe_bit: 5;
	unsigned int in_bit: 5;
	unsigned int out_bit: 5;
	char: 2;
	unsigned int intr_enable_bit: 5;
	unsigned int intr_status_bit: 5;
	unsigned int intr_ack_high: 1;
	unsigned int intr_target_bit: 5;
	unsigned int intr_target_kpss_val: 5;
	unsigned int intr_raw_status_bit: 5;
	unsigned int intr_polarity_bit: 5;
	char: 1;
	unsigned int intr_detection_bit: 5;
	unsigned int intr_detection_width: 5;
};

struct msm_pinctrl_soc_data {
	const struct pinctrl_pin_desc *pins;
	unsigned int npins;
	const struct msm_function *functions;
	unsigned int nfunctions;
	const struct msm_pingroup *groups;
	unsigned int ngroups;
	unsigned int ngpios;
	bool pull_no_keeper;
};

struct msm_pinctrl {
	struct device___248 *dev;
	struct pinctrl_dev___5 *pctrl;
	struct gpio_chip___3 chip;
	struct pinctrl_desc___5 desc;
	struct notifier_block restart_nb;
	struct irq_chip___17 irq_chip;
	int irq;
	raw_spinlock_t lock;
	long unsigned int dual_edge_irqs[5];
	long unsigned int enabled_irqs[5];
	const struct msm_pinctrl_soc_data *soc;
	void *regs;
};

struct gpio_irq_chip___4 {
	struct irq_chip___13 *chip;
	struct irq_domain___5 *domain;
	const struct irq_domain_ops___5 *domain_ops;
	irq_flow_handler_t___10 handler;
	unsigned int default_type;
	struct lock_class_key *lock_key;
	struct lock_class_key *request_key;
	irq_flow_handler_t___10 parent_handler;
	void *parent_handler_data;
	unsigned int num_parents;
	unsigned int *parents;
	unsigned int *map;
	bool threaded;
	bool need_valid_mask;
	long unsigned int *valid_mask;
	unsigned int first;
};

struct gpio_device___2;

struct gpio_chip___4 {
	const char *label;
	struct gpio_device___2 *gpiodev;
	struct device___242 *parent;
	struct module___226 *owner;
	int (*request)(struct gpio_chip___4 *, unsigned int);
	void (*free)(struct gpio_chip___4 *, unsigned int);
	int (*get_direction)(struct gpio_chip___4 *, unsigned int);
	int (*direction_input)(struct gpio_chip___4 *, unsigned int);
	int (*direction_output)(struct gpio_chip___4 *, unsigned int, int);
	int (*get)(struct gpio_chip___4 *, unsigned int);
	int (*get_multiple)(struct gpio_chip___4 *, long unsigned int *, long unsigned int *);
	void (*set)(struct gpio_chip___4 *, unsigned int, int);
	void (*set_multiple)(struct gpio_chip___4 *, long unsigned int *, long unsigned int *);
	int (*set_config)(struct gpio_chip___4 *, unsigned int, long unsigned int);
	int (*to_irq)(struct gpio_chip___4 *, unsigned int);
	void (*dbg_show)(struct seq_file___243 *, struct gpio_chip___4 *);
	int base;
	u16 ngpio;
	const char * const *names;
	bool can_sleep;
	long unsigned int (*read_reg)(void *);
	void (*write_reg)(void *, long unsigned int);
	bool be_bits;
	void *reg_dat;
	void *reg_set;
	void *reg_clr;
	void *reg_dir;
	int bgpio_bits;
	spinlock_t bgpio_lock;
	long unsigned int bgpio_data;
	long unsigned int bgpio_dir;
	struct gpio_irq_chip___4 irq;
	bool need_valid_mask;
	long unsigned int *valid_mask;
	struct device_node___43 *of_node;
	unsigned int of_gpio_n_cells;
	int (*of_xlate)(struct gpio_chip___4 *, const struct of_phandle_args___6 *, u32 *);
};

struct gpio_desc___2;

struct gpio_device___2 {
	int id;
	struct device___242 dev;
	struct cdev___43 chrdev;
	struct device___242 *mockdev;
	struct module___226 *owner;
	struct gpio_chip___4 *chip;
	struct gpio_desc___2 *descs;
	int base;
	u16 ngpio;
	const char *label;
	void *data;
	struct list_head list;
	struct list_head pin_ranges;
};

struct gpio_descs {
	unsigned int ndescs;
	struct gpio_desc___2 *desc[0];
};

struct gpio_desc___2 {
	struct gpio_device___2 *gdev;
	long unsigned int flags;
	const char *label;
	const char *name;
};

struct pinctrl_gpio_range___3 {
	struct list_head node;
	const char *name;
	unsigned int id;
	unsigned int base;
	unsigned int pin_base;
	const unsigned int *pins;
	unsigned int npins;
	struct gpio_chip___4 *gc;
};

struct gpio_pin_range {
	struct list_head node;
	struct pinctrl_dev___4 *pctldev;
	struct pinctrl_gpio_range___3 range;
};

enum of_gpio_flags {
	OF_GPIO_ACTIVE_LOW = 1,
	OF_GPIO_SINGLE_ENDED = 2,
	OF_GPIO_OPEN_DRAIN = 4,
	OF_GPIO_TRANSITORY = 8,
};

struct acpi_device___3;

struct acpi_hotplug_profile___3 {
	struct kobject___267 kobj;
	int (*scan_dependent)(struct acpi_device___3 *);
	void (*notify_online)(struct acpi_device___3 *);
	bool enabled: 1;
	bool demand_offline: 1;
};

struct acpi_device_wakeup_context___3 {
	void (*func)(struct acpi_device_wakeup_context___3 *);
	struct device___242 *dev;
};

struct acpi_device_wakeup___3 {
	acpi_handle gpe_device;
	u64 gpe_number;
	u64 sleep_state;
	struct list_head resources;
	struct acpi_device_wakeup_flags flags;
	struct acpi_device_wakeup_context___3 context;
	struct wakeup_source *ws;
	int prepare_count;
	int enable_count;
};

struct acpi_scan_handler___3;

struct acpi_hotplug_context___3;

struct acpi_driver___3;

struct acpi_device___3 {
	int device_type;
	acpi_handle handle;
	struct fwnode_handle___177 fwnode;
	struct acpi_device___3 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup___3 wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_device_data data;
	struct acpi_scan_handler___3 *handler;
	struct acpi_hotplug_context___3 *hp;
	struct acpi_driver___3 *driver;
	const struct acpi_gpio_mapping *driver_gpios;
	void *driver_data;
	struct device___242 dev;
	unsigned int physical_node_count;
	unsigned int dep_unmet;
	struct list_head physical_node_list;
	struct mutex physical_node_lock;
	void (*remove)(struct acpi_device___3 *);
};

struct acpi_scan_handler___3 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	bool (*match)(const char *, const struct acpi_device_id **);
	int (*attach)(struct acpi_device___3 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___3 *);
	void (*bind)(struct device___242 *);
	void (*unbind)(struct device___242 *);
	struct acpi_hotplug_profile___3 hotplug;
};

struct acpi_hotplug_context___3 {
	struct acpi_device___3 *self;
	int (*notify)(struct acpi_device___3 *, u32);
	void (*uevent)(struct acpi_device___3 *, u32);
	void (*fixup)(struct acpi_device___3 *);
};

typedef int (*acpi_op_add___3)(struct acpi_device___3 *);

typedef int (*acpi_op_remove___3)(struct acpi_device___3 *);

typedef void (*acpi_op_notify___3)(struct acpi_device___3 *, u32);

struct acpi_device_ops___3 {
	acpi_op_add___3 add;
	acpi_op_remove___3 remove;
	acpi_op_notify___3 notify;
};

struct acpi_driver___3 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___3 ops;
	struct device_driver___242 drv;
	struct module___226 *owner;
};

typedef struct poll_table_struct___170 poll_table___23;

enum gpio_lookup_flags {
	GPIO_ACTIVE_HIGH = 0,
	GPIO_ACTIVE_LOW = 1,
	GPIO_OPEN_DRAIN = 2,
	GPIO_OPEN_SOURCE = 4,
	GPIO_PERSISTENT = 0,
	GPIO_TRANSITORY = 8,
};

struct gpiod_lookup {
	const char *chip_label;
	u16 chip_hwnum;
	const char *con_id;
	unsigned int idx;
	enum gpio_lookup_flags flags;
};

struct gpiod_lookup_table {
	struct list_head list;
	const char *dev_id;
	struct gpiod_lookup table[0];
};

struct gpiod_hog {
	struct list_head list;
	const char *chip_label;
	u16 chip_hwnum;
	const char *line_name;
	enum gpio_lookup_flags lflags;
	int dflags;
};

struct gpiochip_info {
	char name[32];
	char label[32];
	__u32 lines;
};

struct gpioline_info {
	__u32 line_offset;
	__u32 flags;
	char name[32];
	char consumer[32];
};

struct gpiohandle_request {
	__u32 lineoffsets[64];
	__u32 flags;
	__u8 default_values[64];
	char consumer_label[32];
	__u32 lines;
	int fd;
};

struct gpiohandle_data {
	__u8 values[64];
};

struct gpioevent_request {
	__u32 lineoffset;
	__u32 handleflags;
	__u32 eventflags;
	char consumer_label[32];
	int fd;
};

struct gpioevent_data {
	__u64 timestamp;
	__u32 id;
};

struct acpi_gpio_info {
	struct acpi_device___3 *adev;
	enum gpiod_flags flags;
	bool gpioint;
	int polarity;
	int triggering;
	unsigned int quirks;
};

struct linehandle_state {
	struct gpio_device___2 *gdev;
	const char *label;
	struct gpio_desc___2 *descs[64];
	u32 numdescs;
};

struct lineevent_state {
	struct gpio_device___2 *gdev;
	const char *label;
	struct gpio_desc___2 *desc;
	u32 eflags;
	int irq;
	wait_queue_head_t wait;
	struct {
		union {
			struct __kfifo kfifo;
			struct gpioevent_data *type;
			const struct gpioevent_data *const_type;
			char (*rectype)[0];
			struct gpioevent_data *ptr;
			const struct gpioevent_data *ptr_const;
		};
		struct gpioevent_data buf[16];
	} events;
	struct mutex read_lock;
	u64 timestamp;
};

struct gpio_desc___3 {
	struct gpio_device *gdev;
	long unsigned int flags;
	const char *label;
	const char *name;
};

struct gpio_device {
	int id;
	struct device___245 dev;
	struct cdev___45 chrdev;
	struct device___245 *mockdev;
	struct module___228 *owner;
	struct gpio_chip *chip;
	struct gpio_desc___3 *descs;
	int base;
	u16 ngpio;
	const char *label;
	void *data;
	struct list_head list;
	struct list_head pin_ranges;
};

struct gpio {
	unsigned int gpio;
	long unsigned int flags;
	const char *label;
};

struct of_mm_gpio_chip {
	struct gpio_chip gc;
	void (*save_regs)(struct of_mm_gpio_chip *);
	void *regs;
};

struct class_attribute {
	struct attribute attr;
	ssize_t (*show)(struct class___245 *, struct class_attribute *, char *);
	ssize_t (*store)(struct class___245 *, struct class_attribute *, const char *, size_t);
};

struct gpiod_data {
	struct gpio_desc___3 *desc;
	struct mutex mutex;
	struct kernfs_node___277 *value_kn;
	int irq;
	unsigned char irq_flags;
	bool direction_can_change;
};

typedef u64 acpi_physical_address;

typedef u8 acpi_adr_space_type;

struct acpi_connection_info {
	u8 *connection;
	u16 length;
	u8 access_length;
};

struct acpi_reference_args {
	struct acpi_device___2 *adev;
	size_t nargs;
	u64 args[8];
};

struct acpi_gpio_info___2 {
	struct acpi_device___2 *adev;
	enum gpiod_flags flags;
	bool gpioint;
	int polarity;
	int triggering;
	unsigned int quirks;
};

struct acpi_gpio_event {
	struct list_head node;
	struct list_head initial_sync_list;
	acpi_handle handle;
	unsigned int pin;
	unsigned int irq;
	struct gpio_desc___3 *desc;
};

struct acpi_gpio_connection {
	struct list_head node;
	unsigned int pin;
	struct gpio_desc___3 *desc;
};

struct acpi_gpio_chip {
	struct acpi_connection_info conn_info;
	struct list_head conns;
	struct mutex conn_lock;
	struct gpio_chip *chip;
	struct list_head events;
};

struct acpi_gpio_lookup {
	struct acpi_gpio_info___2 info;
	int index;
	int pin_index;
	bool active_low;
	struct gpio_desc___3 *desc;
	int n;
};

struct amba_id {
	unsigned int id;
	unsigned int mask;
	void *data;
};

struct amba_device {
	struct device___248 dev;
	struct resource res;
	struct clk *pclk;
	unsigned int periphid;
	unsigned int irq[9];
	char *driver_override;
};

struct amba_driver {
	struct device_driver___248 drv;
	int (*probe)(struct amba_device *, const struct amba_id *);
	int (*remove)(struct amba_device *);
	void (*shutdown)(struct amba_device *);
	const struct amba_id *id_table;
};

struct pl061_context_save_regs {
	u8 gpio_data;
	u8 gpio_dir;
	u8 gpio_is;
	u8 gpio_ibe;
	u8 gpio_iev;
	u8 gpio_ie;
};

struct pl061 {
	raw_spinlock_t lock;
	void *base;
	struct gpio_chip___3 gc;
	int parent_irq;
	struct pl061_context_save_regs csave_regs;
};

struct xgene_gpio {
	struct gpio_chip chip;
	void *base;
	spinlock_t lock;
	u32 set_dr_val[3];
};

struct of_phandle_args___9 {
	struct device_node___47 *np;
	int args_count;
	uint32_t args[16];
};

enum pwm_polarity {
	PWM_POLARITY_NORMAL = 0,
	PWM_POLARITY_INVERSED = 1,
};

struct pwm_args {
	unsigned int period;
	enum pwm_polarity polarity;
};

enum {
	PWMF_REQUESTED = 1,
	PWMF_EXPORTED = 2,
};

struct pwm_state {
	unsigned int period;
	unsigned int duty_cycle;
	enum pwm_polarity polarity;
	bool enabled;
};

struct pwm_chip;

struct pwm_device {
	const char *label;
	long unsigned int flags;
	unsigned int hwpwm;
	unsigned int pwm;
	struct pwm_chip *chip;
	void *chip_data;
	struct pwm_args args;
	struct pwm_state state;
};

struct pwm_ops;

struct pwm_chip {
	struct device___247 *dev;
	struct list_head list;
	const struct pwm_ops *ops;
	int base;
	unsigned int npwm;
	struct pwm_device *pwms;
	struct pwm_device * (*of_xlate)(struct pwm_chip *, const struct of_phandle_args___9 *);
	unsigned int of_pwm_n_cells;
};

struct pwm_capture;

struct pwm_ops {
	int (*request)(struct pwm_chip *, struct pwm_device *);
	void (*free)(struct pwm_chip *, struct pwm_device *);
	int (*config)(struct pwm_chip *, struct pwm_device *, int, int);
	int (*set_polarity)(struct pwm_chip *, struct pwm_device *, enum pwm_polarity);
	int (*capture)(struct pwm_chip *, struct pwm_device *, struct pwm_capture *, long unsigned int);
	int (*enable)(struct pwm_chip *, struct pwm_device *);
	void (*disable)(struct pwm_chip *, struct pwm_device *);
	int (*apply)(struct pwm_chip *, struct pwm_device *, struct pwm_state *);
	void (*get_state)(struct pwm_chip *, struct pwm_device *, struct pwm_state *);
	void (*dbg_show)(struct pwm_chip *, struct seq_file___243 *);
	struct module___226 *owner;
};

struct pwm_capture {
	unsigned int period;
	unsigned int duty_cycle;
};

struct pwm_lookup {
	struct list_head list;
	const char *provider;
	unsigned int index;
	const char *dev_id;
	const char *con_id;
	unsigned int period;
	enum pwm_polarity polarity;
	const char *module;
};

typedef void (*dr_release_t___10)(struct device___247 *, void *);

struct pwm_export {
	struct device___247 child;
	struct pwm_device *pwm;
	struct mutex lock;
};

struct platform_driver___6 {
	int (*probe)(struct platform_device___6 *);
	int (*remove)(struct platform_device___6 *);
	void (*shutdown)(struct platform_device___6 *);
	int (*suspend)(struct platform_device___6 *, pm_message_t);
	int (*resume)(struct platform_device___6 *);
	struct device_driver___248 driver;
	const struct platform_device_id *id_table;
	bool prevent_deferred_probe;
};

struct pwm_chip___2;

struct pwm_device___2 {
	const char *label;
	long unsigned int flags;
	unsigned int hwpwm;
	unsigned int pwm;
	struct pwm_chip___2 *chip;
	void *chip_data;
	struct pwm_args args;
	struct pwm_state state;
};

struct pwm_ops___2;

struct pwm_chip___2 {
	struct device___248 *dev;
	struct list_head list;
	const struct pwm_ops___2 *ops;
	int base;
	unsigned int npwm;
	struct pwm_device___2 *pwms;
	struct pwm_device___2 * (*of_xlate)(struct pwm_chip___2 *, const struct of_phandle_args___8 *);
	unsigned int of_pwm_n_cells;
};

struct pwm_ops___2 {
	int (*request)(struct pwm_chip___2 *, struct pwm_device___2 *);
	void (*free)(struct pwm_chip___2 *, struct pwm_device___2 *);
	int (*config)(struct pwm_chip___2 *, struct pwm_device___2 *, int, int);
	int (*set_polarity)(struct pwm_chip___2 *, struct pwm_device___2 *, enum pwm_polarity);
	int (*capture)(struct pwm_chip___2 *, struct pwm_device___2 *, struct pwm_capture *, long unsigned int);
	int (*enable)(struct pwm_chip___2 *, struct pwm_device___2 *);
	void (*disable)(struct pwm_chip___2 *, struct pwm_device___2 *);
	int (*apply)(struct pwm_chip___2 *, struct pwm_device___2 *, struct pwm_state *);
	void (*get_state)(struct pwm_chip___2 *, struct pwm_device___2 *, struct pwm_state *);
	void (*dbg_show)(struct pwm_chip___2 *, struct seq_file___9 *);
	struct module___90 *owner;
};

struct iproc_pwmc {
	struct pwm_chip___2 chip;
	void *base;
	struct clk *clk;
};

struct module___229;

struct file___284;

struct kiocb___284;

struct vm_area_struct___285;

struct inode___284;

struct file_lock___284;

struct page___285;

struct file_operations___284 {
	struct module___229 *owner;
	loff_t (*llseek)(struct file___284 *, loff_t, int);
	ssize_t (*read)(struct file___284 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___284 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___284 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___284 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___284 *, bool);
	int (*iterate)(struct file___284 *, struct dir_context *);
	int (*iterate_shared)(struct file___284 *, struct dir_context *);
	__poll_t (*poll)(struct file___284 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___284 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___284 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___284 *, struct vm_area_struct___285 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___284 *, struct file___284 *);
	int (*flush)(struct file___284 *, fl_owner_t);
	int (*release)(struct inode___284 *, struct file___284 *);
	int (*fsync)(struct file___284 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___284 *, int);
	int (*lock)(struct file___284 *, int, struct file_lock___284 *);
	ssize_t (*sendpage)(struct file___284 *, struct page___285 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___284 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___284 *, int, struct file_lock___284 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___284 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___284 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___284 *, long int, struct file_lock___284 **, void **);
	long int (*fallocate)(struct file___284 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___284 *);
	ssize_t (*copy_file_range)(struct file___284 *, loff_t, struct file___284 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___284 *, loff_t, struct file___284 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___284 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___284 {
	u64 seqnum;
	struct vm_area_struct___285 *vmas[4];
};

struct page_frag___284 {
	struct page___285 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___284;

struct vm_struct___200;

struct task_struct___285 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___285 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___284 *mm;
	struct mm_struct___284 *active_mm;
	struct vmacache___284 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___285 *real_parent;
	struct task_struct___285 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___285 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___194 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___194 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___194 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___2 *ptracer_cred;
	const struct cred___2 *real_cred;
	const struct cred___2 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___285 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___82 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___284 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___285 *oom_reaper_list;
	struct vm_struct___200 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___130 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___285 *pgtable_t___284;

struct address_space___283;

struct dev_pagemap___273;

struct page___285 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___283 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___285 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___284 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___284 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___273 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___284;

struct lruvec___284 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___284 *pgdat;
};

struct zone___284 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___284 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___284 {
	struct zone___284 *zone;
	int zone_idx;
};

struct zonelist___284 {
	struct zoneref___284 _zonerefs[25];
};

struct pglist_data___284 {
	struct zone___284 node_zones[3];
	struct zonelist___284 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___285 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___285 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___284 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___285 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___285 *owner;
};

struct secondary_data___285 {
	void *stack;
	struct task_struct___285 *task;
	long int status;
};

struct blocking_notifier_head___284 {
	struct rw_semaphore___285 rwsem;
	struct notifier_block *head;
};

struct kernfs_root___277;

struct kernfs_elem_dir___277 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___277 *root;
};

struct kernfs_node___278;

struct kernfs_syscall_ops___277;

struct kernfs_root___277 {
	struct kernfs_node___278 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___277 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___277 {
	struct kernfs_node___278 *target_kn;
};

struct kernfs_ops___277;

struct kernfs_elem_attr___277 {
	const struct kernfs_ops___277 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___278 *notify_next;
};

struct kernfs_node___278 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___278 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___277 dir;
		struct kernfs_elem_symlink___277 symlink;
		struct kernfs_elem_attr___277 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___277;

struct kernfs_ops___277 {
	int (*open)(struct kernfs_open_file___277 *);
	void (*release)(struct kernfs_open_file___277 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___277 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___277 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___277 *, struct vm_area_struct___285 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___277 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___277 {
	int (*remount_fs)(struct kernfs_root___277 *, int *, char *);
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___277 *);
	int (*mkdir)(struct kernfs_node___278 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___278 *);
	int (*rename)(struct kernfs_node___278 *, struct kernfs_node___278 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___278 *, struct kernfs_root___277 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_operations_struct___273;

struct kernfs_open_file___277 {
	struct kernfs_node___278 *kn;
	struct file___284 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___273 *vm_ops;
};

struct dentry___284;

struct path___284 {
	struct vfsmount *mnt;
	struct dentry___284 *dentry;
};

struct file___284 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___284 f_path;
	struct inode___284 *f_inode;
	const struct file_operations___284 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___194 f_owner;
	const struct cred___2 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___283 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___273;

struct vm_operations_struct___273 {
	void (*open)(struct vm_area_struct___285 *);
	void (*close)(struct vm_area_struct___285 *);
	int (*split)(struct vm_area_struct___285 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___285 *);
	vm_fault_t (*fault)(struct vm_fault___273 *);
	vm_fault_t (*huge_fault)(struct vm_fault___273 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___273 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___285 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___273 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___273 *);
	int (*access)(struct vm_area_struct___285 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___285 *);
	int (*set_policy)(struct vm_area_struct___285 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___285 *, long unsigned int);
	struct page___285 * (*find_special_page)(struct vm_area_struct___285 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_area_struct___285 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___285 *vm_next;
	struct vm_area_struct___285 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___284 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___273 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___284 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___271;

struct bin_attribute___247;

struct attribute_group___248 {
	const char *name;
	umode_t (*is_visible)(struct kobject___271 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___271 *, struct bin_attribute___247 *, int);
	struct attribute **attrs;
	struct bin_attribute___247 **bin_attrs;
};

struct kset___270;

struct kobj_type___270;

struct kobject___271 {
	const char *name;
	struct list_head entry;
	struct kobject___271 *parent;
	struct kset___270 *kset;
	struct kobj_type___270 *ktype;
	struct kernfs_node___278 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___247 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___284 *, struct kobject___271 *, struct bin_attribute___247 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___284 *, struct kobject___271 *, struct bin_attribute___247 *, char *, loff_t, size_t);
	int (*mmap)(struct file___284 *, struct kobject___271 *, struct bin_attribute___247 *, struct vm_area_struct___285 *);
};

struct sysfs_ops___270 {
	ssize_t (*show)(struct kobject___271 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___271 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___270;

struct kset___270 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___271 kobj;
	const struct kset_uevent_ops___270 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___270 {
	void (*release)(struct kobject___271 *);
	const struct sysfs_ops___270 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___25 * (*child_ns_type)(struct kobject___271 *);
	const void * (*namespace)(struct kobject___271 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___270 {
	int (* const filter)(struct kset___270 *, struct kobject___271 *);
	const char * (* const name)(struct kset___270 *, struct kobject___271 *);
	int (* const uevent)(struct kset___270 *, struct kobject___271 *, struct kobj_uevent_env *);
};

struct kobj_attribute___263 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___271 *, struct kobj_attribute___263 *, char *);
	ssize_t (*store)(struct kobject___271 *, struct kobj_attribute___263 *, const char *, size_t);
};

struct device___249;

struct dev_pm_ops___249 {
	int (*prepare)(struct device___249 *);
	void (*complete)(struct device___249 *);
	int (*suspend)(struct device___249 *);
	int (*resume)(struct device___249 *);
	int (*freeze)(struct device___249 *);
	int (*thaw)(struct device___249 *);
	int (*poweroff)(struct device___249 *);
	int (*restore)(struct device___249 *);
	int (*suspend_late)(struct device___249 *);
	int (*resume_early)(struct device___249 *);
	int (*freeze_late)(struct device___249 *);
	int (*thaw_early)(struct device___249 *);
	int (*poweroff_late)(struct device___249 *);
	int (*restore_early)(struct device___249 *);
	int (*suspend_noirq)(struct device___249 *);
	int (*resume_noirq)(struct device___249 *);
	int (*freeze_noirq)(struct device___249 *);
	int (*thaw_noirq)(struct device___249 *);
	int (*poweroff_noirq)(struct device___249 *);
	int (*restore_noirq)(struct device___249 *);
	int (*runtime_suspend)(struct device___249 *);
	int (*runtime_resume)(struct device___249 *);
	int (*runtime_idle)(struct device___249 *);
};

struct dev_pm_info___249 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___249 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___249;

struct bus_type___249;

struct device_driver___249;

struct dev_pm_domain___249;

struct dma_map_ops___71;

struct fwnode_handle___183;

struct class___249;

struct device___249 {
	struct device___249 *parent;
	struct device_private *p;
	struct kobject___271 kobj;
	const char *init_name;
	const struct device_type___249 *type;
	struct mutex mutex;
	struct bus_type___249 *bus;
	struct device_driver___249 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___249 power;
	struct dev_pm_domain___249 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___71 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___183 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___249 *class;
	const struct attribute_group___248 **groups;
	void (*release)(struct device___249 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___249 {
	struct dev_pm_ops___249 ops;
	void (*detach)(struct device___249 *, bool);
	int (*activate)(struct device___249 *);
	void (*sync)(struct device___249 *);
	void (*dismiss)(struct device___249 *);
};

struct core_state___284;

struct mm_struct___284 {
	struct {
		struct vm_area_struct___285 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___284 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___285 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___284 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___285 *owner;
		struct user_namespace___3 *user_ns;
		struct file___284 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___284 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct vm_struct___200 {
	struct vm_struct___200 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___285 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bus_type___249 {
	const char *name;
	const char *dev_name;
	struct device___249 *dev_root;
	const struct attribute_group___248 **bus_groups;
	const struct attribute_group___248 **dev_groups;
	const struct attribute_group___248 **drv_groups;
	int (*match)(struct device___249 *, struct device_driver___249 *);
	int (*uevent)(struct device___249 *, struct kobj_uevent_env *);
	int (*probe)(struct device___249 *);
	int (*remove)(struct device___249 *);
	void (*shutdown)(struct device___249 *);
	int (*online)(struct device___249 *);
	int (*offline)(struct device___249 *);
	int (*suspend)(struct device___249 *, pm_message_t);
	int (*resume)(struct device___249 *);
	int (*num_vf)(struct device___249 *);
	int (*dma_configure)(struct device___249 *);
	const struct dev_pm_ops___249 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___249 {
	const char *name;
	struct bus_type___249 *bus;
	struct module___229 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___249 *);
	int (*remove)(struct device___249 *);
	void (*shutdown)(struct device___249 *);
	int (*suspend)(struct device___249 *, pm_message_t);
	int (*resume)(struct device___249 *);
	const struct attribute_group___248 **groups;
	const struct dev_pm_ops___249 *pm;
	void (*coredump)(struct device___249 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___249 {
	const char *name;
	const struct attribute_group___248 **groups;
	int (*uevent)(struct device___249 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___249 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___249 *);
	const struct dev_pm_ops___249 *pm;
};

struct module_kobject___226 {
	struct kobject___271 kobj;
	struct module___229 *mod;
	struct kobject___271 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___226 {
	struct module___229 *mod;
	struct latch_tree_node node;
};

struct module_layout___226 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___226 mtn;
};

struct module_attribute___226;

struct kernel_param___226;

struct module___229 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___226 mkobj;
	struct module_attribute___226 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___271 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___226 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___226 core_layout;
	struct module_layout___226 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct class___249 {
	const char *name;
	struct module___229 *owner;
	const struct attribute_group___248 **class_groups;
	const struct attribute_group___248 **dev_groups;
	struct kobject___271 *dev_kobj;
	int (*dev_uevent)(struct device___249 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___249 *, umode_t *);
	void (*class_release)(struct class___249 *);
	void (*dev_release)(struct device___249 *);
	int (*shutdown_pre)(struct device___249 *);
	const struct kobj_ns_type_operations___25 *ns_type;
	const void * (*namespace)(struct device___249 *);
	const struct dev_pm_ops___249 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___71 {
	void * (*alloc)(struct device___249 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___249 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___249 *, struct vm_area_struct___285 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___249 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___249 *, struct page___285 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___249 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___249 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___249 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___249 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___249 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___249 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___249 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___249 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___249 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___249 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___249 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___249 *, u64);
	u64 (*get_required_mask)(struct device___249 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___183;

struct fwnode_handle___183 {
	struct fwnode_handle___183 *secondary;
	const struct fwnode_operations___183 *ops;
};

struct address_space_operations___283;

struct address_space___283 {
	struct inode___284 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___285 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___283 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___273)(struct vm_area_struct___285 *, long unsigned int, const struct page___285 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___273)(struct page___285 *, void *);

struct dev_pagemap___273 {
	dev_page_fault_t___273 page_fault;
	dev_page_free_t___273 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___249 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___284 {
	struct task_struct___285 *task;
	struct core_thread___284 *next;
};

struct core_state___284 {
	atomic_t nr_threads;
	struct core_thread___284 dumper;
	struct completion startup;
};

struct vm_fault___273 {
	struct vm_area_struct___285 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___285 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___285 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___284 prealloc_pte;
};

struct fwnode_reference_args___183;

struct fwnode_endpoint___183;

struct fwnode_operations___183 {
	struct fwnode_handle___183 * (*get)(struct fwnode_handle___183 *);
	void (*put)(struct fwnode_handle___183 *);
	bool (*device_is_available)(const struct fwnode_handle___183 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___183 *, const struct device___249 *);
	bool (*property_present)(const struct fwnode_handle___183 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___183 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___183 *, const char *, const char **, size_t);
	struct fwnode_handle___183 * (*get_parent)(const struct fwnode_handle___183 *);
	struct fwnode_handle___183 * (*get_next_child_node)(const struct fwnode_handle___183 *, struct fwnode_handle___183 *);
	struct fwnode_handle___183 * (*get_named_child_node)(const struct fwnode_handle___183 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___183 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___183 *);
	struct fwnode_handle___183 * (*graph_get_next_endpoint)(const struct fwnode_handle___183 *, struct fwnode_handle___183 *);
	struct fwnode_handle___183 * (*graph_get_remote_endpoint)(const struct fwnode_handle___183 *);
	struct fwnode_handle___183 * (*graph_get_port_parent)(struct fwnode_handle___183 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___183 *, struct fwnode_endpoint___183 *);
};

struct fwnode_endpoint___183 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___183 *local_fwnode;
};

struct fwnode_reference_args___183 {
	struct fwnode_handle___183 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pci_bus___5;

struct pci_slot___5 {
	struct pci_bus___5 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject___271 kobj;
};

struct pci_dev___5;

struct pci_ops___5;

struct pci_bus___5 {
	struct list_head node;
	struct pci_bus___5 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___5 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___5 *ops;
	struct msi_controller___2 *msi;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	int domain_nr;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___249 *bridge;
	struct device___249 dev;
	struct bin_attribute___247 *legacy_io;
	struct bin_attribute___247 *legacy_mem;
	unsigned int is_added: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
};

struct pci_sriov___2 {
	int pos;
	int nres;
	u32 cap;
	u16 ctrl;
	u16 total_VFs;
	u16 initial_VFs;
	u16 num_VFs;
	u16 offset;
	u16 stride;
	u16 vf_device;
	u32 pgsz;
	u8 link;
	u8 max_VF_buses;
	u16 driver_max_VFs;
	struct pci_dev___5 *dev;
	struct pci_dev___5 *self;
	u32 class;
	u8 hdr_type;
	u16 subsystem_vendor;
	u16 subsystem_device;
	resource_size_t barsz[6];
	bool drivers_autoprobe;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct pci_driver___5;

struct pci_dev___5 {
	struct list_head bus_list;
	struct pci_bus___5 *bus;
	struct pci_bus___5 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___5 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u16 aer_cap;
	struct aer_stats *aer_stats;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	long unsigned int *dma_alias_mask;
	struct pci_driver___5 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	unsigned int imm_ready: 1;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int bridge_d3: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int hotplug_user_indicators: 1;
	unsigned int clear_retrain_link: 1;
	unsigned int d3_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	unsigned int ltr_path: 1;
	unsigned int eetlp_prefix_path: 1;
	pci_channel_state_t error_state;
	struct device___249 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int multifunction: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int ats_enabled: 1;
	unsigned int pasid_enabled: 1;
	unsigned int pri_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int reset_fn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int shpc_managed: 1;
	unsigned int is_thunderbolt: 1;
	unsigned int __aer_firmware_first_valid: 1;
	unsigned int __aer_firmware_first: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int irq_managed: 1;
	unsigned int has_secondary_link: 1;
	unsigned int non_compliant_bars: 1;
	unsigned int is_probed: 1;
	unsigned int link_active_reporting: 1;
	unsigned int untrusted: 1;
	unsigned int no_vf_scan: 1;
	unsigned int io_window: 1;
	unsigned int pref_window: 1;
	unsigned int pref_64_window: 1;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	struct bin_attribute___247 *rom_attr;
	int rom_attr_enabled;
	struct bin_attribute___247 *res_attr[17];
	struct bin_attribute___247 *res_attr_wc[17];
	unsigned int broken_cmd_compl: 1;
	const struct attribute_group___248 **msi_irq_groups;
	struct pci_vpd *vpd;
	union {
		struct pci_sriov___2 *sriov;
		struct pci_dev___5 *physfn;
	};
	u16 ats_cap;
	u8 ats_stu;
	atomic_t ats_ref_cnt;
	u32 pri_reqs_alloc;
	u16 pasid_features;
	struct pci_p2pdma *p2pdma;
	phys_addr_t rom;
	size_t romlen;
	char *driver_override;
	long unsigned int priv_flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t pci_dev_extended_size_rh;
	struct pci_dev_extended_rh pci_dev_extended_rh;
};

struct pci_error_handlers___5;

struct pci_driver___5 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___5 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___5 *);
	int (*suspend)(struct pci_dev___5 *, pm_message_t);
	int (*suspend_late)(struct pci_dev___5 *, pm_message_t);
	int (*resume_early)(struct pci_dev___5 *);
	int (*resume)(struct pci_dev___5 *);
	void (*shutdown)(struct pci_dev___5 *);
	int (*sriov_configure)(struct pci_dev___5 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	const struct pci_error_handlers___5 *err_handler;
	const struct attribute_group___248 **groups;
	struct device_driver___249 driver;
	struct pci_dynids dynids;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct pci_ops___5 {
	int (*add_bus)(struct pci_bus___5 *);
	void (*remove_bus)(struct pci_bus___5 *);
	void * (*map_bus)(struct pci_bus___5 *, unsigned int, int);
	int (*read)(struct pci_bus___5 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___5 *, unsigned int, int, int, u32);
};

struct pci_error_handlers___5 {
	pci_ers_result_t (*error_detected)(struct pci_dev___5 *, enum pci_channel_state);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___5 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___5 *);
	void (*reset_prepare)(struct pci_dev___5 *);
	void (*reset_done)(struct pci_dev___5 *);
	void (*resume)(struct pci_dev___5 *);
};

struct dentry_operations___283;

struct super_block___283;

struct dentry___284 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___284 *d_parent;
	struct qstr d_name;
	struct inode___284 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___283 *d_op;
	struct super_block___283 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___283;

struct block_device___283;

struct inode___284 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___283 *i_op;
	struct super_block___283 *i_sb;
	struct address_space___283 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___285 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___284 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___283 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___283 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___283 {
	int (*d_revalidate)(struct dentry___284 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___284 *, unsigned int);
	int (*d_hash)(const struct dentry___284 *, struct qstr *);
	int (*d_compare)(const struct dentry___284 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___284 *);
	int (*d_init)(struct dentry___284 *);
	void (*d_release)(struct dentry___284 *);
	void (*d_prune)(struct dentry___284 *);
	void (*d_iput)(struct dentry___284 *, struct inode___284 *);
	char * (*d_dname)(struct dentry___284 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___284 *);
	int (*d_manage)(const struct path___284 *, bool);
	struct dentry___284 * (*d_real)(struct dentry___284 *, const struct inode___284 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___283;

struct mem_dqinfo___283 {
	struct quota_format_type___283 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___283;

struct quota_info___283 {
	unsigned int flags;
	struct rw_semaphore___285 dqio_sem;
	struct inode___284 *files[3];
	struct mem_dqinfo___283 info[3];
	const struct quota_format_ops___283 *ops[3];
};

struct rcuwait___283 {
	struct task_struct___285 *task;
};

struct percpu_rw_semaphore___283 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___285 rw_sem;
	struct rcuwait___283 writer;
	int readers_block;
};

struct sb_writers___283 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___283 rw_sem[3];
};

struct file_system_type___283;

struct super_operations___283;

struct dquot_operations___283;

struct quotactl_ops___283;

struct super_block___283 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___283 *s_type;
	const struct super_operations___283 *s_op;
	const struct dquot_operations___283 *dq_op;
	const struct quotactl_ops___283 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___284 *s_root;
	struct rw_semaphore___285 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___283 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___283 s_dquot;
	struct sb_writers___283 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___283 *s_d_op;
	int cleancache_poolid;
	struct shrinker___115 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___284 {
	struct file___284 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___284 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___283 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___284 *ia_file;
};

struct dquot___283 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___283 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___283 {
	int qf_fmt_id;
	const struct quota_format_ops___283 *qf_ops;
	struct module___229 *qf_owner;
	struct quota_format_type___283 *qf_next;
};

struct quota_format_ops___283 {
	int (*check_quota_file)(struct super_block___283 *, int);
	int (*read_file_info)(struct super_block___283 *, int);
	int (*write_file_info)(struct super_block___283 *, int);
	int (*free_file_info)(struct super_block___283 *, int);
	int (*read_dqblk)(struct dquot___283 *);
	int (*commit_dqblk)(struct dquot___283 *);
	int (*release_dqblk)(struct dquot___283 *);
	int (*get_next_id)(struct super_block___283 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___283 {
	int (*write_dquot)(struct dquot___283 *);
	struct dquot___283 * (*alloc_dquot)(struct super_block___283 *, int);
	void (*destroy_dquot)(struct dquot___283 *);
	int (*acquire_dquot)(struct dquot___283 *);
	int (*release_dquot)(struct dquot___283 *);
	int (*mark_dirty)(struct dquot___283 *);
	int (*write_info)(struct super_block___283 *, int);
	qsize_t * (*get_reserved_space)(struct inode___284 *);
	int (*get_projid)(struct inode___284 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___284 *, qsize_t *);
	int (*get_next_id)(struct super_block___283 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___283 {
	int (*quota_on)(struct super_block___283 *, int, int, const struct path___284 *);
	int (*quota_off)(struct super_block___283 *, int);
	int (*quota_enable)(struct super_block___283 *, unsigned int);
	int (*quota_disable)(struct super_block___283 *, unsigned int);
	int (*quota_sync)(struct super_block___283 *, int);
	int (*set_info)(struct super_block___283 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___283 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___283 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___283 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___283 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___283 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___283 {
	int (*writepage)(struct page___285 *, struct writeback_control___3 *);
	int (*readpage)(struct file___284 *, struct page___285 *);
	int (*writepages)(struct address_space___283 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___285 *);
	int (*readpages)(struct file___284 *, struct address_space___283 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___284 *, struct address_space___283 *, loff_t, unsigned int, unsigned int, struct page___285 **, void **);
	int (*write_end)(struct file___284 *, struct address_space___283 *, loff_t, unsigned int, unsigned int, struct page___285 *, void *);
	sector_t (*bmap)(struct address_space___283 *, sector_t);
	void (*invalidatepage)(struct page___285 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___285 *, gfp_t);
	void (*freepage)(struct page___285 *);
	ssize_t (*direct_IO)(struct kiocb___284 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___283 *, struct page___285 *, struct page___285 *, enum migrate_mode);
	bool (*isolate_page)(struct page___285 *, isolate_mode_t);
	void (*putback_page)(struct page___285 *);
	int (*launder_page)(struct page___285 *);
	int (*is_partially_uptodate)(struct page___285 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___285 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___283 *, struct page___285 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___284 *, sector_t *);
	void (*swap_deactivate)(struct file___284 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___283 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___284 *bd_inode;
	struct super_block___283 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___283 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___283 {
	struct dentry___284 * (*lookup)(struct inode___284 *, struct dentry___284 *, unsigned int);
	const char * (*get_link)(struct dentry___284 *, struct inode___284 *, struct delayed_call *);
	int (*permission)(struct inode___284 *, int);
	struct posix_acl * (*get_acl)(struct inode___284 *, int);
	int (*readlink)(struct dentry___284 *, char *, int);
	int (*create)(struct inode___284 *, struct dentry___284 *, umode_t, bool);
	int (*link)(struct dentry___284 *, struct inode___284 *, struct dentry___284 *);
	int (*unlink)(struct inode___284 *, struct dentry___284 *);
	int (*symlink)(struct inode___284 *, struct dentry___284 *, const char *);
	int (*mkdir)(struct inode___284 *, struct dentry___284 *, umode_t);
	int (*rmdir)(struct inode___284 *, struct dentry___284 *);
	int (*mknod)(struct inode___284 *, struct dentry___284 *, umode_t, dev_t);
	int (*rename)(struct inode___284 *, struct dentry___284 *, struct inode___284 *, struct dentry___284 *, unsigned int);
	int (*setattr)(struct dentry___284 *, struct iattr___283 *);
	int (*getattr)(const struct path___284 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___284 *, char *, size_t);
	int (*fiemap)(struct inode___284 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___284 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___284 *, struct dentry___284 *, struct file___284 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___284 *, struct dentry___284 *, umode_t);
	int (*set_acl)(struct inode___284 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___283 {
	void (*fl_copy_lock)(struct file_lock___284 *, struct file_lock___284 *);
	void (*fl_release_private)(struct file_lock___284 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___283;

struct lock_manager_operations___283;

struct file_lock___284 {
	struct file_lock___284 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___284 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___283 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___283 *fl_ops;
	const struct lock_manager_operations___283 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___283 {
	int (*lm_compare_owner)(struct file_lock___284 *, struct file_lock___284 *);
	long unsigned int (*lm_owner_key)(struct file_lock___284 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___284 *);
	int (*lm_grant)(struct file_lock___284 *, int);
	bool (*lm_break)(struct file_lock___284 *);
	int (*lm_change)(struct file_lock___284 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___284 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___283 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___283 *fa_next;
	struct file___284 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___283 {
	const char *name;
	int fs_flags;
	struct dentry___284 * (*mount)(struct file_system_type___283 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___283 *);
	struct module___229 *owner;
	struct file_system_type___283 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___283 {
	struct inode___284 * (*alloc_inode)(struct super_block___283 *);
	void (*destroy_inode)(struct inode___284 *);
	void (*dirty_inode)(struct inode___284 *, int);
	int (*write_inode)(struct inode___284 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___284 *);
	void (*evict_inode)(struct inode___284 *);
	void (*put_super)(struct super_block___283 *);
	int (*sync_fs)(struct super_block___283 *, int);
	int (*freeze_super)(struct super_block___283 *);
	int (*freeze_fs)(struct super_block___283 *);
	int (*thaw_super)(struct super_block___283 *);
	int (*unfreeze_fs)(struct super_block___283 *);
	int (*statfs)(struct dentry___284 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___283 *, int *, char *);
	void (*umount_begin)(struct super_block___283 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___284 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___284 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___284 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___284 *);
	ssize_t (*quota_read)(struct super_block___283 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___283 *, int, const char *, size_t, loff_t);
	struct dquot___283 ** (*get_dquots)(struct inode___284 *);
	int (*bdev_try_to_free_page)(struct super_block___283 *, struct page___285 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___283 *, struct shrink_control___115 *);
	long int (*free_cached_objects)(struct super_block___283 *, struct shrink_control___115 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___273(struct page___285 *);

struct kernel_param_ops___226 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___226 *);
	int (*get)(char *, const struct kernel_param___226 *);
	void (*free)(void *);
};

struct kparam_array___226;

struct kernel_param___226 {
	const char *name;
	struct module___229 *mod;
	const struct kernel_param_ops___226 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___226 *arr;
	};
};

struct kparam_array___226 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___226 *ops;
	void *elem;
};

struct module_attribute___226 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___226 *, struct module_kobject___226 *, char *);
	ssize_t (*store)(struct module_attribute___226 *, struct module_kobject___226 *, const char *, size_t);
	void (*setup)(struct module___229 *, const char *);
	int (*test)(struct module___229 *);
	void (*free)(struct module___229 *);
};

struct module___230;

struct file___285;

struct kiocb___285;

struct vm_area_struct___286;

struct inode___285;

struct file_lock___285;

struct page___286;

struct file_operations___285 {
	struct module___230 *owner;
	loff_t (*llseek)(struct file___285 *, loff_t, int);
	ssize_t (*read)(struct file___285 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___285 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___285 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___285 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___285 *, bool);
	int (*iterate)(struct file___285 *, struct dir_context *);
	int (*iterate_shared)(struct file___285 *, struct dir_context *);
	__poll_t (*poll)(struct file___285 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___285 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___285 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___285 *, struct vm_area_struct___286 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___285 *, struct file___285 *);
	int (*flush)(struct file___285 *, fl_owner_t);
	int (*release)(struct inode___285 *, struct file___285 *);
	int (*fsync)(struct file___285 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___285 *, int);
	int (*lock)(struct file___285 *, int, struct file_lock___285 *);
	ssize_t (*sendpage)(struct file___285 *, struct page___286 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___285 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___285 *, int, struct file_lock___285 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___285 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___285 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___285 *, long int, struct file_lock___285 **, void **);
	long int (*fallocate)(struct file___285 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___285 *);
	ssize_t (*copy_file_range)(struct file___285 *, loff_t, struct file___285 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___285 *, loff_t, struct file___285 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___285 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___285 {
	u64 seqnum;
	struct vm_area_struct___286 *vmas[4];
};

struct page_frag___285 {
	struct page___286 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___285;

struct vm_struct___201;

struct task_struct___286 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___286 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___285 *mm;
	struct mm_struct___285 *active_mm;
	struct vmacache___285 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___286 *real_parent;
	struct task_struct___286 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___286 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___194 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___194 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___194 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___2 *ptracer_cred;
	const struct cred___2 *real_cred;
	const struct cred___2 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___286 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___82 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___285 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___286 *oom_reaper_list;
	struct vm_struct___201 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___130 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___286 *pgtable_t___285;

struct address_space___284;

struct dev_pagemap___274;

struct page___286 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___284 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___286 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___285 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___285 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___274 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___285;

struct lruvec___285 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___285 *pgdat;
};

struct zone___285 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___285 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___285 {
	struct zone___285 *zone;
	int zone_idx;
};

struct zonelist___285 {
	struct zoneref___285 _zonerefs[25];
};

struct pglist_data___285 {
	struct zone___285 node_zones[3];
	struct zonelist___285 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___286 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___286 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___285 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___286 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___286 *owner;
};

struct secondary_data___286 {
	void *stack;
	struct task_struct___286 *task;
	long int status;
};

struct blocking_notifier_head___285 {
	struct rw_semaphore___286 rwsem;
	struct notifier_block *head;
};

struct dentry___285;

struct path___285 {
	struct vfsmount *mnt;
	struct dentry___285 *dentry;
};

struct file___285 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___285 f_path;
	struct inode___285 *f_inode;
	const struct file_operations___285 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___194 f_owner;
	const struct cred___2 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___284 *f_mapping;
	errseq_t f_wb_err;
};

struct kernfs_root___278;

struct kernfs_elem_dir___278 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___278 *root;
};

struct kernfs_node___279;

struct kernfs_syscall_ops___278;

struct kernfs_root___278 {
	struct kernfs_node___279 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___278 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___278 {
	struct kernfs_node___279 *target_kn;
};

struct kernfs_ops___278;

struct kernfs_elem_attr___278 {
	const struct kernfs_ops___278 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___279 *notify_next;
};

struct kernfs_node___279 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___279 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___278 dir;
		struct kernfs_elem_symlink___278 symlink;
		struct kernfs_elem_attr___278 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___278;

struct kernfs_ops___278 {
	int (*open)(struct kernfs_open_file___278 *);
	void (*release)(struct kernfs_open_file___278 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___278 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___278 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___278 *, struct vm_area_struct___286 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___278 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___278 {
	int (*remount_fs)(struct kernfs_root___278 *, int *, char *);
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___278 *);
	int (*mkdir)(struct kernfs_node___279 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___279 *);
	int (*rename)(struct kernfs_node___279 *, struct kernfs_node___279 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___279 *, struct kernfs_root___278 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_operations_struct___274;

struct kernfs_open_file___278 {
	struct kernfs_node___279 *kn;
	struct file___285 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___274 *vm_ops;
};

struct vm_fault___274;

struct vm_operations_struct___274 {
	void (*open)(struct vm_area_struct___286 *);
	void (*close)(struct vm_area_struct___286 *);
	int (*split)(struct vm_area_struct___286 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___286 *);
	vm_fault_t (*fault)(struct vm_fault___274 *);
	vm_fault_t (*huge_fault)(struct vm_fault___274 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___274 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___286 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___274 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___274 *);
	int (*access)(struct vm_area_struct___286 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___286 *);
	int (*set_policy)(struct vm_area_struct___286 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___286 *, long unsigned int);
	struct page___286 * (*find_special_page)(struct vm_area_struct___286 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_area_struct___286 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___286 *vm_next;
	struct vm_area_struct___286 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___285 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___274 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___285 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___272;

struct bin_attribute___248;

struct attribute_group___249 {
	const char *name;
	umode_t (*is_visible)(struct kobject___272 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___272 *, struct bin_attribute___248 *, int);
	struct attribute **attrs;
	struct bin_attribute___248 **bin_attrs;
};

struct kset___271;

struct kobj_type___271;

struct kobject___272 {
	const char *name;
	struct list_head entry;
	struct kobject___272 *parent;
	struct kset___271 *kset;
	struct kobj_type___271 *ktype;
	struct kernfs_node___279 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___248 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___285 *, struct kobject___272 *, struct bin_attribute___248 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___285 *, struct kobject___272 *, struct bin_attribute___248 *, char *, loff_t, size_t);
	int (*mmap)(struct file___285 *, struct kobject___272 *, struct bin_attribute___248 *, struct vm_area_struct___286 *);
};

struct sysfs_ops___271 {
	ssize_t (*show)(struct kobject___272 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___272 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___271;

struct kset___271 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___272 kobj;
	const struct kset_uevent_ops___271 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___271 {
	void (*release)(struct kobject___272 *);
	const struct sysfs_ops___271 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___25 * (*child_ns_type)(struct kobject___272 *);
	const void * (*namespace)(struct kobject___272 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___271 {
	int (* const filter)(struct kset___271 *, struct kobject___272 *);
	const char * (* const name)(struct kset___271 *, struct kobject___272 *);
	int (* const uevent)(struct kset___271 *, struct kobject___272 *, struct kobj_uevent_env *);
};

struct kobj_attribute___264 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___272 *, struct kobj_attribute___264 *, char *);
	ssize_t (*store)(struct kobject___272 *, struct kobj_attribute___264 *, const char *, size_t);
};

struct kernel_param___227;

struct kernel_param_ops___227 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___227 *);
	int (*get)(char *, const struct kernel_param___227 *);
	void (*free)(void *);
};

struct kparam_array___227;

struct kernel_param___227 {
	const char *name;
	struct module___230 *mod;
	const struct kernel_param_ops___227 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___227 *arr;
	};
};

struct kparam_array___227 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___227 *ops;
	void *elem;
};

struct module_kobject___227 {
	struct kobject___272 kobj;
	struct module___230 *mod;
	struct kobject___272 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___227 {
	struct module___230 *mod;
	struct latch_tree_node node;
};

struct module_layout___227 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___227 mtn;
};

struct module_attribute___227;

struct module___230 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___227 mkobj;
	struct module_attribute___227 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___272 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___227 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___227 core_layout;
	struct module_layout___227 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___227 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___227 *, struct module_kobject___227 *, char *);
	ssize_t (*store)(struct module_attribute___227 *, struct module_kobject___227 *, const char *, size_t);
	void (*setup)(struct module___230 *, const char *);
	int (*test)(struct module___230 *);
	void (*free)(struct module___230 *);
};

struct device___250;

struct dev_pm_ops___250 {
	int (*prepare)(struct device___250 *);
	void (*complete)(struct device___250 *);
	int (*suspend)(struct device___250 *);
	int (*resume)(struct device___250 *);
	int (*freeze)(struct device___250 *);
	int (*thaw)(struct device___250 *);
	int (*poweroff)(struct device___250 *);
	int (*restore)(struct device___250 *);
	int (*suspend_late)(struct device___250 *);
	int (*resume_early)(struct device___250 *);
	int (*freeze_late)(struct device___250 *);
	int (*thaw_early)(struct device___250 *);
	int (*poweroff_late)(struct device___250 *);
	int (*restore_early)(struct device___250 *);
	int (*suspend_noirq)(struct device___250 *);
	int (*resume_noirq)(struct device___250 *);
	int (*freeze_noirq)(struct device___250 *);
	int (*thaw_noirq)(struct device___250 *);
	int (*poweroff_noirq)(struct device___250 *);
	int (*restore_noirq)(struct device___250 *);
	int (*runtime_suspend)(struct device___250 *);
	int (*runtime_resume)(struct device___250 *);
	int (*runtime_idle)(struct device___250 *);
};

struct dev_pm_info___250 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___250 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___250;

struct bus_type___250;

struct device_driver___250;

struct dev_pm_domain___250;

struct dma_map_ops___72;

struct fwnode_handle___184;

struct class___250;

struct device___250 {
	struct device___250 *parent;
	struct device_private *p;
	struct kobject___272 kobj;
	const char *init_name;
	const struct device_type___250 *type;
	struct mutex mutex;
	struct bus_type___250 *bus;
	struct device_driver___250 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___250 power;
	struct dev_pm_domain___250 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___72 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___184 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___250 *class;
	const struct attribute_group___249 **groups;
	void (*release)(struct device___250 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___250 {
	struct dev_pm_ops___250 ops;
	void (*detach)(struct device___250 *, bool);
	int (*activate)(struct device___250 *);
	void (*sync)(struct device___250 *);
	void (*dismiss)(struct device___250 *);
};

struct core_state___285;

struct mm_struct___285 {
	struct {
		struct vm_area_struct___286 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___285 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___286 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___285 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___286 *owner;
		struct user_namespace___3 *user_ns;
		struct file___285 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___285 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct vm_struct___201 {
	struct vm_struct___201 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___286 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bus_type___250 {
	const char *name;
	const char *dev_name;
	struct device___250 *dev_root;
	const struct attribute_group___249 **bus_groups;
	const struct attribute_group___249 **dev_groups;
	const struct attribute_group___249 **drv_groups;
	int (*match)(struct device___250 *, struct device_driver___250 *);
	int (*uevent)(struct device___250 *, struct kobj_uevent_env *);
	int (*probe)(struct device___250 *);
	int (*remove)(struct device___250 *);
	void (*shutdown)(struct device___250 *);
	int (*online)(struct device___250 *);
	int (*offline)(struct device___250 *);
	int (*suspend)(struct device___250 *, pm_message_t);
	int (*resume)(struct device___250 *);
	int (*num_vf)(struct device___250 *);
	int (*dma_configure)(struct device___250 *);
	const struct dev_pm_ops___250 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___250 {
	const char *name;
	struct bus_type___250 *bus;
	struct module___230 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___250 *);
	int (*remove)(struct device___250 *);
	void (*shutdown)(struct device___250 *);
	int (*suspend)(struct device___250 *, pm_message_t);
	int (*resume)(struct device___250 *);
	const struct attribute_group___249 **groups;
	const struct dev_pm_ops___250 *pm;
	void (*coredump)(struct device___250 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___250 {
	const char *name;
	const struct attribute_group___249 **groups;
	int (*uevent)(struct device___250 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___250 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___250 *);
	const struct dev_pm_ops___250 *pm;
};

struct class___250 {
	const char *name;
	struct module___230 *owner;
	const struct attribute_group___249 **class_groups;
	const struct attribute_group___249 **dev_groups;
	struct kobject___272 *dev_kobj;
	int (*dev_uevent)(struct device___250 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___250 *, umode_t *);
	void (*class_release)(struct class___250 *);
	void (*dev_release)(struct device___250 *);
	int (*shutdown_pre)(struct device___250 *);
	const struct kobj_ns_type_operations___25 *ns_type;
	const void * (*namespace)(struct device___250 *);
	const struct dev_pm_ops___250 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___72 {
	void * (*alloc)(struct device___250 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___250 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___250 *, struct vm_area_struct___286 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___250 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___250 *, struct page___286 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___250 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___250 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___250 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___250 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___250 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___250 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___250 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___250 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___250 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___250 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___250 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___250 *, u64);
	u64 (*get_required_mask)(struct device___250 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___184;

struct fwnode_handle___184 {
	struct fwnode_handle___184 *secondary;
	const struct fwnode_operations___184 *ops;
};

struct address_space_operations___284;

struct address_space___284 {
	struct inode___285 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___286 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___284 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___274)(struct vm_area_struct___286 *, long unsigned int, const struct page___286 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___274)(struct page___286 *, void *);

struct dev_pagemap___274 {
	dev_page_fault_t___274 page_fault;
	dev_page_free_t___274 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___250 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___285 {
	struct task_struct___286 *task;
	struct core_thread___285 *next;
};

struct core_state___285 {
	atomic_t nr_threads;
	struct core_thread___285 dumper;
	struct completion startup;
};

struct vm_fault___274 {
	struct vm_area_struct___286 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___286 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___286 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___285 prealloc_pte;
};

struct fwnode_reference_args___184;

struct fwnode_endpoint___184;

struct fwnode_operations___184 {
	struct fwnode_handle___184 * (*get)(struct fwnode_handle___184 *);
	void (*put)(struct fwnode_handle___184 *);
	bool (*device_is_available)(const struct fwnode_handle___184 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___184 *, const struct device___250 *);
	bool (*property_present)(const struct fwnode_handle___184 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___184 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___184 *, const char *, const char **, size_t);
	struct fwnode_handle___184 * (*get_parent)(const struct fwnode_handle___184 *);
	struct fwnode_handle___184 * (*get_next_child_node)(const struct fwnode_handle___184 *, struct fwnode_handle___184 *);
	struct fwnode_handle___184 * (*get_named_child_node)(const struct fwnode_handle___184 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___184 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___184 *);
	struct fwnode_handle___184 * (*graph_get_next_endpoint)(const struct fwnode_handle___184 *, struct fwnode_handle___184 *);
	struct fwnode_handle___184 * (*graph_get_remote_endpoint)(const struct fwnode_handle___184 *);
	struct fwnode_handle___184 * (*graph_get_port_parent)(struct fwnode_handle___184 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___184 *, struct fwnode_endpoint___184 *);
};

struct fwnode_endpoint___184 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___184 *local_fwnode;
};

struct fwnode_reference_args___184 {
	struct fwnode_handle___184 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pci_bus___6;

struct pci_slot___6 {
	struct pci_bus___6 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject___272 kobj;
};

struct pci_dev___6;

struct pci_ops___6;

struct pci_bus___6 {
	struct list_head node;
	struct pci_bus___6 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___6 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___6 *ops;
	struct msi_controller___2 *msi;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	int domain_nr;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___250 *bridge;
	struct device___250 dev;
	struct bin_attribute___248 *legacy_io;
	struct bin_attribute___248 *legacy_mem;
	unsigned int is_added: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
};

struct pci_sriov___3 {
	int pos;
	int nres;
	u32 cap;
	u16 ctrl;
	u16 total_VFs;
	u16 initial_VFs;
	u16 num_VFs;
	u16 offset;
	u16 stride;
	u16 vf_device;
	u32 pgsz;
	u8 link;
	u8 max_VF_buses;
	u16 driver_max_VFs;
	struct pci_dev___6 *dev;
	struct pci_dev___6 *self;
	u32 class;
	u8 hdr_type;
	u16 subsystem_vendor;
	u16 subsystem_device;
	resource_size_t barsz[6];
	bool drivers_autoprobe;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct pci_driver___6;

struct pci_dev___6 {
	struct list_head bus_list;
	struct pci_bus___6 *bus;
	struct pci_bus___6 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___6 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u16 aer_cap;
	struct aer_stats *aer_stats;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	long unsigned int *dma_alias_mask;
	struct pci_driver___6 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	unsigned int imm_ready: 1;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int bridge_d3: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int hotplug_user_indicators: 1;
	unsigned int clear_retrain_link: 1;
	unsigned int d3_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	unsigned int ltr_path: 1;
	unsigned int eetlp_prefix_path: 1;
	pci_channel_state_t error_state;
	struct device___250 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int multifunction: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int ats_enabled: 1;
	unsigned int pasid_enabled: 1;
	unsigned int pri_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int reset_fn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int shpc_managed: 1;
	unsigned int is_thunderbolt: 1;
	unsigned int __aer_firmware_first_valid: 1;
	unsigned int __aer_firmware_first: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int irq_managed: 1;
	unsigned int has_secondary_link: 1;
	unsigned int non_compliant_bars: 1;
	unsigned int is_probed: 1;
	unsigned int link_active_reporting: 1;
	unsigned int untrusted: 1;
	unsigned int no_vf_scan: 1;
	unsigned int io_window: 1;
	unsigned int pref_window: 1;
	unsigned int pref_64_window: 1;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	struct bin_attribute___248 *rom_attr;
	int rom_attr_enabled;
	struct bin_attribute___248 *res_attr[17];
	struct bin_attribute___248 *res_attr_wc[17];
	unsigned int broken_cmd_compl: 1;
	const struct attribute_group___249 **msi_irq_groups;
	struct pci_vpd *vpd;
	union {
		struct pci_sriov___3 *sriov;
		struct pci_dev___6 *physfn;
	};
	u16 ats_cap;
	u8 ats_stu;
	atomic_t ats_ref_cnt;
	u32 pri_reqs_alloc;
	u16 pasid_features;
	struct pci_p2pdma *p2pdma;
	phys_addr_t rom;
	size_t romlen;
	char *driver_override;
	long unsigned int priv_flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t pci_dev_extended_size_rh;
	struct pci_dev_extended_rh pci_dev_extended_rh;
};

struct pci_error_handlers___6;

struct pci_driver___6 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___6 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___6 *);
	int (*suspend)(struct pci_dev___6 *, pm_message_t);
	int (*suspend_late)(struct pci_dev___6 *, pm_message_t);
	int (*resume_early)(struct pci_dev___6 *);
	int (*resume)(struct pci_dev___6 *);
	void (*shutdown)(struct pci_dev___6 *);
	int (*sriov_configure)(struct pci_dev___6 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	const struct pci_error_handlers___6 *err_handler;
	const struct attribute_group___249 **groups;
	struct device_driver___250 driver;
	struct pci_dynids dynids;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct pci_ops___6 {
	int (*add_bus)(struct pci_bus___6 *);
	void (*remove_bus)(struct pci_bus___6 *);
	void * (*map_bus)(struct pci_bus___6 *, unsigned int, int);
	int (*read)(struct pci_bus___6 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___6 *, unsigned int, int, int, u32);
};

struct pci_bus_resource {
	struct list_head list;
	struct resource *res;
	unsigned int flags;
};

typedef u64 pci_bus_addr_t;

struct pci_bus_region {
	pci_bus_addr_t start;
	pci_bus_addr_t end;
};

struct pci_error_handlers___6 {
	pci_ers_result_t (*error_detected)(struct pci_dev___6 *, enum pci_channel_state);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___6 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___6 *);
	void (*reset_prepare)(struct pci_dev___6 *);
	void (*reset_done)(struct pci_dev___6 *);
	void (*resume)(struct pci_dev___6 *);
};

struct dentry_operations___284;

struct super_block___284;

struct dentry___285 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___285 *d_parent;
	struct qstr d_name;
	struct inode___285 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___284 *d_op;
	struct super_block___284 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___284;

struct block_device___284;

struct inode___285 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___284 *i_op;
	struct super_block___284 *i_sb;
	struct address_space___284 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___286 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___285 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___284 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___284 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___284 {
	int (*d_revalidate)(struct dentry___285 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___285 *, unsigned int);
	int (*d_hash)(const struct dentry___285 *, struct qstr *);
	int (*d_compare)(const struct dentry___285 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___285 *);
	int (*d_init)(struct dentry___285 *);
	void (*d_release)(struct dentry___285 *);
	void (*d_prune)(struct dentry___285 *);
	void (*d_iput)(struct dentry___285 *, struct inode___285 *);
	char * (*d_dname)(struct dentry___285 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___285 *);
	int (*d_manage)(const struct path___285 *, bool);
	struct dentry___285 * (*d_real)(struct dentry___285 *, const struct inode___285 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___284;

struct mem_dqinfo___284 {
	struct quota_format_type___284 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___284;

struct quota_info___284 {
	unsigned int flags;
	struct rw_semaphore___286 dqio_sem;
	struct inode___285 *files[3];
	struct mem_dqinfo___284 info[3];
	const struct quota_format_ops___284 *ops[3];
};

struct rcuwait___284 {
	struct task_struct___286 *task;
};

struct percpu_rw_semaphore___284 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___286 rw_sem;
	struct rcuwait___284 writer;
	int readers_block;
};

struct sb_writers___284 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___284 rw_sem[3];
};

struct file_system_type___284;

struct super_operations___284;

struct dquot_operations___284;

struct quotactl_ops___284;

struct super_block___284 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___284 *s_type;
	const struct super_operations___284 *s_op;
	const struct dquot_operations___284 *dq_op;
	const struct quotactl_ops___284 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___285 *s_root;
	struct rw_semaphore___286 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___284 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___284 s_dquot;
	struct sb_writers___284 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___284 *s_d_op;
	int cleancache_poolid;
	struct shrinker___115 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___285 {
	struct file___285 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___285 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___284 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___285 *ia_file;
};

struct dquot___284 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___284 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___284 {
	int qf_fmt_id;
	const struct quota_format_ops___284 *qf_ops;
	struct module___230 *qf_owner;
	struct quota_format_type___284 *qf_next;
};

struct quota_format_ops___284 {
	int (*check_quota_file)(struct super_block___284 *, int);
	int (*read_file_info)(struct super_block___284 *, int);
	int (*write_file_info)(struct super_block___284 *, int);
	int (*free_file_info)(struct super_block___284 *, int);
	int (*read_dqblk)(struct dquot___284 *);
	int (*commit_dqblk)(struct dquot___284 *);
	int (*release_dqblk)(struct dquot___284 *);
	int (*get_next_id)(struct super_block___284 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___284 {
	int (*write_dquot)(struct dquot___284 *);
	struct dquot___284 * (*alloc_dquot)(struct super_block___284 *, int);
	void (*destroy_dquot)(struct dquot___284 *);
	int (*acquire_dquot)(struct dquot___284 *);
	int (*release_dquot)(struct dquot___284 *);
	int (*mark_dirty)(struct dquot___284 *);
	int (*write_info)(struct super_block___284 *, int);
	qsize_t * (*get_reserved_space)(struct inode___285 *);
	int (*get_projid)(struct inode___285 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___285 *, qsize_t *);
	int (*get_next_id)(struct super_block___284 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___284 {
	int (*quota_on)(struct super_block___284 *, int, int, const struct path___285 *);
	int (*quota_off)(struct super_block___284 *, int);
	int (*quota_enable)(struct super_block___284 *, unsigned int);
	int (*quota_disable)(struct super_block___284 *, unsigned int);
	int (*quota_sync)(struct super_block___284 *, int);
	int (*set_info)(struct super_block___284 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___284 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___284 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___284 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___284 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___284 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___284 {
	int (*writepage)(struct page___286 *, struct writeback_control___3 *);
	int (*readpage)(struct file___285 *, struct page___286 *);
	int (*writepages)(struct address_space___284 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___286 *);
	int (*readpages)(struct file___285 *, struct address_space___284 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___285 *, struct address_space___284 *, loff_t, unsigned int, unsigned int, struct page___286 **, void **);
	int (*write_end)(struct file___285 *, struct address_space___284 *, loff_t, unsigned int, unsigned int, struct page___286 *, void *);
	sector_t (*bmap)(struct address_space___284 *, sector_t);
	void (*invalidatepage)(struct page___286 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___286 *, gfp_t);
	void (*freepage)(struct page___286 *);
	ssize_t (*direct_IO)(struct kiocb___285 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___284 *, struct page___286 *, struct page___286 *, enum migrate_mode);
	bool (*isolate_page)(struct page___286 *, isolate_mode_t);
	void (*putback_page)(struct page___286 *);
	int (*launder_page)(struct page___286 *);
	int (*is_partially_uptodate)(struct page___286 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___286 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___284 *, struct page___286 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___285 *, sector_t *);
	void (*swap_deactivate)(struct file___285 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___284 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___285 *bd_inode;
	struct super_block___284 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___284 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___284 {
	struct dentry___285 * (*lookup)(struct inode___285 *, struct dentry___285 *, unsigned int);
	const char * (*get_link)(struct dentry___285 *, struct inode___285 *, struct delayed_call *);
	int (*permission)(struct inode___285 *, int);
	struct posix_acl * (*get_acl)(struct inode___285 *, int);
	int (*readlink)(struct dentry___285 *, char *, int);
	int (*create)(struct inode___285 *, struct dentry___285 *, umode_t, bool);
	int (*link)(struct dentry___285 *, struct inode___285 *, struct dentry___285 *);
	int (*unlink)(struct inode___285 *, struct dentry___285 *);
	int (*symlink)(struct inode___285 *, struct dentry___285 *, const char *);
	int (*mkdir)(struct inode___285 *, struct dentry___285 *, umode_t);
	int (*rmdir)(struct inode___285 *, struct dentry___285 *);
	int (*mknod)(struct inode___285 *, struct dentry___285 *, umode_t, dev_t);
	int (*rename)(struct inode___285 *, struct dentry___285 *, struct inode___285 *, struct dentry___285 *, unsigned int);
	int (*setattr)(struct dentry___285 *, struct iattr___284 *);
	int (*getattr)(const struct path___285 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___285 *, char *, size_t);
	int (*fiemap)(struct inode___285 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___285 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___285 *, struct dentry___285 *, struct file___285 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___285 *, struct dentry___285 *, umode_t);
	int (*set_acl)(struct inode___285 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___284 {
	void (*fl_copy_lock)(struct file_lock___285 *, struct file_lock___285 *);
	void (*fl_release_private)(struct file_lock___285 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___284;

struct lock_manager_operations___284;

struct file_lock___285 {
	struct file_lock___285 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___285 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___284 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___284 *fl_ops;
	const struct lock_manager_operations___284 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___284 {
	int (*lm_compare_owner)(struct file_lock___285 *, struct file_lock___285 *);
	long unsigned int (*lm_owner_key)(struct file_lock___285 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___285 *);
	int (*lm_grant)(struct file_lock___285 *, int);
	bool (*lm_break)(struct file_lock___285 *);
	int (*lm_change)(struct file_lock___285 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___285 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___284 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___284 *fa_next;
	struct file___285 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___284 {
	const char *name;
	int fs_flags;
	struct dentry___285 * (*mount)(struct file_system_type___284 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___284 *);
	struct module___230 *owner;
	struct file_system_type___284 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___284 {
	struct inode___285 * (*alloc_inode)(struct super_block___284 *);
	void (*destroy_inode)(struct inode___285 *);
	void (*dirty_inode)(struct inode___285 *, int);
	int (*write_inode)(struct inode___285 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___285 *);
	void (*evict_inode)(struct inode___285 *);
	void (*put_super)(struct super_block___284 *);
	int (*sync_fs)(struct super_block___284 *, int);
	int (*freeze_super)(struct super_block___284 *);
	int (*freeze_fs)(struct super_block___284 *);
	int (*thaw_super)(struct super_block___284 *);
	int (*unfreeze_fs)(struct super_block___284 *);
	int (*statfs)(struct dentry___285 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___284 *, int *, char *);
	void (*umount_begin)(struct super_block___284 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___285 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___285 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___285 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___285 *);
	ssize_t (*quota_read)(struct super_block___284 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___284 *, int, const char *, size_t, loff_t);
	struct dquot___284 ** (*get_dquots)(struct inode___285 *);
	int (*bdev_try_to_free_page)(struct super_block___284 *, struct page___286 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___284 *, struct shrink_control___115 *);
	long int (*free_cached_objects)(struct super_block___284 *, struct shrink_control___115 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___274(struct page___286 *);

enum pci_fixup_pass {
	pci_fixup_early = 0,
	pci_fixup_header = 1,
	pci_fixup_final = 2,
	pci_fixup_enable = 3,
	pci_fixup_resume = 4,
	pci_fixup_suspend = 5,
	pci_fixup_resume_early = 6,
	pci_fixup_suspend_late = 7,
};

struct module___231;

struct file___286;

struct kiocb___286;

struct poll_table_struct___173;

struct vm_area_struct___287;

struct inode___286;

struct file_lock___286;

struct page___287;

struct seq_file___246;

struct file_operations___286 {
	struct module___231 *owner;
	loff_t (*llseek)(struct file___286 *, loff_t, int);
	ssize_t (*read)(struct file___286 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___286 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___286 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___286 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___286 *, bool);
	int (*iterate)(struct file___286 *, struct dir_context *);
	int (*iterate_shared)(struct file___286 *, struct dir_context *);
	__poll_t (*poll)(struct file___286 *, struct poll_table_struct___173 *);
	long int (*unlocked_ioctl)(struct file___286 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___286 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___286 *, struct vm_area_struct___287 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___286 *, struct file___286 *);
	int (*flush)(struct file___286 *, fl_owner_t);
	int (*release)(struct inode___286 *, struct file___286 *);
	int (*fsync)(struct file___286 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___286 *, int);
	int (*lock)(struct file___286 *, int, struct file_lock___286 *);
	ssize_t (*sendpage)(struct file___286 *, struct page___287 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___286 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___286 *, int, struct file_lock___286 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___286 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___286 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___286 *, long int, struct file_lock___286 **, void **);
	long int (*fallocate)(struct file___286 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___246 *, struct file___286 *);
	ssize_t (*copy_file_range)(struct file___286 *, loff_t, struct file___286 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___286 *, loff_t, struct file___286 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___286 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___286 {
	u64 seqnum;
	struct vm_area_struct___287 *vmas[4];
};

struct page_frag___286 {
	struct page___287 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___286;

struct cred___267;

struct vm_struct___202;

struct task_struct___287 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___287 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___286 *mm;
	struct mm_struct___286 *active_mm;
	struct vmacache___286 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___287 *real_parent;
	struct task_struct___287 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___287 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___194 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___194 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___194 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___267 *ptracer_cred;
	const struct cred___267 *real_cred;
	const struct cred___267 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___287 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___82 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___286 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___287 *oom_reaper_list;
	struct vm_struct___202 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___130 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___287 *pgtable_t___286;

struct address_space___285;

struct dev_pagemap___275;

struct page___287 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___285 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___287 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___286 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___286 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___275 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___286;

struct lruvec___286 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___286 *pgdat;
};

struct zone___286 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___286 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___286 {
	struct zone___286 *zone;
	int zone_idx;
};

struct zonelist___286 {
	struct zoneref___286 _zonerefs[25];
};

struct pglist_data___286 {
	struct zone___286 node_zones[3];
	struct zonelist___286 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___287 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___287 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___286 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___287 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___287 *owner;
};

struct secondary_data___287 {
	void *stack;
	struct task_struct___287 *task;
	long int status;
};

struct blocking_notifier_head___286 {
	struct rw_semaphore___287 rwsem;
	struct notifier_block *head;
};

struct kernfs_root___279;

struct kernfs_elem_dir___279 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___279 *root;
};

struct kernfs_node___280;

struct kernfs_syscall_ops___279;

struct kernfs_root___279 {
	struct kernfs_node___280 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___279 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___279 {
	struct kernfs_node___280 *target_kn;
};

struct kernfs_ops___279;

struct kernfs_elem_attr___279 {
	const struct kernfs_ops___279 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___280 *notify_next;
};

struct kernfs_node___280 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___280 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___279 dir;
		struct kernfs_elem_symlink___279 symlink;
		struct kernfs_elem_attr___279 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___279;

struct kernfs_ops___279 {
	int (*open)(struct kernfs_open_file___279 *);
	void (*release)(struct kernfs_open_file___279 *);
	int (*seq_show)(struct seq_file___246 *, void *);
	void * (*seq_start)(struct seq_file___246 *, loff_t *);
	void * (*seq_next)(struct seq_file___246 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___246 *, void *);
	ssize_t (*read)(struct kernfs_open_file___279 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___279 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___279 *, struct vm_area_struct___287 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___279 *, struct poll_table_struct___173 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___279 {
	int (*remount_fs)(struct kernfs_root___279 *, int *, char *);
	int (*show_options)(struct seq_file___246 *, struct kernfs_root___279 *);
	int (*mkdir)(struct kernfs_node___280 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___280 *);
	int (*rename)(struct kernfs_node___280 *, struct kernfs_node___280 *, const char *);
	int (*show_path)(struct seq_file___246 *, struct kernfs_node___280 *, struct kernfs_root___279 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___245;

struct seq_file___246 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___245 *op;
	int poll_event;
	const struct file___286 *file;
	void *private;
};

struct vm_operations_struct___275;

struct kernfs_open_file___279 {
	struct kernfs_node___280 *kn;
	struct file___286 *file;
	struct seq_file___246 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___275 *vm_ops;
};

struct dentry___286;

struct path___286 {
	struct vfsmount *mnt;
	struct dentry___286 *dentry;
};

struct file___286 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___286 f_path;
	struct inode___286 *f_inode;
	const struct file_operations___286 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___194 f_owner;
	const struct cred___267 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___285 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___275;

struct vm_operations_struct___275 {
	void (*open)(struct vm_area_struct___287 *);
	void (*close)(struct vm_area_struct___287 *);
	int (*split)(struct vm_area_struct___287 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___287 *);
	vm_fault_t (*fault)(struct vm_fault___275 *);
	vm_fault_t (*huge_fault)(struct vm_fault___275 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___275 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___287 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___275 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___275 *);
	int (*access)(struct vm_area_struct___287 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___287 *);
	int (*set_policy)(struct vm_area_struct___287 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___287 *, long unsigned int);
	struct page___287 * (*find_special_page)(struct vm_area_struct___287 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___176)(struct file___286 *, wait_queue_head_t *, struct poll_table_struct___173 *);

struct poll_table_struct___173 {
	poll_queue_proc___176 _qproc;
	__poll_t _key;
};

struct vm_area_struct___287 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___287 *vm_next;
	struct vm_area_struct___287 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___286 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___275 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___286 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___273;

struct bin_attribute___249;

struct attribute_group___250 {
	const char *name;
	umode_t (*is_visible)(struct kobject___273 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___273 *, struct bin_attribute___249 *, int);
	struct attribute **attrs;
	struct bin_attribute___249 **bin_attrs;
};

struct kset___272;

struct kobj_type___272;

struct kobject___273 {
	const char *name;
	struct list_head entry;
	struct kobject___273 *parent;
	struct kset___272 *kset;
	struct kobj_type___272 *ktype;
	struct kernfs_node___280 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___249 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___286 *, struct kobject___273 *, struct bin_attribute___249 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___286 *, struct kobject___273 *, struct bin_attribute___249 *, char *, loff_t, size_t);
	int (*mmap)(struct file___286 *, struct kobject___273 *, struct bin_attribute___249 *, struct vm_area_struct___287 *);
};

struct sysfs_ops___272 {
	ssize_t (*show)(struct kobject___273 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___273 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___272;

struct kset___272 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___273 kobj;
	const struct kset_uevent_ops___272 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___272 {
	void (*release)(struct kobject___273 *);
	const struct sysfs_ops___272 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___25 * (*child_ns_type)(struct kobject___273 *);
	const void * (*namespace)(struct kobject___273 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___272 {
	int (* const filter)(struct kset___272 *, struct kobject___273 *);
	const char * (* const name)(struct kset___272 *, struct kobject___273 *);
	int (* const uevent)(struct kset___272 *, struct kobject___273 *, struct kobj_uevent_env *);
};

struct kobj_attribute___265 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___273 *, struct kobj_attribute___265 *, char *);
	ssize_t (*store)(struct kobject___273 *, struct kobj_attribute___265 *, const char *, size_t);
};

struct device___251;

struct dev_pm_ops___251 {
	int (*prepare)(struct device___251 *);
	void (*complete)(struct device___251 *);
	int (*suspend)(struct device___251 *);
	int (*resume)(struct device___251 *);
	int (*freeze)(struct device___251 *);
	int (*thaw)(struct device___251 *);
	int (*poweroff)(struct device___251 *);
	int (*restore)(struct device___251 *);
	int (*suspend_late)(struct device___251 *);
	int (*resume_early)(struct device___251 *);
	int (*freeze_late)(struct device___251 *);
	int (*thaw_early)(struct device___251 *);
	int (*poweroff_late)(struct device___251 *);
	int (*restore_early)(struct device___251 *);
	int (*suspend_noirq)(struct device___251 *);
	int (*resume_noirq)(struct device___251 *);
	int (*freeze_noirq)(struct device___251 *);
	int (*thaw_noirq)(struct device___251 *);
	int (*poweroff_noirq)(struct device___251 *);
	int (*restore_noirq)(struct device___251 *);
	int (*runtime_suspend)(struct device___251 *);
	int (*runtime_resume)(struct device___251 *);
	int (*runtime_idle)(struct device___251 *);
};

struct dev_pm_info___251 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___251 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___251;

struct bus_type___251;

struct device_driver___251;

struct dev_pm_domain___251;

struct irq_domain___10;

struct dma_map_ops___73;

struct device_node___49;

struct fwnode_handle___185;

struct class___251;

struct device___251 {
	struct device___251 *parent;
	struct device_private *p;
	struct kobject___273 kobj;
	const char *init_name;
	const struct device_type___251 *type;
	struct mutex mutex;
	struct bus_type___251 *bus;
	struct device_driver___251 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___251 power;
	struct dev_pm_domain___251 *pm_domain;
	struct irq_domain___10 *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___73 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___49 *of_node;
	struct fwnode_handle___185 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___251 *class;
	const struct attribute_group___250 **groups;
	void (*release)(struct device___251 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___251 {
	struct dev_pm_ops___251 ops;
	void (*detach)(struct device___251 *, bool);
	int (*activate)(struct device___251 *);
	void (*sync)(struct device___251 *);
	void (*dismiss)(struct device___251 *);
};

struct key___267;

struct user_struct___267 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___267 *uid_keyring;
	struct key___267 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___286;

struct mm_struct___286 {
	struct {
		struct vm_area_struct___287 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___286 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___287 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___286 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___287 *owner;
		struct user_namespace___3 *user_ns;
		struct file___286 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___286 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___267 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___267 *session_keyring;
	struct key___267 *process_keyring;
	struct key___267 *thread_keyring;
	struct key___267 *request_key_auth;
	void *security;
	struct user_struct___267 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct vm_struct___202 {
	struct vm_struct___202 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___287 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bus_type___251 {
	const char *name;
	const char *dev_name;
	struct device___251 *dev_root;
	const struct attribute_group___250 **bus_groups;
	const struct attribute_group___250 **dev_groups;
	const struct attribute_group___250 **drv_groups;
	int (*match)(struct device___251 *, struct device_driver___251 *);
	int (*uevent)(struct device___251 *, struct kobj_uevent_env *);
	int (*probe)(struct device___251 *);
	int (*remove)(struct device___251 *);
	void (*shutdown)(struct device___251 *);
	int (*online)(struct device___251 *);
	int (*offline)(struct device___251 *);
	int (*suspend)(struct device___251 *, pm_message_t);
	int (*resume)(struct device___251 *);
	int (*num_vf)(struct device___251 *);
	int (*dma_configure)(struct device___251 *);
	const struct dev_pm_ops___251 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___251 {
	const char *name;
	struct bus_type___251 *bus;
	struct module___231 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___251 *);
	int (*remove)(struct device___251 *);
	void (*shutdown)(struct device___251 *);
	int (*suspend)(struct device___251 *, pm_message_t);
	int (*resume)(struct device___251 *);
	const struct attribute_group___250 **groups;
	const struct dev_pm_ops___251 *pm;
	void (*coredump)(struct device___251 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___251 {
	const char *name;
	const struct attribute_group___250 **groups;
	int (*uevent)(struct device___251 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___251 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___251 *);
	const struct dev_pm_ops___251 *pm;
};

struct module_kobject___228 {
	struct kobject___273 kobj;
	struct module___231 *mod;
	struct kobject___273 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___228 {
	struct module___231 *mod;
	struct latch_tree_node node;
};

struct module_layout___228 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___228 mtn;
};

struct module_attribute___228;

struct kernel_param___228;

struct module___231 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___228 mkobj;
	struct module_attribute___228 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___273 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___228 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___228 core_layout;
	struct module_layout___228 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct class___251 {
	const char *name;
	struct module___231 *owner;
	const struct attribute_group___250 **class_groups;
	const struct attribute_group___250 **dev_groups;
	struct kobject___273 *dev_kobj;
	int (*dev_uevent)(struct device___251 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___251 *, umode_t *);
	void (*class_release)(struct class___251 *);
	void (*dev_release)(struct device___251 *);
	int (*shutdown_pre)(struct device___251 *);
	const struct kobj_ns_type_operations___25 *ns_type;
	const void * (*namespace)(struct device___251 *);
	const struct dev_pm_ops___251 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct irq_domain_ops___10;

struct irq_domain___10 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___10 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___185 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___2 *gc;
	struct irq_domain___10 *parent;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_direct_max_irq;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_tree_mutex;
	unsigned int linear_revmap[0];
};

struct dma_map_ops___73 {
	void * (*alloc)(struct device___251 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___251 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___251 *, struct vm_area_struct___287 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___251 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___251 *, struct page___287 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___251 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___251 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___251 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___251 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___251 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___251 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___251 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___251 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___251 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___251 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___251 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___251 *, u64);
	u64 (*get_required_mask)(struct device___251 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___185;

struct fwnode_handle___185 {
	struct fwnode_handle___185 *secondary;
	const struct fwnode_operations___185 *ops;
};

struct property___46;

struct device_node___49 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___185 fwnode;
	struct property___46 *properties;
	struct property___46 *deadprops;
	struct device_node___49 *parent;
	struct device_node___49 *child;
	struct device_node___49 *sibling;
	struct kobject___273 kobj;
	long unsigned int _flags;
	void *data;
};

struct address_space_operations___285;

struct address_space___285 {
	struct inode___286 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___287 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___285 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___275)(struct vm_area_struct___287 *, long unsigned int, const struct page___287 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___275)(struct page___287 *, void *);

struct dev_pagemap___275 {
	dev_page_fault_t___275 page_fault;
	dev_page_free_t___275 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___251 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___286 {
	struct task_struct___287 *task;
	struct core_thread___286 *next;
};

struct core_state___286 {
	atomic_t nr_threads;
	struct core_thread___286 dumper;
	struct completion startup;
};

struct vm_fault___275 {
	struct vm_area_struct___287 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___287 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___287 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___286 prealloc_pte;
};

struct fwnode_reference_args___185;

struct fwnode_endpoint___185;

struct fwnode_operations___185 {
	struct fwnode_handle___185 * (*get)(struct fwnode_handle___185 *);
	void (*put)(struct fwnode_handle___185 *);
	bool (*device_is_available)(const struct fwnode_handle___185 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___185 *, const struct device___251 *);
	bool (*property_present)(const struct fwnode_handle___185 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___185 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___185 *, const char *, const char **, size_t);
	struct fwnode_handle___185 * (*get_parent)(const struct fwnode_handle___185 *);
	struct fwnode_handle___185 * (*get_next_child_node)(const struct fwnode_handle___185 *, struct fwnode_handle___185 *);
	struct fwnode_handle___185 * (*get_named_child_node)(const struct fwnode_handle___185 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___185 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___185 *);
	struct fwnode_handle___185 * (*graph_get_next_endpoint)(const struct fwnode_handle___185 *, struct fwnode_handle___185 *);
	struct fwnode_handle___185 * (*graph_get_remote_endpoint)(const struct fwnode_handle___185 *);
	struct fwnode_handle___185 * (*graph_get_port_parent)(struct fwnode_handle___185 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___185 *, struct fwnode_endpoint___185 *);
};

struct fwnode_endpoint___185 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___185 *local_fwnode;
};

struct fwnode_reference_args___185 {
	struct fwnode_handle___185 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pci_bus___7;

struct pci_slot___7 {
	struct pci_bus___7 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject___273 kobj;
};

struct pci_dev___7;

struct pci_ops___7;

struct pci_bus___7 {
	struct list_head node;
	struct pci_bus___7 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___7 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___7 *ops;
	struct msi_controller___2 *msi;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	int domain_nr;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___251 *bridge;
	struct device___251 dev;
	struct bin_attribute___249 *legacy_io;
	struct bin_attribute___249 *legacy_mem;
	unsigned int is_added: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
};

struct hotplug_slot_ops;

struct hotplug_slot {
	const struct hotplug_slot_ops *ops;
	struct list_head slot_list;
	struct pci_slot___7 *pci_slot;
	struct module___231 *owner;
	const char *mod_name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

enum pci_dev_flags {
	PCI_DEV_FLAGS_MSI_INTX_DISABLE_BUG = 1,
	PCI_DEV_FLAGS_NO_D3 = 2,
	PCI_DEV_FLAGS_ASSIGNED = 4,
	PCI_DEV_FLAGS_ACS_ENABLED_QUIRK = 8,
	PCI_DEV_FLAG_PCIE_BRIDGE_ALIAS = 32,
	PCI_DEV_FLAGS_NO_BUS_RESET = 64,
	PCI_DEV_FLAGS_NO_PM_RESET = 128,
	PCI_DEV_FLAGS_VPD_REF_F0 = 256,
	PCI_DEV_FLAGS_BRIDGE_XLATE_ROOT = 512,
	PCI_DEV_FLAGS_NO_FLR_RESET = 1024,
	PCI_DEV_FLAGS_NO_RELAXED_ORDERING = 2048,
};

enum pci_bus_flags {
	PCI_BUS_FLAGS_NO_MSI = 1,
	PCI_BUS_FLAGS_NO_MMRBC = 2,
	PCI_BUS_FLAGS_NO_AERSID = 4,
	PCI_BUS_FLAGS_NO_EXTCFG = 8,
};

enum pci_bus_speed {
	PCI_SPEED_33MHz = 0,
	PCI_SPEED_66MHz = 1,
	PCI_SPEED_66MHz_PCIX = 2,
	PCI_SPEED_100MHz_PCIX = 3,
	PCI_SPEED_133MHz_PCIX = 4,
	PCI_SPEED_66MHz_PCIX_ECC = 5,
	PCI_SPEED_100MHz_PCIX_ECC = 6,
	PCI_SPEED_133MHz_PCIX_ECC = 7,
	PCI_SPEED_66MHz_PCIX_266 = 9,
	PCI_SPEED_100MHz_PCIX_266 = 10,
	PCI_SPEED_133MHz_PCIX_266 = 11,
	AGP_UNKNOWN = 12,
	AGP_1X = 13,
	AGP_2X = 14,
	AGP_4X = 15,
	AGP_8X = 16,
	PCI_SPEED_66MHz_PCIX_533 = 17,
	PCI_SPEED_100MHz_PCIX_533 = 18,
	PCI_SPEED_133MHz_PCIX_533 = 19,
	PCIE_SPEED_2_5GT = 20,
	PCIE_SPEED_5_0GT = 21,
	PCIE_SPEED_8_0GT = 22,
	PCIE_SPEED_16_0GT = 23,
	PCI_SPEED_UNKNOWN = 255,
};

struct pci_sriov___4 {
	int pos;
	int nres;
	u32 cap;
	u16 ctrl;
	u16 total_VFs;
	u16 initial_VFs;
	u16 num_VFs;
	u16 offset;
	u16 stride;
	u16 vf_device;
	u32 pgsz;
	u8 link;
	u8 max_VF_buses;
	u16 driver_max_VFs;
	struct pci_dev___7 *dev;
	struct pci_dev___7 *self;
	u32 class;
	u8 hdr_type;
	u16 subsystem_vendor;
	u16 subsystem_device;
	resource_size_t barsz[6];
	bool drivers_autoprobe;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct pci_driver___7;

struct pci_dev___7 {
	struct list_head bus_list;
	struct pci_bus___7 *bus;
	struct pci_bus___7 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___7 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u16 aer_cap;
	struct aer_stats *aer_stats;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	long unsigned int *dma_alias_mask;
	struct pci_driver___7 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	unsigned int imm_ready: 1;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int bridge_d3: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int hotplug_user_indicators: 1;
	unsigned int clear_retrain_link: 1;
	unsigned int d3_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	unsigned int ltr_path: 1;
	unsigned int eetlp_prefix_path: 1;
	pci_channel_state_t error_state;
	struct device___251 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int multifunction: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int ats_enabled: 1;
	unsigned int pasid_enabled: 1;
	unsigned int pri_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int reset_fn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int shpc_managed: 1;
	unsigned int is_thunderbolt: 1;
	unsigned int __aer_firmware_first_valid: 1;
	unsigned int __aer_firmware_first: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int irq_managed: 1;
	unsigned int has_secondary_link: 1;
	unsigned int non_compliant_bars: 1;
	unsigned int is_probed: 1;
	unsigned int link_active_reporting: 1;
	unsigned int untrusted: 1;
	unsigned int no_vf_scan: 1;
	unsigned int io_window: 1;
	unsigned int pref_window: 1;
	unsigned int pref_64_window: 1;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	struct bin_attribute___249 *rom_attr;
	int rom_attr_enabled;
	struct bin_attribute___249 *res_attr[17];
	struct bin_attribute___249 *res_attr_wc[17];
	unsigned int broken_cmd_compl: 1;
	const struct attribute_group___250 **msi_irq_groups;
	struct pci_vpd *vpd;
	union {
		struct pci_sriov___4 *sriov;
		struct pci_dev___7 *physfn;
	};
	u16 ats_cap;
	u8 ats_stu;
	atomic_t ats_ref_cnt;
	u32 pri_reqs_alloc;
	u16 pasid_features;
	struct pci_p2pdma *p2pdma;
	phys_addr_t rom;
	size_t romlen;
	char *driver_override;
	long unsigned int priv_flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t pci_dev_extended_size_rh;
	struct pci_dev_extended_rh pci_dev_extended_rh;
};

struct pci_error_handlers___7;

struct pci_driver___7 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___7 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___7 *);
	int (*suspend)(struct pci_dev___7 *, pm_message_t);
	int (*suspend_late)(struct pci_dev___7 *, pm_message_t);
	int (*resume_early)(struct pci_dev___7 *);
	int (*resume)(struct pci_dev___7 *);
	void (*shutdown)(struct pci_dev___7 *);
	int (*sriov_configure)(struct pci_dev___7 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	const struct pci_error_handlers___7 *err_handler;
	const struct attribute_group___250 **groups;
	struct device_driver___251 driver;
	struct pci_dynids dynids;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct pci_host_bridge___2 {
	struct device___251 dev;
	struct pci_bus___7 *bus;
	struct pci_ops___7 *ops;
	void *sysdata;
	int busnr;
	struct list_head windows;
	u8 (*swizzle_irq)(struct pci_dev___7 *, u8 *);
	int (*map_irq)(const struct pci_dev___7 *, u8, u8);
	void (*release_fn)(struct pci_host_bridge___2 *);
	void *release_data;
	struct msi_controller___2 *msi;
	unsigned int ignore_reset_delay: 1;
	unsigned int no_ext_tags: 1;
	unsigned int native_aer: 1;
	unsigned int native_pcie_hotplug: 1;
	unsigned int native_shpc_hotplug: 1;
	unsigned int native_pme: 1;
	unsigned int native_ltr: 1;
	resource_size_t (*align_resource)(struct pci_dev___7 *, const struct resource *, resource_size_t, resource_size_t, resource_size_t);
	long: 64;
	long unsigned int private[0];
};

struct pci_ops___7 {
	int (*add_bus)(struct pci_bus___7 *);
	void (*remove_bus)(struct pci_bus___7 *);
	void * (*map_bus)(struct pci_bus___7 *, unsigned int, int);
	int (*read)(struct pci_bus___7 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___7 *, unsigned int, int, int, u32);
};

struct msi_desc___9;

struct msi_controller___2 {
	struct module___231 *owner;
	struct device___251 *dev;
	struct device_node___49 *of_node;
	struct list_head list;
	int (*setup_irq)(struct msi_controller___2 *, struct pci_dev___7 *, struct msi_desc___9 *);
	int (*setup_irqs)(struct msi_controller___2 *, struct pci_dev___7 *, int, int);
	void (*teardown_irq)(struct msi_controller___2 *, unsigned int);
};

struct pci_error_handlers___7 {
	pci_ers_result_t (*error_detected)(struct pci_dev___7 *, enum pci_channel_state);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___7 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___7 *);
	void (*reset_prepare)(struct pci_dev___7 *);
	void (*reset_done)(struct pci_dev___7 *);
	void (*resume)(struct pci_dev___7 *);
};

enum {
	PCI_REASSIGN_ALL_RSRC = 1,
	PCI_REASSIGN_ALL_BUS = 2,
	PCI_PROBE_ONLY = 4,
	PCI_CAN_SKIP_ISA_ALIGN = 8,
	PCI_ENABLE_PROC_DOMAINS = 16,
	PCI_COMPAT_DOMAIN_0 = 32,
	PCI_SCAN_ALL_PCIE_DEVS = 64,
};

struct dentry_operations___285;

struct super_block___285;

struct dentry___286 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___286 *d_parent;
	struct qstr d_name;
	struct inode___286 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___285 *d_op;
	struct super_block___285 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___285;

struct block_device___285;

struct cdev___46;

struct inode___286 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___285 *i_op;
	struct super_block___285 *i_sb;
	struct address_space___285 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___287 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___286 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___285 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___285 *i_bdev;
		struct cdev___46 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___285 {
	int (*d_revalidate)(struct dentry___286 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___286 *, unsigned int);
	int (*d_hash)(const struct dentry___286 *, struct qstr *);
	int (*d_compare)(const struct dentry___286 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___286 *);
	int (*d_init)(struct dentry___286 *);
	void (*d_release)(struct dentry___286 *);
	void (*d_prune)(struct dentry___286 *);
	void (*d_iput)(struct dentry___286 *, struct inode___286 *);
	char * (*d_dname)(struct dentry___286 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___286 *);
	int (*d_manage)(const struct path___286 *, bool);
	struct dentry___286 * (*d_real)(struct dentry___286 *, const struct inode___286 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___285;

struct mem_dqinfo___285 {
	struct quota_format_type___285 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___285;

struct quota_info___285 {
	unsigned int flags;
	struct rw_semaphore___287 dqio_sem;
	struct inode___286 *files[3];
	struct mem_dqinfo___285 info[3];
	const struct quota_format_ops___285 *ops[3];
};

struct rcuwait___285 {
	struct task_struct___287 *task;
};

struct percpu_rw_semaphore___285 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___287 rw_sem;
	struct rcuwait___285 writer;
	int readers_block;
};

struct sb_writers___285 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___285 rw_sem[3];
};

struct file_system_type___285;

struct super_operations___285;

struct dquot_operations___285;

struct quotactl_ops___285;

struct super_block___285 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___285 *s_type;
	const struct super_operations___285 *s_op;
	const struct dquot_operations___285 *dq_op;
	const struct quotactl_ops___285 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___286 *s_root;
	struct rw_semaphore___287 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___285 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___285 s_dquot;
	struct sb_writers___285 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___285 *s_d_op;
	int cleancache_poolid;
	struct shrinker___115 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___286 {
	struct file___286 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___286 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___285 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___286 *ia_file;
};

struct dquot___285 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___285 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___285 {
	int qf_fmt_id;
	const struct quota_format_ops___285 *qf_ops;
	struct module___231 *qf_owner;
	struct quota_format_type___285 *qf_next;
};

struct quota_format_ops___285 {
	int (*check_quota_file)(struct super_block___285 *, int);
	int (*read_file_info)(struct super_block___285 *, int);
	int (*write_file_info)(struct super_block___285 *, int);
	int (*free_file_info)(struct super_block___285 *, int);
	int (*read_dqblk)(struct dquot___285 *);
	int (*commit_dqblk)(struct dquot___285 *);
	int (*release_dqblk)(struct dquot___285 *);
	int (*get_next_id)(struct super_block___285 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___285 {
	int (*write_dquot)(struct dquot___285 *);
	struct dquot___285 * (*alloc_dquot)(struct super_block___285 *, int);
	void (*destroy_dquot)(struct dquot___285 *);
	int (*acquire_dquot)(struct dquot___285 *);
	int (*release_dquot)(struct dquot___285 *);
	int (*mark_dirty)(struct dquot___285 *);
	int (*write_info)(struct super_block___285 *, int);
	qsize_t * (*get_reserved_space)(struct inode___286 *);
	int (*get_projid)(struct inode___286 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___286 *, qsize_t *);
	int (*get_next_id)(struct super_block___285 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___285 {
	int (*quota_on)(struct super_block___285 *, int, int, const struct path___286 *);
	int (*quota_off)(struct super_block___285 *, int);
	int (*quota_enable)(struct super_block___285 *, unsigned int);
	int (*quota_disable)(struct super_block___285 *, unsigned int);
	int (*quota_sync)(struct super_block___285 *, int);
	int (*set_info)(struct super_block___285 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___285 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___285 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___285 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___285 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___285 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___285 {
	int (*writepage)(struct page___287 *, struct writeback_control___3 *);
	int (*readpage)(struct file___286 *, struct page___287 *);
	int (*writepages)(struct address_space___285 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___287 *);
	int (*readpages)(struct file___286 *, struct address_space___285 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___286 *, struct address_space___285 *, loff_t, unsigned int, unsigned int, struct page___287 **, void **);
	int (*write_end)(struct file___286 *, struct address_space___285 *, loff_t, unsigned int, unsigned int, struct page___287 *, void *);
	sector_t (*bmap)(struct address_space___285 *, sector_t);
	void (*invalidatepage)(struct page___287 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___287 *, gfp_t);
	void (*freepage)(struct page___287 *);
	ssize_t (*direct_IO)(struct kiocb___286 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___285 *, struct page___287 *, struct page___287 *, enum migrate_mode);
	bool (*isolate_page)(struct page___287 *, isolate_mode_t);
	void (*putback_page)(struct page___287 *);
	int (*launder_page)(struct page___287 *);
	int (*is_partially_uptodate)(struct page___287 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___287 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___285 *, struct page___287 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___286 *, sector_t *);
	void (*swap_deactivate)(struct file___286 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___285 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___286 *bd_inode;
	struct super_block___285 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___285 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___46 {
	struct kobject___273 kobj;
	struct module___231 *owner;
	const struct file_operations___286 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___285 {
	struct dentry___286 * (*lookup)(struct inode___286 *, struct dentry___286 *, unsigned int);
	const char * (*get_link)(struct dentry___286 *, struct inode___286 *, struct delayed_call *);
	int (*permission)(struct inode___286 *, int);
	struct posix_acl * (*get_acl)(struct inode___286 *, int);
	int (*readlink)(struct dentry___286 *, char *, int);
	int (*create)(struct inode___286 *, struct dentry___286 *, umode_t, bool);
	int (*link)(struct dentry___286 *, struct inode___286 *, struct dentry___286 *);
	int (*unlink)(struct inode___286 *, struct dentry___286 *);
	int (*symlink)(struct inode___286 *, struct dentry___286 *, const char *);
	int (*mkdir)(struct inode___286 *, struct dentry___286 *, umode_t);
	int (*rmdir)(struct inode___286 *, struct dentry___286 *);
	int (*mknod)(struct inode___286 *, struct dentry___286 *, umode_t, dev_t);
	int (*rename)(struct inode___286 *, struct dentry___286 *, struct inode___286 *, struct dentry___286 *, unsigned int);
	int (*setattr)(struct dentry___286 *, struct iattr___285 *);
	int (*getattr)(const struct path___286 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___286 *, char *, size_t);
	int (*fiemap)(struct inode___286 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___286 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___286 *, struct dentry___286 *, struct file___286 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___286 *, struct dentry___286 *, umode_t);
	int (*set_acl)(struct inode___286 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___285 {
	void (*fl_copy_lock)(struct file_lock___286 *, struct file_lock___286 *);
	void (*fl_release_private)(struct file_lock___286 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___285;

struct lock_manager_operations___285;

struct file_lock___286 {
	struct file_lock___286 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___286 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___285 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___285 *fl_ops;
	const struct lock_manager_operations___285 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___285 {
	int (*lm_compare_owner)(struct file_lock___286 *, struct file_lock___286 *);
	long unsigned int (*lm_owner_key)(struct file_lock___286 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___286 *);
	int (*lm_grant)(struct file_lock___286 *, int);
	bool (*lm_break)(struct file_lock___286 *);
	int (*lm_change)(struct file_lock___286 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___286 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___285 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___285 *fa_next;
	struct file___286 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___285 {
	const char *name;
	int fs_flags;
	struct dentry___286 * (*mount)(struct file_system_type___285 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___285 *);
	struct module___231 *owner;
	struct file_system_type___285 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___285 {
	struct inode___286 * (*alloc_inode)(struct super_block___285 *);
	void (*destroy_inode)(struct inode___286 *);
	void (*dirty_inode)(struct inode___286 *, int);
	int (*write_inode)(struct inode___286 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___286 *);
	void (*evict_inode)(struct inode___286 *);
	void (*put_super)(struct super_block___285 *);
	int (*sync_fs)(struct super_block___285 *, int);
	int (*freeze_super)(struct super_block___285 *);
	int (*freeze_fs)(struct super_block___285 *);
	int (*thaw_super)(struct super_block___285 *);
	int (*unfreeze_fs)(struct super_block___285 *);
	int (*statfs)(struct dentry___286 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___285 *, int *, char *);
	void (*umount_begin)(struct super_block___285 *);
	int (*show_options)(struct seq_file___246 *, struct dentry___286 *);
	int (*show_devname)(struct seq_file___246 *, struct dentry___286 *);
	int (*show_path)(struct seq_file___246 *, struct dentry___286 *);
	int (*show_stats)(struct seq_file___246 *, struct dentry___286 *);
	ssize_t (*quota_read)(struct super_block___285 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___285 *, int, const char *, size_t, loff_t);
	struct dquot___285 ** (*get_dquots)(struct inode___286 *);
	int (*bdev_try_to_free_page)(struct super_block___285 *, struct page___287 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___285 *, struct shrink_control___115 *);
	long int (*free_cached_objects)(struct super_block___285 *, struct shrink_control___115 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___275(struct page___287 *);

struct node___177 {
	struct device___251 dev;
};

struct property___46 {
	char *name;
	int length;
	void *value;
	struct property___46 *next;
	long unsigned int _flags;
	struct bin_attribute___249 attr;
};

struct msi_desc___9 {
	struct list_head list;
	unsigned int irq;
	unsigned int nvec_used;
	struct device___251 *dev;
	struct msi_msg msg;
	struct irq_affinity_desc *affinity;
	const void *iommu_cookie;
	union {
		struct {
			u32 masked;
			struct {
				u8 is_msix: 1;
				u8 multiple: 3;
				u8 multi_cap: 3;
				u8 maskbit: 1;
				u8 is_64: 1;
				u16 entry_nr;
				unsigned int default_irq;
			} msi_attrib;
			union {
				u8 mask_pos;
				void *mask_base;
			};
		};
		struct platform_msi_desc platform;
		struct fsl_mc_msi_desc fsl_mc;
	};
};

struct hotplug_slot_ops {
	int (*enable_slot)(struct hotplug_slot *);
	int (*disable_slot)(struct hotplug_slot *);
	int (*set_attention_status)(struct hotplug_slot *, u8);
	int (*hardware_test)(struct hotplug_slot *, u32);
	int (*get_power_status)(struct hotplug_slot *, u8 *);
	int (*get_attention_status)(struct hotplug_slot *, u8 *);
	int (*get_latch_status)(struct hotplug_slot *, u8 *);
	int (*get_adapter_status)(struct hotplug_slot *, u8 *);
	int (*reset_slot)(struct hotplug_slot *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct hpp_type0 {
	u32 revision;
	u8 cache_line_size;
	u8 latency_timer;
	u8 enable_serr;
	u8 enable_perr;
};

struct hpp_type1 {
	u32 revision;
	u8 max_mem_read;
	u8 avg_max_split;
	u16 tot_max_split;
};

struct hpp_type2 {
	u32 revision;
	u32 unc_err_mask_and;
	u32 unc_err_mask_or;
	u32 unc_err_sever_and;
	u32 unc_err_sever_or;
	u32 cor_err_mask_and;
	u32 cor_err_mask_or;
	u32 adv_err_cap_and;
	u32 adv_err_cap_or;
	u16 pci_exp_devctl_and;
	u16 pci_exp_devctl_or;
	u16 pci_exp_lnkctl_and;
	u16 pci_exp_lnkctl_or;
	u32 sec_unc_err_sever_and;
	u32 sec_unc_err_sever_or;
	u32 sec_unc_err_mask_and;
	u32 sec_unc_err_mask_or;
};

struct hotplug_params {
	struct hpp_type0 *t0;
	struct hpp_type1 *t1;
	struct hpp_type2 *t2;
	struct hpp_type0 type0_data;
	struct hpp_type1 type1_data;
	struct hpp_type2 type2_data;
};

struct kernel_param_ops___228 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___228 *);
	int (*get)(char *, const struct kernel_param___228 *);
	void (*free)(void *);
};

struct kparam_array___228;

struct kernel_param___228 {
	const char *name;
	struct module___231 *mod;
	const struct kernel_param_ops___228 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___228 *arr;
	};
};

struct kparam_array___228 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___228 *ops;
	void *elem;
};

struct module_attribute___228 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___228 *, struct module_kobject___228 *, char *);
	ssize_t (*store)(struct module_attribute___228 *, struct module_kobject___228 *, const char *, size_t);
	void (*setup)(struct module___231 *, const char *);
	int (*test)(struct module___231 *);
	void (*free)(struct module___231 *);
};

typedef int (*key_restrict_link_func_t___268)(struct key___267 *, const struct key_type *, const union key_payload *, struct key___267 *);

struct key_restriction___267;

struct key___267 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___287 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___267 *restrict_link;
};

struct key_restriction___267 {
	key_restrict_link_func_t___268 check;
	struct key___267 *key;
	struct key_type *keytype;
};

struct seq_operations___245 {
	void * (*start)(struct seq_file___246 *, loff_t *);
	void (*stop)(struct seq_file___246 *, void *);
	void * (*next)(struct seq_file___246 *, void *, loff_t *);
	int (*show)(struct seq_file___246 *, void *);
};

struct irq_fwspec___10 {
	struct fwnode_handle___185 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___10 {
	int (*match)(struct irq_domain___10 *, struct device_node___49 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___10 *, struct irq_fwspec___10 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___10 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___10 *, unsigned int);
	int (*xlate)(struct irq_domain___10 *, struct device_node___49 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___10 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___10 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___10 *, struct irq_data___5 *, bool);
	void (*deactivate)(struct irq_domain___10 *, struct irq_data___5 *);
	int (*translate)(struct irq_domain___10 *, struct irq_fwspec___10 *, long unsigned int *, unsigned int *);
};

enum pci_bar_type {
	pci_bar_unknown = 0,
	pci_bar_io = 1,
	pci_bar_mem32 = 2,
	pci_bar_mem64 = 3,
};

struct pci_domain_busn_res {
	struct list_head list;
	struct resource res;
	int domain_nr;
};

struct bus_attribute {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___243 *, char *);
	ssize_t (*store)(struct bus_type___243 *, const char *, size_t);
};

typedef void (*dr_release_t___11)(struct device___243 *, void *);

struct dmi_strmatch {
	unsigned char slot: 7;
	unsigned char exact_match: 1;
	char substr[79];
};

struct dmi_system_id {
	int (*callback)(const struct dmi_system_id *);
	const char *ident;
	struct dmi_strmatch matches[4];
	void *driver_data;
};

struct pci_dev___8;

struct pci_ops___8;

struct msi_controller___4;

struct pci_bus___8 {
	struct list_head node;
	struct pci_bus___8 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___8 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___8 *ops;
	struct msi_controller___4 *msi;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	int domain_nr;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___243 *bridge;
	struct device___243 dev;
	struct bin_attribute___244 *legacy_io;
	struct bin_attribute___244 *legacy_mem;
	unsigned int is_added: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
};

struct hotplug_slot___2;

struct pci_slot___8 {
	struct pci_bus___8 *bus;
	struct list_head list;
	struct hotplug_slot___2 *hotplug;
	unsigned char number;
	struct kobject___268 kobj;
};

struct hotplug_slot_ops___2;

struct hotplug_slot___2 {
	const struct hotplug_slot_ops___2 *ops;
	struct list_head slot_list;
	struct pci_slot___8 *pci_slot;
	struct module___227 *owner;
	const char *mod_name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

enum pcie_reset_state {
	pcie_deassert_reset = 1,
	pcie_warm_reset = 2,
	pcie_hot_reset = 3,
};

enum pcie_link_width {
	PCIE_LNK_WIDTH_RESRV = 0,
	PCIE_LNK_X1 = 1,
	PCIE_LNK_X2 = 2,
	PCIE_LNK_X4 = 4,
	PCIE_LNK_X8 = 8,
	PCIE_LNK_X12 = 12,
	PCIE_LNK_X16 = 16,
	PCIE_LNK_X32 = 32,
	PCIE_LNK_WIDTH_UNKNOWN = 255,
};

struct pci_cap_saved_data {
	u16 cap_nr;
	bool cap_extended;
	unsigned int size;
	u32 data[0];
};

struct pci_cap_saved_state {
	struct hlist_node next;
	struct pci_cap_saved_data cap;
};

struct pci_sriov {
	int pos;
	int nres;
	u32 cap;
	u16 ctrl;
	u16 total_VFs;
	u16 initial_VFs;
	u16 num_VFs;
	u16 offset;
	u16 stride;
	u16 vf_device;
	u32 pgsz;
	u8 link;
	u8 max_VF_buses;
	u16 driver_max_VFs;
	struct pci_dev___8 *dev;
	struct pci_dev___8 *self;
	u32 class;
	u8 hdr_type;
	u16 subsystem_vendor;
	u16 subsystem_device;
	resource_size_t barsz[6];
	bool drivers_autoprobe;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct pci_driver___8;

struct pci_dev___8 {
	struct list_head bus_list;
	struct pci_bus___8 *bus;
	struct pci_bus___8 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___8 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u16 aer_cap;
	struct aer_stats *aer_stats;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	long unsigned int *dma_alias_mask;
	struct pci_driver___8 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	unsigned int imm_ready: 1;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int bridge_d3: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int hotplug_user_indicators: 1;
	unsigned int clear_retrain_link: 1;
	unsigned int d3_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	unsigned int ltr_path: 1;
	unsigned int eetlp_prefix_path: 1;
	pci_channel_state_t error_state;
	struct device___243 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int multifunction: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int ats_enabled: 1;
	unsigned int pasid_enabled: 1;
	unsigned int pri_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int reset_fn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int shpc_managed: 1;
	unsigned int is_thunderbolt: 1;
	unsigned int __aer_firmware_first_valid: 1;
	unsigned int __aer_firmware_first: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int irq_managed: 1;
	unsigned int has_secondary_link: 1;
	unsigned int non_compliant_bars: 1;
	unsigned int is_probed: 1;
	unsigned int link_active_reporting: 1;
	unsigned int untrusted: 1;
	unsigned int no_vf_scan: 1;
	unsigned int io_window: 1;
	unsigned int pref_window: 1;
	unsigned int pref_64_window: 1;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	struct bin_attribute___244 *rom_attr;
	int rom_attr_enabled;
	struct bin_attribute___244 *res_attr[17];
	struct bin_attribute___244 *res_attr_wc[17];
	unsigned int broken_cmd_compl: 1;
	const struct attribute_group___245 **msi_irq_groups;
	struct pci_vpd *vpd;
	union {
		struct pci_sriov *sriov;
		struct pci_dev___8 *physfn;
	};
	u16 ats_cap;
	u8 ats_stu;
	atomic_t ats_ref_cnt;
	u32 pri_reqs_alloc;
	u16 pasid_features;
	struct pci_p2pdma *p2pdma;
	phys_addr_t rom;
	size_t romlen;
	char *driver_override;
	long unsigned int priv_flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t pci_dev_extended_size_rh;
	struct pci_dev_extended_rh pci_dev_extended_rh;
};

struct pci_error_handlers___8;

struct pci_driver___8 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___8 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___8 *);
	int (*suspend)(struct pci_dev___8 *, pm_message_t);
	int (*suspend_late)(struct pci_dev___8 *, pm_message_t);
	int (*resume_early)(struct pci_dev___8 *);
	int (*resume)(struct pci_dev___8 *);
	void (*shutdown)(struct pci_dev___8 *);
	int (*sriov_configure)(struct pci_dev___8 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	const struct pci_error_handlers___8 *err_handler;
	const struct attribute_group___245 **groups;
	struct device_driver___243 driver;
	struct pci_dynids dynids;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct pci_ops___8 {
	int (*add_bus)(struct pci_bus___8 *);
	void (*remove_bus)(struct pci_bus___8 *);
	void * (*map_bus)(struct pci_bus___8 *, unsigned int, int);
	int (*read)(struct pci_bus___8 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___8 *, unsigned int, int, int, u32);
};

struct msi_controller___4 {
	struct module___227 *owner;
	struct device___243 *dev;
	struct device_node___44 *of_node;
	struct list_head list;
	int (*setup_irq)(struct msi_controller___4 *, struct pci_dev___8 *, struct msi_desc___6 *);
	int (*setup_irqs)(struct msi_controller___4 *, struct pci_dev___8 *, int, int);
	void (*teardown_irq)(struct msi_controller___4 *, unsigned int);
};

struct pci_error_handlers___8 {
	pci_ers_result_t (*error_detected)(struct pci_dev___8 *, enum pci_channel_state);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___8 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___8 *);
	void (*reset_prepare)(struct pci_dev___8 *);
	void (*reset_done)(struct pci_dev___8 *);
	void (*resume)(struct pci_dev___8 *);
};

typedef int (*arch_set_vga_state_t)(struct pci_dev___8 *, bool, unsigned int, u32);

struct hotplug_slot_ops___2 {
	int (*enable_slot)(struct hotplug_slot___2 *);
	int (*disable_slot)(struct hotplug_slot___2 *);
	int (*set_attention_status)(struct hotplug_slot___2 *, u8);
	int (*hardware_test)(struct hotplug_slot___2 *, u32);
	int (*get_power_status)(struct hotplug_slot___2 *, u8 *);
	int (*get_attention_status)(struct hotplug_slot___2 *, u8 *);
	int (*get_latch_status)(struct hotplug_slot___2 *, u8 *);
	int (*get_adapter_status)(struct hotplug_slot___2 *, u8 *);
	int (*reset_slot)(struct hotplug_slot___2 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct pci_platform_pm_ops {
	bool (*bridge_d3)(struct pci_dev___8 *);
	bool (*is_manageable)(struct pci_dev___8 *);
	int (*set_state)(struct pci_dev___8 *, pci_power_t);
	pci_power_t (*get_state)(struct pci_dev___8 *);
	pci_power_t (*choose_state)(struct pci_dev___8 *);
	int (*set_wakeup)(struct pci_dev___8 *, bool);
	bool (*need_resume)(struct pci_dev___8 *);
};

struct pci_pme_device {
	struct list_head list;
	struct pci_dev___8 *dev;
};

struct pci_saved_state {
	u32 config_space[16];
	struct pci_cap_saved_data cap[0];
};

struct pci_devres {
	unsigned int enabled: 1;
	unsigned int pinned: 1;
	unsigned int orig_intx: 1;
	unsigned int restore_intx: 1;
	unsigned int mwi: 1;
	u32 region_mask;
};

struct module___232;

struct file___287;

struct kiocb___287;

struct iov_iter___137;

struct poll_table_struct___174;

struct vm_area_struct___288;

struct inode___287;

struct file_lock___287;

struct page___288;

struct seq_file___247;

struct file_operations___287 {
	struct module___232 *owner;
	loff_t (*llseek)(struct file___287 *, loff_t, int);
	ssize_t (*read)(struct file___287 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___287 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___287 *, struct iov_iter___137 *);
	ssize_t (*write_iter)(struct kiocb___287 *, struct iov_iter___137 *);
	int (*iopoll)(struct kiocb___287 *, bool);
	int (*iterate)(struct file___287 *, struct dir_context *);
	int (*iterate_shared)(struct file___287 *, struct dir_context *);
	__poll_t (*poll)(struct file___287 *, struct poll_table_struct___174 *);
	long int (*unlocked_ioctl)(struct file___287 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___287 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___287 *, struct vm_area_struct___288 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___287 *, struct file___287 *);
	int (*flush)(struct file___287 *, fl_owner_t);
	int (*release)(struct inode___287 *, struct file___287 *);
	int (*fsync)(struct file___287 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___287 *, int);
	int (*lock)(struct file___287 *, int, struct file_lock___287 *);
	ssize_t (*sendpage)(struct file___287 *, struct page___288 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___287 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___287 *, int, struct file_lock___287 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___287 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___287 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___287 *, long int, struct file_lock___287 **, void **);
	long int (*fallocate)(struct file___287 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___247 *, struct file___287 *);
	ssize_t (*copy_file_range)(struct file___287 *, loff_t, struct file___287 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___287 *, loff_t, struct file___287 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___287 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___287 {
	u64 seqnum;
	struct vm_area_struct___288 *vmas[4];
};

struct page_frag___287 {
	struct page___288 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___287;

struct mem_cgroup___116;

struct pid___195;

struct cred___268;

struct nsproxy___242;

struct signal_struct___220;

struct bio_list___148;

struct backing_dev_info___148;

struct css_set___206;

struct vm_struct___203;

struct task_struct___288 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___288 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___287 *mm;
	struct mm_struct___287 *active_mm;
	struct vmacache___287 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___288 *real_parent;
	struct task_struct___288 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___288 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___116 *active_memcg;
	long int rh_reserved2;
	struct pid___195 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___195 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___195 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___268 *ptracer_cred;
	const struct cred___268 *real_cred;
	const struct cred___268 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___242 *nsproxy;
	struct signal_struct___220 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___288 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___148 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___148 *backing_dev_info;
	struct io_context___82 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___206 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___287 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___116 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___288 *oom_reaper_list;
	struct vm_struct___203 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___130 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___288 *pgtable_t___287;

struct address_space___286;

struct dev_pagemap___276;

struct page___288 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___286 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___288 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___287 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___287 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___276 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___116 *mem_cgroup;
};

struct pglist_data___287;

struct lruvec___287 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___287 *pgdat;
};

struct zone___287 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___287 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___287 {
	struct zone___287 *zone;
	int zone_idx;
};

struct zonelist___287 {
	struct zoneref___287 _zonerefs[25];
};

struct pglist_data___287 {
	struct zone___287 node_zones[3];
	struct zonelist___287 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___288 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___288 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___287 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___288 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___288 *owner;
};

struct secondary_data___288 {
	void *stack;
	struct task_struct___288 *task;
	long int status;
};

struct blocking_notifier_head___287 {
	struct rw_semaphore___288 rwsem;
	struct notifier_block *head;
};

struct key___268;

struct ucounts___221;

struct user_namespace___221 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___221 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___9 ns;
	long unsigned int flags;
	struct key___268 *persistent_keyring_register;
	struct rw_semaphore___288 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___221 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_root___280;

struct kernfs_elem_dir___280 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___280 *root;
};

struct kernfs_node___281;

struct kernfs_syscall_ops___280;

struct kernfs_root___280 {
	struct kernfs_node___281 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___280 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___280 {
	struct kernfs_node___281 *target_kn;
};

struct kernfs_ops___280;

struct kernfs_elem_attr___280 {
	const struct kernfs_ops___280 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___281 *notify_next;
};

struct kernfs_node___281 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___281 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___280 dir;
		struct kernfs_elem_symlink___280 symlink;
		struct kernfs_elem_attr___280 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___280;

struct kernfs_ops___280 {
	int (*open)(struct kernfs_open_file___280 *);
	void (*release)(struct kernfs_open_file___280 *);
	int (*seq_show)(struct seq_file___247 *, void *);
	void * (*seq_start)(struct seq_file___247 *, loff_t *);
	void * (*seq_next)(struct seq_file___247 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___247 *, void *);
	ssize_t (*read)(struct kernfs_open_file___280 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___280 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___280 *, struct vm_area_struct___288 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___280 *, struct poll_table_struct___174 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___280 {
	int (*remount_fs)(struct kernfs_root___280 *, int *, char *);
	int (*show_options)(struct seq_file___247 *, struct kernfs_root___280 *);
	int (*mkdir)(struct kernfs_node___281 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___281 *);
	int (*rename)(struct kernfs_node___281 *, struct kernfs_node___281 *, const char *);
	int (*show_path)(struct seq_file___247 *, struct kernfs_node___281 *, struct kernfs_root___280 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___246;

struct seq_file___247 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___246 *op;
	int poll_event;
	const struct file___287 *file;
	void *private;
};

struct vm_operations_struct___276;

struct kernfs_open_file___280 {
	struct kernfs_node___281 *kn;
	struct file___287 *file;
	struct seq_file___247 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___276 *vm_ops;
};

struct dentry___287;

struct path___287 {
	struct vfsmount *mnt;
	struct dentry___287 *dentry;
};

struct fown_struct___195 {
	rwlock_t lock;
	struct pid___195 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___287 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___287 f_path;
	struct inode___287 *f_inode;
	const struct file_operations___287 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___195 f_owner;
	const struct cred___268 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___286 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___276;

struct vm_operations_struct___276 {
	void (*open)(struct vm_area_struct___288 *);
	void (*close)(struct vm_area_struct___288 *);
	int (*split)(struct vm_area_struct___288 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___288 *);
	vm_fault_t (*fault)(struct vm_fault___276 *);
	vm_fault_t (*huge_fault)(struct vm_fault___276 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___276 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___288 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___276 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___276 *);
	int (*access)(struct vm_area_struct___288 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___288 *);
	int (*set_policy)(struct vm_area_struct___288 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___288 *, long unsigned int);
	struct page___288 * (*find_special_page)(struct vm_area_struct___288 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___177)(struct file___287 *, wait_queue_head_t *, struct poll_table_struct___174 *);

struct poll_table_struct___174 {
	poll_queue_proc___177 _qproc;
	__poll_t _key;
};

struct vm_area_struct___288 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___288 *vm_next;
	struct vm_area_struct___288 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___287 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___276 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___287 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___274;

struct bin_attribute___250;

struct attribute_group___251 {
	const char *name;
	umode_t (*is_visible)(struct kobject___274 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___274 *, struct bin_attribute___250 *, int);
	struct attribute **attrs;
	struct bin_attribute___250 **bin_attrs;
};

struct kset___273;

struct kobj_type___273;

struct kobject___274 {
	const char *name;
	struct list_head entry;
	struct kobject___274 *parent;
	struct kset___273 *kset;
	struct kobj_type___273 *ktype;
	struct kernfs_node___281 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___250 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___287 *, struct kobject___274 *, struct bin_attribute___250 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___287 *, struct kobject___274 *, struct bin_attribute___250 *, char *, loff_t, size_t);
	int (*mmap)(struct file___287 *, struct kobject___274 *, struct bin_attribute___250 *, struct vm_area_struct___288 *);
};

struct sysfs_ops___273 {
	ssize_t (*show)(struct kobject___274 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___274 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___273;

struct kset___273 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___274 kobj;
	const struct kset_uevent_ops___273 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___273 {
	void (*release)(struct kobject___274 *);
	const struct sysfs_ops___273 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___25 * (*child_ns_type)(struct kobject___274 *);
	const void * (*namespace)(struct kobject___274 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___273 {
	int (* const filter)(struct kset___273 *, struct kobject___274 *);
	const char * (* const name)(struct kset___273 *, struct kobject___274 *);
	int (* const uevent)(struct kset___273 *, struct kobject___274 *, struct kobj_uevent_env *);
};

struct kobj_attribute___266 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___274 *, struct kobj_attribute___266 *, char *);
	ssize_t (*store)(struct kobject___274 *, struct kobj_attribute___266 *, const char *, size_t);
};

struct device___252;

struct dev_pm_ops___252 {
	int (*prepare)(struct device___252 *);
	void (*complete)(struct device___252 *);
	int (*suspend)(struct device___252 *);
	int (*resume)(struct device___252 *);
	int (*freeze)(struct device___252 *);
	int (*thaw)(struct device___252 *);
	int (*poweroff)(struct device___252 *);
	int (*restore)(struct device___252 *);
	int (*suspend_late)(struct device___252 *);
	int (*resume_early)(struct device___252 *);
	int (*freeze_late)(struct device___252 *);
	int (*thaw_early)(struct device___252 *);
	int (*poweroff_late)(struct device___252 *);
	int (*restore_early)(struct device___252 *);
	int (*suspend_noirq)(struct device___252 *);
	int (*resume_noirq)(struct device___252 *);
	int (*freeze_noirq)(struct device___252 *);
	int (*thaw_noirq)(struct device___252 *);
	int (*poweroff_noirq)(struct device___252 *);
	int (*restore_noirq)(struct device___252 *);
	int (*runtime_suspend)(struct device___252 *);
	int (*runtime_resume)(struct device___252 *);
	int (*runtime_idle)(struct device___252 *);
};

struct dev_pm_info___252 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___252 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___252;

struct bus_type___252;

struct device_driver___252;

struct dev_pm_domain___252;

struct dma_map_ops___74;

struct device_node___50;

struct fwnode_handle___186;

struct class___252;

struct device___252 {
	struct device___252 *parent;
	struct device_private *p;
	struct kobject___274 kobj;
	const char *init_name;
	const struct device_type___252 *type;
	struct mutex mutex;
	struct bus_type___252 *bus;
	struct device_driver___252 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___252 power;
	struct dev_pm_domain___252 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___74 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___50 *of_node;
	struct fwnode_handle___186 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___252 *class;
	const struct attribute_group___251 **groups;
	void (*release)(struct device___252 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___252 {
	struct dev_pm_ops___252 ops;
	void (*detach)(struct device___252 *, bool);
	int (*activate)(struct device___252 *);
	void (*sync)(struct device___252 *);
	void (*dismiss)(struct device___252 *);
};

struct pid_namespace___195;

struct upid___195 {
	int nr;
	struct pid_namespace___195 *ns;
};

struct pid_namespace___195 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___288 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___195 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___287 *proc_self;
	struct dentry___287 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___221 *user_ns;
	struct ucounts___221 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___9 ns;
};

struct pid___195 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___195 numbers[1];
};

struct user_struct___268 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___268 *uid_keyring;
	struct key___268 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___287;

struct mm_struct___287 {
	struct {
		struct vm_area_struct___288 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___287 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___288 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___287 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___288 *owner;
		struct user_namespace___221 *user_ns;
		struct file___287 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___287 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup___206;

struct cgroup_subsys___206;

struct cgroup_subsys_state___206 {
	struct cgroup___206 *cgroup;
	struct cgroup_subsys___206 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___206 *parent;
};

struct cgroup_file___206 {
	struct kernfs_node___281 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___116;

struct mem_cgroup___116 {
	struct cgroup_subsys_state___206 css;
	struct mem_cgroup_id___5 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___206 events_file;
	struct cgroup_file___206 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___288 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___116 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cred___268 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___268 *session_keyring;
	struct key___268 *process_keyring;
	struct key___268 *thread_keyring;
	struct key___268 *request_key_auth;
	void *security;
	struct user_struct___268 *user;
	struct user_namespace___221 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___206;

struct nsproxy___242 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___195 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___206 *cgroup_ns;
};

struct signal_struct___220 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___288 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___288 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___195 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___195 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___287 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___195 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___148;

struct bio_list___148 {
	struct bio___148 *head;
	struct bio___148 *tail;
};

struct bdi_writeback_congested___148;

struct bdi_writeback___148 {
	struct backing_dev_info___148 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___148 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___206 *memcg_css;
	struct cgroup_subsys_state___206 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___148 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___148 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___252 *dev;
	struct device___252 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___287 *debug_dir;
	struct dentry___287 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___206 {
	struct cgroup_subsys_state___206 *subsys[13];
	refcount_t refcount;
	struct css_set___206 *dom_cset;
	struct cgroup___206 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___206 *mg_src_cgrp;
	struct cgroup___206 *mg_dst_cgrp;
	struct css_set___206 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct vm_struct___203 {
	struct vm_struct___203 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___288 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___232 {
	struct task_struct___288 task;
	long unsigned int stack[8192];
};

struct bus_type___252 {
	const char *name;
	const char *dev_name;
	struct device___252 *dev_root;
	const struct attribute_group___251 **bus_groups;
	const struct attribute_group___251 **dev_groups;
	const struct attribute_group___251 **drv_groups;
	int (*match)(struct device___252 *, struct device_driver___252 *);
	int (*uevent)(struct device___252 *, struct kobj_uevent_env *);
	int (*probe)(struct device___252 *);
	int (*remove)(struct device___252 *);
	void (*shutdown)(struct device___252 *);
	int (*online)(struct device___252 *);
	int (*offline)(struct device___252 *);
	int (*suspend)(struct device___252 *, pm_message_t);
	int (*resume)(struct device___252 *);
	int (*num_vf)(struct device___252 *);
	int (*dma_configure)(struct device___252 *);
	const struct dev_pm_ops___252 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___252 {
	const char *name;
	struct bus_type___252 *bus;
	struct module___232 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___252 *);
	int (*remove)(struct device___252 *);
	void (*shutdown)(struct device___252 *);
	int (*suspend)(struct device___252 *, pm_message_t);
	int (*resume)(struct device___252 *);
	const struct attribute_group___251 **groups;
	const struct dev_pm_ops___252 *pm;
	void (*coredump)(struct device___252 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___252 {
	const char *name;
	const struct attribute_group___251 **groups;
	int (*uevent)(struct device___252 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___252 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___252 *);
	const struct dev_pm_ops___252 *pm;
};

struct module_kobject___229 {
	struct kobject___274 kobj;
	struct module___232 *mod;
	struct kobject___274 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___229 {
	struct module___232 *mod;
	struct latch_tree_node node;
};

struct module_layout___229 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___229 mtn;
};

struct module_attribute___229;

struct kernel_param___229;

struct module___232 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___229 mkobj;
	struct module_attribute___229 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___274 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___229 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___229 core_layout;
	struct module_layout___229 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct driver_attribute {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___252 *, char *);
	ssize_t (*store)(struct device_driver___252 *, const char *, size_t);
};

struct class___252 {
	const char *name;
	struct module___232 *owner;
	const struct attribute_group___251 **class_groups;
	const struct attribute_group___251 **dev_groups;
	struct kobject___274 *dev_kobj;
	int (*dev_uevent)(struct device___252 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___252 *, umode_t *);
	void (*class_release)(struct class___252 *);
	void (*dev_release)(struct device___252 *);
	int (*shutdown_pre)(struct device___252 *);
	const struct kobj_ns_type_operations___25 *ns_type;
	const void * (*namespace)(struct device___252 *);
	const struct dev_pm_ops___252 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___74 {
	void * (*alloc)(struct device___252 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___252 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___252 *, struct vm_area_struct___288 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___252 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___252 *, struct page___288 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___252 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___252 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___252 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___252 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___252 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___252 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___252 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___252 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___252 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___252 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___252 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___252 *, u64);
	u64 (*get_required_mask)(struct device___252 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___186;

struct fwnode_handle___186 {
	struct fwnode_handle___186 *secondary;
	const struct fwnode_operations___186 *ops;
};

struct property___47;

struct device_node___50 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___186 fwnode;
	struct property___47 *properties;
	struct property___47 *deadprops;
	struct device_node___50 *parent;
	struct device_node___50 *child;
	struct device_node___50 *sibling;
	struct kobject___274 kobj;
	long unsigned int _flags;
	void *data;
};

struct address_space_operations___286;

struct address_space___286 {
	struct inode___287 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___288 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___286 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___276)(struct vm_area_struct___288 *, long unsigned int, const struct page___288 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___276)(struct page___288 *, void *);

struct dev_pagemap___276 {
	dev_page_fault_t___276 page_fault;
	dev_page_free_t___276 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___252 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___287 {
	struct task_struct___288 *task;
	struct core_thread___287 *next;
};

struct core_state___287 {
	atomic_t nr_threads;
	struct core_thread___287 dumper;
	struct completion startup;
};

struct vm_fault___276 {
	struct vm_area_struct___288 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___288 *cow_page;
	struct mem_cgroup___116 *memcg;
	struct page___288 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___287 prealloc_pte;
};

struct fwnode_reference_args___186;

struct fwnode_endpoint___186;

struct fwnode_operations___186 {
	struct fwnode_handle___186 * (*get)(struct fwnode_handle___186 *);
	void (*put)(struct fwnode_handle___186 *);
	bool (*device_is_available)(const struct fwnode_handle___186 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___186 *, const struct device___252 *);
	bool (*property_present)(const struct fwnode_handle___186 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___186 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___186 *, const char *, const char **, size_t);
	struct fwnode_handle___186 * (*get_parent)(const struct fwnode_handle___186 *);
	struct fwnode_handle___186 * (*get_next_child_node)(const struct fwnode_handle___186 *, struct fwnode_handle___186 *);
	struct fwnode_handle___186 * (*get_named_child_node)(const struct fwnode_handle___186 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___186 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___186 *);
	struct fwnode_handle___186 * (*graph_get_next_endpoint)(const struct fwnode_handle___186 *, struct fwnode_handle___186 *);
	struct fwnode_handle___186 * (*graph_get_remote_endpoint)(const struct fwnode_handle___186 *);
	struct fwnode_handle___186 * (*graph_get_port_parent)(struct fwnode_handle___186 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___186 *, struct fwnode_endpoint___186 *);
};

struct fwnode_endpoint___186 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___186 *local_fwnode;
};

struct fwnode_reference_args___186 {
	struct fwnode_handle___186 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pci_bus___9;

struct pci_slot___9 {
	struct pci_bus___9 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject___274 kobj;
};

struct pci_dev___9;

struct pci_ops___9;

struct pci_bus___9 {
	struct list_head node;
	struct pci_bus___9 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___9 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___9 *ops;
	struct msi_controller___2 *msi;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	int domain_nr;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___252 *bridge;
	struct device___252 dev;
	struct bin_attribute___250 *legacy_io;
	struct bin_attribute___250 *legacy_mem;
	unsigned int is_added: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
};

struct pci_sriov___5 {
	int pos;
	int nres;
	u32 cap;
	u16 ctrl;
	u16 total_VFs;
	u16 initial_VFs;
	u16 num_VFs;
	u16 offset;
	u16 stride;
	u16 vf_device;
	u32 pgsz;
	u8 link;
	u8 max_VF_buses;
	u16 driver_max_VFs;
	struct pci_dev___9 *dev;
	struct pci_dev___9 *self;
	u32 class;
	u8 hdr_type;
	u16 subsystem_vendor;
	u16 subsystem_device;
	resource_size_t barsz[6];
	bool drivers_autoprobe;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct pci_driver___9;

struct pci_dev___9 {
	struct list_head bus_list;
	struct pci_bus___9 *bus;
	struct pci_bus___9 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___9 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u16 aer_cap;
	struct aer_stats *aer_stats;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	long unsigned int *dma_alias_mask;
	struct pci_driver___9 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	unsigned int imm_ready: 1;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int bridge_d3: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int hotplug_user_indicators: 1;
	unsigned int clear_retrain_link: 1;
	unsigned int d3_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	unsigned int ltr_path: 1;
	unsigned int eetlp_prefix_path: 1;
	pci_channel_state_t error_state;
	struct device___252 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int multifunction: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int ats_enabled: 1;
	unsigned int pasid_enabled: 1;
	unsigned int pri_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int reset_fn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int shpc_managed: 1;
	unsigned int is_thunderbolt: 1;
	unsigned int __aer_firmware_first_valid: 1;
	unsigned int __aer_firmware_first: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int irq_managed: 1;
	unsigned int has_secondary_link: 1;
	unsigned int non_compliant_bars: 1;
	unsigned int is_probed: 1;
	unsigned int link_active_reporting: 1;
	unsigned int untrusted: 1;
	unsigned int no_vf_scan: 1;
	unsigned int io_window: 1;
	unsigned int pref_window: 1;
	unsigned int pref_64_window: 1;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	struct bin_attribute___250 *rom_attr;
	int rom_attr_enabled;
	struct bin_attribute___250 *res_attr[17];
	struct bin_attribute___250 *res_attr_wc[17];
	unsigned int broken_cmd_compl: 1;
	const struct attribute_group___251 **msi_irq_groups;
	struct pci_vpd *vpd;
	union {
		struct pci_sriov___5 *sriov;
		struct pci_dev___9 *physfn;
	};
	u16 ats_cap;
	u8 ats_stu;
	atomic_t ats_ref_cnt;
	u32 pri_reqs_alloc;
	u16 pasid_features;
	struct pci_p2pdma *p2pdma;
	phys_addr_t rom;
	size_t romlen;
	char *driver_override;
	long unsigned int priv_flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t pci_dev_extended_size_rh;
	struct pci_dev_extended_rh pci_dev_extended_rh;
};

struct pci_error_handlers___9;

struct pci_driver___9 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___9 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___9 *);
	int (*suspend)(struct pci_dev___9 *, pm_message_t);
	int (*suspend_late)(struct pci_dev___9 *, pm_message_t);
	int (*resume_early)(struct pci_dev___9 *);
	int (*resume)(struct pci_dev___9 *);
	void (*shutdown)(struct pci_dev___9 *);
	int (*sriov_configure)(struct pci_dev___9 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	const struct pci_error_handlers___9 *err_handler;
	const struct attribute_group___251 **groups;
	struct device_driver___252 driver;
	struct pci_dynids dynids;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct pci_ops___9 {
	int (*add_bus)(struct pci_bus___9 *);
	void (*remove_bus)(struct pci_bus___9 *);
	void * (*map_bus)(struct pci_bus___9 *, unsigned int, int);
	int (*read)(struct pci_bus___9 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___9 *, unsigned int, int, int, u32);
};

enum pci_ers_result {
	PCI_ERS_RESULT_NONE = 1,
	PCI_ERS_RESULT_CAN_RECOVER = 2,
	PCI_ERS_RESULT_NEED_RESET = 3,
	PCI_ERS_RESULT_DISCONNECT = 4,
	PCI_ERS_RESULT_RECOVERED = 5,
	PCI_ERS_RESULT_NO_AER_DRIVER = 6,
};

struct pci_error_handlers___9 {
	pci_ers_result_t (*error_detected)(struct pci_dev___9 *, enum pci_channel_state);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___9 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___9 *);
	void (*reset_prepare)(struct pci_dev___9 *);
	void (*reset_done)(struct pci_dev___9 *);
	void (*resume)(struct pci_dev___9 *);
};

struct shrink_control___116 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___116 *memcg;
};

struct shrinker___116 {
	long unsigned int (*count_objects)(struct shrinker___116 *, struct shrink_control___116 *);
	long unsigned int (*scan_objects)(struct shrinker___116 *, struct shrink_control___116 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct dentry_operations___286;

struct super_block___286;

struct dentry___287 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___287 *d_parent;
	struct qstr d_name;
	struct inode___287 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___286 *d_op;
	struct super_block___286 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___286;

struct block_device___286;

struct cdev___47;

struct inode___287 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___286 *i_op;
	struct super_block___286 *i_sb;
	struct address_space___286 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___288 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___148 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___287 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___286 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___286 *i_bdev;
		struct cdev___47 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___286 {
	int (*d_revalidate)(struct dentry___287 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___287 *, unsigned int);
	int (*d_hash)(const struct dentry___287 *, struct qstr *);
	int (*d_compare)(const struct dentry___287 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___287 *);
	int (*d_init)(struct dentry___287 *);
	void (*d_release)(struct dentry___287 *);
	void (*d_prune)(struct dentry___287 *);
	void (*d_iput)(struct dentry___287 *, struct inode___287 *);
	char * (*d_dname)(struct dentry___287 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___287 *);
	int (*d_manage)(const struct path___287 *, bool);
	struct dentry___287 * (*d_real)(struct dentry___287 *, const struct inode___287 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___286;

struct mem_dqinfo___286 {
	struct quota_format_type___286 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___286;

struct quota_info___286 {
	unsigned int flags;
	struct rw_semaphore___288 dqio_sem;
	struct inode___287 *files[3];
	struct mem_dqinfo___286 info[3];
	const struct quota_format_ops___286 *ops[3];
};

struct rcuwait___286 {
	struct task_struct___288 *task;
};

struct percpu_rw_semaphore___286 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___288 rw_sem;
	struct rcuwait___286 writer;
	int readers_block;
};

struct sb_writers___286 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___286 rw_sem[3];
};

struct file_system_type___286;

struct super_operations___286;

struct dquot_operations___286;

struct quotactl_ops___286;

struct super_block___286 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___286 *s_type;
	const struct super_operations___286 *s_op;
	const struct dquot_operations___286 *dq_op;
	const struct quotactl_ops___286 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___287 *s_root;
	struct rw_semaphore___288 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___286 *s_bdev;
	struct backing_dev_info___148 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___286 s_dquot;
	struct sb_writers___286 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___286 *s_d_op;
	int cleancache_poolid;
	struct shrinker___116 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___221 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___287 {
	struct file___287 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___287 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___286 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___287 *ia_file;
};

struct dquot___286 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___286 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___286 {
	int qf_fmt_id;
	const struct quota_format_ops___286 *qf_ops;
	struct module___232 *qf_owner;
	struct quota_format_type___286 *qf_next;
};

struct quota_format_ops___286 {
	int (*check_quota_file)(struct super_block___286 *, int);
	int (*read_file_info)(struct super_block___286 *, int);
	int (*write_file_info)(struct super_block___286 *, int);
	int (*free_file_info)(struct super_block___286 *, int);
	int (*read_dqblk)(struct dquot___286 *);
	int (*commit_dqblk)(struct dquot___286 *);
	int (*release_dqblk)(struct dquot___286 *);
	int (*get_next_id)(struct super_block___286 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___286 {
	int (*write_dquot)(struct dquot___286 *);
	struct dquot___286 * (*alloc_dquot)(struct super_block___286 *, int);
	void (*destroy_dquot)(struct dquot___286 *);
	int (*acquire_dquot)(struct dquot___286 *);
	int (*release_dquot)(struct dquot___286 *);
	int (*mark_dirty)(struct dquot___286 *);
	int (*write_info)(struct super_block___286 *, int);
	qsize_t * (*get_reserved_space)(struct inode___287 *);
	int (*get_projid)(struct inode___287 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___287 *, qsize_t *);
	int (*get_next_id)(struct super_block___286 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___286 {
	int (*quota_on)(struct super_block___286 *, int, int, const struct path___287 *);
	int (*quota_off)(struct super_block___286 *, int);
	int (*quota_enable)(struct super_block___286 *, unsigned int);
	int (*quota_disable)(struct super_block___286 *, unsigned int);
	int (*quota_sync)(struct super_block___286 *, int);
	int (*set_info)(struct super_block___286 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___286 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___286 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___286 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___286 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___286 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___131;

struct swap_info_struct___75;

struct address_space_operations___286 {
	int (*writepage)(struct page___288 *, struct writeback_control___131 *);
	int (*readpage)(struct file___287 *, struct page___288 *);
	int (*writepages)(struct address_space___286 *, struct writeback_control___131 *);
	int (*set_page_dirty)(struct page___288 *);
	int (*readpages)(struct file___287 *, struct address_space___286 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___287 *, struct address_space___286 *, loff_t, unsigned int, unsigned int, struct page___288 **, void **);
	int (*write_end)(struct file___287 *, struct address_space___286 *, loff_t, unsigned int, unsigned int, struct page___288 *, void *);
	sector_t (*bmap)(struct address_space___286 *, sector_t);
	void (*invalidatepage)(struct page___288 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___288 *, gfp_t);
	void (*freepage)(struct page___288 *);
	ssize_t (*direct_IO)(struct kiocb___287 *, struct iov_iter___137 *);
	int (*migratepage)(struct address_space___286 *, struct page___288 *, struct page___288 *, enum migrate_mode);
	bool (*isolate_page)(struct page___288 *, isolate_mode_t);
	void (*putback_page)(struct page___288 *);
	int (*launder_page)(struct page___288 *);
	int (*is_partially_uptodate)(struct page___288 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___288 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___286 *, struct page___288 *);
	int (*swap_activate)(struct swap_info_struct___75 *, struct file___287 *, sector_t *);
	void (*swap_deactivate)(struct file___287 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___131 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___148 *wb;
	struct inode___287 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___149;

struct iov_iter___137 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___149 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct swap_info_struct___75 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___286 *bdev;
	struct file___287 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___286 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___287 *bd_inode;
	struct super_block___286 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___286 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___148 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___47 {
	struct kobject___274 kobj;
	struct module___232 *owner;
	const struct file_operations___287 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___286 {
	struct dentry___287 * (*lookup)(struct inode___287 *, struct dentry___287 *, unsigned int);
	const char * (*get_link)(struct dentry___287 *, struct inode___287 *, struct delayed_call *);
	int (*permission)(struct inode___287 *, int);
	struct posix_acl * (*get_acl)(struct inode___287 *, int);
	int (*readlink)(struct dentry___287 *, char *, int);
	int (*create)(struct inode___287 *, struct dentry___287 *, umode_t, bool);
	int (*link)(struct dentry___287 *, struct inode___287 *, struct dentry___287 *);
	int (*unlink)(struct inode___287 *, struct dentry___287 *);
	int (*symlink)(struct inode___287 *, struct dentry___287 *, const char *);
	int (*mkdir)(struct inode___287 *, struct dentry___287 *, umode_t);
	int (*rmdir)(struct inode___287 *, struct dentry___287 *);
	int (*mknod)(struct inode___287 *, struct dentry___287 *, umode_t, dev_t);
	int (*rename)(struct inode___287 *, struct dentry___287 *, struct inode___287 *, struct dentry___287 *, unsigned int);
	int (*setattr)(struct dentry___287 *, struct iattr___286 *);
	int (*getattr)(const struct path___287 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___287 *, char *, size_t);
	int (*fiemap)(struct inode___287 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___287 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___287 *, struct dentry___287 *, struct file___287 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___287 *, struct dentry___287 *, umode_t);
	int (*set_acl)(struct inode___287 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___286 {
	void (*fl_copy_lock)(struct file_lock___287 *, struct file_lock___287 *);
	void (*fl_release_private)(struct file_lock___287 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___286;

struct lock_manager_operations___286;

struct file_lock___287 {
	struct file_lock___287 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___287 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___286 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___286 *fl_ops;
	const struct lock_manager_operations___286 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___286 {
	int (*lm_compare_owner)(struct file_lock___287 *, struct file_lock___287 *);
	long unsigned int (*lm_owner_key)(struct file_lock___287 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___287 *);
	int (*lm_grant)(struct file_lock___287 *, int);
	bool (*lm_break)(struct file_lock___287 *);
	int (*lm_change)(struct file_lock___287 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___287 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___286 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___286 *fa_next;
	struct file___287 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___286 {
	const char *name;
	int fs_flags;
	struct dentry___287 * (*mount)(struct file_system_type___286 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___286 *);
	struct module___232 *owner;
	struct file_system_type___286 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___286 {
	struct inode___287 * (*alloc_inode)(struct super_block___286 *);
	void (*destroy_inode)(struct inode___287 *);
	void (*dirty_inode)(struct inode___287 *, int);
	int (*write_inode)(struct inode___287 *, struct writeback_control___131 *);
	int (*drop_inode)(struct inode___287 *);
	void (*evict_inode)(struct inode___287 *);
	void (*put_super)(struct super_block___286 *);
	int (*sync_fs)(struct super_block___286 *, int);
	int (*freeze_super)(struct super_block___286 *);
	int (*freeze_fs)(struct super_block___286 *);
	int (*thaw_super)(struct super_block___286 *);
	int (*unfreeze_fs)(struct super_block___286 *);
	int (*statfs)(struct dentry___287 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___286 *, int *, char *);
	void (*umount_begin)(struct super_block___286 *);
	int (*show_options)(struct seq_file___247 *, struct dentry___287 *);
	int (*show_devname)(struct seq_file___247 *, struct dentry___287 *);
	int (*show_path)(struct seq_file___247 *, struct dentry___287 *);
	int (*show_stats)(struct seq_file___247 *, struct dentry___287 *);
	ssize_t (*quota_read)(struct super_block___286 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___286 *, int, const char *, size_t, loff_t);
	struct dquot___286 ** (*get_dquots)(struct inode___287 *);
	int (*bdev_try_to_free_page)(struct super_block___286 *, struct page___288 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___286 *, struct shrink_control___116 *);
	long int (*free_cached_objects)(struct super_block___286 *, struct shrink_control___116 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___148(struct bio___148 *);

struct bio_vec___149 {
	struct page___288 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___148;

struct bio_set___148;

struct bio___148 {
	struct bio___148 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___148 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___148 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___149 *bi_io_vec;
	struct bio_set___148 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___149 bi_inline_vecs[0];
};

typedef void compound_page_dtor___276(struct page___288 *);

struct kernel_param_ops___229 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___229 *);
	int (*get)(char *, const struct kernel_param___229 *);
	void (*free)(void *);
};

struct kparam_array___229;

struct kernel_param___229 {
	const char *name;
	struct module___232 *mod;
	const struct kernel_param_ops___229 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___229 *arr;
	};
};

struct kparam_array___229 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___229 *ops;
	void *elem;
};

struct module_attribute___229 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___229 *, struct module_kobject___229 *, char *);
	ssize_t (*store)(struct module_attribute___229 *, struct module_kobject___229 *, const char *, size_t);
	void (*setup)(struct module___232 *, const char *);
	int (*test)(struct module___232 *);
	void (*free)(struct module___232 *);
};

struct node___178 {
	struct device___252 dev;
};

typedef int (*key_restrict_link_func_t___269)(struct key___268 *, const struct key_type *, const union key_payload *, struct key___268 *);

struct key_restriction___268;

struct key___268 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___288 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___268 *restrict_link;
};

struct key_restriction___268 {
	key_restrict_link_func_t___269 check;
	struct key___268 *key;
	struct key_type *keytype;
};

struct seq_operations___246 {
	void * (*start)(struct seq_file___247 *, loff_t *);
	void (*stop)(struct seq_file___247 *, void *);
	void * (*next)(struct seq_file___247 *, void *, loff_t *);
	int (*show)(struct seq_file___247 *, void *);
};

struct cgroup_namespace___206 {
	refcount_t count;
	struct ns_common___9 ns;
	struct user_namespace___221 *user_ns;
	struct ucounts___221 *ucounts;
	struct css_set___206 *root_cset;
};

struct ucounts___221 {
	struct hlist_node node;
	struct user_namespace___221 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___207;

struct bpf_map_ops___206 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___207 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___207 *, struct file___287 *);
	void (*map_free)(struct bpf_map___207 *);
	int (*map_get_next_key)(struct bpf_map___207 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___207 *);
	void * (*map_lookup_elem)(struct bpf_map___207 *, void *);
	int (*map_update_elem)(struct bpf_map___207 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___207 *, void *);
	int (*map_push_elem)(struct bpf_map___207 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___207 *, void *);
	int (*map_peek_elem)(struct bpf_map___207 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___207 *, struct file___287 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___207 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___207 *, void *, struct seq_file___247 *);
	int (*map_check_btf)(const struct bpf_map___207 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___207 {
	const struct bpf_map_ops___206 *ops;
	struct bpf_map___207 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___268 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___206;

typedef void (*kthread_work_func_t___206)(struct kthread_work___206 *);

struct kthread_worker___206;

struct kthread_work___206 {
	struct list_head node;
	kthread_work_func_t___206 func;
	struct kthread_worker___206 *worker;
	int canceling;
};

struct kthread_worker___206 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___288 *task;
	struct kthread_work___206 *current_work;
};

struct kthread_delayed_work___206 {
	struct kthread_work___206 work;
	struct timer_list timer;
};

struct psi_group___206 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___206 *poll_kworker;
	struct kthread_delayed_work___206 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___206;

struct cgroup_rstat_cpu___206;

struct cgroup___206 {
	struct cgroup_subsys_state___206 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___281 *kn;
	struct cgroup_file___206 procs_file;
	struct cgroup_file___206 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___206 *subsys[13];
	struct cgroup_root___206 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___206 *dom_cgrp;
	struct cgroup_rstat_cpu___206 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___35 bpf;
	atomic_t congestion_count;
	struct cgroup___206 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___206 psi;
	int ancestor_ids[0];
};

struct cftype___206;

struct cgroup_subsys___206 {
	struct cgroup_subsys_state___206 * (*css_alloc)(struct cgroup_subsys_state___206 *);
	int (*css_online)(struct cgroup_subsys_state___206 *);
	void (*css_offline)(struct cgroup_subsys_state___206 *);
	void (*css_released)(struct cgroup_subsys_state___206 *);
	void (*css_free)(struct cgroup_subsys_state___206 *);
	void (*css_reset)(struct cgroup_subsys_state___206 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___206 *, int);
	int (*css_extra_stat_show)(struct seq_file___247 *, struct cgroup_subsys_state___206 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___288 *);
	void (*cancel_fork)(struct task_struct___288 *);
	void (*fork)(struct task_struct___288 *);
	void (*exit)(struct task_struct___288 *);
	void (*free)(struct task_struct___288 *);
	void (*bind)(struct cgroup_subsys_state___206 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___206 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___206 *dfl_cftypes;
	struct cftype___206 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___206 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___206 *updated_children;
	struct cgroup___206 *updated_next;
};

struct cgroup_root___206 {
	struct kernfs_root___280 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___206 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___206 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___206 *ss;
	struct list_head node;
	struct kernfs_ops___280 *kf_ops;
	int (*open)(struct kernfs_open_file___280 *);
	void (*release)(struct kernfs_open_file___280 *);
	u64 (*read_u64)(struct cgroup_subsys_state___206 *, struct cftype___206 *);
	s64 (*read_s64)(struct cgroup_subsys_state___206 *, struct cftype___206 *);
	int (*seq_show)(struct seq_file___247 *, void *);
	void * (*seq_start)(struct seq_file___247 *, loff_t *);
	void * (*seq_next)(struct seq_file___247 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___247 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___206 *, struct cftype___206 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___206 *, struct cftype___206 *, s64);
	ssize_t (*write)(struct kernfs_open_file___280 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___280 *, struct poll_table_struct___174 *);
};

struct bdi_writeback_congested___148 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___148 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___148 {
	struct bio___148 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___149 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___149 bip_inline_vecs[0];
};

struct bio_set___148 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___148 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___116 {
	struct mem_cgroup___116 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___116 {
	struct lruvec___287 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___116 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___116 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct kimage___21;

typedef void *kexec_load_t___21(struct kimage___21 *, char *, long unsigned int, char *, long unsigned int, char *, long unsigned int);

struct kexec_file_ops___22 {
	kexec_probe_t *probe;
	kexec_load_t___21 *load;
	kexec_cleanup_t *cleanup;
};

struct kimage___21 {
	kimage_entry_t head;
	kimage_entry_t *entry;
	kimage_entry_t *last_entry;
	long unsigned int start;
	struct page___288 *control_code_page;
	struct page___288 *swap_page;
	void *vmcoreinfo_data_copy;
	long unsigned int nr_segments;
	struct kexec_segment segment[16];
	struct list_head control_pages;
	struct list_head dest_pages;
	struct list_head unusable_pages;
	long unsigned int control_page;
	unsigned int type: 1;
	unsigned int preserve_context: 1;
	unsigned int file_mode: 1;
	struct kimage_arch arch;
	void *kernel_buf;
	long unsigned int kernel_buf_len;
	void *initrd_buf;
	long unsigned int initrd_buf_len;
	char *cmdline_buf;
	long unsigned int cmdline_buf_len;
	const struct kexec_file_ops___22 *fops;
	void *image_loader_data;
	struct purgatory_info purgatory_info;
};

enum dev_dma_attr {
	DEV_DMA_NOT_SUPPORTED = 0,
	DEV_DMA_NON_COHERENT = 1,
	DEV_DMA_COHERENT = 2,
};

struct property___47 {
	char *name;
	int length;
	void *value;
	struct property___47 *next;
	long unsigned int _flags;
	struct bin_attribute___250 attr;
};

struct acpi_device___4;

struct acpi_hotplug_profile___4 {
	struct kobject___274 kobj;
	int (*scan_dependent)(struct acpi_device___4 *);
	void (*notify_online)(struct acpi_device___4 *);
	bool enabled: 1;
	bool demand_offline: 1;
};

struct acpi_device_wakeup_context___4 {
	void (*func)(struct acpi_device_wakeup_context___4 *);
	struct device___252 *dev;
};

struct acpi_device_wakeup___4 {
	acpi_handle gpe_device;
	u64 gpe_number;
	u64 sleep_state;
	struct list_head resources;
	struct acpi_device_wakeup_flags flags;
	struct acpi_device_wakeup_context___4 context;
	struct wakeup_source *ws;
	int prepare_count;
	int enable_count;
};

struct acpi_scan_handler___4;

struct acpi_hotplug_context___4;

struct acpi_driver___4;

struct acpi_device___4 {
	int device_type;
	acpi_handle handle;
	struct fwnode_handle___186 fwnode;
	struct acpi_device___4 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup___4 wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_device_data data;
	struct acpi_scan_handler___4 *handler;
	struct acpi_hotplug_context___4 *hp;
	struct acpi_driver___4 *driver;
	const struct acpi_gpio_mapping *driver_gpios;
	void *driver_data;
	struct device___252 dev;
	unsigned int physical_node_count;
	unsigned int dep_unmet;
	struct list_head physical_node_list;
	struct mutex physical_node_lock;
	void (*remove)(struct acpi_device___4 *);
};

struct acpi_scan_handler___4 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	bool (*match)(const char *, const struct acpi_device_id **);
	int (*attach)(struct acpi_device___4 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___4 *);
	void (*bind)(struct device___252 *);
	void (*unbind)(struct device___252 *);
	struct acpi_hotplug_profile___4 hotplug;
};

struct acpi_hotplug_context___4 {
	struct acpi_device___4 *self;
	int (*notify)(struct acpi_device___4 *, u32);
	void (*uevent)(struct acpi_device___4 *, u32);
	void (*fixup)(struct acpi_device___4 *);
};

typedef int (*acpi_op_add___4)(struct acpi_device___4 *);

typedef int (*acpi_op_remove___4)(struct acpi_device___4 *);

typedef void (*acpi_op_notify___4)(struct acpi_device___4 *, u32);

struct acpi_device_ops___4 {
	acpi_op_add___4 add;
	acpi_op_remove___4 remove;
	acpi_op_notify___4 notify;
};

struct acpi_driver___4 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___4 ops;
	struct device_driver___252 drv;
	struct module___232 *owner;
};

struct pcie_device {
	int irq;
	struct pci_dev___9 *port;
	u32 service;
	void *priv_data;
	struct device___252 device;
};

struct pcie_port_service_driver {
	const char *name;
	int (*probe)(struct pcie_device *);
	void (*remove)(struct pcie_device *);
	int (*suspend)(struct pcie_device *);
	int (*resume_noirq)(struct pcie_device *);
	int (*resume)(struct pcie_device *);
	int (*runtime_suspend)(struct pcie_device *);
	int (*runtime_resume)(struct pcie_device *);
	void (*error_resume)(struct pci_dev___9 *);
	pci_ers_result_t (*reset_link)(struct pci_dev___9 *);
	int port_type;
	u32 service;
	struct device_driver___252 driver;
};

struct pci_dynid {
	struct list_head node;
	struct pci_device_id id;
};

struct drv_dev_and_id {
	struct pci_driver___9 *drv;
	struct pci_dev___9 *dev;
	const struct pci_device_id *id;
};

struct file___288;

struct kiocb___288;

struct vm_area_struct___289;

struct inode___288;

struct file_lock___288;

struct page___289;

struct file_operations___288 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___288 *, loff_t, int);
	ssize_t (*read)(struct file___288 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___288 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___288 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___288 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___288 *, bool);
	int (*iterate)(struct file___288 *, struct dir_context *);
	int (*iterate_shared)(struct file___288 *, struct dir_context *);
	__poll_t (*poll)(struct file___288 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___288 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___288 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___288 *, struct vm_area_struct___289 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___288 *, struct file___288 *);
	int (*flush)(struct file___288 *, fl_owner_t);
	int (*release)(struct inode___288 *, struct file___288 *);
	int (*fsync)(struct file___288 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___288 *, int);
	int (*lock)(struct file___288 *, int, struct file_lock___288 *);
	ssize_t (*sendpage)(struct file___288 *, struct page___289 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___288 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___288 *, int, struct file_lock___288 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___288 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___288 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___288 *, long int, struct file_lock___288 **, void **);
	long int (*fallocate)(struct file___288 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___288 *);
	ssize_t (*copy_file_range)(struct file___288 *, loff_t, struct file___288 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___288 *, loff_t, struct file___288 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___288 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___288 {
	u64 seqnum;
	struct vm_area_struct___289 *vmas[4];
};

struct page_frag___288 {
	struct page___289 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___288;

struct vm_struct___204;

struct task_struct___289 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___289 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___288 *mm;
	struct mm_struct___288 *active_mm;
	struct vmacache___288 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___289 *real_parent;
	struct task_struct___289 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___289 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___195 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___195 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___195 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___2 *ptracer_cred;
	const struct cred___2 *real_cred;
	const struct cred___2 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___289 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___82 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___288 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___289 *oom_reaper_list;
	struct vm_struct___204 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___130 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct secondary_data___289 {
	void *stack;
	struct task_struct___289 *task;
	long int status;
};

typedef struct page___289 *pgtable_t___288;

struct address_space___287;

struct dev_pagemap___277;

struct page___289 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___287 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___289 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___288 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___288 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___277 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct vm_operations_struct___277;

struct vm_area_struct___289 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___289 *vm_next;
	struct vm_area_struct___289 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___288 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___277 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___288 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct rw_semaphore___289 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___289 *owner;
};

struct core_state___288;

struct mm_struct___288 {
	struct {
		struct vm_area_struct___289 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___288 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___289 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___288 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___289 *owner;
		struct user_namespace___3 *user_ns;
		struct file___288 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___288 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct vm_struct___204 {
	struct vm_struct___204 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___289 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct pglist_data___288;

struct lruvec___288 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___288 *pgdat;
};

struct zone___288 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___288 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___288 {
	struct zone___288 *zone;
	int zone_idx;
};

struct zonelist___288 {
	struct zoneref___288 _zonerefs[25];
};

struct pglist_data___288 {
	struct zone___288 node_zones[3];
	struct zonelist___288 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___289 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___289 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___288 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___288 {
	struct rw_semaphore___289 rwsem;
	struct notifier_block *head;
};

struct kernfs_root___281;

struct kernfs_elem_dir___281 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___281 *root;
};

struct kernfs_node___282;

struct kernfs_syscall_ops___281;

struct kernfs_root___281 {
	struct kernfs_node___282 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___281 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___281 {
	struct kernfs_node___282 *target_kn;
};

struct kernfs_ops___281;

struct kernfs_elem_attr___281 {
	const struct kernfs_ops___281 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___282 *notify_next;
};

struct kernfs_node___282 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___282 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___281 dir;
		struct kernfs_elem_symlink___281 symlink;
		struct kernfs_elem_attr___281 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___281;

struct kernfs_ops___281 {
	int (*open)(struct kernfs_open_file___281 *);
	void (*release)(struct kernfs_open_file___281 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___281 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___281 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___281 *, struct vm_area_struct___289 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___281 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___281 {
	int (*remount_fs)(struct kernfs_root___281 *, int *, char *);
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___281 *);
	int (*mkdir)(struct kernfs_node___282 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___282 *);
	int (*rename)(struct kernfs_node___282 *, struct kernfs_node___282 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___282 *, struct kernfs_root___281 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___281 {
	struct kernfs_node___282 *kn;
	struct file___288 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___277 *vm_ops;
};

struct dentry___288;

struct path___288 {
	struct vfsmount *mnt;
	struct dentry___288 *dentry;
};

struct file___288 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___288 f_path;
	struct inode___288 *f_inode;
	const struct file_operations___288 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___195 f_owner;
	const struct cred___2 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___287 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___277;

struct vm_operations_struct___277 {
	void (*open)(struct vm_area_struct___289 *);
	void (*close)(struct vm_area_struct___289 *);
	int (*split)(struct vm_area_struct___289 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___289 *);
	vm_fault_t (*fault)(struct vm_fault___277 *);
	vm_fault_t (*huge_fault)(struct vm_fault___277 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___277 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___289 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___277 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___277 *);
	int (*access)(struct vm_area_struct___289 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___289 *);
	int (*set_policy)(struct vm_area_struct___289 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___289 *, long unsigned int);
	struct page___289 * (*find_special_page)(struct vm_area_struct___289 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___275;

struct bin_attribute___251;

struct attribute_group___252 {
	const char *name;
	umode_t (*is_visible)(struct kobject___275 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___275 *, struct bin_attribute___251 *, int);
	struct attribute **attrs;
	struct bin_attribute___251 **bin_attrs;
};

struct kset___274;

struct kobj_type___274;

struct kobject___275 {
	const char *name;
	struct list_head entry;
	struct kobject___275 *parent;
	struct kset___274 *kset;
	struct kobj_type___274 *ktype;
	struct kernfs_node___282 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___251 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___288 *, struct kobject___275 *, struct bin_attribute___251 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___288 *, struct kobject___275 *, struct bin_attribute___251 *, char *, loff_t, size_t);
	int (*mmap)(struct file___288 *, struct kobject___275 *, struct bin_attribute___251 *, struct vm_area_struct___289 *);
};

struct sysfs_ops___274 {
	ssize_t (*show)(struct kobject___275 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___275 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___274;

struct kset___274 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___275 kobj;
	const struct kset_uevent_ops___274 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___274 {
	void (*release)(struct kobject___275 *);
	const struct sysfs_ops___274 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___25 * (*child_ns_type)(struct kobject___275 *);
	const void * (*namespace)(struct kobject___275 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___274 {
	int (* const filter)(struct kset___274 *, struct kobject___275 *);
	const char * (* const name)(struct kset___274 *, struct kobject___275 *);
	int (* const uevent)(struct kset___274 *, struct kobject___275 *, struct kobj_uevent_env *);
};

struct kobj_attribute___267 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___275 *, struct kobj_attribute___267 *, char *);
	ssize_t (*store)(struct kobject___275 *, struct kobj_attribute___267 *, const char *, size_t);
};

struct device___253;

struct dev_pm_ops___253 {
	int (*prepare)(struct device___253 *);
	void (*complete)(struct device___253 *);
	int (*suspend)(struct device___253 *);
	int (*resume)(struct device___253 *);
	int (*freeze)(struct device___253 *);
	int (*thaw)(struct device___253 *);
	int (*poweroff)(struct device___253 *);
	int (*restore)(struct device___253 *);
	int (*suspend_late)(struct device___253 *);
	int (*resume_early)(struct device___253 *);
	int (*freeze_late)(struct device___253 *);
	int (*thaw_early)(struct device___253 *);
	int (*poweroff_late)(struct device___253 *);
	int (*restore_early)(struct device___253 *);
	int (*suspend_noirq)(struct device___253 *);
	int (*resume_noirq)(struct device___253 *);
	int (*freeze_noirq)(struct device___253 *);
	int (*thaw_noirq)(struct device___253 *);
	int (*poweroff_noirq)(struct device___253 *);
	int (*restore_noirq)(struct device___253 *);
	int (*runtime_suspend)(struct device___253 *);
	int (*runtime_resume)(struct device___253 *);
	int (*runtime_idle)(struct device___253 *);
};

struct dev_pm_info___253 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___253 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___253;

struct bus_type___253;

struct device_driver___253;

struct dev_pm_domain___253;

struct dma_map_ops___75;

struct device_node___51;

struct fwnode_handle___187;

struct class___253;

struct device___253 {
	struct device___253 *parent;
	struct device_private *p;
	struct kobject___275 kobj;
	const char *init_name;
	const struct device_type___253 *type;
	struct mutex mutex;
	struct bus_type___253 *bus;
	struct device_driver___253 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___253 power;
	struct dev_pm_domain___253 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___75 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___51 *of_node;
	struct fwnode_handle___187 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___253 *class;
	const struct attribute_group___252 **groups;
	void (*release)(struct device___253 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___253 {
	struct dev_pm_ops___253 ops;
	void (*detach)(struct device___253 *, bool);
	int (*activate)(struct device___253 *);
	void (*sync)(struct device___253 *);
	void (*dismiss)(struct device___253 *);
};

struct bus_attribute___2 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___253 *, char *);
	ssize_t (*store)(struct bus_type___253 *, const char *, size_t);
};

struct bus_type___253 {
	const char *name;
	const char *dev_name;
	struct device___253 *dev_root;
	const struct attribute_group___252 **bus_groups;
	const struct attribute_group___252 **dev_groups;
	const struct attribute_group___252 **drv_groups;
	int (*match)(struct device___253 *, struct device_driver___253 *);
	int (*uevent)(struct device___253 *, struct kobj_uevent_env *);
	int (*probe)(struct device___253 *);
	int (*remove)(struct device___253 *);
	void (*shutdown)(struct device___253 *);
	int (*online)(struct device___253 *);
	int (*offline)(struct device___253 *);
	int (*suspend)(struct device___253 *, pm_message_t);
	int (*resume)(struct device___253 *);
	int (*num_vf)(struct device___253 *);
	int (*dma_configure)(struct device___253 *);
	const struct dev_pm_ops___253 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___253 {
	const char *name;
	struct bus_type___253 *bus;
	struct module___11 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___253 *);
	int (*remove)(struct device___253 *);
	void (*shutdown)(struct device___253 *);
	int (*suspend)(struct device___253 *, pm_message_t);
	int (*resume)(struct device___253 *);
	const struct attribute_group___252 **groups;
	const struct dev_pm_ops___253 *pm;
	void (*coredump)(struct device___253 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___253 {
	const char *name;
	const struct attribute_group___252 **groups;
	int (*uevent)(struct device___253 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___253 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___253 *);
	const struct dev_pm_ops___253 *pm;
};

struct class___253 {
	const char *name;
	struct module___11 *owner;
	const struct attribute_group___252 **class_groups;
	const struct attribute_group___252 **dev_groups;
	struct kobject___275 *dev_kobj;
	int (*dev_uevent)(struct device___253 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___253 *, umode_t *);
	void (*class_release)(struct class___253 *);
	void (*dev_release)(struct device___253 *);
	int (*shutdown_pre)(struct device___253 *);
	const struct kobj_ns_type_operations___25 *ns_type;
	const void * (*namespace)(struct device___253 *);
	const struct dev_pm_ops___253 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct device_attribute___13 {
	struct attribute attr;
	ssize_t (*show)(struct device___253 *, struct device_attribute___13 *, char *);
	ssize_t (*store)(struct device___253 *, struct device_attribute___13 *, const char *, size_t);
};

struct dma_map_ops___75 {
	void * (*alloc)(struct device___253 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___253 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___253 *, struct vm_area_struct___289 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___253 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___253 *, struct page___289 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___253 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___253 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___253 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___253 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___253 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___253 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___253 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___253 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___253 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___253 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___253 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___253 *, u64);
	u64 (*get_required_mask)(struct device___253 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___187;

struct fwnode_handle___187 {
	struct fwnode_handle___187 *secondary;
	const struct fwnode_operations___187 *ops;
};

struct property___48;

struct device_node___51 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___187 fwnode;
	struct property___48 *properties;
	struct property___48 *deadprops;
	struct device_node___51 *parent;
	struct device_node___51 *child;
	struct device_node___51 *sibling;
	struct kobject___275 kobj;
	long unsigned int _flags;
	void *data;
};

struct address_space_operations___287;

struct address_space___287 {
	struct inode___288 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___289 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___287 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___277)(struct vm_area_struct___289 *, long unsigned int, const struct page___289 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___277)(struct page___289 *, void *);

struct dev_pagemap___277 {
	dev_page_fault_t___277 page_fault;
	dev_page_free_t___277 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___253 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___288 {
	struct task_struct___289 *task;
	struct core_thread___288 *next;
};

struct core_state___288 {
	atomic_t nr_threads;
	struct core_thread___288 dumper;
	struct completion startup;
};

struct vm_fault___277 {
	struct vm_area_struct___289 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___289 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___289 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___288 prealloc_pte;
};

struct fwnode_reference_args___187;

struct fwnode_endpoint___187;

struct fwnode_operations___187 {
	struct fwnode_handle___187 * (*get)(struct fwnode_handle___187 *);
	void (*put)(struct fwnode_handle___187 *);
	bool (*device_is_available)(const struct fwnode_handle___187 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___187 *, const struct device___253 *);
	bool (*property_present)(const struct fwnode_handle___187 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___187 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___187 *, const char *, const char **, size_t);
	struct fwnode_handle___187 * (*get_parent)(const struct fwnode_handle___187 *);
	struct fwnode_handle___187 * (*get_next_child_node)(const struct fwnode_handle___187 *, struct fwnode_handle___187 *);
	struct fwnode_handle___187 * (*get_named_child_node)(const struct fwnode_handle___187 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___187 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___187 *);
	struct fwnode_handle___187 * (*graph_get_next_endpoint)(const struct fwnode_handle___187 *, struct fwnode_handle___187 *);
	struct fwnode_handle___187 * (*graph_get_remote_endpoint)(const struct fwnode_handle___187 *);
	struct fwnode_handle___187 * (*graph_get_port_parent)(struct fwnode_handle___187 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___187 *, struct fwnode_endpoint___187 *);
};

struct fwnode_endpoint___187 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___187 *local_fwnode;
};

struct fwnode_reference_args___187 {
	struct fwnode_handle___187 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pci_bus___10;

struct pci_slot___10 {
	struct pci_bus___10 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject___275 kobj;
};

struct pci_dev___10;

struct pci_ops___10;

struct pci_bus___10 {
	struct list_head node;
	struct pci_bus___10 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___10 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___10 *ops;
	struct msi_controller___2 *msi;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	int domain_nr;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___253 *bridge;
	struct device___253 dev;
	struct bin_attribute___251 *legacy_io;
	struct bin_attribute___251 *legacy_mem;
	unsigned int is_added: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
};

enum pci_mmap_state {
	pci_mmap_io = 0,
	pci_mmap_mem = 1,
};

struct pci_sriov___6 {
	int pos;
	int nres;
	u32 cap;
	u16 ctrl;
	u16 total_VFs;
	u16 initial_VFs;
	u16 num_VFs;
	u16 offset;
	u16 stride;
	u16 vf_device;
	u32 pgsz;
	u8 link;
	u8 max_VF_buses;
	u16 driver_max_VFs;
	struct pci_dev___10 *dev;
	struct pci_dev___10 *self;
	u32 class;
	u8 hdr_type;
	u16 subsystem_vendor;
	u16 subsystem_device;
	resource_size_t barsz[6];
	bool drivers_autoprobe;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct pci_driver___10;

struct pci_dev___10 {
	struct list_head bus_list;
	struct pci_bus___10 *bus;
	struct pci_bus___10 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___10 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u16 aer_cap;
	struct aer_stats *aer_stats;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	long unsigned int *dma_alias_mask;
	struct pci_driver___10 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	unsigned int imm_ready: 1;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int bridge_d3: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int hotplug_user_indicators: 1;
	unsigned int clear_retrain_link: 1;
	unsigned int d3_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	unsigned int ltr_path: 1;
	unsigned int eetlp_prefix_path: 1;
	pci_channel_state_t error_state;
	struct device___253 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int multifunction: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int ats_enabled: 1;
	unsigned int pasid_enabled: 1;
	unsigned int pri_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int reset_fn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int shpc_managed: 1;
	unsigned int is_thunderbolt: 1;
	unsigned int __aer_firmware_first_valid: 1;
	unsigned int __aer_firmware_first: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int irq_managed: 1;
	unsigned int has_secondary_link: 1;
	unsigned int non_compliant_bars: 1;
	unsigned int is_probed: 1;
	unsigned int link_active_reporting: 1;
	unsigned int untrusted: 1;
	unsigned int no_vf_scan: 1;
	unsigned int io_window: 1;
	unsigned int pref_window: 1;
	unsigned int pref_64_window: 1;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	struct bin_attribute___251 *rom_attr;
	int rom_attr_enabled;
	struct bin_attribute___251 *res_attr[17];
	struct bin_attribute___251 *res_attr_wc[17];
	unsigned int broken_cmd_compl: 1;
	const struct attribute_group___252 **msi_irq_groups;
	struct pci_vpd *vpd;
	union {
		struct pci_sriov___6 *sriov;
		struct pci_dev___10 *physfn;
	};
	u16 ats_cap;
	u8 ats_stu;
	atomic_t ats_ref_cnt;
	u32 pri_reqs_alloc;
	u16 pasid_features;
	struct pci_p2pdma *p2pdma;
	phys_addr_t rom;
	size_t romlen;
	char *driver_override;
	long unsigned int priv_flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t pci_dev_extended_size_rh;
	struct pci_dev_extended_rh pci_dev_extended_rh;
};

struct pci_error_handlers___10;

struct pci_driver___10 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___10 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___10 *);
	int (*suspend)(struct pci_dev___10 *, pm_message_t);
	int (*suspend_late)(struct pci_dev___10 *, pm_message_t);
	int (*resume_early)(struct pci_dev___10 *);
	int (*resume)(struct pci_dev___10 *);
	void (*shutdown)(struct pci_dev___10 *);
	int (*sriov_configure)(struct pci_dev___10 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	const struct pci_error_handlers___10 *err_handler;
	const struct attribute_group___252 **groups;
	struct device_driver___253 driver;
	struct pci_dynids dynids;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct pci_ops___10 {
	int (*add_bus)(struct pci_bus___10 *);
	void (*remove_bus)(struct pci_bus___10 *);
	void * (*map_bus)(struct pci_bus___10 *, unsigned int, int);
	int (*read)(struct pci_bus___10 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___10 *, unsigned int, int, int, u32);
};

struct pci_error_handlers___10 {
	pci_ers_result_t (*error_detected)(struct pci_dev___10 *, enum pci_channel_state);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___10 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___10 *);
	void (*reset_prepare)(struct pci_dev___10 *);
	void (*reset_done)(struct pci_dev___10 *);
	void (*resume)(struct pci_dev___10 *);
};

struct dentry_operations___287;

struct super_block___287;

struct dentry___288 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___288 *d_parent;
	struct qstr d_name;
	struct inode___288 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___287 *d_op;
	struct super_block___287 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___287;

struct block_device___287;

struct inode___288 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___287 *i_op;
	struct super_block___287 *i_sb;
	struct address_space___287 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___289 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___288 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___287 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___287 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___287 {
	int (*d_revalidate)(struct dentry___288 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___288 *, unsigned int);
	int (*d_hash)(const struct dentry___288 *, struct qstr *);
	int (*d_compare)(const struct dentry___288 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___288 *);
	int (*d_init)(struct dentry___288 *);
	void (*d_release)(struct dentry___288 *);
	void (*d_prune)(struct dentry___288 *);
	void (*d_iput)(struct dentry___288 *, struct inode___288 *);
	char * (*d_dname)(struct dentry___288 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___288 *);
	int (*d_manage)(const struct path___288 *, bool);
	struct dentry___288 * (*d_real)(struct dentry___288 *, const struct inode___288 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___287;

struct mem_dqinfo___287 {
	struct quota_format_type___287 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___287;

struct quota_info___287 {
	unsigned int flags;
	struct rw_semaphore___289 dqio_sem;
	struct inode___288 *files[3];
	struct mem_dqinfo___287 info[3];
	const struct quota_format_ops___287 *ops[3];
};

struct rcuwait___287 {
	struct task_struct___289 *task;
};

struct percpu_rw_semaphore___287 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___289 rw_sem;
	struct rcuwait___287 writer;
	int readers_block;
};

struct sb_writers___287 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___287 rw_sem[3];
};

struct file_system_type___287;

struct super_operations___287;

struct dquot_operations___287;

struct quotactl_ops___287;

struct super_block___287 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___287 *s_type;
	const struct super_operations___287 *s_op;
	const struct dquot_operations___287 *dq_op;
	const struct quotactl_ops___287 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___288 *s_root;
	struct rw_semaphore___289 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___287 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___287 s_dquot;
	struct sb_writers___287 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___287 *s_d_op;
	int cleancache_poolid;
	struct shrinker___116 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___288 {
	struct file___288 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___288 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___287 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___288 *ia_file;
};

struct dquot___287 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___287 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___287 {
	int qf_fmt_id;
	const struct quota_format_ops___287 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___287 *qf_next;
};

struct quota_format_ops___287 {
	int (*check_quota_file)(struct super_block___287 *, int);
	int (*read_file_info)(struct super_block___287 *, int);
	int (*write_file_info)(struct super_block___287 *, int);
	int (*free_file_info)(struct super_block___287 *, int);
	int (*read_dqblk)(struct dquot___287 *);
	int (*commit_dqblk)(struct dquot___287 *);
	int (*release_dqblk)(struct dquot___287 *);
	int (*get_next_id)(struct super_block___287 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___287 {
	int (*write_dquot)(struct dquot___287 *);
	struct dquot___287 * (*alloc_dquot)(struct super_block___287 *, int);
	void (*destroy_dquot)(struct dquot___287 *);
	int (*acquire_dquot)(struct dquot___287 *);
	int (*release_dquot)(struct dquot___287 *);
	int (*mark_dirty)(struct dquot___287 *);
	int (*write_info)(struct super_block___287 *, int);
	qsize_t * (*get_reserved_space)(struct inode___288 *);
	int (*get_projid)(struct inode___288 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___288 *, qsize_t *);
	int (*get_next_id)(struct super_block___287 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___287 {
	int (*quota_on)(struct super_block___287 *, int, int, const struct path___288 *);
	int (*quota_off)(struct super_block___287 *, int);
	int (*quota_enable)(struct super_block___287 *, unsigned int);
	int (*quota_disable)(struct super_block___287 *, unsigned int);
	int (*quota_sync)(struct super_block___287 *, int);
	int (*set_info)(struct super_block___287 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___287 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___287 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___287 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___287 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___287 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___287 {
	int (*writepage)(struct page___289 *, struct writeback_control___3 *);
	int (*readpage)(struct file___288 *, struct page___289 *);
	int (*writepages)(struct address_space___287 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___289 *);
	int (*readpages)(struct file___288 *, struct address_space___287 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___288 *, struct address_space___287 *, loff_t, unsigned int, unsigned int, struct page___289 **, void **);
	int (*write_end)(struct file___288 *, struct address_space___287 *, loff_t, unsigned int, unsigned int, struct page___289 *, void *);
	sector_t (*bmap)(struct address_space___287 *, sector_t);
	void (*invalidatepage)(struct page___289 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___289 *, gfp_t);
	void (*freepage)(struct page___289 *);
	ssize_t (*direct_IO)(struct kiocb___288 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___287 *, struct page___289 *, struct page___289 *, enum migrate_mode);
	bool (*isolate_page)(struct page___289 *, isolate_mode_t);
	void (*putback_page)(struct page___289 *);
	int (*launder_page)(struct page___289 *);
	int (*is_partially_uptodate)(struct page___289 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___289 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___287 *, struct page___289 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___288 *, sector_t *);
	void (*swap_deactivate)(struct file___288 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___287 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___288 *bd_inode;
	struct super_block___287 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___287 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___287 {
	struct dentry___288 * (*lookup)(struct inode___288 *, struct dentry___288 *, unsigned int);
	const char * (*get_link)(struct dentry___288 *, struct inode___288 *, struct delayed_call *);
	int (*permission)(struct inode___288 *, int);
	struct posix_acl * (*get_acl)(struct inode___288 *, int);
	int (*readlink)(struct dentry___288 *, char *, int);
	int (*create)(struct inode___288 *, struct dentry___288 *, umode_t, bool);
	int (*link)(struct dentry___288 *, struct inode___288 *, struct dentry___288 *);
	int (*unlink)(struct inode___288 *, struct dentry___288 *);
	int (*symlink)(struct inode___288 *, struct dentry___288 *, const char *);
	int (*mkdir)(struct inode___288 *, struct dentry___288 *, umode_t);
	int (*rmdir)(struct inode___288 *, struct dentry___288 *);
	int (*mknod)(struct inode___288 *, struct dentry___288 *, umode_t, dev_t);
	int (*rename)(struct inode___288 *, struct dentry___288 *, struct inode___288 *, struct dentry___288 *, unsigned int);
	int (*setattr)(struct dentry___288 *, struct iattr___287 *);
	int (*getattr)(const struct path___288 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___288 *, char *, size_t);
	int (*fiemap)(struct inode___288 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___288 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___288 *, struct dentry___288 *, struct file___288 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___288 *, struct dentry___288 *, umode_t);
	int (*set_acl)(struct inode___288 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___287 {
	void (*fl_copy_lock)(struct file_lock___288 *, struct file_lock___288 *);
	void (*fl_release_private)(struct file_lock___288 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___287;

struct lock_manager_operations___287;

struct file_lock___288 {
	struct file_lock___288 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___288 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___287 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___287 *fl_ops;
	const struct lock_manager_operations___287 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___287 {
	int (*lm_compare_owner)(struct file_lock___288 *, struct file_lock___288 *);
	long unsigned int (*lm_owner_key)(struct file_lock___288 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___288 *);
	int (*lm_grant)(struct file_lock___288 *, int);
	bool (*lm_break)(struct file_lock___288 *);
	int (*lm_change)(struct file_lock___288 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___288 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___287 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___287 *fa_next;
	struct file___288 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___287 {
	const char *name;
	int fs_flags;
	struct dentry___288 * (*mount)(struct file_system_type___287 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___287 *);
	struct module___11 *owner;
	struct file_system_type___287 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___287 {
	struct inode___288 * (*alloc_inode)(struct super_block___287 *);
	void (*destroy_inode)(struct inode___288 *);
	void (*dirty_inode)(struct inode___288 *, int);
	int (*write_inode)(struct inode___288 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___288 *);
	void (*evict_inode)(struct inode___288 *);
	void (*put_super)(struct super_block___287 *);
	int (*sync_fs)(struct super_block___287 *, int);
	int (*freeze_super)(struct super_block___287 *);
	int (*freeze_fs)(struct super_block___287 *);
	int (*thaw_super)(struct super_block___287 *);
	int (*unfreeze_fs)(struct super_block___287 *);
	int (*statfs)(struct dentry___288 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___287 *, int *, char *);
	void (*umount_begin)(struct super_block___287 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___288 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___288 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___288 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___288 *);
	ssize_t (*quota_read)(struct super_block___287 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___287 *, int, const char *, size_t, loff_t);
	struct dquot___287 ** (*get_dquots)(struct inode___288 *);
	int (*bdev_try_to_free_page)(struct super_block___287 *, struct page___289 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___287 *, struct shrink_control___116 *);
	long int (*free_cached_objects)(struct super_block___287 *, struct shrink_control___116 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___277(struct page___289 *);

struct property___48 {
	char *name;
	int length;
	void *value;
	struct property___48 *next;
	long unsigned int _flags;
	struct bin_attribute___251 attr;
};

enum pci_mmap_api {
	PCI_MMAP_SYSFS = 0,
	PCI_MMAP_PROCFS = 1,
};

enum pci_lost_interrupt_reason {
	PCI_LOST_IRQ_NO_INFORMATION = 0,
	PCI_LOST_IRQ_DISABLE_MSI = 1,
	PCI_LOST_IRQ_DISABLE_MSIX = 2,
	PCI_LOST_IRQ_DISABLE_ACPI = 3,
};

struct file___289;

struct kiocb___289;

struct vm_area_struct___290;

struct inode___289;

struct file_lock___289;

struct page___290;

struct file_operations___289 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___289 *, loff_t, int);
	ssize_t (*read)(struct file___289 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___289 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___289 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___289 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___289 *, bool);
	int (*iterate)(struct file___289 *, struct dir_context *);
	int (*iterate_shared)(struct file___289 *, struct dir_context *);
	__poll_t (*poll)(struct file___289 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___289 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___289 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___289 *, struct vm_area_struct___290 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___289 *, struct file___289 *);
	int (*flush)(struct file___289 *, fl_owner_t);
	int (*release)(struct inode___289 *, struct file___289 *);
	int (*fsync)(struct file___289 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___289 *, int);
	int (*lock)(struct file___289 *, int, struct file_lock___289 *);
	ssize_t (*sendpage)(struct file___289 *, struct page___290 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___289 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___289 *, int, struct file_lock___289 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___289 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___289 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___289 *, long int, struct file_lock___289 **, void **);
	long int (*fallocate)(struct file___289 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___289 *);
	ssize_t (*copy_file_range)(struct file___289 *, loff_t, struct file___289 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___289 *, loff_t, struct file___289 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___289 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___289 {
	u64 seqnum;
	struct vm_area_struct___290 *vmas[4];
};

struct page_frag___289 {
	struct page___290 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___289;

struct cred___269;

struct signal_struct___221;

struct vm_struct___205;

struct task_struct___290 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___290 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___289 *mm;
	struct mm_struct___289 *active_mm;
	struct vmacache___289 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___290 *real_parent;
	struct task_struct___290 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___290 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___195 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___195 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___195 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___269 *ptracer_cred;
	const struct cred___269 *real_cred;
	const struct cred___269 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___221 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___290 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___82 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___289 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___290 *oom_reaper_list;
	struct vm_struct___205 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___130 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___290 *pgtable_t___289;

struct address_space___288;

struct dev_pagemap___278;

struct page___290 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___288 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___290 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___289 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___289 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___278 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___289;

struct lruvec___289 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___289 *pgdat;
};

struct zone___289 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___289 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___289 {
	struct zone___289 *zone;
	int zone_idx;
};

struct zonelist___289 {
	struct zoneref___289 _zonerefs[25];
};

struct pglist_data___289 {
	struct zone___289 node_zones[3];
	struct zonelist___289 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___290 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___290 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___289 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___290 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___290 *owner;
};

struct secondary_data___290 {
	void *stack;
	struct task_struct___290 *task;
	long int status;
};

struct blocking_notifier_head___289 {
	struct rw_semaphore___290 rwsem;
	struct notifier_block *head;
};

struct kernfs_root___282;

struct kernfs_elem_dir___282 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___282 *root;
};

struct kernfs_node___283;

struct kernfs_syscall_ops___282;

struct kernfs_root___282 {
	struct kernfs_node___283 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___282 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___282 {
	struct kernfs_node___283 *target_kn;
};

struct kernfs_ops___282;

struct kernfs_elem_attr___282 {
	const struct kernfs_ops___282 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___283 *notify_next;
};

struct kernfs_node___283 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___283 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___282 dir;
		struct kernfs_elem_symlink___282 symlink;
		struct kernfs_elem_attr___282 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___282;

struct kernfs_ops___282 {
	int (*open)(struct kernfs_open_file___282 *);
	void (*release)(struct kernfs_open_file___282 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___282 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___282 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___282 *, struct vm_area_struct___290 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___282 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___282 {
	int (*remount_fs)(struct kernfs_root___282 *, int *, char *);
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___282 *);
	int (*mkdir)(struct kernfs_node___283 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___283 *);
	int (*rename)(struct kernfs_node___283 *, struct kernfs_node___283 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___283 *, struct kernfs_root___282 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_operations_struct___278;

struct kernfs_open_file___282 {
	struct kernfs_node___283 *kn;
	struct file___289 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___278 *vm_ops;
};

struct dentry___289;

struct path___289 {
	struct vfsmount *mnt;
	struct dentry___289 *dentry;
};

struct file___289 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___289 f_path;
	struct inode___289 *f_inode;
	const struct file_operations___289 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___195 f_owner;
	const struct cred___269 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___288 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___278;

struct vm_operations_struct___278 {
	void (*open)(struct vm_area_struct___290 *);
	void (*close)(struct vm_area_struct___290 *);
	int (*split)(struct vm_area_struct___290 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___290 *);
	vm_fault_t (*fault)(struct vm_fault___278 *);
	vm_fault_t (*huge_fault)(struct vm_fault___278 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___278 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___290 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___278 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___278 *);
	int (*access)(struct vm_area_struct___290 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___290 *);
	int (*set_policy)(struct vm_area_struct___290 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___290 *, long unsigned int);
	struct page___290 * (*find_special_page)(struct vm_area_struct___290 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_area_struct___290 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___290 *vm_next;
	struct vm_area_struct___290 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___289 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___278 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___289 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___276;

struct bin_attribute___252;

struct attribute_group___253 {
	const char *name;
	umode_t (*is_visible)(struct kobject___276 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___276 *, struct bin_attribute___252 *, int);
	struct attribute **attrs;
	struct bin_attribute___252 **bin_attrs;
};

struct kset___275;

struct kobj_type___275;

struct kobject___276 {
	const char *name;
	struct list_head entry;
	struct kobject___276 *parent;
	struct kset___275 *kset;
	struct kobj_type___275 *ktype;
	struct kernfs_node___283 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___252 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___289 *, struct kobject___276 *, struct bin_attribute___252 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___289 *, struct kobject___276 *, struct bin_attribute___252 *, char *, loff_t, size_t);
	int (*mmap)(struct file___289 *, struct kobject___276 *, struct bin_attribute___252 *, struct vm_area_struct___290 *);
};

struct sysfs_ops___275 {
	ssize_t (*show)(struct kobject___276 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___276 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___275;

struct kset___275 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___276 kobj;
	const struct kset_uevent_ops___275 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___275 {
	void (*release)(struct kobject___276 *);
	const struct sysfs_ops___275 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___25 * (*child_ns_type)(struct kobject___276 *);
	const void * (*namespace)(struct kobject___276 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___275 {
	int (* const filter)(struct kset___275 *, struct kobject___276 *);
	const char * (* const name)(struct kset___275 *, struct kobject___276 *);
	int (* const uevent)(struct kset___275 *, struct kobject___276 *, struct kobj_uevent_env *);
};

struct kobj_attribute___268 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___276 *, struct kobj_attribute___268 *, char *);
	ssize_t (*store)(struct kobject___276 *, struct kobj_attribute___268 *, const char *, size_t);
};

struct device___254;

struct dev_pm_ops___254 {
	int (*prepare)(struct device___254 *);
	void (*complete)(struct device___254 *);
	int (*suspend)(struct device___254 *);
	int (*resume)(struct device___254 *);
	int (*freeze)(struct device___254 *);
	int (*thaw)(struct device___254 *);
	int (*poweroff)(struct device___254 *);
	int (*restore)(struct device___254 *);
	int (*suspend_late)(struct device___254 *);
	int (*resume_early)(struct device___254 *);
	int (*freeze_late)(struct device___254 *);
	int (*thaw_early)(struct device___254 *);
	int (*poweroff_late)(struct device___254 *);
	int (*restore_early)(struct device___254 *);
	int (*suspend_noirq)(struct device___254 *);
	int (*resume_noirq)(struct device___254 *);
	int (*freeze_noirq)(struct device___254 *);
	int (*thaw_noirq)(struct device___254 *);
	int (*poweroff_noirq)(struct device___254 *);
	int (*restore_noirq)(struct device___254 *);
	int (*runtime_suspend)(struct device___254 *);
	int (*runtime_resume)(struct device___254 *);
	int (*runtime_idle)(struct device___254 *);
};

struct dev_pm_info___254 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___254 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___254;

struct bus_type___254;

struct device_driver___254;

struct dev_pm_domain___254;

struct dma_map_ops___76;

struct fwnode_handle___188;

struct class___254;

struct device___254 {
	struct device___254 *parent;
	struct device_private *p;
	struct kobject___276 kobj;
	const char *init_name;
	const struct device_type___254 *type;
	struct mutex mutex;
	struct bus_type___254 *bus;
	struct device_driver___254 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___254 power;
	struct dev_pm_domain___254 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___76 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___188 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___254 *class;
	const struct attribute_group___253 **groups;
	void (*release)(struct device___254 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___254 {
	struct dev_pm_ops___254 ops;
	void (*detach)(struct device___254 *, bool);
	int (*activate)(struct device___254 *);
	void (*sync)(struct device___254 *);
	void (*dismiss)(struct device___254 *);
};

struct key___269;

struct user_struct___269 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___269 *uid_keyring;
	struct key___269 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___289;

struct mm_struct___289 {
	struct {
		struct vm_area_struct___290 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___289 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___290 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___289 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___290 *owner;
		struct user_namespace___3 *user_ns;
		struct file___289 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___289 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___269 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___269 *session_keyring;
	struct key___269 *process_keyring;
	struct key___269 *thread_keyring;
	struct key___269 *request_key_auth;
	void *security;
	struct user_struct___269 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct signal_struct___221 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___290 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___290 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___195 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___195 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___289 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___195 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_struct___205 {
	struct vm_struct___205 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___290 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___233 {
	struct task_struct___290 task;
	long unsigned int stack[8192];
};

struct bus_type___254 {
	const char *name;
	const char *dev_name;
	struct device___254 *dev_root;
	const struct attribute_group___253 **bus_groups;
	const struct attribute_group___253 **dev_groups;
	const struct attribute_group___253 **drv_groups;
	int (*match)(struct device___254 *, struct device_driver___254 *);
	int (*uevent)(struct device___254 *, struct kobj_uevent_env *);
	int (*probe)(struct device___254 *);
	int (*remove)(struct device___254 *);
	void (*shutdown)(struct device___254 *);
	int (*online)(struct device___254 *);
	int (*offline)(struct device___254 *);
	int (*suspend)(struct device___254 *, pm_message_t);
	int (*resume)(struct device___254 *);
	int (*num_vf)(struct device___254 *);
	int (*dma_configure)(struct device___254 *);
	const struct dev_pm_ops___254 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___254 {
	const char *name;
	struct bus_type___254 *bus;
	struct module___11 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___254 *);
	int (*remove)(struct device___254 *);
	void (*shutdown)(struct device___254 *);
	int (*suspend)(struct device___254 *, pm_message_t);
	int (*resume)(struct device___254 *);
	const struct attribute_group___253 **groups;
	const struct dev_pm_ops___254 *pm;
	void (*coredump)(struct device___254 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___254 {
	const char *name;
	const struct attribute_group___253 **groups;
	int (*uevent)(struct device___254 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___254 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___254 *);
	const struct dev_pm_ops___254 *pm;
};

struct class___254 {
	const char *name;
	struct module___11 *owner;
	const struct attribute_group___253 **class_groups;
	const struct attribute_group___253 **dev_groups;
	struct kobject___276 *dev_kobj;
	int (*dev_uevent)(struct device___254 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___254 *, umode_t *);
	void (*class_release)(struct class___254 *);
	void (*dev_release)(struct device___254 *);
	int (*shutdown_pre)(struct device___254 *);
	const struct kobj_ns_type_operations___25 *ns_type;
	const void * (*namespace)(struct device___254 *);
	const struct dev_pm_ops___254 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___76 {
	void * (*alloc)(struct device___254 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___254 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___254 *, struct vm_area_struct___290 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___254 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___254 *, struct page___290 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___254 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___254 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___254 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___254 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___254 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___254 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___254 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___254 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___254 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___254 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___254 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___254 *, u64);
	u64 (*get_required_mask)(struct device___254 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___188;

struct fwnode_handle___188 {
	struct fwnode_handle___188 *secondary;
	const struct fwnode_operations___188 *ops;
};

struct address_space_operations___288;

struct address_space___288 {
	struct inode___289 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___290 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___288 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___278)(struct vm_area_struct___290 *, long unsigned int, const struct page___290 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___278)(struct page___290 *, void *);

struct dev_pagemap___278 {
	dev_page_fault_t___278 page_fault;
	dev_page_free_t___278 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___254 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___289 {
	struct task_struct___290 *task;
	struct core_thread___289 *next;
};

struct core_state___289 {
	atomic_t nr_threads;
	struct core_thread___289 dumper;
	struct completion startup;
};

struct vm_fault___278 {
	struct vm_area_struct___290 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___290 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___290 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___289 prealloc_pte;
};

struct fwnode_reference_args___188;

struct fwnode_endpoint___188;

struct fwnode_operations___188 {
	struct fwnode_handle___188 * (*get)(struct fwnode_handle___188 *);
	void (*put)(struct fwnode_handle___188 *);
	bool (*device_is_available)(const struct fwnode_handle___188 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___188 *, const struct device___254 *);
	bool (*property_present)(const struct fwnode_handle___188 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___188 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___188 *, const char *, const char **, size_t);
	struct fwnode_handle___188 * (*get_parent)(const struct fwnode_handle___188 *);
	struct fwnode_handle___188 * (*get_next_child_node)(const struct fwnode_handle___188 *, struct fwnode_handle___188 *);
	struct fwnode_handle___188 * (*get_named_child_node)(const struct fwnode_handle___188 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___188 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___188 *);
	struct fwnode_handle___188 * (*graph_get_next_endpoint)(const struct fwnode_handle___188 *, struct fwnode_handle___188 *);
	struct fwnode_handle___188 * (*graph_get_remote_endpoint)(const struct fwnode_handle___188 *);
	struct fwnode_handle___188 * (*graph_get_port_parent)(struct fwnode_handle___188 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___188 *, struct fwnode_endpoint___188 *);
};

struct fwnode_endpoint___188 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___188 *local_fwnode;
};

struct fwnode_reference_args___188 {
	struct fwnode_handle___188 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pci_bus___11;

struct pci_slot___11 {
	struct pci_bus___11 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject___276 kobj;
};

struct pci_dev___11;

struct pci_ops___11;

struct pci_bus___11 {
	struct list_head node;
	struct pci_bus___11 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___11 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___11 *ops;
	struct msi_controller___2 *msi;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	int domain_nr;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___254 *bridge;
	struct device___254 dev;
	struct bin_attribute___252 *legacy_io;
	struct bin_attribute___252 *legacy_mem;
	unsigned int is_added: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
};

struct pci_sriov___7 {
	int pos;
	int nres;
	u32 cap;
	u16 ctrl;
	u16 total_VFs;
	u16 initial_VFs;
	u16 num_VFs;
	u16 offset;
	u16 stride;
	u16 vf_device;
	u32 pgsz;
	u8 link;
	u8 max_VF_buses;
	u16 driver_max_VFs;
	struct pci_dev___11 *dev;
	struct pci_dev___11 *self;
	u32 class;
	u8 hdr_type;
	u16 subsystem_vendor;
	u16 subsystem_device;
	resource_size_t barsz[6];
	bool drivers_autoprobe;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct pci_driver___11;

struct pci_dev___11 {
	struct list_head bus_list;
	struct pci_bus___11 *bus;
	struct pci_bus___11 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___11 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u16 aer_cap;
	struct aer_stats *aer_stats;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	long unsigned int *dma_alias_mask;
	struct pci_driver___11 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	unsigned int imm_ready: 1;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int bridge_d3: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int hotplug_user_indicators: 1;
	unsigned int clear_retrain_link: 1;
	unsigned int d3_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	unsigned int ltr_path: 1;
	unsigned int eetlp_prefix_path: 1;
	pci_channel_state_t error_state;
	struct device___254 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int multifunction: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int ats_enabled: 1;
	unsigned int pasid_enabled: 1;
	unsigned int pri_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int reset_fn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int shpc_managed: 1;
	unsigned int is_thunderbolt: 1;
	unsigned int __aer_firmware_first_valid: 1;
	unsigned int __aer_firmware_first: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int irq_managed: 1;
	unsigned int has_secondary_link: 1;
	unsigned int non_compliant_bars: 1;
	unsigned int is_probed: 1;
	unsigned int link_active_reporting: 1;
	unsigned int untrusted: 1;
	unsigned int no_vf_scan: 1;
	unsigned int io_window: 1;
	unsigned int pref_window: 1;
	unsigned int pref_64_window: 1;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	struct bin_attribute___252 *rom_attr;
	int rom_attr_enabled;
	struct bin_attribute___252 *res_attr[17];
	struct bin_attribute___252 *res_attr_wc[17];
	unsigned int broken_cmd_compl: 1;
	const struct attribute_group___253 **msi_irq_groups;
	struct pci_vpd *vpd;
	union {
		struct pci_sriov___7 *sriov;
		struct pci_dev___11 *physfn;
	};
	u16 ats_cap;
	u8 ats_stu;
	atomic_t ats_ref_cnt;
	u32 pri_reqs_alloc;
	u16 pasid_features;
	struct pci_p2pdma *p2pdma;
	phys_addr_t rom;
	size_t romlen;
	char *driver_override;
	long unsigned int priv_flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t pci_dev_extended_size_rh;
	struct pci_dev_extended_rh pci_dev_extended_rh;
};

struct pci_error_handlers___11;

struct pci_driver___11 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___11 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___11 *);
	int (*suspend)(struct pci_dev___11 *, pm_message_t);
	int (*suspend_late)(struct pci_dev___11 *, pm_message_t);
	int (*resume_early)(struct pci_dev___11 *);
	int (*resume)(struct pci_dev___11 *);
	void (*shutdown)(struct pci_dev___11 *);
	int (*sriov_configure)(struct pci_dev___11 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	const struct pci_error_handlers___11 *err_handler;
	const struct attribute_group___253 **groups;
	struct device_driver___254 driver;
	struct pci_dynids dynids;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct pci_vpd_ops;

struct pci_vpd {
	const struct pci_vpd_ops *ops;
	struct bin_attribute___252 *attr;
	struct mutex lock;
	unsigned int len;
	u16 flag;
	u8 cap;
	unsigned int busy: 1;
	unsigned int valid: 1;
};

struct pci_ops___11 {
	int (*add_bus)(struct pci_bus___11 *);
	void (*remove_bus)(struct pci_bus___11 *);
	void * (*map_bus)(struct pci_bus___11 *, unsigned int, int);
	int (*read)(struct pci_bus___11 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___11 *, unsigned int, int, int, u32);
};

struct pci_error_handlers___11 {
	pci_ers_result_t (*error_detected)(struct pci_dev___11 *, enum pci_channel_state);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___11 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___11 *);
	void (*reset_prepare)(struct pci_dev___11 *);
	void (*reset_done)(struct pci_dev___11 *);
	void (*resume)(struct pci_dev___11 *);
};

struct dentry_operations___288;

struct super_block___288;

struct dentry___289 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___289 *d_parent;
	struct qstr d_name;
	struct inode___289 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___288 *d_op;
	struct super_block___288 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___288;

struct block_device___288;

struct inode___289 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___288 *i_op;
	struct super_block___288 *i_sb;
	struct address_space___288 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___290 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___289 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___288 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___288 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___288 {
	int (*d_revalidate)(struct dentry___289 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___289 *, unsigned int);
	int (*d_hash)(const struct dentry___289 *, struct qstr *);
	int (*d_compare)(const struct dentry___289 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___289 *);
	int (*d_init)(struct dentry___289 *);
	void (*d_release)(struct dentry___289 *);
	void (*d_prune)(struct dentry___289 *);
	void (*d_iput)(struct dentry___289 *, struct inode___289 *);
	char * (*d_dname)(struct dentry___289 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___289 *);
	int (*d_manage)(const struct path___289 *, bool);
	struct dentry___289 * (*d_real)(struct dentry___289 *, const struct inode___289 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___288;

struct mem_dqinfo___288 {
	struct quota_format_type___288 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___288;

struct quota_info___288 {
	unsigned int flags;
	struct rw_semaphore___290 dqio_sem;
	struct inode___289 *files[3];
	struct mem_dqinfo___288 info[3];
	const struct quota_format_ops___288 *ops[3];
};

struct rcuwait___288 {
	struct task_struct___290 *task;
};

struct percpu_rw_semaphore___288 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___290 rw_sem;
	struct rcuwait___288 writer;
	int readers_block;
};

struct sb_writers___288 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___288 rw_sem[3];
};

struct file_system_type___288;

struct super_operations___288;

struct dquot_operations___288;

struct quotactl_ops___288;

struct super_block___288 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___288 *s_type;
	const struct super_operations___288 *s_op;
	const struct dquot_operations___288 *dq_op;
	const struct quotactl_ops___288 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___289 *s_root;
	struct rw_semaphore___290 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___288 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___288 s_dquot;
	struct sb_writers___288 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___288 *s_d_op;
	int cleancache_poolid;
	struct shrinker___116 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___289 {
	struct file___289 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___289 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___288 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___289 *ia_file;
};

struct dquot___288 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___288 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___288 {
	int qf_fmt_id;
	const struct quota_format_ops___288 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___288 *qf_next;
};

struct quota_format_ops___288 {
	int (*check_quota_file)(struct super_block___288 *, int);
	int (*read_file_info)(struct super_block___288 *, int);
	int (*write_file_info)(struct super_block___288 *, int);
	int (*free_file_info)(struct super_block___288 *, int);
	int (*read_dqblk)(struct dquot___288 *);
	int (*commit_dqblk)(struct dquot___288 *);
	int (*release_dqblk)(struct dquot___288 *);
	int (*get_next_id)(struct super_block___288 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___288 {
	int (*write_dquot)(struct dquot___288 *);
	struct dquot___288 * (*alloc_dquot)(struct super_block___288 *, int);
	void (*destroy_dquot)(struct dquot___288 *);
	int (*acquire_dquot)(struct dquot___288 *);
	int (*release_dquot)(struct dquot___288 *);
	int (*mark_dirty)(struct dquot___288 *);
	int (*write_info)(struct super_block___288 *, int);
	qsize_t * (*get_reserved_space)(struct inode___289 *);
	int (*get_projid)(struct inode___289 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___289 *, qsize_t *);
	int (*get_next_id)(struct super_block___288 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___288 {
	int (*quota_on)(struct super_block___288 *, int, int, const struct path___289 *);
	int (*quota_off)(struct super_block___288 *, int);
	int (*quota_enable)(struct super_block___288 *, unsigned int);
	int (*quota_disable)(struct super_block___288 *, unsigned int);
	int (*quota_sync)(struct super_block___288 *, int);
	int (*set_info)(struct super_block___288 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___288 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___288 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___288 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___288 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___288 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___288 {
	int (*writepage)(struct page___290 *, struct writeback_control___3 *);
	int (*readpage)(struct file___289 *, struct page___290 *);
	int (*writepages)(struct address_space___288 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___290 *);
	int (*readpages)(struct file___289 *, struct address_space___288 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___289 *, struct address_space___288 *, loff_t, unsigned int, unsigned int, struct page___290 **, void **);
	int (*write_end)(struct file___289 *, struct address_space___288 *, loff_t, unsigned int, unsigned int, struct page___290 *, void *);
	sector_t (*bmap)(struct address_space___288 *, sector_t);
	void (*invalidatepage)(struct page___290 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___290 *, gfp_t);
	void (*freepage)(struct page___290 *);
	ssize_t (*direct_IO)(struct kiocb___289 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___288 *, struct page___290 *, struct page___290 *, enum migrate_mode);
	bool (*isolate_page)(struct page___290 *, isolate_mode_t);
	void (*putback_page)(struct page___290 *);
	int (*launder_page)(struct page___290 *);
	int (*is_partially_uptodate)(struct page___290 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___290 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___288 *, struct page___290 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___289 *, sector_t *);
	void (*swap_deactivate)(struct file___289 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___288 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___289 *bd_inode;
	struct super_block___288 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___288 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___288 {
	struct dentry___289 * (*lookup)(struct inode___289 *, struct dentry___289 *, unsigned int);
	const char * (*get_link)(struct dentry___289 *, struct inode___289 *, struct delayed_call *);
	int (*permission)(struct inode___289 *, int);
	struct posix_acl * (*get_acl)(struct inode___289 *, int);
	int (*readlink)(struct dentry___289 *, char *, int);
	int (*create)(struct inode___289 *, struct dentry___289 *, umode_t, bool);
	int (*link)(struct dentry___289 *, struct inode___289 *, struct dentry___289 *);
	int (*unlink)(struct inode___289 *, struct dentry___289 *);
	int (*symlink)(struct inode___289 *, struct dentry___289 *, const char *);
	int (*mkdir)(struct inode___289 *, struct dentry___289 *, umode_t);
	int (*rmdir)(struct inode___289 *, struct dentry___289 *);
	int (*mknod)(struct inode___289 *, struct dentry___289 *, umode_t, dev_t);
	int (*rename)(struct inode___289 *, struct dentry___289 *, struct inode___289 *, struct dentry___289 *, unsigned int);
	int (*setattr)(struct dentry___289 *, struct iattr___288 *);
	int (*getattr)(const struct path___289 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___289 *, char *, size_t);
	int (*fiemap)(struct inode___289 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___289 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___289 *, struct dentry___289 *, struct file___289 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___289 *, struct dentry___289 *, umode_t);
	int (*set_acl)(struct inode___289 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___288 {
	void (*fl_copy_lock)(struct file_lock___289 *, struct file_lock___289 *);
	void (*fl_release_private)(struct file_lock___289 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___288;

struct lock_manager_operations___288;

struct file_lock___289 {
	struct file_lock___289 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___289 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___288 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___288 *fl_ops;
	const struct lock_manager_operations___288 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___288 {
	int (*lm_compare_owner)(struct file_lock___289 *, struct file_lock___289 *);
	long unsigned int (*lm_owner_key)(struct file_lock___289 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___289 *);
	int (*lm_grant)(struct file_lock___289 *, int);
	bool (*lm_break)(struct file_lock___289 *);
	int (*lm_change)(struct file_lock___289 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___289 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___288 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___288 *fa_next;
	struct file___289 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___288 {
	const char *name;
	int fs_flags;
	struct dentry___289 * (*mount)(struct file_system_type___288 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___288 *);
	struct module___11 *owner;
	struct file_system_type___288 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___288 {
	struct inode___289 * (*alloc_inode)(struct super_block___288 *);
	void (*destroy_inode)(struct inode___289 *);
	void (*dirty_inode)(struct inode___289 *, int);
	int (*write_inode)(struct inode___289 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___289 *);
	void (*evict_inode)(struct inode___289 *);
	void (*put_super)(struct super_block___288 *);
	int (*sync_fs)(struct super_block___288 *, int);
	int (*freeze_super)(struct super_block___288 *);
	int (*freeze_fs)(struct super_block___288 *);
	int (*thaw_super)(struct super_block___288 *);
	int (*unfreeze_fs)(struct super_block___288 *);
	int (*statfs)(struct dentry___289 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___288 *, int *, char *);
	void (*umount_begin)(struct super_block___288 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___289 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___289 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___289 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___289 *);
	ssize_t (*quota_read)(struct super_block___288 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___288 *, int, const char *, size_t, loff_t);
	struct dquot___288 ** (*get_dquots)(struct inode___289 *);
	int (*bdev_try_to_free_page)(struct super_block___288 *, struct page___290 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___288 *, struct shrink_control___116 *);
	long int (*free_cached_objects)(struct super_block___288 *, struct shrink_control___116 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___278(struct page___290 *);

struct pci_fixup {
	u16 vendor;
	u16 device;
	u32 class;
	unsigned int class_shift;
	void (*hook)(struct pci_dev___11 *);
};

typedef int (*key_restrict_link_func_t___270)(struct key___269 *, const struct key_type *, const union key_payload *, struct key___269 *);

struct key_restriction___269;

struct key___269 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___290 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___269 *restrict_link;
};

struct key_restriction___269 {
	key_restrict_link_func_t___270 check;
	struct key___269 *key;
	struct key_type *keytype;
};

struct pci_vpd_ops {
	ssize_t (*read)(struct pci_dev___11 *, loff_t, size_t, void *);
	ssize_t (*write)(struct pci_dev___11 *, loff_t, size_t, const void *);
	int (*set_size)(struct pci_dev___11 *, size_t);
};

struct module___233;

struct file___290;

struct kiocb___290;

struct poll_table_struct___175;

struct vm_area_struct___291;

struct inode___290;

struct file_lock___290;

struct page___291;

struct seq_file___248;

struct file_operations___290 {
	struct module___233 *owner;
	loff_t (*llseek)(struct file___290 *, loff_t, int);
	ssize_t (*read)(struct file___290 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___290 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___290 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___290 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___290 *, bool);
	int (*iterate)(struct file___290 *, struct dir_context *);
	int (*iterate_shared)(struct file___290 *, struct dir_context *);
	__poll_t (*poll)(struct file___290 *, struct poll_table_struct___175 *);
	long int (*unlocked_ioctl)(struct file___290 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___290 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___290 *, struct vm_area_struct___291 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___290 *, struct file___290 *);
	int (*flush)(struct file___290 *, fl_owner_t);
	int (*release)(struct inode___290 *, struct file___290 *);
	int (*fsync)(struct file___290 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___290 *, int);
	int (*lock)(struct file___290 *, int, struct file_lock___290 *);
	ssize_t (*sendpage)(struct file___290 *, struct page___291 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___290 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___290 *, int, struct file_lock___290 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___290 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___290 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___290 *, long int, struct file_lock___290 **, void **);
	long int (*fallocate)(struct file___290 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___248 *, struct file___290 *);
	ssize_t (*copy_file_range)(struct file___290 *, loff_t, struct file___290 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___290 *, loff_t, struct file___290 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___290 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___290 {
	u64 seqnum;
	struct vm_area_struct___291 *vmas[4];
};

struct page_frag___290 {
	struct page___291 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___290;

struct cred___270;

struct vm_struct___206;

struct task_struct___291 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___291 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___290 *mm;
	struct mm_struct___290 *active_mm;
	struct vmacache___290 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___291 *real_parent;
	struct task_struct___291 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___291 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___195 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___195 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___195 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___270 *ptracer_cred;
	const struct cred___270 *real_cred;
	const struct cred___270 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___291 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___82 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___290 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___291 *oom_reaper_list;
	struct vm_struct___206 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___130 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___291 *pgtable_t___290;

struct address_space___289;

struct dev_pagemap___279;

struct page___291 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___289 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___291 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___290 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___290 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___279 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___290;

struct lruvec___290 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___290 *pgdat;
};

struct zone___290 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___290 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___290 {
	struct zone___290 *zone;
	int zone_idx;
};

struct zonelist___290 {
	struct zoneref___290 _zonerefs[25];
};

struct pglist_data___290 {
	struct zone___290 node_zones[3];
	struct zonelist___290 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___291 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___291 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___290 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___291 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___291 *owner;
};

struct secondary_data___291 {
	void *stack;
	struct task_struct___291 *task;
	long int status;
};

struct blocking_notifier_head___290 {
	struct rw_semaphore___291 rwsem;
	struct notifier_block *head;
};

struct dentry___290;

struct path___290 {
	struct vfsmount *mnt;
	struct dentry___290 *dentry;
};

struct file___290 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___290 f_path;
	struct inode___290 *f_inode;
	const struct file_operations___290 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___195 f_owner;
	const struct cred___270 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___289 *f_mapping;
	errseq_t f_wb_err;
};

struct key___270;

struct user_struct___270;

struct cred___270 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___270 *session_keyring;
	struct key___270 *process_keyring;
	struct key___270 *thread_keyring;
	struct key___270 *request_key_auth;
	void *security;
	struct user_struct___270 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___283;

struct kernfs_elem_dir___283 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___283 *root;
};

struct kernfs_node___284;

struct kernfs_syscall_ops___283;

struct kernfs_root___283 {
	struct kernfs_node___284 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___283 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___283 {
	struct kernfs_node___284 *target_kn;
};

struct kernfs_ops___283;

struct kernfs_elem_attr___283 {
	const struct kernfs_ops___283 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___284 *notify_next;
};

struct kernfs_node___284 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___284 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___283 dir;
		struct kernfs_elem_symlink___283 symlink;
		struct kernfs_elem_attr___283 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___283;

struct kernfs_ops___283 {
	int (*open)(struct kernfs_open_file___283 *);
	void (*release)(struct kernfs_open_file___283 *);
	int (*seq_show)(struct seq_file___248 *, void *);
	void * (*seq_start)(struct seq_file___248 *, loff_t *);
	void * (*seq_next)(struct seq_file___248 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___248 *, void *);
	ssize_t (*read)(struct kernfs_open_file___283 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___283 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___283 *, struct vm_area_struct___291 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___283 *, struct poll_table_struct___175 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___283 {
	int (*remount_fs)(struct kernfs_root___283 *, int *, char *);
	int (*show_options)(struct seq_file___248 *, struct kernfs_root___283 *);
	int (*mkdir)(struct kernfs_node___284 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___284 *);
	int (*rename)(struct kernfs_node___284 *, struct kernfs_node___284 *, const char *);
	int (*show_path)(struct seq_file___248 *, struct kernfs_node___284 *, struct kernfs_root___283 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___247;

struct seq_file___248 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___247 *op;
	int poll_event;
	const struct file___290 *file;
	void *private;
};

struct vm_operations_struct___279;

struct kernfs_open_file___283 {
	struct kernfs_node___284 *kn;
	struct file___290 *file;
	struct seq_file___248 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___279 *vm_ops;
};

struct vm_fault___279;

struct vm_operations_struct___279 {
	void (*open)(struct vm_area_struct___291 *);
	void (*close)(struct vm_area_struct___291 *);
	int (*split)(struct vm_area_struct___291 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___291 *);
	vm_fault_t (*fault)(struct vm_fault___279 *);
	vm_fault_t (*huge_fault)(struct vm_fault___279 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___279 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___291 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___279 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___279 *);
	int (*access)(struct vm_area_struct___291 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___291 *);
	int (*set_policy)(struct vm_area_struct___291 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___291 *, long unsigned int);
	struct page___291 * (*find_special_page)(struct vm_area_struct___291 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___178)(struct file___290 *, wait_queue_head_t *, struct poll_table_struct___175 *);

struct poll_table_struct___175 {
	poll_queue_proc___178 _qproc;
	__poll_t _key;
};

struct vm_area_struct___291 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___291 *vm_next;
	struct vm_area_struct___291 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___290 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___279 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___290 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___277;

struct bin_attribute___253;

struct attribute_group___254 {
	const char *name;
	umode_t (*is_visible)(struct kobject___277 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___277 *, struct bin_attribute___253 *, int);
	struct attribute **attrs;
	struct bin_attribute___253 **bin_attrs;
};

struct kset___276;

struct kobj_type___276;

struct kobject___277 {
	const char *name;
	struct list_head entry;
	struct kobject___277 *parent;
	struct kset___276 *kset;
	struct kobj_type___276 *ktype;
	struct kernfs_node___284 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___253 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___290 *, struct kobject___277 *, struct bin_attribute___253 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___290 *, struct kobject___277 *, struct bin_attribute___253 *, char *, loff_t, size_t);
	int (*mmap)(struct file___290 *, struct kobject___277 *, struct bin_attribute___253 *, struct vm_area_struct___291 *);
};

struct sysfs_ops___276 {
	ssize_t (*show)(struct kobject___277 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___277 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___276;

struct kset___276 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___277 kobj;
	const struct kset_uevent_ops___276 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___276 {
	void (*release)(struct kobject___277 *);
	const struct sysfs_ops___276 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___25 * (*child_ns_type)(struct kobject___277 *);
	const void * (*namespace)(struct kobject___277 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___276 {
	int (* const filter)(struct kset___276 *, struct kobject___277 *);
	const char * (* const name)(struct kset___276 *, struct kobject___277 *);
	int (* const uevent)(struct kset___276 *, struct kobject___277 *, struct kobj_uevent_env *);
};

struct kobj_attribute___269 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___277 *, struct kobj_attribute___269 *, char *);
	ssize_t (*store)(struct kobject___277 *, struct kobj_attribute___269 *, const char *, size_t);
};

struct kernel_param___230;

struct kernel_param_ops___230 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___230 *);
	int (*get)(char *, const struct kernel_param___230 *);
	void (*free)(void *);
};

struct kparam_array___230;

struct kernel_param___230 {
	const char *name;
	struct module___233 *mod;
	const struct kernel_param_ops___230 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___230 *arr;
	};
};

struct kparam_array___230 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___230 *ops;
	void *elem;
};

struct module_kobject___230 {
	struct kobject___277 kobj;
	struct module___233 *mod;
	struct kobject___277 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___230 {
	struct module___233 *mod;
	struct latch_tree_node node;
};

struct module_layout___230 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___230 mtn;
};

struct module_attribute___230;

struct module___233 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___230 mkobj;
	struct module_attribute___230 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___277 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___230 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___230 core_layout;
	struct module_layout___230 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___230 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___230 *, struct module_kobject___230 *, char *);
	ssize_t (*store)(struct module_attribute___230 *, struct module_kobject___230 *, const char *, size_t);
	void (*setup)(struct module___233 *, const char *);
	int (*test)(struct module___233 *);
	void (*free)(struct module___233 *);
};

struct device___255;

struct dev_pm_ops___255 {
	int (*prepare)(struct device___255 *);
	void (*complete)(struct device___255 *);
	int (*suspend)(struct device___255 *);
	int (*resume)(struct device___255 *);
	int (*freeze)(struct device___255 *);
	int (*thaw)(struct device___255 *);
	int (*poweroff)(struct device___255 *);
	int (*restore)(struct device___255 *);
	int (*suspend_late)(struct device___255 *);
	int (*resume_early)(struct device___255 *);
	int (*freeze_late)(struct device___255 *);
	int (*thaw_early)(struct device___255 *);
	int (*poweroff_late)(struct device___255 *);
	int (*restore_early)(struct device___255 *);
	int (*suspend_noirq)(struct device___255 *);
	int (*resume_noirq)(struct device___255 *);
	int (*freeze_noirq)(struct device___255 *);
	int (*thaw_noirq)(struct device___255 *);
	int (*poweroff_noirq)(struct device___255 *);
	int (*restore_noirq)(struct device___255 *);
	int (*runtime_suspend)(struct device___255 *);
	int (*runtime_resume)(struct device___255 *);
	int (*runtime_idle)(struct device___255 *);
};

struct dev_pm_info___255 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___255 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___255;

struct bus_type___255;

struct device_driver___255;

struct dev_pm_domain___255;

struct dma_map_ops___77;

struct fwnode_handle___189;

struct class___255;

struct device___255 {
	struct device___255 *parent;
	struct device_private *p;
	struct kobject___277 kobj;
	const char *init_name;
	const struct device_type___255 *type;
	struct mutex mutex;
	struct bus_type___255 *bus;
	struct device_driver___255 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___255 power;
	struct dev_pm_domain___255 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___77 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___189 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___255 *class;
	const struct attribute_group___254 **groups;
	void (*release)(struct device___255 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___255 {
	struct dev_pm_ops___255 ops;
	void (*detach)(struct device___255 *, bool);
	int (*activate)(struct device___255 *);
	void (*sync)(struct device___255 *);
	void (*dismiss)(struct device___255 *);
};

struct user_struct___270 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___270 *uid_keyring;
	struct key___270 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___290;

struct mm_struct___290 {
	struct {
		struct vm_area_struct___291 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___290 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___291 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___290 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___291 *owner;
		struct user_namespace___3 *user_ns;
		struct file___290 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___290 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct vm_struct___206 {
	struct vm_struct___206 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___291 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bus_type___255 {
	const char *name;
	const char *dev_name;
	struct device___255 *dev_root;
	const struct attribute_group___254 **bus_groups;
	const struct attribute_group___254 **dev_groups;
	const struct attribute_group___254 **drv_groups;
	int (*match)(struct device___255 *, struct device_driver___255 *);
	int (*uevent)(struct device___255 *, struct kobj_uevent_env *);
	int (*probe)(struct device___255 *);
	int (*remove)(struct device___255 *);
	void (*shutdown)(struct device___255 *);
	int (*online)(struct device___255 *);
	int (*offline)(struct device___255 *);
	int (*suspend)(struct device___255 *, pm_message_t);
	int (*resume)(struct device___255 *);
	int (*num_vf)(struct device___255 *);
	int (*dma_configure)(struct device___255 *);
	const struct dev_pm_ops___255 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___255 {
	const char *name;
	struct bus_type___255 *bus;
	struct module___233 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___255 *);
	int (*remove)(struct device___255 *);
	void (*shutdown)(struct device___255 *);
	int (*suspend)(struct device___255 *, pm_message_t);
	int (*resume)(struct device___255 *);
	const struct attribute_group___254 **groups;
	const struct dev_pm_ops___255 *pm;
	void (*coredump)(struct device___255 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___255 {
	const char *name;
	const struct attribute_group___254 **groups;
	int (*uevent)(struct device___255 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___255 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___255 *);
	const struct dev_pm_ops___255 *pm;
};

struct class___255 {
	const char *name;
	struct module___233 *owner;
	const struct attribute_group___254 **class_groups;
	const struct attribute_group___254 **dev_groups;
	struct kobject___277 *dev_kobj;
	int (*dev_uevent)(struct device___255 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___255 *, umode_t *);
	void (*class_release)(struct class___255 *);
	void (*dev_release)(struct device___255 *);
	int (*shutdown_pre)(struct device___255 *);
	const struct kobj_ns_type_operations___25 *ns_type;
	const void * (*namespace)(struct device___255 *);
	const struct dev_pm_ops___255 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___77 {
	void * (*alloc)(struct device___255 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___255 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___255 *, struct vm_area_struct___291 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___255 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___255 *, struct page___291 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___255 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___255 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___255 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___255 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___255 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___255 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___255 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___255 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___255 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___255 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___255 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___255 *, u64);
	u64 (*get_required_mask)(struct device___255 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___189;

struct fwnode_handle___189 {
	struct fwnode_handle___189 *secondary;
	const struct fwnode_operations___189 *ops;
};

struct address_space_operations___289;

struct address_space___289 {
	struct inode___290 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___291 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___289 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___279)(struct vm_area_struct___291 *, long unsigned int, const struct page___291 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___279)(struct page___291 *, void *);

struct dev_pagemap___279 {
	dev_page_fault_t___279 page_fault;
	dev_page_free_t___279 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___255 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___290 {
	struct task_struct___291 *task;
	struct core_thread___290 *next;
};

struct core_state___290 {
	atomic_t nr_threads;
	struct core_thread___290 dumper;
	struct completion startup;
};

struct vm_fault___279 {
	struct vm_area_struct___291 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___291 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___291 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___290 prealloc_pte;
};

struct fwnode_reference_args___189;

struct fwnode_endpoint___189;

struct fwnode_operations___189 {
	struct fwnode_handle___189 * (*get)(struct fwnode_handle___189 *);
	void (*put)(struct fwnode_handle___189 *);
	bool (*device_is_available)(const struct fwnode_handle___189 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___189 *, const struct device___255 *);
	bool (*property_present)(const struct fwnode_handle___189 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___189 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___189 *, const char *, const char **, size_t);
	struct fwnode_handle___189 * (*get_parent)(const struct fwnode_handle___189 *);
	struct fwnode_handle___189 * (*get_next_child_node)(const struct fwnode_handle___189 *, struct fwnode_handle___189 *);
	struct fwnode_handle___189 * (*get_named_child_node)(const struct fwnode_handle___189 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___189 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___189 *);
	struct fwnode_handle___189 * (*graph_get_next_endpoint)(const struct fwnode_handle___189 *, struct fwnode_handle___189 *);
	struct fwnode_handle___189 * (*graph_get_remote_endpoint)(const struct fwnode_handle___189 *);
	struct fwnode_handle___189 * (*graph_get_port_parent)(struct fwnode_handle___189 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___189 *, struct fwnode_endpoint___189 *);
};

struct fwnode_endpoint___189 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___189 *local_fwnode;
};

struct fwnode_reference_args___189 {
	struct fwnode_handle___189 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pci_bus___12;

struct pci_slot___12 {
	struct pci_bus___12 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject___277 kobj;
};

struct pci_dev___12;

struct pci_ops___12;

struct pci_bus___12 {
	struct list_head node;
	struct pci_bus___12 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___12 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___12 *ops;
	struct msi_controller___2 *msi;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	int domain_nr;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___255 *bridge;
	struct device___255 dev;
	struct bin_attribute___253 *legacy_io;
	struct bin_attribute___253 *legacy_mem;
	unsigned int is_added: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
};

struct pci_sriov___8 {
	int pos;
	int nres;
	u32 cap;
	u16 ctrl;
	u16 total_VFs;
	u16 initial_VFs;
	u16 num_VFs;
	u16 offset;
	u16 stride;
	u16 vf_device;
	u32 pgsz;
	u8 link;
	u8 max_VF_buses;
	u16 driver_max_VFs;
	struct pci_dev___12 *dev;
	struct pci_dev___12 *self;
	u32 class;
	u8 hdr_type;
	u16 subsystem_vendor;
	u16 subsystem_device;
	resource_size_t barsz[6];
	bool drivers_autoprobe;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct pci_driver___12;

struct pci_dev___12 {
	struct list_head bus_list;
	struct pci_bus___12 *bus;
	struct pci_bus___12 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___12 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u16 aer_cap;
	struct aer_stats *aer_stats;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	long unsigned int *dma_alias_mask;
	struct pci_driver___12 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	unsigned int imm_ready: 1;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int bridge_d3: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int hotplug_user_indicators: 1;
	unsigned int clear_retrain_link: 1;
	unsigned int d3_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	unsigned int ltr_path: 1;
	unsigned int eetlp_prefix_path: 1;
	pci_channel_state_t error_state;
	struct device___255 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int multifunction: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int ats_enabled: 1;
	unsigned int pasid_enabled: 1;
	unsigned int pri_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int reset_fn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int shpc_managed: 1;
	unsigned int is_thunderbolt: 1;
	unsigned int __aer_firmware_first_valid: 1;
	unsigned int __aer_firmware_first: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int irq_managed: 1;
	unsigned int has_secondary_link: 1;
	unsigned int non_compliant_bars: 1;
	unsigned int is_probed: 1;
	unsigned int link_active_reporting: 1;
	unsigned int untrusted: 1;
	unsigned int no_vf_scan: 1;
	unsigned int io_window: 1;
	unsigned int pref_window: 1;
	unsigned int pref_64_window: 1;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	struct bin_attribute___253 *rom_attr;
	int rom_attr_enabled;
	struct bin_attribute___253 *res_attr[17];
	struct bin_attribute___253 *res_attr_wc[17];
	unsigned int broken_cmd_compl: 1;
	const struct attribute_group___254 **msi_irq_groups;
	struct pci_vpd *vpd;
	union {
		struct pci_sriov___8 *sriov;
		struct pci_dev___12 *physfn;
	};
	u16 ats_cap;
	u8 ats_stu;
	atomic_t ats_ref_cnt;
	u32 pri_reqs_alloc;
	u16 pasid_features;
	struct pci_p2pdma *p2pdma;
	phys_addr_t rom;
	size_t romlen;
	char *driver_override;
	long unsigned int priv_flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t pci_dev_extended_size_rh;
	struct pci_dev_extended_rh pci_dev_extended_rh;
};

struct pci_error_handlers___12;

struct pci_driver___12 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___12 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___12 *);
	int (*suspend)(struct pci_dev___12 *, pm_message_t);
	int (*suspend_late)(struct pci_dev___12 *, pm_message_t);
	int (*resume_early)(struct pci_dev___12 *);
	int (*resume)(struct pci_dev___12 *);
	void (*shutdown)(struct pci_dev___12 *);
	int (*sriov_configure)(struct pci_dev___12 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	const struct pci_error_handlers___12 *err_handler;
	const struct attribute_group___254 **groups;
	struct device_driver___255 driver;
	struct pci_dynids dynids;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct pci_ops___12 {
	int (*add_bus)(struct pci_bus___12 *);
	void (*remove_bus)(struct pci_bus___12 *);
	void * (*map_bus)(struct pci_bus___12 *, unsigned int, int);
	int (*read)(struct pci_bus___12 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___12 *, unsigned int, int, int, u32);
};

struct pci_error_handlers___12 {
	pci_ers_result_t (*error_detected)(struct pci_dev___12 *, enum pci_channel_state);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___12 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___12 *);
	void (*reset_prepare)(struct pci_dev___12 *);
	void (*reset_done)(struct pci_dev___12 *);
	void (*resume)(struct pci_dev___12 *);
};

struct dentry_operations___289;

struct super_block___289;

struct dentry___290 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___290 *d_parent;
	struct qstr d_name;
	struct inode___290 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___289 *d_op;
	struct super_block___289 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___289;

struct block_device___289;

struct cdev___48;

struct inode___290 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___289 *i_op;
	struct super_block___289 *i_sb;
	struct address_space___289 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___291 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___290 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___289 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___289 *i_bdev;
		struct cdev___48 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___289 {
	int (*d_revalidate)(struct dentry___290 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___290 *, unsigned int);
	int (*d_hash)(const struct dentry___290 *, struct qstr *);
	int (*d_compare)(const struct dentry___290 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___290 *);
	int (*d_init)(struct dentry___290 *);
	void (*d_release)(struct dentry___290 *);
	void (*d_prune)(struct dentry___290 *);
	void (*d_iput)(struct dentry___290 *, struct inode___290 *);
	char * (*d_dname)(struct dentry___290 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___290 *);
	int (*d_manage)(const struct path___290 *, bool);
	struct dentry___290 * (*d_real)(struct dentry___290 *, const struct inode___290 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___289;

struct mem_dqinfo___289 {
	struct quota_format_type___289 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___289;

struct quota_info___289 {
	unsigned int flags;
	struct rw_semaphore___291 dqio_sem;
	struct inode___290 *files[3];
	struct mem_dqinfo___289 info[3];
	const struct quota_format_ops___289 *ops[3];
};

struct rcuwait___289 {
	struct task_struct___291 *task;
};

struct percpu_rw_semaphore___289 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___291 rw_sem;
	struct rcuwait___289 writer;
	int readers_block;
};

struct sb_writers___289 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___289 rw_sem[3];
};

struct file_system_type___289;

struct super_operations___289;

struct dquot_operations___289;

struct quotactl_ops___289;

struct super_block___289 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___289 *s_type;
	const struct super_operations___289 *s_op;
	const struct dquot_operations___289 *dq_op;
	const struct quotactl_ops___289 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___290 *s_root;
	struct rw_semaphore___291 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___289 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___289 s_dquot;
	struct sb_writers___289 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___289 *s_d_op;
	int cleancache_poolid;
	struct shrinker___116 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___290 {
	struct file___290 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___290 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___289 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___290 *ia_file;
};

struct dquot___289 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___289 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___289 {
	int qf_fmt_id;
	const struct quota_format_ops___289 *qf_ops;
	struct module___233 *qf_owner;
	struct quota_format_type___289 *qf_next;
};

struct quota_format_ops___289 {
	int (*check_quota_file)(struct super_block___289 *, int);
	int (*read_file_info)(struct super_block___289 *, int);
	int (*write_file_info)(struct super_block___289 *, int);
	int (*free_file_info)(struct super_block___289 *, int);
	int (*read_dqblk)(struct dquot___289 *);
	int (*commit_dqblk)(struct dquot___289 *);
	int (*release_dqblk)(struct dquot___289 *);
	int (*get_next_id)(struct super_block___289 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___289 {
	int (*write_dquot)(struct dquot___289 *);
	struct dquot___289 * (*alloc_dquot)(struct super_block___289 *, int);
	void (*destroy_dquot)(struct dquot___289 *);
	int (*acquire_dquot)(struct dquot___289 *);
	int (*release_dquot)(struct dquot___289 *);
	int (*mark_dirty)(struct dquot___289 *);
	int (*write_info)(struct super_block___289 *, int);
	qsize_t * (*get_reserved_space)(struct inode___290 *);
	int (*get_projid)(struct inode___290 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___290 *, qsize_t *);
	int (*get_next_id)(struct super_block___289 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___289 {
	int (*quota_on)(struct super_block___289 *, int, int, const struct path___290 *);
	int (*quota_off)(struct super_block___289 *, int);
	int (*quota_enable)(struct super_block___289 *, unsigned int);
	int (*quota_disable)(struct super_block___289 *, unsigned int);
	int (*quota_sync)(struct super_block___289 *, int);
	int (*set_info)(struct super_block___289 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___289 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___289 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___289 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___289 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___289 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___289 {
	int (*writepage)(struct page___291 *, struct writeback_control___3 *);
	int (*readpage)(struct file___290 *, struct page___291 *);
	int (*writepages)(struct address_space___289 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___291 *);
	int (*readpages)(struct file___290 *, struct address_space___289 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___290 *, struct address_space___289 *, loff_t, unsigned int, unsigned int, struct page___291 **, void **);
	int (*write_end)(struct file___290 *, struct address_space___289 *, loff_t, unsigned int, unsigned int, struct page___291 *, void *);
	sector_t (*bmap)(struct address_space___289 *, sector_t);
	void (*invalidatepage)(struct page___291 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___291 *, gfp_t);
	void (*freepage)(struct page___291 *);
	ssize_t (*direct_IO)(struct kiocb___290 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___289 *, struct page___291 *, struct page___291 *, enum migrate_mode);
	bool (*isolate_page)(struct page___291 *, isolate_mode_t);
	void (*putback_page)(struct page___291 *);
	int (*launder_page)(struct page___291 *);
	int (*is_partially_uptodate)(struct page___291 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___291 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___289 *, struct page___291 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___290 *, sector_t *);
	void (*swap_deactivate)(struct file___290 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___289 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___290 *bd_inode;
	struct super_block___289 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___289 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___48 {
	struct kobject___277 kobj;
	struct module___233 *owner;
	const struct file_operations___290 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___289 {
	struct dentry___290 * (*lookup)(struct inode___290 *, struct dentry___290 *, unsigned int);
	const char * (*get_link)(struct dentry___290 *, struct inode___290 *, struct delayed_call *);
	int (*permission)(struct inode___290 *, int);
	struct posix_acl * (*get_acl)(struct inode___290 *, int);
	int (*readlink)(struct dentry___290 *, char *, int);
	int (*create)(struct inode___290 *, struct dentry___290 *, umode_t, bool);
	int (*link)(struct dentry___290 *, struct inode___290 *, struct dentry___290 *);
	int (*unlink)(struct inode___290 *, struct dentry___290 *);
	int (*symlink)(struct inode___290 *, struct dentry___290 *, const char *);
	int (*mkdir)(struct inode___290 *, struct dentry___290 *, umode_t);
	int (*rmdir)(struct inode___290 *, struct dentry___290 *);
	int (*mknod)(struct inode___290 *, struct dentry___290 *, umode_t, dev_t);
	int (*rename)(struct inode___290 *, struct dentry___290 *, struct inode___290 *, struct dentry___290 *, unsigned int);
	int (*setattr)(struct dentry___290 *, struct iattr___289 *);
	int (*getattr)(const struct path___290 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___290 *, char *, size_t);
	int (*fiemap)(struct inode___290 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___290 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___290 *, struct dentry___290 *, struct file___290 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___290 *, struct dentry___290 *, umode_t);
	int (*set_acl)(struct inode___290 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___289 {
	void (*fl_copy_lock)(struct file_lock___290 *, struct file_lock___290 *);
	void (*fl_release_private)(struct file_lock___290 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___289;

struct lock_manager_operations___289;

struct file_lock___290 {
	struct file_lock___290 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___290 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___289 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___289 *fl_ops;
	const struct lock_manager_operations___289 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___289 {
	int (*lm_compare_owner)(struct file_lock___290 *, struct file_lock___290 *);
	long unsigned int (*lm_owner_key)(struct file_lock___290 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___290 *);
	int (*lm_grant)(struct file_lock___290 *, int);
	bool (*lm_break)(struct file_lock___290 *);
	int (*lm_change)(struct file_lock___290 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___290 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___289 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___289 *fa_next;
	struct file___290 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___289 {
	const char *name;
	int fs_flags;
	struct dentry___290 * (*mount)(struct file_system_type___289 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___289 *);
	struct module___233 *owner;
	struct file_system_type___289 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___289 {
	struct inode___290 * (*alloc_inode)(struct super_block___289 *);
	void (*destroy_inode)(struct inode___290 *);
	void (*dirty_inode)(struct inode___290 *, int);
	int (*write_inode)(struct inode___290 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___290 *);
	void (*evict_inode)(struct inode___290 *);
	void (*put_super)(struct super_block___289 *);
	int (*sync_fs)(struct super_block___289 *, int);
	int (*freeze_super)(struct super_block___289 *);
	int (*freeze_fs)(struct super_block___289 *);
	int (*thaw_super)(struct super_block___289 *);
	int (*unfreeze_fs)(struct super_block___289 *);
	int (*statfs)(struct dentry___290 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___289 *, int *, char *);
	void (*umount_begin)(struct super_block___289 *);
	int (*show_options)(struct seq_file___248 *, struct dentry___290 *);
	int (*show_devname)(struct seq_file___248 *, struct dentry___290 *);
	int (*show_path)(struct seq_file___248 *, struct dentry___290 *);
	int (*show_stats)(struct seq_file___248 *, struct dentry___290 *);
	ssize_t (*quota_read)(struct super_block___289 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___289 *, int, const char *, size_t, loff_t);
	struct dquot___289 ** (*get_dquots)(struct inode___290 *);
	int (*bdev_try_to_free_page)(struct super_block___289 *, struct page___291 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___289 *, struct shrink_control___116 *);
	long int (*free_cached_objects)(struct super_block___289 *, struct shrink_control___116 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___279(struct page___291 *);

struct acpi_device___5;

struct acpi_hotplug_profile___5 {
	struct kobject___277 kobj;
	int (*scan_dependent)(struct acpi_device___5 *);
	void (*notify_online)(struct acpi_device___5 *);
	bool enabled: 1;
	bool demand_offline: 1;
};

struct acpi_device_wakeup_context___5 {
	void (*func)(struct acpi_device_wakeup_context___5 *);
	struct device___255 *dev;
};

struct acpi_device_wakeup___5 {
	acpi_handle gpe_device;
	u64 gpe_number;
	u64 sleep_state;
	struct list_head resources;
	struct acpi_device_wakeup_flags flags;
	struct acpi_device_wakeup_context___5 context;
	struct wakeup_source *ws;
	int prepare_count;
	int enable_count;
};

struct acpi_scan_handler___5;

struct acpi_hotplug_context___5;

struct acpi_driver___5;

struct acpi_device___5 {
	int device_type;
	acpi_handle handle;
	struct fwnode_handle___189 fwnode;
	struct acpi_device___5 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup___5 wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_device_data data;
	struct acpi_scan_handler___5 *handler;
	struct acpi_hotplug_context___5 *hp;
	struct acpi_driver___5 *driver;
	const struct acpi_gpio_mapping *driver_gpios;
	void *driver_data;
	struct device___255 dev;
	unsigned int physical_node_count;
	unsigned int dep_unmet;
	struct list_head physical_node_list;
	struct mutex physical_node_lock;
	void (*remove)(struct acpi_device___5 *);
};

struct acpi_scan_handler___5 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	bool (*match)(const char *, const struct acpi_device_id **);
	int (*attach)(struct acpi_device___5 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___5 *);
	void (*bind)(struct device___255 *);
	void (*unbind)(struct device___255 *);
	struct acpi_hotplug_profile___5 hotplug;
};

struct acpi_hotplug_context___5 {
	struct acpi_device___5 *self;
	int (*notify)(struct acpi_device___5 *, u32);
	void (*uevent)(struct acpi_device___5 *, u32);
	void (*fixup)(struct acpi_device___5 *);
};

typedef int (*acpi_op_add___5)(struct acpi_device___5 *);

typedef int (*acpi_op_remove___5)(struct acpi_device___5 *);

typedef void (*acpi_op_notify___5)(struct acpi_device___5 *, u32);

struct acpi_device_ops___5 {
	acpi_op_add___5 add;
	acpi_op_remove___5 remove;
	acpi_op_notify___5 notify;
};

struct acpi_driver___5 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___5 ops;
	struct device_driver___255 drv;
	struct module___233 *owner;
};

typedef int (*key_restrict_link_func_t___271)(struct key___270 *, const struct key_type *, const union key_payload *, struct key___270 *);

struct key_restriction___270;

struct key___270 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___291 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___270 *restrict_link;
};

struct key_restriction___270 {
	key_restrict_link_func_t___271 check;
	struct key___270 *key;
	struct key_type *keytype;
};

struct seq_operations___247 {
	void * (*start)(struct seq_file___248 *, loff_t *);
	void (*stop)(struct seq_file___248 *, void *);
	void * (*next)(struct seq_file___248 *, void *, loff_t *);
	int (*show)(struct seq_file___248 *, void *);
};

struct pci_dev_resource {
	struct list_head list;
	struct resource *res;
	struct pci_dev___12 *dev;
	resource_size_t start;
	resource_size_t end;
	resource_size_t add_size;
	resource_size_t min_align;
	long unsigned int flags;
};

enum release_type {
	leaf_only = 0,
	whole_subtree = 1,
};

enum enable_type {
	undefined = 4294967295,
	user_disabled = 0,
	auto_disabled = 1,
	user_enabled = 2,
	auto_enabled = 3,
};

struct pci_bus___13;

struct pci_slot___13 {
	struct pci_bus___13 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject___60 kobj;
};

struct pci_dev___13;

struct pci_ops___13;

struct pci_bus___13 {
	struct list_head node;
	struct pci_bus___13 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___13 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___13 *ops;
	struct msi_controller___2 *msi;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	int domain_nr;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___57 *bridge;
	struct device___57 dev;
	struct bin_attribute___57 *legacy_io;
	struct bin_attribute___57 *legacy_mem;
	unsigned int is_added: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
};

struct pci_driver___13;

struct pci_dev___13 {
	struct list_head bus_list;
	struct pci_bus___13 *bus;
	struct pci_bus___13 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___13 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u16 aer_cap;
	struct aer_stats *aer_stats;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	long unsigned int *dma_alias_mask;
	struct pci_driver___13 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	unsigned int imm_ready: 1;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int bridge_d3: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int hotplug_user_indicators: 1;
	unsigned int clear_retrain_link: 1;
	unsigned int d3_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	unsigned int ltr_path: 1;
	unsigned int eetlp_prefix_path: 1;
	pci_channel_state_t error_state;
	struct device___57 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int multifunction: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int ats_enabled: 1;
	unsigned int pasid_enabled: 1;
	unsigned int pri_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int reset_fn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int shpc_managed: 1;
	unsigned int is_thunderbolt: 1;
	unsigned int __aer_firmware_first_valid: 1;
	unsigned int __aer_firmware_first: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int irq_managed: 1;
	unsigned int has_secondary_link: 1;
	unsigned int non_compliant_bars: 1;
	unsigned int is_probed: 1;
	unsigned int link_active_reporting: 1;
	unsigned int untrusted: 1;
	unsigned int no_vf_scan: 1;
	unsigned int io_window: 1;
	unsigned int pref_window: 1;
	unsigned int pref_64_window: 1;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	struct bin_attribute___57 *rom_attr;
	int rom_attr_enabled;
	struct bin_attribute___57 *res_attr[17];
	struct bin_attribute___57 *res_attr_wc[17];
	unsigned int broken_cmd_compl: 1;
	const struct attribute_group___57 **msi_irq_groups;
	struct pci_vpd *vpd;
	union {
		struct pci_sriov *sriov;
		struct pci_dev___13 *physfn;
	};
	u16 ats_cap;
	u8 ats_stu;
	atomic_t ats_ref_cnt;
	u32 pri_reqs_alloc;
	u16 pasid_features;
	struct pci_p2pdma *p2pdma;
	phys_addr_t rom;
	size_t romlen;
	char *driver_override;
	long unsigned int priv_flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t pci_dev_extended_size_rh;
	struct pci_dev_extended_rh pci_dev_extended_rh;
};

struct pci_error_handlers___13;

struct pci_driver___13 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___13 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___13 *);
	int (*suspend)(struct pci_dev___13 *, pm_message_t);
	int (*suspend_late)(struct pci_dev___13 *, pm_message_t);
	int (*resume_early)(struct pci_dev___13 *);
	int (*resume)(struct pci_dev___13 *);
	void (*shutdown)(struct pci_dev___13 *);
	int (*sriov_configure)(struct pci_dev___13 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	const struct pci_error_handlers___13 *err_handler;
	const struct attribute_group___57 **groups;
	struct device_driver___57 driver;
	struct pci_dynids dynids;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct pci_ops___13 {
	int (*add_bus)(struct pci_bus___13 *);
	void (*remove_bus)(struct pci_bus___13 *);
	void * (*map_bus)(struct pci_bus___13 *, unsigned int, int);
	int (*read)(struct pci_bus___13 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___13 *, unsigned int, int, int, u32);
};

struct pci_error_handlers___13 {
	pci_ers_result_t (*error_detected)(struct pci_dev___13 *, enum pci_channel_state);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___13 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___13 *);
	void (*reset_prepare)(struct pci_dev___13 *);
	void (*reset_done)(struct pci_dev___13 *);
	void (*resume)(struct pci_dev___13 *);
};

struct pci_bus___14;

struct hotplug_slot___3;

struct pci_slot___14 {
	struct pci_bus___14 *bus;
	struct list_head list;
	struct hotplug_slot___3 *hotplug;
	unsigned char number;
	struct kobject___277 kobj;
};

struct pci_dev___14;

struct pci_ops___14;

struct pci_bus___14 {
	struct list_head node;
	struct pci_bus___14 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___14 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___14 *ops;
	struct msi_controller___2 *msi;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	int domain_nr;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___255 *bridge;
	struct device___255 dev;
	struct bin_attribute___253 *legacy_io;
	struct bin_attribute___253 *legacy_mem;
	unsigned int is_added: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
};

struct hotplug_slot_ops___3;

struct hotplug_slot___3 {
	const struct hotplug_slot_ops___3 *ops;
	struct list_head slot_list;
	struct pci_slot___14 *pci_slot;
	struct module___233 *owner;
	const char *mod_name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct pci_sriov___9 {
	int pos;
	int nres;
	u32 cap;
	u16 ctrl;
	u16 total_VFs;
	u16 initial_VFs;
	u16 num_VFs;
	u16 offset;
	u16 stride;
	u16 vf_device;
	u32 pgsz;
	u8 link;
	u8 max_VF_buses;
	u16 driver_max_VFs;
	struct pci_dev___14 *dev;
	struct pci_dev___14 *self;
	u32 class;
	u8 hdr_type;
	u16 subsystem_vendor;
	u16 subsystem_device;
	resource_size_t barsz[6];
	bool drivers_autoprobe;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct pci_driver___14;

struct pci_dev___14 {
	struct list_head bus_list;
	struct pci_bus___14 *bus;
	struct pci_bus___14 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___14 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u16 aer_cap;
	struct aer_stats *aer_stats;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	long unsigned int *dma_alias_mask;
	struct pci_driver___14 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	unsigned int imm_ready: 1;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int bridge_d3: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int hotplug_user_indicators: 1;
	unsigned int clear_retrain_link: 1;
	unsigned int d3_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	unsigned int ltr_path: 1;
	unsigned int eetlp_prefix_path: 1;
	pci_channel_state_t error_state;
	struct device___255 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int multifunction: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int ats_enabled: 1;
	unsigned int pasid_enabled: 1;
	unsigned int pri_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int reset_fn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int shpc_managed: 1;
	unsigned int is_thunderbolt: 1;
	unsigned int __aer_firmware_first_valid: 1;
	unsigned int __aer_firmware_first: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int irq_managed: 1;
	unsigned int has_secondary_link: 1;
	unsigned int non_compliant_bars: 1;
	unsigned int is_probed: 1;
	unsigned int link_active_reporting: 1;
	unsigned int untrusted: 1;
	unsigned int no_vf_scan: 1;
	unsigned int io_window: 1;
	unsigned int pref_window: 1;
	unsigned int pref_64_window: 1;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	struct bin_attribute___253 *rom_attr;
	int rom_attr_enabled;
	struct bin_attribute___253 *res_attr[17];
	struct bin_attribute___253 *res_attr_wc[17];
	unsigned int broken_cmd_compl: 1;
	const struct attribute_group___254 **msi_irq_groups;
	struct pci_vpd *vpd;
	union {
		struct pci_sriov___9 *sriov;
		struct pci_dev___14 *physfn;
	};
	u16 ats_cap;
	u8 ats_stu;
	atomic_t ats_ref_cnt;
	u32 pri_reqs_alloc;
	u16 pasid_features;
	struct pci_p2pdma *p2pdma;
	phys_addr_t rom;
	size_t romlen;
	char *driver_override;
	long unsigned int priv_flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t pci_dev_extended_size_rh;
	struct pci_dev_extended_rh pci_dev_extended_rh;
};

struct pci_error_handlers___14;

struct pci_driver___14 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___14 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___14 *);
	int (*suspend)(struct pci_dev___14 *, pm_message_t);
	int (*suspend_late)(struct pci_dev___14 *, pm_message_t);
	int (*resume_early)(struct pci_dev___14 *);
	int (*resume)(struct pci_dev___14 *);
	void (*shutdown)(struct pci_dev___14 *);
	int (*sriov_configure)(struct pci_dev___14 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	const struct pci_error_handlers___14 *err_handler;
	const struct attribute_group___254 **groups;
	struct device_driver___255 driver;
	struct pci_dynids dynids;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct pci_ops___14 {
	int (*add_bus)(struct pci_bus___14 *);
	void (*remove_bus)(struct pci_bus___14 *);
	void * (*map_bus)(struct pci_bus___14 *, unsigned int, int);
	int (*read)(struct pci_bus___14 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___14 *, unsigned int, int, int, u32);
};

struct pci_error_handlers___14 {
	pci_ers_result_t (*error_detected)(struct pci_dev___14 *, enum pci_channel_state);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___14 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___14 *);
	void (*reset_prepare)(struct pci_dev___14 *);
	void (*reset_done)(struct pci_dev___14 *);
	void (*resume)(struct pci_dev___14 *);
};

struct pci_slot_attribute {
	struct attribute attr;
	ssize_t (*show)(struct pci_slot___14 *, char *);
	ssize_t (*store)(struct pci_slot___14 *, const char *, size_t);
};

struct hotplug_slot_ops___3 {
	int (*enable_slot)(struct hotplug_slot___3 *);
	int (*disable_slot)(struct hotplug_slot___3 *);
	int (*set_attention_status)(struct hotplug_slot___3 *, u8);
	int (*hardware_test)(struct hotplug_slot___3 *, u32);
	int (*get_power_status)(struct hotplug_slot___3 *, u8 *);
	int (*get_attention_status)(struct hotplug_slot___3 *, u8 *);
	int (*get_latch_status)(struct hotplug_slot___3 *, u8 *);
	int (*get_adapter_status)(struct hotplug_slot___3 *, u8 *);
	int (*reset_slot)(struct hotplug_slot___3 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct pci_bus___15;

struct pci_slot___15 {
	struct pci_bus___15 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject___269 kobj;
};

struct pci_dev___15;

struct pci_ops___15;

struct msi_controller___5;

struct pci_bus___15 {
	struct list_head node;
	struct pci_bus___15 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___15 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___15 *ops;
	struct msi_controller___5 *msi;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	int domain_nr;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___244 *bridge;
	struct device___244 dev;
	struct bin_attribute___245 *legacy_io;
	struct bin_attribute___245 *legacy_mem;
	unsigned int is_added: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
};

struct pci_sriov___10 {
	int pos;
	int nres;
	u32 cap;
	u16 ctrl;
	u16 total_VFs;
	u16 initial_VFs;
	u16 num_VFs;
	u16 offset;
	u16 stride;
	u16 vf_device;
	u32 pgsz;
	u8 link;
	u8 max_VF_buses;
	u16 driver_max_VFs;
	struct pci_dev___15 *dev;
	struct pci_dev___15 *self;
	u32 class;
	u8 hdr_type;
	u16 subsystem_vendor;
	u16 subsystem_device;
	resource_size_t barsz[6];
	bool drivers_autoprobe;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct pci_driver___15;

struct pci_dev___15 {
	struct list_head bus_list;
	struct pci_bus___15 *bus;
	struct pci_bus___15 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___15 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u16 aer_cap;
	struct aer_stats *aer_stats;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	long unsigned int *dma_alias_mask;
	struct pci_driver___15 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	unsigned int imm_ready: 1;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int bridge_d3: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int hotplug_user_indicators: 1;
	unsigned int clear_retrain_link: 1;
	unsigned int d3_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	unsigned int ltr_path: 1;
	unsigned int eetlp_prefix_path: 1;
	pci_channel_state_t error_state;
	struct device___244 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int multifunction: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int ats_enabled: 1;
	unsigned int pasid_enabled: 1;
	unsigned int pri_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int reset_fn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int shpc_managed: 1;
	unsigned int is_thunderbolt: 1;
	unsigned int __aer_firmware_first_valid: 1;
	unsigned int __aer_firmware_first: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int irq_managed: 1;
	unsigned int has_secondary_link: 1;
	unsigned int non_compliant_bars: 1;
	unsigned int is_probed: 1;
	unsigned int link_active_reporting: 1;
	unsigned int untrusted: 1;
	unsigned int no_vf_scan: 1;
	unsigned int io_window: 1;
	unsigned int pref_window: 1;
	unsigned int pref_64_window: 1;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	struct bin_attribute___245 *rom_attr;
	int rom_attr_enabled;
	struct bin_attribute___245 *res_attr[17];
	struct bin_attribute___245 *res_attr_wc[17];
	unsigned int broken_cmd_compl: 1;
	const struct attribute_group___246 **msi_irq_groups;
	struct pci_vpd *vpd;
	union {
		struct pci_sriov___10 *sriov;
		struct pci_dev___15 *physfn;
	};
	u16 ats_cap;
	u8 ats_stu;
	atomic_t ats_ref_cnt;
	u32 pri_reqs_alloc;
	u16 pasid_features;
	struct pci_p2pdma *p2pdma;
	phys_addr_t rom;
	size_t romlen;
	char *driver_override;
	long unsigned int priv_flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t pci_dev_extended_size_rh;
	struct pci_dev_extended_rh pci_dev_extended_rh;
};

struct pci_error_handlers___15;

struct pci_driver___15 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___15 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___15 *);
	int (*suspend)(struct pci_dev___15 *, pm_message_t);
	int (*suspend_late)(struct pci_dev___15 *, pm_message_t);
	int (*resume_early)(struct pci_dev___15 *);
	int (*resume)(struct pci_dev___15 *);
	void (*shutdown)(struct pci_dev___15 *);
	int (*sriov_configure)(struct pci_dev___15 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	const struct pci_error_handlers___15 *err_handler;
	const struct attribute_group___246 **groups;
	struct device_driver___244 driver;
	struct pci_dynids dynids;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct pci_ops___15 {
	int (*add_bus)(struct pci_bus___15 *);
	void (*remove_bus)(struct pci_bus___15 *);
	void * (*map_bus)(struct pci_bus___15 *, unsigned int, int);
	int (*read)(struct pci_bus___15 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___15 *, unsigned int, int, int, u32);
};

struct msi_controller___5 {
	struct module___11 *owner;
	struct device___244 *dev;
	struct device_node___45 *of_node;
	struct list_head list;
	int (*setup_irq)(struct msi_controller___5 *, struct pci_dev___15 *, struct msi_desc___7 *);
	int (*setup_irqs)(struct msi_controller___5 *, struct pci_dev___15 *, int, int);
	void (*teardown_irq)(struct msi_controller___5 *, unsigned int);
};

struct pci_error_handlers___15 {
	pci_ers_result_t (*error_detected)(struct pci_dev___15 *, enum pci_channel_state);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___15 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___15 *);
	void (*reset_prepare)(struct pci_dev___15 *);
	void (*reset_done)(struct pci_dev___15 *);
	void (*resume)(struct pci_dev___15 *);
};

struct of_pci_range_parser {
	struct device_node___45 *node;
	const __be32 *range;
	const __be32 *end;
	int np;
	int pna;
};

struct of_pci_range {
	u32 pci_space;
	u64 pci_addr;
	u64 cpu_addr;
	u64 size;
	u32 flags;
};

enum dmi_field {
	DMI_NONE = 0,
	DMI_BIOS_VENDOR = 1,
	DMI_BIOS_VERSION = 2,
	DMI_BIOS_DATE = 3,
	DMI_SYS_VENDOR = 4,
	DMI_PRODUCT_NAME = 5,
	DMI_PRODUCT_VERSION = 6,
	DMI_PRODUCT_SERIAL = 7,
	DMI_PRODUCT_UUID = 8,
	DMI_PRODUCT_SKU = 9,
	DMI_PRODUCT_FAMILY = 10,
	DMI_BOARD_VENDOR = 11,
	DMI_BOARD_NAME = 12,
	DMI_BOARD_VERSION = 13,
	DMI_BOARD_SERIAL = 14,
	DMI_BOARD_ASSET_TAG = 15,
	DMI_CHASSIS_VENDOR = 16,
	DMI_CHASSIS_TYPE = 17,
	DMI_CHASSIS_VERSION = 18,
	DMI_CHASSIS_SERIAL = 19,
	DMI_CHASSIS_ASSET_TAG = 20,
	DMI_STRING_MAX = 21,
	DMI_OEM_STRING = 22,
};

struct pci_fixup___2 {
	u16 vendor;
	u16 device;
	u32 class;
	unsigned int class_shift;
	void (*hook)(struct pci_dev___9 *);
};

enum {
	SWITCHTEC_GAS_MRPC_OFFSET = 0,
	SWITCHTEC_GAS_TOP_CFG_OFFSET = 4096,
	SWITCHTEC_GAS_SW_EVENT_OFFSET = 6144,
	SWITCHTEC_GAS_SYS_INFO_OFFSET = 8192,
	SWITCHTEC_GAS_FLASH_INFO_OFFSET = 8704,
	SWITCHTEC_GAS_PART_CFG_OFFSET = 16384,
	SWITCHTEC_GAS_NTB_OFFSET = 65536,
	SWITCHTEC_GAS_PFF_CSR_OFFSET = 1261568,
};

enum {
	SWITCHTEC_NTB_REG_INFO_OFFSET = 0,
	SWITCHTEC_NTB_REG_CTRL_OFFSET = 16384,
	SWITCHTEC_NTB_REG_DBMSG_OFFSET = 409600,
};

struct nt_partition_info {
	u32 xlink_enabled;
	u32 target_part_low;
	u32 target_part_high;
	u32 reserved;
};

struct ntb_info_regs {
	u8 partition_count;
	u8 partition_id;
	u16 reserved1;
	u64 ep_map;
	u16 requester_id;
	u16 reserved2;
	u32 reserved3[4];
	struct nt_partition_info ntp_info[48];
} __attribute__((packed));

struct ntb_ctrl_regs {
	u32 partition_status;
	u32 partition_op;
	u32 partition_ctrl;
	u32 bar_setup;
	u32 bar_error;
	u16 lut_table_entries;
	u16 lut_table_offset;
	u32 lut_error;
	u16 req_id_table_size;
	u16 req_id_table_offset;
	u32 req_id_error;
	u32 reserved1[7];
	struct {
		u32 ctl;
		u32 win_size;
		u64 xlate_addr;
	} bar_entry[6];
	u32 reserved2[216];
	u32 req_id_table[256];
	u32 reserved3[512];
	u64 lut_entry[512];
};

struct pci_dev_reset_methods {
	u16 vendor;
	u16 device;
	int (*reset)(struct pci_dev___9 *, int);
};

struct pci_dev_acs_enabled {
	u16 vendor;
	u16 device;
	int (*acs_enabled)(struct pci_dev___9 *, u16);
};

struct pci_dev_acs_ops {
	u16 vendor;
	u16 device;
	int (*enable_acs)(struct pci_dev___9 *);
	int (*disable_acs_redir)(struct pci_dev___9 *);
};

struct pci_host_bridge___3 {
	struct device___255 dev;
	struct pci_bus___14 *bus;
	struct pci_ops___14 *ops;
	void *sysdata;
	int busnr;
	struct list_head windows;
	u8 (*swizzle_irq)(struct pci_dev___14 *, u8 *);
	int (*map_irq)(const struct pci_dev___14 *, u8, u8);
	void (*release_fn)(struct pci_host_bridge___3 *);
	void *release_data;
	struct msi_controller___2 *msi;
	unsigned int ignore_reset_delay: 1;
	unsigned int no_ext_tags: 1;
	unsigned int native_aer: 1;
	unsigned int native_pcie_hotplug: 1;
	unsigned int native_shpc_hotplug: 1;
	unsigned int native_pme: 1;
	unsigned int native_ltr: 1;
	resource_size_t (*align_resource)(struct pci_dev___14 *, const struct resource *, resource_size_t, resource_size_t, resource_size_t);
	long: 64;
	long unsigned int private[0];
};

struct pcie_device___2 {
	int irq;
	struct pci_dev___14 *port;
	u32 service;
	void *priv_data;
	struct device___255 device;
};

struct pcie_port_service_driver___2 {
	const char *name;
	int (*probe)(struct pcie_device___2 *);
	void (*remove)(struct pcie_device___2 *);
	int (*suspend)(struct pcie_device___2 *);
	int (*resume_noirq)(struct pcie_device___2 *);
	int (*resume)(struct pcie_device___2 *);
	int (*runtime_suspend)(struct pcie_device___2 *);
	int (*runtime_resume)(struct pcie_device___2 *);
	void (*error_resume)(struct pci_dev___14 *);
	pci_ers_result_t (*reset_link)(struct pci_dev___14 *);
	int port_type;
	u32 service;
	struct device_driver___255 driver;
};

struct portdrv_service_data {
	struct pcie_port_service_driver___2 *drv;
	struct device___255 *dev;
	u32 service;
};

typedef int (*pcie_pm_callback_t)(struct pcie_device___2 *);

struct aspm_latency {
	u32 l0s;
	u32 l1;
};

struct pcie_link_state {
	struct pci_dev___14 *pdev;
	struct pci_dev___14 *downstream;
	struct pcie_link_state *root;
	struct pcie_link_state *parent;
	struct list_head sibling;
	u32 aspm_support: 7;
	u32 aspm_enabled: 7;
	u32 aspm_capable: 7;
	u32 aspm_default: 7;
	char: 4;
	u32 aspm_disable: 7;
	u32 clkpm_capable: 1;
	u32 clkpm_enabled: 1;
	u32 clkpm_default: 1;
	struct aspm_latency latency_up;
	struct aspm_latency latency_dw;
	struct aspm_latency acceptable[8];
	struct {
		u32 up_cap_ptr;
		u32 dw_cap_ptr;
		u32 ctl1;
		u32 ctl2;
	} l1ss;
};

struct aspm_register_info {
	u32 support: 2;
	u32 enabled: 2;
	u32 latency_encoding_l0s;
	u32 latency_encoding_l1;
	u32 l1ss_cap_ptr;
	u32 l1ss_cap;
	u32 l1ss_ctl1;
	u32 l1ss_ctl2;
};

struct module___234;

struct file___291;

struct kiocb___291;

struct poll_table_struct___176;

struct vm_area_struct___292;

struct inode___291;

struct file_lock___291;

struct page___292;

struct seq_file___249;

struct file_operations___291 {
	struct module___234 *owner;
	loff_t (*llseek)(struct file___291 *, loff_t, int);
	ssize_t (*read)(struct file___291 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___291 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___291 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___291 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___291 *, bool);
	int (*iterate)(struct file___291 *, struct dir_context *);
	int (*iterate_shared)(struct file___291 *, struct dir_context *);
	__poll_t (*poll)(struct file___291 *, struct poll_table_struct___176 *);
	long int (*unlocked_ioctl)(struct file___291 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___291 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___291 *, struct vm_area_struct___292 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___291 *, struct file___291 *);
	int (*flush)(struct file___291 *, fl_owner_t);
	int (*release)(struct inode___291 *, struct file___291 *);
	int (*fsync)(struct file___291 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___291 *, int);
	int (*lock)(struct file___291 *, int, struct file_lock___291 *);
	ssize_t (*sendpage)(struct file___291 *, struct page___292 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___291 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___291 *, int, struct file_lock___291 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___291 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___291 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___291 *, long int, struct file_lock___291 **, void **);
	long int (*fallocate)(struct file___291 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___249 *, struct file___291 *);
	ssize_t (*copy_file_range)(struct file___291 *, loff_t, struct file___291 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___291 *, loff_t, struct file___291 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___291 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___291 {
	u64 seqnum;
	struct vm_area_struct___292 *vmas[4];
};

struct page_frag___291 {
	struct page___292 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___291;

struct cred___271;

struct vm_struct___207;

struct task_struct___292 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___292 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___291 *mm;
	struct mm_struct___291 *active_mm;
	struct vmacache___291 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___292 *real_parent;
	struct task_struct___292 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___292 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___195 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___195 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___195 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___271 *ptracer_cred;
	const struct cred___271 *real_cred;
	const struct cred___271 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___292 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___82 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___291 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___292 *oom_reaper_list;
	struct vm_struct___207 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___130 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___290;

struct super_block___290;

struct dentry___291 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___291 *d_parent;
	struct qstr d_name;
	struct inode___291 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___290 *d_op;
	struct super_block___290 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct rw_semaphore___292 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___292 *owner;
};

struct address_space_operations___290;

struct address_space___290 {
	struct inode___291 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___292 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___290 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___290;

struct block_device___290;

struct cdev___49;

struct inode___291 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___290 *i_op;
	struct super_block___290 *i_sb;
	struct address_space___290 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___292 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___291 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___290 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___290 *i_bdev;
		struct cdev___49 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___291;

struct dentry_operations___290 {
	int (*d_revalidate)(struct dentry___291 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___291 *, unsigned int);
	int (*d_hash)(const struct dentry___291 *, struct qstr *);
	int (*d_compare)(const struct dentry___291 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___291 *);
	int (*d_init)(struct dentry___291 *);
	void (*d_release)(struct dentry___291 *);
	void (*d_prune)(struct dentry___291 *);
	void (*d_iput)(struct dentry___291 *, struct inode___291 *);
	char * (*d_dname)(struct dentry___291 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___291 *);
	int (*d_manage)(const struct path___291 *, bool);
	struct dentry___291 * (*d_real)(struct dentry___291 *, const struct inode___291 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___290;

struct mem_dqinfo___290 {
	struct quota_format_type___290 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___290;

struct quota_info___290 {
	unsigned int flags;
	struct rw_semaphore___292 dqio_sem;
	struct inode___291 *files[3];
	struct mem_dqinfo___290 info[3];
	const struct quota_format_ops___290 *ops[3];
};

struct rcuwait___290 {
	struct task_struct___292 *task;
};

struct percpu_rw_semaphore___290 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___292 rw_sem;
	struct rcuwait___290 writer;
	int readers_block;
};

struct sb_writers___290 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___290 rw_sem[3];
};

struct file_system_type___290;

struct super_operations___290;

struct dquot_operations___290;

struct quotactl_ops___290;

struct super_block___290 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___290 *s_type;
	const struct super_operations___290 *s_op;
	const struct dquot_operations___290 *dq_op;
	const struct quotactl_ops___290 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___291 *s_root;
	struct rw_semaphore___292 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___290 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___290 s_dquot;
	struct sb_writers___290 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___290 *s_d_op;
	int cleancache_poolid;
	struct shrinker___116 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct path___291 {
	struct vfsmount *mnt;
	struct dentry___291 *dentry;
};

typedef struct page___292 *pgtable_t___291;

struct dev_pagemap___280;

struct page___292 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___290 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___292 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___291 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___291 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___280 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___291;

struct lruvec___291 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___291 *pgdat;
};

struct zone___291 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___291 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___291 {
	struct zone___291 *zone;
	int zone_idx;
};

struct zonelist___291 {
	struct zoneref___291 _zonerefs[25];
};

struct pglist_data___291 {
	struct zone___291 node_zones[3];
	struct zonelist___291 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___292 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___292 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___291 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___292 {
	void *stack;
	struct task_struct___292 *task;
	long int status;
};

struct blocking_notifier_head___291 {
	struct rw_semaphore___292 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___280;

struct vm_area_struct___292 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___292 *vm_next;
	struct vm_area_struct___292 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___291 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___280 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___291 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___291;

struct mm_struct___291 {
	struct {
		struct vm_area_struct___292 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___291 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___292 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___291 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___292 *owner;
		struct user_namespace___3 *user_ns;
		struct file___291 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___291 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___280)(struct vm_area_struct___292 *, long unsigned int, const struct page___292 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___280)(struct page___292 *, void *);

struct device___256;

struct dev_pagemap___280 {
	dev_page_fault_t___280 page_fault;
	dev_page_free_t___280 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___256 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct file___291 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___291 f_path;
	struct inode___291 *f_inode;
	const struct file_operations___291 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___195 f_owner;
	const struct cred___271 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___290 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___280;

struct vm_operations_struct___280 {
	void (*open)(struct vm_area_struct___292 *);
	void (*close)(struct vm_area_struct___292 *);
	int (*split)(struct vm_area_struct___292 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___292 *);
	vm_fault_t (*fault)(struct vm_fault___280 *);
	vm_fault_t (*huge_fault)(struct vm_fault___280 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___280 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___292 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___280 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___280 *);
	int (*access)(struct vm_area_struct___292 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___292 *);
	int (*set_policy)(struct vm_area_struct___292 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___292 *, long unsigned int);
	struct page___292 * (*find_special_page)(struct vm_area_struct___292 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___291 {
	struct task_struct___292 *task;
	struct core_thread___291 *next;
};

struct core_state___291 {
	atomic_t nr_threads;
	struct core_thread___291 dumper;
	struct completion startup;
};

struct vm_fault___280 {
	struct vm_area_struct___292 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___292 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___292 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___291 prealloc_pte;
};

struct key___271;

struct user_struct___271 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___271 *uid_keyring;
	struct key___271 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___271 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___271 *session_keyring;
	struct key___271 *process_keyring;
	struct key___271 *thread_keyring;
	struct key___271 *request_key_auth;
	void *security;
	struct user_struct___271 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct vm_struct___207 {
	struct vm_struct___207 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___292 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct kiocb___291 {
	struct file___291 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___291 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___290 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___291 *ia_file;
};

struct dquot___290 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___290 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___290 {
	int qf_fmt_id;
	const struct quota_format_ops___290 *qf_ops;
	struct module___234 *qf_owner;
	struct quota_format_type___290 *qf_next;
};

struct quota_format_ops___290 {
	int (*check_quota_file)(struct super_block___290 *, int);
	int (*read_file_info)(struct super_block___290 *, int);
	int (*write_file_info)(struct super_block___290 *, int);
	int (*free_file_info)(struct super_block___290 *, int);
	int (*read_dqblk)(struct dquot___290 *);
	int (*commit_dqblk)(struct dquot___290 *);
	int (*release_dqblk)(struct dquot___290 *);
	int (*get_next_id)(struct super_block___290 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___290 {
	int (*write_dquot)(struct dquot___290 *);
	struct dquot___290 * (*alloc_dquot)(struct super_block___290 *, int);
	void (*destroy_dquot)(struct dquot___290 *);
	int (*acquire_dquot)(struct dquot___290 *);
	int (*release_dquot)(struct dquot___290 *);
	int (*mark_dirty)(struct dquot___290 *);
	int (*write_info)(struct super_block___290 *, int);
	qsize_t * (*get_reserved_space)(struct inode___291 *);
	int (*get_projid)(struct inode___291 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___291 *, qsize_t *);
	int (*get_next_id)(struct super_block___290 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___290 {
	int (*quota_on)(struct super_block___290 *, int, int, const struct path___291 *);
	int (*quota_off)(struct super_block___290 *, int);
	int (*quota_enable)(struct super_block___290 *, unsigned int);
	int (*quota_disable)(struct super_block___290 *, unsigned int);
	int (*quota_sync)(struct super_block___290 *, int);
	int (*set_info)(struct super_block___290 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___290 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___290 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___290 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___290 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___290 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___277;

struct kobj_type___277;

struct kernfs_node___285;

struct kobject___278 {
	const char *name;
	struct list_head entry;
	struct kobject___278 *parent;
	struct kset___277 *kset;
	struct kobj_type___277 *ktype;
	struct kernfs_node___285 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___231 {
	struct kobject___278 kobj;
	struct module___234 *mod;
	struct kobject___278 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___231 {
	struct module___234 *mod;
	struct latch_tree_node node;
};

struct module_layout___231 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___231 mtn;
};

struct module_attribute___231;

struct kernel_param___231;

struct module___234 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___231 mkobj;
	struct module_attribute___231 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___278 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___231 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___231 core_layout;
	struct module_layout___231 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___290 {
	int (*writepage)(struct page___292 *, struct writeback_control___3 *);
	int (*readpage)(struct file___291 *, struct page___292 *);
	int (*writepages)(struct address_space___290 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___292 *);
	int (*readpages)(struct file___291 *, struct address_space___290 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___291 *, struct address_space___290 *, loff_t, unsigned int, unsigned int, struct page___292 **, void **);
	int (*write_end)(struct file___291 *, struct address_space___290 *, loff_t, unsigned int, unsigned int, struct page___292 *, void *);
	sector_t (*bmap)(struct address_space___290 *, sector_t);
	void (*invalidatepage)(struct page___292 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___292 *, gfp_t);
	void (*freepage)(struct page___292 *);
	ssize_t (*direct_IO)(struct kiocb___291 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___290 *, struct page___292 *, struct page___292 *, enum migrate_mode);
	bool (*isolate_page)(struct page___292 *, isolate_mode_t);
	void (*putback_page)(struct page___292 *);
	int (*launder_page)(struct page___292 *);
	int (*is_partially_uptodate)(struct page___292 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___292 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___290 *, struct page___292 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___291 *, sector_t *);
	void (*swap_deactivate)(struct file___291 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___290 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___291 *bd_inode;
	struct super_block___290 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___290 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___49 {
	struct kobject___278 kobj;
	struct module___234 *owner;
	const struct file_operations___291 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___290 {
	struct dentry___291 * (*lookup)(struct inode___291 *, struct dentry___291 *, unsigned int);
	const char * (*get_link)(struct dentry___291 *, struct inode___291 *, struct delayed_call *);
	int (*permission)(struct inode___291 *, int);
	struct posix_acl * (*get_acl)(struct inode___291 *, int);
	int (*readlink)(struct dentry___291 *, char *, int);
	int (*create)(struct inode___291 *, struct dentry___291 *, umode_t, bool);
	int (*link)(struct dentry___291 *, struct inode___291 *, struct dentry___291 *);
	int (*unlink)(struct inode___291 *, struct dentry___291 *);
	int (*symlink)(struct inode___291 *, struct dentry___291 *, const char *);
	int (*mkdir)(struct inode___291 *, struct dentry___291 *, umode_t);
	int (*rmdir)(struct inode___291 *, struct dentry___291 *);
	int (*mknod)(struct inode___291 *, struct dentry___291 *, umode_t, dev_t);
	int (*rename)(struct inode___291 *, struct dentry___291 *, struct inode___291 *, struct dentry___291 *, unsigned int);
	int (*setattr)(struct dentry___291 *, struct iattr___290 *);
	int (*getattr)(const struct path___291 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___291 *, char *, size_t);
	int (*fiemap)(struct inode___291 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___291 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___291 *, struct dentry___291 *, struct file___291 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___291 *, struct dentry___291 *, umode_t);
	int (*set_acl)(struct inode___291 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___290 {
	void (*fl_copy_lock)(struct file_lock___291 *, struct file_lock___291 *);
	void (*fl_release_private)(struct file_lock___291 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___290;

struct lock_manager_operations___290;

struct file_lock___291 {
	struct file_lock___291 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___291 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___290 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___290 *fl_ops;
	const struct lock_manager_operations___290 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___290 {
	int (*lm_compare_owner)(struct file_lock___291 *, struct file_lock___291 *);
	long unsigned int (*lm_owner_key)(struct file_lock___291 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___291 *);
	int (*lm_grant)(struct file_lock___291 *, int);
	bool (*lm_break)(struct file_lock___291 *);
	int (*lm_change)(struct file_lock___291 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___291 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___290 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___290 *fa_next;
	struct file___291 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___290 {
	const char *name;
	int fs_flags;
	struct dentry___291 * (*mount)(struct file_system_type___290 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___290 *);
	struct module___234 *owner;
	struct file_system_type___290 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___290 {
	struct inode___291 * (*alloc_inode)(struct super_block___290 *);
	void (*destroy_inode)(struct inode___291 *);
	void (*dirty_inode)(struct inode___291 *, int);
	int (*write_inode)(struct inode___291 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___291 *);
	void (*evict_inode)(struct inode___291 *);
	void (*put_super)(struct super_block___290 *);
	int (*sync_fs)(struct super_block___290 *, int);
	int (*freeze_super)(struct super_block___290 *);
	int (*freeze_fs)(struct super_block___290 *);
	int (*thaw_super)(struct super_block___290 *);
	int (*unfreeze_fs)(struct super_block___290 *);
	int (*statfs)(struct dentry___291 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___290 *, int *, char *);
	void (*umount_begin)(struct super_block___290 *);
	int (*show_options)(struct seq_file___249 *, struct dentry___291 *);
	int (*show_devname)(struct seq_file___249 *, struct dentry___291 *);
	int (*show_path)(struct seq_file___249 *, struct dentry___291 *);
	int (*show_stats)(struct seq_file___249 *, struct dentry___291 *);
	ssize_t (*quota_read)(struct super_block___290 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___290 *, int, const char *, size_t, loff_t);
	struct dquot___290 ** (*get_dquots)(struct inode___291 *);
	int (*bdev_try_to_free_page)(struct super_block___290 *, struct page___292 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___290 *, struct shrink_control___116 *);
	long int (*free_cached_objects)(struct super_block___290 *, struct shrink_control___116 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___179)(struct file___291 *, wait_queue_head_t *, struct poll_table_struct___176 *);

struct poll_table_struct___176 {
	poll_queue_proc___179 _qproc;
	__poll_t _key;
};

struct seq_operations___248;

struct seq_file___249 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___248 *op;
	int poll_event;
	const struct file___291 *file;
	void *private;
};

enum {
	CPER_SEV_RECOVERABLE = 0,
	CPER_SEV_FATAL = 1,
	CPER_SEV_CORRECTED = 2,
	CPER_SEV_INFORMATIONAL = 3,
};

struct kernfs_root___284;

struct kernfs_elem_dir___284 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___284 *root;
};

struct kernfs_syscall_ops___284;

struct kernfs_root___284 {
	struct kernfs_node___285 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___284 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___284 {
	struct kernfs_node___285 *target_kn;
};

struct kernfs_ops___284;

struct kernfs_elem_attr___284 {
	const struct kernfs_ops___284 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___285 *notify_next;
};

struct kernfs_node___285 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___285 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___284 dir;
		struct kernfs_elem_symlink___284 symlink;
		struct kernfs_elem_attr___284 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___284;

struct kernfs_ops___284 {
	int (*open)(struct kernfs_open_file___284 *);
	void (*release)(struct kernfs_open_file___284 *);
	int (*seq_show)(struct seq_file___249 *, void *);
	void * (*seq_start)(struct seq_file___249 *, loff_t *);
	void * (*seq_next)(struct seq_file___249 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___249 *, void *);
	ssize_t (*read)(struct kernfs_open_file___284 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___284 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___284 *, struct vm_area_struct___292 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___284 *, struct poll_table_struct___176 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___284 {
	int (*remount_fs)(struct kernfs_root___284 *, int *, char *);
	int (*show_options)(struct seq_file___249 *, struct kernfs_root___284 *);
	int (*mkdir)(struct kernfs_node___285 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___285 *);
	int (*rename)(struct kernfs_node___285 *, struct kernfs_node___285 *, const char *);
	int (*show_path)(struct seq_file___249 *, struct kernfs_node___285 *, struct kernfs_root___284 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___284 {
	struct kernfs_node___285 *kn;
	struct file___291 *file;
	struct seq_file___249 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___280 *vm_ops;
};

struct bin_attribute___254;

struct attribute_group___255 {
	const char *name;
	umode_t (*is_visible)(struct kobject___278 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___278 *, struct bin_attribute___254 *, int);
	struct attribute **attrs;
	struct bin_attribute___254 **bin_attrs;
};

struct bin_attribute___254 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___291 *, struct kobject___278 *, struct bin_attribute___254 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___291 *, struct kobject___278 *, struct bin_attribute___254 *, char *, loff_t, size_t);
	int (*mmap)(struct file___291 *, struct kobject___278 *, struct bin_attribute___254 *, struct vm_area_struct___292 *);
};

struct sysfs_ops___277 {
	ssize_t (*show)(struct kobject___278 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___278 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___277;

struct kset___277 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___278 kobj;
	const struct kset_uevent_ops___277 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___277 {
	void (*release)(struct kobject___278 *);
	const struct sysfs_ops___277 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___25 * (*child_ns_type)(struct kobject___278 *);
	const void * (*namespace)(struct kobject___278 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___277 {
	int (* const filter)(struct kset___277 *, struct kobject___278 *);
	const char * (* const name)(struct kset___277 *, struct kobject___278 *);
	int (* const uevent)(struct kset___277 *, struct kobject___278 *, struct kobj_uevent_env *);
};

struct kobj_attribute___270 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___278 *, struct kobj_attribute___270 *, char *);
	ssize_t (*store)(struct kobject___278 *, struct kobj_attribute___270 *, const char *, size_t);
};

struct dev_pm_ops___256 {
	int (*prepare)(struct device___256 *);
	void (*complete)(struct device___256 *);
	int (*suspend)(struct device___256 *);
	int (*resume)(struct device___256 *);
	int (*freeze)(struct device___256 *);
	int (*thaw)(struct device___256 *);
	int (*poweroff)(struct device___256 *);
	int (*restore)(struct device___256 *);
	int (*suspend_late)(struct device___256 *);
	int (*resume_early)(struct device___256 *);
	int (*freeze_late)(struct device___256 *);
	int (*thaw_early)(struct device___256 *);
	int (*poweroff_late)(struct device___256 *);
	int (*restore_early)(struct device___256 *);
	int (*suspend_noirq)(struct device___256 *);
	int (*resume_noirq)(struct device___256 *);
	int (*freeze_noirq)(struct device___256 *);
	int (*thaw_noirq)(struct device___256 *);
	int (*poweroff_noirq)(struct device___256 *);
	int (*restore_noirq)(struct device___256 *);
	int (*runtime_suspend)(struct device___256 *);
	int (*runtime_resume)(struct device___256 *);
	int (*runtime_idle)(struct device___256 *);
};

struct dev_pm_info___256 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___256 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___256;

struct bus_type___256;

struct device_driver___256;

struct dev_pm_domain___256;

struct dma_map_ops___78;

struct fwnode_handle___190;

struct class___256;

struct device___256 {
	struct device___256 *parent;
	struct device_private *p;
	struct kobject___278 kobj;
	const char *init_name;
	const struct device_type___256 *type;
	struct mutex mutex;
	struct bus_type___256 *bus;
	struct device_driver___256 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___256 power;
	struct dev_pm_domain___256 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___78 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___190 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___256 *class;
	const struct attribute_group___255 **groups;
	void (*release)(struct device___256 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___256 {
	struct dev_pm_ops___256 ops;
	void (*detach)(struct device___256 *, bool);
	int (*activate)(struct device___256 *);
	void (*sync)(struct device___256 *);
	void (*dismiss)(struct device___256 *);
};

struct bus_type___256 {
	const char *name;
	const char *dev_name;
	struct device___256 *dev_root;
	const struct attribute_group___255 **bus_groups;
	const struct attribute_group___255 **dev_groups;
	const struct attribute_group___255 **drv_groups;
	int (*match)(struct device___256 *, struct device_driver___256 *);
	int (*uevent)(struct device___256 *, struct kobj_uevent_env *);
	int (*probe)(struct device___256 *);
	int (*remove)(struct device___256 *);
	void (*shutdown)(struct device___256 *);
	int (*online)(struct device___256 *);
	int (*offline)(struct device___256 *);
	int (*suspend)(struct device___256 *, pm_message_t);
	int (*resume)(struct device___256 *);
	int (*num_vf)(struct device___256 *);
	int (*dma_configure)(struct device___256 *);
	const struct dev_pm_ops___256 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___256 {
	const char *name;
	struct bus_type___256 *bus;
	struct module___234 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___256 *);
	int (*remove)(struct device___256 *);
	void (*shutdown)(struct device___256 *);
	int (*suspend)(struct device___256 *, pm_message_t);
	int (*resume)(struct device___256 *);
	const struct attribute_group___255 **groups;
	const struct dev_pm_ops___256 *pm;
	void (*coredump)(struct device___256 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___256 {
	const char *name;
	const struct attribute_group___255 **groups;
	int (*uevent)(struct device___256 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___256 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___256 *);
	const struct dev_pm_ops___256 *pm;
};

struct class___256 {
	const char *name;
	struct module___234 *owner;
	const struct attribute_group___255 **class_groups;
	const struct attribute_group___255 **dev_groups;
	struct kobject___278 *dev_kobj;
	int (*dev_uevent)(struct device___256 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___256 *, umode_t *);
	void (*class_release)(struct class___256 *);
	void (*dev_release)(struct device___256 *);
	int (*shutdown_pre)(struct device___256 *);
	const struct kobj_ns_type_operations___25 *ns_type;
	const void * (*namespace)(struct device___256 *);
	const struct dev_pm_ops___256 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct device_attribute___14 {
	struct attribute attr;
	ssize_t (*show)(struct device___256 *, struct device_attribute___14 *, char *);
	ssize_t (*store)(struct device___256 *, struct device_attribute___14 *, const char *, size_t);
};

struct dma_map_ops___78 {
	void * (*alloc)(struct device___256 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___256 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___256 *, struct vm_area_struct___292 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___256 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___256 *, struct page___292 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___256 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___256 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___256 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___256 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___256 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___256 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___256 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___256 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___256 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___256 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___256 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___256 *, u64);
	u64 (*get_required_mask)(struct device___256 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___190;

struct fwnode_handle___190 {
	struct fwnode_handle___190 *secondary;
	const struct fwnode_operations___190 *ops;
};

struct fwnode_reference_args___190;

struct fwnode_endpoint___190;

struct fwnode_operations___190 {
	struct fwnode_handle___190 * (*get)(struct fwnode_handle___190 *);
	void (*put)(struct fwnode_handle___190 *);
	bool (*device_is_available)(const struct fwnode_handle___190 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___190 *, const struct device___256 *);
	bool (*property_present)(const struct fwnode_handle___190 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___190 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___190 *, const char *, const char **, size_t);
	struct fwnode_handle___190 * (*get_parent)(const struct fwnode_handle___190 *);
	struct fwnode_handle___190 * (*get_next_child_node)(const struct fwnode_handle___190 *, struct fwnode_handle___190 *);
	struct fwnode_handle___190 * (*get_named_child_node)(const struct fwnode_handle___190 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___190 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___190 *);
	struct fwnode_handle___190 * (*graph_get_next_endpoint)(const struct fwnode_handle___190 *, struct fwnode_handle___190 *);
	struct fwnode_handle___190 * (*graph_get_remote_endpoint)(const struct fwnode_handle___190 *);
	struct fwnode_handle___190 * (*graph_get_port_parent)(struct fwnode_handle___190 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___190 *, struct fwnode_endpoint___190 *);
};

struct fwnode_endpoint___190 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___190 *local_fwnode;
};

struct fwnode_reference_args___190 {
	struct fwnode_handle___190 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pci_bus___16;

struct pci_slot___16 {
	struct pci_bus___16 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject___278 kobj;
};

struct pci_dev___16;

struct pci_ops___16;

struct pci_bus___16 {
	struct list_head node;
	struct pci_bus___16 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___16 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___16 *ops;
	struct msi_controller___2 *msi;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	int domain_nr;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___256 *bridge;
	struct device___256 dev;
	struct bin_attribute___254 *legacy_io;
	struct bin_attribute___254 *legacy_mem;
	unsigned int is_added: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
};

struct pci_sriov___11 {
	int pos;
	int nres;
	u32 cap;
	u16 ctrl;
	u16 total_VFs;
	u16 initial_VFs;
	u16 num_VFs;
	u16 offset;
	u16 stride;
	u16 vf_device;
	u32 pgsz;
	u8 link;
	u8 max_VF_buses;
	u16 driver_max_VFs;
	struct pci_dev___16 *dev;
	struct pci_dev___16 *self;
	u32 class;
	u8 hdr_type;
	u16 subsystem_vendor;
	u16 subsystem_device;
	resource_size_t barsz[6];
	bool drivers_autoprobe;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct aer_stats___2;

struct pci_driver___16;

struct pci_dev___16 {
	struct list_head bus_list;
	struct pci_bus___16 *bus;
	struct pci_bus___16 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___16 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u16 aer_cap;
	struct aer_stats___2 *aer_stats;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	long unsigned int *dma_alias_mask;
	struct pci_driver___16 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	unsigned int imm_ready: 1;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int bridge_d3: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int hotplug_user_indicators: 1;
	unsigned int clear_retrain_link: 1;
	unsigned int d3_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	unsigned int ltr_path: 1;
	unsigned int eetlp_prefix_path: 1;
	pci_channel_state_t error_state;
	struct device___256 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int multifunction: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int ats_enabled: 1;
	unsigned int pasid_enabled: 1;
	unsigned int pri_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int reset_fn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int shpc_managed: 1;
	unsigned int is_thunderbolt: 1;
	unsigned int __aer_firmware_first_valid: 1;
	unsigned int __aer_firmware_first: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int irq_managed: 1;
	unsigned int has_secondary_link: 1;
	unsigned int non_compliant_bars: 1;
	unsigned int is_probed: 1;
	unsigned int link_active_reporting: 1;
	unsigned int untrusted: 1;
	unsigned int no_vf_scan: 1;
	unsigned int io_window: 1;
	unsigned int pref_window: 1;
	unsigned int pref_64_window: 1;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	struct bin_attribute___254 *rom_attr;
	int rom_attr_enabled;
	struct bin_attribute___254 *res_attr[17];
	struct bin_attribute___254 *res_attr_wc[17];
	unsigned int broken_cmd_compl: 1;
	const struct attribute_group___255 **msi_irq_groups;
	struct pci_vpd *vpd;
	union {
		struct pci_sriov___11 *sriov;
		struct pci_dev___16 *physfn;
	};
	u16 ats_cap;
	u8 ats_stu;
	atomic_t ats_ref_cnt;
	u32 pri_reqs_alloc;
	u16 pasid_features;
	struct pci_p2pdma *p2pdma;
	phys_addr_t rom;
	size_t romlen;
	char *driver_override;
	long unsigned int priv_flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t pci_dev_extended_size_rh;
	struct pci_dev_extended_rh pci_dev_extended_rh;
};

struct aer_stats___2 {
	u64 dev_cor_errs[16];
	u64 dev_fatal_errs[26];
	u64 dev_nonfatal_errs[26];
	u64 dev_total_cor_errs;
	u64 dev_total_fatal_errs;
	u64 dev_total_nonfatal_errs;
	u64 rootport_total_cor_errs;
	u64 rootport_total_fatal_errs;
	u64 rootport_total_nonfatal_errs;
};

struct pci_error_handlers___16;

struct pci_driver___16 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___16 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___16 *);
	int (*suspend)(struct pci_dev___16 *, pm_message_t);
	int (*suspend_late)(struct pci_dev___16 *, pm_message_t);
	int (*resume_early)(struct pci_dev___16 *);
	int (*resume)(struct pci_dev___16 *);
	void (*shutdown)(struct pci_dev___16 *);
	int (*sriov_configure)(struct pci_dev___16 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	const struct pci_error_handlers___16 *err_handler;
	const struct attribute_group___255 **groups;
	struct device_driver___256 driver;
	struct pci_dynids dynids;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct pci_ops___16 {
	int (*add_bus)(struct pci_bus___16 *);
	void (*remove_bus)(struct pci_bus___16 *);
	void * (*map_bus)(struct pci_bus___16 *, unsigned int, int);
	int (*read)(struct pci_bus___16 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___16 *, unsigned int, int, int, u32);
};

struct pci_error_handlers___16 {
	pci_ers_result_t (*error_detected)(struct pci_dev___16 *, enum pci_channel_state);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___16 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___16 *);
	void (*reset_prepare)(struct pci_dev___16 *);
	void (*reset_done)(struct pci_dev___16 *);
	void (*resume)(struct pci_dev___16 *);
};

typedef void compound_page_dtor___280(struct page___292 *);

struct acpi_hest_header {
	u16 type;
	u16 source_id;
};

enum acpi_hest_types {
	ACPI_HEST_TYPE_IA32_CHECK = 0,
	ACPI_HEST_TYPE_IA32_CORRECTED_CHECK = 1,
	ACPI_HEST_TYPE_IA32_NMI = 2,
	ACPI_HEST_TYPE_NOT_USED3 = 3,
	ACPI_HEST_TYPE_NOT_USED4 = 4,
	ACPI_HEST_TYPE_NOT_USED5 = 5,
	ACPI_HEST_TYPE_AER_ROOT_PORT = 6,
	ACPI_HEST_TYPE_AER_ENDPOINT = 7,
	ACPI_HEST_TYPE_AER_BRIDGE = 8,
	ACPI_HEST_TYPE_GENERIC_ERROR = 9,
	ACPI_HEST_TYPE_GENERIC_ERROR_V2 = 10,
	ACPI_HEST_TYPE_IA32_DEFERRED_CHECK = 11,
	ACPI_HEST_TYPE_RESERVED = 12,
};

struct acpi_hest_aer_common {
	u16 reserved1;
	u8 flags;
	u8 enabled;
	u32 records_to_preallocate;
	u32 max_sections_per_record;
	u32 bus;
	u16 device;
	u16 function;
	u16 device_control;
	u16 reserved2;
	u32 uncorrectable_mask;
	u32 uncorrectable_severity;
	u32 correctable_mask;
	u32 advanced_capabilities;
};

struct kernel_param_ops___231 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___231 *);
	int (*get)(char *, const struct kernel_param___231 *);
	void (*free)(void *);
};

struct kparam_array___231;

struct kernel_param___231 {
	const char *name;
	struct module___234 *mod;
	const struct kernel_param_ops___231 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___231 *arr;
	};
};

struct kparam_array___231 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___231 *ops;
	void *elem;
};

struct module_attribute___231 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___231 *, struct module_kobject___231 *, char *);
	ssize_t (*store)(struct module_attribute___231 *, struct module_kobject___231 *, const char *, size_t);
	void (*setup)(struct module___234 *, const char *);
	int (*test)(struct module___234 *);
	void (*free)(struct module___234 *);
};

typedef int (*key_restrict_link_func_t___272)(struct key___271 *, const struct key_type *, const union key_payload *, struct key___271 *);

struct key_restriction___271;

struct key___271 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___292 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___271 *restrict_link;
};

struct key_restriction___271 {
	key_restrict_link_func_t___272 check;
	struct key___271 *key;
	struct key_type *keytype;
};

struct seq_operations___248 {
	void * (*start)(struct seq_file___249 *, loff_t *);
	void (*stop)(struct seq_file___249 *, void *);
	void * (*next)(struct seq_file___249 *, void *, loff_t *);
	int (*show)(struct seq_file___249 *, void *);
};

struct aer_header_log_regs {
	unsigned int dw0;
	unsigned int dw1;
	unsigned int dw2;
	unsigned int dw3;
};

struct aer_capability_regs {
	u32 header;
	u32 uncor_status;
	u32 uncor_mask;
	u32 uncor_severity;
	u32 cor_status;
	u32 cor_mask;
	u32 cap_control;
	struct aer_header_log_regs header_log;
	u32 root_command;
	u32 root_status;
	u16 cor_err_source;
	u16 uncor_err_source;
};

struct aer_err_info {
	struct pci_dev___16 *dev[5];
	int error_dev_num;
	unsigned int id: 16;
	unsigned int severity: 2;
	unsigned int __pad1: 5;
	unsigned int multi_error_valid: 1;
	unsigned int first_error: 5;
	unsigned int __pad2: 2;
	unsigned int tlp_header_valid: 1;
	unsigned int status;
	unsigned int mask;
	struct aer_header_log_regs tlp;
};

struct pcie_device___3 {
	int irq;
	struct pci_dev___16 *port;
	u32 service;
	void *priv_data;
	struct device___256 device;
};

struct pcie_port_service_driver___3 {
	const char *name;
	int (*probe)(struct pcie_device___3 *);
	void (*remove)(struct pcie_device___3 *);
	int (*suspend)(struct pcie_device___3 *);
	int (*resume_noirq)(struct pcie_device___3 *);
	int (*resume)(struct pcie_device___3 *);
	int (*runtime_suspend)(struct pcie_device___3 *);
	int (*runtime_resume)(struct pcie_device___3 *);
	void (*error_resume)(struct pci_dev___16 *);
	pci_ers_result_t (*reset_link)(struct pci_dev___16 *);
	int port_type;
	u32 service;
	struct device_driver___256 driver;
};

struct aer_err_source {
	unsigned int status;
	unsigned int id;
};

struct aer_rpc {
	struct pci_dev___16 *rpd;
	struct {
		union {
			struct __kfifo kfifo;
			struct aer_err_source *type;
			const struct aer_err_source *const_type;
			char (*rectype)[0];
			struct aer_err_source *ptr;
			const struct aer_err_source *ptr_const;
		};
		struct aer_err_source buf[128];
	} aer_fifo;
};

struct aer_hest_parse_info {
	struct pci_dev___16 *pci_dev;
	int firmware_first;
};

struct aer_recover_entry {
	u8 bus;
	u8 devfn;
	u16 domain;
	int severity;
	struct aer_capability_regs *regs;
};

struct pcie_pme_service_data {
	spinlock_t lock;
	struct pcie_device *srv;
	struct work_struct work;
	bool noirq;
};

struct aer_err_info___2 {
	struct pci_dev___15 *dev[5];
	int error_dev_num;
	unsigned int id: 16;
	unsigned int severity: 2;
	unsigned int __pad1: 5;
	unsigned int multi_error_valid: 1;
	unsigned int first_error: 5;
	unsigned int __pad2: 2;
	unsigned int tlp_header_valid: 1;
	unsigned int status;
	unsigned int mask;
	struct aer_header_log_regs tlp;
};

struct dpc_dev {
	struct pcie_device *dev;
	u16 cap_pos;
	bool rp_extensions;
	u8 rp_log_size;
};

struct module___235;

struct file___292;

struct kiocb___292;

struct poll_table_struct___177;

struct vm_area_struct___293;

struct inode___292;

struct file_lock___292;

struct page___293;

struct seq_file___250;

struct file_operations___292 {
	struct module___235 *owner;
	loff_t (*llseek)(struct file___292 *, loff_t, int);
	ssize_t (*read)(struct file___292 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___292 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___292 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___292 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___292 *, bool);
	int (*iterate)(struct file___292 *, struct dir_context *);
	int (*iterate_shared)(struct file___292 *, struct dir_context *);
	__poll_t (*poll)(struct file___292 *, struct poll_table_struct___177 *);
	long int (*unlocked_ioctl)(struct file___292 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___292 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___292 *, struct vm_area_struct___293 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___292 *, struct file___292 *);
	int (*flush)(struct file___292 *, fl_owner_t);
	int (*release)(struct inode___292 *, struct file___292 *);
	int (*fsync)(struct file___292 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___292 *, int);
	int (*lock)(struct file___292 *, int, struct file_lock___292 *);
	ssize_t (*sendpage)(struct file___292 *, struct page___293 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___292 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___292 *, int, struct file_lock___292 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___292 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___292 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___292 *, long int, struct file_lock___292 **, void **);
	long int (*fallocate)(struct file___292 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___250 *, struct file___292 *);
	ssize_t (*copy_file_range)(struct file___292 *, loff_t, struct file___292 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___292 *, loff_t, struct file___292 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___292 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___292 {
	u64 seqnum;
	struct vm_area_struct___293 *vmas[4];
};

struct page_frag___292 {
	struct page___293 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___292;

struct cred___272;

struct vm_struct___208;

struct task_struct___293 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___293 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___292 *mm;
	struct mm_struct___292 *active_mm;
	struct vmacache___292 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___293 *real_parent;
	struct task_struct___293 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___293 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___195 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___195 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___195 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___272 *ptracer_cred;
	const struct cred___272 *real_cred;
	const struct cred___272 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___293 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___82 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___292 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___293 *oom_reaper_list;
	struct vm_struct___208 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___130 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___293 *pgtable_t___292;

struct address_space___291;

struct dev_pagemap___281;

struct page___293 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___291 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___293 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___292 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___292 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___281 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___292;

struct lruvec___292 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___292 *pgdat;
};

struct zone___292 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___292 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___292 {
	struct zone___292 *zone;
	int zone_idx;
};

struct zonelist___292 {
	struct zoneref___292 _zonerefs[25];
};

struct pglist_data___292 {
	struct zone___292 node_zones[3];
	struct zonelist___292 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___293 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___293 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___292 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___293 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___293 *owner;
};

struct secondary_data___293 {
	void *stack;
	struct task_struct___293 *task;
	long int status;
};

struct blocking_notifier_head___292 {
	struct rw_semaphore___293 rwsem;
	struct notifier_block *head;
};

struct vfsmount___65;

struct dentry___292;

struct path___292 {
	struct vfsmount___65 *mnt;
	struct dentry___292 *dentry;
};

struct file___292 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___292 f_path;
	struct inode___292 *f_inode;
	const struct file_operations___292 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___195 f_owner;
	const struct cred___272 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___291 *f_mapping;
	errseq_t f_wb_err;
};

struct key___272;

struct user_struct___272;

struct cred___272 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___272 *session_keyring;
	struct key___272 *process_keyring;
	struct key___272 *thread_keyring;
	struct key___272 *request_key_auth;
	void *security;
	struct user_struct___272 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___285;

struct kernfs_elem_dir___285 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___285 *root;
};

struct kernfs_node___286;

struct kernfs_syscall_ops___285;

struct kernfs_root___285 {
	struct kernfs_node___286 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___285 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___285 {
	struct kernfs_node___286 *target_kn;
};

struct kernfs_ops___285;

struct kernfs_elem_attr___285 {
	const struct kernfs_ops___285 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___286 *notify_next;
};

struct kernfs_node___286 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___286 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___285 dir;
		struct kernfs_elem_symlink___285 symlink;
		struct kernfs_elem_attr___285 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___285;

struct kernfs_ops___285 {
	int (*open)(struct kernfs_open_file___285 *);
	void (*release)(struct kernfs_open_file___285 *);
	int (*seq_show)(struct seq_file___250 *, void *);
	void * (*seq_start)(struct seq_file___250 *, loff_t *);
	void * (*seq_next)(struct seq_file___250 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___250 *, void *);
	ssize_t (*read)(struct kernfs_open_file___285 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___285 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___285 *, struct vm_area_struct___293 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___285 *, struct poll_table_struct___177 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___285 {
	int (*remount_fs)(struct kernfs_root___285 *, int *, char *);
	int (*show_options)(struct seq_file___250 *, struct kernfs_root___285 *);
	int (*mkdir)(struct kernfs_node___286 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___286 *);
	int (*rename)(struct kernfs_node___286 *, struct kernfs_node___286 *, const char *);
	int (*show_path)(struct seq_file___250 *, struct kernfs_node___286 *, struct kernfs_root___285 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___249;

struct seq_file___250 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___249 *op;
	int poll_event;
	const struct file___292 *file;
	void *private;
};

struct vm_operations_struct___281;

struct kernfs_open_file___285 {
	struct kernfs_node___286 *kn;
	struct file___292 *file;
	struct seq_file___250 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___281 *vm_ops;
};

struct vm_fault___281;

struct vm_operations_struct___281 {
	void (*open)(struct vm_area_struct___293 *);
	void (*close)(struct vm_area_struct___293 *);
	int (*split)(struct vm_area_struct___293 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___293 *);
	vm_fault_t (*fault)(struct vm_fault___281 *);
	vm_fault_t (*huge_fault)(struct vm_fault___281 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___281 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___293 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___281 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___281 *);
	int (*access)(struct vm_area_struct___293 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___293 *);
	int (*set_policy)(struct vm_area_struct___293 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___293 *, long unsigned int);
	struct page___293 * (*find_special_page)(struct vm_area_struct___293 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___180)(struct file___292 *, wait_queue_head_t *, struct poll_table_struct___177 *);

struct poll_table_struct___177 {
	poll_queue_proc___180 _qproc;
	__poll_t _key;
};

struct vm_area_struct___293 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___293 *vm_next;
	struct vm_area_struct___293 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___292 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___281 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___292 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___279;

struct bin_attribute___255;

struct attribute_group___256 {
	const char *name;
	umode_t (*is_visible)(struct kobject___279 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___279 *, struct bin_attribute___255 *, int);
	struct attribute **attrs;
	struct bin_attribute___255 **bin_attrs;
};

struct kset___278;

struct kobj_type___278;

struct kobject___279 {
	const char *name;
	struct list_head entry;
	struct kobject___279 *parent;
	struct kset___278 *kset;
	struct kobj_type___278 *ktype;
	struct kernfs_node___286 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___255 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___292 *, struct kobject___279 *, struct bin_attribute___255 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___292 *, struct kobject___279 *, struct bin_attribute___255 *, char *, loff_t, size_t);
	int (*mmap)(struct file___292 *, struct kobject___279 *, struct bin_attribute___255 *, struct vm_area_struct___293 *);
};

struct sysfs_ops___278 {
	ssize_t (*show)(struct kobject___279 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___279 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___278;

struct kset___278 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___279 kobj;
	const struct kset_uevent_ops___278 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___278 {
	void (*release)(struct kobject___279 *);
	const struct sysfs_ops___278 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___25 * (*child_ns_type)(struct kobject___279 *);
	const void * (*namespace)(struct kobject___279 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___278 {
	int (* const filter)(struct kset___278 *, struct kobject___279 *);
	const char * (* const name)(struct kset___278 *, struct kobject___279 *);
	int (* const uevent)(struct kset___278 *, struct kobject___279 *, struct kobj_uevent_env *);
};

struct kobj_attribute___271 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___279 *, struct kobj_attribute___271 *, char *);
	ssize_t (*store)(struct kobject___279 *, struct kobj_attribute___271 *, const char *, size_t);
};

struct kernel_param___232;

struct kernel_param_ops___232 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___232 *);
	int (*get)(char *, const struct kernel_param___232 *);
	void (*free)(void *);
};

struct kparam_array___232;

struct kernel_param___232 {
	const char *name;
	struct module___235 *mod;
	const struct kernel_param_ops___232 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___232 *arr;
	};
};

struct kparam_array___232 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___232 *ops;
	void *elem;
};

struct module_kobject___232 {
	struct kobject___279 kobj;
	struct module___235 *mod;
	struct kobject___279 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___232 {
	struct module___235 *mod;
	struct latch_tree_node node;
};

struct module_layout___232 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___232 mtn;
};

struct module_attribute___232;

struct module___235 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___232 mkobj;
	struct module_attribute___232 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___279 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___232 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___232 core_layout;
	struct module_layout___232 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___232 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___232 *, struct module_kobject___232 *, char *);
	ssize_t (*store)(struct module_attribute___232 *, struct module_kobject___232 *, const char *, size_t);
	void (*setup)(struct module___235 *, const char *);
	int (*test)(struct module___235 *);
	void (*free)(struct module___235 *);
};

struct core_state___292;

struct mm_struct___292 {
	struct {
		struct vm_area_struct___293 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___292 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___293 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___292 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___293 *owner;
		struct user_namespace___3 *user_ns;
		struct file___292 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___292 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___291;

struct address_space___291 {
	struct inode___292 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___293 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___291 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___281)(struct vm_area_struct___293 *, long unsigned int, const struct page___293 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___281)(struct page___293 *, void *);

struct device___257;

struct dev_pagemap___281 {
	dev_page_fault_t___281 page_fault;
	dev_page_free_t___281 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___257 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___292 {
	struct task_struct___293 *task;
	struct core_thread___292 *next;
};

struct core_state___292 {
	atomic_t nr_threads;
	struct core_thread___292 dumper;
	struct completion startup;
};

struct vm_fault___281 {
	struct vm_area_struct___293 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___293 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___293 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___292 prealloc_pte;
};

struct user_struct___272 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___272 *uid_keyring;
	struct key___272 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_struct___208 {
	struct vm_struct___208 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___293 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dev_pm_info___257 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___257 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___257;

struct bus_type___257;

struct device_driver___257;

struct dev_pm_domain___257;

struct dma_map_ops___79;

struct fwnode_handle___191;

struct class___257;

struct device___257 {
	struct device___257 *parent;
	struct device_private *p;
	struct kobject___279 kobj;
	const char *init_name;
	const struct device_type___257 *type;
	struct mutex mutex;
	struct bus_type___257 *bus;
	struct device_driver___257 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___257 power;
	struct dev_pm_domain___257 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___79 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___191 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___257 *class;
	const struct attribute_group___256 **groups;
	void (*release)(struct device___257 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___291;

struct super_block___291;

struct dentry___292 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___292 *d_parent;
	struct qstr d_name;
	struct inode___292 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___291 *d_op;
	struct super_block___291 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___291;

struct block_device___291;

struct cdev___50;

struct inode___292 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___291 *i_op;
	struct super_block___291 *i_sb;
	struct address_space___291 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___293 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___292 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___291 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___291 *i_bdev;
		struct cdev___50 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___291 {
	int (*d_revalidate)(struct dentry___292 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___292 *, unsigned int);
	int (*d_hash)(const struct dentry___292 *, struct qstr *);
	int (*d_compare)(const struct dentry___292 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___292 *);
	int (*d_init)(struct dentry___292 *);
	void (*d_release)(struct dentry___292 *);
	void (*d_prune)(struct dentry___292 *);
	void (*d_iput)(struct dentry___292 *, struct inode___292 *);
	char * (*d_dname)(struct dentry___292 *, char *, int);
	struct vfsmount___65 * (*d_automount)(struct path___292 *);
	int (*d_manage)(const struct path___292 *, bool);
	struct dentry___292 * (*d_real)(struct dentry___292 *, const struct inode___292 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___291;

struct mem_dqinfo___291 {
	struct quota_format_type___291 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___291;

struct quota_info___291 {
	unsigned int flags;
	struct rw_semaphore___293 dqio_sem;
	struct inode___292 *files[3];
	struct mem_dqinfo___291 info[3];
	const struct quota_format_ops___291 *ops[3];
};

struct rcuwait___291 {
	struct task_struct___293 *task;
};

struct percpu_rw_semaphore___291 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___293 rw_sem;
	struct rcuwait___291 writer;
	int readers_block;
};

struct sb_writers___291 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___291 rw_sem[3];
};

struct file_system_type___291;

struct super_operations___291;

struct dquot_operations___291;

struct quotactl_ops___291;

struct super_block___291 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___291 *s_type;
	const struct super_operations___291 *s_op;
	const struct dquot_operations___291 *dq_op;
	const struct quotactl_ops___291 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___292 *s_root;
	struct rw_semaphore___293 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___291 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___291 s_dquot;
	struct sb_writers___291 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___291 *s_d_op;
	int cleancache_poolid;
	struct shrinker___116 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___65 {
	struct dentry___292 *mnt_root;
	struct super_block___291 *mnt_sb;
	int mnt_flags;
};

struct kiocb___292 {
	struct file___292 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___292 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___291 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___292 *ia_file;
};

struct dquot___291 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___291 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___291 {
	int qf_fmt_id;
	const struct quota_format_ops___291 *qf_ops;
	struct module___235 *qf_owner;
	struct quota_format_type___291 *qf_next;
};

struct quota_format_ops___291 {
	int (*check_quota_file)(struct super_block___291 *, int);
	int (*read_file_info)(struct super_block___291 *, int);
	int (*write_file_info)(struct super_block___291 *, int);
	int (*free_file_info)(struct super_block___291 *, int);
	int (*read_dqblk)(struct dquot___291 *);
	int (*commit_dqblk)(struct dquot___291 *);
	int (*release_dqblk)(struct dquot___291 *);
	int (*get_next_id)(struct super_block___291 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___291 {
	int (*write_dquot)(struct dquot___291 *);
	struct dquot___291 * (*alloc_dquot)(struct super_block___291 *, int);
	void (*destroy_dquot)(struct dquot___291 *);
	int (*acquire_dquot)(struct dquot___291 *);
	int (*release_dquot)(struct dquot___291 *);
	int (*mark_dirty)(struct dquot___291 *);
	int (*write_info)(struct super_block___291 *, int);
	qsize_t * (*get_reserved_space)(struct inode___292 *);
	int (*get_projid)(struct inode___292 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___292 *, qsize_t *);
	int (*get_next_id)(struct super_block___291 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___291 {
	int (*quota_on)(struct super_block___291 *, int, int, const struct path___292 *);
	int (*quota_off)(struct super_block___291 *, int);
	int (*quota_enable)(struct super_block___291 *, unsigned int);
	int (*quota_disable)(struct super_block___291 *, unsigned int);
	int (*quota_sync)(struct super_block___291 *, int);
	int (*set_info)(struct super_block___291 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___291 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___291 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___291 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___291 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___291 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___291 {
	int (*writepage)(struct page___293 *, struct writeback_control___3 *);
	int (*readpage)(struct file___292 *, struct page___293 *);
	int (*writepages)(struct address_space___291 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___293 *);
	int (*readpages)(struct file___292 *, struct address_space___291 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___292 *, struct address_space___291 *, loff_t, unsigned int, unsigned int, struct page___293 **, void **);
	int (*write_end)(struct file___292 *, struct address_space___291 *, loff_t, unsigned int, unsigned int, struct page___293 *, void *);
	sector_t (*bmap)(struct address_space___291 *, sector_t);
	void (*invalidatepage)(struct page___293 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___293 *, gfp_t);
	void (*freepage)(struct page___293 *);
	ssize_t (*direct_IO)(struct kiocb___292 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___291 *, struct page___293 *, struct page___293 *, enum migrate_mode);
	bool (*isolate_page)(struct page___293 *, isolate_mode_t);
	void (*putback_page)(struct page___293 *);
	int (*launder_page)(struct page___293 *);
	int (*is_partially_uptodate)(struct page___293 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___293 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___291 *, struct page___293 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___292 *, sector_t *);
	void (*swap_deactivate)(struct file___292 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___291 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___292 *bd_inode;
	struct super_block___291 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___291 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___50 {
	struct kobject___279 kobj;
	struct module___235 *owner;
	const struct file_operations___292 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___291 {
	struct dentry___292 * (*lookup)(struct inode___292 *, struct dentry___292 *, unsigned int);
	const char * (*get_link)(struct dentry___292 *, struct inode___292 *, struct delayed_call *);
	int (*permission)(struct inode___292 *, int);
	struct posix_acl * (*get_acl)(struct inode___292 *, int);
	int (*readlink)(struct dentry___292 *, char *, int);
	int (*create)(struct inode___292 *, struct dentry___292 *, umode_t, bool);
	int (*link)(struct dentry___292 *, struct inode___292 *, struct dentry___292 *);
	int (*unlink)(struct inode___292 *, struct dentry___292 *);
	int (*symlink)(struct inode___292 *, struct dentry___292 *, const char *);
	int (*mkdir)(struct inode___292 *, struct dentry___292 *, umode_t);
	int (*rmdir)(struct inode___292 *, struct dentry___292 *);
	int (*mknod)(struct inode___292 *, struct dentry___292 *, umode_t, dev_t);
	int (*rename)(struct inode___292 *, struct dentry___292 *, struct inode___292 *, struct dentry___292 *, unsigned int);
	int (*setattr)(struct dentry___292 *, struct iattr___291 *);
	int (*getattr)(const struct path___292 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___292 *, char *, size_t);
	int (*fiemap)(struct inode___292 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___292 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___292 *, struct dentry___292 *, struct file___292 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___292 *, struct dentry___292 *, umode_t);
	int (*set_acl)(struct inode___292 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___291 {
	void (*fl_copy_lock)(struct file_lock___292 *, struct file_lock___292 *);
	void (*fl_release_private)(struct file_lock___292 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___291;

struct lock_manager_operations___291;

struct file_lock___292 {
	struct file_lock___292 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___292 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___291 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___291 *fl_ops;
	const struct lock_manager_operations___291 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___291 {
	int (*lm_compare_owner)(struct file_lock___292 *, struct file_lock___292 *);
	long unsigned int (*lm_owner_key)(struct file_lock___292 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___292 *);
	int (*lm_grant)(struct file_lock___292 *, int);
	bool (*lm_break)(struct file_lock___292 *);
	int (*lm_change)(struct file_lock___292 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___292 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___291 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___291 *fa_next;
	struct file___292 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___291 {
	const char *name;
	int fs_flags;
	struct dentry___292 * (*mount)(struct file_system_type___291 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___291 *);
	struct module___235 *owner;
	struct file_system_type___291 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___291 {
	struct inode___292 * (*alloc_inode)(struct super_block___291 *);
	void (*destroy_inode)(struct inode___292 *);
	void (*dirty_inode)(struct inode___292 *, int);
	int (*write_inode)(struct inode___292 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___292 *);
	void (*evict_inode)(struct inode___292 *);
	void (*put_super)(struct super_block___291 *);
	int (*sync_fs)(struct super_block___291 *, int);
	int (*freeze_super)(struct super_block___291 *);
	int (*freeze_fs)(struct super_block___291 *);
	int (*thaw_super)(struct super_block___291 *);
	int (*unfreeze_fs)(struct super_block___291 *);
	int (*statfs)(struct dentry___292 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___291 *, int *, char *);
	void (*umount_begin)(struct super_block___291 *);
	int (*show_options)(struct seq_file___250 *, struct dentry___292 *);
	int (*show_devname)(struct seq_file___250 *, struct dentry___292 *);
	int (*show_path)(struct seq_file___250 *, struct dentry___292 *);
	int (*show_stats)(struct seq_file___250 *, struct dentry___292 *);
	ssize_t (*quota_read)(struct super_block___291 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___291 *, int, const char *, size_t, loff_t);
	struct dquot___291 ** (*get_dquots)(struct inode___292 *);
	int (*bdev_try_to_free_page)(struct super_block___291 *, struct page___293 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___291 *, struct shrink_control___116 *);
	long int (*free_cached_objects)(struct super_block___291 *, struct shrink_control___116 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___281(struct page___293 *);

struct dev_pm_ops___257 {
	int (*prepare)(struct device___257 *);
	void (*complete)(struct device___257 *);
	int (*suspend)(struct device___257 *);
	int (*resume)(struct device___257 *);
	int (*freeze)(struct device___257 *);
	int (*thaw)(struct device___257 *);
	int (*poweroff)(struct device___257 *);
	int (*restore)(struct device___257 *);
	int (*suspend_late)(struct device___257 *);
	int (*resume_early)(struct device___257 *);
	int (*freeze_late)(struct device___257 *);
	int (*thaw_early)(struct device___257 *);
	int (*poweroff_late)(struct device___257 *);
	int (*restore_early)(struct device___257 *);
	int (*suspend_noirq)(struct device___257 *);
	int (*resume_noirq)(struct device___257 *);
	int (*freeze_noirq)(struct device___257 *);
	int (*thaw_noirq)(struct device___257 *);
	int (*poweroff_noirq)(struct device___257 *);
	int (*restore_noirq)(struct device___257 *);
	int (*runtime_suspend)(struct device___257 *);
	int (*runtime_resume)(struct device___257 *);
	int (*runtime_idle)(struct device___257 *);
};

struct dev_pm_domain___257 {
	struct dev_pm_ops___257 ops;
	void (*detach)(struct device___257 *, bool);
	int (*activate)(struct device___257 *);
	void (*sync)(struct device___257 *);
	void (*dismiss)(struct device___257 *);
};

struct bus_type___257 {
	const char *name;
	const char *dev_name;
	struct device___257 *dev_root;
	const struct attribute_group___256 **bus_groups;
	const struct attribute_group___256 **dev_groups;
	const struct attribute_group___256 **drv_groups;
	int (*match)(struct device___257 *, struct device_driver___257 *);
	int (*uevent)(struct device___257 *, struct kobj_uevent_env *);
	int (*probe)(struct device___257 *);
	int (*remove)(struct device___257 *);
	void (*shutdown)(struct device___257 *);
	int (*online)(struct device___257 *);
	int (*offline)(struct device___257 *);
	int (*suspend)(struct device___257 *, pm_message_t);
	int (*resume)(struct device___257 *);
	int (*num_vf)(struct device___257 *);
	int (*dma_configure)(struct device___257 *);
	const struct dev_pm_ops___257 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___257 {
	const char *name;
	struct bus_type___257 *bus;
	struct module___235 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___257 *);
	int (*remove)(struct device___257 *);
	void (*shutdown)(struct device___257 *);
	int (*suspend)(struct device___257 *, pm_message_t);
	int (*resume)(struct device___257 *);
	const struct attribute_group___256 **groups;
	const struct dev_pm_ops___257 *pm;
	void (*coredump)(struct device___257 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___257 {
	const char *name;
	const struct attribute_group___256 **groups;
	int (*uevent)(struct device___257 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___257 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___257 *);
	const struct dev_pm_ops___257 *pm;
};

struct class___257 {
	const char *name;
	struct module___235 *owner;
	const struct attribute_group___256 **class_groups;
	const struct attribute_group___256 **dev_groups;
	struct kobject___279 *dev_kobj;
	int (*dev_uevent)(struct device___257 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___257 *, umode_t *);
	void (*class_release)(struct class___257 *);
	void (*dev_release)(struct device___257 *);
	int (*shutdown_pre)(struct device___257 *);
	const struct kobj_ns_type_operations___25 *ns_type;
	const void * (*namespace)(struct device___257 *);
	const struct dev_pm_ops___257 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___79 {
	void * (*alloc)(struct device___257 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___257 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___257 *, struct vm_area_struct___293 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___257 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___257 *, struct page___293 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___257 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___257 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___257 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___257 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___257 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___257 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___257 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___257 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___257 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___257 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___257 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___257 *, u64);
	u64 (*get_required_mask)(struct device___257 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___191;

struct fwnode_handle___191 {
	struct fwnode_handle___191 *secondary;
	const struct fwnode_operations___191 *ops;
};

struct fwnode_reference_args___191;

struct fwnode_endpoint___191;

struct fwnode_operations___191 {
	struct fwnode_handle___191 * (*get)(struct fwnode_handle___191 *);
	void (*put)(struct fwnode_handle___191 *);
	bool (*device_is_available)(const struct fwnode_handle___191 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___191 *, const struct device___257 *);
	bool (*property_present)(const struct fwnode_handle___191 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___191 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___191 *, const char *, const char **, size_t);
	struct fwnode_handle___191 * (*get_parent)(const struct fwnode_handle___191 *);
	struct fwnode_handle___191 * (*get_next_child_node)(const struct fwnode_handle___191 *, struct fwnode_handle___191 *);
	struct fwnode_handle___191 * (*get_named_child_node)(const struct fwnode_handle___191 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___191 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___191 *);
	struct fwnode_handle___191 * (*graph_get_next_endpoint)(const struct fwnode_handle___191 *, struct fwnode_handle___191 *);
	struct fwnode_handle___191 * (*graph_get_remote_endpoint)(const struct fwnode_handle___191 *);
	struct fwnode_handle___191 * (*graph_get_port_parent)(struct fwnode_handle___191 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___191 *, struct fwnode_endpoint___191 *);
};

struct fwnode_endpoint___191 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___191 *local_fwnode;
};

struct fwnode_reference_args___191 {
	struct fwnode_handle___191 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pci_bus___17;

struct hotplug_slot___4;

struct pci_slot___17 {
	struct pci_bus___17 *bus;
	struct list_head list;
	struct hotplug_slot___4 *hotplug;
	unsigned char number;
	struct kobject___279 kobj;
};

struct pci_dev___17;

struct pci_ops___17;

struct pci_bus___17 {
	struct list_head node;
	struct pci_bus___17 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___17 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___17 *ops;
	struct msi_controller___2 *msi;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	int domain_nr;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___257 *bridge;
	struct device___257 dev;
	struct bin_attribute___255 *legacy_io;
	struct bin_attribute___255 *legacy_mem;
	unsigned int is_added: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
};

struct hotplug_slot_ops___4;

struct hotplug_slot___4 {
	const struct hotplug_slot_ops___4 *ops;
	struct list_head slot_list;
	struct pci_slot___17 *pci_slot;
	struct module___235 *owner;
	const char *mod_name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct pci_sriov___12 {
	int pos;
	int nres;
	u32 cap;
	u16 ctrl;
	u16 total_VFs;
	u16 initial_VFs;
	u16 num_VFs;
	u16 offset;
	u16 stride;
	u16 vf_device;
	u32 pgsz;
	u8 link;
	u8 max_VF_buses;
	u16 driver_max_VFs;
	struct pci_dev___17 *dev;
	struct pci_dev___17 *self;
	u32 class;
	u8 hdr_type;
	u16 subsystem_vendor;
	u16 subsystem_device;
	resource_size_t barsz[6];
	bool drivers_autoprobe;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct pci_driver___17;

struct pci_dev___17 {
	struct list_head bus_list;
	struct pci_bus___17 *bus;
	struct pci_bus___17 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___17 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u16 aer_cap;
	struct aer_stats *aer_stats;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	long unsigned int *dma_alias_mask;
	struct pci_driver___17 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	unsigned int imm_ready: 1;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int bridge_d3: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int hotplug_user_indicators: 1;
	unsigned int clear_retrain_link: 1;
	unsigned int d3_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	unsigned int ltr_path: 1;
	unsigned int eetlp_prefix_path: 1;
	pci_channel_state_t error_state;
	struct device___257 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int multifunction: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int ats_enabled: 1;
	unsigned int pasid_enabled: 1;
	unsigned int pri_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int reset_fn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int shpc_managed: 1;
	unsigned int is_thunderbolt: 1;
	unsigned int __aer_firmware_first_valid: 1;
	unsigned int __aer_firmware_first: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int irq_managed: 1;
	unsigned int has_secondary_link: 1;
	unsigned int non_compliant_bars: 1;
	unsigned int is_probed: 1;
	unsigned int link_active_reporting: 1;
	unsigned int untrusted: 1;
	unsigned int no_vf_scan: 1;
	unsigned int io_window: 1;
	unsigned int pref_window: 1;
	unsigned int pref_64_window: 1;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	struct bin_attribute___255 *rom_attr;
	int rom_attr_enabled;
	struct bin_attribute___255 *res_attr[17];
	struct bin_attribute___255 *res_attr_wc[17];
	unsigned int broken_cmd_compl: 1;
	const struct attribute_group___256 **msi_irq_groups;
	struct pci_vpd *vpd;
	union {
		struct pci_sriov___12 *sriov;
		struct pci_dev___17 *physfn;
	};
	u16 ats_cap;
	u8 ats_stu;
	atomic_t ats_ref_cnt;
	u32 pri_reqs_alloc;
	u16 pasid_features;
	struct pci_p2pdma *p2pdma;
	phys_addr_t rom;
	size_t romlen;
	char *driver_override;
	long unsigned int priv_flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t pci_dev_extended_size_rh;
	struct pci_dev_extended_rh pci_dev_extended_rh;
};

struct pci_error_handlers___17;

struct pci_driver___17 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___17 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___17 *);
	int (*suspend)(struct pci_dev___17 *, pm_message_t);
	int (*suspend_late)(struct pci_dev___17 *, pm_message_t);
	int (*resume_early)(struct pci_dev___17 *);
	int (*resume)(struct pci_dev___17 *);
	void (*shutdown)(struct pci_dev___17 *);
	int (*sriov_configure)(struct pci_dev___17 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	const struct pci_error_handlers___17 *err_handler;
	const struct attribute_group___256 **groups;
	struct device_driver___257 driver;
	struct pci_dynids dynids;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct pci_ops___17 {
	int (*add_bus)(struct pci_bus___17 *);
	void (*remove_bus)(struct pci_bus___17 *);
	void * (*map_bus)(struct pci_bus___17 *, unsigned int, int);
	int (*read)(struct pci_bus___17 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___17 *, unsigned int, int, int, u32);
};

struct pci_error_handlers___17 {
	pci_ers_result_t (*error_detected)(struct pci_dev___17 *, enum pci_channel_state);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___17 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___17 *);
	void (*reset_prepare)(struct pci_dev___17 *);
	void (*reset_done)(struct pci_dev___17 *);
	void (*resume)(struct pci_dev___17 *);
};

struct hotplug_slot_ops___4 {
	int (*enable_slot)(struct hotplug_slot___4 *);
	int (*disable_slot)(struct hotplug_slot___4 *);
	int (*set_attention_status)(struct hotplug_slot___4 *, u8);
	int (*hardware_test)(struct hotplug_slot___4 *, u32);
	int (*get_power_status)(struct hotplug_slot___4 *, u8 *);
	int (*get_attention_status)(struct hotplug_slot___4 *, u8 *);
	int (*get_latch_status)(struct hotplug_slot___4 *, u8 *);
	int (*get_adapter_status)(struct hotplug_slot___4 *, u8 *);
	int (*reset_slot)(struct hotplug_slot___4 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef int (*key_restrict_link_func_t___273)(struct key___272 *, const struct key_type *, const union key_payload *, struct key___272 *);

struct key_restriction___272;

struct key___272 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___293 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___272 *restrict_link;
};

struct key_restriction___272 {
	key_restrict_link_func_t___273 check;
	struct key___272 *key;
	struct key_type *keytype;
};

struct seq_operations___249 {
	void * (*start)(struct seq_file___250 *, loff_t *);
	void (*stop)(struct seq_file___250 *, void *);
	void * (*next)(struct seq_file___250 *, void *, loff_t *);
	int (*show)(struct seq_file___250 *, void *);
};

struct pci_slot_attribute___2 {
	struct attribute attr;
	ssize_t (*show)(struct pci_slot___17 *, char *);
	ssize_t (*store)(struct pci_slot___17 *, const char *, size_t);
};

struct acpi_pci_root___2 {
	struct acpi_device___5 *device;
	struct pci_bus___14 *bus;
	u16 segment;
	struct resource secondary;
	u32 osc_support_set;
	u32 osc_control_set;
	phys_addr_t mcfg_addr;
};

struct controller {
	struct pcie_device *pcie;
	u32 slot_cap;
	u16 slot_ctrl;
	struct mutex ctrl_lock;
	long unsigned int cmd_started;
	unsigned int cmd_busy: 1;
	wait_queue_head_t queue;
	atomic_t pending_events;
	unsigned int notification_enabled: 1;
	unsigned int power_fault_detected;
	struct task_struct___288 *poll_thread;
	u8 state;
	struct mutex state_lock;
	struct delayed_work button_work;
	struct hotplug_slot hotplug_slot;
	struct rw_semaphore___288 reset_lock;
	int request_result;
	wait_queue_head_t requester;
};

struct module___236;

struct file___293;

struct kiocb___293;

struct poll_table_struct___178;

struct vm_area_struct___294;

struct inode___293;

struct file_lock___293;

struct page___294;

struct seq_file___251;

struct file_operations___293 {
	struct module___236 *owner;
	loff_t (*llseek)(struct file___293 *, loff_t, int);
	ssize_t (*read)(struct file___293 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___293 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___293 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___293 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___293 *, bool);
	int (*iterate)(struct file___293 *, struct dir_context *);
	int (*iterate_shared)(struct file___293 *, struct dir_context *);
	__poll_t (*poll)(struct file___293 *, struct poll_table_struct___178 *);
	long int (*unlocked_ioctl)(struct file___293 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___293 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___293 *, struct vm_area_struct___294 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___293 *, struct file___293 *);
	int (*flush)(struct file___293 *, fl_owner_t);
	int (*release)(struct inode___293 *, struct file___293 *);
	int (*fsync)(struct file___293 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___293 *, int);
	int (*lock)(struct file___293 *, int, struct file_lock___293 *);
	ssize_t (*sendpage)(struct file___293 *, struct page___294 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___293 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___293 *, int, struct file_lock___293 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___293 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___293 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___293 *, long int, struct file_lock___293 **, void **);
	long int (*fallocate)(struct file___293 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___251 *, struct file___293 *);
	ssize_t (*copy_file_range)(struct file___293 *, loff_t, struct file___293 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___293 *, loff_t, struct file___293 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___293 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___293 {
	u64 seqnum;
	struct vm_area_struct___294 *vmas[4];
};

struct page_frag___293 {
	struct page___294 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___293;

struct cred___273;

struct vm_struct___209;

struct task_struct___294 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___294 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___293 *mm;
	struct mm_struct___293 *active_mm;
	struct vmacache___293 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___294 *real_parent;
	struct task_struct___294 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___294 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___195 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___195 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___195 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___273 *ptracer_cred;
	const struct cred___273 *real_cred;
	const struct cred___273 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___294 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___82 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___293 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___294 *oom_reaper_list;
	struct vm_struct___209 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___130 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct secondary_data___294 {
	void *stack;
	struct task_struct___294 *task;
	long int status;
};

typedef struct page___294 *pgtable_t___293;

struct address_space___292;

struct dev_pagemap___282;

struct page___294 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___292 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___294 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___293 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___293 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___282 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct key___273;

struct user_struct___273 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___273 *uid_keyring;
	struct key___273 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___282;

struct vm_area_struct___294 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___294 *vm_next;
	struct vm_area_struct___294 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___293 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___282 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___293 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct rw_semaphore___294 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___294 *owner;
};

struct core_state___293;

struct mm_struct___293 {
	struct {
		struct vm_area_struct___294 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___293 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___294 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___293 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___294 *owner;
		struct user_namespace___3 *user_ns;
		struct file___293 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___293 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___273 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___273 *session_keyring;
	struct key___273 *process_keyring;
	struct key___273 *thread_keyring;
	struct key___273 *request_key_auth;
	void *security;
	struct user_struct___273 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct vm_struct___209 {
	struct vm_struct___209 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___294 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct pglist_data___293;

struct lruvec___293 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___293 *pgdat;
};

struct zone___293 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___293 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___293 {
	struct zone___293 *zone;
	int zone_idx;
};

struct zonelist___293 {
	struct zoneref___293 _zonerefs[25];
};

struct pglist_data___293 {
	struct zone___293 node_zones[3];
	struct zonelist___293 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___294 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___294 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___293 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___293 {
	struct rw_semaphore___294 rwsem;
	struct notifier_block *head;
};

struct kernfs_root___286;

struct kernfs_elem_dir___286 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___286 *root;
};

struct kernfs_node___287;

struct kernfs_syscall_ops___286;

struct kernfs_root___286 {
	struct kernfs_node___287 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___286 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___286 {
	struct kernfs_node___287 *target_kn;
};

struct kernfs_ops___286;

struct kernfs_elem_attr___286 {
	const struct kernfs_ops___286 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___287 *notify_next;
};

struct kernfs_node___287 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___287 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___286 dir;
		struct kernfs_elem_symlink___286 symlink;
		struct kernfs_elem_attr___286 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___286;

struct kernfs_ops___286 {
	int (*open)(struct kernfs_open_file___286 *);
	void (*release)(struct kernfs_open_file___286 *);
	int (*seq_show)(struct seq_file___251 *, void *);
	void * (*seq_start)(struct seq_file___251 *, loff_t *);
	void * (*seq_next)(struct seq_file___251 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___251 *, void *);
	ssize_t (*read)(struct kernfs_open_file___286 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___286 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___286 *, struct vm_area_struct___294 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___286 *, struct poll_table_struct___178 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___286 {
	int (*remount_fs)(struct kernfs_root___286 *, int *, char *);
	int (*show_options)(struct seq_file___251 *, struct kernfs_root___286 *);
	int (*mkdir)(struct kernfs_node___287 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___287 *);
	int (*rename)(struct kernfs_node___287 *, struct kernfs_node___287 *, const char *);
	int (*show_path)(struct seq_file___251 *, struct kernfs_node___287 *, struct kernfs_root___286 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___250;

struct seq_file___251 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___250 *op;
	int poll_event;
	const struct file___293 *file;
	void *private;
};

struct kernfs_open_file___286 {
	struct kernfs_node___287 *kn;
	struct file___293 *file;
	struct seq_file___251 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___282 *vm_ops;
};

struct dentry___293;

struct path___293 {
	struct vfsmount *mnt;
	struct dentry___293 *dentry;
};

struct file___293 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___293 f_path;
	struct inode___293 *f_inode;
	const struct file_operations___293 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___195 f_owner;
	const struct cred___273 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___292 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___282;

struct vm_operations_struct___282 {
	void (*open)(struct vm_area_struct___294 *);
	void (*close)(struct vm_area_struct___294 *);
	int (*split)(struct vm_area_struct___294 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___294 *);
	vm_fault_t (*fault)(struct vm_fault___282 *);
	vm_fault_t (*huge_fault)(struct vm_fault___282 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___282 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___294 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___282 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___282 *);
	int (*access)(struct vm_area_struct___294 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___294 *);
	int (*set_policy)(struct vm_area_struct___294 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___294 *, long unsigned int);
	struct page___294 * (*find_special_page)(struct vm_area_struct___294 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___181)(struct file___293 *, wait_queue_head_t *, struct poll_table_struct___178 *);

struct poll_table_struct___178 {
	poll_queue_proc___181 _qproc;
	__poll_t _key;
};

struct kobject___280;

struct bin_attribute___256;

struct attribute_group___257 {
	const char *name;
	umode_t (*is_visible)(struct kobject___280 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___280 *, struct bin_attribute___256 *, int);
	struct attribute **attrs;
	struct bin_attribute___256 **bin_attrs;
};

struct kset___279;

struct kobj_type___279;

struct kobject___280 {
	const char *name;
	struct list_head entry;
	struct kobject___280 *parent;
	struct kset___279 *kset;
	struct kobj_type___279 *ktype;
	struct kernfs_node___287 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___256 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___293 *, struct kobject___280 *, struct bin_attribute___256 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___293 *, struct kobject___280 *, struct bin_attribute___256 *, char *, loff_t, size_t);
	int (*mmap)(struct file___293 *, struct kobject___280 *, struct bin_attribute___256 *, struct vm_area_struct___294 *);
};

struct sysfs_ops___279 {
	ssize_t (*show)(struct kobject___280 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___280 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___279;

struct kset___279 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___280 kobj;
	const struct kset_uevent_ops___279 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___279 {
	void (*release)(struct kobject___280 *);
	const struct sysfs_ops___279 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___25 * (*child_ns_type)(struct kobject___280 *);
	const void * (*namespace)(struct kobject___280 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___279 {
	int (* const filter)(struct kset___279 *, struct kobject___280 *);
	const char * (* const name)(struct kset___279 *, struct kobject___280 *);
	int (* const uevent)(struct kset___279 *, struct kobject___280 *, struct kobj_uevent_env *);
};

struct kobj_attribute___272 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___280 *, struct kobj_attribute___272 *, char *);
	ssize_t (*store)(struct kobject___280 *, struct kobj_attribute___272 *, const char *, size_t);
};

struct device___258;

struct dev_pm_ops___258 {
	int (*prepare)(struct device___258 *);
	void (*complete)(struct device___258 *);
	int (*suspend)(struct device___258 *);
	int (*resume)(struct device___258 *);
	int (*freeze)(struct device___258 *);
	int (*thaw)(struct device___258 *);
	int (*poweroff)(struct device___258 *);
	int (*restore)(struct device___258 *);
	int (*suspend_late)(struct device___258 *);
	int (*resume_early)(struct device___258 *);
	int (*freeze_late)(struct device___258 *);
	int (*thaw_early)(struct device___258 *);
	int (*poweroff_late)(struct device___258 *);
	int (*restore_early)(struct device___258 *);
	int (*suspend_noirq)(struct device___258 *);
	int (*resume_noirq)(struct device___258 *);
	int (*freeze_noirq)(struct device___258 *);
	int (*thaw_noirq)(struct device___258 *);
	int (*poweroff_noirq)(struct device___258 *);
	int (*restore_noirq)(struct device___258 *);
	int (*runtime_suspend)(struct device___258 *);
	int (*runtime_resume)(struct device___258 *);
	int (*runtime_idle)(struct device___258 *);
};

struct dev_pm_info___258 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___258 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___258;

struct bus_type___258;

struct device_driver___258;

struct dev_pm_domain___258;

struct dma_map_ops___80;

struct fwnode_handle___192;

struct class___258;

struct device___258 {
	struct device___258 *parent;
	struct device_private *p;
	struct kobject___280 kobj;
	const char *init_name;
	const struct device_type___258 *type;
	struct mutex mutex;
	struct bus_type___258 *bus;
	struct device_driver___258 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___258 power;
	struct dev_pm_domain___258 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___80 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___192 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___258 *class;
	const struct attribute_group___257 **groups;
	void (*release)(struct device___258 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___258 {
	struct dev_pm_ops___258 ops;
	void (*detach)(struct device___258 *, bool);
	int (*activate)(struct device___258 *);
	void (*sync)(struct device___258 *);
	void (*dismiss)(struct device___258 *);
};

struct bus_type___258 {
	const char *name;
	const char *dev_name;
	struct device___258 *dev_root;
	const struct attribute_group___257 **bus_groups;
	const struct attribute_group___257 **dev_groups;
	const struct attribute_group___257 **drv_groups;
	int (*match)(struct device___258 *, struct device_driver___258 *);
	int (*uevent)(struct device___258 *, struct kobj_uevent_env *);
	int (*probe)(struct device___258 *);
	int (*remove)(struct device___258 *);
	void (*shutdown)(struct device___258 *);
	int (*online)(struct device___258 *);
	int (*offline)(struct device___258 *);
	int (*suspend)(struct device___258 *, pm_message_t);
	int (*resume)(struct device___258 *);
	int (*num_vf)(struct device___258 *);
	int (*dma_configure)(struct device___258 *);
	const struct dev_pm_ops___258 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___258 {
	const char *name;
	struct bus_type___258 *bus;
	struct module___236 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___258 *);
	int (*remove)(struct device___258 *);
	void (*shutdown)(struct device___258 *);
	int (*suspend)(struct device___258 *, pm_message_t);
	int (*resume)(struct device___258 *);
	const struct attribute_group___257 **groups;
	const struct dev_pm_ops___258 *pm;
	void (*coredump)(struct device___258 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___258 {
	const char *name;
	const struct attribute_group___257 **groups;
	int (*uevent)(struct device___258 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___258 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___258 *);
	const struct dev_pm_ops___258 *pm;
};

struct module_kobject___233 {
	struct kobject___280 kobj;
	struct module___236 *mod;
	struct kobject___280 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___233 {
	struct module___236 *mod;
	struct latch_tree_node node;
};

struct module_layout___233 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___233 mtn;
};

struct module_attribute___233;

struct kernel_param___233;

struct module___236 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___233 mkobj;
	struct module_attribute___233 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___280 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___233 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___233 core_layout;
	struct module_layout___233 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct class___258 {
	const char *name;
	struct module___236 *owner;
	const struct attribute_group___257 **class_groups;
	const struct attribute_group___257 **dev_groups;
	struct kobject___280 *dev_kobj;
	int (*dev_uevent)(struct device___258 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___258 *, umode_t *);
	void (*class_release)(struct class___258 *);
	void (*dev_release)(struct device___258 *);
	int (*shutdown_pre)(struct device___258 *);
	const struct kobj_ns_type_operations___25 *ns_type;
	const void * (*namespace)(struct device___258 *);
	const struct dev_pm_ops___258 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___80 {
	void * (*alloc)(struct device___258 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___258 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___258 *, struct vm_area_struct___294 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___258 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___258 *, struct page___294 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___258 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___258 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___258 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___258 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___258 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___258 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___258 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___258 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___258 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___258 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___258 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___258 *, u64);
	u64 (*get_required_mask)(struct device___258 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___192;

struct fwnode_handle___192 {
	struct fwnode_handle___192 *secondary;
	const struct fwnode_operations___192 *ops;
};

struct address_space_operations___292;

struct address_space___292 {
	struct inode___293 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___294 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___292 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___282)(struct vm_area_struct___294 *, long unsigned int, const struct page___294 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___282)(struct page___294 *, void *);

struct dev_pagemap___282 {
	dev_page_fault_t___282 page_fault;
	dev_page_free_t___282 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___258 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___293 {
	struct task_struct___294 *task;
	struct core_thread___293 *next;
};

struct core_state___293 {
	atomic_t nr_threads;
	struct core_thread___293 dumper;
	struct completion startup;
};

struct vm_fault___282 {
	struct vm_area_struct___294 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___294 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___294 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___293 prealloc_pte;
};

struct fwnode_reference_args___192;

struct fwnode_endpoint___192;

struct fwnode_operations___192 {
	struct fwnode_handle___192 * (*get)(struct fwnode_handle___192 *);
	void (*put)(struct fwnode_handle___192 *);
	bool (*device_is_available)(const struct fwnode_handle___192 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___192 *, const struct device___258 *);
	bool (*property_present)(const struct fwnode_handle___192 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___192 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___192 *, const char *, const char **, size_t);
	struct fwnode_handle___192 * (*get_parent)(const struct fwnode_handle___192 *);
	struct fwnode_handle___192 * (*get_next_child_node)(const struct fwnode_handle___192 *, struct fwnode_handle___192 *);
	struct fwnode_handle___192 * (*get_named_child_node)(const struct fwnode_handle___192 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___192 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___192 *);
	struct fwnode_handle___192 * (*graph_get_next_endpoint)(const struct fwnode_handle___192 *, struct fwnode_handle___192 *);
	struct fwnode_handle___192 * (*graph_get_remote_endpoint)(const struct fwnode_handle___192 *);
	struct fwnode_handle___192 * (*graph_get_port_parent)(struct fwnode_handle___192 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___192 *, struct fwnode_endpoint___192 *);
};

struct fwnode_endpoint___192 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___192 *local_fwnode;
};

struct fwnode_reference_args___192 {
	struct fwnode_handle___192 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pci_bus___18;

struct hotplug_slot___5;

struct pci_slot___18 {
	struct pci_bus___18 *bus;
	struct list_head list;
	struct hotplug_slot___5 *hotplug;
	unsigned char number;
	struct kobject___280 kobj;
};

struct pci_dev___18;

struct pci_ops___18;

struct pci_bus___18 {
	struct list_head node;
	struct pci_bus___18 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___18 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___18 *ops;
	struct msi_controller___2 *msi;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	int domain_nr;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___258 *bridge;
	struct device___258 dev;
	struct bin_attribute___256 *legacy_io;
	struct bin_attribute___256 *legacy_mem;
	unsigned int is_added: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
};

struct hotplug_slot_ops___5;

struct hotplug_slot___5 {
	const struct hotplug_slot_ops___5 *ops;
	struct list_head slot_list;
	struct pci_slot___18 *pci_slot;
	struct module___236 *owner;
	const char *mod_name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct pci_sriov___13 {
	int pos;
	int nres;
	u32 cap;
	u16 ctrl;
	u16 total_VFs;
	u16 initial_VFs;
	u16 num_VFs;
	u16 offset;
	u16 stride;
	u16 vf_device;
	u32 pgsz;
	u8 link;
	u8 max_VF_buses;
	u16 driver_max_VFs;
	struct pci_dev___18 *dev;
	struct pci_dev___18 *self;
	u32 class;
	u8 hdr_type;
	u16 subsystem_vendor;
	u16 subsystem_device;
	resource_size_t barsz[6];
	bool drivers_autoprobe;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct pci_driver___18;

struct pci_dev___18 {
	struct list_head bus_list;
	struct pci_bus___18 *bus;
	struct pci_bus___18 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___18 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u16 aer_cap;
	struct aer_stats *aer_stats;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	long unsigned int *dma_alias_mask;
	struct pci_driver___18 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	unsigned int imm_ready: 1;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int bridge_d3: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int hotplug_user_indicators: 1;
	unsigned int clear_retrain_link: 1;
	unsigned int d3_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	unsigned int ltr_path: 1;
	unsigned int eetlp_prefix_path: 1;
	pci_channel_state_t error_state;
	struct device___258 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int multifunction: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int ats_enabled: 1;
	unsigned int pasid_enabled: 1;
	unsigned int pri_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int reset_fn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int shpc_managed: 1;
	unsigned int is_thunderbolt: 1;
	unsigned int __aer_firmware_first_valid: 1;
	unsigned int __aer_firmware_first: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int irq_managed: 1;
	unsigned int has_secondary_link: 1;
	unsigned int non_compliant_bars: 1;
	unsigned int is_probed: 1;
	unsigned int link_active_reporting: 1;
	unsigned int untrusted: 1;
	unsigned int no_vf_scan: 1;
	unsigned int io_window: 1;
	unsigned int pref_window: 1;
	unsigned int pref_64_window: 1;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	struct bin_attribute___256 *rom_attr;
	int rom_attr_enabled;
	struct bin_attribute___256 *res_attr[17];
	struct bin_attribute___256 *res_attr_wc[17];
	unsigned int broken_cmd_compl: 1;
	const struct attribute_group___257 **msi_irq_groups;
	struct pci_vpd *vpd;
	union {
		struct pci_sriov___13 *sriov;
		struct pci_dev___18 *physfn;
	};
	u16 ats_cap;
	u8 ats_stu;
	atomic_t ats_ref_cnt;
	u32 pri_reqs_alloc;
	u16 pasid_features;
	struct pci_p2pdma *p2pdma;
	phys_addr_t rom;
	size_t romlen;
	char *driver_override;
	long unsigned int priv_flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t pci_dev_extended_size_rh;
	struct pci_dev_extended_rh pci_dev_extended_rh;
};

struct pci_error_handlers___18;

struct pci_driver___18 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___18 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___18 *);
	int (*suspend)(struct pci_dev___18 *, pm_message_t);
	int (*suspend_late)(struct pci_dev___18 *, pm_message_t);
	int (*resume_early)(struct pci_dev___18 *);
	int (*resume)(struct pci_dev___18 *);
	void (*shutdown)(struct pci_dev___18 *);
	int (*sriov_configure)(struct pci_dev___18 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	const struct pci_error_handlers___18 *err_handler;
	const struct attribute_group___257 **groups;
	struct device_driver___258 driver;
	struct pci_dynids dynids;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct pci_ops___18 {
	int (*add_bus)(struct pci_bus___18 *);
	void (*remove_bus)(struct pci_bus___18 *);
	void * (*map_bus)(struct pci_bus___18 *, unsigned int, int);
	int (*read)(struct pci_bus___18 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___18 *, unsigned int, int, int, u32);
};

struct pci_error_handlers___18 {
	pci_ers_result_t (*error_detected)(struct pci_dev___18 *, enum pci_channel_state);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___18 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___18 *);
	void (*reset_prepare)(struct pci_dev___18 *);
	void (*reset_done)(struct pci_dev___18 *);
	void (*resume)(struct pci_dev___18 *);
};

struct dentry_operations___292;

struct super_block___292;

struct dentry___293 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___293 *d_parent;
	struct qstr d_name;
	struct inode___293 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___292 *d_op;
	struct super_block___292 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___292;

struct block_device___292;

struct cdev___51;

struct inode___293 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___292 *i_op;
	struct super_block___292 *i_sb;
	struct address_space___292 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___294 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___293 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___292 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___292 *i_bdev;
		struct cdev___51 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___292 {
	int (*d_revalidate)(struct dentry___293 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___293 *, unsigned int);
	int (*d_hash)(const struct dentry___293 *, struct qstr *);
	int (*d_compare)(const struct dentry___293 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___293 *);
	int (*d_init)(struct dentry___293 *);
	void (*d_release)(struct dentry___293 *);
	void (*d_prune)(struct dentry___293 *);
	void (*d_iput)(struct dentry___293 *, struct inode___293 *);
	char * (*d_dname)(struct dentry___293 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___293 *);
	int (*d_manage)(const struct path___293 *, bool);
	struct dentry___293 * (*d_real)(struct dentry___293 *, const struct inode___293 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___292;

struct mem_dqinfo___292 {
	struct quota_format_type___292 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___292;

struct quota_info___292 {
	unsigned int flags;
	struct rw_semaphore___294 dqio_sem;
	struct inode___293 *files[3];
	struct mem_dqinfo___292 info[3];
	const struct quota_format_ops___292 *ops[3];
};

struct rcuwait___292 {
	struct task_struct___294 *task;
};

struct percpu_rw_semaphore___292 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___294 rw_sem;
	struct rcuwait___292 writer;
	int readers_block;
};

struct sb_writers___292 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___292 rw_sem[3];
};

struct file_system_type___292;

struct super_operations___292;

struct dquot_operations___292;

struct quotactl_ops___292;

struct super_block___292 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___292 *s_type;
	const struct super_operations___292 *s_op;
	const struct dquot_operations___292 *dq_op;
	const struct quotactl_ops___292 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___293 *s_root;
	struct rw_semaphore___294 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___292 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___292 s_dquot;
	struct sb_writers___292 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___292 *s_d_op;
	int cleancache_poolid;
	struct shrinker___116 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___293 {
	struct file___293 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___293 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___292 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___293 *ia_file;
};

struct dquot___292 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___292 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___292 {
	int qf_fmt_id;
	const struct quota_format_ops___292 *qf_ops;
	struct module___236 *qf_owner;
	struct quota_format_type___292 *qf_next;
};

struct quota_format_ops___292 {
	int (*check_quota_file)(struct super_block___292 *, int);
	int (*read_file_info)(struct super_block___292 *, int);
	int (*write_file_info)(struct super_block___292 *, int);
	int (*free_file_info)(struct super_block___292 *, int);
	int (*read_dqblk)(struct dquot___292 *);
	int (*commit_dqblk)(struct dquot___292 *);
	int (*release_dqblk)(struct dquot___292 *);
	int (*get_next_id)(struct super_block___292 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___292 {
	int (*write_dquot)(struct dquot___292 *);
	struct dquot___292 * (*alloc_dquot)(struct super_block___292 *, int);
	void (*destroy_dquot)(struct dquot___292 *);
	int (*acquire_dquot)(struct dquot___292 *);
	int (*release_dquot)(struct dquot___292 *);
	int (*mark_dirty)(struct dquot___292 *);
	int (*write_info)(struct super_block___292 *, int);
	qsize_t * (*get_reserved_space)(struct inode___293 *);
	int (*get_projid)(struct inode___293 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___293 *, qsize_t *);
	int (*get_next_id)(struct super_block___292 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___292 {
	int (*quota_on)(struct super_block___292 *, int, int, const struct path___293 *);
	int (*quota_off)(struct super_block___292 *, int);
	int (*quota_enable)(struct super_block___292 *, unsigned int);
	int (*quota_disable)(struct super_block___292 *, unsigned int);
	int (*quota_sync)(struct super_block___292 *, int);
	int (*set_info)(struct super_block___292 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___292 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___292 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___292 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___292 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___292 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___292 {
	int (*writepage)(struct page___294 *, struct writeback_control___3 *);
	int (*readpage)(struct file___293 *, struct page___294 *);
	int (*writepages)(struct address_space___292 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___294 *);
	int (*readpages)(struct file___293 *, struct address_space___292 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___293 *, struct address_space___292 *, loff_t, unsigned int, unsigned int, struct page___294 **, void **);
	int (*write_end)(struct file___293 *, struct address_space___292 *, loff_t, unsigned int, unsigned int, struct page___294 *, void *);
	sector_t (*bmap)(struct address_space___292 *, sector_t);
	void (*invalidatepage)(struct page___294 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___294 *, gfp_t);
	void (*freepage)(struct page___294 *);
	ssize_t (*direct_IO)(struct kiocb___293 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___292 *, struct page___294 *, struct page___294 *, enum migrate_mode);
	bool (*isolate_page)(struct page___294 *, isolate_mode_t);
	void (*putback_page)(struct page___294 *);
	int (*launder_page)(struct page___294 *);
	int (*is_partially_uptodate)(struct page___294 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___294 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___292 *, struct page___294 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___293 *, sector_t *);
	void (*swap_deactivate)(struct file___293 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___292 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___293 *bd_inode;
	struct super_block___292 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___292 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___51 {
	struct kobject___280 kobj;
	struct module___236 *owner;
	const struct file_operations___293 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___292 {
	struct dentry___293 * (*lookup)(struct inode___293 *, struct dentry___293 *, unsigned int);
	const char * (*get_link)(struct dentry___293 *, struct inode___293 *, struct delayed_call *);
	int (*permission)(struct inode___293 *, int);
	struct posix_acl * (*get_acl)(struct inode___293 *, int);
	int (*readlink)(struct dentry___293 *, char *, int);
	int (*create)(struct inode___293 *, struct dentry___293 *, umode_t, bool);
	int (*link)(struct dentry___293 *, struct inode___293 *, struct dentry___293 *);
	int (*unlink)(struct inode___293 *, struct dentry___293 *);
	int (*symlink)(struct inode___293 *, struct dentry___293 *, const char *);
	int (*mkdir)(struct inode___293 *, struct dentry___293 *, umode_t);
	int (*rmdir)(struct inode___293 *, struct dentry___293 *);
	int (*mknod)(struct inode___293 *, struct dentry___293 *, umode_t, dev_t);
	int (*rename)(struct inode___293 *, struct dentry___293 *, struct inode___293 *, struct dentry___293 *, unsigned int);
	int (*setattr)(struct dentry___293 *, struct iattr___292 *);
	int (*getattr)(const struct path___293 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___293 *, char *, size_t);
	int (*fiemap)(struct inode___293 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___293 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___293 *, struct dentry___293 *, struct file___293 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___293 *, struct dentry___293 *, umode_t);
	int (*set_acl)(struct inode___293 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___292 {
	void (*fl_copy_lock)(struct file_lock___293 *, struct file_lock___293 *);
	void (*fl_release_private)(struct file_lock___293 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___292;

struct lock_manager_operations___292;

struct file_lock___293 {
	struct file_lock___293 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___293 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___292 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___292 *fl_ops;
	const struct lock_manager_operations___292 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___292 {
	int (*lm_compare_owner)(struct file_lock___293 *, struct file_lock___293 *);
	long unsigned int (*lm_owner_key)(struct file_lock___293 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___293 *);
	int (*lm_grant)(struct file_lock___293 *, int);
	bool (*lm_break)(struct file_lock___293 *);
	int (*lm_change)(struct file_lock___293 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___293 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___292 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___292 *fa_next;
	struct file___293 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___292 {
	const char *name;
	int fs_flags;
	struct dentry___293 * (*mount)(struct file_system_type___292 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___292 *);
	struct module___236 *owner;
	struct file_system_type___292 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___292 {
	struct inode___293 * (*alloc_inode)(struct super_block___292 *);
	void (*destroy_inode)(struct inode___293 *);
	void (*dirty_inode)(struct inode___293 *, int);
	int (*write_inode)(struct inode___293 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___293 *);
	void (*evict_inode)(struct inode___293 *);
	void (*put_super)(struct super_block___292 *);
	int (*sync_fs)(struct super_block___292 *, int);
	int (*freeze_super)(struct super_block___292 *);
	int (*freeze_fs)(struct super_block___292 *);
	int (*thaw_super)(struct super_block___292 *);
	int (*unfreeze_fs)(struct super_block___292 *);
	int (*statfs)(struct dentry___293 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___292 *, int *, char *);
	void (*umount_begin)(struct super_block___292 *);
	int (*show_options)(struct seq_file___251 *, struct dentry___293 *);
	int (*show_devname)(struct seq_file___251 *, struct dentry___293 *);
	int (*show_path)(struct seq_file___251 *, struct dentry___293 *);
	int (*show_stats)(struct seq_file___251 *, struct dentry___293 *);
	ssize_t (*quota_read)(struct super_block___292 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___292 *, int, const char *, size_t, loff_t);
	struct dquot___292 ** (*get_dquots)(struct inode___293 *);
	int (*bdev_try_to_free_page)(struct super_block___292 *, struct page___294 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___292 *, struct shrink_control___116 *);
	long int (*free_cached_objects)(struct super_block___292 *, struct shrink_control___116 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___282(struct page___294 *);

struct pci_fixup___3 {
	u16 vendor;
	u16 device;
	u32 class;
	unsigned int class_shift;
	void (*hook)(struct pci_dev___18 *);
};

struct hotplug_slot_ops___5 {
	int (*enable_slot)(struct hotplug_slot___5 *);
	int (*disable_slot)(struct hotplug_slot___5 *);
	int (*set_attention_status)(struct hotplug_slot___5 *, u8);
	int (*hardware_test)(struct hotplug_slot___5 *, u32);
	int (*get_power_status)(struct hotplug_slot___5 *, u8 *);
	int (*get_attention_status)(struct hotplug_slot___5 *, u8 *);
	int (*get_latch_status)(struct hotplug_slot___5 *, u8 *);
	int (*get_adapter_status)(struct hotplug_slot___5 *, u8 *);
	int (*reset_slot)(struct hotplug_slot___5 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct kernel_param_ops___233 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___233 *);
	int (*get)(char *, const struct kernel_param___233 *);
	void (*free)(void *);
};

struct kparam_array___233;

struct kernel_param___233 {
	const char *name;
	struct module___236 *mod;
	const struct kernel_param_ops___233 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___233 *arr;
	};
};

struct kparam_array___233 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___233 *ops;
	void *elem;
};

struct module_attribute___233 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___233 *, struct module_kobject___233 *, char *);
	ssize_t (*store)(struct module_attribute___233 *, struct module_kobject___233 *, const char *, size_t);
	void (*setup)(struct module___236 *, const char *);
	int (*test)(struct module___236 *);
	void (*free)(struct module___236 *);
};

typedef int (*key_restrict_link_func_t___274)(struct key___273 *, const struct key_type *, const union key_payload *, struct key___273 *);

struct key_restriction___273;

struct key___273 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___294 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___273 *restrict_link;
};

struct key_restriction___273 {
	key_restrict_link_func_t___274 check;
	struct key___273 *key;
	struct key_type *keytype;
};

struct seq_operations___250 {
	void * (*start)(struct seq_file___251 *, loff_t *);
	void (*stop)(struct seq_file___251 *, void *);
	void * (*next)(struct seq_file___251 *, void *, loff_t *);
	int (*show)(struct seq_file___251 *, void *);
};

struct pcie_device___4 {
	int irq;
	struct pci_dev___18 *port;
	u32 service;
	void *priv_data;
	struct device___258 device;
};

struct controller___2 {
	struct pcie_device___4 *pcie;
	u32 slot_cap;
	u16 slot_ctrl;
	struct mutex ctrl_lock;
	long unsigned int cmd_started;
	unsigned int cmd_busy: 1;
	wait_queue_head_t queue;
	atomic_t pending_events;
	unsigned int notification_enabled: 1;
	unsigned int power_fault_detected;
	struct task_struct___294 *poll_thread;
	u8 state;
	struct mutex state_lock;
	struct delayed_work button_work;
	struct hotplug_slot___5 hotplug_slot;
	struct rw_semaphore___294 reset_lock;
	int request_result;
	wait_queue_head_t requester;
};

struct acpiphp_slot;

struct slot {
	struct hotplug_slot___3 hotplug_slot;
	struct acpiphp_slot *acpi_slot;
	unsigned int sun;
};

struct acpiphp_slot {
	struct list_head node;
	struct pci_bus___14 *bus;
	struct list_head funcs;
	struct slot *slot;
	u8 device;
	u32 flags;
};

struct acpiphp_attention_info {
	int (*set_attn)(struct hotplug_slot___3 *, u8);
	int (*get_attn)(struct hotplug_slot___3 *, u8 *);
	struct module___233 *owner;
};

struct acpi_object_list {
	u32 count;
	union acpi_object *pointer;
};

struct acpiphp_context;

struct acpiphp_bridge {
	struct list_head list;
	struct list_head slots;
	struct kref ref;
	struct acpiphp_context *context;
	int nr_slots;
	struct pci_bus___14 *pci_bus;
	struct pci_dev___14 *pci_dev;
	bool is_going_away;
};

struct acpiphp_func {
	struct acpiphp_bridge *parent;
	struct acpiphp_slot *slot;
	struct list_head sibling;
	u8 function;
	u32 flags;
};

struct acpiphp_context {
	struct acpi_hotplug_context___5 hp;
	struct acpiphp_func func;
	struct acpiphp_bridge *bridge;
	unsigned int refcount;
};

struct acpiphp_root_context {
	struct acpi_hotplug_context___5 hp;
	struct acpiphp_bridge *root_bridge;
};

struct module___237;

struct file___294;

struct kiocb___294;

struct poll_table_struct___179;

struct vm_area_struct___295;

struct inode___294;

struct file_lock___294;

struct page___295;

struct seq_file___252;

struct file_operations___294 {
	struct module___237 *owner;
	loff_t (*llseek)(struct file___294 *, loff_t, int);
	ssize_t (*read)(struct file___294 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___294 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___294 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___294 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___294 *, bool);
	int (*iterate)(struct file___294 *, struct dir_context *);
	int (*iterate_shared)(struct file___294 *, struct dir_context *);
	__poll_t (*poll)(struct file___294 *, struct poll_table_struct___179 *);
	long int (*unlocked_ioctl)(struct file___294 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___294 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___294 *, struct vm_area_struct___295 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___294 *, struct file___294 *);
	int (*flush)(struct file___294 *, fl_owner_t);
	int (*release)(struct inode___294 *, struct file___294 *);
	int (*fsync)(struct file___294 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___294 *, int);
	int (*lock)(struct file___294 *, int, struct file_lock___294 *);
	ssize_t (*sendpage)(struct file___294 *, struct page___295 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___294 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___294 *, int, struct file_lock___294 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___294 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___294 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___294 *, long int, struct file_lock___294 **, void **);
	long int (*fallocate)(struct file___294 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___252 *, struct file___294 *);
	ssize_t (*copy_file_range)(struct file___294 *, loff_t, struct file___294 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___294 *, loff_t, struct file___294 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___294 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___294 {
	u64 seqnum;
	struct vm_area_struct___295 *vmas[4];
};

struct page_frag___294 {
	struct page___295 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___294;

struct cred___274;

struct vm_struct___210;

struct task_struct___295 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___295 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___294 *mm;
	struct mm_struct___294 *active_mm;
	struct vmacache___294 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___295 *real_parent;
	struct task_struct___295 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___295 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___195 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___195 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___195 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___274 *ptracer_cred;
	const struct cred___274 *real_cred;
	const struct cred___274 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___295 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___82 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___294 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___295 *oom_reaper_list;
	struct vm_struct___210 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___130 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___295 *pgtable_t___294;

struct address_space___293;

struct dev_pagemap___283;

struct page___295 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___293 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___295 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___294 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___294 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___283 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___294;

struct lruvec___294 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___294 *pgdat;
};

struct zone___294 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___294 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___294 {
	struct zone___294 *zone;
	int zone_idx;
};

struct zonelist___294 {
	struct zoneref___294 _zonerefs[25];
};

struct pglist_data___294 {
	struct zone___294 node_zones[3];
	struct zonelist___294 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___295 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___295 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___294 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___295 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___295 *owner;
};

struct secondary_data___295 {
	void *stack;
	struct task_struct___295 *task;
	long int status;
};

struct blocking_notifier_head___294 {
	struct rw_semaphore___295 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___283;

struct vm_area_struct___295 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___295 *vm_next;
	struct vm_area_struct___295 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___294 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___283 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___294 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___294;

struct mm_struct___294 {
	struct {
		struct vm_area_struct___295 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___294 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___295 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___294 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___295 *owner;
		struct user_namespace___3 *user_ns;
		struct file___294 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___294 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___293;

struct address_space___293 {
	struct inode___294 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___295 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___293 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___283)(struct vm_area_struct___295 *, long unsigned int, const struct page___295 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___283)(struct page___295 *, void *);

struct device___259;

struct dev_pagemap___283 {
	dev_page_fault_t___283 page_fault;
	dev_page_free_t___283 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___259 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct dentry___294;

struct path___294 {
	struct vfsmount *mnt;
	struct dentry___294 *dentry;
};

struct file___294 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___294 f_path;
	struct inode___294 *f_inode;
	const struct file_operations___294 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___195 f_owner;
	const struct cred___274 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___293 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___283;

struct vm_operations_struct___283 {
	void (*open)(struct vm_area_struct___295 *);
	void (*close)(struct vm_area_struct___295 *);
	int (*split)(struct vm_area_struct___295 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___295 *);
	vm_fault_t (*fault)(struct vm_fault___283 *);
	vm_fault_t (*huge_fault)(struct vm_fault___283 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___283 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___295 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___283 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___283 *);
	int (*access)(struct vm_area_struct___295 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___295 *);
	int (*set_policy)(struct vm_area_struct___295 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___295 *, long unsigned int);
	struct page___295 * (*find_special_page)(struct vm_area_struct___295 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___294 {
	struct task_struct___295 *task;
	struct core_thread___294 *next;
};

struct core_state___294 {
	atomic_t nr_threads;
	struct core_thread___294 dumper;
	struct completion startup;
};

struct vm_fault___283 {
	struct vm_area_struct___295 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___295 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___295 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___294 prealloc_pte;
};

struct key___274;

struct user_struct___274 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___274 *uid_keyring;
	struct key___274 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___274 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___274 *session_keyring;
	struct key___274 *process_keyring;
	struct key___274 *thread_keyring;
	struct key___274 *request_key_auth;
	void *security;
	struct user_struct___274 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct vm_struct___210 {
	struct vm_struct___210 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___295 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct kset___280;

struct kobj_type___280;

struct kernfs_node___288;

struct kobject___281 {
	const char *name;
	struct list_head entry;
	struct kobject___281 *parent;
	struct kset___280 *kset;
	struct kobj_type___280 *ktype;
	struct kernfs_node___288 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___259 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___259 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___259;

struct bus_type___259;

struct device_driver___259;

struct dev_pm_domain___259;

struct irq_domain___11;

struct dma_map_ops___81;

struct device_node___52;

struct fwnode_handle___193;

struct class___259;

struct attribute_group___258;

struct device___259 {
	struct device___259 *parent;
	struct device_private *p;
	struct kobject___281 kobj;
	const char *init_name;
	const struct device_type___259 *type;
	struct mutex mutex;
	struct bus_type___259 *bus;
	struct device_driver___259 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___259 power;
	struct dev_pm_domain___259 *pm_domain;
	struct irq_domain___11 *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___81 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___52 *of_node;
	struct fwnode_handle___193 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___259 *class;
	const struct attribute_group___258 **groups;
	void (*release)(struct device___259 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___293;

struct super_block___293;

struct dentry___294 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___294 *d_parent;
	struct qstr d_name;
	struct inode___294 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___293 *d_op;
	struct super_block___293 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___293;

struct block_device___293;

struct cdev___52;

struct inode___294 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___293 *i_op;
	struct super_block___293 *i_sb;
	struct address_space___293 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___295 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___294 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___293 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___293 *i_bdev;
		struct cdev___52 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___293 {
	int (*d_revalidate)(struct dentry___294 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___294 *, unsigned int);
	int (*d_hash)(const struct dentry___294 *, struct qstr *);
	int (*d_compare)(const struct dentry___294 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___294 *);
	int (*d_init)(struct dentry___294 *);
	void (*d_release)(struct dentry___294 *);
	void (*d_prune)(struct dentry___294 *);
	void (*d_iput)(struct dentry___294 *, struct inode___294 *);
	char * (*d_dname)(struct dentry___294 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___294 *);
	int (*d_manage)(const struct path___294 *, bool);
	struct dentry___294 * (*d_real)(struct dentry___294 *, const struct inode___294 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___293;

struct mem_dqinfo___293 {
	struct quota_format_type___293 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___293;

struct quota_info___293 {
	unsigned int flags;
	struct rw_semaphore___295 dqio_sem;
	struct inode___294 *files[3];
	struct mem_dqinfo___293 info[3];
	const struct quota_format_ops___293 *ops[3];
};

struct rcuwait___293 {
	struct task_struct___295 *task;
};

struct percpu_rw_semaphore___293 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___295 rw_sem;
	struct rcuwait___293 writer;
	int readers_block;
};

struct sb_writers___293 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___293 rw_sem[3];
};

struct file_system_type___293;

struct super_operations___293;

struct dquot_operations___293;

struct quotactl_ops___293;

struct super_block___293 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___293 *s_type;
	const struct super_operations___293 *s_op;
	const struct dquot_operations___293 *dq_op;
	const struct quotactl_ops___293 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___294 *s_root;
	struct rw_semaphore___295 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___293 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___293 s_dquot;
	struct sb_writers___293 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___293 *s_d_op;
	int cleancache_poolid;
	struct shrinker___116 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___294 {
	struct file___294 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___294 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___293 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___294 *ia_file;
};

struct dquot___293 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___293 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___293 {
	int qf_fmt_id;
	const struct quota_format_ops___293 *qf_ops;
	struct module___237 *qf_owner;
	struct quota_format_type___293 *qf_next;
};

struct quota_format_ops___293 {
	int (*check_quota_file)(struct super_block___293 *, int);
	int (*read_file_info)(struct super_block___293 *, int);
	int (*write_file_info)(struct super_block___293 *, int);
	int (*free_file_info)(struct super_block___293 *, int);
	int (*read_dqblk)(struct dquot___293 *);
	int (*commit_dqblk)(struct dquot___293 *);
	int (*release_dqblk)(struct dquot___293 *);
	int (*get_next_id)(struct super_block___293 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___293 {
	int (*write_dquot)(struct dquot___293 *);
	struct dquot___293 * (*alloc_dquot)(struct super_block___293 *, int);
	void (*destroy_dquot)(struct dquot___293 *);
	int (*acquire_dquot)(struct dquot___293 *);
	int (*release_dquot)(struct dquot___293 *);
	int (*mark_dirty)(struct dquot___293 *);
	int (*write_info)(struct super_block___293 *, int);
	qsize_t * (*get_reserved_space)(struct inode___294 *);
	int (*get_projid)(struct inode___294 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___294 *, qsize_t *);
	int (*get_next_id)(struct super_block___293 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___293 {
	int (*quota_on)(struct super_block___293 *, int, int, const struct path___294 *);
	int (*quota_off)(struct super_block___293 *, int);
	int (*quota_enable)(struct super_block___293 *, unsigned int);
	int (*quota_disable)(struct super_block___293 *, unsigned int);
	int (*quota_sync)(struct super_block___293 *, int);
	int (*set_info)(struct super_block___293 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___293 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___293 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___293 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___293 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___293 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___234 {
	struct kobject___281 kobj;
	struct module___237 *mod;
	struct kobject___281 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___234 {
	struct module___237 *mod;
	struct latch_tree_node node;
};

struct module_layout___234 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___234 mtn;
};

struct module_attribute___234;

struct kernel_param___234;

struct module___237 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___234 mkobj;
	struct module_attribute___234 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___281 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___234 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___234 core_layout;
	struct module_layout___234 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___293 {
	int (*writepage)(struct page___295 *, struct writeback_control___3 *);
	int (*readpage)(struct file___294 *, struct page___295 *);
	int (*writepages)(struct address_space___293 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___295 *);
	int (*readpages)(struct file___294 *, struct address_space___293 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___294 *, struct address_space___293 *, loff_t, unsigned int, unsigned int, struct page___295 **, void **);
	int (*write_end)(struct file___294 *, struct address_space___293 *, loff_t, unsigned int, unsigned int, struct page___295 *, void *);
	sector_t (*bmap)(struct address_space___293 *, sector_t);
	void (*invalidatepage)(struct page___295 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___295 *, gfp_t);
	void (*freepage)(struct page___295 *);
	ssize_t (*direct_IO)(struct kiocb___294 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___293 *, struct page___295 *, struct page___295 *, enum migrate_mode);
	bool (*isolate_page)(struct page___295 *, isolate_mode_t);
	void (*putback_page)(struct page___295 *);
	int (*launder_page)(struct page___295 *);
	int (*is_partially_uptodate)(struct page___295 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___295 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___293 *, struct page___295 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___294 *, sector_t *);
	void (*swap_deactivate)(struct file___294 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___293 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___294 *bd_inode;
	struct super_block___293 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___293 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___52 {
	struct kobject___281 kobj;
	struct module___237 *owner;
	const struct file_operations___294 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___293 {
	struct dentry___294 * (*lookup)(struct inode___294 *, struct dentry___294 *, unsigned int);
	const char * (*get_link)(struct dentry___294 *, struct inode___294 *, struct delayed_call *);
	int (*permission)(struct inode___294 *, int);
	struct posix_acl * (*get_acl)(struct inode___294 *, int);
	int (*readlink)(struct dentry___294 *, char *, int);
	int (*create)(struct inode___294 *, struct dentry___294 *, umode_t, bool);
	int (*link)(struct dentry___294 *, struct inode___294 *, struct dentry___294 *);
	int (*unlink)(struct inode___294 *, struct dentry___294 *);
	int (*symlink)(struct inode___294 *, struct dentry___294 *, const char *);
	int (*mkdir)(struct inode___294 *, struct dentry___294 *, umode_t);
	int (*rmdir)(struct inode___294 *, struct dentry___294 *);
	int (*mknod)(struct inode___294 *, struct dentry___294 *, umode_t, dev_t);
	int (*rename)(struct inode___294 *, struct dentry___294 *, struct inode___294 *, struct dentry___294 *, unsigned int);
	int (*setattr)(struct dentry___294 *, struct iattr___293 *);
	int (*getattr)(const struct path___294 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___294 *, char *, size_t);
	int (*fiemap)(struct inode___294 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___294 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___294 *, struct dentry___294 *, struct file___294 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___294 *, struct dentry___294 *, umode_t);
	int (*set_acl)(struct inode___294 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___293 {
	void (*fl_copy_lock)(struct file_lock___294 *, struct file_lock___294 *);
	void (*fl_release_private)(struct file_lock___294 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___293;

struct lock_manager_operations___293;

struct file_lock___294 {
	struct file_lock___294 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___294 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___293 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___293 *fl_ops;
	const struct lock_manager_operations___293 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___293 {
	int (*lm_compare_owner)(struct file_lock___294 *, struct file_lock___294 *);
	long unsigned int (*lm_owner_key)(struct file_lock___294 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___294 *);
	int (*lm_grant)(struct file_lock___294 *, int);
	bool (*lm_break)(struct file_lock___294 *);
	int (*lm_change)(struct file_lock___294 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___294 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___293 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___293 *fa_next;
	struct file___294 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___293 {
	const char *name;
	int fs_flags;
	struct dentry___294 * (*mount)(struct file_system_type___293 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___293 *);
	struct module___237 *owner;
	struct file_system_type___293 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___293 {
	struct inode___294 * (*alloc_inode)(struct super_block___293 *);
	void (*destroy_inode)(struct inode___294 *);
	void (*dirty_inode)(struct inode___294 *, int);
	int (*write_inode)(struct inode___294 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___294 *);
	void (*evict_inode)(struct inode___294 *);
	void (*put_super)(struct super_block___293 *);
	int (*sync_fs)(struct super_block___293 *, int);
	int (*freeze_super)(struct super_block___293 *);
	int (*freeze_fs)(struct super_block___293 *);
	int (*thaw_super)(struct super_block___293 *);
	int (*unfreeze_fs)(struct super_block___293 *);
	int (*statfs)(struct dentry___294 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___293 *, int *, char *);
	void (*umount_begin)(struct super_block___293 *);
	int (*show_options)(struct seq_file___252 *, struct dentry___294 *);
	int (*show_devname)(struct seq_file___252 *, struct dentry___294 *);
	int (*show_path)(struct seq_file___252 *, struct dentry___294 *);
	int (*show_stats)(struct seq_file___252 *, struct dentry___294 *);
	ssize_t (*quota_read)(struct super_block___293 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___293 *, int, const char *, size_t, loff_t);
	struct dquot___293 ** (*get_dquots)(struct inode___294 *);
	int (*bdev_try_to_free_page)(struct super_block___293 *, struct page___295 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___293 *, struct shrink_control___116 *);
	long int (*free_cached_objects)(struct super_block___293 *, struct shrink_control___116 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___182)(struct file___294 *, wait_queue_head_t *, struct poll_table_struct___179 *);

struct poll_table_struct___179 {
	poll_queue_proc___182 _qproc;
	__poll_t _key;
};

struct seq_operations___251;

struct seq_file___252 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___251 *op;
	int poll_event;
	const struct file___294 *file;
	void *private;
};

struct kobj_attribute___273 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___281 *, struct kobj_attribute___273 *, char *);
	ssize_t (*store)(struct kobject___281 *, struct kobj_attribute___273 *, const char *, size_t);
};

typedef void compound_page_dtor___283(struct page___295 *);

struct irq_desc___15;

typedef void (*irq_flow_handler_t___15)(struct irq_desc___15 *);

struct msi_desc___10;

struct irq_common_data___8 {
	unsigned int state_use_accessors;
	unsigned int node;
	void *handler_data;
	struct msi_desc___10 *msi_desc;
	cpumask_var_t affinity;
	cpumask_var_t effective_affinity;
};

struct irq_chip___18;

struct irq_data___18 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___8 *common;
	struct irq_chip___18 *chip;
	struct irq_domain___11 *domain;
	struct irq_data___18 *parent_data;
	void *chip_data;
};

struct irqaction___12;

struct irq_desc___15 {
	struct irq_common_data___8 irq_common_data;
	struct irq_data___18 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___15 handle_irq;
	struct irqaction___12 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int irq_count;
	unsigned int tot_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___281 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___237 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_operations___193;

struct fwnode_handle___193 {
	struct fwnode_handle___193 *secondary;
	const struct fwnode_operations___193 *ops;
};

struct fwnode_reference_args___193;

struct fwnode_endpoint___193;

struct fwnode_operations___193 {
	struct fwnode_handle___193 * (*get)(struct fwnode_handle___193 *);
	void (*put)(struct fwnode_handle___193 *);
	bool (*device_is_available)(const struct fwnode_handle___193 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___193 *, const struct device___259 *);
	bool (*property_present)(const struct fwnode_handle___193 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___193 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___193 *, const char *, const char **, size_t);
	struct fwnode_handle___193 * (*get_parent)(const struct fwnode_handle___193 *);
	struct fwnode_handle___193 * (*get_next_child_node)(const struct fwnode_handle___193 *, struct fwnode_handle___193 *);
	struct fwnode_handle___193 * (*get_named_child_node)(const struct fwnode_handle___193 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___193 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___193 *);
	struct fwnode_handle___193 * (*graph_get_next_endpoint)(const struct fwnode_handle___193 *, struct fwnode_handle___193 *);
	struct fwnode_handle___193 * (*graph_get_remote_endpoint)(const struct fwnode_handle___193 *);
	struct fwnode_handle___193 * (*graph_get_port_parent)(struct fwnode_handle___193 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___193 *, struct fwnode_endpoint___193 *);
};

struct fwnode_endpoint___193 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___193 *local_fwnode;
};

struct fwnode_reference_args___193 {
	struct fwnode_handle___193 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct msi_desc___10 {
	struct list_head list;
	unsigned int irq;
	unsigned int nvec_used;
	struct device___259 *dev;
	struct msi_msg msg;
	struct irq_affinity_desc *affinity;
	const void *iommu_cookie;
	union {
		struct {
			u32 masked;
			struct {
				u8 is_msix: 1;
				u8 multiple: 3;
				u8 multi_cap: 3;
				u8 maskbit: 1;
				u8 is_64: 1;
				u16 entry_nr;
				unsigned int default_irq;
			} msi_attrib;
			union {
				u8 mask_pos;
				void *mask_base;
			};
		};
		struct platform_msi_desc platform;
		struct fsl_mc_msi_desc fsl_mc;
	};
};

struct irq_chip___18 {
	struct device___259 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___18 *);
	void (*irq_shutdown)(struct irq_data___18 *);
	void (*irq_enable)(struct irq_data___18 *);
	void (*irq_disable)(struct irq_data___18 *);
	void (*irq_ack)(struct irq_data___18 *);
	void (*irq_mask)(struct irq_data___18 *);
	void (*irq_mask_ack)(struct irq_data___18 *);
	void (*irq_unmask)(struct irq_data___18 *);
	void (*irq_eoi)(struct irq_data___18 *);
	int (*irq_set_affinity)(struct irq_data___18 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___18 *);
	int (*irq_set_type)(struct irq_data___18 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___18 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___18 *);
	void (*irq_bus_sync_unlock)(struct irq_data___18 *);
	void (*irq_cpu_online)(struct irq_data___18 *);
	void (*irq_cpu_offline)(struct irq_data___18 *);
	void (*irq_suspend)(struct irq_data___18 *);
	void (*irq_resume)(struct irq_data___18 *);
	void (*irq_pm_shutdown)(struct irq_data___18 *);
	void (*irq_calc_mask)(struct irq_data___18 *);
	void (*irq_print_chip)(struct irq_data___18 *, struct seq_file___252 *);
	int (*irq_request_resources)(struct irq_data___18 *);
	void (*irq_release_resources)(struct irq_data___18 *);
	void (*irq_compose_msi_msg)(struct irq_data___18 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___18 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___18 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___18 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___18 *, void *);
	void (*ipi_send_single)(struct irq_data___18 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___18 *, const struct cpumask *);
	long unsigned int flags;
};

struct irq_domain_ops___11;

struct irq_domain_chip_generic___10;

struct irq_domain___11 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___11 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___193 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___10 *gc;
	struct irq_domain___11 *parent;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_direct_max_irq;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_tree_mutex;
	unsigned int linear_revmap[0];
};

struct kernfs_root___287;

struct kernfs_elem_dir___287 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___287 *root;
};

struct kernfs_syscall_ops___287;

struct kernfs_root___287 {
	struct kernfs_node___288 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___287 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___287 {
	struct kernfs_node___288 *target_kn;
};

struct kernfs_ops___287;

struct kernfs_elem_attr___287 {
	const struct kernfs_ops___287 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___288 *notify_next;
};

struct kernfs_node___288 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___288 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___287 dir;
		struct kernfs_elem_symlink___287 symlink;
		struct kernfs_elem_attr___287 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___287;

struct kernfs_ops___287 {
	int (*open)(struct kernfs_open_file___287 *);
	void (*release)(struct kernfs_open_file___287 *);
	int (*seq_show)(struct seq_file___252 *, void *);
	void * (*seq_start)(struct seq_file___252 *, loff_t *);
	void * (*seq_next)(struct seq_file___252 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___252 *, void *);
	ssize_t (*read)(struct kernfs_open_file___287 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___287 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___287 *, struct vm_area_struct___295 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___287 *, struct poll_table_struct___179 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___287 {
	int (*remount_fs)(struct kernfs_root___287 *, int *, char *);
	int (*show_options)(struct seq_file___252 *, struct kernfs_root___287 *);
	int (*mkdir)(struct kernfs_node___288 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___288 *);
	int (*rename)(struct kernfs_node___288 *, struct kernfs_node___288 *, const char *);
	int (*show_path)(struct seq_file___252 *, struct kernfs_node___288 *, struct kernfs_root___287 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___287 {
	struct kernfs_node___288 *kn;
	struct file___294 *file;
	struct seq_file___252 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___283 *vm_ops;
};

struct bin_attribute___257;

struct attribute_group___258 {
	const char *name;
	umode_t (*is_visible)(struct kobject___281 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___281 *, struct bin_attribute___257 *, int);
	struct attribute **attrs;
	struct bin_attribute___257 **bin_attrs;
};

struct bin_attribute___257 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___294 *, struct kobject___281 *, struct bin_attribute___257 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___294 *, struct kobject___281 *, struct bin_attribute___257 *, char *, loff_t, size_t);
	int (*mmap)(struct file___294 *, struct kobject___281 *, struct bin_attribute___257 *, struct vm_area_struct___295 *);
};

struct sysfs_ops___280 {
	ssize_t (*show)(struct kobject___281 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___281 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___280;

struct kset___280 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___281 kobj;
	const struct kset_uevent_ops___280 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___280 {
	void (*release)(struct kobject___281 *);
	const struct sysfs_ops___280 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___25 * (*child_ns_type)(struct kobject___281 *);
	const void * (*namespace)(struct kobject___281 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___280 {
	int (* const filter)(struct kset___280 *, struct kobject___281 *);
	const char * (* const name)(struct kset___280 *, struct kobject___281 *);
	int (* const uevent)(struct kset___280 *, struct kobject___281 *, struct kobj_uevent_env *);
};

struct irqaction___12 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___12 *next;
	irq_handler_t thread_fn;
	struct task_struct___295 *thread;
	struct irqaction___12 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip_type___11 {
	struct irq_chip___18 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___15 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___11 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___11 *);
	void (*resume)(struct irq_chip_generic___11 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___11 *domain;
	struct list_head list;
	struct irq_chip_type___11 chip_types[0];
};

struct irq_domain_chip_generic___10 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___11 *gc[0];
};

struct dev_pm_ops___259 {
	int (*prepare)(struct device___259 *);
	void (*complete)(struct device___259 *);
	int (*suspend)(struct device___259 *);
	int (*resume)(struct device___259 *);
	int (*freeze)(struct device___259 *);
	int (*thaw)(struct device___259 *);
	int (*poweroff)(struct device___259 *);
	int (*restore)(struct device___259 *);
	int (*suspend_late)(struct device___259 *);
	int (*resume_early)(struct device___259 *);
	int (*freeze_late)(struct device___259 *);
	int (*thaw_early)(struct device___259 *);
	int (*poweroff_late)(struct device___259 *);
	int (*restore_early)(struct device___259 *);
	int (*suspend_noirq)(struct device___259 *);
	int (*resume_noirq)(struct device___259 *);
	int (*freeze_noirq)(struct device___259 *);
	int (*thaw_noirq)(struct device___259 *);
	int (*poweroff_noirq)(struct device___259 *);
	int (*restore_noirq)(struct device___259 *);
	int (*runtime_suspend)(struct device___259 *);
	int (*runtime_resume)(struct device___259 *);
	int (*runtime_idle)(struct device___259 *);
};

struct dev_pm_domain___259 {
	struct dev_pm_ops___259 ops;
	void (*detach)(struct device___259 *, bool);
	int (*activate)(struct device___259 *);
	void (*sync)(struct device___259 *);
	void (*dismiss)(struct device___259 *);
};

struct bus_type___259 {
	const char *name;
	const char *dev_name;
	struct device___259 *dev_root;
	const struct attribute_group___258 **bus_groups;
	const struct attribute_group___258 **dev_groups;
	const struct attribute_group___258 **drv_groups;
	int (*match)(struct device___259 *, struct device_driver___259 *);
	int (*uevent)(struct device___259 *, struct kobj_uevent_env *);
	int (*probe)(struct device___259 *);
	int (*remove)(struct device___259 *);
	void (*shutdown)(struct device___259 *);
	int (*online)(struct device___259 *);
	int (*offline)(struct device___259 *);
	int (*suspend)(struct device___259 *, pm_message_t);
	int (*resume)(struct device___259 *);
	int (*num_vf)(struct device___259 *);
	int (*dma_configure)(struct device___259 *);
	const struct dev_pm_ops___259 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___259 {
	const char *name;
	struct bus_type___259 *bus;
	struct module___237 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___259 *);
	int (*remove)(struct device___259 *);
	void (*shutdown)(struct device___259 *);
	int (*suspend)(struct device___259 *, pm_message_t);
	int (*resume)(struct device___259 *);
	const struct attribute_group___258 **groups;
	const struct dev_pm_ops___259 *pm;
	void (*coredump)(struct device___259 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___259 {
	const char *name;
	const struct attribute_group___258 **groups;
	int (*uevent)(struct device___259 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___259 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___259 *);
	const struct dev_pm_ops___259 *pm;
};

struct class___259 {
	const char *name;
	struct module___237 *owner;
	const struct attribute_group___258 **class_groups;
	const struct attribute_group___258 **dev_groups;
	struct kobject___281 *dev_kobj;
	int (*dev_uevent)(struct device___259 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___259 *, umode_t *);
	void (*class_release)(struct class___259 *);
	void (*dev_release)(struct device___259 *);
	int (*shutdown_pre)(struct device___259 *);
	const struct kobj_ns_type_operations___25 *ns_type;
	const void * (*namespace)(struct device___259 *);
	const struct dev_pm_ops___259 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct device_attribute___15 {
	struct attribute attr;
	ssize_t (*show)(struct device___259 *, struct device_attribute___15 *, char *);
	ssize_t (*store)(struct device___259 *, struct device_attribute___15 *, const char *, size_t);
};

struct dma_map_ops___81 {
	void * (*alloc)(struct device___259 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___259 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___259 *, struct vm_area_struct___295 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___259 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___259 *, struct page___295 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___259 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___259 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___259 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___259 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___259 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___259 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___259 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___259 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___259 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___259 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___259 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___259 *, u64);
	u64 (*get_required_mask)(struct device___259 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct property___49;

struct device_node___52 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___193 fwnode;
	struct property___49 *properties;
	struct property___49 *deadprops;
	struct device_node___52 *parent;
	struct device_node___52 *child;
	struct device_node___52 *sibling;
	struct kobject___281 kobj;
	long unsigned int _flags;
	void *data;
};

struct pci_bus___19;

struct pci_slot___19 {
	struct pci_bus___19 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject___281 kobj;
};

struct pci_dev___19;

struct pci_ops___19;

struct msi_controller___6;

struct pci_bus___19 {
	struct list_head node;
	struct pci_bus___19 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___19 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___19 *ops;
	struct msi_controller___6 *msi;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	int domain_nr;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___259 *bridge;
	struct device___259 dev;
	struct bin_attribute___257 *legacy_io;
	struct bin_attribute___257 *legacy_mem;
	unsigned int is_added: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
};

struct pci_sriov___14 {
	int pos;
	int nres;
	u32 cap;
	u16 ctrl;
	u16 total_VFs;
	u16 initial_VFs;
	u16 num_VFs;
	u16 offset;
	u16 stride;
	u16 vf_device;
	u32 pgsz;
	u8 link;
	u8 max_VF_buses;
	u16 driver_max_VFs;
	struct pci_dev___19 *dev;
	struct pci_dev___19 *self;
	u32 class;
	u8 hdr_type;
	u16 subsystem_vendor;
	u16 subsystem_device;
	resource_size_t barsz[6];
	bool drivers_autoprobe;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct pci_driver___19;

struct pci_dev___19 {
	struct list_head bus_list;
	struct pci_bus___19 *bus;
	struct pci_bus___19 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___19 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u16 aer_cap;
	struct aer_stats *aer_stats;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	long unsigned int *dma_alias_mask;
	struct pci_driver___19 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	unsigned int imm_ready: 1;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int bridge_d3: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int hotplug_user_indicators: 1;
	unsigned int clear_retrain_link: 1;
	unsigned int d3_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	unsigned int ltr_path: 1;
	unsigned int eetlp_prefix_path: 1;
	pci_channel_state_t error_state;
	struct device___259 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int multifunction: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int ats_enabled: 1;
	unsigned int pasid_enabled: 1;
	unsigned int pri_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int reset_fn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int shpc_managed: 1;
	unsigned int is_thunderbolt: 1;
	unsigned int __aer_firmware_first_valid: 1;
	unsigned int __aer_firmware_first: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int irq_managed: 1;
	unsigned int has_secondary_link: 1;
	unsigned int non_compliant_bars: 1;
	unsigned int is_probed: 1;
	unsigned int link_active_reporting: 1;
	unsigned int untrusted: 1;
	unsigned int no_vf_scan: 1;
	unsigned int io_window: 1;
	unsigned int pref_window: 1;
	unsigned int pref_64_window: 1;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	struct bin_attribute___257 *rom_attr;
	int rom_attr_enabled;
	struct bin_attribute___257 *res_attr[17];
	struct bin_attribute___257 *res_attr_wc[17];
	unsigned int broken_cmd_compl: 1;
	const struct attribute_group___258 **msi_irq_groups;
	struct pci_vpd *vpd;
	union {
		struct pci_sriov___14 *sriov;
		struct pci_dev___19 *physfn;
	};
	u16 ats_cap;
	u8 ats_stu;
	atomic_t ats_ref_cnt;
	u32 pri_reqs_alloc;
	u16 pasid_features;
	struct pci_p2pdma *p2pdma;
	phys_addr_t rom;
	size_t romlen;
	char *driver_override;
	long unsigned int priv_flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t pci_dev_extended_size_rh;
	struct pci_dev_extended_rh pci_dev_extended_rh;
};

struct pci_error_handlers___19;

struct pci_driver___19 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___19 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___19 *);
	int (*suspend)(struct pci_dev___19 *, pm_message_t);
	int (*suspend_late)(struct pci_dev___19 *, pm_message_t);
	int (*resume_early)(struct pci_dev___19 *);
	int (*resume)(struct pci_dev___19 *);
	void (*shutdown)(struct pci_dev___19 *);
	int (*sriov_configure)(struct pci_dev___19 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	const struct pci_error_handlers___19 *err_handler;
	const struct attribute_group___258 **groups;
	struct device_driver___259 driver;
	struct pci_dynids dynids;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct pci_ops___19 {
	int (*add_bus)(struct pci_bus___19 *);
	void (*remove_bus)(struct pci_bus___19 *);
	void * (*map_bus)(struct pci_bus___19 *, unsigned int, int);
	int (*read)(struct pci_bus___19 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___19 *, unsigned int, int, int, u32);
};

struct msi_controller___6 {
	struct module___237 *owner;
	struct device___259 *dev;
	struct device_node___52 *of_node;
	struct list_head list;
	int (*setup_irq)(struct msi_controller___6 *, struct pci_dev___19 *, struct msi_desc___10 *);
	int (*setup_irqs)(struct msi_controller___6 *, struct pci_dev___19 *, int, int);
	void (*teardown_irq)(struct msi_controller___6 *, unsigned int);
};

struct pci_error_handlers___19 {
	pci_ers_result_t (*error_detected)(struct pci_dev___19 *, enum pci_channel_state);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___19 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___19 *);
	void (*reset_prepare)(struct pci_dev___19 *);
	void (*reset_done)(struct pci_dev___19 *);
	void (*resume)(struct pci_dev___19 *);
};

struct msix_entry {
	u32 vector;
	u16 entry;
};

struct msi_alloc_info___5 {
	struct msi_desc___10 *desc;
	irq_hw_number_t hwirq;
	union {
		long unsigned int ul;
		void *ptr;
	} scratchpad[2];
};

typedef struct msi_alloc_info___5 msi_alloc_info_t___5;

struct msi_domain_info___5;

struct msi_domain_ops___5 {
	irq_hw_number_t (*get_hwirq)(struct msi_domain_info___5 *, msi_alloc_info_t___5 *);
	int (*msi_init)(struct irq_domain___11 *, struct msi_domain_info___5 *, unsigned int, irq_hw_number_t, msi_alloc_info_t___5 *);
	void (*msi_free)(struct irq_domain___11 *, struct msi_domain_info___5 *, unsigned int);
	int (*msi_check)(struct irq_domain___11 *, struct msi_domain_info___5 *, struct device___259 *);
	int (*msi_prepare)(struct irq_domain___11 *, struct device___259 *, int, msi_alloc_info_t___5 *);
	void (*msi_finish)(msi_alloc_info_t___5 *, int);
	void (*set_desc)(msi_alloc_info_t___5 *, struct msi_desc___10 *);
	int (*handle_error)(struct irq_domain___11 *, struct msi_desc___10 *, int);
};

struct msi_domain_info___5 {
	u32 flags;
	struct msi_domain_ops___5 *ops;
	struct irq_chip___18 *chip;
	void *chip_data;
	irq_flow_handler_t___15 handler;
	void *handler_data;
	const char *handler_name;
	void *data;
};

struct kernel_param_ops___234 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___234 *);
	int (*get)(char *, const struct kernel_param___234 *);
	void (*free)(void *);
};

struct kparam_array___234;

struct kernel_param___234 {
	const char *name;
	struct module___237 *mod;
	const struct kernel_param_ops___234 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___234 *arr;
	};
};

struct kparam_array___234 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___234 *ops;
	void *elem;
};

struct module_attribute___234 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___234 *, struct module_kobject___234 *, char *);
	ssize_t (*store)(struct module_attribute___234 *, struct module_kobject___234 *, const char *, size_t);
	void (*setup)(struct module___237 *, const char *);
	int (*test)(struct module___237 *);
	void (*free)(struct module___237 *);
};

typedef int (*key_restrict_link_func_t___275)(struct key___274 *, const struct key_type *, const union key_payload *, struct key___274 *);

struct key_restriction___274;

struct key___274 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___295 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___274 *restrict_link;
};

struct key_restriction___274 {
	key_restrict_link_func_t___275 check;
	struct key___274 *key;
	struct key_type *keytype;
};

struct seq_operations___251 {
	void * (*start)(struct seq_file___252 *, loff_t *);
	void (*stop)(struct seq_file___252 *, void *);
	void * (*next)(struct seq_file___252 *, void *, loff_t *);
	int (*show)(struct seq_file___252 *, void *);
};

struct property___49 {
	char *name;
	int length;
	void *value;
	struct property___49 *next;
	long unsigned int _flags;
	struct bin_attribute___257 attr;
};

struct irq_fwspec___11 {
	struct fwnode_handle___193 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___11 {
	int (*match)(struct irq_domain___11 *, struct device_node___52 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___11 *, struct irq_fwspec___11 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___11 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___11 *, unsigned int);
	int (*xlate)(struct irq_domain___11 *, struct device_node___52 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___11 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___11 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___11 *, struct irq_data___18 *, bool);
	void (*deactivate)(struct irq_domain___11 *, struct irq_data___18 *);
	int (*translate)(struct irq_domain___11 *, struct irq_fwspec___11 *, long unsigned int *, unsigned int *);
};

struct module___238;

struct file___295;

struct kiocb___295;

struct poll_table_struct___180;

struct vm_area_struct___296;

struct inode___295;

struct file_lock___295;

struct page___296;

struct seq_file___253;

struct file_operations___295 {
	struct module___238 *owner;
	loff_t (*llseek)(struct file___295 *, loff_t, int);
	ssize_t (*read)(struct file___295 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___295 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___295 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___295 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___295 *, bool);
	int (*iterate)(struct file___295 *, struct dir_context *);
	int (*iterate_shared)(struct file___295 *, struct dir_context *);
	__poll_t (*poll)(struct file___295 *, struct poll_table_struct___180 *);
	long int (*unlocked_ioctl)(struct file___295 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___295 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___295 *, struct vm_area_struct___296 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___295 *, struct file___295 *);
	int (*flush)(struct file___295 *, fl_owner_t);
	int (*release)(struct inode___295 *, struct file___295 *);
	int (*fsync)(struct file___295 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___295 *, int);
	int (*lock)(struct file___295 *, int, struct file_lock___295 *);
	ssize_t (*sendpage)(struct file___295 *, struct page___296 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___295 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___295 *, int, struct file_lock___295 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___295 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___295 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___295 *, long int, struct file_lock___295 **, void **);
	long int (*fallocate)(struct file___295 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___253 *, struct file___295 *);
	ssize_t (*copy_file_range)(struct file___295 *, loff_t, struct file___295 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___295 *, loff_t, struct file___295 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___295 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___295 {
	u64 seqnum;
	struct vm_area_struct___296 *vmas[4];
};

struct page_frag___295 {
	struct page___296 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___295;

struct cred___275;

struct vm_struct___211;

struct task_struct___296 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___296 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___295 *mm;
	struct mm_struct___295 *active_mm;
	struct vmacache___295 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___296 *real_parent;
	struct task_struct___296 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___296 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___195 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___195 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___195 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___275 *ptracer_cred;
	const struct cred___275 *real_cred;
	const struct cred___275 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___296 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___82 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___295 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___296 *oom_reaper_list;
	struct vm_struct___211 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___130 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___296 *pgtable_t___295;

struct address_space___294;

struct dev_pagemap___284;

struct page___296 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___294 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___296 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___295 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___295 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___284 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___295;

struct lruvec___295 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___295 *pgdat;
};

struct zone___295 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___295 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___295 {
	struct zone___295 *zone;
	int zone_idx;
};

struct zonelist___295 {
	struct zoneref___295 _zonerefs[25];
};

struct pglist_data___295 {
	struct zone___295 node_zones[3];
	struct zonelist___295 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___296 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___296 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___295 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___296 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___296 *owner;
};

struct secondary_data___296 {
	void *stack;
	struct task_struct___296 *task;
	long int status;
};

struct blocking_notifier_head___295 {
	struct rw_semaphore___296 rwsem;
	struct notifier_block *head;
};

struct kernfs_root___288;

struct kernfs_elem_dir___288 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___288 *root;
};

struct kernfs_node___289;

struct kernfs_syscall_ops___288;

struct kernfs_root___288 {
	struct kernfs_node___289 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___288 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___288 {
	struct kernfs_node___289 *target_kn;
};

struct kernfs_ops___288;

struct kernfs_elem_attr___288 {
	const struct kernfs_ops___288 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___289 *notify_next;
};

struct kernfs_node___289 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___289 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___288 dir;
		struct kernfs_elem_symlink___288 symlink;
		struct kernfs_elem_attr___288 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___288;

struct kernfs_ops___288 {
	int (*open)(struct kernfs_open_file___288 *);
	void (*release)(struct kernfs_open_file___288 *);
	int (*seq_show)(struct seq_file___253 *, void *);
	void * (*seq_start)(struct seq_file___253 *, loff_t *);
	void * (*seq_next)(struct seq_file___253 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___253 *, void *);
	ssize_t (*read)(struct kernfs_open_file___288 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___288 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___288 *, struct vm_area_struct___296 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___288 *, struct poll_table_struct___180 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___288 {
	int (*remount_fs)(struct kernfs_root___288 *, int *, char *);
	int (*show_options)(struct seq_file___253 *, struct kernfs_root___288 *);
	int (*mkdir)(struct kernfs_node___289 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___289 *);
	int (*rename)(struct kernfs_node___289 *, struct kernfs_node___289 *, const char *);
	int (*show_path)(struct seq_file___253 *, struct kernfs_node___289 *, struct kernfs_root___288 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___252;

struct seq_file___253 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___252 *op;
	int poll_event;
	const struct file___295 *file;
	void *private;
};

struct vm_operations_struct___284;

struct kernfs_open_file___288 {
	struct kernfs_node___289 *kn;
	struct file___295 *file;
	struct seq_file___253 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___284 *vm_ops;
};

struct dentry___295;

struct path___295 {
	struct vfsmount *mnt;
	struct dentry___295 *dentry;
};

struct file___295 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___295 f_path;
	struct inode___295 *f_inode;
	const struct file_operations___295 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___195 f_owner;
	const struct cred___275 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___294 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___284;

struct vm_operations_struct___284 {
	void (*open)(struct vm_area_struct___296 *);
	void (*close)(struct vm_area_struct___296 *);
	int (*split)(struct vm_area_struct___296 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___296 *);
	vm_fault_t (*fault)(struct vm_fault___284 *);
	vm_fault_t (*huge_fault)(struct vm_fault___284 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___284 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___296 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___284 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___284 *);
	int (*access)(struct vm_area_struct___296 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___296 *);
	int (*set_policy)(struct vm_area_struct___296 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___296 *, long unsigned int);
	struct page___296 * (*find_special_page)(struct vm_area_struct___296 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___183)(struct file___295 *, wait_queue_head_t *, struct poll_table_struct___180 *);

struct poll_table_struct___180 {
	poll_queue_proc___183 _qproc;
	__poll_t _key;
};

struct vm_area_struct___296 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___296 *vm_next;
	struct vm_area_struct___296 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___295 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___284 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___295 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___282;

struct bin_attribute___258;

struct attribute_group___259 {
	const char *name;
	umode_t (*is_visible)(struct kobject___282 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___282 *, struct bin_attribute___258 *, int);
	struct attribute **attrs;
	struct bin_attribute___258 **bin_attrs;
};

struct kset___281;

struct kobj_type___281;

struct kobject___282 {
	const char *name;
	struct list_head entry;
	struct kobject___282 *parent;
	struct kset___281 *kset;
	struct kobj_type___281 *ktype;
	struct kernfs_node___289 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___258 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___295 *, struct kobject___282 *, struct bin_attribute___258 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___295 *, struct kobject___282 *, struct bin_attribute___258 *, char *, loff_t, size_t);
	int (*mmap)(struct file___295 *, struct kobject___282 *, struct bin_attribute___258 *, struct vm_area_struct___296 *);
};

struct sysfs_ops___281 {
	ssize_t (*show)(struct kobject___282 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___282 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___281;

struct kset___281 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___282 kobj;
	const struct kset_uevent_ops___281 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___281 {
	void (*release)(struct kobject___282 *);
	const struct sysfs_ops___281 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___25 * (*child_ns_type)(struct kobject___282 *);
	const void * (*namespace)(struct kobject___282 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___281 {
	int (* const filter)(struct kset___281 *, struct kobject___282 *);
	const char * (* const name)(struct kset___281 *, struct kobject___282 *);
	int (* const uevent)(struct kset___281 *, struct kobject___282 *, struct kobj_uevent_env *);
};

struct kobj_attribute___274 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___282 *, struct kobj_attribute___274 *, char *);
	ssize_t (*store)(struct kobject___282 *, struct kobj_attribute___274 *, const char *, size_t);
};

struct fwnode_operations___194;

struct fwnode_handle___194 {
	struct fwnode_handle___194 *secondary;
	const struct fwnode_operations___194 *ops;
};

struct device___260;

struct fwnode_reference_args___194;

struct fwnode_endpoint___194;

struct fwnode_operations___194 {
	struct fwnode_handle___194 * (*get)(struct fwnode_handle___194 *);
	void (*put)(struct fwnode_handle___194 *);
	bool (*device_is_available)(const struct fwnode_handle___194 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___194 *, const struct device___260 *);
	bool (*property_present)(const struct fwnode_handle___194 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___194 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___194 *, const char *, const char **, size_t);
	struct fwnode_handle___194 * (*get_parent)(const struct fwnode_handle___194 *);
	struct fwnode_handle___194 * (*get_next_child_node)(const struct fwnode_handle___194 *, struct fwnode_handle___194 *);
	struct fwnode_handle___194 * (*get_named_child_node)(const struct fwnode_handle___194 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___194 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___194 *);
	struct fwnode_handle___194 * (*graph_get_next_endpoint)(const struct fwnode_handle___194 *, struct fwnode_handle___194 *);
	struct fwnode_handle___194 * (*graph_get_remote_endpoint)(const struct fwnode_handle___194 *);
	struct fwnode_handle___194 * (*graph_get_port_parent)(struct fwnode_handle___194 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___194 *, struct fwnode_endpoint___194 *);
};

struct fwnode_endpoint___194 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___194 *local_fwnode;
};

struct fwnode_reference_args___194 {
	struct fwnode_handle___194 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct dev_pm_qos___10;

struct dev_pm_info___260 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___260 *, s32);
	struct dev_pm_qos___10 *qos;
};

struct device_type___260;

struct bus_type___260;

struct device_driver___260;

struct dev_pm_domain___260;

struct irq_domain___12;

struct dma_map_ops___82;

struct device_node___53;

struct class___260;

struct device___260 {
	struct device___260 *parent;
	struct device_private *p;
	struct kobject___282 kobj;
	const char *init_name;
	const struct device_type___260 *type;
	struct mutex mutex;
	struct bus_type___260 *bus;
	struct device_driver___260 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___260 power;
	struct dev_pm_domain___260 *pm_domain;
	struct irq_domain___12 *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___82 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___53 *of_node;
	struct fwnode_handle___194 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___260 *class;
	const struct attribute_group___259 **groups;
	void (*release)(struct device___260 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct property___50 {
	char *name;
	int length;
	void *value;
	struct property___50 *next;
	long unsigned int _flags;
	struct bin_attribute___258 attr;
};

struct device_node___53 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___194 fwnode;
	struct property___50 *properties;
	struct property___50 *deadprops;
	struct device_node___53 *parent;
	struct device_node___53 *child;
	struct device_node___53 *sibling;
	struct kobject___282 kobj;
	long unsigned int _flags;
	void *data;
};

struct irq_fwspec___12 {
	struct fwnode_handle___194 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___12 {
	int (*match)(struct irq_domain___12 *, struct device_node___53 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___12 *, struct irq_fwspec___12 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___12 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___12 *, unsigned int);
	int (*xlate)(struct irq_domain___12 *, struct device_node___53 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___12 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___12 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___12 *, struct irq_data___5 *, bool);
	void (*deactivate)(struct irq_domain___12 *, struct irq_data___5 *);
	int (*translate)(struct irq_domain___12 *, struct irq_fwspec___12 *, long unsigned int *, unsigned int *);
};

struct irq_domain___12 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___12 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___194 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___2 *gc;
	struct irq_domain___12 *parent;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_direct_max_irq;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_tree_mutex;
	unsigned int linear_revmap[0];
};

struct dev_pm_ops___260 {
	int (*prepare)(struct device___260 *);
	void (*complete)(struct device___260 *);
	int (*suspend)(struct device___260 *);
	int (*resume)(struct device___260 *);
	int (*freeze)(struct device___260 *);
	int (*thaw)(struct device___260 *);
	int (*poweroff)(struct device___260 *);
	int (*restore)(struct device___260 *);
	int (*suspend_late)(struct device___260 *);
	int (*resume_early)(struct device___260 *);
	int (*freeze_late)(struct device___260 *);
	int (*thaw_early)(struct device___260 *);
	int (*poweroff_late)(struct device___260 *);
	int (*restore_early)(struct device___260 *);
	int (*suspend_noirq)(struct device___260 *);
	int (*resume_noirq)(struct device___260 *);
	int (*freeze_noirq)(struct device___260 *);
	int (*thaw_noirq)(struct device___260 *);
	int (*poweroff_noirq)(struct device___260 *);
	int (*restore_noirq)(struct device___260 *);
	int (*runtime_suspend)(struct device___260 *);
	int (*runtime_resume)(struct device___260 *);
	int (*runtime_idle)(struct device___260 *);
};

struct pm_qos_constraints___10 {
	struct plist_head list;
	s32 target_value;
	s32 default_value;
	s32 no_constraint_value;
	enum pm_qos_type type;
	struct blocking_notifier_head___295 *notifiers;
};

struct dev_pm_qos_request___10;

struct dev_pm_qos___10 {
	struct pm_qos_constraints___10 resume_latency;
	struct pm_qos_constraints___10 latency_tolerance;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___10 *resume_latency_req;
	struct dev_pm_qos_request___10 *latency_tolerance_req;
	struct dev_pm_qos_request___10 *flags_req;
};

struct dev_pm_domain___260 {
	struct dev_pm_ops___260 ops;
	void (*detach)(struct device___260 *, bool);
	int (*activate)(struct device___260 *);
	void (*sync)(struct device___260 *);
	void (*dismiss)(struct device___260 *);
};

struct key___275;

struct user_struct___275 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___275 *uid_keyring;
	struct key___275 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___295;

struct mm_struct___295 {
	struct {
		struct vm_area_struct___296 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___295 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___296 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___295 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___296 *owner;
		struct user_namespace___3 *user_ns;
		struct file___295 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___295 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___275 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___275 *session_keyring;
	struct key___275 *process_keyring;
	struct key___275 *thread_keyring;
	struct key___275 *request_key_auth;
	void *security;
	struct user_struct___275 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct vm_struct___211 {
	struct vm_struct___211 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___296 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bus_type___260 {
	const char *name;
	const char *dev_name;
	struct device___260 *dev_root;
	const struct attribute_group___259 **bus_groups;
	const struct attribute_group___259 **dev_groups;
	const struct attribute_group___259 **drv_groups;
	int (*match)(struct device___260 *, struct device_driver___260 *);
	int (*uevent)(struct device___260 *, struct kobj_uevent_env *);
	int (*probe)(struct device___260 *);
	int (*remove)(struct device___260 *);
	void (*shutdown)(struct device___260 *);
	int (*online)(struct device___260 *);
	int (*offline)(struct device___260 *);
	int (*suspend)(struct device___260 *, pm_message_t);
	int (*resume)(struct device___260 *);
	int (*num_vf)(struct device___260 *);
	int (*dma_configure)(struct device___260 *);
	const struct dev_pm_ops___260 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___260 {
	const char *name;
	struct bus_type___260 *bus;
	struct module___238 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___260 *);
	int (*remove)(struct device___260 *);
	void (*shutdown)(struct device___260 *);
	int (*suspend)(struct device___260 *, pm_message_t);
	int (*resume)(struct device___260 *);
	const struct attribute_group___259 **groups;
	const struct dev_pm_ops___260 *pm;
	void (*coredump)(struct device___260 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___260 {
	const char *name;
	const struct attribute_group___259 **groups;
	int (*uevent)(struct device___260 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___260 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___260 *);
	const struct dev_pm_ops___260 *pm;
};

struct module_kobject___235 {
	struct kobject___282 kobj;
	struct module___238 *mod;
	struct kobject___282 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___235 {
	struct module___238 *mod;
	struct latch_tree_node node;
};

struct module_layout___235 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___235 mtn;
};

struct module_attribute___235;

struct kernel_param___235;

struct module___238 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___235 mkobj;
	struct module_attribute___235 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___282 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___235 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___235 core_layout;
	struct module_layout___235 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct class___260 {
	const char *name;
	struct module___238 *owner;
	const struct attribute_group___259 **class_groups;
	const struct attribute_group___259 **dev_groups;
	struct kobject___282 *dev_kobj;
	int (*dev_uevent)(struct device___260 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___260 *, umode_t *);
	void (*class_release)(struct class___260 *);
	void (*dev_release)(struct device___260 *);
	int (*shutdown_pre)(struct device___260 *);
	const struct kobj_ns_type_operations___25 *ns_type;
	const void * (*namespace)(struct device___260 *);
	const struct dev_pm_ops___260 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___82 {
	void * (*alloc)(struct device___260 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___260 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___260 *, struct vm_area_struct___296 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___260 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___260 *, struct page___296 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___260 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___260 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___260 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___260 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___260 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___260 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___260 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___260 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___260 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___260 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___260 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___260 *, u64);
	u64 (*get_required_mask)(struct device___260 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct address_space_operations___294;

struct address_space___294 {
	struct inode___295 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___296 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___294 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___284)(struct vm_area_struct___296 *, long unsigned int, const struct page___296 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___284)(struct page___296 *, void *);

struct dev_pagemap___284 {
	dev_page_fault_t___284 page_fault;
	dev_page_free_t___284 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___260 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___295 {
	struct task_struct___296 *task;
	struct core_thread___295 *next;
};

struct core_state___295 {
	atomic_t nr_threads;
	struct core_thread___295 dumper;
	struct completion startup;
};

struct vm_fault___284 {
	struct vm_area_struct___296 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___296 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___296 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___295 prealloc_pte;
};

struct pci_bus___20;

struct hotplug_slot___6;

struct pci_slot___20 {
	struct pci_bus___20 *bus;
	struct list_head list;
	struct hotplug_slot___6 *hotplug;
	unsigned char number;
	struct kobject___282 kobj;
};

struct pci_dev___20;

struct pci_ops___20;

struct msi_controller___7;

struct pci_bus___20 {
	struct list_head node;
	struct pci_bus___20 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___20 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___20 *ops;
	struct msi_controller___7 *msi;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	int domain_nr;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___260 *bridge;
	struct device___260 dev;
	struct bin_attribute___258 *legacy_io;
	struct bin_attribute___258 *legacy_mem;
	unsigned int is_added: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
};

struct hotplug_slot_ops___6;

struct hotplug_slot___6 {
	const struct hotplug_slot_ops___6 *ops;
	struct list_head slot_list;
	struct pci_slot___20 *pci_slot;
	struct module___238 *owner;
	const char *mod_name;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct pci_sriov___15 {
	int pos;
	int nres;
	u32 cap;
	u16 ctrl;
	u16 total_VFs;
	u16 initial_VFs;
	u16 num_VFs;
	u16 offset;
	u16 stride;
	u16 vf_device;
	u32 pgsz;
	u8 link;
	u8 max_VF_buses;
	u16 driver_max_VFs;
	struct pci_dev___20 *dev;
	struct pci_dev___20 *self;
	u32 class;
	u8 hdr_type;
	u16 subsystem_vendor;
	u16 subsystem_device;
	resource_size_t barsz[6];
	bool drivers_autoprobe;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct pci_driver___20;

struct pci_dev___20 {
	struct list_head bus_list;
	struct pci_bus___20 *bus;
	struct pci_bus___20 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___20 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u16 aer_cap;
	struct aer_stats *aer_stats;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	long unsigned int *dma_alias_mask;
	struct pci_driver___20 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	unsigned int imm_ready: 1;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int bridge_d3: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int hotplug_user_indicators: 1;
	unsigned int clear_retrain_link: 1;
	unsigned int d3_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	unsigned int ltr_path: 1;
	unsigned int eetlp_prefix_path: 1;
	pci_channel_state_t error_state;
	struct device___260 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int multifunction: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int ats_enabled: 1;
	unsigned int pasid_enabled: 1;
	unsigned int pri_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int reset_fn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int shpc_managed: 1;
	unsigned int is_thunderbolt: 1;
	unsigned int __aer_firmware_first_valid: 1;
	unsigned int __aer_firmware_first: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int irq_managed: 1;
	unsigned int has_secondary_link: 1;
	unsigned int non_compliant_bars: 1;
	unsigned int is_probed: 1;
	unsigned int link_active_reporting: 1;
	unsigned int untrusted: 1;
	unsigned int no_vf_scan: 1;
	unsigned int io_window: 1;
	unsigned int pref_window: 1;
	unsigned int pref_64_window: 1;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	struct bin_attribute___258 *rom_attr;
	int rom_attr_enabled;
	struct bin_attribute___258 *res_attr[17];
	struct bin_attribute___258 *res_attr_wc[17];
	unsigned int broken_cmd_compl: 1;
	const struct attribute_group___259 **msi_irq_groups;
	struct pci_vpd *vpd;
	union {
		struct pci_sriov___15 *sriov;
		struct pci_dev___20 *physfn;
	};
	u16 ats_cap;
	u8 ats_stu;
	atomic_t ats_ref_cnt;
	u32 pri_reqs_alloc;
	u16 pasid_features;
	struct pci_p2pdma *p2pdma;
	phys_addr_t rom;
	size_t romlen;
	char *driver_override;
	long unsigned int priv_flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t pci_dev_extended_size_rh;
	struct pci_dev_extended_rh pci_dev_extended_rh;
};

struct pci_error_handlers___20;

struct pci_driver___20 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___20 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___20 *);
	int (*suspend)(struct pci_dev___20 *, pm_message_t);
	int (*suspend_late)(struct pci_dev___20 *, pm_message_t);
	int (*resume_early)(struct pci_dev___20 *);
	int (*resume)(struct pci_dev___20 *);
	void (*shutdown)(struct pci_dev___20 *);
	int (*sriov_configure)(struct pci_dev___20 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	const struct pci_error_handlers___20 *err_handler;
	const struct attribute_group___259 **groups;
	struct device_driver___260 driver;
	struct pci_dynids dynids;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct pci_host_bridge___4 {
	struct device___260 dev;
	struct pci_bus___20 *bus;
	struct pci_ops___20 *ops;
	void *sysdata;
	int busnr;
	struct list_head windows;
	u8 (*swizzle_irq)(struct pci_dev___20 *, u8 *);
	int (*map_irq)(const struct pci_dev___20 *, u8, u8);
	void (*release_fn)(struct pci_host_bridge___4 *);
	void *release_data;
	struct msi_controller___7 *msi;
	unsigned int ignore_reset_delay: 1;
	unsigned int no_ext_tags: 1;
	unsigned int native_aer: 1;
	unsigned int native_pcie_hotplug: 1;
	unsigned int native_shpc_hotplug: 1;
	unsigned int native_pme: 1;
	unsigned int native_ltr: 1;
	resource_size_t (*align_resource)(struct pci_dev___20 *, const struct resource *, resource_size_t, resource_size_t, resource_size_t);
	long: 64;
	long unsigned int private[0];
};

struct pci_ops___20 {
	int (*add_bus)(struct pci_bus___20 *);
	void (*remove_bus)(struct pci_bus___20 *);
	void * (*map_bus)(struct pci_bus___20 *, unsigned int, int);
	int (*read)(struct pci_bus___20 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___20 *, unsigned int, int, int, u32);
};

struct msi_desc___11;

struct msi_controller___7 {
	struct module___238 *owner;
	struct device___260 *dev;
	struct device_node___53 *of_node;
	struct list_head list;
	int (*setup_irq)(struct msi_controller___7 *, struct pci_dev___20 *, struct msi_desc___11 *);
	int (*setup_irqs)(struct msi_controller___7 *, struct pci_dev___20 *, int, int);
	void (*teardown_irq)(struct msi_controller___7 *, unsigned int);
};

struct pci_error_handlers___20 {
	pci_ers_result_t (*error_detected)(struct pci_dev___20 *, enum pci_channel_state);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___20 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___20 *);
	void (*reset_prepare)(struct pci_dev___20 *);
	void (*reset_done)(struct pci_dev___20 *);
	void (*resume)(struct pci_dev___20 *);
};

struct dentry_operations___294;

struct super_block___294;

struct dentry___295 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___295 *d_parent;
	struct qstr d_name;
	struct inode___295 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___294 *d_op;
	struct super_block___294 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___294;

struct block_device___294;

struct cdev___53;

struct inode___295 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___294 *i_op;
	struct super_block___294 *i_sb;
	struct address_space___294 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___296 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___295 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___294 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___294 *i_bdev;
		struct cdev___53 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___294 {
	int (*d_revalidate)(struct dentry___295 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___295 *, unsigned int);
	int (*d_hash)(const struct dentry___295 *, struct qstr *);
	int (*d_compare)(const struct dentry___295 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___295 *);
	int (*d_init)(struct dentry___295 *);
	void (*d_release)(struct dentry___295 *);
	void (*d_prune)(struct dentry___295 *);
	void (*d_iput)(struct dentry___295 *, struct inode___295 *);
	char * (*d_dname)(struct dentry___295 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___295 *);
	int (*d_manage)(const struct path___295 *, bool);
	struct dentry___295 * (*d_real)(struct dentry___295 *, const struct inode___295 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___294;

struct mem_dqinfo___294 {
	struct quota_format_type___294 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___294;

struct quota_info___294 {
	unsigned int flags;
	struct rw_semaphore___296 dqio_sem;
	struct inode___295 *files[3];
	struct mem_dqinfo___294 info[3];
	const struct quota_format_ops___294 *ops[3];
};

struct rcuwait___294 {
	struct task_struct___296 *task;
};

struct percpu_rw_semaphore___294 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___296 rw_sem;
	struct rcuwait___294 writer;
	int readers_block;
};

struct sb_writers___294 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___294 rw_sem[3];
};

struct file_system_type___294;

struct super_operations___294;

struct dquot_operations___294;

struct quotactl_ops___294;

struct super_block___294 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___294 *s_type;
	const struct super_operations___294 *s_op;
	const struct dquot_operations___294 *dq_op;
	const struct quotactl_ops___294 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___295 *s_root;
	struct rw_semaphore___296 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___294 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___294 s_dquot;
	struct sb_writers___294 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___294 *s_d_op;
	int cleancache_poolid;
	struct shrinker___116 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___295 {
	struct file___295 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___295 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___294 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___295 *ia_file;
};

struct dquot___294 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___294 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___294 {
	int qf_fmt_id;
	const struct quota_format_ops___294 *qf_ops;
	struct module___238 *qf_owner;
	struct quota_format_type___294 *qf_next;
};

struct quota_format_ops___294 {
	int (*check_quota_file)(struct super_block___294 *, int);
	int (*read_file_info)(struct super_block___294 *, int);
	int (*write_file_info)(struct super_block___294 *, int);
	int (*free_file_info)(struct super_block___294 *, int);
	int (*read_dqblk)(struct dquot___294 *);
	int (*commit_dqblk)(struct dquot___294 *);
	int (*release_dqblk)(struct dquot___294 *);
	int (*get_next_id)(struct super_block___294 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___294 {
	int (*write_dquot)(struct dquot___294 *);
	struct dquot___294 * (*alloc_dquot)(struct super_block___294 *, int);
	void (*destroy_dquot)(struct dquot___294 *);
	int (*acquire_dquot)(struct dquot___294 *);
	int (*release_dquot)(struct dquot___294 *);
	int (*mark_dirty)(struct dquot___294 *);
	int (*write_info)(struct super_block___294 *, int);
	qsize_t * (*get_reserved_space)(struct inode___295 *);
	int (*get_projid)(struct inode___295 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___295 *, qsize_t *);
	int (*get_next_id)(struct super_block___294 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___294 {
	int (*quota_on)(struct super_block___294 *, int, int, const struct path___295 *);
	int (*quota_off)(struct super_block___294 *, int);
	int (*quota_enable)(struct super_block___294 *, unsigned int);
	int (*quota_disable)(struct super_block___294 *, unsigned int);
	int (*quota_sync)(struct super_block___294 *, int);
	int (*set_info)(struct super_block___294 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___294 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___294 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___294 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___294 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___294 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___294 {
	int (*writepage)(struct page___296 *, struct writeback_control___3 *);
	int (*readpage)(struct file___295 *, struct page___296 *);
	int (*writepages)(struct address_space___294 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___296 *);
	int (*readpages)(struct file___295 *, struct address_space___294 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___295 *, struct address_space___294 *, loff_t, unsigned int, unsigned int, struct page___296 **, void **);
	int (*write_end)(struct file___295 *, struct address_space___294 *, loff_t, unsigned int, unsigned int, struct page___296 *, void *);
	sector_t (*bmap)(struct address_space___294 *, sector_t);
	void (*invalidatepage)(struct page___296 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___296 *, gfp_t);
	void (*freepage)(struct page___296 *);
	ssize_t (*direct_IO)(struct kiocb___295 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___294 *, struct page___296 *, struct page___296 *, enum migrate_mode);
	bool (*isolate_page)(struct page___296 *, isolate_mode_t);
	void (*putback_page)(struct page___296 *);
	int (*launder_page)(struct page___296 *);
	int (*is_partially_uptodate)(struct page___296 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___296 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___294 *, struct page___296 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___295 *, sector_t *);
	void (*swap_deactivate)(struct file___295 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___294 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___295 *bd_inode;
	struct super_block___294 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___294 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___53 {
	struct kobject___282 kobj;
	struct module___238 *owner;
	const struct file_operations___295 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___294 {
	struct dentry___295 * (*lookup)(struct inode___295 *, struct dentry___295 *, unsigned int);
	const char * (*get_link)(struct dentry___295 *, struct inode___295 *, struct delayed_call *);
	int (*permission)(struct inode___295 *, int);
	struct posix_acl * (*get_acl)(struct inode___295 *, int);
	int (*readlink)(struct dentry___295 *, char *, int);
	int (*create)(struct inode___295 *, struct dentry___295 *, umode_t, bool);
	int (*link)(struct dentry___295 *, struct inode___295 *, struct dentry___295 *);
	int (*unlink)(struct inode___295 *, struct dentry___295 *);
	int (*symlink)(struct inode___295 *, struct dentry___295 *, const char *);
	int (*mkdir)(struct inode___295 *, struct dentry___295 *, umode_t);
	int (*rmdir)(struct inode___295 *, struct dentry___295 *);
	int (*mknod)(struct inode___295 *, struct dentry___295 *, umode_t, dev_t);
	int (*rename)(struct inode___295 *, struct dentry___295 *, struct inode___295 *, struct dentry___295 *, unsigned int);
	int (*setattr)(struct dentry___295 *, struct iattr___294 *);
	int (*getattr)(const struct path___295 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___295 *, char *, size_t);
	int (*fiemap)(struct inode___295 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___295 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___295 *, struct dentry___295 *, struct file___295 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___295 *, struct dentry___295 *, umode_t);
	int (*set_acl)(struct inode___295 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___294 {
	void (*fl_copy_lock)(struct file_lock___295 *, struct file_lock___295 *);
	void (*fl_release_private)(struct file_lock___295 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___294;

struct lock_manager_operations___294;

struct file_lock___295 {
	struct file_lock___295 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___295 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___294 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___294 *fl_ops;
	const struct lock_manager_operations___294 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___294 {
	int (*lm_compare_owner)(struct file_lock___295 *, struct file_lock___295 *);
	long unsigned int (*lm_owner_key)(struct file_lock___295 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___295 *);
	int (*lm_grant)(struct file_lock___295 *, int);
	bool (*lm_break)(struct file_lock___295 *);
	int (*lm_change)(struct file_lock___295 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___295 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___294 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___294 *fa_next;
	struct file___295 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___294 {
	const char *name;
	int fs_flags;
	struct dentry___295 * (*mount)(struct file_system_type___294 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___294 *);
	struct module___238 *owner;
	struct file_system_type___294 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___294 {
	struct inode___295 * (*alloc_inode)(struct super_block___294 *);
	void (*destroy_inode)(struct inode___295 *);
	void (*dirty_inode)(struct inode___295 *, int);
	int (*write_inode)(struct inode___295 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___295 *);
	void (*evict_inode)(struct inode___295 *);
	void (*put_super)(struct super_block___294 *);
	int (*sync_fs)(struct super_block___294 *, int);
	int (*freeze_super)(struct super_block___294 *);
	int (*freeze_fs)(struct super_block___294 *);
	int (*thaw_super)(struct super_block___294 *);
	int (*unfreeze_fs)(struct super_block___294 *);
	int (*statfs)(struct dentry___295 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___294 *, int *, char *);
	void (*umount_begin)(struct super_block___294 *);
	int (*show_options)(struct seq_file___253 *, struct dentry___295 *);
	int (*show_devname)(struct seq_file___253 *, struct dentry___295 *);
	int (*show_path)(struct seq_file___253 *, struct dentry___295 *);
	int (*show_stats)(struct seq_file___253 *, struct dentry___295 *);
	ssize_t (*quota_read)(struct super_block___294 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___294 *, int, const char *, size_t, loff_t);
	struct dquot___294 ** (*get_dquots)(struct inode___295 *);
	int (*bdev_try_to_free_page)(struct super_block___294 *, struct page___296 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___294 *, struct shrink_control___116 *);
	long int (*free_cached_objects)(struct super_block___294 *, struct shrink_control___116 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___284(struct page___296 *);

struct msi_desc___11 {
	struct list_head list;
	unsigned int irq;
	unsigned int nvec_used;
	struct device___260 *dev;
	struct msi_msg msg;
	struct irq_affinity_desc *affinity;
	const void *iommu_cookie;
	union {
		struct {
			u32 masked;
			struct {
				u8 is_msix: 1;
				u8 multiple: 3;
				u8 multi_cap: 3;
				u8 maskbit: 1;
				u8 is_64: 1;
				u16 entry_nr;
				unsigned int default_irq;
			} msi_attrib;
			union {
				u8 mask_pos;
				void *mask_base;
			};
		};
		struct platform_msi_desc platform;
		struct fsl_mc_msi_desc fsl_mc;
	};
};

struct hotplug_slot_ops___6 {
	int (*enable_slot)(struct hotplug_slot___6 *);
	int (*disable_slot)(struct hotplug_slot___6 *);
	int (*set_attention_status)(struct hotplug_slot___6 *, u8);
	int (*hardware_test)(struct hotplug_slot___6 *, u32);
	int (*get_power_status)(struct hotplug_slot___6 *, u8 *);
	int (*get_attention_status)(struct hotplug_slot___6 *, u8 *);
	int (*get_latch_status)(struct hotplug_slot___6 *, u8 *);
	int (*get_adapter_status)(struct hotplug_slot___6 *, u8 *);
	int (*reset_slot)(struct hotplug_slot___6 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct kernel_param_ops___235 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___235 *);
	int (*get)(char *, const struct kernel_param___235 *);
	void (*free)(void *);
};

struct kparam_array___235;

struct kernel_param___235 {
	const char *name;
	struct module___238 *mod;
	const struct kernel_param_ops___235 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___235 *arr;
	};
};

struct kparam_array___235 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___235 *ops;
	void *elem;
};

struct module_attribute___235 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___235 *, struct module_kobject___235 *, char *);
	ssize_t (*store)(struct module_attribute___235 *, struct module_kobject___235 *, const char *, size_t);
	void (*setup)(struct module___238 *, const char *);
	int (*test)(struct module___238 *);
	void (*free)(struct module___238 *);
};

struct acpi_device___6;

struct acpi_hotplug_profile___6 {
	struct kobject___282 kobj;
	int (*scan_dependent)(struct acpi_device___6 *);
	void (*notify_online)(struct acpi_device___6 *);
	bool enabled: 1;
	bool demand_offline: 1;
};

struct acpi_device_wakeup_context___6 {
	void (*func)(struct acpi_device_wakeup_context___6 *);
	struct device___260 *dev;
};

struct acpi_device_wakeup___6 {
	acpi_handle gpe_device;
	u64 gpe_number;
	u64 sleep_state;
	struct list_head resources;
	struct acpi_device_wakeup_flags flags;
	struct acpi_device_wakeup_context___6 context;
	struct wakeup_source *ws;
	int prepare_count;
	int enable_count;
};

struct acpi_scan_handler___6;

struct acpi_hotplug_context___6;

struct acpi_driver___6;

struct acpi_device___6 {
	int device_type;
	acpi_handle handle;
	struct fwnode_handle___194 fwnode;
	struct acpi_device___6 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup___6 wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_device_data data;
	struct acpi_scan_handler___6 *handler;
	struct acpi_hotplug_context___6 *hp;
	struct acpi_driver___6 *driver;
	const struct acpi_gpio_mapping *driver_gpios;
	void *driver_data;
	struct device___260 dev;
	unsigned int physical_node_count;
	unsigned int dep_unmet;
	struct list_head physical_node_list;
	struct mutex physical_node_lock;
	void (*remove)(struct acpi_device___6 *);
};

struct acpi_scan_handler___6 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	bool (*match)(const char *, const struct acpi_device_id **);
	int (*attach)(struct acpi_device___6 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___6 *);
	void (*bind)(struct device___260 *);
	void (*unbind)(struct device___260 *);
	struct acpi_hotplug_profile___6 hotplug;
};

struct acpi_hotplug_context___6 {
	struct acpi_device___6 *self;
	int (*notify)(struct acpi_device___6 *, u32);
	void (*uevent)(struct acpi_device___6 *, u32);
	void (*fixup)(struct acpi_device___6 *);
};

typedef int (*acpi_op_add___6)(struct acpi_device___6 *);

typedef int (*acpi_op_remove___6)(struct acpi_device___6 *);

typedef void (*acpi_op_notify___6)(struct acpi_device___6 *, u32);

struct acpi_device_ops___6 {
	acpi_op_add___6 add;
	acpi_op_remove___6 remove;
	acpi_op_notify___6 notify;
};

struct acpi_driver___6 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___6 ops;
	struct device_driver___260 drv;
	struct module___238 *owner;
};

struct acpi_bus_type {
	struct list_head list;
	const char *name;
	bool (*match)(struct device___260 *);
	struct acpi_device___6 * (*find_companion)(struct device___260 *);
	void (*setup)(struct device___260 *);
	void (*cleanup)(struct device___260 *);
};

struct acpi_pci_root___3 {
	struct acpi_device___6 *device;
	struct pci_bus___20 *bus;
	u16 segment;
	struct resource secondary;
	u32 osc_support_set;
	u32 osc_control_set;
	phys_addr_t mcfg_addr;
};

typedef int (*key_restrict_link_func_t___276)(struct key___275 *, const struct key_type *, const union key_payload *, struct key___275 *);

struct key_restriction___275;

struct key___275 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___296 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___275 *restrict_link;
};

struct key_restriction___275 {
	key_restrict_link_func_t___276 check;
	struct key___275 *key;
	struct key_type *keytype;
};

struct seq_operations___252 {
	void * (*start)(struct seq_file___253 *, loff_t *);
	void (*stop)(struct seq_file___253 *, void *);
	void * (*next)(struct seq_file___253 *, void *, loff_t *);
	int (*show)(struct seq_file___253 *, void *);
};

enum pm_qos_flags_status {
	PM_QOS_FLAGS_UNDEFINED = 4294967295,
	PM_QOS_FLAGS_NONE = 0,
	PM_QOS_FLAGS_SOME = 1,
	PM_QOS_FLAGS_ALL = 2,
};

struct dev_pm_qos_request___10 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___260 *dev;
};

struct pci_platform_pm_ops___2 {
	bool (*bridge_d3)(struct pci_dev___20 *);
	bool (*is_manageable)(struct pci_dev___20 *);
	int (*set_state)(struct pci_dev___20 *, pci_power_t);
	pci_power_t (*get_state)(struct pci_dev___20 *);
	pci_power_t (*choose_state)(struct pci_dev___20 *);
	int (*set_wakeup)(struct pci_dev___20 *, bool);
	bool (*need_resume)(struct pci_dev___20 *);
};

enum dmi_device_type {
	DMI_DEV_TYPE_ANY = 0,
	DMI_DEV_TYPE_OTHER = 1,
	DMI_DEV_TYPE_UNKNOWN = 2,
	DMI_DEV_TYPE_VIDEO = 3,
	DMI_DEV_TYPE_SCSI = 4,
	DMI_DEV_TYPE_ETHERNET = 5,
	DMI_DEV_TYPE_TOKENRING = 6,
	DMI_DEV_TYPE_SOUND = 7,
	DMI_DEV_TYPE_PATA = 8,
	DMI_DEV_TYPE_SATA = 9,
	DMI_DEV_TYPE_SAS = 10,
	DMI_DEV_TYPE_IPMI = 4294967295,
	DMI_DEV_TYPE_OEM_STRING = 4294967294,
	DMI_DEV_TYPE_DEV_ONBOARD = 4294967293,
	DMI_DEV_TYPE_DEV_SLOT = 4294967292,
};

struct dmi_device {
	struct list_head list;
	int type;
	const char *name;
	void *device_data;
};

struct dmi_dev_onboard {
	struct dmi_device dev;
	int instance;
	int segment;
	int bus;
	int devfn;
};

struct device_attribute___16 {
	struct attribute attr;
	ssize_t (*show)(struct device___260 *, struct device_attribute___16 *, char *);
	ssize_t (*store)(struct device___260 *, struct device_attribute___16 *, const char *, size_t);
};

enum smbios_attr_enum {
	SMBIOS_ATTR_NONE = 0,
	SMBIOS_ATTR_LABEL_SHOW = 1,
	SMBIOS_ATTR_INSTANCE_SHOW = 2,
};

enum acpi_attr_enum {
	ACPI_ATTR_LABEL_SHOW = 0,
	ACPI_ATTR_INDEX_SHOW = 1,
};

struct module___239;

struct file___296;

struct kiocb___296;

struct poll_table_struct___181;

struct vm_area_struct___297;

struct inode___296;

struct file_lock___296;

struct page___297;

struct seq_file___254;

struct file_operations___296 {
	struct module___239 *owner;
	loff_t (*llseek)(struct file___296 *, loff_t, int);
	ssize_t (*read)(struct file___296 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___296 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___296 *, struct iov_iter___137 *);
	ssize_t (*write_iter)(struct kiocb___296 *, struct iov_iter___137 *);
	int (*iopoll)(struct kiocb___296 *, bool);
	int (*iterate)(struct file___296 *, struct dir_context *);
	int (*iterate_shared)(struct file___296 *, struct dir_context *);
	__poll_t (*poll)(struct file___296 *, struct poll_table_struct___181 *);
	long int (*unlocked_ioctl)(struct file___296 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___296 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___296 *, struct vm_area_struct___297 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___296 *, struct file___296 *);
	int (*flush)(struct file___296 *, fl_owner_t);
	int (*release)(struct inode___296 *, struct file___296 *);
	int (*fsync)(struct file___296 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___296 *, int);
	int (*lock)(struct file___296 *, int, struct file_lock___296 *);
	ssize_t (*sendpage)(struct file___296 *, struct page___297 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___296 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___296 *, int, struct file_lock___296 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___296 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___296 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___296 *, long int, struct file_lock___296 **, void **);
	long int (*fallocate)(struct file___296 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___254 *, struct file___296 *);
	ssize_t (*copy_file_range)(struct file___296 *, loff_t, struct file___296 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___296 *, loff_t, struct file___296 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___296 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct perf_event___131;

struct debug_info___131 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___131 *hbp_break[16];
	struct perf_event___131 *hbp_watch[16];
};

struct task_struct___297;

struct hw_perf_event___131 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___297 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___131)(struct perf_event___131 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___131;

struct perf_event_context___131;

struct fasync_struct___295;

struct pid_namespace___196;

struct trace_event_call___124;

struct perf_cgroup___131;

struct perf_event___131 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___131 *group_leader;
	struct pmu___131 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___131 hw;
	struct perf_event_context___131 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___131 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___297 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___295 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___131 *);
	struct callback_head callback_head;
	struct pid_namespace___196 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___131 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___131 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___124 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___131 *cgrp;
	struct list_head sb_list;
};

struct thread_struct___131 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___131 debug;
	long: 64;
};

struct vmacache___296 {
	u64 seqnum;
	struct vm_area_struct___297 *vmas[4];
};

struct page_frag___296 {
	struct page___297 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___296;

struct pid___196;

struct cred___276;

struct nsproxy___243;

struct signal_struct___222;

struct css_set___207;

struct vm_struct___212;

struct task_struct___297 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___297 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___296 *mm;
	struct mm_struct___296 *active_mm;
	struct vmacache___296 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___297 *real_parent;
	struct task_struct___297 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___297 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___196 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___196 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___196 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___276 *ptracer_cred;
	const struct cred___276 *real_cred;
	const struct cred___276 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___243 *nsproxy;
	struct signal_struct___222 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___297 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___82 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___207 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___131 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___296 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___297 *oom_reaper_list;
	struct vm_struct___212 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___131 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___297 *pgtable_t___296;

struct address_space___295;

struct dev_pagemap___285;

struct page___297 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___295 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___297 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___296 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___296 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___285 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___296;

struct lruvec___296 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___296 *pgdat;
};

struct zone___296 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___296 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___296 {
	struct zone___296 *zone;
	int zone_idx;
};

struct zonelist___296 {
	struct zoneref___296 _zonerefs[25];
};

struct pglist_data___296 {
	struct zone___296 node_zones[3];
	struct zonelist___296 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___297 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___297 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___296 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___297 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___297 *owner;
};

struct secondary_data___297 {
	void *stack;
	struct task_struct___297 *task;
	long int status;
};

struct blocking_notifier_head___296 {
	struct rw_semaphore___297 rwsem;
	struct notifier_block *head;
};

struct key___276;

struct ucounts___222;

struct user_namespace___222 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___222 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___9 ns;
	long unsigned int flags;
	struct key___276 *persistent_keyring_register;
	struct rw_semaphore___297 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___222 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_root___289;

struct kernfs_elem_dir___289 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___289 *root;
};

struct kernfs_node___290;

struct kernfs_syscall_ops___289;

struct kernfs_root___289 {
	struct kernfs_node___290 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___289 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___289 {
	struct kernfs_node___290 *target_kn;
};

struct kernfs_ops___289;

struct kernfs_elem_attr___289 {
	const struct kernfs_ops___289 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___290 *notify_next;
};

struct kernfs_node___290 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___290 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___289 dir;
		struct kernfs_elem_symlink___289 symlink;
		struct kernfs_elem_attr___289 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___289;

struct kernfs_ops___289 {
	int (*open)(struct kernfs_open_file___289 *);
	void (*release)(struct kernfs_open_file___289 *);
	int (*seq_show)(struct seq_file___254 *, void *);
	void * (*seq_start)(struct seq_file___254 *, loff_t *);
	void * (*seq_next)(struct seq_file___254 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___254 *, void *);
	ssize_t (*read)(struct kernfs_open_file___289 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___289 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___289 *, struct vm_area_struct___297 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___289 *, struct poll_table_struct___181 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___289 {
	int (*remount_fs)(struct kernfs_root___289 *, int *, char *);
	int (*show_options)(struct seq_file___254 *, struct kernfs_root___289 *);
	int (*mkdir)(struct kernfs_node___290 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___290 *);
	int (*rename)(struct kernfs_node___290 *, struct kernfs_node___290 *, const char *);
	int (*show_path)(struct seq_file___254 *, struct kernfs_node___290 *, struct kernfs_root___289 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___253;

struct seq_file___254 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___253 *op;
	int poll_event;
	const struct file___296 *file;
	void *private;
};

struct vm_operations_struct___285;

struct kernfs_open_file___289 {
	struct kernfs_node___290 *kn;
	struct file___296 *file;
	struct seq_file___254 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___285 *vm_ops;
};

struct dentry___296;

struct path___296 {
	struct vfsmount *mnt;
	struct dentry___296 *dentry;
};

struct fown_struct___196 {
	rwlock_t lock;
	struct pid___196 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___296 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___296 f_path;
	struct inode___296 *f_inode;
	const struct file_operations___296 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___196 f_owner;
	const struct cred___276 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___295 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___285;

struct vm_operations_struct___285 {
	void (*open)(struct vm_area_struct___297 *);
	void (*close)(struct vm_area_struct___297 *);
	int (*split)(struct vm_area_struct___297 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___297 *);
	vm_fault_t (*fault)(struct vm_fault___285 *);
	vm_fault_t (*huge_fault)(struct vm_fault___285 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___285 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___297 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___285 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___285 *);
	int (*access)(struct vm_area_struct___297 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___297 *);
	int (*set_policy)(struct vm_area_struct___297 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___297 *, long unsigned int);
	struct page___297 * (*find_special_page)(struct vm_area_struct___297 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___184)(struct file___296 *, wait_queue_head_t *, struct poll_table_struct___181 *);

struct poll_table_struct___181 {
	poll_queue_proc___184 _qproc;
	__poll_t _key;
};

struct vm_area_struct___297 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___297 *vm_next;
	struct vm_area_struct___297 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___296 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___285 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___296 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___283;

struct bin_attribute___259;

struct attribute_group___260 {
	const char *name;
	umode_t (*is_visible)(struct kobject___283 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___283 *, struct bin_attribute___259 *, int);
	struct attribute **attrs;
	struct bin_attribute___259 **bin_attrs;
};

struct kset___282;

struct kobj_type___282;

struct kobject___283 {
	const char *name;
	struct list_head entry;
	struct kobject___283 *parent;
	struct kset___282 *kset;
	struct kobj_type___282 *ktype;
	struct kernfs_node___290 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___259 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___296 *, struct kobject___283 *, struct bin_attribute___259 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___296 *, struct kobject___283 *, struct bin_attribute___259 *, char *, loff_t, size_t);
	int (*mmap)(struct file___296 *, struct kobject___283 *, struct bin_attribute___259 *, struct vm_area_struct___297 *);
};

struct sysfs_ops___282 {
	ssize_t (*show)(struct kobject___283 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___283 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___282;

struct kset___282 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___283 kobj;
	const struct kset_uevent_ops___282 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___282 {
	void (*release)(struct kobject___283 *);
	const struct sysfs_ops___282 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___25 * (*child_ns_type)(struct kobject___283 *);
	const void * (*namespace)(struct kobject___283 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___282 {
	int (* const filter)(struct kset___282 *, struct kobject___283 *);
	const char * (* const name)(struct kset___282 *, struct kobject___283 *);
	int (* const uevent)(struct kset___282 *, struct kobject___283 *, struct kobj_uevent_env *);
};

struct kobj_attribute___275 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___283 *, struct kobj_attribute___275 *, char *);
	ssize_t (*store)(struct kobject___283 *, struct kobj_attribute___275 *, const char *, size_t);
};

struct device___261;

struct dev_pm_ops___261 {
	int (*prepare)(struct device___261 *);
	void (*complete)(struct device___261 *);
	int (*suspend)(struct device___261 *);
	int (*resume)(struct device___261 *);
	int (*freeze)(struct device___261 *);
	int (*thaw)(struct device___261 *);
	int (*poweroff)(struct device___261 *);
	int (*restore)(struct device___261 *);
	int (*suspend_late)(struct device___261 *);
	int (*resume_early)(struct device___261 *);
	int (*freeze_late)(struct device___261 *);
	int (*thaw_early)(struct device___261 *);
	int (*poweroff_late)(struct device___261 *);
	int (*restore_early)(struct device___261 *);
	int (*suspend_noirq)(struct device___261 *);
	int (*resume_noirq)(struct device___261 *);
	int (*freeze_noirq)(struct device___261 *);
	int (*thaw_noirq)(struct device___261 *);
	int (*poweroff_noirq)(struct device___261 *);
	int (*restore_noirq)(struct device___261 *);
	int (*runtime_suspend)(struct device___261 *);
	int (*runtime_resume)(struct device___261 *);
	int (*runtime_idle)(struct device___261 *);
};

struct dev_pm_info___261 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___261 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___261;

struct bus_type___261;

struct device_driver___261;

struct dev_pm_domain___261;

struct dma_map_ops___83;

struct fwnode_handle___195;

struct class___261;

struct device___261 {
	struct device___261 *parent;
	struct device_private *p;
	struct kobject___283 kobj;
	const char *init_name;
	const struct device_type___261 *type;
	struct mutex mutex;
	struct bus_type___261 *bus;
	struct device_driver___261 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___261 power;
	struct dev_pm_domain___261 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___83 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___195 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___261 *class;
	const struct attribute_group___260 **groups;
	void (*release)(struct device___261 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___261 {
	struct dev_pm_ops___261 ops;
	void (*detach)(struct device___261 *, bool);
	int (*activate)(struct device___261 *);
	void (*sync)(struct device___261 *);
	void (*dismiss)(struct device___261 *);
};

struct upid___196 {
	int nr;
	struct pid_namespace___196 *ns;
};

struct pid_namespace___196 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___297 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___196 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___296 *proc_self;
	struct dentry___296 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___222 *user_ns;
	struct ucounts___222 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___9 ns;
};

struct pid___196 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___196 numbers[1];
};

struct user_struct___276 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___276 *uid_keyring;
	struct key___276 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___296;

struct mm_struct___296 {
	struct {
		struct vm_area_struct___297 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___296 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___297 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___296 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___297 *owner;
		struct user_namespace___222 *user_ns;
		struct file___296 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___296 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___276 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___276 *session_keyring;
	struct key___276 *process_keyring;
	struct key___276 *thread_keyring;
	struct key___276 *request_key_auth;
	void *security;
	struct user_struct___276 *user;
	struct user_namespace___222 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___207;

struct nsproxy___243 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___196 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___207 *cgroup_ns;
};

struct signal_struct___222 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___297 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___297 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___196 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___196 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___296 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___196 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide21;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___207;

struct cgroup___207;

struct css_set___207 {
	struct cgroup_subsys_state___207 *subsys[13];
	refcount_t refcount;
	struct css_set___207 *dom_cset;
	struct cgroup___207 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___207 *mg_src_cgrp;
	struct cgroup___207 *mg_dst_cgrp;
	struct css_set___207 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___131 {
	struct pmu___131 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___297 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___131 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___212 {
	struct vm_struct___212 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___297 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___234 {
	struct task_struct___297 task;
	long unsigned int stack[8192];
};

struct bus_type___261 {
	const char *name;
	const char *dev_name;
	struct device___261 *dev_root;
	const struct attribute_group___260 **bus_groups;
	const struct attribute_group___260 **dev_groups;
	const struct attribute_group___260 **drv_groups;
	int (*match)(struct device___261 *, struct device_driver___261 *);
	int (*uevent)(struct device___261 *, struct kobj_uevent_env *);
	int (*probe)(struct device___261 *);
	int (*remove)(struct device___261 *);
	void (*shutdown)(struct device___261 *);
	int (*online)(struct device___261 *);
	int (*offline)(struct device___261 *);
	int (*suspend)(struct device___261 *, pm_message_t);
	int (*resume)(struct device___261 *);
	int (*num_vf)(struct device___261 *);
	int (*dma_configure)(struct device___261 *);
	const struct dev_pm_ops___261 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___261 {
	const char *name;
	struct bus_type___261 *bus;
	struct module___239 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___261 *);
	int (*remove)(struct device___261 *);
	void (*shutdown)(struct device___261 *);
	int (*suspend)(struct device___261 *, pm_message_t);
	int (*resume)(struct device___261 *);
	const struct attribute_group___260 **groups;
	const struct dev_pm_ops___261 *pm;
	void (*coredump)(struct device___261 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___261 {
	const char *name;
	const struct attribute_group___260 **groups;
	int (*uevent)(struct device___261 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___261 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___261 *);
	const struct dev_pm_ops___261 *pm;
};

struct module_kobject___236 {
	struct kobject___283 kobj;
	struct module___239 *mod;
	struct kobject___283 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___236 {
	struct module___239 *mod;
	struct latch_tree_node node;
};

struct module_layout___236 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___236 mtn;
};

struct module_attribute___236;

struct kernel_param___236;

struct module___239 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___236 mkobj;
	struct module_attribute___236 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___283 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___236 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___236 core_layout;
	struct module_layout___236 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___124 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct class___261 {
	const char *name;
	struct module___239 *owner;
	const struct attribute_group___260 **class_groups;
	const struct attribute_group___260 **dev_groups;
	struct kobject___283 *dev_kobj;
	int (*dev_uevent)(struct device___261 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___261 *, umode_t *);
	void (*class_release)(struct class___261 *);
	void (*dev_release)(struct device___261 *);
	int (*shutdown_pre)(struct device___261 *);
	const struct kobj_ns_type_operations___25 *ns_type;
	const void * (*namespace)(struct device___261 *);
	const struct dev_pm_ops___261 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___83 {
	void * (*alloc)(struct device___261 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___261 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___261 *, struct vm_area_struct___297 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___261 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___261 *, struct page___297 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___261 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___261 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___261 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___261 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___261 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___261 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___261 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___261 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___261 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___261 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___261 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___261 *, u64);
	u64 (*get_required_mask)(struct device___261 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___195;

struct fwnode_handle___195 {
	struct fwnode_handle___195 *secondary;
	const struct fwnode_operations___195 *ops;
};

struct address_space_operations___295;

struct address_space___295 {
	struct inode___296 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___297 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___295 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___285)(struct vm_area_struct___297 *, long unsigned int, const struct page___297 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___285)(struct page___297 *, void *);

struct dev_pagemap___285 {
	dev_page_fault_t___285 page_fault;
	dev_page_free_t___285 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___261 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___296 {
	struct task_struct___297 *task;
	struct core_thread___296 *next;
};

struct core_state___296 {
	atomic_t nr_threads;
	struct core_thread___296 dumper;
	struct completion startup;
};

struct vm_fault___285 {
	struct vm_area_struct___297 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___297 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___297 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___296 prealloc_pte;
};

struct fwnode_reference_args___195;

struct fwnode_endpoint___195;

struct fwnode_operations___195 {
	struct fwnode_handle___195 * (*get)(struct fwnode_handle___195 *);
	void (*put)(struct fwnode_handle___195 *);
	bool (*device_is_available)(const struct fwnode_handle___195 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___195 *, const struct device___261 *);
	bool (*property_present)(const struct fwnode_handle___195 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___195 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___195 *, const char *, const char **, size_t);
	struct fwnode_handle___195 * (*get_parent)(const struct fwnode_handle___195 *);
	struct fwnode_handle___195 * (*get_next_child_node)(const struct fwnode_handle___195 *, struct fwnode_handle___195 *);
	struct fwnode_handle___195 * (*get_named_child_node)(const struct fwnode_handle___195 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___195 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___195 *);
	struct fwnode_handle___195 * (*graph_get_next_endpoint)(const struct fwnode_handle___195 *, struct fwnode_handle___195 *);
	struct fwnode_handle___195 * (*graph_get_remote_endpoint)(const struct fwnode_handle___195 *);
	struct fwnode_handle___195 * (*graph_get_port_parent)(struct fwnode_handle___195 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___195 *, struct fwnode_endpoint___195 *);
};

struct fwnode_endpoint___195 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___195 *local_fwnode;
};

struct fwnode_reference_args___195 {
	struct fwnode_handle___195 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pci_bus___21;

struct pci_slot___21 {
	struct pci_bus___21 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject___283 kobj;
};

struct pci_dev___21;

struct pci_ops___21;

struct pci_bus___21 {
	struct list_head node;
	struct pci_bus___21 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___21 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___21 *ops;
	struct msi_controller___2 *msi;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	int domain_nr;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___261 *bridge;
	struct device___261 dev;
	struct bin_attribute___259 *legacy_io;
	struct bin_attribute___259 *legacy_mem;
	unsigned int is_added: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
};

struct pci_sriov___16 {
	int pos;
	int nres;
	u32 cap;
	u16 ctrl;
	u16 total_VFs;
	u16 initial_VFs;
	u16 num_VFs;
	u16 offset;
	u16 stride;
	u16 vf_device;
	u32 pgsz;
	u8 link;
	u8 max_VF_buses;
	u16 driver_max_VFs;
	struct pci_dev___21 *dev;
	struct pci_dev___21 *self;
	u32 class;
	u8 hdr_type;
	u16 subsystem_vendor;
	u16 subsystem_device;
	resource_size_t barsz[6];
	bool drivers_autoprobe;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct pci_driver___21;

struct pci_dev___21 {
	struct list_head bus_list;
	struct pci_bus___21 *bus;
	struct pci_bus___21 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___21 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u16 aer_cap;
	struct aer_stats *aer_stats;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	long unsigned int *dma_alias_mask;
	struct pci_driver___21 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	unsigned int imm_ready: 1;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int bridge_d3: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int hotplug_user_indicators: 1;
	unsigned int clear_retrain_link: 1;
	unsigned int d3_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	unsigned int ltr_path: 1;
	unsigned int eetlp_prefix_path: 1;
	pci_channel_state_t error_state;
	struct device___261 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int multifunction: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int ats_enabled: 1;
	unsigned int pasid_enabled: 1;
	unsigned int pri_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int reset_fn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int shpc_managed: 1;
	unsigned int is_thunderbolt: 1;
	unsigned int __aer_firmware_first_valid: 1;
	unsigned int __aer_firmware_first: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int irq_managed: 1;
	unsigned int has_secondary_link: 1;
	unsigned int non_compliant_bars: 1;
	unsigned int is_probed: 1;
	unsigned int link_active_reporting: 1;
	unsigned int untrusted: 1;
	unsigned int no_vf_scan: 1;
	unsigned int io_window: 1;
	unsigned int pref_window: 1;
	unsigned int pref_64_window: 1;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	struct bin_attribute___259 *rom_attr;
	int rom_attr_enabled;
	struct bin_attribute___259 *res_attr[17];
	struct bin_attribute___259 *res_attr_wc[17];
	unsigned int broken_cmd_compl: 1;
	const struct attribute_group___260 **msi_irq_groups;
	struct pci_vpd *vpd;
	union {
		struct pci_sriov___16 *sriov;
		struct pci_dev___21 *physfn;
	};
	u16 ats_cap;
	u8 ats_stu;
	atomic_t ats_ref_cnt;
	u32 pri_reqs_alloc;
	u16 pasid_features;
	struct pci_p2pdma *p2pdma;
	phys_addr_t rom;
	size_t romlen;
	char *driver_override;
	long unsigned int priv_flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t pci_dev_extended_size_rh;
	struct pci_dev_extended_rh pci_dev_extended_rh;
};

struct pci_error_handlers___21;

struct pci_driver___21 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___21 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___21 *);
	int (*suspend)(struct pci_dev___21 *, pm_message_t);
	int (*suspend_late)(struct pci_dev___21 *, pm_message_t);
	int (*resume_early)(struct pci_dev___21 *);
	int (*resume)(struct pci_dev___21 *);
	void (*shutdown)(struct pci_dev___21 *);
	int (*sriov_configure)(struct pci_dev___21 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	const struct pci_error_handlers___21 *err_handler;
	const struct attribute_group___260 **groups;
	struct device_driver___261 driver;
	struct pci_dynids dynids;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct pci_ops___21 {
	int (*add_bus)(struct pci_bus___21 *);
	void (*remove_bus)(struct pci_bus___21 *);
	void * (*map_bus)(struct pci_bus___21 *, unsigned int, int);
	int (*read)(struct pci_bus___21 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___21 *, unsigned int, int, int, u32);
};

struct pci_error_handlers___21 {
	pci_ers_result_t (*error_detected)(struct pci_dev___21 *, enum pci_channel_state);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___21 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___21 *);
	void (*reset_prepare)(struct pci_dev___21 *);
	void (*reset_done)(struct pci_dev___21 *);
	void (*resume)(struct pci_dev___21 *);
};

struct dentry_operations___295;

struct super_block___295;

struct dentry___296 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___296 *d_parent;
	struct qstr d_name;
	struct inode___296 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___295 *d_op;
	struct super_block___295 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___295;

struct block_device___295;

struct inode___296 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___295 *i_op;
	struct super_block___295 *i_sb;
	struct address_space___295 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___297 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___296 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___295 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___295 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___295 {
	int (*d_revalidate)(struct dentry___296 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___296 *, unsigned int);
	int (*d_hash)(const struct dentry___296 *, struct qstr *);
	int (*d_compare)(const struct dentry___296 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___296 *);
	int (*d_init)(struct dentry___296 *);
	void (*d_release)(struct dentry___296 *);
	void (*d_prune)(struct dentry___296 *);
	void (*d_iput)(struct dentry___296 *, struct inode___296 *);
	char * (*d_dname)(struct dentry___296 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___296 *);
	int (*d_manage)(const struct path___296 *, bool);
	struct dentry___296 * (*d_real)(struct dentry___296 *, const struct inode___296 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___295;

struct mem_dqinfo___295 {
	struct quota_format_type___295 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___295;

struct quota_info___295 {
	unsigned int flags;
	struct rw_semaphore___297 dqio_sem;
	struct inode___296 *files[3];
	struct mem_dqinfo___295 info[3];
	const struct quota_format_ops___295 *ops[3];
};

struct rcuwait___295 {
	struct task_struct___297 *task;
};

struct percpu_rw_semaphore___295 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___297 rw_sem;
	struct rcuwait___295 writer;
	int readers_block;
};

struct sb_writers___295 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___295 rw_sem[3];
};

struct file_system_type___295;

struct super_operations___295;

struct dquot_operations___295;

struct quotactl_ops___295;

struct super_block___295 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___295 *s_type;
	const struct super_operations___295 *s_op;
	const struct dquot_operations___295 *dq_op;
	const struct quotactl_ops___295 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___296 *s_root;
	struct rw_semaphore___297 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___295 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___295 s_dquot;
	struct sb_writers___295 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___295 *s_d_op;
	int cleancache_poolid;
	struct shrinker___116 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___222 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___296 {
	struct file___296 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___296 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___295 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___296 *ia_file;
};

struct dquot___295 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___295 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___295 {
	int qf_fmt_id;
	const struct quota_format_ops___295 *qf_ops;
	struct module___239 *qf_owner;
	struct quota_format_type___295 *qf_next;
};

struct quota_format_ops___295 {
	int (*check_quota_file)(struct super_block___295 *, int);
	int (*read_file_info)(struct super_block___295 *, int);
	int (*write_file_info)(struct super_block___295 *, int);
	int (*free_file_info)(struct super_block___295 *, int);
	int (*read_dqblk)(struct dquot___295 *);
	int (*commit_dqblk)(struct dquot___295 *);
	int (*release_dqblk)(struct dquot___295 *);
	int (*get_next_id)(struct super_block___295 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___295 {
	int (*write_dquot)(struct dquot___295 *);
	struct dquot___295 * (*alloc_dquot)(struct super_block___295 *, int);
	void (*destroy_dquot)(struct dquot___295 *);
	int (*acquire_dquot)(struct dquot___295 *);
	int (*release_dquot)(struct dquot___295 *);
	int (*mark_dirty)(struct dquot___295 *);
	int (*write_info)(struct super_block___295 *, int);
	qsize_t * (*get_reserved_space)(struct inode___296 *);
	int (*get_projid)(struct inode___296 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___296 *, qsize_t *);
	int (*get_next_id)(struct super_block___295 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___295 {
	int (*quota_on)(struct super_block___295 *, int, int, const struct path___296 *);
	int (*quota_off)(struct super_block___295 *, int);
	int (*quota_enable)(struct super_block___295 *, unsigned int);
	int (*quota_disable)(struct super_block___295 *, unsigned int);
	int (*quota_sync)(struct super_block___295 *, int);
	int (*set_info)(struct super_block___295 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___295 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___295 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___295 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___295 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___295 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___295 {
	int (*writepage)(struct page___297 *, struct writeback_control___3 *);
	int (*readpage)(struct file___296 *, struct page___297 *);
	int (*writepages)(struct address_space___295 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___297 *);
	int (*readpages)(struct file___296 *, struct address_space___295 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___296 *, struct address_space___295 *, loff_t, unsigned int, unsigned int, struct page___297 **, void **);
	int (*write_end)(struct file___296 *, struct address_space___295 *, loff_t, unsigned int, unsigned int, struct page___297 *, void *);
	sector_t (*bmap)(struct address_space___295 *, sector_t);
	void (*invalidatepage)(struct page___297 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___297 *, gfp_t);
	void (*freepage)(struct page___297 *);
	ssize_t (*direct_IO)(struct kiocb___296 *, struct iov_iter___137 *);
	int (*migratepage)(struct address_space___295 *, struct page___297 *, struct page___297 *, enum migrate_mode);
	bool (*isolate_page)(struct page___297 *, isolate_mode_t);
	void (*putback_page)(struct page___297 *);
	int (*launder_page)(struct page___297 *);
	int (*is_partially_uptodate)(struct page___297 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___297 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___295 *, struct page___297 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___296 *, sector_t *);
	void (*swap_deactivate)(struct file___296 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___295 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___296 *bd_inode;
	struct super_block___295 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___295 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___295 {
	struct dentry___296 * (*lookup)(struct inode___296 *, struct dentry___296 *, unsigned int);
	const char * (*get_link)(struct dentry___296 *, struct inode___296 *, struct delayed_call *);
	int (*permission)(struct inode___296 *, int);
	struct posix_acl * (*get_acl)(struct inode___296 *, int);
	int (*readlink)(struct dentry___296 *, char *, int);
	int (*create)(struct inode___296 *, struct dentry___296 *, umode_t, bool);
	int (*link)(struct dentry___296 *, struct inode___296 *, struct dentry___296 *);
	int (*unlink)(struct inode___296 *, struct dentry___296 *);
	int (*symlink)(struct inode___296 *, struct dentry___296 *, const char *);
	int (*mkdir)(struct inode___296 *, struct dentry___296 *, umode_t);
	int (*rmdir)(struct inode___296 *, struct dentry___296 *);
	int (*mknod)(struct inode___296 *, struct dentry___296 *, umode_t, dev_t);
	int (*rename)(struct inode___296 *, struct dentry___296 *, struct inode___296 *, struct dentry___296 *, unsigned int);
	int (*setattr)(struct dentry___296 *, struct iattr___295 *);
	int (*getattr)(const struct path___296 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___296 *, char *, size_t);
	int (*fiemap)(struct inode___296 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___296 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___296 *, struct dentry___296 *, struct file___296 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___296 *, struct dentry___296 *, umode_t);
	int (*set_acl)(struct inode___296 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___295 {
	void (*fl_copy_lock)(struct file_lock___296 *, struct file_lock___296 *);
	void (*fl_release_private)(struct file_lock___296 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___295;

struct file_lock___296 {
	struct file_lock___296 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___296 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___295 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___295 *fl_ops;
	const struct lock_manager_operations___295 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___295 {
	int (*lm_compare_owner)(struct file_lock___296 *, struct file_lock___296 *);
	long unsigned int (*lm_owner_key)(struct file_lock___296 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___296 *);
	int (*lm_grant)(struct file_lock___296 *, int);
	bool (*lm_break)(struct file_lock___296 *);
	int (*lm_change)(struct file_lock___296 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___296 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___295 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___295 *fa_next;
	struct file___296 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___295 {
	const char *name;
	int fs_flags;
	struct dentry___296 * (*mount)(struct file_system_type___295 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___295 *);
	struct module___239 *owner;
	struct file_system_type___295 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___295 {
	struct inode___296 * (*alloc_inode)(struct super_block___295 *);
	void (*destroy_inode)(struct inode___296 *);
	void (*dirty_inode)(struct inode___296 *, int);
	int (*write_inode)(struct inode___296 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___296 *);
	void (*evict_inode)(struct inode___296 *);
	void (*put_super)(struct super_block___295 *);
	int (*sync_fs)(struct super_block___295 *, int);
	int (*freeze_super)(struct super_block___295 *);
	int (*freeze_fs)(struct super_block___295 *);
	int (*thaw_super)(struct super_block___295 *);
	int (*unfreeze_fs)(struct super_block___295 *);
	int (*statfs)(struct dentry___296 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___295 *, int *, char *);
	void (*umount_begin)(struct super_block___295 *);
	int (*show_options)(struct seq_file___254 *, struct dentry___296 *);
	int (*show_devname)(struct seq_file___254 *, struct dentry___296 *);
	int (*show_path)(struct seq_file___254 *, struct dentry___296 *);
	int (*show_stats)(struct seq_file___254 *, struct dentry___296 *);
	ssize_t (*quota_read)(struct super_block___295 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___295 *, int, const char *, size_t, loff_t);
	struct dquot___295 ** (*get_dquots)(struct inode___296 *);
	int (*bdev_try_to_free_page)(struct super_block___295 *, struct page___297 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___295 *, struct shrink_control___116 *);
	long int (*free_cached_objects)(struct super_block___295 *, struct shrink_control___116 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___285(struct page___297 *);

typedef int (*key_restrict_link_func_t___277)(struct key___276 *, const struct key_type *, const union key_payload *, struct key___276 *);

struct key_restriction___276;

struct key___276 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___297 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___276 *restrict_link;
};

struct key_restriction___276 {
	key_restrict_link_func_t___277 check;
	struct key___276 *key;
	struct key_type *keytype;
};

struct seq_operations___253 {
	void * (*start)(struct seq_file___254 *, loff_t *);
	void (*stop)(struct seq_file___254 *, void *);
	void * (*next)(struct seq_file___254 *, void *, loff_t *);
	int (*show)(struct seq_file___254 *, void *);
};

struct cgroup_namespace___207 {
	refcount_t count;
	struct ns_common___9 ns;
	struct user_namespace___222 *user_ns;
	struct ucounts___222 *ucounts;
	struct css_set___207 *root_cset;
};

struct ucounts___222 {
	struct hlist_node node;
	struct user_namespace___222 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct kernel_param_ops___236 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___236 *);
	int (*get)(char *, const struct kernel_param___236 *);
	void (*free)(void *);
};

struct kparam_array___236;

struct kernel_param___236 {
	const char *name;
	struct module___239 *mod;
	const struct kernel_param_ops___236 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___236 *arr;
	};
};

struct kparam_array___236 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___236 *ops;
	void *elem;
};

struct module_attribute___236 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___236 *, struct module_kobject___236 *, char *);
	ssize_t (*store)(struct module_attribute___236 *, struct module_kobject___236 *, const char *, size_t);
	void (*setup)(struct module___239 *, const char *);
	int (*test)(struct module___239 *);
	void (*free)(struct module___239 *);
};

struct trace_event_class___124;

struct trace_event_call___124 {
	struct list_head list;
	struct trace_event_class___124 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___13 event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___35 *prog_array;
	int (*perf_perm)(struct trace_event_call___124 *, struct perf_event___131 *);
};

struct node___179 {
	struct device___261 dev;
};

struct bpf_map___208;

struct bpf_map_ops___207 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___208 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___208 *, struct file___296 *);
	void (*map_free)(struct bpf_map___208 *);
	int (*map_get_next_key)(struct bpf_map___208 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___208 *);
	void * (*map_lookup_elem)(struct bpf_map___208 *, void *);
	int (*map_update_elem)(struct bpf_map___208 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___208 *, void *);
	int (*map_push_elem)(struct bpf_map___208 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___208 *, void *);
	int (*map_peek_elem)(struct bpf_map___208 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___208 *, struct file___296 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___208 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___208 *, void *, struct seq_file___254 *);
	int (*map_check_btf)(const struct bpf_map___208 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___208 {
	const struct bpf_map_ops___207 *ops;
	struct bpf_map___208 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___276 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___207;

typedef void (*kthread_work_func_t___207)(struct kthread_work___207 *);

struct kthread_worker___207;

struct kthread_work___207 {
	struct list_head node;
	kthread_work_func_t___207 func;
	struct kthread_worker___207 *worker;
	int canceling;
};

struct kthread_worker___207 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___297 *task;
	struct kthread_work___207 *current_work;
};

struct kthread_delayed_work___207 {
	struct kthread_work___207 work;
	struct timer_list timer;
};

struct psi_group___207 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___207 *poll_kworker;
	struct kthread_delayed_work___207 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___207 {
	struct kernfs_node___290 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___207;

struct cgroup_subsys_state___207 {
	struct cgroup___207 *cgroup;
	struct cgroup_subsys___207 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___207 *parent;
};

struct cgroup_root___207;

struct cgroup_rstat_cpu___207;

struct cgroup___207 {
	struct cgroup_subsys_state___207 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___290 *kn;
	struct cgroup_file___207 procs_file;
	struct cgroup_file___207 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___207 *subsys[13];
	struct cgroup_root___207 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___207 *dom_cgrp;
	struct cgroup_rstat_cpu___207 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___35 bpf;
	atomic_t congestion_count;
	struct cgroup___207 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___207 psi;
	int ancestor_ids[0];
};

struct cftype___207;

struct cgroup_subsys___207 {
	struct cgroup_subsys_state___207 * (*css_alloc)(struct cgroup_subsys_state___207 *);
	int (*css_online)(struct cgroup_subsys_state___207 *);
	void (*css_offline)(struct cgroup_subsys_state___207 *);
	void (*css_released)(struct cgroup_subsys_state___207 *);
	void (*css_free)(struct cgroup_subsys_state___207 *);
	void (*css_reset)(struct cgroup_subsys_state___207 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___207 *, int);
	int (*css_extra_stat_show)(struct seq_file___254 *, struct cgroup_subsys_state___207 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___297 *);
	void (*cancel_fork)(struct task_struct___297 *);
	void (*fork)(struct task_struct___297 *);
	void (*exit)(struct task_struct___297 *);
	void (*free)(struct task_struct___297 *);
	void (*bind)(struct cgroup_subsys_state___207 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___207 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___207 *dfl_cftypes;
	struct cftype___207 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___207 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___207 *updated_children;
	struct cgroup___207 *updated_next;
};

struct cgroup_root___207 {
	struct kernfs_root___289 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___207 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___207 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___207 *ss;
	struct list_head node;
	struct kernfs_ops___289 *kf_ops;
	int (*open)(struct kernfs_open_file___289 *);
	void (*release)(struct kernfs_open_file___289 *);
	u64 (*read_u64)(struct cgroup_subsys_state___207 *, struct cftype___207 *);
	s64 (*read_s64)(struct cgroup_subsys_state___207 *, struct cftype___207 *);
	int (*seq_show)(struct seq_file___254 *, void *);
	void * (*seq_start)(struct seq_file___254 *, loff_t *);
	void * (*seq_next)(struct seq_file___254 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___254 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___207 *, struct cftype___207 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___207 *, struct cftype___207 *, s64);
	ssize_t (*write)(struct kernfs_open_file___289 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___289 *, struct poll_table_struct___181 *);
};

struct perf_cpu_context___131;

struct pmu___131 {
	struct list_head entry;
	struct module___239 *module;
	struct device___261 *dev;
	const struct attribute_group___260 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___131 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___131 *);
	void (*pmu_disable)(struct pmu___131 *);
	int (*event_init)(struct perf_event___131 *);
	void (*event_mapped)(struct perf_event___131 *, struct mm_struct___296 *);
	void (*event_unmapped)(struct perf_event___131 *, struct mm_struct___296 *);
	int (*add)(struct perf_event___131 *, int);
	void (*del)(struct perf_event___131 *, int);
	void (*start)(struct perf_event___131 *, int);
	void (*stop)(struct perf_event___131 *, int);
	void (*read)(struct perf_event___131 *);
	void (*start_txn)(struct pmu___131 *, unsigned int);
	int (*commit_txn)(struct pmu___131 *);
	void (*cancel_txn)(struct pmu___131 *);
	int (*event_idx)(struct perf_event___131 *);
	void (*sched_task)(struct perf_event_context___131 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___131 *);
	int (*filter_match)(struct perf_event___131 *);
	int (*check_period)(struct perf_event___131 *, u64);
};

struct perf_cpu_context___131 {
	struct perf_event_context___131 ctx;
	struct perf_event_context___131 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___131 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___131 {
	struct cgroup_subsys_state___207 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___124 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___124 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___124 *);
	struct list_head * (*get_fields)(struct trace_event_call___124 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___124 *);
};

struct syscall_metadata___64 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___124 *enter_event;
	struct trace_event_call___124 *exit_event;
};

struct platform_device___7 {
	const char *name;
	int id;
	bool id_auto;
	struct device___260 dev;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct pci_config_window___2;

struct pci_ecam_ops___2 {
	unsigned int bus_shift;
	struct pci_ops___20 pci_ops;
	int (*init)(struct pci_config_window___2 *);
};

struct pci_config_window___2 {
	struct resource res;
	struct resource busr;
	void *priv;
	struct pci_ecam_ops___2 *ops;
	union {
		void *win;
		void **winp;
	};
	struct device___260 *parent;
};

struct platform_driver___7 {
	int (*probe)(struct platform_device___7 *);
	int (*remove)(struct platform_device___7 *);
	void (*shutdown)(struct platform_device___7 *);
	int (*suspend)(struct platform_device___7 *, pm_message_t);
	int (*resume)(struct platform_device___7 *);
	struct device_driver___260 driver;
	const struct platform_device_id *id_table;
	bool prevent_deferred_probe;
};

struct node___180 {
	struct device___243 dev;
};

struct platform_device___8 {
	const char *name;
	int id;
	bool id_auto;
	struct device___243 dev;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct platform_driver___8 {
	int (*probe)(struct platform_device___8 *);
	int (*remove)(struct platform_device___8 *);
	void (*shutdown)(struct platform_device___8 *);
	int (*suspend)(struct platform_device___8 *, pm_message_t);
	int (*resume)(struct platform_device___8 *);
	struct device_driver___243 driver;
	const struct platform_device_id *id_table;
	bool prevent_deferred_probe;
};

struct xgene_msi;

struct xgene_msi_group {
	struct xgene_msi *msi;
	int gic_irq;
	u32 msi_grp;
};

struct xgene_msi {
	struct device_node___44 *node;
	struct irq_domain___6 *inner_domain;
	struct irq_domain___6 *msi_domain;
	u64 msi_addr;
	void *msi_regs;
	long unsigned int *bitmap;
	struct mutex bitmap_lock;
	struct xgene_msi_group *msi_groups;
	int num_cpus;
};

struct pci_host_bridge___5 {
	struct device___243 dev;
	struct pci_bus___8 *bus;
	struct pci_ops___8 *ops;
	void *sysdata;
	int busnr;
	struct list_head windows;
	u8 (*swizzle_irq)(struct pci_dev___8 *, u8 *);
	int (*map_irq)(const struct pci_dev___8 *, u8, u8);
	void (*release_fn)(struct pci_host_bridge___5 *);
	void *release_data;
	struct msi_controller___4 *msi;
	unsigned int ignore_reset_delay: 1;
	unsigned int no_ext_tags: 1;
	unsigned int native_aer: 1;
	unsigned int native_pcie_hotplug: 1;
	unsigned int native_shpc_hotplug: 1;
	unsigned int native_pme: 1;
	unsigned int native_ltr: 1;
	resource_size_t (*align_resource)(struct pci_dev___8 *, const struct resource *, resource_size_t, resource_size_t, resource_size_t);
	long: 64;
	long unsigned int private[0];
};

struct pci_fixup___4 {
	u16 vendor;
	u16 device;
	u32 class;
	unsigned int class_shift;
	void (*hook)(struct pci_dev___8 *);
};

struct pci_config_window___3;

struct pci_ecam_ops___3 {
	unsigned int bus_shift;
	struct pci_ops___8 pci_ops;
	int (*init)(struct pci_config_window___3 *);
};

struct pci_config_window___3 {
	struct resource res;
	struct resource busr;
	void *priv;
	struct pci_ecam_ops___3 *ops;
	union {
		void *win;
		void **winp;
	};
	struct device___243 *parent;
};

struct of_pci_range_parser___2 {
	struct device_node___44 *node;
	const __be32 *range;
	const __be32 *end;
	int np;
	int pna;
};

struct phy___3;

struct phy_ops___3 {
	int (*init)(struct phy___3 *);
	int (*exit)(struct phy___3 *);
	int (*power_on)(struct phy___3 *);
	int (*power_off)(struct phy___3 *);
	int (*set_mode)(struct phy___3 *, enum phy_mode);
	int (*reset)(struct phy___3 *);
	int (*calibrate)(struct phy___3 *);
	struct module___227 *owner;
};

struct phy___3 {
	struct device___243 dev;
	int id;
	const struct phy_ops___3 *ops;
	struct mutex mutex;
	int init_count;
	int power_count;
	struct phy_attrs attrs;
	struct regulator *pwr;
};

enum iproc_pcie_type {
	IPROC_PCIE_PAXB_BCMA = 0,
	IPROC_PCIE_PAXB = 1,
	IPROC_PCIE_PAXB_V2 = 2,
	IPROC_PCIE_PAXC = 3,
	IPROC_PCIE_PAXC_V2 = 4,
};

struct iproc_pcie_ob {
	resource_size_t axi_offset;
	unsigned int nr_windows;
};

struct iproc_pcie_ib {
	unsigned int nr_regions;
};

struct iproc_msi;

struct iproc_pcie_ob_map;

struct iproc_pcie_ib_map;

struct iproc_pcie {
	struct device___243 *dev;
	enum iproc_pcie_type type;
	u16 *reg_offsets;
	void *base;
	phys_addr_t base_addr;
	struct resource mem;
	struct pci_bus___8 *root_bus;
	struct phy___3 *phy;
	int (*map_irq)(const struct pci_dev___8 *, u8, u8);
	bool ep_is_internal;
	bool iproc_cfg_read;
	bool rej_unconfig_pf;
	bool has_apb_err_disable;
	bool fix_paxc_cap;
	bool need_ob_cfg;
	struct iproc_pcie_ob ob;
	const struct iproc_pcie_ob_map *ob_map;
	bool need_ib_cfg;
	struct iproc_pcie_ib ib;
	const struct iproc_pcie_ib_map *ib_map;
	bool need_msi_steer;
	struct iproc_msi *msi;
};

struct iproc_pcie_ob_map {
	resource_size_t window_sizes[4];
	unsigned int nr_sizes;
};

enum iproc_pcie_ib_map_type {
	IPROC_PCIE_IB_MAP_MEM = 0,
	IPROC_PCIE_IB_MAP_IO = 1,
	IPROC_PCIE_IB_MAP_INVALID = 2,
};

struct iproc_pcie_ib_map {
	enum iproc_pcie_ib_map_type type;
	unsigned int size_unit;
	resource_size_t region_sizes[9];
	unsigned int nr_sizes;
	unsigned int nr_windows;
	u16 imap_addr_offset;
	u16 imap_window_offset;
};

enum iproc_pcie_reg {
	IPROC_PCIE_CLK_CTRL = 0,
	IPROC_PCIE_MSI_GIC_MODE = 1,
	IPROC_PCIE_MSI_BASE_ADDR = 2,
	IPROC_PCIE_MSI_WINDOW_SIZE = 3,
	IPROC_PCIE_MSI_ADDR_LO = 4,
	IPROC_PCIE_MSI_ADDR_HI = 5,
	IPROC_PCIE_MSI_EN_CFG = 6,
	IPROC_PCIE_CFG_IND_ADDR = 7,
	IPROC_PCIE_CFG_IND_DATA = 8,
	IPROC_PCIE_CFG_ADDR = 9,
	IPROC_PCIE_CFG_DATA = 10,
	IPROC_PCIE_INTX_EN = 11,
	IPROC_PCIE_OARR0 = 12,
	IPROC_PCIE_OMAP0 = 13,
	IPROC_PCIE_OARR1 = 14,
	IPROC_PCIE_OMAP1 = 15,
	IPROC_PCIE_OARR2 = 16,
	IPROC_PCIE_OMAP2 = 17,
	IPROC_PCIE_OARR3 = 18,
	IPROC_PCIE_OMAP3 = 19,
	IPROC_PCIE_IARR0 = 20,
	IPROC_PCIE_IMAP0 = 21,
	IPROC_PCIE_IARR1 = 22,
	IPROC_PCIE_IMAP1 = 23,
	IPROC_PCIE_IARR2 = 24,
	IPROC_PCIE_IMAP2 = 25,
	IPROC_PCIE_IARR3 = 26,
	IPROC_PCIE_IMAP3 = 27,
	IPROC_PCIE_IARR4 = 28,
	IPROC_PCIE_IMAP4 = 29,
	IPROC_PCIE_LINK_STATUS = 30,
	IPROC_PCIE_APB_ERR_EN = 31,
	IPROC_PCIE_MAX_NUM_REG = 32,
};

struct file___297;

struct kiocb___297;

struct vm_area_struct___298;

struct inode___297;

struct file_lock___297;

struct page___298;

struct file_operations___297 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___297 *, loff_t, int);
	ssize_t (*read)(struct file___297 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___297 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___297 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___297 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___297 *, bool);
	int (*iterate)(struct file___297 *, struct dir_context *);
	int (*iterate_shared)(struct file___297 *, struct dir_context *);
	__poll_t (*poll)(struct file___297 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___297 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___297 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___297 *, struct vm_area_struct___298 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___297 *, struct file___297 *);
	int (*flush)(struct file___297 *, fl_owner_t);
	int (*release)(struct inode___297 *, struct file___297 *);
	int (*fsync)(struct file___297 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___297 *, int);
	int (*lock)(struct file___297 *, int, struct file_lock___297 *);
	ssize_t (*sendpage)(struct file___297 *, struct page___298 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___297 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___297 *, int, struct file_lock___297 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___297 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___297 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___297 *, long int, struct file_lock___297 **, void **);
	long int (*fallocate)(struct file___297 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___297 *);
	ssize_t (*copy_file_range)(struct file___297 *, loff_t, struct file___297 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___297 *, loff_t, struct file___297 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___297 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___297 {
	u64 seqnum;
	struct vm_area_struct___298 *vmas[4];
};

struct page_frag___297 {
	struct page___298 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___297;

struct vm_struct___213;

struct task_struct___298 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___298 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___297 *mm;
	struct mm_struct___297 *active_mm;
	struct vmacache___297 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___298 *real_parent;
	struct task_struct___298 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___298 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___196 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___196 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___196 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___2 *ptracer_cred;
	const struct cred___2 *real_cred;
	const struct cred___2 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___298 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___82 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___297 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___298 *oom_reaper_list;
	struct vm_struct___213 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___131 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct secondary_data___298 {
	void *stack;
	struct task_struct___298 *task;
	long int status;
};

struct irqaction___13 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___13 *next;
	irq_handler_t thread_fn;
	struct task_struct___298 *thread;
	struct irqaction___13 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_desc___16;

typedef void (*irq_flow_handler_t___16)(struct irq_desc___16 *);

struct msi_desc___12;

struct irq_common_data___9 {
	unsigned int state_use_accessors;
	unsigned int node;
	void *handler_data;
	struct msi_desc___12 *msi_desc;
	cpumask_var_t affinity;
	cpumask_var_t effective_affinity;
};

struct irq_chip___19;

struct irq_domain___13;

struct irq_data___19 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___9 *common;
	struct irq_chip___19 *chip;
	struct irq_domain___13 *domain;
	struct irq_data___19 *parent_data;
	void *chip_data;
};

struct kset___283;

struct kobj_type___283;

struct kernfs_node___291;

struct kobject___284 {
	const char *name;
	struct list_head entry;
	struct kobject___284 *parent;
	struct kset___283 *kset;
	struct kobj_type___283 *ktype;
	struct kernfs_node___291 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct irq_desc___16 {
	struct irq_common_data___9 irq_common_data;
	struct irq_data___19 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___16 handle_irq;
	struct irqaction___13 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int irq_count;
	unsigned int tot_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___284 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___11 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___298 *pgtable_t___297;

struct address_space___296;

struct dev_pagemap___286;

struct page___298 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___296 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___298 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___297 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___297 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___286 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___297;

struct lruvec___297 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___297 *pgdat;
};

struct zone___297 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___297 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___297 {
	struct zone___297 *zone;
	int zone_idx;
};

struct zonelist___297 {
	struct zoneref___297 _zonerefs[25];
};

struct pglist_data___297 {
	struct zone___297 node_zones[3];
	struct zonelist___297 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___298 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___298 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___297 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___298 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___298 *owner;
};

struct blocking_notifier_head___297 {
	struct rw_semaphore___298 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___286;

struct vm_area_struct___298 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___298 *vm_next;
	struct vm_area_struct___298 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___297 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___286 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___297 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___297;

struct mm_struct___297 {
	struct {
		struct vm_area_struct___298 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___297 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___298 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___297 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___298 *owner;
		struct user_namespace___3 *user_ns;
		struct file___297 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___297 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___296;

struct address_space___296 {
	struct inode___297 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___298 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___296 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___286)(struct vm_area_struct___298 *, long unsigned int, const struct page___298 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___286)(struct page___298 *, void *);

struct device___262;

struct dev_pagemap___286 {
	dev_page_fault_t___286 page_fault;
	dev_page_free_t___286 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___262 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct dentry___297;

struct path___297 {
	struct vfsmount *mnt;
	struct dentry___297 *dentry;
};

struct file___297 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___297 f_path;
	struct inode___297 *f_inode;
	const struct file_operations___297 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___196 f_owner;
	const struct cred___2 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___296 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___286;

struct vm_operations_struct___286 {
	void (*open)(struct vm_area_struct___298 *);
	void (*close)(struct vm_area_struct___298 *);
	int (*split)(struct vm_area_struct___298 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___298 *);
	vm_fault_t (*fault)(struct vm_fault___286 *);
	vm_fault_t (*huge_fault)(struct vm_fault___286 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___286 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___298 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___286 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___286 *);
	int (*access)(struct vm_area_struct___298 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___298 *);
	int (*set_policy)(struct vm_area_struct___298 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___298 *, long unsigned int);
	struct page___298 * (*find_special_page)(struct vm_area_struct___298 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___297 {
	struct task_struct___298 *task;
	struct core_thread___297 *next;
};

struct core_state___297 {
	atomic_t nr_threads;
	struct core_thread___297 dumper;
	struct completion startup;
};

struct vm_fault___286 {
	struct vm_area_struct___298 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___298 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___298 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___297 prealloc_pte;
};

struct vm_struct___213 {
	struct vm_struct___213 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___298 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct fwnode_operations___196;

struct fwnode_handle___196 {
	struct fwnode_handle___196 *secondary;
	const struct fwnode_operations___196 *ops;
};

struct fwnode_reference_args___196;

struct fwnode_endpoint___196;

struct fwnode_operations___196 {
	struct fwnode_handle___196 * (*get)(struct fwnode_handle___196 *);
	void (*put)(struct fwnode_handle___196 *);
	bool (*device_is_available)(const struct fwnode_handle___196 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___196 *, const struct device___262 *);
	bool (*property_present)(const struct fwnode_handle___196 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___196 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___196 *, const char *, const char **, size_t);
	struct fwnode_handle___196 * (*get_parent)(const struct fwnode_handle___196 *);
	struct fwnode_handle___196 * (*get_next_child_node)(const struct fwnode_handle___196 *, struct fwnode_handle___196 *);
	struct fwnode_handle___196 * (*get_named_child_node)(const struct fwnode_handle___196 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___196 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___196 *);
	struct fwnode_handle___196 * (*graph_get_next_endpoint)(const struct fwnode_handle___196 *, struct fwnode_handle___196 *);
	struct fwnode_handle___196 * (*graph_get_remote_endpoint)(const struct fwnode_handle___196 *);
	struct fwnode_handle___196 * (*graph_get_port_parent)(struct fwnode_handle___196 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___196 *, struct fwnode_endpoint___196 *);
};

struct fwnode_endpoint___196 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___196 *local_fwnode;
};

struct fwnode_reference_args___196 {
	struct fwnode_handle___196 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct dev_pm_info___262 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___262 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___262;

struct bus_type___262;

struct device_driver___262;

struct dev_pm_domain___262;

struct dma_map_ops___84;

struct device_node___54;

struct class___262;

struct attribute_group___261;

struct device___262 {
	struct device___262 *parent;
	struct device_private *p;
	struct kobject___284 kobj;
	const char *init_name;
	const struct device_type___262 *type;
	struct mutex mutex;
	struct bus_type___262 *bus;
	struct device_driver___262 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___262 power;
	struct dev_pm_domain___262 *pm_domain;
	struct irq_domain___13 *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___84 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___54 *of_node;
	struct fwnode_handle___196 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___262 *class;
	const struct attribute_group___261 **groups;
	void (*release)(struct device___262 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct msi_desc___12 {
	struct list_head list;
	unsigned int irq;
	unsigned int nvec_used;
	struct device___262 *dev;
	struct msi_msg msg;
	struct irq_affinity_desc *affinity;
	const void *iommu_cookie;
	union {
		struct {
			u32 masked;
			struct {
				u8 is_msix: 1;
				u8 multiple: 3;
				u8 multi_cap: 3;
				u8 maskbit: 1;
				u8 is_64: 1;
				u16 entry_nr;
				unsigned int default_irq;
			} msi_attrib;
			union {
				u8 mask_pos;
				void *mask_base;
			};
		};
		struct platform_msi_desc platform;
		struct fsl_mc_msi_desc fsl_mc;
	};
};

struct irq_chip___19 {
	struct device___262 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___19 *);
	void (*irq_shutdown)(struct irq_data___19 *);
	void (*irq_enable)(struct irq_data___19 *);
	void (*irq_disable)(struct irq_data___19 *);
	void (*irq_ack)(struct irq_data___19 *);
	void (*irq_mask)(struct irq_data___19 *);
	void (*irq_mask_ack)(struct irq_data___19 *);
	void (*irq_unmask)(struct irq_data___19 *);
	void (*irq_eoi)(struct irq_data___19 *);
	int (*irq_set_affinity)(struct irq_data___19 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___19 *);
	int (*irq_set_type)(struct irq_data___19 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___19 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___19 *);
	void (*irq_bus_sync_unlock)(struct irq_data___19 *);
	void (*irq_cpu_online)(struct irq_data___19 *);
	void (*irq_cpu_offline)(struct irq_data___19 *);
	void (*irq_suspend)(struct irq_data___19 *);
	void (*irq_resume)(struct irq_data___19 *);
	void (*irq_pm_shutdown)(struct irq_data___19 *);
	void (*irq_calc_mask)(struct irq_data___19 *);
	void (*irq_print_chip)(struct irq_data___19 *, struct seq_file___9 *);
	int (*irq_request_resources)(struct irq_data___19 *);
	void (*irq_release_resources)(struct irq_data___19 *);
	void (*irq_compose_msi_msg)(struct irq_data___19 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___19 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___19 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___19 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___19 *, void *);
	void (*ipi_send_single)(struct irq_data___19 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___19 *, const struct cpumask *);
	long unsigned int flags;
};

struct irq_domain_ops___13;

struct irq_domain_chip_generic___11;

struct irq_domain___13 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___13 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___196 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___11 *gc;
	struct irq_domain___13 *parent;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_direct_max_irq;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_tree_mutex;
	unsigned int linear_revmap[0];
};

struct kernfs_root___290;

struct kernfs_elem_dir___290 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___290 *root;
};

struct kernfs_syscall_ops___290;

struct kernfs_root___290 {
	struct kernfs_node___291 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___290 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___290 {
	struct kernfs_node___291 *target_kn;
};

struct kernfs_ops___290;

struct kernfs_elem_attr___290 {
	const struct kernfs_ops___290 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___291 *notify_next;
};

struct kernfs_node___291 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___291 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___290 dir;
		struct kernfs_elem_symlink___290 symlink;
		struct kernfs_elem_attr___290 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___290;

struct kernfs_ops___290 {
	int (*open)(struct kernfs_open_file___290 *);
	void (*release)(struct kernfs_open_file___290 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___290 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___290 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___290 *, struct vm_area_struct___298 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___290 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___290 {
	int (*remount_fs)(struct kernfs_root___290 *, int *, char *);
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___290 *);
	int (*mkdir)(struct kernfs_node___291 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___291 *);
	int (*rename)(struct kernfs_node___291 *, struct kernfs_node___291 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___291 *, struct kernfs_root___290 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___290 {
	struct kernfs_node___291 *kn;
	struct file___297 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___286 *vm_ops;
};

struct bin_attribute___260;

struct attribute_group___261 {
	const char *name;
	umode_t (*is_visible)(struct kobject___284 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___284 *, struct bin_attribute___260 *, int);
	struct attribute **attrs;
	struct bin_attribute___260 **bin_attrs;
};

struct bin_attribute___260 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___297 *, struct kobject___284 *, struct bin_attribute___260 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___297 *, struct kobject___284 *, struct bin_attribute___260 *, char *, loff_t, size_t);
	int (*mmap)(struct file___297 *, struct kobject___284 *, struct bin_attribute___260 *, struct vm_area_struct___298 *);
};

struct sysfs_ops___283 {
	ssize_t (*show)(struct kobject___284 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___284 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___283;

struct kset___283 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___284 kobj;
	const struct kset_uevent_ops___283 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___283 {
	void (*release)(struct kobject___284 *);
	const struct sysfs_ops___283 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___25 * (*child_ns_type)(struct kobject___284 *);
	const void * (*namespace)(struct kobject___284 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___283 {
	int (* const filter)(struct kset___283 *, struct kobject___284 *);
	const char * (* const name)(struct kset___283 *, struct kobject___284 *);
	int (* const uevent)(struct kset___283 *, struct kobject___284 *, struct kobj_uevent_env *);
};

struct kobj_attribute___276 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___284 *, struct kobj_attribute___276 *, char *);
	ssize_t (*store)(struct kobject___284 *, struct kobj_attribute___276 *, const char *, size_t);
};

struct irq_chip_type___12 {
	struct irq_chip___19 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___16 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___12 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___12 *);
	void (*resume)(struct irq_chip_generic___12 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___13 *domain;
	struct list_head list;
	struct irq_chip_type___12 chip_types[0];
};

struct irq_domain_chip_generic___11 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___12 *gc[0];
};

struct property___51 {
	char *name;
	int length;
	void *value;
	struct property___51 *next;
	long unsigned int _flags;
	struct bin_attribute___260 attr;
};

struct device_node___54 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___196 fwnode;
	struct property___51 *properties;
	struct property___51 *deadprops;
	struct device_node___54 *parent;
	struct device_node___54 *child;
	struct device_node___54 *sibling;
	struct kobject___284 kobj;
	long unsigned int _flags;
	void *data;
};

struct irq_fwspec___13 {
	struct fwnode_handle___196 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___13 {
	int (*match)(struct irq_domain___13 *, struct device_node___54 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___13 *, struct irq_fwspec___13 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___13 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___13 *, unsigned int);
	int (*xlate)(struct irq_domain___13 *, struct device_node___54 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___13 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___13 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___13 *, struct irq_data___19 *, bool);
	void (*deactivate)(struct irq_domain___13 *, struct irq_data___19 *);
	int (*translate)(struct irq_domain___13 *, struct irq_fwspec___13 *, long unsigned int *, unsigned int *);
};

struct pci_dev___22;

struct msi_controller___8 {
	struct module___11 *owner;
	struct device___262 *dev;
	struct device_node___54 *of_node;
	struct list_head list;
	int (*setup_irq)(struct msi_controller___8 *, struct pci_dev___22 *, struct msi_desc___12 *);
	int (*setup_irqs)(struct msi_controller___8 *, struct pci_dev___22 *, int, int);
	void (*teardown_irq)(struct msi_controller___8 *, unsigned int);
};

struct pci_bus___22;

struct pci_slot___22;

struct pci_driver___22;

struct pci_dev___22 {
	struct list_head bus_list;
	struct pci_bus___22 *bus;
	struct pci_bus___22 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___22 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u16 aer_cap;
	struct aer_stats *aer_stats;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	long unsigned int *dma_alias_mask;
	struct pci_driver___22 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	unsigned int imm_ready: 1;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int bridge_d3: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int hotplug_user_indicators: 1;
	unsigned int clear_retrain_link: 1;
	unsigned int d3_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	unsigned int ltr_path: 1;
	unsigned int eetlp_prefix_path: 1;
	pci_channel_state_t error_state;
	struct device___262 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int multifunction: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int ats_enabled: 1;
	unsigned int pasid_enabled: 1;
	unsigned int pri_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int reset_fn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int shpc_managed: 1;
	unsigned int is_thunderbolt: 1;
	unsigned int __aer_firmware_first_valid: 1;
	unsigned int __aer_firmware_first: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int irq_managed: 1;
	unsigned int has_secondary_link: 1;
	unsigned int non_compliant_bars: 1;
	unsigned int is_probed: 1;
	unsigned int link_active_reporting: 1;
	unsigned int untrusted: 1;
	unsigned int no_vf_scan: 1;
	unsigned int io_window: 1;
	unsigned int pref_window: 1;
	unsigned int pref_64_window: 1;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	struct bin_attribute___260 *rom_attr;
	int rom_attr_enabled;
	struct bin_attribute___260 *res_attr[17];
	struct bin_attribute___260 *res_attr_wc[17];
	unsigned int broken_cmd_compl: 1;
	const struct attribute_group___261 **msi_irq_groups;
	struct pci_vpd *vpd;
	union {
		struct pci_sriov *sriov;
		struct pci_dev___22 *physfn;
	};
	u16 ats_cap;
	u8 ats_stu;
	atomic_t ats_ref_cnt;
	u32 pri_reqs_alloc;
	u16 pasid_features;
	struct pci_p2pdma *p2pdma;
	phys_addr_t rom;
	size_t romlen;
	char *driver_override;
	long unsigned int priv_flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t pci_dev_extended_size_rh;
	struct pci_dev_extended_rh pci_dev_extended_rh;
};

struct msi_alloc_info___6 {
	struct msi_desc___12 *desc;
	irq_hw_number_t hwirq;
	union {
		long unsigned int ul;
		void *ptr;
	} scratchpad[2];
};

typedef struct msi_alloc_info___6 msi_alloc_info_t___6;

struct msi_domain_info___6;

struct msi_domain_ops___6 {
	irq_hw_number_t (*get_hwirq)(struct msi_domain_info___6 *, msi_alloc_info_t___6 *);
	int (*msi_init)(struct irq_domain___13 *, struct msi_domain_info___6 *, unsigned int, irq_hw_number_t, msi_alloc_info_t___6 *);
	void (*msi_free)(struct irq_domain___13 *, struct msi_domain_info___6 *, unsigned int);
	int (*msi_check)(struct irq_domain___13 *, struct msi_domain_info___6 *, struct device___262 *);
	int (*msi_prepare)(struct irq_domain___13 *, struct device___262 *, int, msi_alloc_info_t___6 *);
	void (*msi_finish)(msi_alloc_info_t___6 *, int);
	void (*set_desc)(msi_alloc_info_t___6 *, struct msi_desc___12 *);
	int (*handle_error)(struct irq_domain___13 *, struct msi_desc___12 *, int);
};

struct msi_domain_info___6 {
	u32 flags;
	struct msi_domain_ops___6 *ops;
	struct irq_chip___19 *chip;
	void *chip_data;
	irq_flow_handler_t___16 handler;
	void *handler_data;
	const char *handler_name;
	void *data;
};

struct dev_pm_ops___262 {
	int (*prepare)(struct device___262 *);
	void (*complete)(struct device___262 *);
	int (*suspend)(struct device___262 *);
	int (*resume)(struct device___262 *);
	int (*freeze)(struct device___262 *);
	int (*thaw)(struct device___262 *);
	int (*poweroff)(struct device___262 *);
	int (*restore)(struct device___262 *);
	int (*suspend_late)(struct device___262 *);
	int (*resume_early)(struct device___262 *);
	int (*freeze_late)(struct device___262 *);
	int (*thaw_early)(struct device___262 *);
	int (*poweroff_late)(struct device___262 *);
	int (*restore_early)(struct device___262 *);
	int (*suspend_noirq)(struct device___262 *);
	int (*resume_noirq)(struct device___262 *);
	int (*freeze_noirq)(struct device___262 *);
	int (*thaw_noirq)(struct device___262 *);
	int (*poweroff_noirq)(struct device___262 *);
	int (*restore_noirq)(struct device___262 *);
	int (*runtime_suspend)(struct device___262 *);
	int (*runtime_resume)(struct device___262 *);
	int (*runtime_idle)(struct device___262 *);
};

struct dev_pm_domain___262 {
	struct dev_pm_ops___262 ops;
	void (*detach)(struct device___262 *, bool);
	int (*activate)(struct device___262 *);
	void (*sync)(struct device___262 *);
	void (*dismiss)(struct device___262 *);
};

struct bus_type___262 {
	const char *name;
	const char *dev_name;
	struct device___262 *dev_root;
	const struct attribute_group___261 **bus_groups;
	const struct attribute_group___261 **dev_groups;
	const struct attribute_group___261 **drv_groups;
	int (*match)(struct device___262 *, struct device_driver___262 *);
	int (*uevent)(struct device___262 *, struct kobj_uevent_env *);
	int (*probe)(struct device___262 *);
	int (*remove)(struct device___262 *);
	void (*shutdown)(struct device___262 *);
	int (*online)(struct device___262 *);
	int (*offline)(struct device___262 *);
	int (*suspend)(struct device___262 *, pm_message_t);
	int (*resume)(struct device___262 *);
	int (*num_vf)(struct device___262 *);
	int (*dma_configure)(struct device___262 *);
	const struct dev_pm_ops___262 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___262 {
	const char *name;
	struct bus_type___262 *bus;
	struct module___11 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___262 *);
	int (*remove)(struct device___262 *);
	void (*shutdown)(struct device___262 *);
	int (*suspend)(struct device___262 *, pm_message_t);
	int (*resume)(struct device___262 *);
	const struct attribute_group___261 **groups;
	const struct dev_pm_ops___262 *pm;
	void (*coredump)(struct device___262 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___262 {
	const char *name;
	const struct attribute_group___261 **groups;
	int (*uevent)(struct device___262 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___262 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___262 *);
	const struct dev_pm_ops___262 *pm;
};

struct class___262 {
	const char *name;
	struct module___11 *owner;
	const struct attribute_group___261 **class_groups;
	const struct attribute_group___261 **dev_groups;
	struct kobject___284 *dev_kobj;
	int (*dev_uevent)(struct device___262 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___262 *, umode_t *);
	void (*class_release)(struct class___262 *);
	void (*dev_release)(struct device___262 *);
	int (*shutdown_pre)(struct device___262 *);
	const struct kobj_ns_type_operations___25 *ns_type;
	const void * (*namespace)(struct device___262 *);
	const struct dev_pm_ops___262 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___84 {
	void * (*alloc)(struct device___262 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___262 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___262 *, struct vm_area_struct___298 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___262 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___262 *, struct page___298 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___262 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___262 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___262 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___262 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___262 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___262 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___262 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___262 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___262 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___262 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___262 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___262 *, u64);
	u64 (*get_required_mask)(struct device___262 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct pci_slot___22 {
	struct pci_bus___22 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject___284 kobj;
};

struct pci_ops___22;

struct pci_bus___22 {
	struct list_head node;
	struct pci_bus___22 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___22 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___22 *ops;
	struct msi_controller___8 *msi;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	int domain_nr;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___262 *bridge;
	struct device___262 dev;
	struct bin_attribute___260 *legacy_io;
	struct bin_attribute___260 *legacy_mem;
	unsigned int is_added: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
};

struct pci_error_handlers___22;

struct pci_driver___22 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___22 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___22 *);
	int (*suspend)(struct pci_dev___22 *, pm_message_t);
	int (*suspend_late)(struct pci_dev___22 *, pm_message_t);
	int (*resume_early)(struct pci_dev___22 *);
	int (*resume)(struct pci_dev___22 *);
	void (*shutdown)(struct pci_dev___22 *);
	int (*sriov_configure)(struct pci_dev___22 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	const struct pci_error_handlers___22 *err_handler;
	const struct attribute_group___261 **groups;
	struct device_driver___262 driver;
	struct pci_dynids dynids;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct pci_ops___22 {
	int (*add_bus)(struct pci_bus___22 *);
	void (*remove_bus)(struct pci_bus___22 *);
	void * (*map_bus)(struct pci_bus___22 *, unsigned int, int);
	int (*read)(struct pci_bus___22 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___22 *, unsigned int, int, int, u32);
};

struct pci_error_handlers___22 {
	pci_ers_result_t (*error_detected)(struct pci_dev___22 *, enum pci_channel_state);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___22 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___22 *);
	void (*reset_prepare)(struct pci_dev___22 *);
	void (*reset_done)(struct pci_dev___22 *);
	void (*resume)(struct pci_dev___22 *);
};

struct dentry_operations___296;

struct super_block___296;

struct dentry___297 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___297 *d_parent;
	struct qstr d_name;
	struct inode___297 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___296 *d_op;
	struct super_block___296 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___296;

struct block_device___296;

struct inode___297 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___296 *i_op;
	struct super_block___296 *i_sb;
	struct address_space___296 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___298 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___297 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___296 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___296 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___296 {
	int (*d_revalidate)(struct dentry___297 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___297 *, unsigned int);
	int (*d_hash)(const struct dentry___297 *, struct qstr *);
	int (*d_compare)(const struct dentry___297 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___297 *);
	int (*d_init)(struct dentry___297 *);
	void (*d_release)(struct dentry___297 *);
	void (*d_prune)(struct dentry___297 *);
	void (*d_iput)(struct dentry___297 *, struct inode___297 *);
	char * (*d_dname)(struct dentry___297 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___297 *);
	int (*d_manage)(const struct path___297 *, bool);
	struct dentry___297 * (*d_real)(struct dentry___297 *, const struct inode___297 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___296;

struct mem_dqinfo___296 {
	struct quota_format_type___296 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___296;

struct quota_info___296 {
	unsigned int flags;
	struct rw_semaphore___298 dqio_sem;
	struct inode___297 *files[3];
	struct mem_dqinfo___296 info[3];
	const struct quota_format_ops___296 *ops[3];
};

struct rcuwait___296 {
	struct task_struct___298 *task;
};

struct percpu_rw_semaphore___296 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___298 rw_sem;
	struct rcuwait___296 writer;
	int readers_block;
};

struct sb_writers___296 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___296 rw_sem[3];
};

struct file_system_type___296;

struct super_operations___296;

struct dquot_operations___296;

struct quotactl_ops___296;

struct super_block___296 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___296 *s_type;
	const struct super_operations___296 *s_op;
	const struct dquot_operations___296 *dq_op;
	const struct quotactl_ops___296 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___297 *s_root;
	struct rw_semaphore___298 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___296 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___296 s_dquot;
	struct sb_writers___296 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___296 *s_d_op;
	int cleancache_poolid;
	struct shrinker___116 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___297 {
	struct file___297 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___297 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___296 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___297 *ia_file;
};

struct dquot___296 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___296 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___296 {
	int qf_fmt_id;
	const struct quota_format_ops___296 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___296 *qf_next;
};

struct quota_format_ops___296 {
	int (*check_quota_file)(struct super_block___296 *, int);
	int (*read_file_info)(struct super_block___296 *, int);
	int (*write_file_info)(struct super_block___296 *, int);
	int (*free_file_info)(struct super_block___296 *, int);
	int (*read_dqblk)(struct dquot___296 *);
	int (*commit_dqblk)(struct dquot___296 *);
	int (*release_dqblk)(struct dquot___296 *);
	int (*get_next_id)(struct super_block___296 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___296 {
	int (*write_dquot)(struct dquot___296 *);
	struct dquot___296 * (*alloc_dquot)(struct super_block___296 *, int);
	void (*destroy_dquot)(struct dquot___296 *);
	int (*acquire_dquot)(struct dquot___296 *);
	int (*release_dquot)(struct dquot___296 *);
	int (*mark_dirty)(struct dquot___296 *);
	int (*write_info)(struct super_block___296 *, int);
	qsize_t * (*get_reserved_space)(struct inode___297 *);
	int (*get_projid)(struct inode___297 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___297 *, qsize_t *);
	int (*get_next_id)(struct super_block___296 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___296 {
	int (*quota_on)(struct super_block___296 *, int, int, const struct path___297 *);
	int (*quota_off)(struct super_block___296 *, int);
	int (*quota_enable)(struct super_block___296 *, unsigned int);
	int (*quota_disable)(struct super_block___296 *, unsigned int);
	int (*quota_sync)(struct super_block___296 *, int);
	int (*set_info)(struct super_block___296 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___296 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___296 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___296 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___296 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___296 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___296 {
	int (*writepage)(struct page___298 *, struct writeback_control___3 *);
	int (*readpage)(struct file___297 *, struct page___298 *);
	int (*writepages)(struct address_space___296 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___298 *);
	int (*readpages)(struct file___297 *, struct address_space___296 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___297 *, struct address_space___296 *, loff_t, unsigned int, unsigned int, struct page___298 **, void **);
	int (*write_end)(struct file___297 *, struct address_space___296 *, loff_t, unsigned int, unsigned int, struct page___298 *, void *);
	sector_t (*bmap)(struct address_space___296 *, sector_t);
	void (*invalidatepage)(struct page___298 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___298 *, gfp_t);
	void (*freepage)(struct page___298 *);
	ssize_t (*direct_IO)(struct kiocb___297 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___296 *, struct page___298 *, struct page___298 *, enum migrate_mode);
	bool (*isolate_page)(struct page___298 *, isolate_mode_t);
	void (*putback_page)(struct page___298 *);
	int (*launder_page)(struct page___298 *);
	int (*is_partially_uptodate)(struct page___298 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___298 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___296 *, struct page___298 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___297 *, sector_t *);
	void (*swap_deactivate)(struct file___297 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___296 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___297 *bd_inode;
	struct super_block___296 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___296 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___296 {
	struct dentry___297 * (*lookup)(struct inode___297 *, struct dentry___297 *, unsigned int);
	const char * (*get_link)(struct dentry___297 *, struct inode___297 *, struct delayed_call *);
	int (*permission)(struct inode___297 *, int);
	struct posix_acl * (*get_acl)(struct inode___297 *, int);
	int (*readlink)(struct dentry___297 *, char *, int);
	int (*create)(struct inode___297 *, struct dentry___297 *, umode_t, bool);
	int (*link)(struct dentry___297 *, struct inode___297 *, struct dentry___297 *);
	int (*unlink)(struct inode___297 *, struct dentry___297 *);
	int (*symlink)(struct inode___297 *, struct dentry___297 *, const char *);
	int (*mkdir)(struct inode___297 *, struct dentry___297 *, umode_t);
	int (*rmdir)(struct inode___297 *, struct dentry___297 *);
	int (*mknod)(struct inode___297 *, struct dentry___297 *, umode_t, dev_t);
	int (*rename)(struct inode___297 *, struct dentry___297 *, struct inode___297 *, struct dentry___297 *, unsigned int);
	int (*setattr)(struct dentry___297 *, struct iattr___296 *);
	int (*getattr)(const struct path___297 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___297 *, char *, size_t);
	int (*fiemap)(struct inode___297 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___297 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___297 *, struct dentry___297 *, struct file___297 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___297 *, struct dentry___297 *, umode_t);
	int (*set_acl)(struct inode___297 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___296 {
	void (*fl_copy_lock)(struct file_lock___297 *, struct file_lock___297 *);
	void (*fl_release_private)(struct file_lock___297 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___296;

struct lock_manager_operations___296;

struct file_lock___297 {
	struct file_lock___297 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___297 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___296 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___296 *fl_ops;
	const struct lock_manager_operations___296 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___296 {
	int (*lm_compare_owner)(struct file_lock___297 *, struct file_lock___297 *);
	long unsigned int (*lm_owner_key)(struct file_lock___297 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___297 *);
	int (*lm_grant)(struct file_lock___297 *, int);
	bool (*lm_break)(struct file_lock___297 *);
	int (*lm_change)(struct file_lock___297 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___297 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___296 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___296 *fa_next;
	struct file___297 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___296 {
	const char *name;
	int fs_flags;
	struct dentry___297 * (*mount)(struct file_system_type___296 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___296 *);
	struct module___11 *owner;
	struct file_system_type___296 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___296 {
	struct inode___297 * (*alloc_inode)(struct super_block___296 *);
	void (*destroy_inode)(struct inode___297 *);
	void (*dirty_inode)(struct inode___297 *, int);
	int (*write_inode)(struct inode___297 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___297 *);
	void (*evict_inode)(struct inode___297 *);
	void (*put_super)(struct super_block___296 *);
	int (*sync_fs)(struct super_block___296 *, int);
	int (*freeze_super)(struct super_block___296 *);
	int (*freeze_fs)(struct super_block___296 *);
	int (*thaw_super)(struct super_block___296 *);
	int (*unfreeze_fs)(struct super_block___296 *);
	int (*statfs)(struct dentry___297 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___296 *, int *, char *);
	void (*umount_begin)(struct super_block___296 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___297 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___297 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___297 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___297 *);
	ssize_t (*quota_read)(struct super_block___296 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___296 *, int, const char *, size_t, loff_t);
	struct dquot___296 ** (*get_dquots)(struct inode___297 *);
	int (*bdev_try_to_free_page)(struct super_block___296 *, struct page___298 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___296 *, struct shrink_control___116 *);
	long int (*free_cached_objects)(struct super_block___296 *, struct shrink_control___116 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___286(struct page___298 *);

struct phy___4;

struct iproc_pcie_ob_map___2;

struct iproc_pcie_ib_map___2;

struct iproc_msi___2;

struct iproc_pcie___2 {
	struct device___262 *dev;
	enum iproc_pcie_type type;
	u16 *reg_offsets;
	void *base;
	phys_addr_t base_addr;
	struct resource mem;
	struct pci_bus___22 *root_bus;
	struct phy___4 *phy;
	int (*map_irq)(const struct pci_dev___22 *, u8, u8);
	bool ep_is_internal;
	bool iproc_cfg_read;
	bool rej_unconfig_pf;
	bool has_apb_err_disable;
	bool fix_paxc_cap;
	bool need_ob_cfg;
	struct iproc_pcie_ob ob;
	const struct iproc_pcie_ob_map___2 *ob_map;
	bool need_ib_cfg;
	struct iproc_pcie_ib ib;
	const struct iproc_pcie_ib_map___2 *ib_map;
	bool need_msi_steer;
	struct iproc_msi___2 *msi;
};

struct iproc_msi_grp;

struct iproc_msi___2 {
	struct iproc_pcie___2 *pcie;
	const u16 (*reg_offsets)[8];
	struct iproc_msi_grp *grps;
	int nr_irqs;
	int nr_cpus;
	bool has_inten_reg;
	long unsigned int *bitmap;
	struct mutex bitmap_lock;
	unsigned int nr_msi_vecs;
	struct irq_domain___13 *inner_domain;
	struct irq_domain___13 *msi_domain;
	unsigned int nr_eq_region;
	unsigned int nr_msi_region;
	void *eq_cpu;
	dma_addr_t eq_dma;
	phys_addr_t msi_addr;
};

enum iproc_msi_reg {
	IPROC_MSI_EQ_PAGE = 0,
	IPROC_MSI_EQ_PAGE_UPPER = 1,
	IPROC_MSI_PAGE = 2,
	IPROC_MSI_PAGE_UPPER = 3,
	IPROC_MSI_CTRL = 4,
	IPROC_MSI_EQ_HEAD = 5,
	IPROC_MSI_EQ_TAIL = 6,
	IPROC_MSI_INTS_EN = 7,
	IPROC_MSI_REG_SIZE = 8,
};

struct iproc_msi_grp {
	struct iproc_msi___2 *msi;
	int gic_irq;
	unsigned int eq;
};

struct module___240;

struct file___298;

struct kiocb___298;

struct vm_area_struct___299;

struct inode___298;

struct file_lock___298;

struct page___299;

struct file_operations___298 {
	struct module___240 *owner;
	loff_t (*llseek)(struct file___298 *, loff_t, int);
	ssize_t (*read)(struct file___298 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___298 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___298 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___298 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___298 *, bool);
	int (*iterate)(struct file___298 *, struct dir_context *);
	int (*iterate_shared)(struct file___298 *, struct dir_context *);
	__poll_t (*poll)(struct file___298 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___298 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___298 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___298 *, struct vm_area_struct___299 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___298 *, struct file___298 *);
	int (*flush)(struct file___298 *, fl_owner_t);
	int (*release)(struct inode___298 *, struct file___298 *);
	int (*fsync)(struct file___298 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___298 *, int);
	int (*lock)(struct file___298 *, int, struct file_lock___298 *);
	ssize_t (*sendpage)(struct file___298 *, struct page___299 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___298 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___298 *, int, struct file_lock___298 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___298 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___298 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___298 *, long int, struct file_lock___298 **, void **);
	long int (*fallocate)(struct file___298 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___298 *);
	ssize_t (*copy_file_range)(struct file___298 *, loff_t, struct file___298 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___298 *, loff_t, struct file___298 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___298 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___298 {
	u64 seqnum;
	struct vm_area_struct___299 *vmas[4];
};

struct page_frag___298 {
	struct page___299 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___298;

struct vm_struct___214;

struct task_struct___299 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___299 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___298 *mm;
	struct mm_struct___298 *active_mm;
	struct vmacache___298 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___299 *real_parent;
	struct task_struct___299 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___299 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___196 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___196 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___196 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___2 *ptracer_cred;
	const struct cred___2 *real_cred;
	const struct cred___2 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___299 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___82 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___298 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___299 *oom_reaper_list;
	struct vm_struct___214 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___131 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___299 *pgtable_t___298;

struct address_space___297;

struct dev_pagemap___287;

struct page___299 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___297 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___299 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___298 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___298 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___287 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___298;

struct lruvec___298 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___298 *pgdat;
};

struct zone___298 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___298 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___298 {
	struct zone___298 *zone;
	int zone_idx;
};

struct zonelist___298 {
	struct zoneref___298 _zonerefs[25];
};

struct pglist_data___298 {
	struct zone___298 node_zones[3];
	struct zonelist___298 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___299 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___299 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___298 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___299 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___299 *owner;
};

struct secondary_data___299 {
	void *stack;
	struct task_struct___299 *task;
	long int status;
};

struct blocking_notifier_head___298 {
	struct rw_semaphore___299 rwsem;
	struct notifier_block *head;
};

struct kernfs_root___291;

struct kernfs_elem_dir___291 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___291 *root;
};

struct kernfs_node___292;

struct kernfs_syscall_ops___291;

struct kernfs_root___291 {
	struct kernfs_node___292 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___291 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___291 {
	struct kernfs_node___292 *target_kn;
};

struct kernfs_ops___291;

struct kernfs_elem_attr___291 {
	const struct kernfs_ops___291 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___292 *notify_next;
};

struct kernfs_node___292 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___292 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___291 dir;
		struct kernfs_elem_symlink___291 symlink;
		struct kernfs_elem_attr___291 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___291;

struct kernfs_ops___291 {
	int (*open)(struct kernfs_open_file___291 *);
	void (*release)(struct kernfs_open_file___291 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___291 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___291 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___291 *, struct vm_area_struct___299 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___291 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___291 {
	int (*remount_fs)(struct kernfs_root___291 *, int *, char *);
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___291 *);
	int (*mkdir)(struct kernfs_node___292 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___292 *);
	int (*rename)(struct kernfs_node___292 *, struct kernfs_node___292 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___292 *, struct kernfs_root___291 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_operations_struct___287;

struct kernfs_open_file___291 {
	struct kernfs_node___292 *kn;
	struct file___298 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___287 *vm_ops;
};

struct dentry___298;

struct path___298 {
	struct vfsmount *mnt;
	struct dentry___298 *dentry;
};

struct file___298 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___298 f_path;
	struct inode___298 *f_inode;
	const struct file_operations___298 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___196 f_owner;
	const struct cred___2 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___297 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___287;

struct vm_operations_struct___287 {
	void (*open)(struct vm_area_struct___299 *);
	void (*close)(struct vm_area_struct___299 *);
	int (*split)(struct vm_area_struct___299 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___299 *);
	vm_fault_t (*fault)(struct vm_fault___287 *);
	vm_fault_t (*huge_fault)(struct vm_fault___287 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___287 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___299 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___287 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___287 *);
	int (*access)(struct vm_area_struct___299 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___299 *);
	int (*set_policy)(struct vm_area_struct___299 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___299 *, long unsigned int);
	struct page___299 * (*find_special_page)(struct vm_area_struct___299 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_area_struct___299 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___299 *vm_next;
	struct vm_area_struct___299 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___298 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___287 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___298 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___285;

struct bin_attribute___261;

struct attribute_group___262 {
	const char *name;
	umode_t (*is_visible)(struct kobject___285 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___285 *, struct bin_attribute___261 *, int);
	struct attribute **attrs;
	struct bin_attribute___261 **bin_attrs;
};

struct kset___284;

struct kobj_type___284;

struct kobject___285 {
	const char *name;
	struct list_head entry;
	struct kobject___285 *parent;
	struct kset___284 *kset;
	struct kobj_type___284 *ktype;
	struct kernfs_node___292 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___261 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___298 *, struct kobject___285 *, struct bin_attribute___261 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___298 *, struct kobject___285 *, struct bin_attribute___261 *, char *, loff_t, size_t);
	int (*mmap)(struct file___298 *, struct kobject___285 *, struct bin_attribute___261 *, struct vm_area_struct___299 *);
};

struct sysfs_ops___284 {
	ssize_t (*show)(struct kobject___285 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___285 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___284;

struct kset___284 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___285 kobj;
	const struct kset_uevent_ops___284 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___284 {
	void (*release)(struct kobject___285 *);
	const struct sysfs_ops___284 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___25 * (*child_ns_type)(struct kobject___285 *);
	const void * (*namespace)(struct kobject___285 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___284 {
	int (* const filter)(struct kset___284 *, struct kobject___285 *);
	const char * (* const name)(struct kset___284 *, struct kobject___285 *);
	int (* const uevent)(struct kset___284 *, struct kobject___285 *, struct kobj_uevent_env *);
};

struct kobj_attribute___277 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___285 *, struct kobj_attribute___277 *, char *);
	ssize_t (*store)(struct kobject___285 *, struct kobj_attribute___277 *, const char *, size_t);
};

struct device___263;

struct dev_pm_ops___263 {
	int (*prepare)(struct device___263 *);
	void (*complete)(struct device___263 *);
	int (*suspend)(struct device___263 *);
	int (*resume)(struct device___263 *);
	int (*freeze)(struct device___263 *);
	int (*thaw)(struct device___263 *);
	int (*poweroff)(struct device___263 *);
	int (*restore)(struct device___263 *);
	int (*suspend_late)(struct device___263 *);
	int (*resume_early)(struct device___263 *);
	int (*freeze_late)(struct device___263 *);
	int (*thaw_early)(struct device___263 *);
	int (*poweroff_late)(struct device___263 *);
	int (*restore_early)(struct device___263 *);
	int (*suspend_noirq)(struct device___263 *);
	int (*resume_noirq)(struct device___263 *);
	int (*freeze_noirq)(struct device___263 *);
	int (*thaw_noirq)(struct device___263 *);
	int (*poweroff_noirq)(struct device___263 *);
	int (*restore_noirq)(struct device___263 *);
	int (*runtime_suspend)(struct device___263 *);
	int (*runtime_resume)(struct device___263 *);
	int (*runtime_idle)(struct device___263 *);
};

struct dev_pm_info___263 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___263 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___263;

struct bus_type___263;

struct device_driver___263;

struct dev_pm_domain___263;

struct irq_domain___14;

struct dma_map_ops___85;

struct device_node___55;

struct fwnode_handle___197;

struct class___263;

struct device___263 {
	struct device___263 *parent;
	struct device_private *p;
	struct kobject___285 kobj;
	const char *init_name;
	const struct device_type___263 *type;
	struct mutex mutex;
	struct bus_type___263 *bus;
	struct device_driver___263 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___263 power;
	struct dev_pm_domain___263 *pm_domain;
	struct irq_domain___14 *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___85 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___55 *of_node;
	struct fwnode_handle___197 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___263 *class;
	const struct attribute_group___262 **groups;
	void (*release)(struct device___263 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___263 {
	struct dev_pm_ops___263 ops;
	void (*detach)(struct device___263 *, bool);
	int (*activate)(struct device___263 *);
	void (*sync)(struct device___263 *);
	void (*dismiss)(struct device___263 *);
};

struct core_state___298;

struct mm_struct___298 {
	struct {
		struct vm_area_struct___299 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___298 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___299 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___298 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___299 *owner;
		struct user_namespace___3 *user_ns;
		struct file___298 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___298 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct vm_struct___214 {
	struct vm_struct___214 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___299 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bus_type___263 {
	const char *name;
	const char *dev_name;
	struct device___263 *dev_root;
	const struct attribute_group___262 **bus_groups;
	const struct attribute_group___262 **dev_groups;
	const struct attribute_group___262 **drv_groups;
	int (*match)(struct device___263 *, struct device_driver___263 *);
	int (*uevent)(struct device___263 *, struct kobj_uevent_env *);
	int (*probe)(struct device___263 *);
	int (*remove)(struct device___263 *);
	void (*shutdown)(struct device___263 *);
	int (*online)(struct device___263 *);
	int (*offline)(struct device___263 *);
	int (*suspend)(struct device___263 *, pm_message_t);
	int (*resume)(struct device___263 *);
	int (*num_vf)(struct device___263 *);
	int (*dma_configure)(struct device___263 *);
	const struct dev_pm_ops___263 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___263 {
	const char *name;
	struct bus_type___263 *bus;
	struct module___240 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___263 *);
	int (*remove)(struct device___263 *);
	void (*shutdown)(struct device___263 *);
	int (*suspend)(struct device___263 *, pm_message_t);
	int (*resume)(struct device___263 *);
	const struct attribute_group___262 **groups;
	const struct dev_pm_ops___263 *pm;
	void (*coredump)(struct device___263 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___263 {
	const char *name;
	const struct attribute_group___262 **groups;
	int (*uevent)(struct device___263 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___263 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___263 *);
	const struct dev_pm_ops___263 *pm;
};

struct module_kobject___237 {
	struct kobject___285 kobj;
	struct module___240 *mod;
	struct kobject___285 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___237 {
	struct module___240 *mod;
	struct latch_tree_node node;
};

struct module_layout___237 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___237 mtn;
};

struct module_attribute___237;

struct kernel_param___237;

struct module___240 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___237 mkobj;
	struct module_attribute___237 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___285 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___237 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___237 core_layout;
	struct module_layout___237 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct class___263 {
	const char *name;
	struct module___240 *owner;
	const struct attribute_group___262 **class_groups;
	const struct attribute_group___262 **dev_groups;
	struct kobject___285 *dev_kobj;
	int (*dev_uevent)(struct device___263 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___263 *, umode_t *);
	void (*class_release)(struct class___263 *);
	void (*dev_release)(struct device___263 *);
	int (*shutdown_pre)(struct device___263 *);
	const struct kobj_ns_type_operations___25 *ns_type;
	const void * (*namespace)(struct device___263 *);
	const struct dev_pm_ops___263 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct irq_domain_ops___14;

struct irq_domain_chip_generic___12;

struct irq_domain___14 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___14 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___197 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___12 *gc;
	struct irq_domain___14 *parent;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_direct_max_irq;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_tree_mutex;
	unsigned int linear_revmap[0];
};

struct dma_map_ops___85 {
	void * (*alloc)(struct device___263 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___263 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___263 *, struct vm_area_struct___299 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___263 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___263 *, struct page___299 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___263 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___263 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___263 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___263 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___263 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___263 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___263 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___263 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___263 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___263 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___263 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___263 *, u64);
	u64 (*get_required_mask)(struct device___263 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___197;

struct fwnode_handle___197 {
	struct fwnode_handle___197 *secondary;
	const struct fwnode_operations___197 *ops;
};

struct property___52;

struct device_node___55 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___197 fwnode;
	struct property___52 *properties;
	struct property___52 *deadprops;
	struct device_node___55 *parent;
	struct device_node___55 *child;
	struct device_node___55 *sibling;
	struct kobject___285 kobj;
	long unsigned int _flags;
	void *data;
};

struct irqaction___14 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___14 *next;
	irq_handler_t thread_fn;
	struct task_struct___299 *thread;
	struct irqaction___14 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___297;

struct address_space___297 {
	struct inode___298 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___299 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___297 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___287)(struct vm_area_struct___299 *, long unsigned int, const struct page___299 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___287)(struct page___299 *, void *);

struct dev_pagemap___287 {
	dev_page_fault_t___287 page_fault;
	dev_page_free_t___287 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___263 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___298 {
	struct task_struct___299 *task;
	struct core_thread___298 *next;
};

struct core_state___298 {
	atomic_t nr_threads;
	struct core_thread___298 dumper;
	struct completion startup;
};

struct vm_fault___287 {
	struct vm_area_struct___299 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___299 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___299 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___298 prealloc_pte;
};

struct fwnode_reference_args___197;

struct fwnode_endpoint___197;

struct fwnode_operations___197 {
	struct fwnode_handle___197 * (*get)(struct fwnode_handle___197 *);
	void (*put)(struct fwnode_handle___197 *);
	bool (*device_is_available)(const struct fwnode_handle___197 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___197 *, const struct device___263 *);
	bool (*property_present)(const struct fwnode_handle___197 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___197 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___197 *, const char *, const char **, size_t);
	struct fwnode_handle___197 * (*get_parent)(const struct fwnode_handle___197 *);
	struct fwnode_handle___197 * (*get_next_child_node)(const struct fwnode_handle___197 *, struct fwnode_handle___197 *);
	struct fwnode_handle___197 * (*get_named_child_node)(const struct fwnode_handle___197 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___197 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___197 *);
	struct fwnode_handle___197 * (*graph_get_next_endpoint)(const struct fwnode_handle___197 *, struct fwnode_handle___197 *);
	struct fwnode_handle___197 * (*graph_get_remote_endpoint)(const struct fwnode_handle___197 *);
	struct fwnode_handle___197 * (*graph_get_port_parent)(struct fwnode_handle___197 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___197 *, struct fwnode_endpoint___197 *);
};

struct fwnode_endpoint___197 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___197 *local_fwnode;
};

struct fwnode_reference_args___197 {
	struct fwnode_handle___197 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pci_bus___23;

struct pci_slot___23 {
	struct pci_bus___23 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject___285 kobj;
};

struct pci_dev___23;

struct pci_ops___23;

struct msi_controller___9;

struct pci_bus___23 {
	struct list_head node;
	struct pci_bus___23 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___23 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___23 *ops;
	struct msi_controller___9 *msi;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	int domain_nr;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___263 *bridge;
	struct device___263 dev;
	struct bin_attribute___261 *legacy_io;
	struct bin_attribute___261 *legacy_mem;
	unsigned int is_added: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
};

struct pci_sriov___17 {
	int pos;
	int nres;
	u32 cap;
	u16 ctrl;
	u16 total_VFs;
	u16 initial_VFs;
	u16 num_VFs;
	u16 offset;
	u16 stride;
	u16 vf_device;
	u32 pgsz;
	u8 link;
	u8 max_VF_buses;
	u16 driver_max_VFs;
	struct pci_dev___23 *dev;
	struct pci_dev___23 *self;
	u32 class;
	u8 hdr_type;
	u16 subsystem_vendor;
	u16 subsystem_device;
	resource_size_t barsz[6];
	bool drivers_autoprobe;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct pci_driver___23;

struct pci_dev___23 {
	struct list_head bus_list;
	struct pci_bus___23 *bus;
	struct pci_bus___23 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___23 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u16 aer_cap;
	struct aer_stats *aer_stats;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	long unsigned int *dma_alias_mask;
	struct pci_driver___23 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	unsigned int imm_ready: 1;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int bridge_d3: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int hotplug_user_indicators: 1;
	unsigned int clear_retrain_link: 1;
	unsigned int d3_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	unsigned int ltr_path: 1;
	unsigned int eetlp_prefix_path: 1;
	pci_channel_state_t error_state;
	struct device___263 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int multifunction: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int ats_enabled: 1;
	unsigned int pasid_enabled: 1;
	unsigned int pri_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int reset_fn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int shpc_managed: 1;
	unsigned int is_thunderbolt: 1;
	unsigned int __aer_firmware_first_valid: 1;
	unsigned int __aer_firmware_first: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int irq_managed: 1;
	unsigned int has_secondary_link: 1;
	unsigned int non_compliant_bars: 1;
	unsigned int is_probed: 1;
	unsigned int link_active_reporting: 1;
	unsigned int untrusted: 1;
	unsigned int no_vf_scan: 1;
	unsigned int io_window: 1;
	unsigned int pref_window: 1;
	unsigned int pref_64_window: 1;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	struct bin_attribute___261 *rom_attr;
	int rom_attr_enabled;
	struct bin_attribute___261 *res_attr[17];
	struct bin_attribute___261 *res_attr_wc[17];
	unsigned int broken_cmd_compl: 1;
	const struct attribute_group___262 **msi_irq_groups;
	struct pci_vpd *vpd;
	union {
		struct pci_sriov___17 *sriov;
		struct pci_dev___23 *physfn;
	};
	u16 ats_cap;
	u8 ats_stu;
	atomic_t ats_ref_cnt;
	u32 pri_reqs_alloc;
	u16 pasid_features;
	struct pci_p2pdma *p2pdma;
	phys_addr_t rom;
	size_t romlen;
	char *driver_override;
	long unsigned int priv_flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t pci_dev_extended_size_rh;
	struct pci_dev_extended_rh pci_dev_extended_rh;
};

struct pci_error_handlers___23;

struct pci_driver___23 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___23 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___23 *);
	int (*suspend)(struct pci_dev___23 *, pm_message_t);
	int (*suspend_late)(struct pci_dev___23 *, pm_message_t);
	int (*resume_early)(struct pci_dev___23 *);
	int (*resume)(struct pci_dev___23 *);
	void (*shutdown)(struct pci_dev___23 *);
	int (*sriov_configure)(struct pci_dev___23 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	const struct pci_error_handlers___23 *err_handler;
	const struct attribute_group___262 **groups;
	struct device_driver___263 driver;
	struct pci_dynids dynids;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct pci_host_bridge___6 {
	struct device___263 dev;
	struct pci_bus___23 *bus;
	struct pci_ops___23 *ops;
	void *sysdata;
	int busnr;
	struct list_head windows;
	u8 (*swizzle_irq)(struct pci_dev___23 *, u8 *);
	int (*map_irq)(const struct pci_dev___23 *, u8, u8);
	void (*release_fn)(struct pci_host_bridge___6 *);
	void *release_data;
	struct msi_controller___9 *msi;
	unsigned int ignore_reset_delay: 1;
	unsigned int no_ext_tags: 1;
	unsigned int native_aer: 1;
	unsigned int native_pcie_hotplug: 1;
	unsigned int native_shpc_hotplug: 1;
	unsigned int native_pme: 1;
	unsigned int native_ltr: 1;
	resource_size_t (*align_resource)(struct pci_dev___23 *, const struct resource *, resource_size_t, resource_size_t, resource_size_t);
	long: 64;
	long unsigned int private[0];
};

struct pci_ops___23 {
	int (*add_bus)(struct pci_bus___23 *);
	void (*remove_bus)(struct pci_bus___23 *);
	void * (*map_bus)(struct pci_bus___23 *, unsigned int, int);
	int (*read)(struct pci_bus___23 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___23 *, unsigned int, int, int, u32);
};

struct msi_desc___13;

struct msi_controller___9 {
	struct module___240 *owner;
	struct device___263 *dev;
	struct device_node___55 *of_node;
	struct list_head list;
	int (*setup_irq)(struct msi_controller___9 *, struct pci_dev___23 *, struct msi_desc___13 *);
	int (*setup_irqs)(struct msi_controller___9 *, struct pci_dev___23 *, int, int);
	void (*teardown_irq)(struct msi_controller___9 *, unsigned int);
};

struct pci_error_handlers___23 {
	pci_ers_result_t (*error_detected)(struct pci_dev___23 *, enum pci_channel_state);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___23 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___23 *);
	void (*reset_prepare)(struct pci_dev___23 *);
	void (*reset_done)(struct pci_dev___23 *);
	void (*resume)(struct pci_dev___23 *);
};

struct dentry_operations___297;

struct super_block___297;

struct dentry___298 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___298 *d_parent;
	struct qstr d_name;
	struct inode___298 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___297 *d_op;
	struct super_block___297 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___297;

struct block_device___297;

struct inode___298 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___297 *i_op;
	struct super_block___297 *i_sb;
	struct address_space___297 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___299 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___298 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___297 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___297 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___297 {
	int (*d_revalidate)(struct dentry___298 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___298 *, unsigned int);
	int (*d_hash)(const struct dentry___298 *, struct qstr *);
	int (*d_compare)(const struct dentry___298 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___298 *);
	int (*d_init)(struct dentry___298 *);
	void (*d_release)(struct dentry___298 *);
	void (*d_prune)(struct dentry___298 *);
	void (*d_iput)(struct dentry___298 *, struct inode___298 *);
	char * (*d_dname)(struct dentry___298 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___298 *);
	int (*d_manage)(const struct path___298 *, bool);
	struct dentry___298 * (*d_real)(struct dentry___298 *, const struct inode___298 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___297;

struct mem_dqinfo___297 {
	struct quota_format_type___297 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___297;

struct quota_info___297 {
	unsigned int flags;
	struct rw_semaphore___299 dqio_sem;
	struct inode___298 *files[3];
	struct mem_dqinfo___297 info[3];
	const struct quota_format_ops___297 *ops[3];
};

struct rcuwait___297 {
	struct task_struct___299 *task;
};

struct percpu_rw_semaphore___297 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___299 rw_sem;
	struct rcuwait___297 writer;
	int readers_block;
};

struct sb_writers___297 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___297 rw_sem[3];
};

struct file_system_type___297;

struct super_operations___297;

struct dquot_operations___297;

struct quotactl_ops___297;

struct super_block___297 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___297 *s_type;
	const struct super_operations___297 *s_op;
	const struct dquot_operations___297 *dq_op;
	const struct quotactl_ops___297 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___298 *s_root;
	struct rw_semaphore___299 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___297 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___297 s_dquot;
	struct sb_writers___297 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___297 *s_d_op;
	int cleancache_poolid;
	struct shrinker___116 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___298 {
	struct file___298 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___298 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___297 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___298 *ia_file;
};

struct dquot___297 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___297 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___297 {
	int qf_fmt_id;
	const struct quota_format_ops___297 *qf_ops;
	struct module___240 *qf_owner;
	struct quota_format_type___297 *qf_next;
};

struct quota_format_ops___297 {
	int (*check_quota_file)(struct super_block___297 *, int);
	int (*read_file_info)(struct super_block___297 *, int);
	int (*write_file_info)(struct super_block___297 *, int);
	int (*free_file_info)(struct super_block___297 *, int);
	int (*read_dqblk)(struct dquot___297 *);
	int (*commit_dqblk)(struct dquot___297 *);
	int (*release_dqblk)(struct dquot___297 *);
	int (*get_next_id)(struct super_block___297 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___297 {
	int (*write_dquot)(struct dquot___297 *);
	struct dquot___297 * (*alloc_dquot)(struct super_block___297 *, int);
	void (*destroy_dquot)(struct dquot___297 *);
	int (*acquire_dquot)(struct dquot___297 *);
	int (*release_dquot)(struct dquot___297 *);
	int (*mark_dirty)(struct dquot___297 *);
	int (*write_info)(struct super_block___297 *, int);
	qsize_t * (*get_reserved_space)(struct inode___298 *);
	int (*get_projid)(struct inode___298 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___298 *, qsize_t *);
	int (*get_next_id)(struct super_block___297 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___297 {
	int (*quota_on)(struct super_block___297 *, int, int, const struct path___298 *);
	int (*quota_off)(struct super_block___297 *, int);
	int (*quota_enable)(struct super_block___297 *, unsigned int);
	int (*quota_disable)(struct super_block___297 *, unsigned int);
	int (*quota_sync)(struct super_block___297 *, int);
	int (*set_info)(struct super_block___297 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___297 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___297 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___297 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___297 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___297 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___297 {
	int (*writepage)(struct page___299 *, struct writeback_control___3 *);
	int (*readpage)(struct file___298 *, struct page___299 *);
	int (*writepages)(struct address_space___297 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___299 *);
	int (*readpages)(struct file___298 *, struct address_space___297 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___298 *, struct address_space___297 *, loff_t, unsigned int, unsigned int, struct page___299 **, void **);
	int (*write_end)(struct file___298 *, struct address_space___297 *, loff_t, unsigned int, unsigned int, struct page___299 *, void *);
	sector_t (*bmap)(struct address_space___297 *, sector_t);
	void (*invalidatepage)(struct page___299 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___299 *, gfp_t);
	void (*freepage)(struct page___299 *);
	ssize_t (*direct_IO)(struct kiocb___298 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___297 *, struct page___299 *, struct page___299 *, enum migrate_mode);
	bool (*isolate_page)(struct page___299 *, isolate_mode_t);
	void (*putback_page)(struct page___299 *);
	int (*launder_page)(struct page___299 *);
	int (*is_partially_uptodate)(struct page___299 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___299 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___297 *, struct page___299 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___298 *, sector_t *);
	void (*swap_deactivate)(struct file___298 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___297 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___298 *bd_inode;
	struct super_block___297 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___297 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___297 {
	struct dentry___298 * (*lookup)(struct inode___298 *, struct dentry___298 *, unsigned int);
	const char * (*get_link)(struct dentry___298 *, struct inode___298 *, struct delayed_call *);
	int (*permission)(struct inode___298 *, int);
	struct posix_acl * (*get_acl)(struct inode___298 *, int);
	int (*readlink)(struct dentry___298 *, char *, int);
	int (*create)(struct inode___298 *, struct dentry___298 *, umode_t, bool);
	int (*link)(struct dentry___298 *, struct inode___298 *, struct dentry___298 *);
	int (*unlink)(struct inode___298 *, struct dentry___298 *);
	int (*symlink)(struct inode___298 *, struct dentry___298 *, const char *);
	int (*mkdir)(struct inode___298 *, struct dentry___298 *, umode_t);
	int (*rmdir)(struct inode___298 *, struct dentry___298 *);
	int (*mknod)(struct inode___298 *, struct dentry___298 *, umode_t, dev_t);
	int (*rename)(struct inode___298 *, struct dentry___298 *, struct inode___298 *, struct dentry___298 *, unsigned int);
	int (*setattr)(struct dentry___298 *, struct iattr___297 *);
	int (*getattr)(const struct path___298 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___298 *, char *, size_t);
	int (*fiemap)(struct inode___298 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___298 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___298 *, struct dentry___298 *, struct file___298 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___298 *, struct dentry___298 *, umode_t);
	int (*set_acl)(struct inode___298 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___297 {
	void (*fl_copy_lock)(struct file_lock___298 *, struct file_lock___298 *);
	void (*fl_release_private)(struct file_lock___298 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___297;

struct lock_manager_operations___297;

struct file_lock___298 {
	struct file_lock___298 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___298 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___297 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___297 *fl_ops;
	const struct lock_manager_operations___297 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___297 {
	int (*lm_compare_owner)(struct file_lock___298 *, struct file_lock___298 *);
	long unsigned int (*lm_owner_key)(struct file_lock___298 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___298 *);
	int (*lm_grant)(struct file_lock___298 *, int);
	bool (*lm_break)(struct file_lock___298 *);
	int (*lm_change)(struct file_lock___298 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___298 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___297 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___297 *fa_next;
	struct file___298 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___297 {
	const char *name;
	int fs_flags;
	struct dentry___298 * (*mount)(struct file_system_type___297 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___297 *);
	struct module___240 *owner;
	struct file_system_type___297 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___297 {
	struct inode___298 * (*alloc_inode)(struct super_block___297 *);
	void (*destroy_inode)(struct inode___298 *);
	void (*dirty_inode)(struct inode___298 *, int);
	int (*write_inode)(struct inode___298 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___298 *);
	void (*evict_inode)(struct inode___298 *);
	void (*put_super)(struct super_block___297 *);
	int (*sync_fs)(struct super_block___297 *, int);
	int (*freeze_super)(struct super_block___297 *);
	int (*freeze_fs)(struct super_block___297 *);
	int (*thaw_super)(struct super_block___297 *);
	int (*unfreeze_fs)(struct super_block___297 *);
	int (*statfs)(struct dentry___298 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___297 *, int *, char *);
	void (*umount_begin)(struct super_block___297 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___298 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___298 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___298 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___298 *);
	ssize_t (*quota_read)(struct super_block___297 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___297 *, int, const char *, size_t, loff_t);
	struct dquot___297 ** (*get_dquots)(struct inode___298 *);
	int (*bdev_try_to_free_page)(struct super_block___297 *, struct page___299 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___297 *, struct shrink_control___116 *);
	long int (*free_cached_objects)(struct super_block___297 *, struct shrink_control___116 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___287(struct page___299 *);

struct kernel_param_ops___237 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___237 *);
	int (*get)(char *, const struct kernel_param___237 *);
	void (*free)(void *);
};

struct kparam_array___237;

struct kernel_param___237 {
	const char *name;
	struct module___240 *mod;
	const struct kernel_param_ops___237 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___237 *arr;
	};
};

struct kparam_array___237 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___237 *ops;
	void *elem;
};

struct module_attribute___237 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___237 *, struct module_kobject___237 *, char *);
	ssize_t (*store)(struct module_attribute___237 *, struct module_kobject___237 *, const char *, size_t);
	void (*setup)(struct module___240 *, const char *);
	int (*test)(struct module___240 *);
	void (*free)(struct module___240 *);
};

struct platform_device___9 {
	const char *name;
	int id;
	bool id_auto;
	struct device___263 dev;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct platform_driver___9 {
	int (*probe)(struct platform_device___9 *);
	int (*remove)(struct platform_device___9 *);
	void (*shutdown)(struct platform_device___9 *);
	int (*suspend)(struct platform_device___9 *, pm_message_t);
	int (*resume)(struct platform_device___9 *);
	struct device_driver___263 driver;
	const struct platform_device_id *id_table;
	bool prevent_deferred_probe;
};

struct property___52 {
	char *name;
	int length;
	void *value;
	struct property___52 *next;
	long unsigned int _flags;
	struct bin_attribute___261 attr;
};

struct msi_desc___13 {
	struct list_head list;
	unsigned int irq;
	unsigned int nvec_used;
	struct device___263 *dev;
	struct msi_msg msg;
	struct irq_affinity_desc *affinity;
	const void *iommu_cookie;
	union {
		struct {
			u32 masked;
			struct {
				u8 is_msix: 1;
				u8 multiple: 3;
				u8 multi_cap: 3;
				u8 maskbit: 1;
				u8 is_64: 1;
				u16 entry_nr;
				unsigned int default_irq;
			} msi_attrib;
			union {
				u8 mask_pos;
				void *mask_base;
			};
		};
		struct platform_msi_desc platform;
		struct fsl_mc_msi_desc fsl_mc;
	};
};

struct irq_desc___17;

typedef void (*irq_flow_handler_t___17)(struct irq_desc___17 *);

struct irq_common_data___10 {
	unsigned int state_use_accessors;
	unsigned int node;
	void *handler_data;
	struct msi_desc___13 *msi_desc;
	cpumask_var_t affinity;
	cpumask_var_t effective_affinity;
};

struct irq_chip___20;

struct irq_data___20 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___10 *common;
	struct irq_chip___20 *chip;
	struct irq_domain___14 *domain;
	struct irq_data___20 *parent_data;
	void *chip_data;
};

struct irq_desc___17 {
	struct irq_common_data___10 irq_common_data;
	struct irq_data___20 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___17 handle_irq;
	struct irqaction___14 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int irq_count;
	unsigned int tot_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___285 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___240 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip___20 {
	struct device___263 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___20 *);
	void (*irq_shutdown)(struct irq_data___20 *);
	void (*irq_enable)(struct irq_data___20 *);
	void (*irq_disable)(struct irq_data___20 *);
	void (*irq_ack)(struct irq_data___20 *);
	void (*irq_mask)(struct irq_data___20 *);
	void (*irq_mask_ack)(struct irq_data___20 *);
	void (*irq_unmask)(struct irq_data___20 *);
	void (*irq_eoi)(struct irq_data___20 *);
	int (*irq_set_affinity)(struct irq_data___20 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___20 *);
	int (*irq_set_type)(struct irq_data___20 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___20 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___20 *);
	void (*irq_bus_sync_unlock)(struct irq_data___20 *);
	void (*irq_cpu_online)(struct irq_data___20 *);
	void (*irq_cpu_offline)(struct irq_data___20 *);
	void (*irq_suspend)(struct irq_data___20 *);
	void (*irq_resume)(struct irq_data___20 *);
	void (*irq_pm_shutdown)(struct irq_data___20 *);
	void (*irq_calc_mask)(struct irq_data___20 *);
	void (*irq_print_chip)(struct irq_data___20 *, struct seq_file___9 *);
	int (*irq_request_resources)(struct irq_data___20 *);
	void (*irq_release_resources)(struct irq_data___20 *);
	void (*irq_compose_msi_msg)(struct irq_data___20 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___20 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___20 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___20 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___20 *, void *);
	void (*ipi_send_single)(struct irq_data___20 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___20 *, const struct cpumask *);
	long unsigned int flags;
};

struct irq_chip_type___13 {
	struct irq_chip___20 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___17 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___13 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___13 *);
	void (*resume)(struct irq_chip_generic___13 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___14 *domain;
	struct list_head list;
	struct irq_chip_type___13 chip_types[0];
};

struct irq_domain_chip_generic___12 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___13 *gc[0];
};

struct irq_fwspec___14 {
	struct fwnode_handle___197 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___14 {
	int (*match)(struct irq_domain___14 *, struct device_node___55 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___14 *, struct irq_fwspec___14 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___14 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___14 *, unsigned int);
	int (*xlate)(struct irq_domain___14 *, struct device_node___55 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___14 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___14 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___14 *, struct irq_data___20 *, bool);
	void (*deactivate)(struct irq_domain___14 *, struct irq_data___20 *);
	int (*translate)(struct irq_domain___14 *, struct irq_fwspec___14 *, long unsigned int *, unsigned int *);
};

struct node___181 {
	struct device___263 dev;
};

struct phy___5;

struct phy_ops___4 {
	int (*init)(struct phy___5 *);
	int (*exit)(struct phy___5 *);
	int (*power_on)(struct phy___5 *);
	int (*power_off)(struct phy___5 *);
	int (*set_mode)(struct phy___5 *, enum phy_mode);
	int (*reset)(struct phy___5 *);
	int (*calibrate)(struct phy___5 *);
	struct module___240 *owner;
};

struct phy___5 {
	struct device___263 dev;
	int id;
	const struct phy_ops___4 *ops;
	struct mutex mutex;
	int init_count;
	int power_count;
	struct phy_attrs attrs;
	struct regulator *pwr;
};

struct iproc_pcie___3 {
	struct device___263 *dev;
	enum iproc_pcie_type type;
	u16 *reg_offsets;
	void *base;
	phys_addr_t base_addr;
	struct resource mem;
	struct pci_bus___23 *root_bus;
	struct phy___5 *phy;
	int (*map_irq)(const struct pci_dev___23 *, u8, u8);
	bool ep_is_internal;
	bool iproc_cfg_read;
	bool rej_unconfig_pf;
	bool has_apb_err_disable;
	bool fix_paxc_cap;
	bool need_ob_cfg;
	struct iproc_pcie_ob ob;
	const struct iproc_pcie_ob_map___2 *ob_map;
	bool need_ib_cfg;
	struct iproc_pcie_ib ib;
	const struct iproc_pcie_ib_map___2 *ib_map;
	bool need_msi_steer;
	struct iproc_msi *msi;
};

enum pci_interrupt_pin {
	PCI_INTERRUPT_UNKNOWN = 0,
	PCI_INTERRUPT_INTA = 1,
	PCI_INTERRUPT_INTB = 2,
	PCI_INTERRUPT_INTC = 3,
	PCI_INTERRUPT_INTD = 4,
};

enum pci_barno {
	BAR_0 = 0,
	BAR_1 = 1,
	BAR_2 = 2,
	BAR_3 = 3,
	BAR_4 = 4,
	BAR_5 = 5,
};

struct pci_epf_header {
	u16 vendorid;
	u16 deviceid;
	u8 revid;
	u8 progif_code;
	u8 subclass_code;
	u8 baseclass_code;
	u8 cache_line_size;
	u16 subsys_vendor_id;
	u16 subsys_id;
	enum pci_interrupt_pin interrupt_pin;
};

struct pci_epf_bar {
	dma_addr_t phys_addr;
	size_t size;
	enum pci_barno barno;
	int flags;
};

struct config_group___4;

struct pci_epc_ops;

struct pci_epc_mem;

struct pci_epc {
	struct device___263 dev;
	struct list_head pci_epf;
	const struct pci_epc_ops *ops;
	struct pci_epc_mem *mem;
	u8 max_functions;
	struct config_group___4 *group;
	spinlock_t lock;
	unsigned int features;
};

enum pci_epc_irq_type {
	PCI_EPC_IRQ_UNKNOWN = 0,
	PCI_EPC_IRQ_LEGACY = 1,
	PCI_EPC_IRQ_MSI = 2,
	PCI_EPC_IRQ_MSIX = 3,
};

struct pci_epc_ops {
	int (*write_header)(struct pci_epc *, u8, struct pci_epf_header *);
	int (*set_bar)(struct pci_epc *, u8, struct pci_epf_bar *);
	void (*clear_bar)(struct pci_epc *, u8, struct pci_epf_bar *);
	int (*map_addr)(struct pci_epc *, u8, phys_addr_t, u64, size_t);
	void (*unmap_addr)(struct pci_epc *, u8, phys_addr_t);
	int (*set_msi)(struct pci_epc *, u8, u8);
	int (*get_msi)(struct pci_epc *, u8);
	int (*set_msix)(struct pci_epc *, u8, u16);
	int (*get_msix)(struct pci_epc *, u8);
	int (*raise_irq)(struct pci_epc *, u8, enum pci_epc_irq_type, u16);
	int (*start)(struct pci_epc *);
	void (*stop)(struct pci_epc *);
	struct module___11 *owner;
};

struct pci_epc_mem {
	phys_addr_t phys_base;
	size_t size;
	long unsigned int *bitmap;
	size_t page_size;
	int pages;
};

enum dw_pcie_region_type {
	DW_PCIE_REGION_UNKNOWN = 0,
	DW_PCIE_REGION_INBOUND = 1,
	DW_PCIE_REGION_OUTBOUND = 2,
};

struct pcie_port;

struct dw_pcie_host_ops {
	int (*rd_own_conf)(struct pcie_port *, int, int, u32 *);
	int (*wr_own_conf)(struct pcie_port *, int, int, u32);
	int (*rd_other_conf)(struct pcie_port *, struct pci_bus___23 *, unsigned int, int, int, u32 *);
	int (*wr_other_conf)(struct pcie_port *, struct pci_bus___23 *, unsigned int, int, int, u32);
	int (*host_init)(struct pcie_port *);
	void (*msi_set_irq)(struct pcie_port *, int);
	void (*msi_clear_irq)(struct pcie_port *, int);
	phys_addr_t (*get_msi_addr)(struct pcie_port *);
	u32 (*get_msi_data)(struct pcie_port *, int);
	void (*scan_bus)(struct pcie_port *);
	void (*set_num_vectors)(struct pcie_port *);
	int (*msi_host_init)(struct pcie_port *);
	void (*msi_irq_ack)(int, struct pcie_port *);
};

struct pcie_port {
	u8 root_bus_nr;
	u64 cfg0_base;
	void *va_cfg0_base;
	u32 cfg0_size;
	u64 cfg1_base;
	void *va_cfg1_base;
	u32 cfg1_size;
	resource_size_t io_base;
	phys_addr_t io_bus_addr;
	u32 io_size;
	u64 mem_base;
	phys_addr_t mem_bus_addr;
	u32 mem_size;
	struct resource *cfg;
	struct resource *io;
	struct resource *mem;
	struct resource *busn;
	int irq;
	const struct dw_pcie_host_ops *ops;
	int msi_irq;
	struct irq_domain *irq_domain;
	struct irq_domain *msi_domain;
	dma_addr_t msi_data;
	u32 num_vectors;
	u32 irq_status[8];
	raw_spinlock_t lock;
	long unsigned int msi_irq_in_use[4];
};

enum dw_pcie_as_type {
	DW_PCIE_AS_UNKNOWN = 0,
	DW_PCIE_AS_MEM = 1,
	DW_PCIE_AS_IO = 2,
};

struct dw_pcie_ep;

struct dw_pcie_ep_ops {
	void (*ep_init)(struct dw_pcie_ep *);
	int (*raise_irq)(struct dw_pcie_ep *, u8, enum pci_epc_irq_type, u16);
};

struct dw_pcie_ep {
	struct pci_epc *epc;
	struct dw_pcie_ep_ops *ops;
	phys_addr_t phys_base;
	size_t addr_size;
	size_t page_size;
	u8 bar_to_atu[6];
	phys_addr_t *outbound_addr;
	long unsigned int *ib_window_map;
	long unsigned int *ob_window_map;
	u32 num_ib_windows;
	u32 num_ob_windows;
	void *msi_mem;
	phys_addr_t msi_mem_phys;
	u8 msi_cap;
	u8 msix_cap;
};

struct dw_pcie;

struct dw_pcie_ops {
	u64 (*cpu_addr_fixup)(struct dw_pcie *, u64);
	u32 (*read_dbi)(struct dw_pcie *, void *, u32, size_t);
	void (*write_dbi)(struct dw_pcie *, void *, u32, size_t, u32);
	int (*link_up)(struct dw_pcie *);
	int (*start_link)(struct dw_pcie *);
	void (*stop_link)(struct dw_pcie *);
};

struct dw_pcie {
	struct device___263 *dev;
	void *dbi_base;
	void *dbi_base2;
	u32 num_viewport;
	u8 iatu_unroll_enabled;
	struct pcie_port pp;
	struct dw_pcie_ep ep;
	const struct dw_pcie_ops *ops;
};

struct pci_bus___24;

struct pci_slot___24 {
	struct pci_bus___24 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject___284 kobj;
};

struct pci_dev___24;

struct pci_ops___24;

struct msi_controller___10;

struct pci_bus___24 {
	struct list_head node;
	struct pci_bus___24 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___24 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___24 *ops;
	struct msi_controller___10 *msi;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	int domain_nr;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___262 *bridge;
	struct device___262 dev;
	struct bin_attribute___260 *legacy_io;
	struct bin_attribute___260 *legacy_mem;
	unsigned int is_added: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
};

struct pci_sriov___18 {
	int pos;
	int nres;
	u32 cap;
	u16 ctrl;
	u16 total_VFs;
	u16 initial_VFs;
	u16 num_VFs;
	u16 offset;
	u16 stride;
	u16 vf_device;
	u32 pgsz;
	u8 link;
	u8 max_VF_buses;
	u16 driver_max_VFs;
	struct pci_dev___24 *dev;
	struct pci_dev___24 *self;
	u32 class;
	u8 hdr_type;
	u16 subsystem_vendor;
	u16 subsystem_device;
	resource_size_t barsz[6];
	bool drivers_autoprobe;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct pci_driver___24;

struct pci_dev___24 {
	struct list_head bus_list;
	struct pci_bus___24 *bus;
	struct pci_bus___24 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___24 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u16 aer_cap;
	struct aer_stats *aer_stats;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	long unsigned int *dma_alias_mask;
	struct pci_driver___24 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	unsigned int imm_ready: 1;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int bridge_d3: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int hotplug_user_indicators: 1;
	unsigned int clear_retrain_link: 1;
	unsigned int d3_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	unsigned int ltr_path: 1;
	unsigned int eetlp_prefix_path: 1;
	pci_channel_state_t error_state;
	struct device___262 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int multifunction: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int ats_enabled: 1;
	unsigned int pasid_enabled: 1;
	unsigned int pri_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int reset_fn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int shpc_managed: 1;
	unsigned int is_thunderbolt: 1;
	unsigned int __aer_firmware_first_valid: 1;
	unsigned int __aer_firmware_first: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int irq_managed: 1;
	unsigned int has_secondary_link: 1;
	unsigned int non_compliant_bars: 1;
	unsigned int is_probed: 1;
	unsigned int link_active_reporting: 1;
	unsigned int untrusted: 1;
	unsigned int no_vf_scan: 1;
	unsigned int io_window: 1;
	unsigned int pref_window: 1;
	unsigned int pref_64_window: 1;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	struct bin_attribute___260 *rom_attr;
	int rom_attr_enabled;
	struct bin_attribute___260 *res_attr[17];
	struct bin_attribute___260 *res_attr_wc[17];
	unsigned int broken_cmd_compl: 1;
	const struct attribute_group___261 **msi_irq_groups;
	struct pci_vpd *vpd;
	union {
		struct pci_sriov___18 *sriov;
		struct pci_dev___24 *physfn;
	};
	u16 ats_cap;
	u8 ats_stu;
	atomic_t ats_ref_cnt;
	u32 pri_reqs_alloc;
	u16 pasid_features;
	struct pci_p2pdma *p2pdma;
	phys_addr_t rom;
	size_t romlen;
	char *driver_override;
	long unsigned int priv_flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t pci_dev_extended_size_rh;
	struct pci_dev_extended_rh pci_dev_extended_rh;
};

struct pci_error_handlers___24;

struct pci_driver___24 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___24 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___24 *);
	int (*suspend)(struct pci_dev___24 *, pm_message_t);
	int (*suspend_late)(struct pci_dev___24 *, pm_message_t);
	int (*resume_early)(struct pci_dev___24 *);
	int (*resume)(struct pci_dev___24 *);
	void (*shutdown)(struct pci_dev___24 *);
	int (*sriov_configure)(struct pci_dev___24 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	const struct pci_error_handlers___24 *err_handler;
	const struct attribute_group___261 **groups;
	struct device_driver___262 driver;
	struct pci_dynids dynids;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct pci_host_bridge___7 {
	struct device___262 dev;
	struct pci_bus___24 *bus;
	struct pci_ops___24 *ops;
	void *sysdata;
	int busnr;
	struct list_head windows;
	u8 (*swizzle_irq)(struct pci_dev___24 *, u8 *);
	int (*map_irq)(const struct pci_dev___24 *, u8, u8);
	void (*release_fn)(struct pci_host_bridge___7 *);
	void *release_data;
	struct msi_controller___10 *msi;
	unsigned int ignore_reset_delay: 1;
	unsigned int no_ext_tags: 1;
	unsigned int native_aer: 1;
	unsigned int native_pcie_hotplug: 1;
	unsigned int native_shpc_hotplug: 1;
	unsigned int native_pme: 1;
	unsigned int native_ltr: 1;
	resource_size_t (*align_resource)(struct pci_dev___24 *, const struct resource *, resource_size_t, resource_size_t, resource_size_t);
	long: 64;
	long unsigned int private[0];
};

struct pci_ops___24 {
	int (*add_bus)(struct pci_bus___24 *);
	void (*remove_bus)(struct pci_bus___24 *);
	void * (*map_bus)(struct pci_bus___24 *, unsigned int, int);
	int (*read)(struct pci_bus___24 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___24 *, unsigned int, int, int, u32);
};

struct msi_controller___10 {
	struct module___11 *owner;
	struct device___262 *dev;
	struct device_node___54 *of_node;
	struct list_head list;
	int (*setup_irq)(struct msi_controller___10 *, struct pci_dev___24 *, struct msi_desc___12 *);
	int (*setup_irqs)(struct msi_controller___10 *, struct pci_dev___24 *, int, int);
	void (*teardown_irq)(struct msi_controller___10 *, unsigned int);
};

struct pci_error_handlers___24 {
	pci_ers_result_t (*error_detected)(struct pci_dev___24 *, enum pci_channel_state);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___24 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___24 *);
	void (*reset_prepare)(struct pci_dev___24 *);
	void (*reset_done)(struct pci_dev___24 *);
	void (*resume)(struct pci_dev___24 *);
};

struct platform_device___10 {
	const char *name;
	int id;
	bool id_auto;
	struct device___262 dev;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct pci_epc_ops___2;

struct pci_epc___2 {
	struct device___262 dev;
	struct list_head pci_epf;
	const struct pci_epc_ops___2 *ops;
	struct pci_epc_mem *mem;
	u8 max_functions;
	struct config_group___4 *group;
	spinlock_t lock;
	unsigned int features;
};

struct pci_epc_ops___2 {
	int (*write_header)(struct pci_epc___2 *, u8, struct pci_epf_header *);
	int (*set_bar)(struct pci_epc___2 *, u8, struct pci_epf_bar *);
	void (*clear_bar)(struct pci_epc___2 *, u8, struct pci_epf_bar *);
	int (*map_addr)(struct pci_epc___2 *, u8, phys_addr_t, u64, size_t);
	void (*unmap_addr)(struct pci_epc___2 *, u8, phys_addr_t);
	int (*set_msi)(struct pci_epc___2 *, u8, u8);
	int (*get_msi)(struct pci_epc___2 *, u8);
	int (*set_msix)(struct pci_epc___2 *, u8, u16);
	int (*get_msix)(struct pci_epc___2 *, u8);
	int (*raise_irq)(struct pci_epc___2 *, u8, enum pci_epc_irq_type, u16);
	int (*start)(struct pci_epc___2 *);
	void (*stop)(struct pci_epc___2 *);
	struct module___11 *owner;
};

struct pcie_port___2;

struct dw_pcie_host_ops___2 {
	int (*rd_own_conf)(struct pcie_port___2 *, int, int, u32 *);
	int (*wr_own_conf)(struct pcie_port___2 *, int, int, u32);
	int (*rd_other_conf)(struct pcie_port___2 *, struct pci_bus___24 *, unsigned int, int, int, u32 *);
	int (*wr_other_conf)(struct pcie_port___2 *, struct pci_bus___24 *, unsigned int, int, int, u32);
	int (*host_init)(struct pcie_port___2 *);
	void (*msi_set_irq)(struct pcie_port___2 *, int);
	void (*msi_clear_irq)(struct pcie_port___2 *, int);
	phys_addr_t (*get_msi_addr)(struct pcie_port___2 *);
	u32 (*get_msi_data)(struct pcie_port___2 *, int);
	void (*scan_bus)(struct pcie_port___2 *);
	void (*set_num_vectors)(struct pcie_port___2 *);
	int (*msi_host_init)(struct pcie_port___2 *);
	void (*msi_irq_ack)(int, struct pcie_port___2 *);
};

struct pcie_port___2 {
	u8 root_bus_nr;
	u64 cfg0_base;
	void *va_cfg0_base;
	u32 cfg0_size;
	u64 cfg1_base;
	void *va_cfg1_base;
	u32 cfg1_size;
	resource_size_t io_base;
	phys_addr_t io_bus_addr;
	u32 io_size;
	u64 mem_base;
	phys_addr_t mem_bus_addr;
	u32 mem_size;
	struct resource *cfg;
	struct resource *io;
	struct resource *mem;
	struct resource *busn;
	int irq;
	const struct dw_pcie_host_ops___2 *ops;
	int msi_irq;
	struct irq_domain___13 *irq_domain;
	struct irq_domain___13 *msi_domain;
	dma_addr_t msi_data;
	u32 num_vectors;
	u32 irq_status[8];
	raw_spinlock_t lock;
	long unsigned int msi_irq_in_use[4];
};

struct dw_pcie_ep___2;

struct dw_pcie_ep_ops___2 {
	void (*ep_init)(struct dw_pcie_ep___2 *);
	int (*raise_irq)(struct dw_pcie_ep___2 *, u8, enum pci_epc_irq_type, u16);
};

struct dw_pcie_ep___2 {
	struct pci_epc___2 *epc;
	struct dw_pcie_ep_ops___2 *ops;
	phys_addr_t phys_base;
	size_t addr_size;
	size_t page_size;
	u8 bar_to_atu[6];
	phys_addr_t *outbound_addr;
	long unsigned int *ib_window_map;
	long unsigned int *ob_window_map;
	u32 num_ib_windows;
	u32 num_ob_windows;
	void *msi_mem;
	phys_addr_t msi_mem_phys;
	u8 msi_cap;
	u8 msix_cap;
};

struct dw_pcie___2;

struct dw_pcie_ops___2 {
	u64 (*cpu_addr_fixup)(struct dw_pcie___2 *, u64);
	u32 (*read_dbi)(struct dw_pcie___2 *, void *, u32, size_t);
	void (*write_dbi)(struct dw_pcie___2 *, void *, u32, size_t, u32);
	int (*link_up)(struct dw_pcie___2 *);
	int (*start_link)(struct dw_pcie___2 *);
	void (*stop_link)(struct dw_pcie___2 *);
};

struct dw_pcie___2 {
	struct device___262 *dev;
	void *dbi_base;
	void *dbi_base2;
	u32 num_viewport;
	u8 iatu_unroll_enabled;
	struct pcie_port___2 pp;
	struct dw_pcie_ep___2 ep;
	const struct dw_pcie_ops___2 *ops;
};

struct irq_common_data___11;

struct irq_chip___21;

struct irq_data___21 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___11 *common;
	struct irq_chip___21 *chip;
	struct irq_domain *domain;
	struct irq_data___21 *parent_data;
	void *chip_data;
};

struct irq_chip___21 {
	struct device___260 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___21 *);
	void (*irq_shutdown)(struct irq_data___21 *);
	void (*irq_enable)(struct irq_data___21 *);
	void (*irq_disable)(struct irq_data___21 *);
	void (*irq_ack)(struct irq_data___21 *);
	void (*irq_mask)(struct irq_data___21 *);
	void (*irq_mask_ack)(struct irq_data___21 *);
	void (*irq_unmask)(struct irq_data___21 *);
	void (*irq_eoi)(struct irq_data___21 *);
	int (*irq_set_affinity)(struct irq_data___21 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___21 *);
	int (*irq_set_type)(struct irq_data___21 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___21 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___21 *);
	void (*irq_bus_sync_unlock)(struct irq_data___21 *);
	void (*irq_cpu_online)(struct irq_data___21 *);
	void (*irq_cpu_offline)(struct irq_data___21 *);
	void (*irq_suspend)(struct irq_data___21 *);
	void (*irq_resume)(struct irq_data___21 *);
	void (*irq_pm_shutdown)(struct irq_data___21 *);
	void (*irq_calc_mask)(struct irq_data___21 *);
	void (*irq_print_chip)(struct irq_data___21 *, struct seq_file___253 *);
	int (*irq_request_resources)(struct irq_data___21 *);
	void (*irq_release_resources)(struct irq_data___21 *);
	void (*irq_compose_msi_msg)(struct irq_data___21 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___21 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___21 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___21 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___21 *, void *);
	void (*ipi_send_single)(struct irq_data___21 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___21 *, const struct cpumask *);
	long unsigned int flags;
};

struct irq_common_data___11 {
	unsigned int state_use_accessors;
	unsigned int node;
	void *handler_data;
	struct msi_desc___11 *msi_desc;
	cpumask_var_t affinity;
	cpumask_var_t effective_affinity;
};

struct pci_epc_ops___3;

struct pci_epc___3 {
	struct device___260 dev;
	struct list_head pci_epf;
	const struct pci_epc_ops___3 *ops;
	struct pci_epc_mem *mem;
	u8 max_functions;
	struct config_group___4 *group;
	spinlock_t lock;
	unsigned int features;
};

struct pci_epc_ops___3 {
	int (*write_header)(struct pci_epc___3 *, u8, struct pci_epf_header *);
	int (*set_bar)(struct pci_epc___3 *, u8, struct pci_epf_bar *);
	void (*clear_bar)(struct pci_epc___3 *, u8, struct pci_epf_bar *);
	int (*map_addr)(struct pci_epc___3 *, u8, phys_addr_t, u64, size_t);
	void (*unmap_addr)(struct pci_epc___3 *, u8, phys_addr_t);
	int (*set_msi)(struct pci_epc___3 *, u8, u8);
	int (*get_msi)(struct pci_epc___3 *, u8);
	int (*set_msix)(struct pci_epc___3 *, u8, u16);
	int (*get_msix)(struct pci_epc___3 *, u8);
	int (*raise_irq)(struct pci_epc___3 *, u8, enum pci_epc_irq_type, u16);
	int (*start)(struct pci_epc___3 *);
	void (*stop)(struct pci_epc___3 *);
	struct module___238 *owner;
};

struct pcie_port___3;

struct dw_pcie_host_ops___3 {
	int (*rd_own_conf)(struct pcie_port___3 *, int, int, u32 *);
	int (*wr_own_conf)(struct pcie_port___3 *, int, int, u32);
	int (*rd_other_conf)(struct pcie_port___3 *, struct pci_bus___20 *, unsigned int, int, int, u32 *);
	int (*wr_other_conf)(struct pcie_port___3 *, struct pci_bus___20 *, unsigned int, int, int, u32);
	int (*host_init)(struct pcie_port___3 *);
	void (*msi_set_irq)(struct pcie_port___3 *, int);
	void (*msi_clear_irq)(struct pcie_port___3 *, int);
	phys_addr_t (*get_msi_addr)(struct pcie_port___3 *);
	u32 (*get_msi_data)(struct pcie_port___3 *, int);
	void (*scan_bus)(struct pcie_port___3 *);
	void (*set_num_vectors)(struct pcie_port___3 *);
	int (*msi_host_init)(struct pcie_port___3 *);
	void (*msi_irq_ack)(int, struct pcie_port___3 *);
};

struct pcie_port___3 {
	u8 root_bus_nr;
	u64 cfg0_base;
	void *va_cfg0_base;
	u32 cfg0_size;
	u64 cfg1_base;
	void *va_cfg1_base;
	u32 cfg1_size;
	resource_size_t io_base;
	phys_addr_t io_bus_addr;
	u32 io_size;
	u64 mem_base;
	phys_addr_t mem_bus_addr;
	u32 mem_size;
	struct resource *cfg;
	struct resource *io;
	struct resource *mem;
	struct resource *busn;
	int irq;
	const struct dw_pcie_host_ops___3 *ops;
	int msi_irq;
	struct irq_domain *irq_domain;
	struct irq_domain *msi_domain;
	dma_addr_t msi_data;
	u32 num_vectors;
	u32 irq_status[8];
	raw_spinlock_t lock;
	long unsigned int msi_irq_in_use[4];
};

struct dw_pcie_ep___3;

struct dw_pcie_ep_ops___3 {
	void (*ep_init)(struct dw_pcie_ep___3 *);
	int (*raise_irq)(struct dw_pcie_ep___3 *, u8, enum pci_epc_irq_type, u16);
};

struct dw_pcie_ep___3 {
	struct pci_epc___3 *epc;
	struct dw_pcie_ep_ops___3 *ops;
	phys_addr_t phys_base;
	size_t addr_size;
	size_t page_size;
	u8 bar_to_atu[6];
	phys_addr_t *outbound_addr;
	long unsigned int *ib_window_map;
	long unsigned int *ob_window_map;
	u32 num_ib_windows;
	u32 num_ob_windows;
	void *msi_mem;
	phys_addr_t msi_mem_phys;
	u8 msi_cap;
	u8 msix_cap;
};

struct dw_pcie___3;

struct dw_pcie_ops___3 {
	u64 (*cpu_addr_fixup)(struct dw_pcie___3 *, u64);
	u32 (*read_dbi)(struct dw_pcie___3 *, void *, u32, size_t);
	void (*write_dbi)(struct dw_pcie___3 *, void *, u32, size_t, u32);
	int (*link_up)(struct dw_pcie___3 *);
	int (*start_link)(struct dw_pcie___3 *);
	void (*stop_link)(struct dw_pcie___3 *);
};

struct dw_pcie___3 {
	struct device___260 *dev;
	void *dbi_base;
	void *dbi_base2;
	u32 num_viewport;
	u8 iatu_unroll_enabled;
	struct pcie_port___3 pp;
	struct dw_pcie_ep___3 ep;
	const struct dw_pcie_ops___3 *ops;
};

struct hisi_pcie;

struct pcie_soc_ops {
	int (*hisi_pcie_link_up)(struct hisi_pcie *);
};

struct hisi_pcie {
	struct dw_pcie___3 *pci;
	struct regmap *subctrl;
	u32 port_id;
	const struct pcie_soc_ops *soc_ops;
};

struct thunder_pem_pci {
	u32 ea_entry[3];
	void *pem_reg_base;
};

struct of_pci_range_parser___3 {
	struct device_node___52 *node;
	const __be32 *range;
	const __be32 *end;
	int np;
	int pna;
};

struct pci_host_bridge___8 {
	struct device___259 dev;
	struct pci_bus___19 *bus;
	struct pci_ops___19 *ops;
	void *sysdata;
	int busnr;
	struct list_head windows;
	u8 (*swizzle_irq)(struct pci_dev___19 *, u8 *);
	int (*map_irq)(const struct pci_dev___19 *, u8, u8);
	void (*release_fn)(struct pci_host_bridge___8 *);
	void *release_data;
	struct msi_controller___6 *msi;
	unsigned int ignore_reset_delay: 1;
	unsigned int no_ext_tags: 1;
	unsigned int native_aer: 1;
	unsigned int native_pcie_hotplug: 1;
	unsigned int native_shpc_hotplug: 1;
	unsigned int native_pme: 1;
	unsigned int native_ltr: 1;
	resource_size_t (*align_resource)(struct pci_dev___19 *, const struct resource *, resource_size_t, resource_size_t, resource_size_t);
	long: 64;
	long unsigned int private[0];
};

struct acpi_device___7;

struct acpi_hotplug_profile___7 {
	struct kobject___281 kobj;
	int (*scan_dependent)(struct acpi_device___7 *);
	void (*notify_online)(struct acpi_device___7 *);
	bool enabled: 1;
	bool demand_offline: 1;
};

struct acpi_device_wakeup_context___7 {
	void (*func)(struct acpi_device_wakeup_context___7 *);
	struct device___259 *dev;
};

struct acpi_device_wakeup___7 {
	acpi_handle gpe_device;
	u64 gpe_number;
	u64 sleep_state;
	struct list_head resources;
	struct acpi_device_wakeup_flags flags;
	struct acpi_device_wakeup_context___7 context;
	struct wakeup_source *ws;
	int prepare_count;
	int enable_count;
};

struct acpi_scan_handler___7;

struct acpi_hotplug_context___7;

struct acpi_driver___7;

struct acpi_device___7 {
	int device_type;
	acpi_handle handle;
	struct fwnode_handle___193 fwnode;
	struct acpi_device___7 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup___7 wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_device_data data;
	struct acpi_scan_handler___7 *handler;
	struct acpi_hotplug_context___7 *hp;
	struct acpi_driver___7 *driver;
	const struct acpi_gpio_mapping *driver_gpios;
	void *driver_data;
	struct device___259 dev;
	unsigned int physical_node_count;
	unsigned int dep_unmet;
	struct list_head physical_node_list;
	struct mutex physical_node_lock;
	void (*remove)(struct acpi_device___7 *);
};

struct acpi_scan_handler___7 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	bool (*match)(const char *, const struct acpi_device_id **);
	int (*attach)(struct acpi_device___7 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___7 *);
	void (*bind)(struct device___259 *);
	void (*unbind)(struct device___259 *);
	struct acpi_hotplug_profile___7 hotplug;
};

struct acpi_hotplug_context___7 {
	struct acpi_device___7 *self;
	int (*notify)(struct acpi_device___7 *, u32);
	void (*uevent)(struct acpi_device___7 *, u32);
	void (*fixup)(struct acpi_device___7 *);
};

typedef int (*acpi_op_add___7)(struct acpi_device___7 *);

typedef int (*acpi_op_remove___7)(struct acpi_device___7 *);

typedef void (*acpi_op_notify___7)(struct acpi_device___7 *, u32);

struct acpi_device_ops___7 {
	acpi_op_add___7 add;
	acpi_op_remove___7 remove;
	acpi_op_notify___7 notify;
};

struct acpi_driver___7 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___7 ops;
	struct device_driver___259 drv;
	struct module___237 *owner;
};

struct platform_device___11 {
	const char *name;
	int id;
	bool id_auto;
	struct device___259 dev;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct platform_driver___10 {
	int (*probe)(struct platform_device___11 *);
	int (*remove)(struct platform_device___11 *);
	void (*shutdown)(struct platform_device___11 *);
	int (*suspend)(struct platform_device___11 *, pm_message_t);
	int (*resume)(struct platform_device___11 *);
	struct device_driver___259 driver;
	const struct platform_device_id *id_table;
	bool prevent_deferred_probe;
};

struct pci_config_window___4;

struct pci_ecam_ops___4 {
	unsigned int bus_shift;
	struct pci_ops___19 pci_ops;
	int (*init)(struct pci_config_window___4 *);
};

struct pci_config_window___4 {
	struct resource res;
	struct resource busr;
	void *priv;
	struct pci_ecam_ops___4 *ops;
	union {
		void *win;
		void **winp;
	};
	struct device___259 *parent;
};

struct xgene_pcie_port {
	struct device_node___52 *node;
	struct device___259 *dev;
	struct clk *clk;
	void *csr_base;
	void *cfg_base;
	long unsigned int cfg_addr;
	bool link_up;
	u32 version;
};

struct iproc_pcie___4 {
	struct device___260 *dev;
	enum iproc_pcie_type type;
	u16 *reg_offsets;
	void *base;
	phys_addr_t base_addr;
	struct resource mem;
	struct pci_bus___20 *root_bus;
	struct phy___4 *phy;
	int (*map_irq)(const struct pci_dev___20 *, u8, u8);
	bool ep_is_internal;
	bool iproc_cfg_read;
	bool rej_unconfig_pf;
	bool has_apb_err_disable;
	bool fix_paxc_cap;
	bool need_ob_cfg;
	struct iproc_pcie_ob ob;
	const struct iproc_pcie_ob_map___2 *ob_map;
	bool need_ib_cfg;
	struct iproc_pcie_ib ib;
	const struct iproc_pcie_ib_map___2 *ib_map;
	bool need_msi_steer;
	struct iproc_msi *msi;
};

enum hdmi_infoframe_type {
	HDMI_INFOFRAME_TYPE_VENDOR = 129,
	HDMI_INFOFRAME_TYPE_AVI = 130,
	HDMI_INFOFRAME_TYPE_SPD = 131,
	HDMI_INFOFRAME_TYPE_AUDIO = 132,
};

struct hdmi_any_infoframe {
	enum hdmi_infoframe_type type;
	unsigned char version;
	unsigned char length;
};

enum hdmi_colorspace {
	HDMI_COLORSPACE_RGB = 0,
	HDMI_COLORSPACE_YUV422 = 1,
	HDMI_COLORSPACE_YUV444 = 2,
	HDMI_COLORSPACE_YUV420 = 3,
	HDMI_COLORSPACE_RESERVED4 = 4,
	HDMI_COLORSPACE_RESERVED5 = 5,
	HDMI_COLORSPACE_RESERVED6 = 6,
	HDMI_COLORSPACE_IDO_DEFINED = 7,
};

enum hdmi_scan_mode {
	HDMI_SCAN_MODE_NONE = 0,
	HDMI_SCAN_MODE_OVERSCAN = 1,
	HDMI_SCAN_MODE_UNDERSCAN = 2,
	HDMI_SCAN_MODE_RESERVED = 3,
};

enum hdmi_colorimetry {
	HDMI_COLORIMETRY_NONE = 0,
	HDMI_COLORIMETRY_ITU_601 = 1,
	HDMI_COLORIMETRY_ITU_709 = 2,
	HDMI_COLORIMETRY_EXTENDED = 3,
};

enum hdmi_picture_aspect {
	HDMI_PICTURE_ASPECT_NONE = 0,
	HDMI_PICTURE_ASPECT_4_3 = 1,
	HDMI_PICTURE_ASPECT_16_9 = 2,
	HDMI_PICTURE_ASPECT_64_27 = 3,
	HDMI_PICTURE_ASPECT_256_135 = 4,
	HDMI_PICTURE_ASPECT_RESERVED = 5,
};

enum hdmi_active_aspect {
	HDMI_ACTIVE_ASPECT_16_9_TOP = 2,
	HDMI_ACTIVE_ASPECT_14_9_TOP = 3,
	HDMI_ACTIVE_ASPECT_16_9_CENTER = 4,
	HDMI_ACTIVE_ASPECT_PICTURE = 8,
	HDMI_ACTIVE_ASPECT_4_3 = 9,
	HDMI_ACTIVE_ASPECT_16_9 = 10,
	HDMI_ACTIVE_ASPECT_14_9 = 11,
	HDMI_ACTIVE_ASPECT_4_3_SP_14_9 = 13,
	HDMI_ACTIVE_ASPECT_16_9_SP_14_9 = 14,
	HDMI_ACTIVE_ASPECT_16_9_SP_4_3 = 15,
};

enum hdmi_extended_colorimetry {
	HDMI_EXTENDED_COLORIMETRY_XV_YCC_601 = 0,
	HDMI_EXTENDED_COLORIMETRY_XV_YCC_709 = 1,
	HDMI_EXTENDED_COLORIMETRY_S_YCC_601 = 2,
	HDMI_EXTENDED_COLORIMETRY_ADOBE_YCC_601 = 3,
	HDMI_EXTENDED_COLORIMETRY_ADOBE_RGB = 4,
	HDMI_EXTENDED_COLORIMETRY_BT2020_CONST_LUM = 5,
	HDMI_EXTENDED_COLORIMETRY_BT2020 = 6,
	HDMI_EXTENDED_COLORIMETRY_RESERVED = 7,
};

enum hdmi_quantization_range {
	HDMI_QUANTIZATION_RANGE_DEFAULT = 0,
	HDMI_QUANTIZATION_RANGE_LIMITED = 1,
	HDMI_QUANTIZATION_RANGE_FULL = 2,
	HDMI_QUANTIZATION_RANGE_RESERVED = 3,
};

enum hdmi_nups {
	HDMI_NUPS_UNKNOWN = 0,
	HDMI_NUPS_HORIZONTAL = 1,
	HDMI_NUPS_VERTICAL = 2,
	HDMI_NUPS_BOTH = 3,
};

enum hdmi_ycc_quantization_range {
	HDMI_YCC_QUANTIZATION_RANGE_LIMITED = 0,
	HDMI_YCC_QUANTIZATION_RANGE_FULL = 1,
};

enum hdmi_content_type {
	HDMI_CONTENT_TYPE_GRAPHICS = 0,
	HDMI_CONTENT_TYPE_PHOTO = 1,
	HDMI_CONTENT_TYPE_CINEMA = 2,
	HDMI_CONTENT_TYPE_GAME = 3,
};

struct hdmi_avi_infoframe {
	enum hdmi_infoframe_type type;
	unsigned char version;
	unsigned char length;
	enum hdmi_colorspace colorspace;
	enum hdmi_scan_mode scan_mode;
	enum hdmi_colorimetry colorimetry;
	enum hdmi_picture_aspect picture_aspect;
	enum hdmi_active_aspect active_aspect;
	bool itc;
	enum hdmi_extended_colorimetry extended_colorimetry;
	enum hdmi_quantization_range quantization_range;
	enum hdmi_nups nups;
	unsigned char video_code;
	enum hdmi_ycc_quantization_range ycc_quantization_range;
	enum hdmi_content_type content_type;
	unsigned char pixel_repeat;
	short unsigned int top_bar;
	short unsigned int bottom_bar;
	short unsigned int left_bar;
	short unsigned int right_bar;
};

enum hdmi_spd_sdi {
	HDMI_SPD_SDI_UNKNOWN = 0,
	HDMI_SPD_SDI_DSTB = 1,
	HDMI_SPD_SDI_DVDP = 2,
	HDMI_SPD_SDI_DVHS = 3,
	HDMI_SPD_SDI_HDDVR = 4,
	HDMI_SPD_SDI_DVC = 5,
	HDMI_SPD_SDI_DSC = 6,
	HDMI_SPD_SDI_VCD = 7,
	HDMI_SPD_SDI_GAME = 8,
	HDMI_SPD_SDI_PC = 9,
	HDMI_SPD_SDI_BD = 10,
	HDMI_SPD_SDI_SACD = 11,
	HDMI_SPD_SDI_HDDVD = 12,
	HDMI_SPD_SDI_PMP = 13,
};

struct hdmi_spd_infoframe {
	enum hdmi_infoframe_type type;
	unsigned char version;
	unsigned char length;
	char vendor[8];
	char product[16];
	enum hdmi_spd_sdi sdi;
};

enum hdmi_audio_coding_type {
	HDMI_AUDIO_CODING_TYPE_STREAM = 0,
	HDMI_AUDIO_CODING_TYPE_PCM = 1,
	HDMI_AUDIO_CODING_TYPE_AC3 = 2,
	HDMI_AUDIO_CODING_TYPE_MPEG1 = 3,
	HDMI_AUDIO_CODING_TYPE_MP3 = 4,
	HDMI_AUDIO_CODING_TYPE_MPEG2 = 5,
	HDMI_AUDIO_CODING_TYPE_AAC_LC = 6,
	HDMI_AUDIO_CODING_TYPE_DTS = 7,
	HDMI_AUDIO_CODING_TYPE_ATRAC = 8,
	HDMI_AUDIO_CODING_TYPE_DSD = 9,
	HDMI_AUDIO_CODING_TYPE_EAC3 = 10,
	HDMI_AUDIO_CODING_TYPE_DTS_HD = 11,
	HDMI_AUDIO_CODING_TYPE_MLP = 12,
	HDMI_AUDIO_CODING_TYPE_DST = 13,
	HDMI_AUDIO_CODING_TYPE_WMA_PRO = 14,
	HDMI_AUDIO_CODING_TYPE_CXT = 15,
};

enum hdmi_audio_sample_size {
	HDMI_AUDIO_SAMPLE_SIZE_STREAM = 0,
	HDMI_AUDIO_SAMPLE_SIZE_16 = 1,
	HDMI_AUDIO_SAMPLE_SIZE_20 = 2,
	HDMI_AUDIO_SAMPLE_SIZE_24 = 3,
};

enum hdmi_audio_sample_frequency {
	HDMI_AUDIO_SAMPLE_FREQUENCY_STREAM = 0,
	HDMI_AUDIO_SAMPLE_FREQUENCY_32000 = 1,
	HDMI_AUDIO_SAMPLE_FREQUENCY_44100 = 2,
	HDMI_AUDIO_SAMPLE_FREQUENCY_48000 = 3,
	HDMI_AUDIO_SAMPLE_FREQUENCY_88200 = 4,
	HDMI_AUDIO_SAMPLE_FREQUENCY_96000 = 5,
	HDMI_AUDIO_SAMPLE_FREQUENCY_176400 = 6,
	HDMI_AUDIO_SAMPLE_FREQUENCY_192000 = 7,
};

enum hdmi_audio_coding_type_ext {
	HDMI_AUDIO_CODING_TYPE_EXT_CT = 0,
	HDMI_AUDIO_CODING_TYPE_EXT_HE_AAC = 1,
	HDMI_AUDIO_CODING_TYPE_EXT_HE_AAC_V2 = 2,
	HDMI_AUDIO_CODING_TYPE_EXT_MPEG_SURROUND = 3,
	HDMI_AUDIO_CODING_TYPE_EXT_MPEG4_HE_AAC = 4,
	HDMI_AUDIO_CODING_TYPE_EXT_MPEG4_HE_AAC_V2 = 5,
	HDMI_AUDIO_CODING_TYPE_EXT_MPEG4_AAC_LC = 6,
	HDMI_AUDIO_CODING_TYPE_EXT_DRA = 7,
	HDMI_AUDIO_CODING_TYPE_EXT_MPEG4_HE_AAC_SURROUND = 8,
	HDMI_AUDIO_CODING_TYPE_EXT_MPEG4_AAC_LC_SURROUND = 10,
};

struct hdmi_audio_infoframe {
	enum hdmi_infoframe_type type;
	unsigned char version;
	unsigned char length;
	unsigned char channels;
	enum hdmi_audio_coding_type coding_type;
	enum hdmi_audio_sample_size sample_size;
	enum hdmi_audio_sample_frequency sample_frequency;
	enum hdmi_audio_coding_type_ext coding_type_ext;
	unsigned char channel_allocation;
	unsigned char level_shift_value;
	bool downmix_inhibit;
};

enum hdmi_3d_structure {
	HDMI_3D_STRUCTURE_INVALID = 4294967295,
	HDMI_3D_STRUCTURE_FRAME_PACKING = 0,
	HDMI_3D_STRUCTURE_FIELD_ALTERNATIVE = 1,
	HDMI_3D_STRUCTURE_LINE_ALTERNATIVE = 2,
	HDMI_3D_STRUCTURE_SIDE_BY_SIDE_FULL = 3,
	HDMI_3D_STRUCTURE_L_DEPTH = 4,
	HDMI_3D_STRUCTURE_L_DEPTH_GFX_GFX_DEPTH = 5,
	HDMI_3D_STRUCTURE_TOP_AND_BOTTOM = 6,
	HDMI_3D_STRUCTURE_SIDE_BY_SIDE_HALF = 8,
};

struct hdmi_vendor_infoframe {
	enum hdmi_infoframe_type type;
	unsigned char version;
	unsigned char length;
	unsigned int oui;
	u8 vic;
	enum hdmi_3d_structure s3d_struct;
	unsigned int s3d_ext_data;
};

union hdmi_vendor_any_infoframe {
	struct {
		enum hdmi_infoframe_type type;
		unsigned char version;
		unsigned char length;
		unsigned int oui;
	} any;
	struct hdmi_vendor_infoframe hdmi;
};

union hdmi_infoframe {
	struct hdmi_any_infoframe any;
	struct hdmi_avi_infoframe avi;
	struct hdmi_spd_infoframe spd;
	union hdmi_vendor_any_infoframe vendor;
	struct hdmi_audio_infoframe audio;
};

struct linux_logo {
	int type;
	unsigned int width;
	unsigned int height;
	unsigned int clutsize;
	const unsigned char *clut;
	const unsigned char *data;
};

struct module___241;

struct file___299;

struct kiocb___299;

struct vm_area_struct___300;

struct inode___299;

struct file_lock___299;

struct page___300;

struct file_operations___299 {
	struct module___241 *owner;
	loff_t (*llseek)(struct file___299 *, loff_t, int);
	ssize_t (*read)(struct file___299 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___299 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___299 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___299 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___299 *, bool);
	int (*iterate)(struct file___299 *, struct dir_context *);
	int (*iterate_shared)(struct file___299 *, struct dir_context *);
	__poll_t (*poll)(struct file___299 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___299 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___299 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___299 *, struct vm_area_struct___300 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___299 *, struct file___299 *);
	int (*flush)(struct file___299 *, fl_owner_t);
	int (*release)(struct inode___299 *, struct file___299 *);
	int (*fsync)(struct file___299 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___299 *, int);
	int (*lock)(struct file___299 *, int, struct file_lock___299 *);
	ssize_t (*sendpage)(struct file___299 *, struct page___300 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___299 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___299 *, int, struct file_lock___299 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___299 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___299 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___299 *, long int, struct file_lock___299 **, void **);
	long int (*fallocate)(struct file___299 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___299 *);
	ssize_t (*copy_file_range)(struct file___299 *, loff_t, struct file___299 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___299 *, loff_t, struct file___299 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___299 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___299 {
	u64 seqnum;
	struct vm_area_struct___300 *vmas[4];
};

struct page_frag___299 {
	struct page___300 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___299;

struct pid___197;

struct cred___277;

struct nsproxy___244;

struct signal_struct___223;

struct vm_struct___215;

struct task_struct___300 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___300 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___299 *mm;
	struct mm_struct___299 *active_mm;
	struct vmacache___299 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___300 *real_parent;
	struct task_struct___300 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___300 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___197 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___197 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___197 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___277 *ptracer_cred;
	const struct cred___277 *real_cred;
	const struct cred___277 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___244 *nsproxy;
	struct signal_struct___223 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___300 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___82 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___299 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___300 *oom_reaper_list;
	struct vm_struct___215 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___131 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___300 *pgtable_t___299;

struct address_space___298;

struct dev_pagemap___288;

struct page___300 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___298 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___300 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___299 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___299 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___288 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___299;

struct lruvec___299 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___299 *pgdat;
};

struct zone___299 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___299 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___299 {
	struct zone___299 *zone;
	int zone_idx;
};

struct zonelist___299 {
	struct zoneref___299 _zonerefs[25];
};

struct pglist_data___299 {
	struct zone___299 node_zones[3];
	struct zonelist___299 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___300 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___300 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___299 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___300 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___300 *owner;
};

struct secondary_data___300 {
	void *stack;
	struct task_struct___300 *task;
	long int status;
};

struct blocking_notifier_head___299 {
	struct rw_semaphore___300 rwsem;
	struct notifier_block *head;
};

struct dentry___299;

struct path___299 {
	struct vfsmount *mnt;
	struct dentry___299 *dentry;
};

struct fown_struct___197 {
	rwlock_t lock;
	struct pid___197 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___299 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___299 f_path;
	struct inode___299 *f_inode;
	const struct file_operations___299 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___197 f_owner;
	const struct cred___277 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___298 *f_mapping;
	errseq_t f_wb_err;
};

struct key___277;

struct user_struct___277;

struct cred___277 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___277 *session_keyring;
	struct key___277 *process_keyring;
	struct key___277 *thread_keyring;
	struct key___277 *request_key_auth;
	void *security;
	struct user_struct___277 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___292;

struct kernfs_elem_dir___292 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___292 *root;
};

struct kernfs_node___293;

struct kernfs_syscall_ops___292;

struct kernfs_root___292 {
	struct kernfs_node___293 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___292 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___292 {
	struct kernfs_node___293 *target_kn;
};

struct kernfs_ops___292;

struct kernfs_elem_attr___292 {
	const struct kernfs_ops___292 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___293 *notify_next;
};

struct kernfs_node___293 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___293 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___292 dir;
		struct kernfs_elem_symlink___292 symlink;
		struct kernfs_elem_attr___292 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___292;

struct kernfs_ops___292 {
	int (*open)(struct kernfs_open_file___292 *);
	void (*release)(struct kernfs_open_file___292 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___292 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___292 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___292 *, struct vm_area_struct___300 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___292 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___292 {
	int (*remount_fs)(struct kernfs_root___292 *, int *, char *);
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___292 *);
	int (*mkdir)(struct kernfs_node___293 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___293 *);
	int (*rename)(struct kernfs_node___293 *, struct kernfs_node___293 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___293 *, struct kernfs_root___292 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_operations_struct___288;

struct kernfs_open_file___292 {
	struct kernfs_node___293 *kn;
	struct file___299 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___288 *vm_ops;
};

struct vm_fault___288;

struct vm_operations_struct___288 {
	void (*open)(struct vm_area_struct___300 *);
	void (*close)(struct vm_area_struct___300 *);
	int (*split)(struct vm_area_struct___300 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___300 *);
	vm_fault_t (*fault)(struct vm_fault___288 *);
	vm_fault_t (*huge_fault)(struct vm_fault___288 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___288 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___300 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___288 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___288 *);
	int (*access)(struct vm_area_struct___300 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___300 *);
	int (*set_policy)(struct vm_area_struct___300 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___300 *, long unsigned int);
	struct page___300 * (*find_special_page)(struct vm_area_struct___300 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_area_struct___300 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___300 *vm_next;
	struct vm_area_struct___300 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___299 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___288 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___299 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___286;

struct bin_attribute___262;

struct attribute_group___263 {
	const char *name;
	umode_t (*is_visible)(struct kobject___286 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___286 *, struct bin_attribute___262 *, int);
	struct attribute **attrs;
	struct bin_attribute___262 **bin_attrs;
};

struct kset___285;

struct kobj_type___285;

struct kobject___286 {
	const char *name;
	struct list_head entry;
	struct kobject___286 *parent;
	struct kset___285 *kset;
	struct kobj_type___285 *ktype;
	struct kernfs_node___293 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___262 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___299 *, struct kobject___286 *, struct bin_attribute___262 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___299 *, struct kobject___286 *, struct bin_attribute___262 *, char *, loff_t, size_t);
	int (*mmap)(struct file___299 *, struct kobject___286 *, struct bin_attribute___262 *, struct vm_area_struct___300 *);
};

struct sysfs_ops___285 {
	ssize_t (*show)(struct kobject___286 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___286 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___285;

struct kset___285 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___286 kobj;
	const struct kset_uevent_ops___285 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___285 {
	void (*release)(struct kobject___286 *);
	const struct sysfs_ops___285 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___25 * (*child_ns_type)(struct kobject___286 *);
	const void * (*namespace)(struct kobject___286 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___285 {
	int (* const filter)(struct kset___285 *, struct kobject___286 *);
	const char * (* const name)(struct kset___285 *, struct kobject___286 *);
	int (* const uevent)(struct kset___285 *, struct kobject___286 *, struct kobj_uevent_env *);
};

struct kobj_attribute___278 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___286 *, struct kobj_attribute___278 *, char *);
	ssize_t (*store)(struct kobject___286 *, struct kobj_attribute___278 *, const char *, size_t);
};

struct kernel_param___238;

struct kernel_param_ops___238 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___238 *);
	int (*get)(char *, const struct kernel_param___238 *);
	void (*free)(void *);
};

struct kparam_array___238;

struct kernel_param___238 {
	const char *name;
	struct module___241 *mod;
	const struct kernel_param_ops___238 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___238 *arr;
	};
};

struct kparam_array___238 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___238 *ops;
	void *elem;
};

struct module_kobject___238 {
	struct kobject___286 kobj;
	struct module___241 *mod;
	struct kobject___286 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___238 {
	struct module___241 *mod;
	struct latch_tree_node node;
};

struct module_layout___238 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___238 mtn;
};

struct module_attribute___238;

struct module___241 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___238 mkobj;
	struct module_attribute___238 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___286 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___238 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___238 core_layout;
	struct module_layout___238 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___238 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___238 *, struct module_kobject___238 *, char *);
	ssize_t (*store)(struct module_attribute___238 *, struct module_kobject___238 *, const char *, size_t);
	void (*setup)(struct module___241 *, const char *);
	int (*test)(struct module___241 *);
	void (*free)(struct module___241 *);
};

struct device___264;

struct dev_pm_ops___264 {
	int (*prepare)(struct device___264 *);
	void (*complete)(struct device___264 *);
	int (*suspend)(struct device___264 *);
	int (*resume)(struct device___264 *);
	int (*freeze)(struct device___264 *);
	int (*thaw)(struct device___264 *);
	int (*poweroff)(struct device___264 *);
	int (*restore)(struct device___264 *);
	int (*suspend_late)(struct device___264 *);
	int (*resume_early)(struct device___264 *);
	int (*freeze_late)(struct device___264 *);
	int (*thaw_early)(struct device___264 *);
	int (*poweroff_late)(struct device___264 *);
	int (*restore_early)(struct device___264 *);
	int (*suspend_noirq)(struct device___264 *);
	int (*resume_noirq)(struct device___264 *);
	int (*freeze_noirq)(struct device___264 *);
	int (*thaw_noirq)(struct device___264 *);
	int (*poweroff_noirq)(struct device___264 *);
	int (*restore_noirq)(struct device___264 *);
	int (*runtime_suspend)(struct device___264 *);
	int (*runtime_resume)(struct device___264 *);
	int (*runtime_idle)(struct device___264 *);
};

struct dev_pm_info___264 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___264 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___264;

struct bus_type___264;

struct device_driver___264;

struct dev_pm_domain___264;

struct irq_domain___15;

struct device_node___56;

struct fwnode_handle___198;

struct class___264;

struct device___264 {
	struct device___264 *parent;
	struct device_private *p;
	struct kobject___286 kobj;
	const char *init_name;
	const struct device_type___264 *type;
	struct mutex mutex;
	struct bus_type___264 *bus;
	struct device_driver___264 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___264 power;
	struct dev_pm_domain___264 *pm_domain;
	struct irq_domain___15 *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___56 *of_node;
	struct fwnode_handle___198 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___264 *class;
	const struct attribute_group___263 **groups;
	void (*release)(struct device___264 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___264 {
	struct dev_pm_ops___264 ops;
	void (*detach)(struct device___264 *, bool);
	int (*activate)(struct device___264 *);
	void (*sync)(struct device___264 *);
	void (*dismiss)(struct device___264 *);
};

struct pid_namespace___197;

struct upid___197 {
	int nr;
	struct pid_namespace___197 *ns;
};

struct pid_namespace___197 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___300 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___197 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___299 *proc_self;
	struct dentry___299 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___3 *user_ns;
	struct ucounts___2 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___9 ns;
};

struct pid___197 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___197 numbers[1];
};

struct user_struct___277 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___277 *uid_keyring;
	struct key___277 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___299;

struct mm_struct___299 {
	struct {
		struct vm_area_struct___300 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___299 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___300 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___299 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___300 *owner;
		struct user_namespace___3 *user_ns;
		struct file___299 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___299 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct nsproxy___244 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___197 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct signal_struct___223 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___300 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___300 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___197 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___197 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___299 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___197 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_struct___215 {
	struct vm_struct___215 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___300 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___235 {
	struct task_struct___300 task;
	long unsigned int stack[8192];
};

struct bus_type___264 {
	const char *name;
	const char *dev_name;
	struct device___264 *dev_root;
	const struct attribute_group___263 **bus_groups;
	const struct attribute_group___263 **dev_groups;
	const struct attribute_group___263 **drv_groups;
	int (*match)(struct device___264 *, struct device_driver___264 *);
	int (*uevent)(struct device___264 *, struct kobj_uevent_env *);
	int (*probe)(struct device___264 *);
	int (*remove)(struct device___264 *);
	void (*shutdown)(struct device___264 *);
	int (*online)(struct device___264 *);
	int (*offline)(struct device___264 *);
	int (*suspend)(struct device___264 *, pm_message_t);
	int (*resume)(struct device___264 *);
	int (*num_vf)(struct device___264 *);
	int (*dma_configure)(struct device___264 *);
	const struct dev_pm_ops___264 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___264 {
	const char *name;
	struct bus_type___264 *bus;
	struct module___241 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___264 *);
	int (*remove)(struct device___264 *);
	void (*shutdown)(struct device___264 *);
	int (*suspend)(struct device___264 *, pm_message_t);
	int (*resume)(struct device___264 *);
	const struct attribute_group___263 **groups;
	const struct dev_pm_ops___264 *pm;
	void (*coredump)(struct device___264 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___264 {
	const char *name;
	const struct attribute_group___263 **groups;
	int (*uevent)(struct device___264 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___264 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___264 *);
	const struct dev_pm_ops___264 *pm;
};

struct class___264 {
	const char *name;
	struct module___241 *owner;
	const struct attribute_group___263 **class_groups;
	const struct attribute_group___263 **dev_groups;
	struct kobject___286 *dev_kobj;
	int (*dev_uevent)(struct device___264 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___264 *, umode_t *);
	void (*class_release)(struct class___264 *);
	void (*dev_release)(struct device___264 *);
	int (*shutdown_pre)(struct device___264 *);
	const struct kobj_ns_type_operations___25 *ns_type;
	const void * (*namespace)(struct device___264 *);
	const struct dev_pm_ops___264 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct device_attribute___17 {
	struct attribute attr;
	ssize_t (*show)(struct device___264 *, struct device_attribute___17 *, char *);
	ssize_t (*store)(struct device___264 *, struct device_attribute___17 *, const char *, size_t);
};

typedef void (*dr_release_t___12)(struct device___264 *, void *);

struct irq_domain_ops___15;

struct irq_domain___15 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___15 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___198 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___2 *gc;
	struct irq_domain___15 *parent;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_direct_max_irq;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_tree_mutex;
	unsigned int linear_revmap[0];
};

struct fwnode_operations___198;

struct fwnode_handle___198 {
	struct fwnode_handle___198 *secondary;
	const struct fwnode_operations___198 *ops;
};

struct property___53;

struct device_node___56 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___198 fwnode;
	struct property___53 *properties;
	struct property___53 *deadprops;
	struct device_node___56 *parent;
	struct device_node___56 *child;
	struct device_node___56 *sibling;
	struct kobject___286 kobj;
	long unsigned int _flags;
	void *data;
};

typedef int (*key_restrict_link_func_t___278)(struct key___277 *, const struct key_type *, const union key_payload *, struct key___277 *);

struct key_restriction___277;

struct key___277 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___300 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___277 *restrict_link;
};

struct key_restriction___277 {
	key_restrict_link_func_t___278 check;
	struct key___277 *key;
	struct key_type *keytype;
};

struct address_space_operations___298;

struct address_space___298 {
	struct inode___299 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___300 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___298 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___288)(struct vm_area_struct___300 *, long unsigned int, const struct page___300 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___288)(struct page___300 *, void *);

struct dev_pagemap___288 {
	dev_page_fault_t___288 page_fault;
	dev_page_free_t___288 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___264 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___299 {
	struct task_struct___300 *task;
	struct core_thread___299 *next;
};

struct core_state___299 {
	atomic_t nr_threads;
	struct core_thread___299 dumper;
	struct completion startup;
};

struct vm_fault___288 {
	struct vm_area_struct___300 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___300 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___300 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___299 prealloc_pte;
};

struct dentry_operations___298;

struct super_block___298;

struct dentry___299 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___299 *d_parent;
	struct qstr d_name;
	struct inode___299 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___298 *d_op;
	struct super_block___298 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___298;

struct block_device___298;

struct inode___299 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___298 *i_op;
	struct super_block___298 *i_sb;
	struct address_space___298 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___300 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___299 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___298 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___298 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___298 {
	int (*d_revalidate)(struct dentry___299 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___299 *, unsigned int);
	int (*d_hash)(const struct dentry___299 *, struct qstr *);
	int (*d_compare)(const struct dentry___299 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___299 *);
	int (*d_init)(struct dentry___299 *);
	void (*d_release)(struct dentry___299 *);
	void (*d_prune)(struct dentry___299 *);
	void (*d_iput)(struct dentry___299 *, struct inode___299 *);
	char * (*d_dname)(struct dentry___299 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___299 *);
	int (*d_manage)(const struct path___299 *, bool);
	struct dentry___299 * (*d_real)(struct dentry___299 *, const struct inode___299 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___298;

struct mem_dqinfo___298 {
	struct quota_format_type___298 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___298;

struct quota_info___298 {
	unsigned int flags;
	struct rw_semaphore___300 dqio_sem;
	struct inode___299 *files[3];
	struct mem_dqinfo___298 info[3];
	const struct quota_format_ops___298 *ops[3];
};

struct rcuwait___298 {
	struct task_struct___300 *task;
};

struct percpu_rw_semaphore___298 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___300 rw_sem;
	struct rcuwait___298 writer;
	int readers_block;
};

struct sb_writers___298 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___298 rw_sem[3];
};

struct file_system_type___298;

struct super_operations___298;

struct dquot_operations___298;

struct quotactl_ops___298;

struct super_block___298 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___298 *s_type;
	const struct super_operations___298 *s_op;
	const struct dquot_operations___298 *dq_op;
	const struct quotactl_ops___298 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___299 *s_root;
	struct rw_semaphore___300 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___298 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___298 s_dquot;
	struct sb_writers___298 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___298 *s_d_op;
	int cleancache_poolid;
	struct shrinker___116 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___299 {
	struct file___299 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___299 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___298 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___299 *ia_file;
};

struct dquot___298 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___298 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___298 {
	int qf_fmt_id;
	const struct quota_format_ops___298 *qf_ops;
	struct module___241 *qf_owner;
	struct quota_format_type___298 *qf_next;
};

struct quota_format_ops___298 {
	int (*check_quota_file)(struct super_block___298 *, int);
	int (*read_file_info)(struct super_block___298 *, int);
	int (*write_file_info)(struct super_block___298 *, int);
	int (*free_file_info)(struct super_block___298 *, int);
	int (*read_dqblk)(struct dquot___298 *);
	int (*commit_dqblk)(struct dquot___298 *);
	int (*release_dqblk)(struct dquot___298 *);
	int (*get_next_id)(struct super_block___298 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___298 {
	int (*write_dquot)(struct dquot___298 *);
	struct dquot___298 * (*alloc_dquot)(struct super_block___298 *, int);
	void (*destroy_dquot)(struct dquot___298 *);
	int (*acquire_dquot)(struct dquot___298 *);
	int (*release_dquot)(struct dquot___298 *);
	int (*mark_dirty)(struct dquot___298 *);
	int (*write_info)(struct super_block___298 *, int);
	qsize_t * (*get_reserved_space)(struct inode___299 *);
	int (*get_projid)(struct inode___299 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___299 *, qsize_t *);
	int (*get_next_id)(struct super_block___298 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___298 {
	int (*quota_on)(struct super_block___298 *, int, int, const struct path___299 *);
	int (*quota_off)(struct super_block___298 *, int);
	int (*quota_enable)(struct super_block___298 *, unsigned int);
	int (*quota_disable)(struct super_block___298 *, unsigned int);
	int (*quota_sync)(struct super_block___298 *, int);
	int (*set_info)(struct super_block___298 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___298 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___298 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___298 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___298 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___298 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___298 {
	int (*writepage)(struct page___300 *, struct writeback_control___3 *);
	int (*readpage)(struct file___299 *, struct page___300 *);
	int (*writepages)(struct address_space___298 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___300 *);
	int (*readpages)(struct file___299 *, struct address_space___298 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___299 *, struct address_space___298 *, loff_t, unsigned int, unsigned int, struct page___300 **, void **);
	int (*write_end)(struct file___299 *, struct address_space___298 *, loff_t, unsigned int, unsigned int, struct page___300 *, void *);
	sector_t (*bmap)(struct address_space___298 *, sector_t);
	void (*invalidatepage)(struct page___300 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___300 *, gfp_t);
	void (*freepage)(struct page___300 *);
	ssize_t (*direct_IO)(struct kiocb___299 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___298 *, struct page___300 *, struct page___300 *, enum migrate_mode);
	bool (*isolate_page)(struct page___300 *, isolate_mode_t);
	void (*putback_page)(struct page___300 *);
	int (*launder_page)(struct page___300 *);
	int (*is_partially_uptodate)(struct page___300 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___300 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___298 *, struct page___300 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___299 *, sector_t *);
	void (*swap_deactivate)(struct file___299 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___298 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___299 *bd_inode;
	struct super_block___298 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___298 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___298 {
	struct dentry___299 * (*lookup)(struct inode___299 *, struct dentry___299 *, unsigned int);
	const char * (*get_link)(struct dentry___299 *, struct inode___299 *, struct delayed_call *);
	int (*permission)(struct inode___299 *, int);
	struct posix_acl * (*get_acl)(struct inode___299 *, int);
	int (*readlink)(struct dentry___299 *, char *, int);
	int (*create)(struct inode___299 *, struct dentry___299 *, umode_t, bool);
	int (*link)(struct dentry___299 *, struct inode___299 *, struct dentry___299 *);
	int (*unlink)(struct inode___299 *, struct dentry___299 *);
	int (*symlink)(struct inode___299 *, struct dentry___299 *, const char *);
	int (*mkdir)(struct inode___299 *, struct dentry___299 *, umode_t);
	int (*rmdir)(struct inode___299 *, struct dentry___299 *);
	int (*mknod)(struct inode___299 *, struct dentry___299 *, umode_t, dev_t);
	int (*rename)(struct inode___299 *, struct dentry___299 *, struct inode___299 *, struct dentry___299 *, unsigned int);
	int (*setattr)(struct dentry___299 *, struct iattr___298 *);
	int (*getattr)(const struct path___299 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___299 *, char *, size_t);
	int (*fiemap)(struct inode___299 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___299 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___299 *, struct dentry___299 *, struct file___299 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___299 *, struct dentry___299 *, umode_t);
	int (*set_acl)(struct inode___299 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___298 {
	void (*fl_copy_lock)(struct file_lock___299 *, struct file_lock___299 *);
	void (*fl_release_private)(struct file_lock___299 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___298;

struct lock_manager_operations___298;

struct file_lock___299 {
	struct file_lock___299 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___299 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___298 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___298 *fl_ops;
	const struct lock_manager_operations___298 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___298 {
	int (*lm_compare_owner)(struct file_lock___299 *, struct file_lock___299 *);
	long unsigned int (*lm_owner_key)(struct file_lock___299 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___299 *);
	int (*lm_grant)(struct file_lock___299 *, int);
	bool (*lm_break)(struct file_lock___299 *);
	int (*lm_change)(struct file_lock___299 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___299 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___298 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___298 *fa_next;
	struct file___299 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___298 {
	const char *name;
	int fs_flags;
	struct dentry___299 * (*mount)(struct file_system_type___298 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___298 *);
	struct module___241 *owner;
	struct file_system_type___298 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___298 {
	struct inode___299 * (*alloc_inode)(struct super_block___298 *);
	void (*destroy_inode)(struct inode___299 *);
	void (*dirty_inode)(struct inode___299 *, int);
	int (*write_inode)(struct inode___299 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___299 *);
	void (*evict_inode)(struct inode___299 *);
	void (*put_super)(struct super_block___298 *);
	int (*sync_fs)(struct super_block___298 *, int);
	int (*freeze_super)(struct super_block___298 *);
	int (*freeze_fs)(struct super_block___298 *);
	int (*thaw_super)(struct super_block___298 *);
	int (*unfreeze_fs)(struct super_block___298 *);
	int (*statfs)(struct dentry___299 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___298 *, int *, char *);
	void (*umount_begin)(struct super_block___298 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___299 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___299 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___299 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___299 *);
	ssize_t (*quota_read)(struct super_block___298 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___298 *, int, const char *, size_t, loff_t);
	struct dquot___298 ** (*get_dquots)(struct inode___299 *);
	int (*bdev_try_to_free_page)(struct super_block___298 *, struct page___300 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___298 *, struct shrink_control___116 *);
	long int (*free_cached_objects)(struct super_block___298 *, struct shrink_control___116 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___288(struct page___300 *);

struct fwnode_reference_args___198;

struct fwnode_endpoint___198;

struct fwnode_operations___198 {
	struct fwnode_handle___198 * (*get)(struct fwnode_handle___198 *);
	void (*put)(struct fwnode_handle___198 *);
	bool (*device_is_available)(const struct fwnode_handle___198 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___198 *, const struct device___264 *);
	bool (*property_present)(const struct fwnode_handle___198 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___198 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___198 *, const char *, const char **, size_t);
	struct fwnode_handle___198 * (*get_parent)(const struct fwnode_handle___198 *);
	struct fwnode_handle___198 * (*get_next_child_node)(const struct fwnode_handle___198 *, struct fwnode_handle___198 *);
	struct fwnode_handle___198 * (*get_named_child_node)(const struct fwnode_handle___198 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___198 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___198 *);
	struct fwnode_handle___198 * (*graph_get_next_endpoint)(const struct fwnode_handle___198 *, struct fwnode_handle___198 *);
	struct fwnode_handle___198 * (*graph_get_remote_endpoint)(const struct fwnode_handle___198 *);
	struct fwnode_handle___198 * (*graph_get_port_parent)(struct fwnode_handle___198 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___198 *, struct fwnode_endpoint___198 *);
};

struct fwnode_endpoint___198 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___198 *local_fwnode;
};

struct fwnode_reference_args___198 {
	struct fwnode_handle___198 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct property___53 {
	char *name;
	int length;
	void *value;
	struct property___53 *next;
	long unsigned int _flags;
	struct bin_attribute___262 attr;
};

struct irq_fwspec___15 {
	struct fwnode_handle___198 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___15 {
	int (*match)(struct irq_domain___15 *, struct device_node___56 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___15 *, struct irq_fwspec___15 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___15 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___15 *, unsigned int);
	int (*xlate)(struct irq_domain___15 *, struct device_node___56 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___15 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___15 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___15 *, struct irq_data___5 *, bool);
	void (*deactivate)(struct irq_domain___15 *, struct irq_data___5 *);
	int (*translate)(struct irq_domain___15 *, struct irq_fwspec___15 *, long unsigned int *, unsigned int *);
};

struct fb_fix_screeninfo {
	char id[16];
	long unsigned int smem_start;
	__u32 smem_len;
	__u32 type;
	__u32 type_aux;
	__u32 visual;
	__u16 xpanstep;
	__u16 ypanstep;
	__u16 ywrapstep;
	__u32 line_length;
	long unsigned int mmio_start;
	__u32 mmio_len;
	__u32 accel;
	__u16 capabilities;
	__u16 reserved[2];
};

struct fb_bitfield {
	__u32 offset;
	__u32 length;
	__u32 msb_right;
};

struct fb_var_screeninfo {
	__u32 xres;
	__u32 yres;
	__u32 xres_virtual;
	__u32 yres_virtual;
	__u32 xoffset;
	__u32 yoffset;
	__u32 bits_per_pixel;
	__u32 grayscale;
	struct fb_bitfield red;
	struct fb_bitfield green;
	struct fb_bitfield blue;
	struct fb_bitfield transp;
	__u32 nonstd;
	__u32 activate;
	__u32 height;
	__u32 width;
	__u32 accel_flags;
	__u32 pixclock;
	__u32 left_margin;
	__u32 right_margin;
	__u32 upper_margin;
	__u32 lower_margin;
	__u32 hsync_len;
	__u32 vsync_len;
	__u32 sync;
	__u32 vmode;
	__u32 rotate;
	__u32 colorspace;
	__u32 reserved[4];
};

struct fb_cmap {
	__u32 start;
	__u32 len;
	__u16 *red;
	__u16 *green;
	__u16 *blue;
	__u16 *transp;
};

enum {
	FB_BLANK_UNBLANK = 0,
	FB_BLANK_NORMAL = 1,
	FB_BLANK_VSYNC_SUSPEND = 2,
	FB_BLANK_HSYNC_SUSPEND = 3,
	FB_BLANK_POWERDOWN = 4,
};

struct fb_copyarea {
	__u32 dx;
	__u32 dy;
	__u32 width;
	__u32 height;
	__u32 sx;
	__u32 sy;
};

struct fb_fillrect {
	__u32 dx;
	__u32 dy;
	__u32 width;
	__u32 height;
	__u32 color;
	__u32 rop;
};

struct fb_image {
	__u32 dx;
	__u32 dy;
	__u32 width;
	__u32 height;
	__u32 fg_color;
	__u32 bg_color;
	__u8 depth;
	const char *data;
	struct fb_cmap cmap;
};

struct fbcurpos {
	__u16 x;
	__u16 y;
};

struct fb_cursor {
	__u16 set;
	__u16 enable;
	__u16 rop;
	const char *mask;
	struct fbcurpos hot;
	struct fb_image image;
};

struct fb_chroma {
	__u32 redx;
	__u32 greenx;
	__u32 bluex;
	__u32 whitex;
	__u32 redy;
	__u32 greeny;
	__u32 bluey;
	__u32 whitey;
};

struct fb_videomode;

struct fb_monspecs {
	struct fb_chroma chroma;
	struct fb_videomode *modedb;
	__u8 manufacturer[4];
	__u8 monitor[14];
	__u8 serial_no[14];
	__u8 ascii[14];
	__u32 modedb_len;
	__u32 model;
	__u32 serial;
	__u32 year;
	__u32 week;
	__u32 hfmin;
	__u32 hfmax;
	__u32 dclkmin;
	__u32 dclkmax;
	__u16 input;
	__u16 dpms;
	__u16 signal;
	__u16 vfmin;
	__u16 vfmax;
	__u16 gamma;
	__u16 gtf: 1;
	__u16 misc;
	__u8 version;
	__u8 revision;
	__u8 max_x;
	__u8 max_y;
};

struct fb_videomode {
	const char *name;
	u32 refresh;
	u32 xres;
	u32 yres;
	u32 pixclock;
	u32 left_margin;
	u32 right_margin;
	u32 upper_margin;
	u32 lower_margin;
	u32 hsync_len;
	u32 vsync_len;
	u32 sync;
	u32 vmode;
	u32 flag;
};

struct fb_info;

struct fb_event {
	struct fb_info *info;
	void *data;
};

struct fb_pixmap {
	u8 *addr;
	u32 size;
	u32 offset;
	u32 buf_align;
	u32 scan_align;
	u32 access_align;
	u32 flags;
	u32 blit_x;
	u32 blit_y;
	void (*writeio)(struct fb_info *, void *, void *, unsigned int);
	void (*readio)(struct fb_info *, void *, void *, unsigned int);
};

struct backlight_device;

struct fb_deferred_io;

struct fb_ops;

struct fb_tile_ops;

struct apertures_struct;

struct fb_info {
	atomic_t count;
	int node;
	int flags;
	int fbcon_rotate_hint;
	struct mutex lock;
	struct mutex mm_lock;
	struct fb_var_screeninfo var;
	struct fb_fix_screeninfo fix;
	struct fb_monspecs monspecs;
	struct work_struct queue;
	struct fb_pixmap pixmap;
	struct fb_pixmap sprite;
	struct fb_cmap cmap;
	struct list_head modelist;
	struct fb_videomode *mode;
	struct backlight_device *bl_dev;
	struct mutex bl_curve_mutex;
	u8 bl_curve[128];
	struct delayed_work deferred_work;
	struct fb_deferred_io *fbdefio;
	struct fb_ops *fbops;
	struct device___264 *device;
	struct device___264 *dev;
	int class_flag;
	struct fb_tile_ops *tileops;
	union {
		char *screen_base;
		char *screen_buffer;
	};
	long unsigned int screen_size;
	void *pseudo_palette;
	u32 state;
	void *fbcon_par;
	void *par;
	struct apertures_struct *apertures;
	bool skip_vt_switch;
};

struct fb_blit_caps {
	u32 x;
	u32 y;
	u32 len;
	u32 flags;
};

struct fb_deferred_io {
	long unsigned int delay;
	struct mutex lock;
	struct list_head pagelist;
	void (*first_io)(struct fb_info *);
	void (*deferred_io)(struct fb_info *, struct list_head *);
};

struct fb_ops {
	struct module___241 *owner;
	int (*fb_open)(struct fb_info *, int);
	int (*fb_release)(struct fb_info *, int);
	ssize_t (*fb_read)(struct fb_info *, char *, size_t, loff_t *);
	ssize_t (*fb_write)(struct fb_info *, const char *, size_t, loff_t *);
	int (*fb_check_var)(struct fb_var_screeninfo *, struct fb_info *);
	int (*fb_set_par)(struct fb_info *);
	int (*fb_setcolreg)(unsigned int, unsigned int, unsigned int, unsigned int, unsigned int, struct fb_info *);
	int (*fb_setcmap)(struct fb_cmap *, struct fb_info *);
	int (*fb_blank)(int, struct fb_info *);
	int (*fb_pan_display)(struct fb_var_screeninfo *, struct fb_info *);
	void (*fb_fillrect)(struct fb_info *, const struct fb_fillrect *);
	void (*fb_copyarea)(struct fb_info *, const struct fb_copyarea *);
	void (*fb_imageblit)(struct fb_info *, const struct fb_image *);
	int (*fb_cursor)(struct fb_info *, struct fb_cursor *);
	int (*fb_sync)(struct fb_info *);
	int (*fb_ioctl)(struct fb_info *, unsigned int, long unsigned int);
	int (*fb_compat_ioctl)(struct fb_info *, unsigned int, long unsigned int);
	int (*fb_mmap)(struct fb_info *, struct vm_area_struct___300 *);
	void (*fb_get_caps)(struct fb_info *, struct fb_blit_caps *, struct fb_var_screeninfo *);
	void (*fb_destroy)(struct fb_info *);
	int (*fb_debug_enter)(struct fb_info *);
	int (*fb_debug_leave)(struct fb_info *);
};

struct fb_tilemap {
	__u32 width;
	__u32 height;
	__u32 depth;
	__u32 length;
	const __u8 *data;
};

struct fb_tilerect {
	__u32 sx;
	__u32 sy;
	__u32 width;
	__u32 height;
	__u32 index;
	__u32 fg;
	__u32 bg;
	__u32 rop;
};

struct fb_tilearea {
	__u32 sx;
	__u32 sy;
	__u32 dx;
	__u32 dy;
	__u32 width;
	__u32 height;
};

struct fb_tileblit {
	__u32 sx;
	__u32 sy;
	__u32 width;
	__u32 height;
	__u32 fg;
	__u32 bg;
	__u32 length;
	__u32 *indices;
};

struct fb_tilecursor {
	__u32 sx;
	__u32 sy;
	__u32 mode;
	__u32 shape;
	__u32 fg;
	__u32 bg;
};

struct fb_tile_ops {
	void (*fb_settile)(struct fb_info *, struct fb_tilemap *);
	void (*fb_tilecopy)(struct fb_info *, struct fb_tilearea *);
	void (*fb_tilefill)(struct fb_info *, struct fb_tilerect *);
	void (*fb_tileblit)(struct fb_info *, struct fb_tileblit *);
	void (*fb_tilecursor)(struct fb_info *, struct fb_tilecursor *);
	int (*fb_get_tilemax)(struct fb_info *);
};

struct aperture {
	resource_size_t base;
	resource_size_t size;
};

struct apertures_struct {
	unsigned int count;
	struct aperture ranges[0];
};

enum backlight_type {
	BACKLIGHT_RAW = 1,
	BACKLIGHT_PLATFORM = 2,
	BACKLIGHT_FIRMWARE = 3,
	BACKLIGHT_TYPE_MAX = 4,
};

struct backlight_properties {
	int brightness;
	int max_brightness;
	int power;
	int fb_blank;
	enum backlight_type type;
	unsigned int state;
};

struct backlight_ops;

struct backlight_device {
	struct backlight_properties props;
	struct mutex update_lock;
	struct mutex ops_lock;
	const struct backlight_ops *ops;
	struct notifier_block fb_notif;
	struct list_head entry;
	struct device___264 dev;
	bool fb_bl_on[32];
	int use_count;
};

struct dmt_videomode {
	u32 dmt_id;
	u32 std_2byte_code;
	u32 cvt_3byte_code;
	const struct fb_videomode *mode;
};

enum backlight_update_reason {
	BACKLIGHT_UPDATE_HOTKEY = 0,
	BACKLIGHT_UPDATE_SYSFS = 1,
};

enum backlight_notification {
	BACKLIGHT_REGISTERED = 0,
	BACKLIGHT_UNREGISTERED = 1,
};

struct backlight_ops {
	unsigned int options;
	int (*update_status)(struct backlight_device *);
	int (*get_brightness)(struct backlight_device *);
	int (*check_fb)(struct backlight_device *, struct fb_info *);
};

struct file___300;

struct kiocb___300;

struct vm_area_struct___301;

struct inode___300;

struct file_lock___300;

struct page___301;

struct file_operations___300 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___300 *, loff_t, int);
	ssize_t (*read)(struct file___300 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___300 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___300 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___300 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___300 *, bool);
	int (*iterate)(struct file___300 *, struct dir_context *);
	int (*iterate_shared)(struct file___300 *, struct dir_context *);
	__poll_t (*poll)(struct file___300 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___300 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___300 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___300 *, struct vm_area_struct___301 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___300 *, struct file___300 *);
	int (*flush)(struct file___300 *, fl_owner_t);
	int (*release)(struct inode___300 *, struct file___300 *);
	int (*fsync)(struct file___300 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___300 *, int);
	int (*lock)(struct file___300 *, int, struct file_lock___300 *);
	ssize_t (*sendpage)(struct file___300 *, struct page___301 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___300 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___300 *, int, struct file_lock___300 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___300 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___300 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___300 *, long int, struct file_lock___300 **, void **);
	long int (*fallocate)(struct file___300 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___300 *);
	ssize_t (*copy_file_range)(struct file___300 *, loff_t, struct file___300 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___300 *, loff_t, struct file___300 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___300 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___300 {
	u64 seqnum;
	struct vm_area_struct___301 *vmas[4];
};

struct page_frag___300 {
	struct page___301 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___300;

struct pid___198;

struct cred___278;

struct nsproxy___245;

struct signal_struct___224;

struct vm_struct___216;

struct task_struct___301 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___301 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___300 *mm;
	struct mm_struct___300 *active_mm;
	struct vmacache___300 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___301 *real_parent;
	struct task_struct___301 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___301 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___198 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___198 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___198 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___278 *ptracer_cred;
	const struct cred___278 *real_cred;
	const struct cred___278 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___245 *nsproxy;
	struct signal_struct___224 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___301 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___82 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___300 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___301 *oom_reaper_list;
	struct vm_struct___216 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___131 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___198;

struct upid___198 {
	int nr;
	struct pid_namespace___198 *ns;
};

struct dentry___300;

struct pid_namespace___198 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___301 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___198 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___300 *proc_self;
	struct dentry___300 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___3 *user_ns;
	struct ucounts___2 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___9 ns;
};

struct pid___198 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___198 numbers[1];
};

struct secondary_data___301 {
	void *stack;
	struct task_struct___301 *task;
	long int status;
};

typedef struct page___301 *pgtable_t___300;

struct address_space___299;

struct dev_pagemap___289;

struct page___301 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___299 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___301 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___300 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___300 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___289 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct key___278;

struct user_struct___278 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___278 *uid_keyring;
	struct key___278 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___289;

struct vm_area_struct___301 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___301 *vm_next;
	struct vm_area_struct___301 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___300 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___289 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___300 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct rw_semaphore___301 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___301 *owner;
};

struct core_state___300;

struct mm_struct___300 {
	struct {
		struct vm_area_struct___301 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___300 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___301 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___300 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___301 *owner;
		struct user_namespace___3 *user_ns;
		struct file___300 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___300 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___278 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___278 *session_keyring;
	struct key___278 *process_keyring;
	struct key___278 *thread_keyring;
	struct key___278 *request_key_auth;
	void *security;
	struct user_struct___278 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct nsproxy___245 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___198 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct signal_struct___224 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___301 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___301 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___198 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___198 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___300 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___198 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_struct___216 {
	struct vm_struct___216 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___301 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___236 {
	struct task_struct___301 task;
	long unsigned int stack[8192];
};

typedef int (*key_restrict_link_func_t___279)(struct key___278 *, const struct key_type *, const union key_payload *, struct key___278 *);

struct key_restriction___278;

struct key___278 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___301 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___278 *restrict_link;
};

struct key_restriction___278 {
	key_restrict_link_func_t___279 check;
	struct key___278 *key;
	struct key_type *keytype;
};

struct pglist_data___300;

struct lruvec___300 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___300 *pgdat;
};

struct zone___300 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___300 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___300 {
	struct zone___300 *zone;
	int zone_idx;
};

struct zonelist___300 {
	struct zoneref___300 _zonerefs[25];
};

struct pglist_data___300 {
	struct zone___300 node_zones[3];
	struct zonelist___300 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___301 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___301 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___300 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___300 {
	struct rw_semaphore___301 rwsem;
	struct notifier_block *head;
};

struct address_space_operations___299;

struct address_space___299 {
	struct inode___300 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___301 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___299 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___289)(struct vm_area_struct___301 *, long unsigned int, const struct page___301 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___289)(struct page___301 *, void *);

struct device___265;

struct dev_pagemap___289 {
	dev_page_fault_t___289 page_fault;
	dev_page_free_t___289 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___265 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___300 {
	struct vfsmount *mnt;
	struct dentry___300 *dentry;
};

struct fown_struct___198 {
	rwlock_t lock;
	struct pid___198 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___300 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___300 f_path;
	struct inode___300 *f_inode;
	const struct file_operations___300 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___198 f_owner;
	const struct cred___278 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___299 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___289;

struct vm_operations_struct___289 {
	void (*open)(struct vm_area_struct___301 *);
	void (*close)(struct vm_area_struct___301 *);
	int (*split)(struct vm_area_struct___301 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___301 *);
	vm_fault_t (*fault)(struct vm_fault___289 *);
	vm_fault_t (*huge_fault)(struct vm_fault___289 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___289 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___301 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___289 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___289 *);
	int (*access)(struct vm_area_struct___301 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___301 *);
	int (*set_policy)(struct vm_area_struct___301 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___301 *, long unsigned int);
	struct page___301 * (*find_special_page)(struct vm_area_struct___301 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___300 {
	struct task_struct___301 *task;
	struct core_thread___300 *next;
};

struct core_state___300 {
	atomic_t nr_threads;
	struct core_thread___300 dumper;
	struct completion startup;
};

struct vm_fault___289 {
	struct vm_area_struct___301 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___301 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___301 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___300 prealloc_pte;
};

struct kset___286;

struct kobj_type___286;

struct kernfs_node___294;

struct kobject___287 {
	const char *name;
	struct list_head entry;
	struct kobject___287 *parent;
	struct kset___286 *kset;
	struct kobj_type___286 *ktype;
	struct kernfs_node___294 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___265 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___265 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___265;

struct bus_type___265;

struct device_driver___265;

struct dev_pm_domain___265;

struct irq_domain___16;

struct device_node___57;

struct fwnode_handle___199;

struct class___265;

struct attribute_group___264;

struct device___265 {
	struct device___265 *parent;
	struct device_private *p;
	struct kobject___287 kobj;
	const char *init_name;
	const struct device_type___265 *type;
	struct mutex mutex;
	struct bus_type___265 *bus;
	struct device_driver___265 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___265 power;
	struct dev_pm_domain___265 *pm_domain;
	struct irq_domain___16 *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___57 *of_node;
	struct fwnode_handle___199 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___265 *class;
	const struct attribute_group___264 **groups;
	void (*release)(struct device___265 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___299;

struct super_block___299;

struct dentry___300 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___300 *d_parent;
	struct qstr d_name;
	struct inode___300 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___299 *d_op;
	struct super_block___299 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___299;

struct block_device___299;

struct inode___300 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___299 *i_op;
	struct super_block___299 *i_sb;
	struct address_space___299 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___301 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___300 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___299 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___299 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___299 {
	int (*d_revalidate)(struct dentry___300 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___300 *, unsigned int);
	int (*d_hash)(const struct dentry___300 *, struct qstr *);
	int (*d_compare)(const struct dentry___300 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___300 *);
	int (*d_init)(struct dentry___300 *);
	void (*d_release)(struct dentry___300 *);
	void (*d_prune)(struct dentry___300 *);
	void (*d_iput)(struct dentry___300 *, struct inode___300 *);
	char * (*d_dname)(struct dentry___300 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___300 *);
	int (*d_manage)(const struct path___300 *, bool);
	struct dentry___300 * (*d_real)(struct dentry___300 *, const struct inode___300 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___299;

struct mem_dqinfo___299 {
	struct quota_format_type___299 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___299;

struct quota_info___299 {
	unsigned int flags;
	struct rw_semaphore___301 dqio_sem;
	struct inode___300 *files[3];
	struct mem_dqinfo___299 info[3];
	const struct quota_format_ops___299 *ops[3];
};

struct rcuwait___299 {
	struct task_struct___301 *task;
};

struct percpu_rw_semaphore___299 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___301 rw_sem;
	struct rcuwait___299 writer;
	int readers_block;
};

struct sb_writers___299 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___299 rw_sem[3];
};

struct file_system_type___299;

struct super_operations___299;

struct dquot_operations___299;

struct quotactl_ops___299;

struct super_block___299 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___299 *s_type;
	const struct super_operations___299 *s_op;
	const struct dquot_operations___299 *dq_op;
	const struct quotactl_ops___299 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___300 *s_root;
	struct rw_semaphore___301 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___299 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___299 s_dquot;
	struct sb_writers___299 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___299 *s_d_op;
	int cleancache_poolid;
	struct shrinker___116 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___300 {
	struct file___300 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___300 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___299 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___300 *ia_file;
};

struct dquot___299 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___299 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___299 {
	int qf_fmt_id;
	const struct quota_format_ops___299 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___299 *qf_next;
};

struct quota_format_ops___299 {
	int (*check_quota_file)(struct super_block___299 *, int);
	int (*read_file_info)(struct super_block___299 *, int);
	int (*write_file_info)(struct super_block___299 *, int);
	int (*free_file_info)(struct super_block___299 *, int);
	int (*read_dqblk)(struct dquot___299 *);
	int (*commit_dqblk)(struct dquot___299 *);
	int (*release_dqblk)(struct dquot___299 *);
	int (*get_next_id)(struct super_block___299 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___299 {
	int (*write_dquot)(struct dquot___299 *);
	struct dquot___299 * (*alloc_dquot)(struct super_block___299 *, int);
	void (*destroy_dquot)(struct dquot___299 *);
	int (*acquire_dquot)(struct dquot___299 *);
	int (*release_dquot)(struct dquot___299 *);
	int (*mark_dirty)(struct dquot___299 *);
	int (*write_info)(struct super_block___299 *, int);
	qsize_t * (*get_reserved_space)(struct inode___300 *);
	int (*get_projid)(struct inode___300 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___300 *, qsize_t *);
	int (*get_next_id)(struct super_block___299 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___299 {
	int (*quota_on)(struct super_block___299 *, int, int, const struct path___300 *);
	int (*quota_off)(struct super_block___299 *, int);
	int (*quota_enable)(struct super_block___299 *, unsigned int);
	int (*quota_disable)(struct super_block___299 *, unsigned int);
	int (*quota_sync)(struct super_block___299 *, int);
	int (*set_info)(struct super_block___299 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___299 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___299 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___299 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___299 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___299 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___299 {
	int (*writepage)(struct page___301 *, struct writeback_control___3 *);
	int (*readpage)(struct file___300 *, struct page___301 *);
	int (*writepages)(struct address_space___299 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___301 *);
	int (*readpages)(struct file___300 *, struct address_space___299 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___300 *, struct address_space___299 *, loff_t, unsigned int, unsigned int, struct page___301 **, void **);
	int (*write_end)(struct file___300 *, struct address_space___299 *, loff_t, unsigned int, unsigned int, struct page___301 *, void *);
	sector_t (*bmap)(struct address_space___299 *, sector_t);
	void (*invalidatepage)(struct page___301 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___301 *, gfp_t);
	void (*freepage)(struct page___301 *);
	ssize_t (*direct_IO)(struct kiocb___300 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___299 *, struct page___301 *, struct page___301 *, enum migrate_mode);
	bool (*isolate_page)(struct page___301 *, isolate_mode_t);
	void (*putback_page)(struct page___301 *);
	int (*launder_page)(struct page___301 *);
	int (*is_partially_uptodate)(struct page___301 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___301 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___299 *, struct page___301 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___300 *, sector_t *);
	void (*swap_deactivate)(struct file___300 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___299 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___300 *bd_inode;
	struct super_block___299 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___299 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___299 {
	struct dentry___300 * (*lookup)(struct inode___300 *, struct dentry___300 *, unsigned int);
	const char * (*get_link)(struct dentry___300 *, struct inode___300 *, struct delayed_call *);
	int (*permission)(struct inode___300 *, int);
	struct posix_acl * (*get_acl)(struct inode___300 *, int);
	int (*readlink)(struct dentry___300 *, char *, int);
	int (*create)(struct inode___300 *, struct dentry___300 *, umode_t, bool);
	int (*link)(struct dentry___300 *, struct inode___300 *, struct dentry___300 *);
	int (*unlink)(struct inode___300 *, struct dentry___300 *);
	int (*symlink)(struct inode___300 *, struct dentry___300 *, const char *);
	int (*mkdir)(struct inode___300 *, struct dentry___300 *, umode_t);
	int (*rmdir)(struct inode___300 *, struct dentry___300 *);
	int (*mknod)(struct inode___300 *, struct dentry___300 *, umode_t, dev_t);
	int (*rename)(struct inode___300 *, struct dentry___300 *, struct inode___300 *, struct dentry___300 *, unsigned int);
	int (*setattr)(struct dentry___300 *, struct iattr___299 *);
	int (*getattr)(const struct path___300 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___300 *, char *, size_t);
	int (*fiemap)(struct inode___300 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___300 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___300 *, struct dentry___300 *, struct file___300 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___300 *, struct dentry___300 *, umode_t);
	int (*set_acl)(struct inode___300 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___299 {
	void (*fl_copy_lock)(struct file_lock___300 *, struct file_lock___300 *);
	void (*fl_release_private)(struct file_lock___300 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___299;

struct lock_manager_operations___299;

struct file_lock___300 {
	struct file_lock___300 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___300 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___299 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___299 *fl_ops;
	const struct lock_manager_operations___299 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___299 {
	int (*lm_compare_owner)(struct file_lock___300 *, struct file_lock___300 *);
	long unsigned int (*lm_owner_key)(struct file_lock___300 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___300 *);
	int (*lm_grant)(struct file_lock___300 *, int);
	bool (*lm_break)(struct file_lock___300 *);
	int (*lm_change)(struct file_lock___300 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___300 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___299 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___299 *fa_next;
	struct file___300 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___299 {
	const char *name;
	int fs_flags;
	struct dentry___300 * (*mount)(struct file_system_type___299 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___299 *);
	struct module___11 *owner;
	struct file_system_type___299 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___299 {
	struct inode___300 * (*alloc_inode)(struct super_block___299 *);
	void (*destroy_inode)(struct inode___300 *);
	void (*dirty_inode)(struct inode___300 *, int);
	int (*write_inode)(struct inode___300 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___300 *);
	void (*evict_inode)(struct inode___300 *);
	void (*put_super)(struct super_block___299 *);
	int (*sync_fs)(struct super_block___299 *, int);
	int (*freeze_super)(struct super_block___299 *);
	int (*freeze_fs)(struct super_block___299 *);
	int (*thaw_super)(struct super_block___299 *);
	int (*unfreeze_fs)(struct super_block___299 *);
	int (*statfs)(struct dentry___300 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___299 *, int *, char *);
	void (*umount_begin)(struct super_block___299 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___300 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___300 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___300 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___300 *);
	ssize_t (*quota_read)(struct super_block___299 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___299 *, int, const char *, size_t, loff_t);
	struct dquot___299 ** (*get_dquots)(struct inode___300 *);
	int (*bdev_try_to_free_page)(struct super_block___299 *, struct page___301 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___299 *, struct shrink_control___116 *);
	long int (*free_cached_objects)(struct super_block___299 *, struct shrink_control___116 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_attribute___279 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___287 *, struct kobj_attribute___279 *, char *);
	ssize_t (*store)(struct kobject___287 *, struct kobj_attribute___279 *, const char *, size_t);
};

typedef void compound_page_dtor___289(struct page___301 *);

struct kernfs_root___293;

struct kernfs_elem_dir___293 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___293 *root;
};

struct kernfs_syscall_ops___293;

struct kernfs_root___293 {
	struct kernfs_node___294 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___293 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___293 {
	struct kernfs_node___294 *target_kn;
};

struct kernfs_ops___293;

struct kernfs_elem_attr___293 {
	const struct kernfs_ops___293 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___294 *notify_next;
};

struct kernfs_node___294 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___294 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___293 dir;
		struct kernfs_elem_symlink___293 symlink;
		struct kernfs_elem_attr___293 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___293;

struct kernfs_ops___293 {
	int (*open)(struct kernfs_open_file___293 *);
	void (*release)(struct kernfs_open_file___293 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___293 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___293 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___293 *, struct vm_area_struct___301 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___293 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___293 {
	int (*remount_fs)(struct kernfs_root___293 *, int *, char *);
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___293 *);
	int (*mkdir)(struct kernfs_node___294 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___294 *);
	int (*rename)(struct kernfs_node___294 *, struct kernfs_node___294 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___294 *, struct kernfs_root___293 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___293 {
	struct kernfs_node___294 *kn;
	struct file___300 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___289 *vm_ops;
};

struct bin_attribute___263;

struct attribute_group___264 {
	const char *name;
	umode_t (*is_visible)(struct kobject___287 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___287 *, struct bin_attribute___263 *, int);
	struct attribute **attrs;
	struct bin_attribute___263 **bin_attrs;
};

struct bin_attribute___263 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___300 *, struct kobject___287 *, struct bin_attribute___263 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___300 *, struct kobject___287 *, struct bin_attribute___263 *, char *, loff_t, size_t);
	int (*mmap)(struct file___300 *, struct kobject___287 *, struct bin_attribute___263 *, struct vm_area_struct___301 *);
};

struct sysfs_ops___286 {
	ssize_t (*show)(struct kobject___287 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___287 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___286;

struct kset___286 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___287 kobj;
	const struct kset_uevent_ops___286 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___286 {
	void (*release)(struct kobject___287 *);
	const struct sysfs_ops___286 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___25 * (*child_ns_type)(struct kobject___287 *);
	const void * (*namespace)(struct kobject___287 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___286 {
	int (* const filter)(struct kset___286 *, struct kobject___287 *);
	const char * (* const name)(struct kset___286 *, struct kobject___287 *);
	int (* const uevent)(struct kset___286 *, struct kobject___287 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___265 {
	int (*prepare)(struct device___265 *);
	void (*complete)(struct device___265 *);
	int (*suspend)(struct device___265 *);
	int (*resume)(struct device___265 *);
	int (*freeze)(struct device___265 *);
	int (*thaw)(struct device___265 *);
	int (*poweroff)(struct device___265 *);
	int (*restore)(struct device___265 *);
	int (*suspend_late)(struct device___265 *);
	int (*resume_early)(struct device___265 *);
	int (*freeze_late)(struct device___265 *);
	int (*thaw_early)(struct device___265 *);
	int (*poweroff_late)(struct device___265 *);
	int (*restore_early)(struct device___265 *);
	int (*suspend_noirq)(struct device___265 *);
	int (*resume_noirq)(struct device___265 *);
	int (*freeze_noirq)(struct device___265 *);
	int (*thaw_noirq)(struct device___265 *);
	int (*poweroff_noirq)(struct device___265 *);
	int (*restore_noirq)(struct device___265 *);
	int (*runtime_suspend)(struct device___265 *);
	int (*runtime_resume)(struct device___265 *);
	int (*runtime_idle)(struct device___265 *);
};

struct dev_pm_domain___265 {
	struct dev_pm_ops___265 ops;
	void (*detach)(struct device___265 *, bool);
	int (*activate)(struct device___265 *);
	void (*sync)(struct device___265 *);
	void (*dismiss)(struct device___265 *);
};

struct bus_type___265 {
	const char *name;
	const char *dev_name;
	struct device___265 *dev_root;
	const struct attribute_group___264 **bus_groups;
	const struct attribute_group___264 **dev_groups;
	const struct attribute_group___264 **drv_groups;
	int (*match)(struct device___265 *, struct device_driver___265 *);
	int (*uevent)(struct device___265 *, struct kobj_uevent_env *);
	int (*probe)(struct device___265 *);
	int (*remove)(struct device___265 *);
	void (*shutdown)(struct device___265 *);
	int (*online)(struct device___265 *);
	int (*offline)(struct device___265 *);
	int (*suspend)(struct device___265 *, pm_message_t);
	int (*resume)(struct device___265 *);
	int (*num_vf)(struct device___265 *);
	int (*dma_configure)(struct device___265 *);
	const struct dev_pm_ops___265 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___265 {
	const char *name;
	struct bus_type___265 *bus;
	struct module___11 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___265 *);
	int (*remove)(struct device___265 *);
	void (*shutdown)(struct device___265 *);
	int (*suspend)(struct device___265 *, pm_message_t);
	int (*resume)(struct device___265 *);
	const struct attribute_group___264 **groups;
	const struct dev_pm_ops___265 *pm;
	void (*coredump)(struct device___265 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___265 {
	const char *name;
	const struct attribute_group___264 **groups;
	int (*uevent)(struct device___265 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___265 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___265 *);
	const struct dev_pm_ops___265 *pm;
};

struct class___265 {
	const char *name;
	struct module___11 *owner;
	const struct attribute_group___264 **class_groups;
	const struct attribute_group___264 **dev_groups;
	struct kobject___287 *dev_kobj;
	int (*dev_uevent)(struct device___265 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___265 *, umode_t *);
	void (*class_release)(struct class___265 *);
	void (*dev_release)(struct device___265 *);
	int (*shutdown_pre)(struct device___265 *);
	const struct kobj_ns_type_operations___25 *ns_type;
	const void * (*namespace)(struct device___265 *);
	const struct dev_pm_ops___265 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct irq_domain_ops___16;

struct irq_domain___16 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___16 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___199 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___2 *gc;
	struct irq_domain___16 *parent;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_direct_max_irq;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_tree_mutex;
	unsigned int linear_revmap[0];
};

struct fwnode_operations___199;

struct fwnode_handle___199 {
	struct fwnode_handle___199 *secondary;
	const struct fwnode_operations___199 *ops;
};

struct property___54;

struct device_node___57 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___199 fwnode;
	struct property___54 *properties;
	struct property___54 *deadprops;
	struct device_node___57 *parent;
	struct device_node___57 *child;
	struct device_node___57 *sibling;
	struct kobject___287 kobj;
	long unsigned int _flags;
	void *data;
};

struct fwnode_reference_args___199;

struct fwnode_endpoint___199;

struct fwnode_operations___199 {
	struct fwnode_handle___199 * (*get)(struct fwnode_handle___199 *);
	void (*put)(struct fwnode_handle___199 *);
	bool (*device_is_available)(const struct fwnode_handle___199 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___199 *, const struct device___265 *);
	bool (*property_present)(const struct fwnode_handle___199 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___199 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___199 *, const char *, const char **, size_t);
	struct fwnode_handle___199 * (*get_parent)(const struct fwnode_handle___199 *);
	struct fwnode_handle___199 * (*get_next_child_node)(const struct fwnode_handle___199 *, struct fwnode_handle___199 *);
	struct fwnode_handle___199 * (*get_named_child_node)(const struct fwnode_handle___199 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___199 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___199 *);
	struct fwnode_handle___199 * (*graph_get_next_endpoint)(const struct fwnode_handle___199 *, struct fwnode_handle___199 *);
	struct fwnode_handle___199 * (*graph_get_remote_endpoint)(const struct fwnode_handle___199 *);
	struct fwnode_handle___199 * (*graph_get_port_parent)(struct fwnode_handle___199 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___199 *, struct fwnode_endpoint___199 *);
};

struct fwnode_endpoint___199 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___199 *local_fwnode;
};

struct fwnode_reference_args___199 {
	struct fwnode_handle___199 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct property___54 {
	char *name;
	int length;
	void *value;
	struct property___54 *next;
	long unsigned int _flags;
	struct bin_attribute___263 attr;
};

struct irq_fwspec___16 {
	struct fwnode_handle___199 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___16 {
	int (*match)(struct irq_domain___16 *, struct device_node___57 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___16 *, struct irq_fwspec___16 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___16 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___16 *, unsigned int);
	int (*xlate)(struct irq_domain___16 *, struct device_node___57 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___16 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___16 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___16 *, struct irq_data___5 *, bool);
	void (*deactivate)(struct irq_domain___16 *, struct irq_data___5 *);
	int (*translate)(struct irq_domain___16 *, struct irq_fwspec___16 *, long unsigned int *, unsigned int *);
};

struct backlight_device___2;

struct fb_info___2;

struct backlight_ops___2 {
	unsigned int options;
	int (*update_status)(struct backlight_device___2 *);
	int (*get_brightness)(struct backlight_device___2 *);
	int (*check_fb)(struct backlight_device___2 *, struct fb_info___2 *);
};

struct backlight_device___2 {
	struct backlight_properties props;
	struct mutex update_lock;
	struct mutex ops_lock;
	const struct backlight_ops___2 *ops;
	struct notifier_block fb_notif;
	struct list_head entry;
	struct device___265 dev;
	bool fb_bl_on[32];
	int use_count;
};

struct fb_pixmap___2 {
	u8 *addr;
	u32 size;
	u32 offset;
	u32 buf_align;
	u32 scan_align;
	u32 access_align;
	u32 flags;
	u32 blit_x;
	u32 blit_y;
	void (*writeio)(struct fb_info___2 *, void *, void *, unsigned int);
	void (*readio)(struct fb_info___2 *, void *, void *, unsigned int);
};

struct fb_deferred_io___2;

struct fb_ops___2;

struct fb_tile_ops___2;

struct fb_info___2 {
	atomic_t count;
	int node;
	int flags;
	int fbcon_rotate_hint;
	struct mutex lock;
	struct mutex mm_lock;
	struct fb_var_screeninfo var;
	struct fb_fix_screeninfo fix;
	struct fb_monspecs monspecs;
	struct work_struct queue;
	struct fb_pixmap___2 pixmap;
	struct fb_pixmap___2 sprite;
	struct fb_cmap cmap;
	struct list_head modelist;
	struct fb_videomode *mode;
	struct backlight_device___2 *bl_dev;
	struct mutex bl_curve_mutex;
	u8 bl_curve[128];
	struct delayed_work deferred_work;
	struct fb_deferred_io___2 *fbdefio;
	struct fb_ops___2 *fbops;
	struct device___265 *device;
	struct device___265 *dev;
	int class_flag;
	struct fb_tile_ops___2 *tileops;
	union {
		char *screen_base;
		char *screen_buffer;
	};
	long unsigned int screen_size;
	void *pseudo_palette;
	u32 state;
	void *fbcon_par;
	void *par;
	struct apertures_struct *apertures;
	bool skip_vt_switch;
};

struct fb_deferred_io___2 {
	long unsigned int delay;
	struct mutex lock;
	struct list_head pagelist;
	void (*first_io)(struct fb_info___2 *);
	void (*deferred_io)(struct fb_info___2 *, struct list_head *);
};

struct fb_ops___2 {
	struct module___11 *owner;
	int (*fb_open)(struct fb_info___2 *, int);
	int (*fb_release)(struct fb_info___2 *, int);
	ssize_t (*fb_read)(struct fb_info___2 *, char *, size_t, loff_t *);
	ssize_t (*fb_write)(struct fb_info___2 *, const char *, size_t, loff_t *);
	int (*fb_check_var)(struct fb_var_screeninfo *, struct fb_info___2 *);
	int (*fb_set_par)(struct fb_info___2 *);
	int (*fb_setcolreg)(unsigned int, unsigned int, unsigned int, unsigned int, unsigned int, struct fb_info___2 *);
	int (*fb_setcmap)(struct fb_cmap *, struct fb_info___2 *);
	int (*fb_blank)(int, struct fb_info___2 *);
	int (*fb_pan_display)(struct fb_var_screeninfo *, struct fb_info___2 *);
	void (*fb_fillrect)(struct fb_info___2 *, const struct fb_fillrect *);
	void (*fb_copyarea)(struct fb_info___2 *, const struct fb_copyarea *);
	void (*fb_imageblit)(struct fb_info___2 *, const struct fb_image *);
	int (*fb_cursor)(struct fb_info___2 *, struct fb_cursor *);
	int (*fb_sync)(struct fb_info___2 *);
	int (*fb_ioctl)(struct fb_info___2 *, unsigned int, long unsigned int);
	int (*fb_compat_ioctl)(struct fb_info___2 *, unsigned int, long unsigned int);
	int (*fb_mmap)(struct fb_info___2 *, struct vm_area_struct___301 *);
	void (*fb_get_caps)(struct fb_info___2 *, struct fb_blit_caps *, struct fb_var_screeninfo *);
	void (*fb_destroy)(struct fb_info___2 *);
	int (*fb_debug_enter)(struct fb_info___2 *);
	int (*fb_debug_leave)(struct fb_info___2 *);
};

struct fb_tile_ops___2 {
	void (*fb_settile)(struct fb_info___2 *, struct fb_tilemap *);
	void (*fb_tilecopy)(struct fb_info___2 *, struct fb_tilearea *);
	void (*fb_tilefill)(struct fb_info___2 *, struct fb_tilerect *);
	void (*fb_tileblit)(struct fb_info___2 *, struct fb_tileblit *);
	void (*fb_tilecursor)(struct fb_info___2 *, struct fb_tilecursor *);
	int (*fb_get_tilemax)(struct fb_info___2 *);
};

struct module___242;

struct file___301;

struct kiocb___301;

struct poll_table_struct___182;

struct vm_area_struct___302;

struct inode___301;

struct file_lock___301;

struct page___302;

struct seq_file___255;

struct file_operations___301 {
	struct module___242 *owner;
	loff_t (*llseek)(struct file___301 *, loff_t, int);
	ssize_t (*read)(struct file___301 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___301 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___301 *, struct iov_iter___137 *);
	ssize_t (*write_iter)(struct kiocb___301 *, struct iov_iter___137 *);
	int (*iopoll)(struct kiocb___301 *, bool);
	int (*iterate)(struct file___301 *, struct dir_context *);
	int (*iterate_shared)(struct file___301 *, struct dir_context *);
	__poll_t (*poll)(struct file___301 *, struct poll_table_struct___182 *);
	long int (*unlocked_ioctl)(struct file___301 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___301 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___301 *, struct vm_area_struct___302 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___301 *, struct file___301 *);
	int (*flush)(struct file___301 *, fl_owner_t);
	int (*release)(struct inode___301 *, struct file___301 *);
	int (*fsync)(struct file___301 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___301 *, int);
	int (*lock)(struct file___301 *, int, struct file_lock___301 *);
	ssize_t (*sendpage)(struct file___301 *, struct page___302 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___301 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___301 *, int, struct file_lock___301 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___301 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___301 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___301 *, long int, struct file_lock___301 **, void **);
	long int (*fallocate)(struct file___301 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___255 *, struct file___301 *);
	ssize_t (*copy_file_range)(struct file___301 *, loff_t, struct file___301 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___301 *, loff_t, struct file___301 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___301 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___301 {
	u64 seqnum;
	struct vm_area_struct___302 *vmas[4];
};

struct page_frag___301 {
	struct page___302 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___301;

struct pid___199;

struct cred___279;

struct nsproxy___246;

struct signal_struct___225;

struct vm_struct___217;

struct task_struct___302 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___302 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___301 *mm;
	struct mm_struct___301 *active_mm;
	struct vmacache___301 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___302 *real_parent;
	struct task_struct___302 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___302 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___199 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___199 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___199 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___279 *ptracer_cred;
	const struct cred___279 *real_cred;
	const struct cred___279 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___246 *nsproxy;
	struct signal_struct___225 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___302 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___82 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___301 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___302 *oom_reaper_list;
	struct vm_struct___217 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___131 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___302 *pgtable_t___301;

struct address_space___300;

struct dev_pagemap___290;

struct page___302 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___300 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___302 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___301 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___301 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___290 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___301;

struct lruvec___301 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___301 *pgdat;
};

struct zone___301 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___301 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___301 {
	struct zone___301 *zone;
	int zone_idx;
};

struct zonelist___301 {
	struct zoneref___301 _zonerefs[25];
};

struct pglist_data___301 {
	struct zone___301 node_zones[3];
	struct zonelist___301 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___302 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___302 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___301 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___302 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___302 *owner;
};

struct secondary_data___302 {
	void *stack;
	struct task_struct___302 *task;
	long int status;
};

struct blocking_notifier_head___301 {
	struct rw_semaphore___302 rwsem;
	struct notifier_block *head;
};

struct dentry___301;

struct path___301 {
	struct vfsmount *mnt;
	struct dentry___301 *dentry;
};

struct fown_struct___199 {
	rwlock_t lock;
	struct pid___199 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___301 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___301 f_path;
	struct inode___301 *f_inode;
	const struct file_operations___301 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___199 f_owner;
	const struct cred___279 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___300 *f_mapping;
	errseq_t f_wb_err;
};

struct key___279;

struct user_struct___279;

struct cred___279 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___279 *session_keyring;
	struct key___279 *process_keyring;
	struct key___279 *thread_keyring;
	struct key___279 *request_key_auth;
	void *security;
	struct user_struct___279 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___294;

struct kernfs_elem_dir___294 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___294 *root;
};

struct kernfs_node___295;

struct kernfs_syscall_ops___294;

struct kernfs_root___294 {
	struct kernfs_node___295 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___294 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___294 {
	struct kernfs_node___295 *target_kn;
};

struct kernfs_ops___294;

struct kernfs_elem_attr___294 {
	const struct kernfs_ops___294 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___295 *notify_next;
};

struct kernfs_node___295 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___295 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___294 dir;
		struct kernfs_elem_symlink___294 symlink;
		struct kernfs_elem_attr___294 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___294;

struct kernfs_ops___294 {
	int (*open)(struct kernfs_open_file___294 *);
	void (*release)(struct kernfs_open_file___294 *);
	int (*seq_show)(struct seq_file___255 *, void *);
	void * (*seq_start)(struct seq_file___255 *, loff_t *);
	void * (*seq_next)(struct seq_file___255 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___255 *, void *);
	ssize_t (*read)(struct kernfs_open_file___294 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___294 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___294 *, struct vm_area_struct___302 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___294 *, struct poll_table_struct___182 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___294 {
	int (*remount_fs)(struct kernfs_root___294 *, int *, char *);
	int (*show_options)(struct seq_file___255 *, struct kernfs_root___294 *);
	int (*mkdir)(struct kernfs_node___295 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___295 *);
	int (*rename)(struct kernfs_node___295 *, struct kernfs_node___295 *, const char *);
	int (*show_path)(struct seq_file___255 *, struct kernfs_node___295 *, struct kernfs_root___294 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___254;

struct seq_file___255 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___254 *op;
	int poll_event;
	const struct file___301 *file;
	void *private;
};

struct vm_operations_struct___290;

struct kernfs_open_file___294 {
	struct kernfs_node___295 *kn;
	struct file___301 *file;
	struct seq_file___255 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___290 *vm_ops;
};

struct vm_fault___290;

struct vm_operations_struct___290 {
	void (*open)(struct vm_area_struct___302 *);
	void (*close)(struct vm_area_struct___302 *);
	int (*split)(struct vm_area_struct___302 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___302 *);
	vm_fault_t (*fault)(struct vm_fault___290 *);
	vm_fault_t (*huge_fault)(struct vm_fault___290 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___290 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___302 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___290 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___290 *);
	int (*access)(struct vm_area_struct___302 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___302 *);
	int (*set_policy)(struct vm_area_struct___302 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___302 *, long unsigned int);
	struct page___302 * (*find_special_page)(struct vm_area_struct___302 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___185)(struct file___301 *, wait_queue_head_t *, struct poll_table_struct___182 *);

struct poll_table_struct___182 {
	poll_queue_proc___185 _qproc;
	__poll_t _key;
};

struct vm_area_struct___302 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___302 *vm_next;
	struct vm_area_struct___302 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___301 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___290 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___301 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___288;

struct bin_attribute___264;

struct attribute_group___265 {
	const char *name;
	umode_t (*is_visible)(struct kobject___288 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___288 *, struct bin_attribute___264 *, int);
	struct attribute **attrs;
	struct bin_attribute___264 **bin_attrs;
};

struct kset___287;

struct kobj_type___287;

struct kobject___288 {
	const char *name;
	struct list_head entry;
	struct kobject___288 *parent;
	struct kset___287 *kset;
	struct kobj_type___287 *ktype;
	struct kernfs_node___295 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___264 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___301 *, struct kobject___288 *, struct bin_attribute___264 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___301 *, struct kobject___288 *, struct bin_attribute___264 *, char *, loff_t, size_t);
	int (*mmap)(struct file___301 *, struct kobject___288 *, struct bin_attribute___264 *, struct vm_area_struct___302 *);
};

struct sysfs_ops___287 {
	ssize_t (*show)(struct kobject___288 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___288 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___287;

struct kset___287 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___288 kobj;
	const struct kset_uevent_ops___287 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___287 {
	void (*release)(struct kobject___288 *);
	const struct sysfs_ops___287 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___25 * (*child_ns_type)(struct kobject___288 *);
	const void * (*namespace)(struct kobject___288 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___287 {
	int (* const filter)(struct kset___287 *, struct kobject___288 *);
	const char * (* const name)(struct kset___287 *, struct kobject___288 *);
	int (* const uevent)(struct kset___287 *, struct kobject___288 *, struct kobj_uevent_env *);
};

struct kobj_attribute___280 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___288 *, struct kobj_attribute___280 *, char *);
	ssize_t (*store)(struct kobject___288 *, struct kobj_attribute___280 *, const char *, size_t);
};

struct kernel_param___239;

struct kernel_param_ops___239 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___239 *);
	int (*get)(char *, const struct kernel_param___239 *);
	void (*free)(void *);
};

struct kparam_array___239;

struct kernel_param___239 {
	const char *name;
	struct module___242 *mod;
	const struct kernel_param_ops___239 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___239 *arr;
	};
};

struct kparam_array___239 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___239 *ops;
	void *elem;
};

struct module_kobject___239 {
	struct kobject___288 kobj;
	struct module___242 *mod;
	struct kobject___288 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___239 {
	struct module___242 *mod;
	struct latch_tree_node node;
};

struct module_layout___239 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___239 mtn;
};

struct module_attribute___239;

struct module___242 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___239 mkobj;
	struct module_attribute___239 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___288 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___239 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___239 core_layout;
	struct module_layout___239 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___239 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___239 *, struct module_kobject___239 *, char *);
	ssize_t (*store)(struct module_attribute___239 *, struct module_kobject___239 *, const char *, size_t);
	void (*setup)(struct module___242 *, const char *);
	int (*test)(struct module___242 *);
	void (*free)(struct module___242 *);
};

struct pid_namespace___199;

struct upid___199 {
	int nr;
	struct pid_namespace___199 *ns;
};

struct pid_namespace___199 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___302 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___199 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___301 *proc_self;
	struct dentry___301 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___3 *user_ns;
	struct ucounts___2 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___9 ns;
};

struct pid___199 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___199 numbers[1];
};

struct user_struct___279 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___279 *uid_keyring;
	struct key___279 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___301;

struct mm_struct___301 {
	struct {
		struct vm_area_struct___302 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___301 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___302 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___301 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___302 *owner;
		struct user_namespace___3 *user_ns;
		struct file___301 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___301 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct nsproxy___246 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___199 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct signal_struct___225 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___302 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___302 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___199 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___199 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___301 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___199 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_struct___217 {
	struct vm_struct___217 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___302 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___237 {
	struct task_struct___302 task;
	long unsigned int stack[8192];
};

struct address_space_operations___300;

struct address_space___300 {
	struct inode___301 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___302 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___300 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___290)(struct vm_area_struct___302 *, long unsigned int, const struct page___302 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___290)(struct page___302 *, void *);

struct device___266;

struct dev_pagemap___290 {
	dev_page_fault_t___290 page_fault;
	dev_page_free_t___290 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___266 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___301 {
	struct task_struct___302 *task;
	struct core_thread___301 *next;
};

struct core_state___301 {
	atomic_t nr_threads;
	struct core_thread___301 dumper;
	struct completion startup;
};

struct vm_fault___290 {
	struct vm_area_struct___302 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___302 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___302 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___301 prealloc_pte;
};

struct kiocb___301 {
	struct file___301 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___301 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dentry_operations___300;

struct super_block___300;

struct dentry___301 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___301 *d_parent;
	struct qstr d_name;
	struct inode___301 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___300 *d_op;
	struct super_block___300 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___300;

struct block_device___300;

struct cdev___54;

struct inode___301 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___300 *i_op;
	struct super_block___300 *i_sb;
	struct address_space___300 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___302 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___301 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___300 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___300 *i_bdev;
		struct cdev___54 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___300 {
	int (*d_revalidate)(struct dentry___301 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___301 *, unsigned int);
	int (*d_hash)(const struct dentry___301 *, struct qstr *);
	int (*d_compare)(const struct dentry___301 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___301 *);
	int (*d_init)(struct dentry___301 *);
	void (*d_release)(struct dentry___301 *);
	void (*d_prune)(struct dentry___301 *);
	void (*d_iput)(struct dentry___301 *, struct inode___301 *);
	char * (*d_dname)(struct dentry___301 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___301 *);
	int (*d_manage)(const struct path___301 *, bool);
	struct dentry___301 * (*d_real)(struct dentry___301 *, const struct inode___301 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___300;

struct mem_dqinfo___300 {
	struct quota_format_type___300 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___300;

struct quota_info___300 {
	unsigned int flags;
	struct rw_semaphore___302 dqio_sem;
	struct inode___301 *files[3];
	struct mem_dqinfo___300 info[3];
	const struct quota_format_ops___300 *ops[3];
};

struct rcuwait___300 {
	struct task_struct___302 *task;
};

struct percpu_rw_semaphore___300 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___302 rw_sem;
	struct rcuwait___300 writer;
	int readers_block;
};

struct sb_writers___300 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___300 rw_sem[3];
};

struct file_system_type___300;

struct super_operations___300;

struct dquot_operations___300;

struct quotactl_ops___300;

struct super_block___300 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___300 *s_type;
	const struct super_operations___300 *s_op;
	const struct dquot_operations___300 *dq_op;
	const struct quotactl_ops___300 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___301 *s_root;
	struct rw_semaphore___302 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___300 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___300 s_dquot;
	struct sb_writers___300 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___300 *s_d_op;
	int cleancache_poolid;
	struct shrinker___116 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct iattr___300 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___301 *ia_file;
};

struct dquot___300 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___300 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___300 {
	int qf_fmt_id;
	const struct quota_format_ops___300 *qf_ops;
	struct module___242 *qf_owner;
	struct quota_format_type___300 *qf_next;
};

struct quota_format_ops___300 {
	int (*check_quota_file)(struct super_block___300 *, int);
	int (*read_file_info)(struct super_block___300 *, int);
	int (*write_file_info)(struct super_block___300 *, int);
	int (*free_file_info)(struct super_block___300 *, int);
	int (*read_dqblk)(struct dquot___300 *);
	int (*commit_dqblk)(struct dquot___300 *);
	int (*release_dqblk)(struct dquot___300 *);
	int (*get_next_id)(struct super_block___300 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___300 {
	int (*write_dquot)(struct dquot___300 *);
	struct dquot___300 * (*alloc_dquot)(struct super_block___300 *, int);
	void (*destroy_dquot)(struct dquot___300 *);
	int (*acquire_dquot)(struct dquot___300 *);
	int (*release_dquot)(struct dquot___300 *);
	int (*mark_dirty)(struct dquot___300 *);
	int (*write_info)(struct super_block___300 *, int);
	qsize_t * (*get_reserved_space)(struct inode___301 *);
	int (*get_projid)(struct inode___301 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___301 *, qsize_t *);
	int (*get_next_id)(struct super_block___300 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___300 {
	int (*quota_on)(struct super_block___300 *, int, int, const struct path___301 *);
	int (*quota_off)(struct super_block___300 *, int);
	int (*quota_enable)(struct super_block___300 *, unsigned int);
	int (*quota_disable)(struct super_block___300 *, unsigned int);
	int (*quota_sync)(struct super_block___300 *, int);
	int (*set_info)(struct super_block___300 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___300 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___300 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___300 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___300 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___300 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___300 {
	int (*writepage)(struct page___302 *, struct writeback_control___3 *);
	int (*readpage)(struct file___301 *, struct page___302 *);
	int (*writepages)(struct address_space___300 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___302 *);
	int (*readpages)(struct file___301 *, struct address_space___300 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___301 *, struct address_space___300 *, loff_t, unsigned int, unsigned int, struct page___302 **, void **);
	int (*write_end)(struct file___301 *, struct address_space___300 *, loff_t, unsigned int, unsigned int, struct page___302 *, void *);
	sector_t (*bmap)(struct address_space___300 *, sector_t);
	void (*invalidatepage)(struct page___302 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___302 *, gfp_t);
	void (*freepage)(struct page___302 *);
	ssize_t (*direct_IO)(struct kiocb___301 *, struct iov_iter___137 *);
	int (*migratepage)(struct address_space___300 *, struct page___302 *, struct page___302 *, enum migrate_mode);
	bool (*isolate_page)(struct page___302 *, isolate_mode_t);
	void (*putback_page)(struct page___302 *);
	int (*launder_page)(struct page___302 *);
	int (*is_partially_uptodate)(struct page___302 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___302 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___300 *, struct page___302 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___301 *, sector_t *);
	void (*swap_deactivate)(struct file___301 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___300 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___301 *bd_inode;
	struct super_block___300 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___300 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___54 {
	struct kobject___288 kobj;
	struct module___242 *owner;
	const struct file_operations___301 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___300 {
	struct dentry___301 * (*lookup)(struct inode___301 *, struct dentry___301 *, unsigned int);
	const char * (*get_link)(struct dentry___301 *, struct inode___301 *, struct delayed_call *);
	int (*permission)(struct inode___301 *, int);
	struct posix_acl * (*get_acl)(struct inode___301 *, int);
	int (*readlink)(struct dentry___301 *, char *, int);
	int (*create)(struct inode___301 *, struct dentry___301 *, umode_t, bool);
	int (*link)(struct dentry___301 *, struct inode___301 *, struct dentry___301 *);
	int (*unlink)(struct inode___301 *, struct dentry___301 *);
	int (*symlink)(struct inode___301 *, struct dentry___301 *, const char *);
	int (*mkdir)(struct inode___301 *, struct dentry___301 *, umode_t);
	int (*rmdir)(struct inode___301 *, struct dentry___301 *);
	int (*mknod)(struct inode___301 *, struct dentry___301 *, umode_t, dev_t);
	int (*rename)(struct inode___301 *, struct dentry___301 *, struct inode___301 *, struct dentry___301 *, unsigned int);
	int (*setattr)(struct dentry___301 *, struct iattr___300 *);
	int (*getattr)(const struct path___301 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___301 *, char *, size_t);
	int (*fiemap)(struct inode___301 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___301 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___301 *, struct dentry___301 *, struct file___301 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___301 *, struct dentry___301 *, umode_t);
	int (*set_acl)(struct inode___301 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___300 {
	void (*fl_copy_lock)(struct file_lock___301 *, struct file_lock___301 *);
	void (*fl_release_private)(struct file_lock___301 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___300;

struct lock_manager_operations___300;

struct file_lock___301 {
	struct file_lock___301 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___301 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___300 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___300 *fl_ops;
	const struct lock_manager_operations___300 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___300 {
	int (*lm_compare_owner)(struct file_lock___301 *, struct file_lock___301 *);
	long unsigned int (*lm_owner_key)(struct file_lock___301 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___301 *);
	int (*lm_grant)(struct file_lock___301 *, int);
	bool (*lm_break)(struct file_lock___301 *);
	int (*lm_change)(struct file_lock___301 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___301 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___300 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___300 *fa_next;
	struct file___301 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___300 {
	const char *name;
	int fs_flags;
	struct dentry___301 * (*mount)(struct file_system_type___300 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___300 *);
	struct module___242 *owner;
	struct file_system_type___300 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___300 {
	struct inode___301 * (*alloc_inode)(struct super_block___300 *);
	void (*destroy_inode)(struct inode___301 *);
	void (*dirty_inode)(struct inode___301 *, int);
	int (*write_inode)(struct inode___301 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___301 *);
	void (*evict_inode)(struct inode___301 *);
	void (*put_super)(struct super_block___300 *);
	int (*sync_fs)(struct super_block___300 *, int);
	int (*freeze_super)(struct super_block___300 *);
	int (*freeze_fs)(struct super_block___300 *);
	int (*thaw_super)(struct super_block___300 *);
	int (*unfreeze_fs)(struct super_block___300 *);
	int (*statfs)(struct dentry___301 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___300 *, int *, char *);
	void (*umount_begin)(struct super_block___300 *);
	int (*show_options)(struct seq_file___255 *, struct dentry___301 *);
	int (*show_devname)(struct seq_file___255 *, struct dentry___301 *);
	int (*show_path)(struct seq_file___255 *, struct dentry___301 *);
	int (*show_stats)(struct seq_file___255 *, struct dentry___301 *);
	ssize_t (*quota_read)(struct super_block___300 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___300 *, int, const char *, size_t, loff_t);
	struct dquot___300 ** (*get_dquots)(struct inode___301 *);
	int (*bdev_try_to_free_page)(struct super_block___300 *, struct page___302 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___300 *, struct shrink_control___116 *);
	long int (*free_cached_objects)(struct super_block___300 *, struct shrink_control___116 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___266 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___266 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___266;

struct bus_type___266;

struct device_driver___266;

struct dev_pm_domain___266;

struct irq_domain___17;

struct dma_map_ops___86;

struct device_node___58;

struct fwnode_handle___200;

struct class___266;

struct device___266 {
	struct device___266 *parent;
	struct device_private *p;
	struct kobject___288 kobj;
	const char *init_name;
	const struct device_type___266 *type;
	struct mutex mutex;
	struct bus_type___266 *bus;
	struct device_driver___266 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___266 power;
	struct dev_pm_domain___266 *pm_domain;
	struct irq_domain___17 *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___86 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___58 *of_node;
	struct fwnode_handle___200 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___266 *class;
	const struct attribute_group___265 **groups;
	void (*release)(struct device___266 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

typedef void compound_page_dtor___290(struct page___302 *);

typedef int (*key_restrict_link_func_t___280)(struct key___279 *, const struct key_type *, const union key_payload *, struct key___279 *);

struct key_restriction___279;

struct key___279 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___302 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___279 *restrict_link;
};

struct key_restriction___279 {
	key_restrict_link_func_t___280 check;
	struct key___279 *key;
	struct key_type *keytype;
};

struct seq_operations___254 {
	void * (*start)(struct seq_file___255 *, loff_t *);
	void (*stop)(struct seq_file___255 *, void *);
	void * (*next)(struct seq_file___255 *, void *, loff_t *);
	int (*show)(struct seq_file___255 *, void *);
};

struct consw___12 {
	struct module___242 *owner;
	const char * (*con_startup)();
	void (*con_init)(struct vc_data *, int);
	void (*con_deinit)(struct vc_data *);
	void (*con_clear)(struct vc_data *, int, int, int, int);
	void (*con_putc)(struct vc_data *, int, int, int);
	void (*con_putcs)(struct vc_data *, const short unsigned int *, int, int, int);
	void (*con_cursor)(struct vc_data *, int);
	bool (*con_scroll)(struct vc_data *, unsigned int, unsigned int, enum con_scroll, unsigned int);
	int (*con_switch)(struct vc_data *);
	int (*con_blank)(struct vc_data *, int, int);
	int (*con_font_set)(struct vc_data *, struct console_font *, unsigned int);
	int (*con_font_get)(struct vc_data *, struct console_font *);
	int (*con_font_default)(struct vc_data *, struct console_font *, char *);
	int (*con_font_copy)(struct vc_data *, int);
	int (*con_resize)(struct vc_data *, unsigned int, unsigned int, unsigned int);
	void (*con_set_palette)(struct vc_data *, const unsigned char *);
	void (*con_scrolldelta)(struct vc_data *, int);
	int (*con_set_origin)(struct vc_data *);
	void (*con_save_screen)(struct vc_data *);
	u8 (*con_build_attr)(struct vc_data *, u8, u8, u8, u8, u8, u8);
	void (*con_invert_region)(struct vc_data *, u16 *, int);
	u16 * (*con_screen_pos)(struct vc_data *, int);
	long unsigned int (*con_getxy)(struct vc_data *, long unsigned int, int *, int *);
	void (*con_flush_scrollback)(struct vc_data *);
	int (*con_debug_enter)(struct vc_data *);
	int (*con_debug_leave)(struct vc_data *);
};

struct dev_pm_ops___266 {
	int (*prepare)(struct device___266 *);
	void (*complete)(struct device___266 *);
	int (*suspend)(struct device___266 *);
	int (*resume)(struct device___266 *);
	int (*freeze)(struct device___266 *);
	int (*thaw)(struct device___266 *);
	int (*poweroff)(struct device___266 *);
	int (*restore)(struct device___266 *);
	int (*suspend_late)(struct device___266 *);
	int (*resume_early)(struct device___266 *);
	int (*freeze_late)(struct device___266 *);
	int (*thaw_early)(struct device___266 *);
	int (*poweroff_late)(struct device___266 *);
	int (*restore_early)(struct device___266 *);
	int (*suspend_noirq)(struct device___266 *);
	int (*resume_noirq)(struct device___266 *);
	int (*freeze_noirq)(struct device___266 *);
	int (*thaw_noirq)(struct device___266 *);
	int (*poweroff_noirq)(struct device___266 *);
	int (*restore_noirq)(struct device___266 *);
	int (*runtime_suspend)(struct device___266 *);
	int (*runtime_resume)(struct device___266 *);
	int (*runtime_idle)(struct device___266 *);
};

struct dev_pm_domain___266 {
	struct dev_pm_ops___266 ops;
	void (*detach)(struct device___266 *, bool);
	int (*activate)(struct device___266 *);
	void (*sync)(struct device___266 *);
	void (*dismiss)(struct device___266 *);
};

struct bus_type___266 {
	const char *name;
	const char *dev_name;
	struct device___266 *dev_root;
	const struct attribute_group___265 **bus_groups;
	const struct attribute_group___265 **dev_groups;
	const struct attribute_group___265 **drv_groups;
	int (*match)(struct device___266 *, struct device_driver___266 *);
	int (*uevent)(struct device___266 *, struct kobj_uevent_env *);
	int (*probe)(struct device___266 *);
	int (*remove)(struct device___266 *);
	void (*shutdown)(struct device___266 *);
	int (*online)(struct device___266 *);
	int (*offline)(struct device___266 *);
	int (*suspend)(struct device___266 *, pm_message_t);
	int (*resume)(struct device___266 *);
	int (*num_vf)(struct device___266 *);
	int (*dma_configure)(struct device___266 *);
	const struct dev_pm_ops___266 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___266 {
	const char *name;
	struct bus_type___266 *bus;
	struct module___242 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___266 *);
	int (*remove)(struct device___266 *);
	void (*shutdown)(struct device___266 *);
	int (*suspend)(struct device___266 *, pm_message_t);
	int (*resume)(struct device___266 *);
	const struct attribute_group___265 **groups;
	const struct dev_pm_ops___266 *pm;
	void (*coredump)(struct device___266 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___266 {
	const char *name;
	const struct attribute_group___265 **groups;
	int (*uevent)(struct device___266 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___266 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___266 *);
	const struct dev_pm_ops___266 *pm;
};

struct class___266 {
	const char *name;
	struct module___242 *owner;
	const struct attribute_group___265 **class_groups;
	const struct attribute_group___265 **dev_groups;
	struct kobject___288 *dev_kobj;
	int (*dev_uevent)(struct device___266 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___266 *, umode_t *);
	void (*class_release)(struct class___266 *);
	void (*dev_release)(struct device___266 *);
	int (*shutdown_pre)(struct device___266 *);
	const struct kobj_ns_type_operations___25 *ns_type;
	const void * (*namespace)(struct device___266 *);
	const struct dev_pm_ops___266 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct irq_domain_ops___17;

struct irq_domain___17 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___17 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___200 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___2 *gc;
	struct irq_domain___17 *parent;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_direct_max_irq;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_tree_mutex;
	unsigned int linear_revmap[0];
};

struct dma_map_ops___86 {
	void * (*alloc)(struct device___266 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___266 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___266 *, struct vm_area_struct___302 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___266 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___266 *, struct page___302 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___266 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___266 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___266 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___266 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___266 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___266 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___266 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___266 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___266 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___266 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___266 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___266 *, u64);
	u64 (*get_required_mask)(struct device___266 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___200;

struct fwnode_handle___200 {
	struct fwnode_handle___200 *secondary;
	const struct fwnode_operations___200 *ops;
};

struct property___55;

struct device_node___58 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___200 fwnode;
	struct property___55 *properties;
	struct property___55 *deadprops;
	struct device_node___58 *parent;
	struct device_node___58 *child;
	struct device_node___58 *sibling;
	struct kobject___288 kobj;
	long unsigned int _flags;
	void *data;
};

struct fwnode_reference_args___200;

struct fwnode_endpoint___200;

struct fwnode_operations___200 {
	struct fwnode_handle___200 * (*get)(struct fwnode_handle___200 *);
	void (*put)(struct fwnode_handle___200 *);
	bool (*device_is_available)(const struct fwnode_handle___200 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___200 *, const struct device___266 *);
	bool (*property_present)(const struct fwnode_handle___200 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___200 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___200 *, const char *, const char **, size_t);
	struct fwnode_handle___200 * (*get_parent)(const struct fwnode_handle___200 *);
	struct fwnode_handle___200 * (*get_next_child_node)(const struct fwnode_handle___200 *, struct fwnode_handle___200 *);
	struct fwnode_handle___200 * (*get_named_child_node)(const struct fwnode_handle___200 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___200 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___200 *);
	struct fwnode_handle___200 * (*graph_get_next_endpoint)(const struct fwnode_handle___200 *, struct fwnode_handle___200 *);
	struct fwnode_handle___200 * (*graph_get_remote_endpoint)(const struct fwnode_handle___200 *);
	struct fwnode_handle___200 * (*graph_get_port_parent)(struct fwnode_handle___200 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___200 *, struct fwnode_endpoint___200 *);
};

struct fwnode_endpoint___200 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___200 *local_fwnode;
};

struct fwnode_reference_args___200 {
	struct fwnode_handle___200 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct property___55 {
	char *name;
	int length;
	void *value;
	struct property___55 *next;
	long unsigned int _flags;
	struct bin_attribute___264 attr;
};

struct irq_fwspec___17 {
	struct fwnode_handle___200 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___17 {
	int (*match)(struct irq_domain___17 *, struct device_node___58 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___17 *, struct irq_fwspec___17 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___17 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___17 *, unsigned int);
	int (*xlate)(struct irq_domain___17 *, struct device_node___58 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___17 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___17 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___17 *, struct irq_data___5 *, bool);
	void (*deactivate)(struct irq_domain___17 *, struct irq_data___5 *);
	int (*translate)(struct irq_domain___17 *, struct irq_fwspec___17 *, long unsigned int *, unsigned int *);
};

struct fb_con2fbmap {
	__u32 console;
	__u32 framebuffer;
};

struct backlight_device___3;

struct fb_info___3;

struct backlight_ops___3 {
	unsigned int options;
	int (*update_status)(struct backlight_device___3 *);
	int (*get_brightness)(struct backlight_device___3 *);
	int (*check_fb)(struct backlight_device___3 *, struct fb_info___3 *);
};

struct backlight_device___3 {
	struct backlight_properties props;
	struct mutex update_lock;
	struct mutex ops_lock;
	const struct backlight_ops___3 *ops;
	struct notifier_block fb_notif;
	struct list_head entry;
	struct device___266 dev;
	bool fb_bl_on[32];
	int use_count;
};

struct fb_pixmap___3 {
	u8 *addr;
	u32 size;
	u32 offset;
	u32 buf_align;
	u32 scan_align;
	u32 access_align;
	u32 flags;
	u32 blit_x;
	u32 blit_y;
	void (*writeio)(struct fb_info___3 *, void *, void *, unsigned int);
	void (*readio)(struct fb_info___3 *, void *, void *, unsigned int);
};

struct fb_deferred_io___3;

struct fb_ops___3;

struct fb_tile_ops___3;

struct fb_info___3 {
	atomic_t count;
	int node;
	int flags;
	int fbcon_rotate_hint;
	struct mutex lock;
	struct mutex mm_lock;
	struct fb_var_screeninfo var;
	struct fb_fix_screeninfo fix;
	struct fb_monspecs monspecs;
	struct work_struct queue;
	struct fb_pixmap___3 pixmap;
	struct fb_pixmap___3 sprite;
	struct fb_cmap cmap;
	struct list_head modelist;
	struct fb_videomode *mode;
	struct backlight_device___3 *bl_dev;
	struct mutex bl_curve_mutex;
	u8 bl_curve[128];
	struct delayed_work deferred_work;
	struct fb_deferred_io___3 *fbdefio;
	struct fb_ops___3 *fbops;
	struct device___266 *device;
	struct device___266 *dev;
	int class_flag;
	struct fb_tile_ops___3 *tileops;
	union {
		char *screen_base;
		char *screen_buffer;
	};
	long unsigned int screen_size;
	void *pseudo_palette;
	u32 state;
	void *fbcon_par;
	void *par;
	struct apertures_struct *apertures;
	bool skip_vt_switch;
};

struct fb_cmap_user {
	__u32 start;
	__u32 len;
	__u16 *red;
	__u16 *green;
	__u16 *blue;
	__u16 *transp;
};

struct fb_event___2 {
	struct fb_info___3 *info;
	void *data;
};

struct fb_deferred_io___3 {
	long unsigned int delay;
	struct mutex lock;
	struct list_head pagelist;
	void (*first_io)(struct fb_info___3 *);
	void (*deferred_io)(struct fb_info___3 *, struct list_head *);
};

struct fb_ops___3 {
	struct module___242 *owner;
	int (*fb_open)(struct fb_info___3 *, int);
	int (*fb_release)(struct fb_info___3 *, int);
	ssize_t (*fb_read)(struct fb_info___3 *, char *, size_t, loff_t *);
	ssize_t (*fb_write)(struct fb_info___3 *, const char *, size_t, loff_t *);
	int (*fb_check_var)(struct fb_var_screeninfo *, struct fb_info___3 *);
	int (*fb_set_par)(struct fb_info___3 *);
	int (*fb_setcolreg)(unsigned int, unsigned int, unsigned int, unsigned int, unsigned int, struct fb_info___3 *);
	int (*fb_setcmap)(struct fb_cmap *, struct fb_info___3 *);
	int (*fb_blank)(int, struct fb_info___3 *);
	int (*fb_pan_display)(struct fb_var_screeninfo *, struct fb_info___3 *);
	void (*fb_fillrect)(struct fb_info___3 *, const struct fb_fillrect *);
	void (*fb_copyarea)(struct fb_info___3 *, const struct fb_copyarea *);
	void (*fb_imageblit)(struct fb_info___3 *, const struct fb_image *);
	int (*fb_cursor)(struct fb_info___3 *, struct fb_cursor *);
	int (*fb_sync)(struct fb_info___3 *);
	int (*fb_ioctl)(struct fb_info___3 *, unsigned int, long unsigned int);
	int (*fb_compat_ioctl)(struct fb_info___3 *, unsigned int, long unsigned int);
	int (*fb_mmap)(struct fb_info___3 *, struct vm_area_struct___302 *);
	void (*fb_get_caps)(struct fb_info___3 *, struct fb_blit_caps *, struct fb_var_screeninfo *);
	void (*fb_destroy)(struct fb_info___3 *);
	int (*fb_debug_enter)(struct fb_info___3 *);
	int (*fb_debug_leave)(struct fb_info___3 *);
};

struct fb_tile_ops___3 {
	void (*fb_settile)(struct fb_info___3 *, struct fb_tilemap *);
	void (*fb_tilecopy)(struct fb_info___3 *, struct fb_tilearea *);
	void (*fb_tilefill)(struct fb_info___3 *, struct fb_tilerect *);
	void (*fb_tileblit)(struct fb_info___3 *, struct fb_tileblit *);
	void (*fb_tilecursor)(struct fb_info___3 *, struct fb_tilecursor *);
	int (*fb_get_tilemax)(struct fb_info___3 *);
};

struct fb_modelist {
	struct list_head list;
	struct fb_videomode mode;
};

struct pci_bus___25;

struct pci_slot___25 {
	struct pci_bus___25 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject___288 kobj;
};

struct pci_dev___25;

struct pci_ops___25;

struct pci_bus___25 {
	struct list_head node;
	struct pci_bus___25 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___25 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___25 *ops;
	struct msi_controller___2 *msi;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	int domain_nr;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___266 *bridge;
	struct device___266 dev;
	struct bin_attribute___264 *legacy_io;
	struct bin_attribute___264 *legacy_mem;
	unsigned int is_added: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
};

struct pci_driver___25;

struct pci_dev___25 {
	struct list_head bus_list;
	struct pci_bus___25 *bus;
	struct pci_bus___25 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___25 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u16 aer_cap;
	struct aer_stats *aer_stats;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	long unsigned int *dma_alias_mask;
	struct pci_driver___25 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	unsigned int imm_ready: 1;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int bridge_d3: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int hotplug_user_indicators: 1;
	unsigned int clear_retrain_link: 1;
	unsigned int d3_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	unsigned int ltr_path: 1;
	unsigned int eetlp_prefix_path: 1;
	pci_channel_state_t error_state;
	struct device___266 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int multifunction: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int ats_enabled: 1;
	unsigned int pasid_enabled: 1;
	unsigned int pri_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int reset_fn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int shpc_managed: 1;
	unsigned int is_thunderbolt: 1;
	unsigned int __aer_firmware_first_valid: 1;
	unsigned int __aer_firmware_first: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int irq_managed: 1;
	unsigned int has_secondary_link: 1;
	unsigned int non_compliant_bars: 1;
	unsigned int is_probed: 1;
	unsigned int link_active_reporting: 1;
	unsigned int untrusted: 1;
	unsigned int no_vf_scan: 1;
	unsigned int io_window: 1;
	unsigned int pref_window: 1;
	unsigned int pref_64_window: 1;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	struct bin_attribute___264 *rom_attr;
	int rom_attr_enabled;
	struct bin_attribute___264 *res_attr[17];
	struct bin_attribute___264 *res_attr_wc[17];
	unsigned int broken_cmd_compl: 1;
	const struct attribute_group___265 **msi_irq_groups;
	struct pci_vpd *vpd;
	union {
		struct pci_sriov *sriov;
		struct pci_dev___25 *physfn;
	};
	u16 ats_cap;
	u8 ats_stu;
	atomic_t ats_ref_cnt;
	u32 pri_reqs_alloc;
	u16 pasid_features;
	struct pci_p2pdma *p2pdma;
	phys_addr_t rom;
	size_t romlen;
	char *driver_override;
	long unsigned int priv_flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t pci_dev_extended_size_rh;
	struct pci_dev_extended_rh pci_dev_extended_rh;
};

struct pci_error_handlers___25;

struct pci_driver___25 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___25 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___25 *);
	int (*suspend)(struct pci_dev___25 *, pm_message_t);
	int (*suspend_late)(struct pci_dev___25 *, pm_message_t);
	int (*resume_early)(struct pci_dev___25 *);
	int (*resume)(struct pci_dev___25 *);
	void (*shutdown)(struct pci_dev___25 *);
	int (*sriov_configure)(struct pci_dev___25 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	const struct pci_error_handlers___25 *err_handler;
	const struct attribute_group___265 **groups;
	struct device_driver___266 driver;
	struct pci_dynids dynids;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct pci_ops___25 {
	int (*add_bus)(struct pci_bus___25 *);
	void (*remove_bus)(struct pci_bus___25 *);
	void * (*map_bus)(struct pci_bus___25 *, unsigned int, int);
	int (*read)(struct pci_bus___25 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___25 *, unsigned int, int, int, u32);
};

struct pci_error_handlers___25 {
	pci_ers_result_t (*error_detected)(struct pci_dev___25 *, enum pci_channel_state);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___25 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___25 *);
	void (*reset_prepare)(struct pci_dev___25 *);
	void (*reset_done)(struct pci_dev___25 *);
	void (*resume)(struct pci_dev___25 *);
};

struct logo_data {
	int depth;
	int needs_directpalette;
	int needs_truepalette;
	int needs_cmapreset;
	const struct linux_logo *logo;
};

struct module___243;

struct file___302;

struct kiocb___302;

struct vm_area_struct___303;

struct inode___302;

struct file_lock___302;

struct page___303;

struct file_operations___302 {
	struct module___243 *owner;
	loff_t (*llseek)(struct file___302 *, loff_t, int);
	ssize_t (*read)(struct file___302 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___302 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___302 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___302 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___302 *, bool);
	int (*iterate)(struct file___302 *, struct dir_context *);
	int (*iterate_shared)(struct file___302 *, struct dir_context *);
	__poll_t (*poll)(struct file___302 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___302 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___302 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___302 *, struct vm_area_struct___303 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___302 *, struct file___302 *);
	int (*flush)(struct file___302 *, fl_owner_t);
	int (*release)(struct inode___302 *, struct file___302 *);
	int (*fsync)(struct file___302 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___302 *, int);
	int (*lock)(struct file___302 *, int, struct file_lock___302 *);
	ssize_t (*sendpage)(struct file___302 *, struct page___303 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___302 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___302 *, int, struct file_lock___302 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___302 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___302 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___302 *, long int, struct file_lock___302 **, void **);
	long int (*fallocate)(struct file___302 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___302 *);
	ssize_t (*copy_file_range)(struct file___302 *, loff_t, struct file___302 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___302 *, loff_t, struct file___302 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___302 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___302 {
	u64 seqnum;
	struct vm_area_struct___303 *vmas[4];
};

struct page_frag___302 {
	struct page___303 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___302;

struct pid___200;

struct cred___280;

struct nsproxy___247;

struct signal_struct___226;

struct vm_struct___218;

struct task_struct___303 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___303 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___302 *mm;
	struct mm_struct___302 *active_mm;
	struct vmacache___302 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___303 *real_parent;
	struct task_struct___303 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___303 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___200 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___200 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___200 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___280 *ptracer_cred;
	const struct cred___280 *real_cred;
	const struct cred___280 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___247 *nsproxy;
	struct signal_struct___226 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___303 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___82 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___302 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___303 *oom_reaper_list;
	struct vm_struct___218 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___131 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___200;

struct upid___200 {
	int nr;
	struct pid_namespace___200 *ns;
};

struct dentry___302;

struct pid_namespace___200 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___303 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___200 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___302 *proc_self;
	struct dentry___302 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___3 *user_ns;
	struct ucounts___2 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___9 ns;
};

struct pid___200 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___200 numbers[1];
};

struct secondary_data___303 {
	void *stack;
	struct task_struct___303 *task;
	long int status;
};

typedef struct page___303 *pgtable_t___302;

struct address_space___301;

struct dev_pagemap___291;

struct page___303 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___301 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___303 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___302 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___302 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___291 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct key___280;

struct user_struct___280 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___280 *uid_keyring;
	struct key___280 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___291;

struct vm_area_struct___303 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___303 *vm_next;
	struct vm_area_struct___303 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___302 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___291 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___302 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct rw_semaphore___303 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___303 *owner;
};

struct core_state___302;

struct mm_struct___302 {
	struct {
		struct vm_area_struct___303 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___302 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___303 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___302 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___303 *owner;
		struct user_namespace___3 *user_ns;
		struct file___302 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___302 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___280 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___280 *session_keyring;
	struct key___280 *process_keyring;
	struct key___280 *thread_keyring;
	struct key___280 *request_key_auth;
	void *security;
	struct user_struct___280 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct nsproxy___247 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___200 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct signal_struct___226 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___303 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___303 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___200 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___200 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___302 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___200 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_struct___218 {
	struct vm_struct___218 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___303 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___238 {
	struct task_struct___303 task;
	long unsigned int stack[8192];
};

typedef int (*key_restrict_link_func_t___281)(struct key___280 *, const struct key_type *, const union key_payload *, struct key___280 *);

struct key_restriction___280;

struct key___280 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___303 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___280 *restrict_link;
};

struct key_restriction___280 {
	key_restrict_link_func_t___281 check;
	struct key___280 *key;
	struct key_type *keytype;
};

struct pglist_data___302;

struct lruvec___302 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___302 *pgdat;
};

struct zone___302 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___302 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___302 {
	struct zone___302 *zone;
	int zone_idx;
};

struct zonelist___302 {
	struct zoneref___302 _zonerefs[25];
};

struct pglist_data___302 {
	struct zone___302 node_zones[3];
	struct zonelist___302 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___303 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___303 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___302 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___302 {
	struct rw_semaphore___303 rwsem;
	struct notifier_block *head;
};

struct address_space_operations___301;

struct address_space___301 {
	struct inode___302 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___303 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___301 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___291)(struct vm_area_struct___303 *, long unsigned int, const struct page___303 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___291)(struct page___303 *, void *);

struct device___267;

struct dev_pagemap___291 {
	dev_page_fault_t___291 page_fault;
	dev_page_free_t___291 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___267 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___302 {
	struct vfsmount *mnt;
	struct dentry___302 *dentry;
};

struct fown_struct___200 {
	rwlock_t lock;
	struct pid___200 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___302 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___302 f_path;
	struct inode___302 *f_inode;
	const struct file_operations___302 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___200 f_owner;
	const struct cred___280 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___301 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___291;

struct vm_operations_struct___291 {
	void (*open)(struct vm_area_struct___303 *);
	void (*close)(struct vm_area_struct___303 *);
	int (*split)(struct vm_area_struct___303 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___303 *);
	vm_fault_t (*fault)(struct vm_fault___291 *);
	vm_fault_t (*huge_fault)(struct vm_fault___291 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___291 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___303 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___291 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___291 *);
	int (*access)(struct vm_area_struct___303 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___303 *);
	int (*set_policy)(struct vm_area_struct___303 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___303 *, long unsigned int);
	struct page___303 * (*find_special_page)(struct vm_area_struct___303 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___302 {
	struct task_struct___303 *task;
	struct core_thread___302 *next;
};

struct core_state___302 {
	atomic_t nr_threads;
	struct core_thread___302 dumper;
	struct completion startup;
};

struct vm_fault___291 {
	struct vm_area_struct___303 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___303 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___303 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___302 prealloc_pte;
};

struct kset___288;

struct kobj_type___288;

struct kernfs_node___296;

struct kobject___289 {
	const char *name;
	struct list_head entry;
	struct kobject___289 *parent;
	struct kset___288 *kset;
	struct kobj_type___288 *ktype;
	struct kernfs_node___296 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___267 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___267 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___267;

struct bus_type___267;

struct device_driver___267;

struct dev_pm_domain___267;

struct irq_domain___18;

struct dma_map_ops___87;

struct device_node___59;

struct fwnode_handle___201;

struct class___267;

struct attribute_group___266;

struct device___267 {
	struct device___267 *parent;
	struct device_private *p;
	struct kobject___289 kobj;
	const char *init_name;
	const struct device_type___267 *type;
	struct mutex mutex;
	struct bus_type___267 *bus;
	struct device_driver___267 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___267 power;
	struct dev_pm_domain___267 *pm_domain;
	struct irq_domain___18 *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___87 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___59 *of_node;
	struct fwnode_handle___201 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___267 *class;
	const struct attribute_group___266 **groups;
	void (*release)(struct device___267 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___301;

struct super_block___301;

struct dentry___302 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___302 *d_parent;
	struct qstr d_name;
	struct inode___302 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___301 *d_op;
	struct super_block___301 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___301;

struct block_device___301;

struct inode___302 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___301 *i_op;
	struct super_block___301 *i_sb;
	struct address_space___301 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___303 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___302 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___301 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___301 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___301 {
	int (*d_revalidate)(struct dentry___302 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___302 *, unsigned int);
	int (*d_hash)(const struct dentry___302 *, struct qstr *);
	int (*d_compare)(const struct dentry___302 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___302 *);
	int (*d_init)(struct dentry___302 *);
	void (*d_release)(struct dentry___302 *);
	void (*d_prune)(struct dentry___302 *);
	void (*d_iput)(struct dentry___302 *, struct inode___302 *);
	char * (*d_dname)(struct dentry___302 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___302 *);
	int (*d_manage)(const struct path___302 *, bool);
	struct dentry___302 * (*d_real)(struct dentry___302 *, const struct inode___302 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___301;

struct mem_dqinfo___301 {
	struct quota_format_type___301 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___301;

struct quota_info___301 {
	unsigned int flags;
	struct rw_semaphore___303 dqio_sem;
	struct inode___302 *files[3];
	struct mem_dqinfo___301 info[3];
	const struct quota_format_ops___301 *ops[3];
};

struct rcuwait___301 {
	struct task_struct___303 *task;
};

struct percpu_rw_semaphore___301 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___303 rw_sem;
	struct rcuwait___301 writer;
	int readers_block;
};

struct sb_writers___301 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___301 rw_sem[3];
};

struct file_system_type___301;

struct super_operations___301;

struct dquot_operations___301;

struct quotactl_ops___301;

struct super_block___301 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___301 *s_type;
	const struct super_operations___301 *s_op;
	const struct dquot_operations___301 *dq_op;
	const struct quotactl_ops___301 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___302 *s_root;
	struct rw_semaphore___303 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___301 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___301 s_dquot;
	struct sb_writers___301 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___301 *s_d_op;
	int cleancache_poolid;
	struct shrinker___116 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___302 {
	struct file___302 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___302 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___301 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___302 *ia_file;
};

struct dquot___301 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___301 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___301 {
	int qf_fmt_id;
	const struct quota_format_ops___301 *qf_ops;
	struct module___243 *qf_owner;
	struct quota_format_type___301 *qf_next;
};

struct quota_format_ops___301 {
	int (*check_quota_file)(struct super_block___301 *, int);
	int (*read_file_info)(struct super_block___301 *, int);
	int (*write_file_info)(struct super_block___301 *, int);
	int (*free_file_info)(struct super_block___301 *, int);
	int (*read_dqblk)(struct dquot___301 *);
	int (*commit_dqblk)(struct dquot___301 *);
	int (*release_dqblk)(struct dquot___301 *);
	int (*get_next_id)(struct super_block___301 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___301 {
	int (*write_dquot)(struct dquot___301 *);
	struct dquot___301 * (*alloc_dquot)(struct super_block___301 *, int);
	void (*destroy_dquot)(struct dquot___301 *);
	int (*acquire_dquot)(struct dquot___301 *);
	int (*release_dquot)(struct dquot___301 *);
	int (*mark_dirty)(struct dquot___301 *);
	int (*write_info)(struct super_block___301 *, int);
	qsize_t * (*get_reserved_space)(struct inode___302 *);
	int (*get_projid)(struct inode___302 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___302 *, qsize_t *);
	int (*get_next_id)(struct super_block___301 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___301 {
	int (*quota_on)(struct super_block___301 *, int, int, const struct path___302 *);
	int (*quota_off)(struct super_block___301 *, int);
	int (*quota_enable)(struct super_block___301 *, unsigned int);
	int (*quota_disable)(struct super_block___301 *, unsigned int);
	int (*quota_sync)(struct super_block___301 *, int);
	int (*set_info)(struct super_block___301 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___301 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___301 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___301 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___301 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___301 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___240 {
	struct kobject___289 kobj;
	struct module___243 *mod;
	struct kobject___289 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___240 {
	struct module___243 *mod;
	struct latch_tree_node node;
};

struct module_layout___240 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___240 mtn;
};

struct module_attribute___240;

struct kernel_param___240;

struct module___243 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___240 mkobj;
	struct module_attribute___240 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___289 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___240 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___240 core_layout;
	struct module_layout___240 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___301 {
	int (*writepage)(struct page___303 *, struct writeback_control___3 *);
	int (*readpage)(struct file___302 *, struct page___303 *);
	int (*writepages)(struct address_space___301 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___303 *);
	int (*readpages)(struct file___302 *, struct address_space___301 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___302 *, struct address_space___301 *, loff_t, unsigned int, unsigned int, struct page___303 **, void **);
	int (*write_end)(struct file___302 *, struct address_space___301 *, loff_t, unsigned int, unsigned int, struct page___303 *, void *);
	sector_t (*bmap)(struct address_space___301 *, sector_t);
	void (*invalidatepage)(struct page___303 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___303 *, gfp_t);
	void (*freepage)(struct page___303 *);
	ssize_t (*direct_IO)(struct kiocb___302 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___301 *, struct page___303 *, struct page___303 *, enum migrate_mode);
	bool (*isolate_page)(struct page___303 *, isolate_mode_t);
	void (*putback_page)(struct page___303 *);
	int (*launder_page)(struct page___303 *);
	int (*is_partially_uptodate)(struct page___303 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___303 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___301 *, struct page___303 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___302 *, sector_t *);
	void (*swap_deactivate)(struct file___302 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___301 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___302 *bd_inode;
	struct super_block___301 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___301 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___301 {
	struct dentry___302 * (*lookup)(struct inode___302 *, struct dentry___302 *, unsigned int);
	const char * (*get_link)(struct dentry___302 *, struct inode___302 *, struct delayed_call *);
	int (*permission)(struct inode___302 *, int);
	struct posix_acl * (*get_acl)(struct inode___302 *, int);
	int (*readlink)(struct dentry___302 *, char *, int);
	int (*create)(struct inode___302 *, struct dentry___302 *, umode_t, bool);
	int (*link)(struct dentry___302 *, struct inode___302 *, struct dentry___302 *);
	int (*unlink)(struct inode___302 *, struct dentry___302 *);
	int (*symlink)(struct inode___302 *, struct dentry___302 *, const char *);
	int (*mkdir)(struct inode___302 *, struct dentry___302 *, umode_t);
	int (*rmdir)(struct inode___302 *, struct dentry___302 *);
	int (*mknod)(struct inode___302 *, struct dentry___302 *, umode_t, dev_t);
	int (*rename)(struct inode___302 *, struct dentry___302 *, struct inode___302 *, struct dentry___302 *, unsigned int);
	int (*setattr)(struct dentry___302 *, struct iattr___301 *);
	int (*getattr)(const struct path___302 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___302 *, char *, size_t);
	int (*fiemap)(struct inode___302 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___302 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___302 *, struct dentry___302 *, struct file___302 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___302 *, struct dentry___302 *, umode_t);
	int (*set_acl)(struct inode___302 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___301 {
	void (*fl_copy_lock)(struct file_lock___302 *, struct file_lock___302 *);
	void (*fl_release_private)(struct file_lock___302 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___301;

struct lock_manager_operations___301;

struct file_lock___302 {
	struct file_lock___302 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___302 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___301 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___301 *fl_ops;
	const struct lock_manager_operations___301 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___301 {
	int (*lm_compare_owner)(struct file_lock___302 *, struct file_lock___302 *);
	long unsigned int (*lm_owner_key)(struct file_lock___302 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___302 *);
	int (*lm_grant)(struct file_lock___302 *, int);
	bool (*lm_break)(struct file_lock___302 *);
	int (*lm_change)(struct file_lock___302 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___302 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___301 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___301 *fa_next;
	struct file___302 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___301 {
	const char *name;
	int fs_flags;
	struct dentry___302 * (*mount)(struct file_system_type___301 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___301 *);
	struct module___243 *owner;
	struct file_system_type___301 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___301 {
	struct inode___302 * (*alloc_inode)(struct super_block___301 *);
	void (*destroy_inode)(struct inode___302 *);
	void (*dirty_inode)(struct inode___302 *, int);
	int (*write_inode)(struct inode___302 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___302 *);
	void (*evict_inode)(struct inode___302 *);
	void (*put_super)(struct super_block___301 *);
	int (*sync_fs)(struct super_block___301 *, int);
	int (*freeze_super)(struct super_block___301 *);
	int (*freeze_fs)(struct super_block___301 *);
	int (*thaw_super)(struct super_block___301 *);
	int (*unfreeze_fs)(struct super_block___301 *);
	int (*statfs)(struct dentry___302 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___301 *, int *, char *);
	void (*umount_begin)(struct super_block___301 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___302 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___302 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___302 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___302 *);
	ssize_t (*quota_read)(struct super_block___301 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___301 *, int, const char *, size_t, loff_t);
	struct dquot___301 ** (*get_dquots)(struct inode___302 *);
	int (*bdev_try_to_free_page)(struct super_block___301 *, struct page___303 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___301 *, struct shrink_control___116 *);
	long int (*free_cached_objects)(struct super_block___301 *, struct shrink_control___116 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_attribute___281 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___289 *, struct kobj_attribute___281 *, char *);
	ssize_t (*store)(struct kobject___289 *, struct kobj_attribute___281 *, const char *, size_t);
};

typedef void compound_page_dtor___291(struct page___303 *);

struct kernfs_root___295;

struct kernfs_elem_dir___295 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___295 *root;
};

struct kernfs_syscall_ops___295;

struct kernfs_root___295 {
	struct kernfs_node___296 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___295 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___295 {
	struct kernfs_node___296 *target_kn;
};

struct kernfs_ops___295;

struct kernfs_elem_attr___295 {
	const struct kernfs_ops___295 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___296 *notify_next;
};

struct kernfs_node___296 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___296 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___295 dir;
		struct kernfs_elem_symlink___295 symlink;
		struct kernfs_elem_attr___295 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___295;

struct kernfs_ops___295 {
	int (*open)(struct kernfs_open_file___295 *);
	void (*release)(struct kernfs_open_file___295 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___295 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___295 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___295 *, struct vm_area_struct___303 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___295 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___295 {
	int (*remount_fs)(struct kernfs_root___295 *, int *, char *);
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___295 *);
	int (*mkdir)(struct kernfs_node___296 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___296 *);
	int (*rename)(struct kernfs_node___296 *, struct kernfs_node___296 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___296 *, struct kernfs_root___295 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___295 {
	struct kernfs_node___296 *kn;
	struct file___302 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___291 *vm_ops;
};

struct bin_attribute___265;

struct attribute_group___266 {
	const char *name;
	umode_t (*is_visible)(struct kobject___289 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___289 *, struct bin_attribute___265 *, int);
	struct attribute **attrs;
	struct bin_attribute___265 **bin_attrs;
};

struct bin_attribute___265 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___302 *, struct kobject___289 *, struct bin_attribute___265 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___302 *, struct kobject___289 *, struct bin_attribute___265 *, char *, loff_t, size_t);
	int (*mmap)(struct file___302 *, struct kobject___289 *, struct bin_attribute___265 *, struct vm_area_struct___303 *);
};

struct sysfs_ops___288 {
	ssize_t (*show)(struct kobject___289 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___289 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___288;

struct kset___288 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___289 kobj;
	const struct kset_uevent_ops___288 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___288 {
	void (*release)(struct kobject___289 *);
	const struct sysfs_ops___288 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___25 * (*child_ns_type)(struct kobject___289 *);
	const void * (*namespace)(struct kobject___289 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___288 {
	int (* const filter)(struct kset___288 *, struct kobject___289 *);
	const char * (* const name)(struct kset___288 *, struct kobject___289 *);
	int (* const uevent)(struct kset___288 *, struct kobject___289 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___267 {
	int (*prepare)(struct device___267 *);
	void (*complete)(struct device___267 *);
	int (*suspend)(struct device___267 *);
	int (*resume)(struct device___267 *);
	int (*freeze)(struct device___267 *);
	int (*thaw)(struct device___267 *);
	int (*poweroff)(struct device___267 *);
	int (*restore)(struct device___267 *);
	int (*suspend_late)(struct device___267 *);
	int (*resume_early)(struct device___267 *);
	int (*freeze_late)(struct device___267 *);
	int (*thaw_early)(struct device___267 *);
	int (*poweroff_late)(struct device___267 *);
	int (*restore_early)(struct device___267 *);
	int (*suspend_noirq)(struct device___267 *);
	int (*resume_noirq)(struct device___267 *);
	int (*freeze_noirq)(struct device___267 *);
	int (*thaw_noirq)(struct device___267 *);
	int (*poweroff_noirq)(struct device___267 *);
	int (*restore_noirq)(struct device___267 *);
	int (*runtime_suspend)(struct device___267 *);
	int (*runtime_resume)(struct device___267 *);
	int (*runtime_idle)(struct device___267 *);
};

struct dev_pm_domain___267 {
	struct dev_pm_ops___267 ops;
	void (*detach)(struct device___267 *, bool);
	int (*activate)(struct device___267 *);
	void (*sync)(struct device___267 *);
	void (*dismiss)(struct device___267 *);
};

struct bus_type___267 {
	const char *name;
	const char *dev_name;
	struct device___267 *dev_root;
	const struct attribute_group___266 **bus_groups;
	const struct attribute_group___266 **dev_groups;
	const struct attribute_group___266 **drv_groups;
	int (*match)(struct device___267 *, struct device_driver___267 *);
	int (*uevent)(struct device___267 *, struct kobj_uevent_env *);
	int (*probe)(struct device___267 *);
	int (*remove)(struct device___267 *);
	void (*shutdown)(struct device___267 *);
	int (*online)(struct device___267 *);
	int (*offline)(struct device___267 *);
	int (*suspend)(struct device___267 *, pm_message_t);
	int (*resume)(struct device___267 *);
	int (*num_vf)(struct device___267 *);
	int (*dma_configure)(struct device___267 *);
	const struct dev_pm_ops___267 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___267 {
	const char *name;
	struct bus_type___267 *bus;
	struct module___243 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___267 *);
	int (*remove)(struct device___267 *);
	void (*shutdown)(struct device___267 *);
	int (*suspend)(struct device___267 *, pm_message_t);
	int (*resume)(struct device___267 *);
	const struct attribute_group___266 **groups;
	const struct dev_pm_ops___267 *pm;
	void (*coredump)(struct device___267 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___267 {
	const char *name;
	const struct attribute_group___266 **groups;
	int (*uevent)(struct device___267 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___267 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___267 *);
	const struct dev_pm_ops___267 *pm;
};

struct class___267 {
	const char *name;
	struct module___243 *owner;
	const struct attribute_group___266 **class_groups;
	const struct attribute_group___266 **dev_groups;
	struct kobject___289 *dev_kobj;
	int (*dev_uevent)(struct device___267 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___267 *, umode_t *);
	void (*class_release)(struct class___267 *);
	void (*dev_release)(struct device___267 *);
	int (*shutdown_pre)(struct device___267 *);
	const struct kobj_ns_type_operations___25 *ns_type;
	const void * (*namespace)(struct device___267 *);
	const struct dev_pm_ops___267 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct irq_domain_ops___18;

struct irq_domain___18 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___18 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___201 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___2 *gc;
	struct irq_domain___18 *parent;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_direct_max_irq;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_tree_mutex;
	unsigned int linear_revmap[0];
};

struct dma_map_ops___87 {
	void * (*alloc)(struct device___267 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___267 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___267 *, struct vm_area_struct___303 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___267 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___267 *, struct page___303 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___267 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___267 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___267 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___267 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___267 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___267 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___267 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___267 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___267 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___267 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___267 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___267 *, u64);
	u64 (*get_required_mask)(struct device___267 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___201;

struct fwnode_handle___201 {
	struct fwnode_handle___201 *secondary;
	const struct fwnode_operations___201 *ops;
};

struct property___56;

struct device_node___59 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___201 fwnode;
	struct property___56 *properties;
	struct property___56 *deadprops;
	struct device_node___59 *parent;
	struct device_node___59 *child;
	struct device_node___59 *sibling;
	struct kobject___289 kobj;
	long unsigned int _flags;
	void *data;
};

struct fwnode_reference_args___201;

struct fwnode_endpoint___201;

struct fwnode_operations___201 {
	struct fwnode_handle___201 * (*get)(struct fwnode_handle___201 *);
	void (*put)(struct fwnode_handle___201 *);
	bool (*device_is_available)(const struct fwnode_handle___201 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___201 *, const struct device___267 *);
	bool (*property_present)(const struct fwnode_handle___201 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___201 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___201 *, const char *, const char **, size_t);
	struct fwnode_handle___201 * (*get_parent)(const struct fwnode_handle___201 *);
	struct fwnode_handle___201 * (*get_next_child_node)(const struct fwnode_handle___201 *, struct fwnode_handle___201 *);
	struct fwnode_handle___201 * (*get_named_child_node)(const struct fwnode_handle___201 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___201 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___201 *);
	struct fwnode_handle___201 * (*graph_get_next_endpoint)(const struct fwnode_handle___201 *, struct fwnode_handle___201 *);
	struct fwnode_handle___201 * (*graph_get_remote_endpoint)(const struct fwnode_handle___201 *);
	struct fwnode_handle___201 * (*graph_get_port_parent)(struct fwnode_handle___201 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___201 *, struct fwnode_endpoint___201 *);
};

struct fwnode_endpoint___201 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___201 *local_fwnode;
};

struct fwnode_reference_args___201 {
	struct fwnode_handle___201 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct property___56 {
	char *name;
	int length;
	void *value;
	struct property___56 *next;
	long unsigned int _flags;
	struct bin_attribute___265 attr;
};

struct irq_fwspec___18 {
	struct fwnode_handle___201 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___18 {
	int (*match)(struct irq_domain___18 *, struct device_node___59 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___18 *, struct irq_fwspec___18 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___18 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___18 *, unsigned int);
	int (*xlate)(struct irq_domain___18 *, struct device_node___59 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___18 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___18 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___18 *, struct irq_data___5 *, bool);
	void (*deactivate)(struct irq_domain___18 *, struct irq_data___5 *);
	int (*translate)(struct irq_domain___18 *, struct irq_fwspec___18 *, long unsigned int *, unsigned int *);
};

struct backlight_device___4;

struct fb_info___4;

struct backlight_ops___4 {
	unsigned int options;
	int (*update_status)(struct backlight_device___4 *);
	int (*get_brightness)(struct backlight_device___4 *);
	int (*check_fb)(struct backlight_device___4 *, struct fb_info___4 *);
};

struct backlight_device___4 {
	struct backlight_properties props;
	struct mutex update_lock;
	struct mutex ops_lock;
	const struct backlight_ops___4 *ops;
	struct notifier_block fb_notif;
	struct list_head entry;
	struct device___267 dev;
	bool fb_bl_on[32];
	int use_count;
};

struct fb_pixmap___4 {
	u8 *addr;
	u32 size;
	u32 offset;
	u32 buf_align;
	u32 scan_align;
	u32 access_align;
	u32 flags;
	u32 blit_x;
	u32 blit_y;
	void (*writeio)(struct fb_info___4 *, void *, void *, unsigned int);
	void (*readio)(struct fb_info___4 *, void *, void *, unsigned int);
};

struct fb_deferred_io___4;

struct fb_ops___4;

struct fb_tile_ops___4;

struct fb_info___4 {
	atomic_t count;
	int node;
	int flags;
	int fbcon_rotate_hint;
	struct mutex lock;
	struct mutex mm_lock;
	struct fb_var_screeninfo var;
	struct fb_fix_screeninfo fix;
	struct fb_monspecs monspecs;
	struct work_struct queue;
	struct fb_pixmap___4 pixmap;
	struct fb_pixmap___4 sprite;
	struct fb_cmap cmap;
	struct list_head modelist;
	struct fb_videomode *mode;
	struct backlight_device___4 *bl_dev;
	struct mutex bl_curve_mutex;
	u8 bl_curve[128];
	struct delayed_work deferred_work;
	struct fb_deferred_io___4 *fbdefio;
	struct fb_ops___4 *fbops;
	struct device___267 *device;
	struct device___267 *dev;
	int class_flag;
	struct fb_tile_ops___4 *tileops;
	union {
		char *screen_base;
		char *screen_buffer;
	};
	long unsigned int screen_size;
	void *pseudo_palette;
	u32 state;
	void *fbcon_par;
	void *par;
	struct apertures_struct *apertures;
	bool skip_vt_switch;
};

struct fb_deferred_io___4 {
	long unsigned int delay;
	struct mutex lock;
	struct list_head pagelist;
	void (*first_io)(struct fb_info___4 *);
	void (*deferred_io)(struct fb_info___4 *, struct list_head *);
};

struct fb_ops___4 {
	struct module___243 *owner;
	int (*fb_open)(struct fb_info___4 *, int);
	int (*fb_release)(struct fb_info___4 *, int);
	ssize_t (*fb_read)(struct fb_info___4 *, char *, size_t, loff_t *);
	ssize_t (*fb_write)(struct fb_info___4 *, const char *, size_t, loff_t *);
	int (*fb_check_var)(struct fb_var_screeninfo *, struct fb_info___4 *);
	int (*fb_set_par)(struct fb_info___4 *);
	int (*fb_setcolreg)(unsigned int, unsigned int, unsigned int, unsigned int, unsigned int, struct fb_info___4 *);
	int (*fb_setcmap)(struct fb_cmap *, struct fb_info___4 *);
	int (*fb_blank)(int, struct fb_info___4 *);
	int (*fb_pan_display)(struct fb_var_screeninfo *, struct fb_info___4 *);
	void (*fb_fillrect)(struct fb_info___4 *, const struct fb_fillrect *);
	void (*fb_copyarea)(struct fb_info___4 *, const struct fb_copyarea *);
	void (*fb_imageblit)(struct fb_info___4 *, const struct fb_image *);
	int (*fb_cursor)(struct fb_info___4 *, struct fb_cursor *);
	int (*fb_sync)(struct fb_info___4 *);
	int (*fb_ioctl)(struct fb_info___4 *, unsigned int, long unsigned int);
	int (*fb_compat_ioctl)(struct fb_info___4 *, unsigned int, long unsigned int);
	int (*fb_mmap)(struct fb_info___4 *, struct vm_area_struct___303 *);
	void (*fb_get_caps)(struct fb_info___4 *, struct fb_blit_caps *, struct fb_var_screeninfo *);
	void (*fb_destroy)(struct fb_info___4 *);
	int (*fb_debug_enter)(struct fb_info___4 *);
	int (*fb_debug_leave)(struct fb_info___4 *);
};

struct fb_tile_ops___4 {
	void (*fb_settile)(struct fb_info___4 *, struct fb_tilemap *);
	void (*fb_tilecopy)(struct fb_info___4 *, struct fb_tilearea *);
	void (*fb_tilefill)(struct fb_info___4 *, struct fb_tilerect *);
	void (*fb_tileblit)(struct fb_info___4 *, struct fb_tileblit *);
	void (*fb_tilecursor)(struct fb_info___4 *, struct fb_tilecursor *);
	int (*fb_get_tilemax)(struct fb_info___4 *);
};

struct kernel_param_ops___240 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___240 *);
	int (*get)(char *, const struct kernel_param___240 *);
	void (*free)(void *);
};

struct kparam_array___240;

struct kernel_param___240 {
	const char *name;
	struct module___243 *mod;
	const struct kernel_param_ops___240 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___240 *arr;
	};
};

struct kparam_array___240 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___240 *ops;
	void *elem;
};

struct module_attribute___240 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___240 *, struct module_kobject___240 *, char *);
	ssize_t (*store)(struct module_attribute___240 *, struct module_kobject___240 *, const char *, size_t);
	void (*setup)(struct module___243 *, const char *);
	int (*test)(struct module___243 *);
	void (*free)(struct module___243 *);
};

enum display_flags {
	DISPLAY_FLAGS_HSYNC_LOW = 1,
	DISPLAY_FLAGS_HSYNC_HIGH = 2,
	DISPLAY_FLAGS_VSYNC_LOW = 4,
	DISPLAY_FLAGS_VSYNC_HIGH = 8,
	DISPLAY_FLAGS_DE_LOW = 16,
	DISPLAY_FLAGS_DE_HIGH = 32,
	DISPLAY_FLAGS_PIXDATA_POSEDGE = 64,
	DISPLAY_FLAGS_PIXDATA_NEGEDGE = 128,
	DISPLAY_FLAGS_INTERLACED = 256,
	DISPLAY_FLAGS_DOUBLESCAN = 512,
	DISPLAY_FLAGS_DOUBLECLK = 1024,
	DISPLAY_FLAGS_SYNC_POSEDGE = 2048,
	DISPLAY_FLAGS_SYNC_NEGEDGE = 4096,
};

struct videomode {
	long unsigned int pixelclock;
	u32 hactive;
	u32 hfront_porch;
	u32 hback_porch;
	u32 hsync_len;
	u32 vactive;
	u32 vfront_porch;
	u32 vback_porch;
	u32 vsync_len;
	enum display_flags flags;
};

struct broken_edid {
	u8 manufacturer[4];
	u32 model;
	u32 fix;
};

struct __fb_timings {
	u32 dclk;
	u32 hfreq;
	u32 vfreq;
	u32 hactive;
	u32 vactive;
	u32 hblank;
	u32 vblank;
	u32 htotal;
	u32 vtotal;
};

typedef unsigned int u_int;

struct device_attribute___18 {
	struct attribute attr;
	ssize_t (*show)(struct device___267 *, struct device_attribute___18 *, char *);
	ssize_t (*store)(struct device___267 *, struct device_attribute___18 *, const char *, size_t);
};

struct consw___13 {
	struct module___243 *owner;
	const char * (*con_startup)();
	void (*con_init)(struct vc_data *, int);
	void (*con_deinit)(struct vc_data *);
	void (*con_clear)(struct vc_data *, int, int, int, int);
	void (*con_putc)(struct vc_data *, int, int, int);
	void (*con_putcs)(struct vc_data *, const short unsigned int *, int, int, int);
	void (*con_cursor)(struct vc_data *, int);
	bool (*con_scroll)(struct vc_data *, unsigned int, unsigned int, enum con_scroll, unsigned int);
	int (*con_switch)(struct vc_data *);
	int (*con_blank)(struct vc_data *, int, int);
	int (*con_font_set)(struct vc_data *, struct console_font *, unsigned int);
	int (*con_font_get)(struct vc_data *, struct console_font *);
	int (*con_font_default)(struct vc_data *, struct console_font *, char *);
	int (*con_font_copy)(struct vc_data *, int);
	int (*con_resize)(struct vc_data *, unsigned int, unsigned int, unsigned int);
	void (*con_set_palette)(struct vc_data *, const unsigned char *);
	void (*con_scrolldelta)(struct vc_data *, int);
	int (*con_set_origin)(struct vc_data *);
	void (*con_save_screen)(struct vc_data *);
	u8 (*con_build_attr)(struct vc_data *, u8, u8, u8, u8, u8, u8);
	void (*con_invert_region)(struct vc_data *, u16 *, int);
	u16 * (*con_screen_pos)(struct vc_data *, int);
	long unsigned int (*con_getxy)(struct vc_data *, long unsigned int, int *, int *);
	void (*con_flush_scrollback)(struct vc_data *);
	int (*con_debug_enter)(struct vc_data *);
	int (*con_debug_leave)(struct vc_data *);
};

struct fb_cvt_data {
	u32 xres;
	u32 yres;
	u32 refresh;
	u32 f_refresh;
	u32 pixclock;
	u32 hperiod;
	u32 hblank;
	u32 hfreq;
	u32 htotal;
	u32 vtotal;
	u32 vsync;
	u32 hsync;
	u32 h_front_porch;
	u32 h_back_porch;
	u32 v_front_porch;
	u32 v_back_porch;
	u32 h_margin;
	u32 v_margin;
	u32 interlace;
	u32 aspect_ratio;
	u32 active_pixels;
	u32 flags;
	u32 status;
};

struct module___244;

struct file___303;

struct kiocb___303;

struct vm_area_struct___304;

struct inode___303;

struct file_lock___303;

struct page___304;

struct seq_file___256;

struct file_operations___303 {
	struct module___244 *owner;
	loff_t (*llseek)(struct file___303 *, loff_t, int);
	ssize_t (*read)(struct file___303 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___303 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___303 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___303 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___303 *, bool);
	int (*iterate)(struct file___303 *, struct dir_context *);
	int (*iterate_shared)(struct file___303 *, struct dir_context *);
	__poll_t (*poll)(struct file___303 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___303 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___303 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___303 *, struct vm_area_struct___304 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___303 *, struct file___303 *);
	int (*flush)(struct file___303 *, fl_owner_t);
	int (*release)(struct inode___303 *, struct file___303 *);
	int (*fsync)(struct file___303 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___303 *, int);
	int (*lock)(struct file___303 *, int, struct file_lock___303 *);
	ssize_t (*sendpage)(struct file___303 *, struct page___304 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___303 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___303 *, int, struct file_lock___303 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___303 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___303 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___303 *, long int, struct file_lock___303 **, void **);
	long int (*fallocate)(struct file___303 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___256 *, struct file___303 *);
	ssize_t (*copy_file_range)(struct file___303 *, loff_t, struct file___303 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___303 *, loff_t, struct file___303 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___303 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___303 {
	u64 seqnum;
	struct vm_area_struct___304 *vmas[4];
};

struct page_frag___303 {
	struct page___304 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___303;

struct mem_cgroup___117;

struct pid___201;

struct cred___281;

struct nsproxy___248;

struct signal_struct___227;

struct bio_list___149;

struct backing_dev_info___149;

struct css_set___208;

struct vm_struct___219;

struct task_struct___304 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___304 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___303 *mm;
	struct mm_struct___303 *active_mm;
	struct vmacache___303 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___304 *real_parent;
	struct task_struct___304 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___304 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___117 *active_memcg;
	long int rh_reserved2;
	struct pid___201 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___201 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___201 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___281 *ptracer_cred;
	const struct cred___281 *real_cred;
	const struct cred___281 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___248 *nsproxy;
	struct signal_struct___227 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___304 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___149 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___149 *backing_dev_info;
	struct io_context___82 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___208 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___303 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___117 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___304 *oom_reaper_list;
	struct vm_struct___219 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___131 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rw_semaphore___304 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___304 *owner;
};

struct key___281;

struct ucounts___223;

struct user_namespace___223 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___223 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___9 ns;
	long unsigned int flags;
	struct key___281 *persistent_keyring_register;
	struct rw_semaphore___304 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___223 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___304 *pgtable_t___303;

struct address_space___302;

struct dev_pagemap___292;

struct page___304 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___302 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___304 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___303 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___303 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___292 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___117 *mem_cgroup;
};

struct pglist_data___303;

struct lruvec___303 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___303 *pgdat;
};

struct zone___303 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___303 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___303 {
	struct zone___303 *zone;
	int zone_idx;
};

struct zonelist___303 {
	struct zoneref___303 _zonerefs[25];
};

struct pglist_data___303 {
	struct zone___303 node_zones[3];
	struct zonelist___303 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___304 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___304 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___303 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___304 {
	void *stack;
	struct task_struct___304 *task;
	long int status;
};

struct blocking_notifier_head___303 {
	struct rw_semaphore___304 rwsem;
	struct notifier_block *head;
};

struct dentry___303;

struct path___303 {
	struct vfsmount *mnt;
	struct dentry___303 *dentry;
};

struct fown_struct___201 {
	rwlock_t lock;
	struct pid___201 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___303 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___303 f_path;
	struct inode___303 *f_inode;
	const struct file_operations___303 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___201 f_owner;
	const struct cred___281 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___302 *f_mapping;
	errseq_t f_wb_err;
};

struct user_struct___281;

struct cred___281 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___281 *session_keyring;
	struct key___281 *process_keyring;
	struct key___281 *thread_keyring;
	struct key___281 *request_key_auth;
	void *security;
	struct user_struct___281 *user;
	struct user_namespace___223 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___296;

struct kernfs_elem_dir___296 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___296 *root;
};

struct kernfs_node___297;

struct kernfs_syscall_ops___296;

struct kernfs_root___296 {
	struct kernfs_node___297 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___296 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___296 {
	struct kernfs_node___297 *target_kn;
};

struct kernfs_ops___296;

struct kernfs_elem_attr___296 {
	const struct kernfs_ops___296 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___297 *notify_next;
};

struct kernfs_node___297 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___297 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___296 dir;
		struct kernfs_elem_symlink___296 symlink;
		struct kernfs_elem_attr___296 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___296;

struct kernfs_ops___296 {
	int (*open)(struct kernfs_open_file___296 *);
	void (*release)(struct kernfs_open_file___296 *);
	int (*seq_show)(struct seq_file___256 *, void *);
	void * (*seq_start)(struct seq_file___256 *, loff_t *);
	void * (*seq_next)(struct seq_file___256 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___256 *, void *);
	ssize_t (*read)(struct kernfs_open_file___296 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___296 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___296 *, struct vm_area_struct___304 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___296 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___296 {
	int (*remount_fs)(struct kernfs_root___296 *, int *, char *);
	int (*show_options)(struct seq_file___256 *, struct kernfs_root___296 *);
	int (*mkdir)(struct kernfs_node___297 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___297 *);
	int (*rename)(struct kernfs_node___297 *, struct kernfs_node___297 *, const char *);
	int (*show_path)(struct seq_file___256 *, struct kernfs_node___297 *, struct kernfs_root___296 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___255;

struct seq_file___256 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___255 *op;
	int poll_event;
	const struct file___303 *file;
	void *private;
};

struct vm_operations_struct___292;

struct kernfs_open_file___296 {
	struct kernfs_node___297 *kn;
	struct file___303 *file;
	struct seq_file___256 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___292 *vm_ops;
};

struct vm_fault___292;

struct vm_operations_struct___292 {
	void (*open)(struct vm_area_struct___304 *);
	void (*close)(struct vm_area_struct___304 *);
	int (*split)(struct vm_area_struct___304 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___304 *);
	vm_fault_t (*fault)(struct vm_fault___292 *);
	vm_fault_t (*huge_fault)(struct vm_fault___292 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___292 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___304 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___292 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___292 *);
	int (*access)(struct vm_area_struct___304 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___304 *);
	int (*set_policy)(struct vm_area_struct___304 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___304 *, long unsigned int);
	struct page___304 * (*find_special_page)(struct vm_area_struct___304 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct anon_vma___22;

struct vm_area_struct___304 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___304 *vm_next;
	struct vm_area_struct___304 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___303 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma___22 *anon_vma;
	const struct vm_operations_struct___292 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___303 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___290;

struct bin_attribute___266;

struct attribute_group___267 {
	const char *name;
	umode_t (*is_visible)(struct kobject___290 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___290 *, struct bin_attribute___266 *, int);
	struct attribute **attrs;
	struct bin_attribute___266 **bin_attrs;
};

struct kset___289;

struct kobj_type___289;

struct kobject___290 {
	const char *name;
	struct list_head entry;
	struct kobject___290 *parent;
	struct kset___289 *kset;
	struct kobj_type___289 *ktype;
	struct kernfs_node___297 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___266 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___303 *, struct kobject___290 *, struct bin_attribute___266 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___303 *, struct kobject___290 *, struct bin_attribute___266 *, char *, loff_t, size_t);
	int (*mmap)(struct file___303 *, struct kobject___290 *, struct bin_attribute___266 *, struct vm_area_struct___304 *);
};

struct sysfs_ops___289 {
	ssize_t (*show)(struct kobject___290 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___290 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___289;

struct kset___289 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___290 kobj;
	const struct kset_uevent_ops___289 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___289 {
	void (*release)(struct kobject___290 *);
	const struct sysfs_ops___289 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___25 * (*child_ns_type)(struct kobject___290 *);
	const void * (*namespace)(struct kobject___290 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___289 {
	int (* const filter)(struct kset___289 *, struct kobject___290 *);
	const char * (* const name)(struct kset___289 *, struct kobject___290 *);
	int (* const uevent)(struct kset___289 *, struct kobject___290 *, struct kobj_uevent_env *);
};

struct kobj_attribute___282 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___290 *, struct kobj_attribute___282 *, char *);
	ssize_t (*store)(struct kobject___290 *, struct kobj_attribute___282 *, const char *, size_t);
};

struct kernel_param___241;

struct kernel_param_ops___241 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___241 *);
	int (*get)(char *, const struct kernel_param___241 *);
	void (*free)(void *);
};

struct kparam_array___241;

struct kernel_param___241 {
	const char *name;
	struct module___244 *mod;
	const struct kernel_param_ops___241 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___241 *arr;
	};
};

struct kparam_array___241 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___241 *ops;
	void *elem;
};

struct module_kobject___241 {
	struct kobject___290 kobj;
	struct module___244 *mod;
	struct kobject___290 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___241 {
	struct module___244 *mod;
	struct latch_tree_node node;
};

struct module_layout___241 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___241 mtn;
};

struct module_attribute___241;

struct module___244 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___241 mkobj;
	struct module_attribute___241 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___290 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___241 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___241 core_layout;
	struct module_layout___241 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___241 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___241 *, struct module_kobject___241 *, char *);
	ssize_t (*store)(struct module_attribute___241 *, struct module_kobject___241 *, const char *, size_t);
	void (*setup)(struct module___244 *, const char *);
	int (*test)(struct module___244 *);
	void (*free)(struct module___244 *);
};

struct core_state___303;

struct mm_struct___303 {
	struct {
		struct vm_area_struct___304 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___303 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___304 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___303 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___304 *owner;
		struct user_namespace___223 *user_ns;
		struct file___303 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___303 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___302;

struct address_space___302 {
	struct inode___303 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___304 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___302 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___292)(struct vm_area_struct___304 *, long unsigned int, const struct page___304 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___292)(struct page___304 *, void *);

struct device___268;

struct dev_pagemap___292 {
	dev_page_fault_t___292 page_fault;
	dev_page_free_t___292 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___268 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct cgroup___208;

struct cgroup_subsys___208;

struct cgroup_subsys_state___208 {
	struct cgroup___208 *cgroup;
	struct cgroup_subsys___208 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___208 *parent;
};

struct cgroup_file___208 {
	struct kernfs_node___297 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___117;

struct mem_cgroup___117 {
	struct cgroup_subsys_state___208 css;
	struct mem_cgroup_id___4 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___208 events_file;
	struct cgroup_file___208 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___304 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___117 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct anon_vma___22 {
	struct anon_vma___22 *root;
	struct rw_semaphore___304 rwsem;
	atomic_t refcount;
	unsigned int degree;
	struct anon_vma___22 *parent;
	struct rb_root_cached rb_root;
};

struct core_thread___303 {
	struct task_struct___304 *task;
	struct core_thread___303 *next;
};

struct core_state___303 {
	atomic_t nr_threads;
	struct core_thread___303 dumper;
	struct completion startup;
};

struct vm_fault___292 {
	struct vm_area_struct___304 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___304 *cow_page;
	struct mem_cgroup___117 *memcg;
	struct page___304 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___303 prealloc_pte;
};

struct shrink_control___117 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___117 *memcg;
};

struct shrinker___117 {
	long unsigned int (*count_objects)(struct shrinker___117 *, struct shrink_control___117 *);
	long unsigned int (*scan_objects)(struct shrinker___117 *, struct shrink_control___117 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct pid_namespace___201;

struct upid___201 {
	int nr;
	struct pid_namespace___201 *ns;
};

struct pid_namespace___201 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___304 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___201 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___303 *proc_self;
	struct dentry___303 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___223 *user_ns;
	struct ucounts___223 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___9 ns;
};

struct pid___201 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___201 numbers[1];
};

struct user_struct___281 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___281 *uid_keyring;
	struct key___281 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cgroup_namespace___208;

struct nsproxy___248 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___201 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___208 *cgroup_ns;
};

struct signal_struct___227 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___304 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___304 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___201 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___201 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___303 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___201 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___149;

struct bio_list___149 {
	struct bio___149 *head;
	struct bio___149 *tail;
};

struct bdi_writeback_congested___149;

struct bdi_writeback___149 {
	struct backing_dev_info___149 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___149 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___208 *memcg_css;
	struct cgroup_subsys_state___208 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___149 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___149 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___268 *dev;
	struct device___268 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___303 *debug_dir;
	struct dentry___303 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___208 {
	struct cgroup_subsys_state___208 *subsys[13];
	refcount_t refcount;
	struct css_set___208 *dom_cset;
	struct cgroup___208 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___208 *mg_src_cgrp;
	struct cgroup___208 *mg_dst_cgrp;
	struct css_set___208 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct vm_struct___219 {
	struct vm_struct___219 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___304 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___239 {
	struct task_struct___304 task;
	long unsigned int stack[8192];
};

struct dev_pm_info___268 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___268 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___268;

struct bus_type___268;

struct device_driver___268;

struct dev_pm_domain___268;

struct irq_domain___19;

struct device_node___60;

struct fwnode_handle___202;

struct class___268;

struct device___268 {
	struct device___268 *parent;
	struct device_private *p;
	struct kobject___290 kobj;
	const char *init_name;
	const struct device_type___268 *type;
	struct mutex mutex;
	struct bus_type___268 *bus;
	struct device_driver___268 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___268 power;
	struct dev_pm_domain___268 *pm_domain;
	struct irq_domain___19 *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___60 *of_node;
	struct fwnode_handle___202 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___268 *class;
	const struct attribute_group___267 **groups;
	void (*release)(struct device___268 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___302;

struct super_block___302;

struct dentry___303 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___303 *d_parent;
	struct qstr d_name;
	struct inode___303 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___302 *d_op;
	struct super_block___302 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___302;

struct block_device___302;

struct inode___303 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___302 *i_op;
	struct super_block___302 *i_sb;
	struct address_space___302 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___304 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___149 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___303 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___302 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___302 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___302 {
	int (*d_revalidate)(struct dentry___303 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___303 *, unsigned int);
	int (*d_hash)(const struct dentry___303 *, struct qstr *);
	int (*d_compare)(const struct dentry___303 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___303 *);
	int (*d_init)(struct dentry___303 *);
	void (*d_release)(struct dentry___303 *);
	void (*d_prune)(struct dentry___303 *);
	void (*d_iput)(struct dentry___303 *, struct inode___303 *);
	char * (*d_dname)(struct dentry___303 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___303 *);
	int (*d_manage)(const struct path___303 *, bool);
	struct dentry___303 * (*d_real)(struct dentry___303 *, const struct inode___303 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___302;

struct mem_dqinfo___302 {
	struct quota_format_type___302 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___302;

struct quota_info___302 {
	unsigned int flags;
	struct rw_semaphore___304 dqio_sem;
	struct inode___303 *files[3];
	struct mem_dqinfo___302 info[3];
	const struct quota_format_ops___302 *ops[3];
};

struct rcuwait___302 {
	struct task_struct___304 *task;
};

struct percpu_rw_semaphore___302 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___304 rw_sem;
	struct rcuwait___302 writer;
	int readers_block;
};

struct sb_writers___302 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___302 rw_sem[3];
};

struct file_system_type___302;

struct super_operations___302;

struct dquot_operations___302;

struct quotactl_ops___302;

struct super_block___302 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___302 *s_type;
	const struct super_operations___302 *s_op;
	const struct dquot_operations___302 *dq_op;
	const struct quotactl_ops___302 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___303 *s_root;
	struct rw_semaphore___304 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___302 *s_bdev;
	struct backing_dev_info___149 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___302 s_dquot;
	struct sb_writers___302 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___302 *s_d_op;
	int cleancache_poolid;
	struct shrinker___117 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___223 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___303 {
	struct file___303 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___303 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___302 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___303 *ia_file;
};

struct dquot___302 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___302 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___302 {
	int qf_fmt_id;
	const struct quota_format_ops___302 *qf_ops;
	struct module___244 *qf_owner;
	struct quota_format_type___302 *qf_next;
};

struct quota_format_ops___302 {
	int (*check_quota_file)(struct super_block___302 *, int);
	int (*read_file_info)(struct super_block___302 *, int);
	int (*write_file_info)(struct super_block___302 *, int);
	int (*free_file_info)(struct super_block___302 *, int);
	int (*read_dqblk)(struct dquot___302 *);
	int (*commit_dqblk)(struct dquot___302 *);
	int (*release_dqblk)(struct dquot___302 *);
	int (*get_next_id)(struct super_block___302 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___302 {
	int (*write_dquot)(struct dquot___302 *);
	struct dquot___302 * (*alloc_dquot)(struct super_block___302 *, int);
	void (*destroy_dquot)(struct dquot___302 *);
	int (*acquire_dquot)(struct dquot___302 *);
	int (*release_dquot)(struct dquot___302 *);
	int (*mark_dirty)(struct dquot___302 *);
	int (*write_info)(struct super_block___302 *, int);
	qsize_t * (*get_reserved_space)(struct inode___303 *);
	int (*get_projid)(struct inode___303 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___303 *, qsize_t *);
	int (*get_next_id)(struct super_block___302 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___302 {
	int (*quota_on)(struct super_block___302 *, int, int, const struct path___303 *);
	int (*quota_off)(struct super_block___302 *, int);
	int (*quota_enable)(struct super_block___302 *, unsigned int);
	int (*quota_disable)(struct super_block___302 *, unsigned int);
	int (*quota_sync)(struct super_block___302 *, int);
	int (*set_info)(struct super_block___302 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___302 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___302 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___302 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___302 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___302 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___132;

struct address_space_operations___302 {
	int (*writepage)(struct page___304 *, struct writeback_control___132 *);
	int (*readpage)(struct file___303 *, struct page___304 *);
	int (*writepages)(struct address_space___302 *, struct writeback_control___132 *);
	int (*set_page_dirty)(struct page___304 *);
	int (*readpages)(struct file___303 *, struct address_space___302 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___303 *, struct address_space___302 *, loff_t, unsigned int, unsigned int, struct page___304 **, void **);
	int (*write_end)(struct file___303 *, struct address_space___302 *, loff_t, unsigned int, unsigned int, struct page___304 *, void *);
	sector_t (*bmap)(struct address_space___302 *, sector_t);
	void (*invalidatepage)(struct page___304 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___304 *, gfp_t);
	void (*freepage)(struct page___304 *);
	ssize_t (*direct_IO)(struct kiocb___303 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___302 *, struct page___304 *, struct page___304 *, enum migrate_mode);
	bool (*isolate_page)(struct page___304 *, isolate_mode_t);
	void (*putback_page)(struct page___304 *);
	int (*launder_page)(struct page___304 *);
	int (*is_partially_uptodate)(struct page___304 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___304 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___302 *, struct page___304 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___303 *, sector_t *);
	void (*swap_deactivate)(struct file___303 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___132 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___149 *wb;
	struct inode___303 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___302 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___303 *bd_inode;
	struct super_block___302 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___302 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___149 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___302 {
	struct dentry___303 * (*lookup)(struct inode___303 *, struct dentry___303 *, unsigned int);
	const char * (*get_link)(struct dentry___303 *, struct inode___303 *, struct delayed_call *);
	int (*permission)(struct inode___303 *, int);
	struct posix_acl * (*get_acl)(struct inode___303 *, int);
	int (*readlink)(struct dentry___303 *, char *, int);
	int (*create)(struct inode___303 *, struct dentry___303 *, umode_t, bool);
	int (*link)(struct dentry___303 *, struct inode___303 *, struct dentry___303 *);
	int (*unlink)(struct inode___303 *, struct dentry___303 *);
	int (*symlink)(struct inode___303 *, struct dentry___303 *, const char *);
	int (*mkdir)(struct inode___303 *, struct dentry___303 *, umode_t);
	int (*rmdir)(struct inode___303 *, struct dentry___303 *);
	int (*mknod)(struct inode___303 *, struct dentry___303 *, umode_t, dev_t);
	int (*rename)(struct inode___303 *, struct dentry___303 *, struct inode___303 *, struct dentry___303 *, unsigned int);
	int (*setattr)(struct dentry___303 *, struct iattr___302 *);
	int (*getattr)(const struct path___303 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___303 *, char *, size_t);
	int (*fiemap)(struct inode___303 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___303 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___303 *, struct dentry___303 *, struct file___303 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___303 *, struct dentry___303 *, umode_t);
	int (*set_acl)(struct inode___303 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___302 {
	void (*fl_copy_lock)(struct file_lock___303 *, struct file_lock___303 *);
	void (*fl_release_private)(struct file_lock___303 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___302;

struct lock_manager_operations___302;

struct file_lock___303 {
	struct file_lock___303 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___303 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___302 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___302 *fl_ops;
	const struct lock_manager_operations___302 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___302 {
	int (*lm_compare_owner)(struct file_lock___303 *, struct file_lock___303 *);
	long unsigned int (*lm_owner_key)(struct file_lock___303 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___303 *);
	int (*lm_grant)(struct file_lock___303 *, int);
	bool (*lm_break)(struct file_lock___303 *);
	int (*lm_change)(struct file_lock___303 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___303 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___302 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___302 *fa_next;
	struct file___303 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___302 {
	const char *name;
	int fs_flags;
	struct dentry___303 * (*mount)(struct file_system_type___302 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___302 *);
	struct module___244 *owner;
	struct file_system_type___302 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___302 {
	struct inode___303 * (*alloc_inode)(struct super_block___302 *);
	void (*destroy_inode)(struct inode___303 *);
	void (*dirty_inode)(struct inode___303 *, int);
	int (*write_inode)(struct inode___303 *, struct writeback_control___132 *);
	int (*drop_inode)(struct inode___303 *);
	void (*evict_inode)(struct inode___303 *);
	void (*put_super)(struct super_block___302 *);
	int (*sync_fs)(struct super_block___302 *, int);
	int (*freeze_super)(struct super_block___302 *);
	int (*freeze_fs)(struct super_block___302 *);
	int (*thaw_super)(struct super_block___302 *);
	int (*unfreeze_fs)(struct super_block___302 *);
	int (*statfs)(struct dentry___303 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___302 *, int *, char *);
	void (*umount_begin)(struct super_block___302 *);
	int (*show_options)(struct seq_file___256 *, struct dentry___303 *);
	int (*show_devname)(struct seq_file___256 *, struct dentry___303 *);
	int (*show_path)(struct seq_file___256 *, struct dentry___303 *);
	int (*show_stats)(struct seq_file___256 *, struct dentry___303 *);
	ssize_t (*quota_read)(struct super_block___302 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___302 *, int, const char *, size_t, loff_t);
	struct dquot___302 ** (*get_dquots)(struct inode___303 *);
	int (*bdev_try_to_free_page)(struct super_block___302 *, struct page___304 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___302 *, struct shrink_control___117 *);
	long int (*free_cached_objects)(struct super_block___302 *, struct shrink_control___117 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___149(struct bio___149 *);

struct bio_vec___150 {
	struct page___304 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___149;

struct bio_set___149;

struct bio___149 {
	struct bio___149 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___149 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___149 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___150 *bi_io_vec;
	struct bio_set___149 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___150 bi_inline_vecs[0];
};

typedef void compound_page_dtor___292(struct page___304 *);

typedef int (*key_restrict_link_func_t___282)(struct key___281 *, const struct key_type *, const union key_payload *, struct key___281 *);

struct key_restriction___281;

struct key___281 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___304 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___281 *restrict_link;
};

struct key_restriction___281 {
	key_restrict_link_func_t___282 check;
	struct key___281 *key;
	struct key_type *keytype;
};

struct cgroup_namespace___208 {
	refcount_t count;
	struct ns_common___9 ns;
	struct user_namespace___223 *user_ns;
	struct ucounts___223 *ucounts;
	struct css_set___208 *root_cset;
};

struct ucounts___223 {
	struct hlist_node node;
	struct user_namespace___223 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct dev_pm_ops___268 {
	int (*prepare)(struct device___268 *);
	void (*complete)(struct device___268 *);
	int (*suspend)(struct device___268 *);
	int (*resume)(struct device___268 *);
	int (*freeze)(struct device___268 *);
	int (*thaw)(struct device___268 *);
	int (*poweroff)(struct device___268 *);
	int (*restore)(struct device___268 *);
	int (*suspend_late)(struct device___268 *);
	int (*resume_early)(struct device___268 *);
	int (*freeze_late)(struct device___268 *);
	int (*thaw_early)(struct device___268 *);
	int (*poweroff_late)(struct device___268 *);
	int (*restore_early)(struct device___268 *);
	int (*suspend_noirq)(struct device___268 *);
	int (*resume_noirq)(struct device___268 *);
	int (*freeze_noirq)(struct device___268 *);
	int (*thaw_noirq)(struct device___268 *);
	int (*poweroff_noirq)(struct device___268 *);
	int (*restore_noirq)(struct device___268 *);
	int (*runtime_suspend)(struct device___268 *);
	int (*runtime_resume)(struct device___268 *);
	int (*runtime_idle)(struct device___268 *);
};

struct dev_pm_domain___268 {
	struct dev_pm_ops___268 ops;
	void (*detach)(struct device___268 *, bool);
	int (*activate)(struct device___268 *);
	void (*sync)(struct device___268 *);
	void (*dismiss)(struct device___268 *);
};

struct bus_type___268 {
	const char *name;
	const char *dev_name;
	struct device___268 *dev_root;
	const struct attribute_group___267 **bus_groups;
	const struct attribute_group___267 **dev_groups;
	const struct attribute_group___267 **drv_groups;
	int (*match)(struct device___268 *, struct device_driver___268 *);
	int (*uevent)(struct device___268 *, struct kobj_uevent_env *);
	int (*probe)(struct device___268 *);
	int (*remove)(struct device___268 *);
	void (*shutdown)(struct device___268 *);
	int (*online)(struct device___268 *);
	int (*offline)(struct device___268 *);
	int (*suspend)(struct device___268 *, pm_message_t);
	int (*resume)(struct device___268 *);
	int (*num_vf)(struct device___268 *);
	int (*dma_configure)(struct device___268 *);
	const struct dev_pm_ops___268 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___268 {
	const char *name;
	struct bus_type___268 *bus;
	struct module___244 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___268 *);
	int (*remove)(struct device___268 *);
	void (*shutdown)(struct device___268 *);
	int (*suspend)(struct device___268 *, pm_message_t);
	int (*resume)(struct device___268 *);
	const struct attribute_group___267 **groups;
	const struct dev_pm_ops___268 *pm;
	void (*coredump)(struct device___268 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___268 {
	const char *name;
	const struct attribute_group___267 **groups;
	int (*uevent)(struct device___268 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___268 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___268 *);
	const struct dev_pm_ops___268 *pm;
};

struct class___268 {
	const char *name;
	struct module___244 *owner;
	const struct attribute_group___267 **class_groups;
	const struct attribute_group___267 **dev_groups;
	struct kobject___290 *dev_kobj;
	int (*dev_uevent)(struct device___268 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___268 *, umode_t *);
	void (*class_release)(struct class___268 *);
	void (*dev_release)(struct device___268 *);
	int (*shutdown_pre)(struct device___268 *);
	const struct kobj_ns_type_operations___25 *ns_type;
	const void * (*namespace)(struct device___268 *);
	const struct dev_pm_ops___268 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct irq_domain_ops___19;

struct irq_domain___19 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___19 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___202 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___2 *gc;
	struct irq_domain___19 *parent;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_direct_max_irq;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_tree_mutex;
	unsigned int linear_revmap[0];
};

struct fwnode_operations___202;

struct fwnode_handle___202 {
	struct fwnode_handle___202 *secondary;
	const struct fwnode_operations___202 *ops;
};

struct property___57;

struct device_node___60 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___202 fwnode;
	struct property___57 *properties;
	struct property___57 *deadprops;
	struct device_node___60 *parent;
	struct device_node___60 *child;
	struct device_node___60 *sibling;
	struct kobject___290 kobj;
	long unsigned int _flags;
	void *data;
};

struct fwnode_reference_args___202;

struct fwnode_endpoint___202;

struct fwnode_operations___202 {
	struct fwnode_handle___202 * (*get)(struct fwnode_handle___202 *);
	void (*put)(struct fwnode_handle___202 *);
	bool (*device_is_available)(const struct fwnode_handle___202 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___202 *, const struct device___268 *);
	bool (*property_present)(const struct fwnode_handle___202 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___202 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___202 *, const char *, const char **, size_t);
	struct fwnode_handle___202 * (*get_parent)(const struct fwnode_handle___202 *);
	struct fwnode_handle___202 * (*get_next_child_node)(const struct fwnode_handle___202 *, struct fwnode_handle___202 *);
	struct fwnode_handle___202 * (*get_named_child_node)(const struct fwnode_handle___202 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___202 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___202 *);
	struct fwnode_handle___202 * (*graph_get_next_endpoint)(const struct fwnode_handle___202 *, struct fwnode_handle___202 *);
	struct fwnode_handle___202 * (*graph_get_remote_endpoint)(const struct fwnode_handle___202 *);
	struct fwnode_handle___202 * (*graph_get_port_parent)(struct fwnode_handle___202 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___202 *, struct fwnode_endpoint___202 *);
};

struct fwnode_endpoint___202 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___202 *local_fwnode;
};

struct fwnode_reference_args___202 {
	struct fwnode_handle___202 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct property___57 {
	char *name;
	int length;
	void *value;
	struct property___57 *next;
	long unsigned int _flags;
	struct bin_attribute___266 attr;
};

struct irq_fwspec___19 {
	struct fwnode_handle___202 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___19 {
	int (*match)(struct irq_domain___19 *, struct device_node___60 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___19 *, struct irq_fwspec___19 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___19 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___19 *, unsigned int);
	int (*xlate)(struct irq_domain___19 *, struct device_node___60 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___19 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___19 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___19 *, struct irq_data___5 *, bool);
	void (*deactivate)(struct irq_domain___19 *, struct irq_data___5 *);
	int (*translate)(struct irq_domain___19 *, struct irq_fwspec___19 *, long unsigned int *, unsigned int *);
};

struct backlight_device___5;

struct fb_info___5;

struct backlight_ops___5 {
	unsigned int options;
	int (*update_status)(struct backlight_device___5 *);
	int (*get_brightness)(struct backlight_device___5 *);
	int (*check_fb)(struct backlight_device___5 *, struct fb_info___5 *);
};

struct backlight_device___5 {
	struct backlight_properties props;
	struct mutex update_lock;
	struct mutex ops_lock;
	const struct backlight_ops___5 *ops;
	struct notifier_block fb_notif;
	struct list_head entry;
	struct device___268 dev;
	bool fb_bl_on[32];
	int use_count;
};

struct fb_pixmap___5 {
	u8 *addr;
	u32 size;
	u32 offset;
	u32 buf_align;
	u32 scan_align;
	u32 access_align;
	u32 flags;
	u32 blit_x;
	u32 blit_y;
	void (*writeio)(struct fb_info___5 *, void *, void *, unsigned int);
	void (*readio)(struct fb_info___5 *, void *, void *, unsigned int);
};

struct fb_deferred_io___5;

struct fb_ops___5;

struct fb_tile_ops___5;

struct fb_info___5 {
	atomic_t count;
	int node;
	int flags;
	int fbcon_rotate_hint;
	struct mutex lock;
	struct mutex mm_lock;
	struct fb_var_screeninfo var;
	struct fb_fix_screeninfo fix;
	struct fb_monspecs monspecs;
	struct work_struct queue;
	struct fb_pixmap___5 pixmap;
	struct fb_pixmap___5 sprite;
	struct fb_cmap cmap;
	struct list_head modelist;
	struct fb_videomode *mode;
	struct backlight_device___5 *bl_dev;
	struct mutex bl_curve_mutex;
	u8 bl_curve[128];
	struct delayed_work deferred_work;
	struct fb_deferred_io___5 *fbdefio;
	struct fb_ops___5 *fbops;
	struct device___268 *device;
	struct device___268 *dev;
	int class_flag;
	struct fb_tile_ops___5 *tileops;
	union {
		char *screen_base;
		char *screen_buffer;
	};
	long unsigned int screen_size;
	void *pseudo_palette;
	u32 state;
	void *fbcon_par;
	void *par;
	struct apertures_struct *apertures;
	bool skip_vt_switch;
};

struct fb_deferred_io___5 {
	long unsigned int delay;
	struct mutex lock;
	struct list_head pagelist;
	void (*first_io)(struct fb_info___5 *);
	void (*deferred_io)(struct fb_info___5 *, struct list_head *);
};

struct fb_ops___5 {
	struct module___244 *owner;
	int (*fb_open)(struct fb_info___5 *, int);
	int (*fb_release)(struct fb_info___5 *, int);
	ssize_t (*fb_read)(struct fb_info___5 *, char *, size_t, loff_t *);
	ssize_t (*fb_write)(struct fb_info___5 *, const char *, size_t, loff_t *);
	int (*fb_check_var)(struct fb_var_screeninfo *, struct fb_info___5 *);
	int (*fb_set_par)(struct fb_info___5 *);
	int (*fb_setcolreg)(unsigned int, unsigned int, unsigned int, unsigned int, unsigned int, struct fb_info___5 *);
	int (*fb_setcmap)(struct fb_cmap *, struct fb_info___5 *);
	int (*fb_blank)(int, struct fb_info___5 *);
	int (*fb_pan_display)(struct fb_var_screeninfo *, struct fb_info___5 *);
	void (*fb_fillrect)(struct fb_info___5 *, const struct fb_fillrect *);
	void (*fb_copyarea)(struct fb_info___5 *, const struct fb_copyarea *);
	void (*fb_imageblit)(struct fb_info___5 *, const struct fb_image *);
	int (*fb_cursor)(struct fb_info___5 *, struct fb_cursor *);
	int (*fb_sync)(struct fb_info___5 *);
	int (*fb_ioctl)(struct fb_info___5 *, unsigned int, long unsigned int);
	int (*fb_compat_ioctl)(struct fb_info___5 *, unsigned int, long unsigned int);
	int (*fb_mmap)(struct fb_info___5 *, struct vm_area_struct___304 *);
	void (*fb_get_caps)(struct fb_info___5 *, struct fb_blit_caps *, struct fb_var_screeninfo *);
	void (*fb_destroy)(struct fb_info___5 *);
	int (*fb_debug_enter)(struct fb_info___5 *);
	int (*fb_debug_leave)(struct fb_info___5 *);
};

struct fb_tile_ops___5 {
	void (*fb_settile)(struct fb_info___5 *, struct fb_tilemap *);
	void (*fb_tilecopy)(struct fb_info___5 *, struct fb_tilearea *);
	void (*fb_tilefill)(struct fb_info___5 *, struct fb_tilerect *);
	void (*fb_tileblit)(struct fb_info___5 *, struct fb_tileblit *);
	void (*fb_tilecursor)(struct fb_info___5 *, struct fb_tilecursor *);
	int (*fb_get_tilemax)(struct fb_info___5 *);
};

struct seq_operations___255 {
	void * (*start)(struct seq_file___256 *, loff_t *);
	void (*stop)(struct seq_file___256 *, void *);
	void * (*next)(struct seq_file___256 *, void *, loff_t *);
	int (*show)(struct seq_file___256 *, void *);
};

struct bpf_map___209;

struct bpf_map_ops___208 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___209 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___209 *, struct file___303 *);
	void (*map_free)(struct bpf_map___209 *);
	int (*map_get_next_key)(struct bpf_map___209 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___209 *);
	void * (*map_lookup_elem)(struct bpf_map___209 *, void *);
	int (*map_update_elem)(struct bpf_map___209 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___209 *, void *);
	int (*map_push_elem)(struct bpf_map___209 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___209 *, void *);
	int (*map_peek_elem)(struct bpf_map___209 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___209 *, struct file___303 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___209 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___209 *, void *, struct seq_file___256 *);
	int (*map_check_btf)(const struct bpf_map___209 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___209 {
	const struct bpf_map_ops___208 *ops;
	struct bpf_map___209 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___281 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___208;

typedef void (*kthread_work_func_t___208)(struct kthread_work___208 *);

struct kthread_worker___208;

struct kthread_work___208 {
	struct list_head node;
	kthread_work_func_t___208 func;
	struct kthread_worker___208 *worker;
	int canceling;
};

struct kthread_worker___208 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___304 *task;
	struct kthread_work___208 *current_work;
};

struct kthread_delayed_work___208 {
	struct kthread_work___208 work;
	struct timer_list timer;
};

struct psi_group___208 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___208 *poll_kworker;
	struct kthread_delayed_work___208 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___208;

struct cgroup_rstat_cpu___208;

struct cgroup___208 {
	struct cgroup_subsys_state___208 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___297 *kn;
	struct cgroup_file___208 procs_file;
	struct cgroup_file___208 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___208 *subsys[13];
	struct cgroup_root___208 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___208 *dom_cgrp;
	struct cgroup_rstat_cpu___208 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___35 bpf;
	atomic_t congestion_count;
	struct cgroup___208 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___208 psi;
	int ancestor_ids[0];
};

struct cftype___208;

struct cgroup_subsys___208 {
	struct cgroup_subsys_state___208 * (*css_alloc)(struct cgroup_subsys_state___208 *);
	int (*css_online)(struct cgroup_subsys_state___208 *);
	void (*css_offline)(struct cgroup_subsys_state___208 *);
	void (*css_released)(struct cgroup_subsys_state___208 *);
	void (*css_free)(struct cgroup_subsys_state___208 *);
	void (*css_reset)(struct cgroup_subsys_state___208 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___208 *, int);
	int (*css_extra_stat_show)(struct seq_file___256 *, struct cgroup_subsys_state___208 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___304 *);
	void (*cancel_fork)(struct task_struct___304 *);
	void (*fork)(struct task_struct___304 *);
	void (*exit)(struct task_struct___304 *);
	void (*free)(struct task_struct___304 *);
	void (*bind)(struct cgroup_subsys_state___208 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___208 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___208 *dfl_cftypes;
	struct cftype___208 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___208 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___208 *updated_children;
	struct cgroup___208 *updated_next;
};

struct cgroup_root___208 {
	struct kernfs_root___296 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___208 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___208 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___208 *ss;
	struct list_head node;
	struct kernfs_ops___296 *kf_ops;
	int (*open)(struct kernfs_open_file___296 *);
	void (*release)(struct kernfs_open_file___296 *);
	u64 (*read_u64)(struct cgroup_subsys_state___208 *, struct cftype___208 *);
	s64 (*read_s64)(struct cgroup_subsys_state___208 *, struct cftype___208 *);
	int (*seq_show)(struct seq_file___256 *, void *);
	void * (*seq_start)(struct seq_file___256 *, loff_t *);
	void * (*seq_next)(struct seq_file___256 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___256 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___208 *, struct cftype___208 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___208 *, struct cftype___208 *, s64);
	ssize_t (*write)(struct kernfs_open_file___296 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___296 *, struct poll_table_struct___6 *);
};

struct bdi_writeback_congested___149 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___149 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___149 {
	struct bio___149 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___150 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___150 bip_inline_vecs[0];
};

struct bio_set___149 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___149 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___117 {
	struct mem_cgroup___117 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___117 {
	struct lruvec___303 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___117 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___117 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

typedef unsigned char u_char;

struct module___245;

struct file___304;

struct kiocb___304;

struct vm_area_struct___305;

struct inode___304;

struct file_lock___304;

struct page___305;

struct seq_file___257;

struct file_operations___304 {
	struct module___245 *owner;
	loff_t (*llseek)(struct file___304 *, loff_t, int);
	ssize_t (*read)(struct file___304 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___304 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___304 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___304 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___304 *, bool);
	int (*iterate)(struct file___304 *, struct dir_context *);
	int (*iterate_shared)(struct file___304 *, struct dir_context *);
	__poll_t (*poll)(struct file___304 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___304 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___304 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___304 *, struct vm_area_struct___305 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___304 *, struct file___304 *);
	int (*flush)(struct file___304 *, fl_owner_t);
	int (*release)(struct inode___304 *, struct file___304 *);
	int (*fsync)(struct file___304 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___304 *, int);
	int (*lock)(struct file___304 *, int, struct file_lock___304 *);
	ssize_t (*sendpage)(struct file___304 *, struct page___305 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___304 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___304 *, int, struct file_lock___304 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___304 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___304 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___304 *, long int, struct file_lock___304 **, void **);
	long int (*fallocate)(struct file___304 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___257 *, struct file___304 *);
	ssize_t (*copy_file_range)(struct file___304 *, loff_t, struct file___304 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___304 *, loff_t, struct file___304 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___304 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___304 {
	u64 seqnum;
	struct vm_area_struct___305 *vmas[4];
};

struct page_frag___304 {
	struct page___305 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___304;

struct pid___202;

struct cred___282;

struct nsproxy___249;

struct signal_struct___228;

struct vm_struct___220;

struct task_struct___305 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___305 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___304 *mm;
	struct mm_struct___304 *active_mm;
	struct vmacache___304 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___305 *real_parent;
	struct task_struct___305 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___305 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___202 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___202 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___202 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___282 *ptracer_cred;
	const struct cred___282 *real_cred;
	const struct cred___282 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___249 *nsproxy;
	struct signal_struct___228 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___305 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___82 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___304 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___305 *oom_reaper_list;
	struct vm_struct___220 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___131 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___305 *pgtable_t___304;

struct address_space___303;

struct dev_pagemap___293;

struct page___305 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___303 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___305 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___304 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___304 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___293 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___304;

struct lruvec___304 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___304 *pgdat;
};

struct zone___304 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___304 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___304 {
	struct zone___304 *zone;
	int zone_idx;
};

struct zonelist___304 {
	struct zoneref___304 _zonerefs[25];
};

struct pglist_data___304 {
	struct zone___304 node_zones[3];
	struct zonelist___304 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___305 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___305 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___304 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___305 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___305 *owner;
};

struct secondary_data___305 {
	void *stack;
	struct task_struct___305 *task;
	long int status;
};

struct blocking_notifier_head___304 {
	struct rw_semaphore___305 rwsem;
	struct notifier_block *head;
};

struct dentry___304;

struct path___304 {
	struct vfsmount *mnt;
	struct dentry___304 *dentry;
};

struct fown_struct___202 {
	rwlock_t lock;
	struct pid___202 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___304 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___304 f_path;
	struct inode___304 *f_inode;
	const struct file_operations___304 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___202 f_owner;
	const struct cred___282 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___303 *f_mapping;
	errseq_t f_wb_err;
};

struct key___282;

struct user_struct___282;

struct cred___282 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___282 *session_keyring;
	struct key___282 *process_keyring;
	struct key___282 *thread_keyring;
	struct key___282 *request_key_auth;
	void *security;
	struct user_struct___282 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___297;

struct kernfs_elem_dir___297 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___297 *root;
};

struct kernfs_node___298;

struct kernfs_syscall_ops___297;

struct kernfs_root___297 {
	struct kernfs_node___298 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___297 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___297 {
	struct kernfs_node___298 *target_kn;
};

struct kernfs_ops___297;

struct kernfs_elem_attr___297 {
	const struct kernfs_ops___297 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___298 *notify_next;
};

struct kernfs_node___298 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___298 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___297 dir;
		struct kernfs_elem_symlink___297 symlink;
		struct kernfs_elem_attr___297 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___297;

struct kernfs_ops___297 {
	int (*open)(struct kernfs_open_file___297 *);
	void (*release)(struct kernfs_open_file___297 *);
	int (*seq_show)(struct seq_file___257 *, void *);
	void * (*seq_start)(struct seq_file___257 *, loff_t *);
	void * (*seq_next)(struct seq_file___257 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___257 *, void *);
	ssize_t (*read)(struct kernfs_open_file___297 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___297 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___297 *, struct vm_area_struct___305 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___297 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___297 {
	int (*remount_fs)(struct kernfs_root___297 *, int *, char *);
	int (*show_options)(struct seq_file___257 *, struct kernfs_root___297 *);
	int (*mkdir)(struct kernfs_node___298 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___298 *);
	int (*rename)(struct kernfs_node___298 *, struct kernfs_node___298 *, const char *);
	int (*show_path)(struct seq_file___257 *, struct kernfs_node___298 *, struct kernfs_root___297 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___256;

struct seq_file___257 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___256 *op;
	int poll_event;
	const struct file___304 *file;
	void *private;
};

struct vm_operations_struct___293;

struct kernfs_open_file___297 {
	struct kernfs_node___298 *kn;
	struct file___304 *file;
	struct seq_file___257 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___293 *vm_ops;
};

struct vm_fault___293;

struct vm_operations_struct___293 {
	void (*open)(struct vm_area_struct___305 *);
	void (*close)(struct vm_area_struct___305 *);
	int (*split)(struct vm_area_struct___305 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___305 *);
	vm_fault_t (*fault)(struct vm_fault___293 *);
	vm_fault_t (*huge_fault)(struct vm_fault___293 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___293 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___305 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___293 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___293 *);
	int (*access)(struct vm_area_struct___305 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___305 *);
	int (*set_policy)(struct vm_area_struct___305 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___305 *, long unsigned int);
	struct page___305 * (*find_special_page)(struct vm_area_struct___305 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_area_struct___305 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___305 *vm_next;
	struct vm_area_struct___305 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___304 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___293 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___304 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___291;

struct bin_attribute___267;

struct attribute_group___268 {
	const char *name;
	umode_t (*is_visible)(struct kobject___291 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___291 *, struct bin_attribute___267 *, int);
	struct attribute **attrs;
	struct bin_attribute___267 **bin_attrs;
};

struct kset___290;

struct kobj_type___290;

struct kobject___291 {
	const char *name;
	struct list_head entry;
	struct kobject___291 *parent;
	struct kset___290 *kset;
	struct kobj_type___290 *ktype;
	struct kernfs_node___298 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___267 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___304 *, struct kobject___291 *, struct bin_attribute___267 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___304 *, struct kobject___291 *, struct bin_attribute___267 *, char *, loff_t, size_t);
	int (*mmap)(struct file___304 *, struct kobject___291 *, struct bin_attribute___267 *, struct vm_area_struct___305 *);
};

struct sysfs_ops___290 {
	ssize_t (*show)(struct kobject___291 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___291 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___290;

struct kset___290 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___291 kobj;
	const struct kset_uevent_ops___290 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___290 {
	void (*release)(struct kobject___291 *);
	const struct sysfs_ops___290 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___25 * (*child_ns_type)(struct kobject___291 *);
	const void * (*namespace)(struct kobject___291 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___290 {
	int (* const filter)(struct kset___290 *, struct kobject___291 *);
	const char * (* const name)(struct kset___290 *, struct kobject___291 *);
	int (* const uevent)(struct kset___290 *, struct kobject___291 *, struct kobj_uevent_env *);
};

struct kobj_attribute___283 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___291 *, struct kobj_attribute___283 *, char *);
	ssize_t (*store)(struct kobject___291 *, struct kobj_attribute___283 *, const char *, size_t);
};

struct kernel_param___242;

struct kernel_param_ops___242 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___242 *);
	int (*get)(char *, const struct kernel_param___242 *);
	void (*free)(void *);
};

struct kparam_array___242;

struct kernel_param___242 {
	const char *name;
	struct module___245 *mod;
	const struct kernel_param_ops___242 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___242 *arr;
	};
};

struct kparam_array___242 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___242 *ops;
	void *elem;
};

struct module_kobject___242 {
	struct kobject___291 kobj;
	struct module___245 *mod;
	struct kobject___291 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___242 {
	struct module___245 *mod;
	struct latch_tree_node node;
};

struct module_layout___242 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___242 mtn;
};

struct module_attribute___242;

struct module___245 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___242 mkobj;
	struct module_attribute___242 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___291 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___242 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___242 core_layout;
	struct module_layout___242 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___242 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___242 *, struct module_kobject___242 *, char *);
	ssize_t (*store)(struct module_attribute___242 *, struct module_kobject___242 *, const char *, size_t);
	void (*setup)(struct module___245 *, const char *);
	int (*test)(struct module___245 *);
	void (*free)(struct module___245 *);
};

struct dentry_operations___303;

struct super_block___303;

struct dentry___304 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___304 *d_parent;
	struct qstr d_name;
	struct inode___304 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___303 *d_op;
	struct super_block___303 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___303;

struct address_space___303 {
	struct inode___304 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___305 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___303 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___303;

struct block_device___303;

struct cdev___55;

struct inode___304 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___303 *i_op;
	struct super_block___303 *i_sb;
	struct address_space___303 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___305 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___304 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___303 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___303 *i_bdev;
		struct cdev___55 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___303 {
	int (*d_revalidate)(struct dentry___304 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___304 *, unsigned int);
	int (*d_hash)(const struct dentry___304 *, struct qstr *);
	int (*d_compare)(const struct dentry___304 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___304 *);
	int (*d_init)(struct dentry___304 *);
	void (*d_release)(struct dentry___304 *);
	void (*d_prune)(struct dentry___304 *);
	void (*d_iput)(struct dentry___304 *, struct inode___304 *);
	char * (*d_dname)(struct dentry___304 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___304 *);
	int (*d_manage)(const struct path___304 *, bool);
	struct dentry___304 * (*d_real)(struct dentry___304 *, const struct inode___304 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___303;

struct mem_dqinfo___303 {
	struct quota_format_type___303 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___303;

struct quota_info___303 {
	unsigned int flags;
	struct rw_semaphore___305 dqio_sem;
	struct inode___304 *files[3];
	struct mem_dqinfo___303 info[3];
	const struct quota_format_ops___303 *ops[3];
};

struct rcuwait___303 {
	struct task_struct___305 *task;
};

struct percpu_rw_semaphore___303 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___305 rw_sem;
	struct rcuwait___303 writer;
	int readers_block;
};

struct sb_writers___303 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___303 rw_sem[3];
};

struct file_system_type___303;

struct super_operations___303;

struct dquot_operations___303;

struct quotactl_ops___303;

struct super_block___303 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___303 *s_type;
	const struct super_operations___303 *s_op;
	const struct dquot_operations___303 *dq_op;
	const struct quotactl_ops___303 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___304 *s_root;
	struct rw_semaphore___305 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___303 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___303 s_dquot;
	struct sb_writers___303 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___303 *s_d_op;
	int cleancache_poolid;
	struct shrinker___117 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct pid_namespace___202;

struct upid___202 {
	int nr;
	struct pid_namespace___202 *ns;
};

struct pid_namespace___202 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___305 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___202 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___304 *proc_self;
	struct dentry___304 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___3 *user_ns;
	struct ucounts___2 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___9 ns;
};

struct pid___202 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___202 numbers[1];
};

struct core_state___304;

struct mm_struct___304 {
	struct {
		struct vm_area_struct___305 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___304 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___305 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___304 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___305 *owner;
		struct user_namespace___3 *user_ns;
		struct file___304 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___304 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___293)(struct vm_area_struct___305 *, long unsigned int, const struct page___305 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___293)(struct page___305 *, void *);

struct device___269;

struct dev_pagemap___293 {
	dev_page_fault_t___293 page_fault;
	dev_page_free_t___293 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___269 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___304 {
	struct task_struct___305 *task;
	struct core_thread___304 *next;
};

struct core_state___304 {
	atomic_t nr_threads;
	struct core_thread___304 dumper;
	struct completion startup;
};

struct vm_fault___293 {
	struct vm_area_struct___305 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___305 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___305 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___304 prealloc_pte;
};

struct user_struct___282 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___282 *uid_keyring;
	struct key___282 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct nsproxy___249 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___202 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct tty_struct___21;

struct signal_struct___228 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___305 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___305 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___202 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___202 *tty_old_pgrp;
	int leader;
	struct tty_struct___21 *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___304 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___202 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_struct___220 {
	struct vm_struct___220 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___305 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___240 {
	struct task_struct___305 task;
	long unsigned int stack[8192];
};

struct kiocb___304 {
	struct file___304 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___304 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___303 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___304 *ia_file;
};

struct dquot___303 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___303 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___303 {
	int qf_fmt_id;
	const struct quota_format_ops___303 *qf_ops;
	struct module___245 *qf_owner;
	struct quota_format_type___303 *qf_next;
};

struct quota_format_ops___303 {
	int (*check_quota_file)(struct super_block___303 *, int);
	int (*read_file_info)(struct super_block___303 *, int);
	int (*write_file_info)(struct super_block___303 *, int);
	int (*free_file_info)(struct super_block___303 *, int);
	int (*read_dqblk)(struct dquot___303 *);
	int (*commit_dqblk)(struct dquot___303 *);
	int (*release_dqblk)(struct dquot___303 *);
	int (*get_next_id)(struct super_block___303 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___303 {
	int (*write_dquot)(struct dquot___303 *);
	struct dquot___303 * (*alloc_dquot)(struct super_block___303 *, int);
	void (*destroy_dquot)(struct dquot___303 *);
	int (*acquire_dquot)(struct dquot___303 *);
	int (*release_dquot)(struct dquot___303 *);
	int (*mark_dirty)(struct dquot___303 *);
	int (*write_info)(struct super_block___303 *, int);
	qsize_t * (*get_reserved_space)(struct inode___304 *);
	int (*get_projid)(struct inode___304 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___304 *, qsize_t *);
	int (*get_next_id)(struct super_block___303 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___303 {
	int (*quota_on)(struct super_block___303 *, int, int, const struct path___304 *);
	int (*quota_off)(struct super_block___303 *, int);
	int (*quota_enable)(struct super_block___303 *, unsigned int);
	int (*quota_disable)(struct super_block___303 *, unsigned int);
	int (*quota_sync)(struct super_block___303 *, int);
	int (*set_info)(struct super_block___303 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___303 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___303 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___303 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___303 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___303 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___303 {
	int (*writepage)(struct page___305 *, struct writeback_control___3 *);
	int (*readpage)(struct file___304 *, struct page___305 *);
	int (*writepages)(struct address_space___303 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___305 *);
	int (*readpages)(struct file___304 *, struct address_space___303 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___304 *, struct address_space___303 *, loff_t, unsigned int, unsigned int, struct page___305 **, void **);
	int (*write_end)(struct file___304 *, struct address_space___303 *, loff_t, unsigned int, unsigned int, struct page___305 *, void *);
	sector_t (*bmap)(struct address_space___303 *, sector_t);
	void (*invalidatepage)(struct page___305 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___305 *, gfp_t);
	void (*freepage)(struct page___305 *);
	ssize_t (*direct_IO)(struct kiocb___304 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___303 *, struct page___305 *, struct page___305 *, enum migrate_mode);
	bool (*isolate_page)(struct page___305 *, isolate_mode_t);
	void (*putback_page)(struct page___305 *);
	int (*launder_page)(struct page___305 *);
	int (*is_partially_uptodate)(struct page___305 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___305 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___303 *, struct page___305 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___304 *, sector_t *);
	void (*swap_deactivate)(struct file___304 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___303 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___304 *bd_inode;
	struct super_block___303 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___303 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___55 {
	struct kobject___291 kobj;
	struct module___245 *owner;
	const struct file_operations___304 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___303 {
	struct dentry___304 * (*lookup)(struct inode___304 *, struct dentry___304 *, unsigned int);
	const char * (*get_link)(struct dentry___304 *, struct inode___304 *, struct delayed_call *);
	int (*permission)(struct inode___304 *, int);
	struct posix_acl * (*get_acl)(struct inode___304 *, int);
	int (*readlink)(struct dentry___304 *, char *, int);
	int (*create)(struct inode___304 *, struct dentry___304 *, umode_t, bool);
	int (*link)(struct dentry___304 *, struct inode___304 *, struct dentry___304 *);
	int (*unlink)(struct inode___304 *, struct dentry___304 *);
	int (*symlink)(struct inode___304 *, struct dentry___304 *, const char *);
	int (*mkdir)(struct inode___304 *, struct dentry___304 *, umode_t);
	int (*rmdir)(struct inode___304 *, struct dentry___304 *);
	int (*mknod)(struct inode___304 *, struct dentry___304 *, umode_t, dev_t);
	int (*rename)(struct inode___304 *, struct dentry___304 *, struct inode___304 *, struct dentry___304 *, unsigned int);
	int (*setattr)(struct dentry___304 *, struct iattr___303 *);
	int (*getattr)(const struct path___304 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___304 *, char *, size_t);
	int (*fiemap)(struct inode___304 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___304 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___304 *, struct dentry___304 *, struct file___304 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___304 *, struct dentry___304 *, umode_t);
	int (*set_acl)(struct inode___304 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___303 {
	void (*fl_copy_lock)(struct file_lock___304 *, struct file_lock___304 *);
	void (*fl_release_private)(struct file_lock___304 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___303;

struct lock_manager_operations___303;

struct file_lock___304 {
	struct file_lock___304 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___304 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___303 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___303 *fl_ops;
	const struct lock_manager_operations___303 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___303 {
	int (*lm_compare_owner)(struct file_lock___304 *, struct file_lock___304 *);
	long unsigned int (*lm_owner_key)(struct file_lock___304 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___304 *);
	int (*lm_grant)(struct file_lock___304 *, int);
	bool (*lm_break)(struct file_lock___304 *);
	int (*lm_change)(struct file_lock___304 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___304 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___303 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___303 *fa_next;
	struct file___304 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___303 {
	const char *name;
	int fs_flags;
	struct dentry___304 * (*mount)(struct file_system_type___303 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___303 *);
	struct module___245 *owner;
	struct file_system_type___303 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___303 {
	struct inode___304 * (*alloc_inode)(struct super_block___303 *);
	void (*destroy_inode)(struct inode___304 *);
	void (*dirty_inode)(struct inode___304 *, int);
	int (*write_inode)(struct inode___304 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___304 *);
	void (*evict_inode)(struct inode___304 *);
	void (*put_super)(struct super_block___303 *);
	int (*sync_fs)(struct super_block___303 *, int);
	int (*freeze_super)(struct super_block___303 *);
	int (*freeze_fs)(struct super_block___303 *);
	int (*thaw_super)(struct super_block___303 *);
	int (*unfreeze_fs)(struct super_block___303 *);
	int (*statfs)(struct dentry___304 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___303 *, int *, char *);
	void (*umount_begin)(struct super_block___303 *);
	int (*show_options)(struct seq_file___257 *, struct dentry___304 *);
	int (*show_devname)(struct seq_file___257 *, struct dentry___304 *);
	int (*show_path)(struct seq_file___257 *, struct dentry___304 *);
	int (*show_stats)(struct seq_file___257 *, struct dentry___304 *);
	ssize_t (*quota_read)(struct super_block___303 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___303 *, int, const char *, size_t, loff_t);
	struct dquot___303 ** (*get_dquots)(struct inode___304 *);
	int (*bdev_try_to_free_page)(struct super_block___303 *, struct page___305 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___303 *, struct shrink_control___117 *);
	long int (*free_cached_objects)(struct super_block___303 *, struct shrink_control___117 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vc_data___3;

struct consw___14 {
	struct module___245 *owner;
	const char * (*con_startup)();
	void (*con_init)(struct vc_data___3 *, int);
	void (*con_deinit)(struct vc_data___3 *);
	void (*con_clear)(struct vc_data___3 *, int, int, int, int);
	void (*con_putc)(struct vc_data___3 *, int, int, int);
	void (*con_putcs)(struct vc_data___3 *, const short unsigned int *, int, int, int);
	void (*con_cursor)(struct vc_data___3 *, int);
	bool (*con_scroll)(struct vc_data___3 *, unsigned int, unsigned int, enum con_scroll, unsigned int);
	int (*con_switch)(struct vc_data___3 *);
	int (*con_blank)(struct vc_data___3 *, int, int);
	int (*con_font_set)(struct vc_data___3 *, struct console_font *, unsigned int);
	int (*con_font_get)(struct vc_data___3 *, struct console_font *);
	int (*con_font_default)(struct vc_data___3 *, struct console_font *, char *);
	int (*con_font_copy)(struct vc_data___3 *, int);
	int (*con_resize)(struct vc_data___3 *, unsigned int, unsigned int, unsigned int);
	void (*con_set_palette)(struct vc_data___3 *, const unsigned char *);
	void (*con_scrolldelta)(struct vc_data___3 *, int);
	int (*con_set_origin)(struct vc_data___3 *);
	void (*con_save_screen)(struct vc_data___3 *);
	u8 (*con_build_attr)(struct vc_data___3 *, u8, u8, u8, u8, u8, u8);
	void (*con_invert_region)(struct vc_data___3 *, u16 *, int);
	u16 * (*con_screen_pos)(struct vc_data___3 *, int);
	long unsigned int (*con_getxy)(struct vc_data___3 *, long unsigned int, int *, int *);
	void (*con_flush_scrollback)(struct vc_data___3 *);
	int (*con_debug_enter)(struct vc_data___3 *);
	int (*con_debug_leave)(struct vc_data___3 *);
};

struct tty_port_operations___21;

struct tty_port_client_operations___21;

struct tty_port___21 {
	struct tty_bufhead buf;
	struct tty_struct___21 *tty;
	struct tty_struct___21 *itty;
	const struct tty_port_operations___21 *ops;
	const struct tty_port_client_operations___21 *client_ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	unsigned char low_latency: 1;
	struct mutex mutex;
	struct mutex buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
	void *client_data;
};

struct vc_data___3 {
	struct tty_port___21 port;
	short unsigned int vc_num;
	unsigned int vc_cols;
	unsigned int vc_rows;
	unsigned int vc_size_row;
	unsigned int vc_scan_lines;
	long unsigned int vc_origin;
	long unsigned int vc_scr_end;
	long unsigned int vc_visible_origin;
	unsigned int vc_top;
	unsigned int vc_bottom;
	const struct consw___14 *vc_sw;
	short unsigned int *vc_screenbuf;
	unsigned int vc_screenbuf_size;
	unsigned char vc_mode;
	unsigned char vc_attr;
	unsigned char vc_def_color;
	unsigned char vc_color;
	unsigned char vc_s_color;
	unsigned char vc_ulcolor;
	unsigned char vc_itcolor;
	unsigned char vc_halfcolor;
	unsigned int vc_cursor_type;
	short unsigned int vc_complement_mask;
	short unsigned int vc_s_complement_mask;
	unsigned int vc_x;
	unsigned int vc_y;
	unsigned int vc_saved_x;
	unsigned int vc_saved_y;
	long unsigned int vc_pos;
	short unsigned int vc_hi_font_mask;
	struct console_font vc_font;
	short unsigned int vc_video_erase_char;
	unsigned int vc_state;
	unsigned int vc_npar;
	unsigned int vc_par[16];
	struct vt_mode vt_mode;
	struct pid___202 *vt_pid;
	int vt_newvt;
	wait_queue_head_t paste_wait;
	unsigned int vc_charset: 1;
	unsigned int vc_s_charset: 1;
	unsigned int vc_disp_ctrl: 1;
	unsigned int vc_toggle_meta: 1;
	unsigned int vc_decscnm: 1;
	unsigned int vc_decom: 1;
	unsigned int vc_decawm: 1;
	unsigned int vc_deccm: 1;
	unsigned int vc_decim: 1;
	unsigned int vc_intensity: 2;
	unsigned int vc_italic: 1;
	unsigned int vc_underline: 1;
	unsigned int vc_blink: 1;
	unsigned int vc_reverse: 1;
	unsigned int vc_s_intensity: 2;
	unsigned int vc_s_italic: 1;
	unsigned int vc_s_underline: 1;
	unsigned int vc_s_blink: 1;
	unsigned int vc_s_reverse: 1;
	unsigned int vc_ques: 1;
	unsigned int vc_need_wrap: 1;
	unsigned int vc_can_do_color: 1;
	unsigned int vc_report_mouse: 2;
	unsigned char vc_utf: 1;
	unsigned char vc_utf_count;
	int vc_utf_char;
	unsigned int vc_tab_stop[8];
	unsigned char vc_palette[48];
	short unsigned int *vc_translate;
	unsigned char vc_G0_charset;
	unsigned char vc_G1_charset;
	unsigned char vc_saved_G0;
	unsigned char vc_saved_G1;
	unsigned int vc_resize_user;
	unsigned int vc_bell_pitch;
	unsigned int vc_bell_duration;
	short unsigned int vc_cur_blink_ms;
	struct vc_data___3 **vc_display_fg;
	struct uni_pagedir *vc_uni_pagedir;
	struct uni_pagedir **vc_uni_pagedir_loc;
};

struct tty_driver___21;

struct console___5 {
	char name[16];
	void (*write)(struct console___5 *, const char *, unsigned int);
	int (*read)(struct console___5 *, char *, unsigned int);
	struct tty_driver___21 * (*device)(struct console___5 *, int *);
	void (*unblank)();
	int (*setup)(struct console___5 *, char *);
	int (*match)(struct console___5 *, char *, int, char *);
	short int flags;
	short int index;
	int cflag;
	void *data;
	struct console___5 *next;
};

struct tty_operations___21;

struct tty_driver___21 {
	int magic;
	struct kref kref;
	struct cdev___55 **cdevs;
	struct module___245 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___21 *other;
	struct tty_struct___21 **ttys;
	struct tty_port___21 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___21 *ops;
	struct list_head tty_drivers;
};

typedef int (*key_restrict_link_func_t___283)(struct key___282 *, const struct key_type *, const union key_payload *, struct key___282 *);

struct key_restriction___282;

struct key___282 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___305 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___282 *restrict_link;
};

struct key_restriction___282 {
	key_restrict_link_func_t___283 check;
	struct key___282 *key;
	struct key_type *keytype;
};

struct tty_ldisc___21;

struct tty_struct___21 {
	int magic;
	struct kref kref;
	struct device___269 *dev;
	struct tty_driver___21 *driver;
	const struct tty_operations___21 *ops;
	int index;
	struct ld_semaphore ldisc_sem;
	struct tty_ldisc___21 *ldisc;
	struct mutex atomic_write_lock;
	struct mutex legacy_mutex;
	struct mutex throttle_mutex;
	struct rw_semaphore___305 termios_rwsem;
	struct mutex winsize_mutex;
	spinlock_t ctrl_lock;
	spinlock_t flow_lock;
	struct ktermios termios;
	struct ktermios termios_locked;
	struct termiox *termiox;
	char name[64];
	struct pid___202 *pgrp;
	struct pid___202 *session;
	long unsigned int flags;
	int count;
	struct winsize winsize;
	long unsigned int stopped: 1;
	long unsigned int flow_stopped: 1;
	int: 30;
	long unsigned int unused: 62;
	int hw_stopped;
	long unsigned int ctrl_status: 8;
	long unsigned int packet: 1;
	int: 23;
	long unsigned int unused_ctrl: 55;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___21 *link;
	struct fasync_struct___303 *fasync;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	spinlock_t files_lock;
	struct list_head tty_files;
	int closing;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___21 *port;
};

struct dev_pm_info___269 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___269 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___269;

struct bus_type___269;

struct device_driver___269;

struct dev_pm_domain___269;

struct irq_domain___20;

struct device_node___61;

struct fwnode_handle___203;

struct class___269;

struct device___269 {
	struct device___269 *parent;
	struct device_private *p;
	struct kobject___291 kobj;
	const char *init_name;
	const struct device_type___269 *type;
	struct mutex mutex;
	struct bus_type___269 *bus;
	struct device_driver___269 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___269 power;
	struct dev_pm_domain___269 *pm_domain;
	struct irq_domain___20 *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___61 *of_node;
	struct fwnode_handle___203 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___269 *class;
	const struct attribute_group___268 **groups;
	void (*release)(struct device___269 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

typedef void compound_page_dtor___293(struct page___305 *);

struct dev_pm_ops___269 {
	int (*prepare)(struct device___269 *);
	void (*complete)(struct device___269 *);
	int (*suspend)(struct device___269 *);
	int (*resume)(struct device___269 *);
	int (*freeze)(struct device___269 *);
	int (*thaw)(struct device___269 *);
	int (*poweroff)(struct device___269 *);
	int (*restore)(struct device___269 *);
	int (*suspend_late)(struct device___269 *);
	int (*resume_early)(struct device___269 *);
	int (*freeze_late)(struct device___269 *);
	int (*thaw_early)(struct device___269 *);
	int (*poweroff_late)(struct device___269 *);
	int (*restore_early)(struct device___269 *);
	int (*suspend_noirq)(struct device___269 *);
	int (*resume_noirq)(struct device___269 *);
	int (*freeze_noirq)(struct device___269 *);
	int (*thaw_noirq)(struct device___269 *);
	int (*poweroff_noirq)(struct device___269 *);
	int (*restore_noirq)(struct device___269 *);
	int (*runtime_suspend)(struct device___269 *);
	int (*runtime_resume)(struct device___269 *);
	int (*runtime_idle)(struct device___269 *);
};

struct dev_pm_domain___269 {
	struct dev_pm_ops___269 ops;
	void (*detach)(struct device___269 *, bool);
	int (*activate)(struct device___269 *);
	void (*sync)(struct device___269 *);
	void (*dismiss)(struct device___269 *);
};

struct bus_type___269 {
	const char *name;
	const char *dev_name;
	struct device___269 *dev_root;
	const struct attribute_group___268 **bus_groups;
	const struct attribute_group___268 **dev_groups;
	const struct attribute_group___268 **drv_groups;
	int (*match)(struct device___269 *, struct device_driver___269 *);
	int (*uevent)(struct device___269 *, struct kobj_uevent_env *);
	int (*probe)(struct device___269 *);
	int (*remove)(struct device___269 *);
	void (*shutdown)(struct device___269 *);
	int (*online)(struct device___269 *);
	int (*offline)(struct device___269 *);
	int (*suspend)(struct device___269 *, pm_message_t);
	int (*resume)(struct device___269 *);
	int (*num_vf)(struct device___269 *);
	int (*dma_configure)(struct device___269 *);
	const struct dev_pm_ops___269 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___269 {
	const char *name;
	struct bus_type___269 *bus;
	struct module___245 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___269 *);
	int (*remove)(struct device___269 *);
	void (*shutdown)(struct device___269 *);
	int (*suspend)(struct device___269 *, pm_message_t);
	int (*resume)(struct device___269 *);
	const struct attribute_group___268 **groups;
	const struct dev_pm_ops___269 *pm;
	void (*coredump)(struct device___269 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___269 {
	const char *name;
	const struct attribute_group___268 **groups;
	int (*uevent)(struct device___269 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___269 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___269 *);
	const struct dev_pm_ops___269 *pm;
};

struct class___269 {
	const char *name;
	struct module___245 *owner;
	const struct attribute_group___268 **class_groups;
	const struct attribute_group___268 **dev_groups;
	struct kobject___291 *dev_kobj;
	int (*dev_uevent)(struct device___269 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___269 *, umode_t *);
	void (*class_release)(struct class___269 *);
	void (*dev_release)(struct device___269 *);
	int (*shutdown_pre)(struct device___269 *);
	const struct kobj_ns_type_operations___25 *ns_type;
	const void * (*namespace)(struct device___269 *);
	const struct dev_pm_ops___269 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct device_attribute___19 {
	struct attribute attr;
	ssize_t (*show)(struct device___269 *, struct device_attribute___19 *, char *);
	ssize_t (*store)(struct device___269 *, struct device_attribute___19 *, const char *, size_t);
};

struct irq_domain_ops___20;

struct irq_domain___20 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___20 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___203 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___2 *gc;
	struct irq_domain___20 *parent;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_direct_max_irq;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_tree_mutex;
	unsigned int linear_revmap[0];
};

struct fwnode_operations___203;

struct fwnode_handle___203 {
	struct fwnode_handle___203 *secondary;
	const struct fwnode_operations___203 *ops;
};

struct property___58;

struct device_node___61 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___203 fwnode;
	struct property___58 *properties;
	struct property___58 *deadprops;
	struct device_node___61 *parent;
	struct device_node___61 *child;
	struct device_node___61 *sibling;
	struct kobject___291 kobj;
	long unsigned int _flags;
	void *data;
};

struct fwnode_reference_args___203;

struct fwnode_endpoint___203;

struct fwnode_operations___203 {
	struct fwnode_handle___203 * (*get)(struct fwnode_handle___203 *);
	void (*put)(struct fwnode_handle___203 *);
	bool (*device_is_available)(const struct fwnode_handle___203 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___203 *, const struct device___269 *);
	bool (*property_present)(const struct fwnode_handle___203 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___203 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___203 *, const char *, const char **, size_t);
	struct fwnode_handle___203 * (*get_parent)(const struct fwnode_handle___203 *);
	struct fwnode_handle___203 * (*get_next_child_node)(const struct fwnode_handle___203 *, struct fwnode_handle___203 *);
	struct fwnode_handle___203 * (*get_named_child_node)(const struct fwnode_handle___203 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___203 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___203 *);
	struct fwnode_handle___203 * (*graph_get_next_endpoint)(const struct fwnode_handle___203 *, struct fwnode_handle___203 *);
	struct fwnode_handle___203 * (*graph_get_remote_endpoint)(const struct fwnode_handle___203 *);
	struct fwnode_handle___203 * (*graph_get_port_parent)(struct fwnode_handle___203 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___203 *, struct fwnode_endpoint___203 *);
};

struct fwnode_endpoint___203 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___203 *local_fwnode;
};

struct fwnode_reference_args___203 {
	struct fwnode_handle___203 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct property___58 {
	char *name;
	int length;
	void *value;
	struct property___58 *next;
	long unsigned int _flags;
	struct bin_attribute___267 attr;
};

struct irq_fwspec___20 {
	struct fwnode_handle___203 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___20 {
	int (*match)(struct irq_domain___20 *, struct device_node___61 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___20 *, struct irq_fwspec___20 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___20 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___20 *, unsigned int);
	int (*xlate)(struct irq_domain___20 *, struct device_node___61 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___20 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___20 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___20 *, struct irq_data___5 *, bool);
	void (*deactivate)(struct irq_domain___20 *, struct irq_data___5 *);
	int (*translate)(struct irq_domain___20 *, struct irq_fwspec___20 *, long unsigned int *, unsigned int *);
};

struct backlight_device___6;

struct fb_info___6;

struct backlight_ops___6 {
	unsigned int options;
	int (*update_status)(struct backlight_device___6 *);
	int (*get_brightness)(struct backlight_device___6 *);
	int (*check_fb)(struct backlight_device___6 *, struct fb_info___6 *);
};

struct backlight_device___6 {
	struct backlight_properties props;
	struct mutex update_lock;
	struct mutex ops_lock;
	const struct backlight_ops___6 *ops;
	struct notifier_block fb_notif;
	struct list_head entry;
	struct device___269 dev;
	bool fb_bl_on[32];
	int use_count;
};

struct fb_pixmap___6 {
	u8 *addr;
	u32 size;
	u32 offset;
	u32 buf_align;
	u32 scan_align;
	u32 access_align;
	u32 flags;
	u32 blit_x;
	u32 blit_y;
	void (*writeio)(struct fb_info___6 *, void *, void *, unsigned int);
	void (*readio)(struct fb_info___6 *, void *, void *, unsigned int);
};

struct fb_deferred_io___6;

struct fb_ops___6;

struct fb_tile_ops___6;

struct fb_info___6 {
	atomic_t count;
	int node;
	int flags;
	int fbcon_rotate_hint;
	struct mutex lock;
	struct mutex mm_lock;
	struct fb_var_screeninfo var;
	struct fb_fix_screeninfo fix;
	struct fb_monspecs monspecs;
	struct work_struct queue;
	struct fb_pixmap___6 pixmap;
	struct fb_pixmap___6 sprite;
	struct fb_cmap cmap;
	struct list_head modelist;
	struct fb_videomode *mode;
	struct backlight_device___6 *bl_dev;
	struct mutex bl_curve_mutex;
	u8 bl_curve[128];
	struct delayed_work deferred_work;
	struct fb_deferred_io___6 *fbdefio;
	struct fb_ops___6 *fbops;
	struct device___269 *device;
	struct device___269 *dev;
	int class_flag;
	struct fb_tile_ops___6 *tileops;
	union {
		char *screen_base;
		char *screen_buffer;
	};
	long unsigned int screen_size;
	void *pseudo_palette;
	u32 state;
	void *fbcon_par;
	void *par;
	struct apertures_struct *apertures;
	bool skip_vt_switch;
};

struct fb_event___3 {
	struct fb_info___6 *info;
	void *data;
};

struct fb_deferred_io___6 {
	long unsigned int delay;
	struct mutex lock;
	struct list_head pagelist;
	void (*first_io)(struct fb_info___6 *);
	void (*deferred_io)(struct fb_info___6 *, struct list_head *);
};

struct fb_ops___6 {
	struct module___245 *owner;
	int (*fb_open)(struct fb_info___6 *, int);
	int (*fb_release)(struct fb_info___6 *, int);
	ssize_t (*fb_read)(struct fb_info___6 *, char *, size_t, loff_t *);
	ssize_t (*fb_write)(struct fb_info___6 *, const char *, size_t, loff_t *);
	int (*fb_check_var)(struct fb_var_screeninfo *, struct fb_info___6 *);
	int (*fb_set_par)(struct fb_info___6 *);
	int (*fb_setcolreg)(unsigned int, unsigned int, unsigned int, unsigned int, unsigned int, struct fb_info___6 *);
	int (*fb_setcmap)(struct fb_cmap *, struct fb_info___6 *);
	int (*fb_blank)(int, struct fb_info___6 *);
	int (*fb_pan_display)(struct fb_var_screeninfo *, struct fb_info___6 *);
	void (*fb_fillrect)(struct fb_info___6 *, const struct fb_fillrect *);
	void (*fb_copyarea)(struct fb_info___6 *, const struct fb_copyarea *);
	void (*fb_imageblit)(struct fb_info___6 *, const struct fb_image *);
	int (*fb_cursor)(struct fb_info___6 *, struct fb_cursor *);
	int (*fb_sync)(struct fb_info___6 *);
	int (*fb_ioctl)(struct fb_info___6 *, unsigned int, long unsigned int);
	int (*fb_compat_ioctl)(struct fb_info___6 *, unsigned int, long unsigned int);
	int (*fb_mmap)(struct fb_info___6 *, struct vm_area_struct___305 *);
	void (*fb_get_caps)(struct fb_info___6 *, struct fb_blit_caps *, struct fb_var_screeninfo *);
	void (*fb_destroy)(struct fb_info___6 *);
	int (*fb_debug_enter)(struct fb_info___6 *);
	int (*fb_debug_leave)(struct fb_info___6 *);
};

struct fb_tile_ops___6 {
	void (*fb_settile)(struct fb_info___6 *, struct fb_tilemap *);
	void (*fb_tilecopy)(struct fb_info___6 *, struct fb_tilearea *);
	void (*fb_tilefill)(struct fb_info___6 *, struct fb_tilerect *);
	void (*fb_tileblit)(struct fb_info___6 *, struct fb_tileblit *);
	void (*fb_tilecursor)(struct fb_info___6 *, struct fb_tilecursor *);
	int (*fb_get_tilemax)(struct fb_info___6 *);
};

struct seq_operations___256 {
	void * (*start)(struct seq_file___257 *, loff_t *);
	void (*stop)(struct seq_file___257 *, void *);
	void * (*next)(struct seq_file___257 *, void *, loff_t *);
	int (*show)(struct seq_file___257 *, void *);
};

struct tty_operations___21 {
	struct tty_struct___21 * (*lookup)(struct tty_driver___21 *, struct file___304 *, int);
	int (*install)(struct tty_driver___21 *, struct tty_struct___21 *);
	void (*remove)(struct tty_driver___21 *, struct tty_struct___21 *);
	int (*open)(struct tty_struct___21 *, struct file___304 *);
	void (*close)(struct tty_struct___21 *, struct file___304 *);
	void (*shutdown)(struct tty_struct___21 *);
	void (*cleanup)(struct tty_struct___21 *);
	int (*write)(struct tty_struct___21 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___21 *, unsigned char);
	void (*flush_chars)(struct tty_struct___21 *);
	int (*write_room)(struct tty_struct___21 *);
	int (*chars_in_buffer)(struct tty_struct___21 *);
	int (*ioctl)(struct tty_struct___21 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___21 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___21 *, struct ktermios *);
	void (*throttle)(struct tty_struct___21 *);
	void (*unthrottle)(struct tty_struct___21 *);
	void (*stop)(struct tty_struct___21 *);
	void (*start)(struct tty_struct___21 *);
	void (*hangup)(struct tty_struct___21 *);
	int (*break_ctl)(struct tty_struct___21 *, int);
	void (*flush_buffer)(struct tty_struct___21 *);
	void (*set_ldisc)(struct tty_struct___21 *);
	void (*wait_until_sent)(struct tty_struct___21 *, int);
	void (*send_xchar)(struct tty_struct___21 *, char);
	int (*tiocmget)(struct tty_struct___21 *);
	int (*tiocmset)(struct tty_struct___21 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___21 *, struct winsize *);
	int (*set_termiox)(struct tty_struct___21 *, struct termiox *);
	int (*get_icount)(struct tty_struct___21 *, struct serial_icounter_struct *);
	void (*show_fdinfo)(struct tty_struct___21 *, struct seq_file___257 *);
	int (*poll_init)(struct tty_driver___21 *, int, char *);
	int (*poll_get_char)(struct tty_driver___21 *, int);
	void (*poll_put_char)(struct tty_driver___21 *, int, char);
	int (*proc_show)(struct seq_file___257 *, void *);
};

struct tty_ldisc_ops___21 {
	int magic;
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___21 *);
	void (*close)(struct tty_struct___21 *);
	void (*flush_buffer)(struct tty_struct___21 *);
	ssize_t (*read)(struct tty_struct___21 *, struct file___304 *, unsigned char *, size_t);
	ssize_t (*write)(struct tty_struct___21 *, struct file___304 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___21 *, struct file___304 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___21 *, struct file___304 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___21 *, struct ktermios *);
	__poll_t (*poll)(struct tty_struct___21 *, struct file___304 *, struct poll_table_struct___6 *);
	int (*hangup)(struct tty_struct___21 *);
	void (*receive_buf)(struct tty_struct___21 *, const unsigned char *, char *, int);
	void (*write_wakeup)(struct tty_struct___21 *);
	void (*dcd_change)(struct tty_struct___21 *, unsigned int);
	int (*receive_buf2)(struct tty_struct___21 *, const unsigned char *, char *, int);
	struct module___245 *owner;
	int refcount;
};

struct tty_ldisc___21 {
	struct tty_ldisc_ops___21 *ops;
	struct tty_struct___21 *tty;
};

struct tty_port_operations___21 {
	int (*carrier_raised)(struct tty_port___21 *);
	void (*dtr_rts)(struct tty_port___21 *, int);
	void (*shutdown)(struct tty_port___21 *);
	int (*activate)(struct tty_port___21 *, struct tty_struct___21 *);
	void (*destruct)(struct tty_port___21 *);
};

struct tty_port_client_operations___21 {
	int (*receive_buf)(struct tty_port___21 *, const unsigned char *, const unsigned char *, size_t);
	void (*write_wakeup)(struct tty_port___21 *);
};

struct vc___2 {
	struct vc_data___3 *d;
	struct work_struct SAK_work;
};

struct vt_spawn_console___2 {
	spinlock_t lock;
	struct pid___202 *pid;
	int sig;
};

struct display {
	const u_char *fontdata;
	int userfont;
	u_short scrollmode;
	u_short inverse;
	short int yscroll;
	int vrows;
	int cursor_shape;
	int con_rotate;
	u32 xres_virtual;
	u32 yres_virtual;
	u32 height;
	u32 width;
	u32 bits_per_pixel;
	u32 grayscale;
	u32 nonstd;
	u32 accel_flags;
	u32 rotate;
	struct fb_bitfield red;
	struct fb_bitfield green;
	struct fb_bitfield blue;
	struct fb_bitfield transp;
	const struct fb_videomode *mode;
};

struct fbcon_ops {
	void (*bmove)(struct vc_data___3 *, struct fb_info___6 *, int, int, int, int, int, int);
	void (*clear)(struct vc_data___3 *, struct fb_info___6 *, int, int, int, int);
	void (*putcs)(struct vc_data___3 *, struct fb_info___6 *, const short unsigned int *, int, int, int, int, int);
	void (*clear_margins)(struct vc_data___3 *, struct fb_info___6 *, int, int);
	void (*cursor)(struct vc_data___3 *, struct fb_info___6 *, int, int, int, int);
	int (*update_start)(struct fb_info___6 *);
	int (*rotate_font)(struct fb_info___6 *, struct vc_data___3 *);
	struct fb_var_screeninfo var;
	struct timer_list cursor_timer;
	struct fb_cursor cursor_state;
	struct display *p;
	struct fb_info___6 *info;
	int currcon;
	int cur_blink_jiffies;
	int cursor_flash;
	int cursor_reset;
	int blank_state;
	int graphics;
	int save_graphics;
	int flags;
	int rotate;
	int cur_rotate;
	char *cursor_data;
	u8 *fontbuffer;
	u8 *fontdata;
	u8 *cursor_src;
	u32 cursor_size;
	u32 fd_size;
};

enum {
	FBCON_LOGO_CANSHOW = 4294967295,
	FBCON_LOGO_DRAW = 4294967294,
	FBCON_LOGO_DONTSHOW = 4294967293,
};

struct module___246;

struct file___305;

struct kiocb___305;

struct vm_area_struct___306;

struct inode___305;

struct file_lock___305;

struct page___306;

struct file_operations___305 {
	struct module___246 *owner;
	loff_t (*llseek)(struct file___305 *, loff_t, int);
	ssize_t (*read)(struct file___305 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___305 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___305 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___305 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___305 *, bool);
	int (*iterate)(struct file___305 *, struct dir_context *);
	int (*iterate_shared)(struct file___305 *, struct dir_context *);
	__poll_t (*poll)(struct file___305 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___305 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___305 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___305 *, struct vm_area_struct___306 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___305 *, struct file___305 *);
	int (*flush)(struct file___305 *, fl_owner_t);
	int (*release)(struct inode___305 *, struct file___305 *);
	int (*fsync)(struct file___305 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___305 *, int);
	int (*lock)(struct file___305 *, int, struct file_lock___305 *);
	ssize_t (*sendpage)(struct file___305 *, struct page___306 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___305 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___305 *, int, struct file_lock___305 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___305 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___305 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___305 *, long int, struct file_lock___305 **, void **);
	long int (*fallocate)(struct file___305 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___305 *);
	ssize_t (*copy_file_range)(struct file___305 *, loff_t, struct file___305 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___305 *, loff_t, struct file___305 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___305 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___305 {
	u64 seqnum;
	struct vm_area_struct___306 *vmas[4];
};

struct page_frag___305 {
	struct page___306 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___305;

struct pid___203;

struct cred___283;

struct nsproxy___250;

struct signal_struct___229;

struct vm_struct___221;

struct task_struct___306 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___306 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___305 *mm;
	struct mm_struct___305 *active_mm;
	struct vmacache___305 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___306 *real_parent;
	struct task_struct___306 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___306 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___203 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___203 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___203 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___283 *ptracer_cred;
	const struct cred___283 *real_cred;
	const struct cred___283 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___250 *nsproxy;
	struct signal_struct___229 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___306 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___82 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___305 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___306 *oom_reaper_list;
	struct vm_struct___221 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___131 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rw_semaphore___306 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___306 *owner;
};

struct secondary_data___306 {
	void *stack;
	struct task_struct___306 *task;
	long int status;
};

struct blocking_notifier_head___305 {
	struct rw_semaphore___306 rwsem;
	struct notifier_block *head;
};

typedef struct page___306 *pgtable_t___305;

struct address_space___304;

struct dev_pagemap___294;

struct page___306 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___304 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___306 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___305 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___305 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___294 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___305;

struct lruvec___305 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___305 *pgdat;
};

struct zone___305 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___305 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___305 {
	struct zone___305 *zone;
	int zone_idx;
};

struct zonelist___305 {
	struct zoneref___305 _zonerefs[25];
};

struct pglist_data___305 {
	struct zone___305 node_zones[3];
	struct zonelist___305 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___306 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___306 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___305 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct kernfs_root___298;

struct kernfs_elem_dir___298 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___298 *root;
};

struct kernfs_node___299;

struct kernfs_syscall_ops___298;

struct kernfs_root___298 {
	struct kernfs_node___299 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___298 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___298 {
	struct kernfs_node___299 *target_kn;
};

struct kernfs_ops___298;

struct kernfs_elem_attr___298 {
	const struct kernfs_ops___298 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___299 *notify_next;
};

struct kernfs_node___299 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___299 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___298 dir;
		struct kernfs_elem_symlink___298 symlink;
		struct kernfs_elem_attr___298 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___298;

struct kernfs_ops___298 {
	int (*open)(struct kernfs_open_file___298 *);
	void (*release)(struct kernfs_open_file___298 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___298 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___298 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___298 *, struct vm_area_struct___306 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___298 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___298 {
	int (*remount_fs)(struct kernfs_root___298 *, int *, char *);
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___298 *);
	int (*mkdir)(struct kernfs_node___299 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___299 *);
	int (*rename)(struct kernfs_node___299 *, struct kernfs_node___299 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___299 *, struct kernfs_root___298 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_operations_struct___294;

struct kernfs_open_file___298 {
	struct kernfs_node___299 *kn;
	struct file___305 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___294 *vm_ops;
};

struct dentry___305;

struct path___305 {
	struct vfsmount *mnt;
	struct dentry___305 *dentry;
};

struct fown_struct___203 {
	rwlock_t lock;
	struct pid___203 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___305 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___305 f_path;
	struct inode___305 *f_inode;
	const struct file_operations___305 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___203 f_owner;
	const struct cred___283 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___304 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___294;

struct vm_operations_struct___294 {
	void (*open)(struct vm_area_struct___306 *);
	void (*close)(struct vm_area_struct___306 *);
	int (*split)(struct vm_area_struct___306 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___306 *);
	vm_fault_t (*fault)(struct vm_fault___294 *);
	vm_fault_t (*huge_fault)(struct vm_fault___294 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___294 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___306 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___294 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___294 *);
	int (*access)(struct vm_area_struct___306 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___306 *);
	int (*set_policy)(struct vm_area_struct___306 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___306 *, long unsigned int);
	struct page___306 * (*find_special_page)(struct vm_area_struct___306 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_area_struct___306 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___306 *vm_next;
	struct vm_area_struct___306 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___305 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___294 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___305 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___292;

struct bin_attribute___268;

struct attribute_group___269 {
	const char *name;
	umode_t (*is_visible)(struct kobject___292 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___292 *, struct bin_attribute___268 *, int);
	struct attribute **attrs;
	struct bin_attribute___268 **bin_attrs;
};

struct kset___291;

struct kobj_type___291;

struct kobject___292 {
	const char *name;
	struct list_head entry;
	struct kobject___292 *parent;
	struct kset___291 *kset;
	struct kobj_type___291 *ktype;
	struct kernfs_node___299 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___268 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___305 *, struct kobject___292 *, struct bin_attribute___268 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___305 *, struct kobject___292 *, struct bin_attribute___268 *, char *, loff_t, size_t);
	int (*mmap)(struct file___305 *, struct kobject___292 *, struct bin_attribute___268 *, struct vm_area_struct___306 *);
};

struct sysfs_ops___291 {
	ssize_t (*show)(struct kobject___292 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___292 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___291;

struct kset___291 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___292 kobj;
	const struct kset_uevent_ops___291 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___291 {
	void (*release)(struct kobject___292 *);
	const struct sysfs_ops___291 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___25 * (*child_ns_type)(struct kobject___292 *);
	const void * (*namespace)(struct kobject___292 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___291 {
	int (* const filter)(struct kset___291 *, struct kobject___292 *);
	const char * (* const name)(struct kset___291 *, struct kobject___292 *);
	int (* const uevent)(struct kset___291 *, struct kobject___292 *, struct kobj_uevent_env *);
};

struct kobj_attribute___284 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___292 *, struct kobj_attribute___284 *, char *);
	ssize_t (*store)(struct kobject___292 *, struct kobj_attribute___284 *, const char *, size_t);
};

struct device___270;

struct dev_pm_ops___270 {
	int (*prepare)(struct device___270 *);
	void (*complete)(struct device___270 *);
	int (*suspend)(struct device___270 *);
	int (*resume)(struct device___270 *);
	int (*freeze)(struct device___270 *);
	int (*thaw)(struct device___270 *);
	int (*poweroff)(struct device___270 *);
	int (*restore)(struct device___270 *);
	int (*suspend_late)(struct device___270 *);
	int (*resume_early)(struct device___270 *);
	int (*freeze_late)(struct device___270 *);
	int (*thaw_early)(struct device___270 *);
	int (*poweroff_late)(struct device___270 *);
	int (*restore_early)(struct device___270 *);
	int (*suspend_noirq)(struct device___270 *);
	int (*resume_noirq)(struct device___270 *);
	int (*freeze_noirq)(struct device___270 *);
	int (*thaw_noirq)(struct device___270 *);
	int (*poweroff_noirq)(struct device___270 *);
	int (*restore_noirq)(struct device___270 *);
	int (*runtime_suspend)(struct device___270 *);
	int (*runtime_resume)(struct device___270 *);
	int (*runtime_idle)(struct device___270 *);
};

struct dev_pm_info___270 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___270 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___270;

struct bus_type___270;

struct device_driver___270;

struct dev_pm_domain___270;

struct irq_domain___21;

struct dma_map_ops___88;

struct device_node___62;

struct fwnode_handle___204;

struct class___270;

struct device___270 {
	struct device___270 *parent;
	struct device_private *p;
	struct kobject___292 kobj;
	const char *init_name;
	const struct device_type___270 *type;
	struct mutex mutex;
	struct bus_type___270 *bus;
	struct device_driver___270 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___270 power;
	struct dev_pm_domain___270 *pm_domain;
	struct irq_domain___21 *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___88 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___62 *of_node;
	struct fwnode_handle___204 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___270 *class;
	const struct attribute_group___269 **groups;
	void (*release)(struct device___270 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___270 {
	struct dev_pm_ops___270 ops;
	void (*detach)(struct device___270 *, bool);
	int (*activate)(struct device___270 *);
	void (*sync)(struct device___270 *);
	void (*dismiss)(struct device___270 *);
};

struct pid_namespace___203;

struct upid___203 {
	int nr;
	struct pid_namespace___203 *ns;
};

struct pid_namespace___203 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___306 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___203 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___305 *proc_self;
	struct dentry___305 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___3 *user_ns;
	struct ucounts___2 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___9 ns;
};

struct pid___203 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___203 numbers[1];
};

struct key___283;

struct user_struct___283 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___283 *uid_keyring;
	struct key___283 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___305;

struct mm_struct___305 {
	struct {
		struct vm_area_struct___306 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___305 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___306 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___305 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___306 *owner;
		struct user_namespace___3 *user_ns;
		struct file___305 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___305 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___283 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___283 *session_keyring;
	struct key___283 *process_keyring;
	struct key___283 *thread_keyring;
	struct key___283 *request_key_auth;
	void *security;
	struct user_struct___283 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct nsproxy___250 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___203 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct signal_struct___229 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___306 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___306 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___203 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___203 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___305 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___203 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_struct___221 {
	struct vm_struct___221 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___306 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___241 {
	struct task_struct___306 task;
	long unsigned int stack[8192];
};

struct bus_type___270 {
	const char *name;
	const char *dev_name;
	struct device___270 *dev_root;
	const struct attribute_group___269 **bus_groups;
	const struct attribute_group___269 **dev_groups;
	const struct attribute_group___269 **drv_groups;
	int (*match)(struct device___270 *, struct device_driver___270 *);
	int (*uevent)(struct device___270 *, struct kobj_uevent_env *);
	int (*probe)(struct device___270 *);
	int (*remove)(struct device___270 *);
	void (*shutdown)(struct device___270 *);
	int (*online)(struct device___270 *);
	int (*offline)(struct device___270 *);
	int (*suspend)(struct device___270 *, pm_message_t);
	int (*resume)(struct device___270 *);
	int (*num_vf)(struct device___270 *);
	int (*dma_configure)(struct device___270 *);
	const struct dev_pm_ops___270 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___270 {
	const char *name;
	struct bus_type___270 *bus;
	struct module___246 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___270 *);
	int (*remove)(struct device___270 *);
	void (*shutdown)(struct device___270 *);
	int (*suspend)(struct device___270 *, pm_message_t);
	int (*resume)(struct device___270 *);
	const struct attribute_group___269 **groups;
	const struct dev_pm_ops___270 *pm;
	void (*coredump)(struct device___270 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___270 {
	const char *name;
	const struct attribute_group___269 **groups;
	int (*uevent)(struct device___270 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___270 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___270 *);
	const struct dev_pm_ops___270 *pm;
};

struct module_kobject___243 {
	struct kobject___292 kobj;
	struct module___246 *mod;
	struct kobject___292 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___243 {
	struct module___246 *mod;
	struct latch_tree_node node;
};

struct module_layout___243 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___243 mtn;
};

struct module_attribute___243;

struct kernel_param___243;

struct module___246 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___243 mkobj;
	struct module_attribute___243 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___292 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___243 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___243 core_layout;
	struct module_layout___243 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct class___270 {
	const char *name;
	struct module___246 *owner;
	const struct attribute_group___269 **class_groups;
	const struct attribute_group___269 **dev_groups;
	struct kobject___292 *dev_kobj;
	int (*dev_uevent)(struct device___270 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___270 *, umode_t *);
	void (*class_release)(struct class___270 *);
	void (*dev_release)(struct device___270 *);
	int (*shutdown_pre)(struct device___270 *);
	const struct kobj_ns_type_operations___25 *ns_type;
	const void * (*namespace)(struct device___270 *);
	const struct dev_pm_ops___270 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct irq_domain_ops___21;

struct irq_domain___21 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___21 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___204 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___2 *gc;
	struct irq_domain___21 *parent;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_direct_max_irq;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_tree_mutex;
	unsigned int linear_revmap[0];
};

struct dma_map_ops___88 {
	void * (*alloc)(struct device___270 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___270 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___270 *, struct vm_area_struct___306 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___270 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___270 *, struct page___306 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___270 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___270 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___270 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___270 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___270 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___270 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___270 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___270 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___270 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___270 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___270 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___270 *, u64);
	u64 (*get_required_mask)(struct device___270 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___204;

struct fwnode_handle___204 {
	struct fwnode_handle___204 *secondary;
	const struct fwnode_operations___204 *ops;
};

struct property___59;

struct device_node___62 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___204 fwnode;
	struct property___59 *properties;
	struct property___59 *deadprops;
	struct device_node___62 *parent;
	struct device_node___62 *child;
	struct device_node___62 *sibling;
	struct kobject___292 kobj;
	long unsigned int _flags;
	void *data;
};

struct amba_device___2 {
	struct device___270 dev;
	struct resource res;
	struct clk *pclk;
	unsigned int periphid;
	unsigned int irq[9];
	char *driver_override;
};

struct amba_driver___2 {
	struct device_driver___270 drv;
	int (*probe)(struct amba_device___2 *, const struct amba_id *);
	int (*remove)(struct amba_device___2 *);
	void (*shutdown)(struct amba_device___2 *);
	const struct amba_id *id_table;
};

typedef int (*key_restrict_link_func_t___284)(struct key___283 *, const struct key_type *, const union key_payload *, struct key___283 *);

struct key_restriction___283;

struct key___283 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___306 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___283 *restrict_link;
};

struct key_restriction___283 {
	key_restrict_link_func_t___284 check;
	struct key___283 *key;
	struct key_type *keytype;
};

struct address_space_operations___304;

struct address_space___304 {
	struct inode___305 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___306 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___304 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___294)(struct vm_area_struct___306 *, long unsigned int, const struct page___306 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___294)(struct page___306 *, void *);

struct dev_pagemap___294 {
	dev_page_fault_t___294 page_fault;
	dev_page_free_t___294 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___270 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___305 {
	struct task_struct___306 *task;
	struct core_thread___305 *next;
};

struct core_state___305 {
	atomic_t nr_threads;
	struct core_thread___305 dumper;
	struct completion startup;
};

struct vm_fault___294 {
	struct vm_area_struct___306 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___306 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___306 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___305 prealloc_pte;
};

struct dentry_operations___304;

struct super_block___304;

struct dentry___305 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___305 *d_parent;
	struct qstr d_name;
	struct inode___305 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___304 *d_op;
	struct super_block___304 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___304;

struct block_device___304;

struct inode___305 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___304 *i_op;
	struct super_block___304 *i_sb;
	struct address_space___304 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___306 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___305 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___304 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___304 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___304 {
	int (*d_revalidate)(struct dentry___305 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___305 *, unsigned int);
	int (*d_hash)(const struct dentry___305 *, struct qstr *);
	int (*d_compare)(const struct dentry___305 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___305 *);
	int (*d_init)(struct dentry___305 *);
	void (*d_release)(struct dentry___305 *);
	void (*d_prune)(struct dentry___305 *);
	void (*d_iput)(struct dentry___305 *, struct inode___305 *);
	char * (*d_dname)(struct dentry___305 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___305 *);
	int (*d_manage)(const struct path___305 *, bool);
	struct dentry___305 * (*d_real)(struct dentry___305 *, const struct inode___305 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___304;

struct mem_dqinfo___304 {
	struct quota_format_type___304 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___304;

struct quota_info___304 {
	unsigned int flags;
	struct rw_semaphore___306 dqio_sem;
	struct inode___305 *files[3];
	struct mem_dqinfo___304 info[3];
	const struct quota_format_ops___304 *ops[3];
};

struct rcuwait___304 {
	struct task_struct___306 *task;
};

struct percpu_rw_semaphore___304 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___306 rw_sem;
	struct rcuwait___304 writer;
	int readers_block;
};

struct sb_writers___304 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___304 rw_sem[3];
};

struct file_system_type___304;

struct super_operations___304;

struct dquot_operations___304;

struct quotactl_ops___304;

struct super_block___304 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___304 *s_type;
	const struct super_operations___304 *s_op;
	const struct dquot_operations___304 *dq_op;
	const struct quotactl_ops___304 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___305 *s_root;
	struct rw_semaphore___306 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___304 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___304 s_dquot;
	struct sb_writers___304 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___304 *s_d_op;
	int cleancache_poolid;
	struct shrinker___117 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___305 {
	struct file___305 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___305 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___304 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___305 *ia_file;
};

struct dquot___304 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___304 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___304 {
	int qf_fmt_id;
	const struct quota_format_ops___304 *qf_ops;
	struct module___246 *qf_owner;
	struct quota_format_type___304 *qf_next;
};

struct quota_format_ops___304 {
	int (*check_quota_file)(struct super_block___304 *, int);
	int (*read_file_info)(struct super_block___304 *, int);
	int (*write_file_info)(struct super_block___304 *, int);
	int (*free_file_info)(struct super_block___304 *, int);
	int (*read_dqblk)(struct dquot___304 *);
	int (*commit_dqblk)(struct dquot___304 *);
	int (*release_dqblk)(struct dquot___304 *);
	int (*get_next_id)(struct super_block___304 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___304 {
	int (*write_dquot)(struct dquot___304 *);
	struct dquot___304 * (*alloc_dquot)(struct super_block___304 *, int);
	void (*destroy_dquot)(struct dquot___304 *);
	int (*acquire_dquot)(struct dquot___304 *);
	int (*release_dquot)(struct dquot___304 *);
	int (*mark_dirty)(struct dquot___304 *);
	int (*write_info)(struct super_block___304 *, int);
	qsize_t * (*get_reserved_space)(struct inode___305 *);
	int (*get_projid)(struct inode___305 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___305 *, qsize_t *);
	int (*get_next_id)(struct super_block___304 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___304 {
	int (*quota_on)(struct super_block___304 *, int, int, const struct path___305 *);
	int (*quota_off)(struct super_block___304 *, int);
	int (*quota_enable)(struct super_block___304 *, unsigned int);
	int (*quota_disable)(struct super_block___304 *, unsigned int);
	int (*quota_sync)(struct super_block___304 *, int);
	int (*set_info)(struct super_block___304 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___304 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___304 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___304 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___304 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___304 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___304 {
	int (*writepage)(struct page___306 *, struct writeback_control___3 *);
	int (*readpage)(struct file___305 *, struct page___306 *);
	int (*writepages)(struct address_space___304 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___306 *);
	int (*readpages)(struct file___305 *, struct address_space___304 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___305 *, struct address_space___304 *, loff_t, unsigned int, unsigned int, struct page___306 **, void **);
	int (*write_end)(struct file___305 *, struct address_space___304 *, loff_t, unsigned int, unsigned int, struct page___306 *, void *);
	sector_t (*bmap)(struct address_space___304 *, sector_t);
	void (*invalidatepage)(struct page___306 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___306 *, gfp_t);
	void (*freepage)(struct page___306 *);
	ssize_t (*direct_IO)(struct kiocb___305 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___304 *, struct page___306 *, struct page___306 *, enum migrate_mode);
	bool (*isolate_page)(struct page___306 *, isolate_mode_t);
	void (*putback_page)(struct page___306 *);
	int (*launder_page)(struct page___306 *);
	int (*is_partially_uptodate)(struct page___306 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___306 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___304 *, struct page___306 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___305 *, sector_t *);
	void (*swap_deactivate)(struct file___305 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___304 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___305 *bd_inode;
	struct super_block___304 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___304 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___304 {
	struct dentry___305 * (*lookup)(struct inode___305 *, struct dentry___305 *, unsigned int);
	const char * (*get_link)(struct dentry___305 *, struct inode___305 *, struct delayed_call *);
	int (*permission)(struct inode___305 *, int);
	struct posix_acl * (*get_acl)(struct inode___305 *, int);
	int (*readlink)(struct dentry___305 *, char *, int);
	int (*create)(struct inode___305 *, struct dentry___305 *, umode_t, bool);
	int (*link)(struct dentry___305 *, struct inode___305 *, struct dentry___305 *);
	int (*unlink)(struct inode___305 *, struct dentry___305 *);
	int (*symlink)(struct inode___305 *, struct dentry___305 *, const char *);
	int (*mkdir)(struct inode___305 *, struct dentry___305 *, umode_t);
	int (*rmdir)(struct inode___305 *, struct dentry___305 *);
	int (*mknod)(struct inode___305 *, struct dentry___305 *, umode_t, dev_t);
	int (*rename)(struct inode___305 *, struct dentry___305 *, struct inode___305 *, struct dentry___305 *, unsigned int);
	int (*setattr)(struct dentry___305 *, struct iattr___304 *);
	int (*getattr)(const struct path___305 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___305 *, char *, size_t);
	int (*fiemap)(struct inode___305 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___305 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___305 *, struct dentry___305 *, struct file___305 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___305 *, struct dentry___305 *, umode_t);
	int (*set_acl)(struct inode___305 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___304 {
	void (*fl_copy_lock)(struct file_lock___305 *, struct file_lock___305 *);
	void (*fl_release_private)(struct file_lock___305 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___304;

struct lock_manager_operations___304;

struct file_lock___305 {
	struct file_lock___305 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___305 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___304 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___304 *fl_ops;
	const struct lock_manager_operations___304 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___304 {
	int (*lm_compare_owner)(struct file_lock___305 *, struct file_lock___305 *);
	long unsigned int (*lm_owner_key)(struct file_lock___305 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___305 *);
	int (*lm_grant)(struct file_lock___305 *, int);
	bool (*lm_break)(struct file_lock___305 *);
	int (*lm_change)(struct file_lock___305 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___305 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___304 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___304 *fa_next;
	struct file___305 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___304 {
	const char *name;
	int fs_flags;
	struct dentry___305 * (*mount)(struct file_system_type___304 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___304 *);
	struct module___246 *owner;
	struct file_system_type___304 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___304 {
	struct inode___305 * (*alloc_inode)(struct super_block___304 *);
	void (*destroy_inode)(struct inode___305 *);
	void (*dirty_inode)(struct inode___305 *, int);
	int (*write_inode)(struct inode___305 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___305 *);
	void (*evict_inode)(struct inode___305 *);
	void (*put_super)(struct super_block___304 *);
	int (*sync_fs)(struct super_block___304 *, int);
	int (*freeze_super)(struct super_block___304 *);
	int (*freeze_fs)(struct super_block___304 *);
	int (*thaw_super)(struct super_block___304 *);
	int (*unfreeze_fs)(struct super_block___304 *);
	int (*statfs)(struct dentry___305 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___304 *, int *, char *);
	void (*umount_begin)(struct super_block___304 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___305 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___305 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___305 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___305 *);
	ssize_t (*quota_read)(struct super_block___304 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___304 *, int, const char *, size_t, loff_t);
	struct dquot___304 ** (*get_dquots)(struct inode___305 *);
	int (*bdev_try_to_free_page)(struct super_block___304 *, struct page___306 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___304 *, struct shrink_control___117 *);
	long int (*free_cached_objects)(struct super_block___304 *, struct shrink_control___117 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___294(struct page___306 *);

struct fwnode_reference_args___204;

struct fwnode_endpoint___204;

struct fwnode_operations___204 {
	struct fwnode_handle___204 * (*get)(struct fwnode_handle___204 *);
	void (*put)(struct fwnode_handle___204 *);
	bool (*device_is_available)(const struct fwnode_handle___204 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___204 *, const struct device___270 *);
	bool (*property_present)(const struct fwnode_handle___204 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___204 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___204 *, const char *, const char **, size_t);
	struct fwnode_handle___204 * (*get_parent)(const struct fwnode_handle___204 *);
	struct fwnode_handle___204 * (*get_next_child_node)(const struct fwnode_handle___204 *, struct fwnode_handle___204 *);
	struct fwnode_handle___204 * (*get_named_child_node)(const struct fwnode_handle___204 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___204 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___204 *);
	struct fwnode_handle___204 * (*graph_get_next_endpoint)(const struct fwnode_handle___204 *, struct fwnode_handle___204 *);
	struct fwnode_handle___204 * (*graph_get_remote_endpoint)(const struct fwnode_handle___204 *);
	struct fwnode_handle___204 * (*graph_get_port_parent)(struct fwnode_handle___204 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___204 *, struct fwnode_endpoint___204 *);
};

struct fwnode_endpoint___204 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___204 *local_fwnode;
};

struct fwnode_reference_args___204 {
	struct fwnode_handle___204 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct property___59 {
	char *name;
	int length;
	void *value;
	struct property___59 *next;
	long unsigned int _flags;
	struct bin_attribute___268 attr;
};

struct irq_fwspec___21 {
	struct fwnode_handle___204 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___21 {
	int (*match)(struct irq_domain___21 *, struct device_node___62 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___21 *, struct irq_fwspec___21 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___21 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___21 *, unsigned int);
	int (*xlate)(struct irq_domain___21 *, struct device_node___62 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___21 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___21 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___21 *, struct irq_data___5 *, bool);
	void (*deactivate)(struct irq_domain___21 *, struct irq_data___5 *);
	int (*translate)(struct irq_domain___21 *, struct irq_fwspec___21 *, long unsigned int *, unsigned int *);
};

struct backlight_device___7;

struct fb_info___7;

struct backlight_ops___7 {
	unsigned int options;
	int (*update_status)(struct backlight_device___7 *);
	int (*get_brightness)(struct backlight_device___7 *);
	int (*check_fb)(struct backlight_device___7 *, struct fb_info___7 *);
};

struct backlight_device___7 {
	struct backlight_properties props;
	struct mutex update_lock;
	struct mutex ops_lock;
	const struct backlight_ops___7 *ops;
	struct notifier_block fb_notif;
	struct list_head entry;
	struct device___270 dev;
	bool fb_bl_on[32];
	int use_count;
};

struct fb_pixmap___7 {
	u8 *addr;
	u32 size;
	u32 offset;
	u32 buf_align;
	u32 scan_align;
	u32 access_align;
	u32 flags;
	u32 blit_x;
	u32 blit_y;
	void (*writeio)(struct fb_info___7 *, void *, void *, unsigned int);
	void (*readio)(struct fb_info___7 *, void *, void *, unsigned int);
};

struct fb_deferred_io___7;

struct fb_ops___7;

struct fb_tile_ops___7;

struct fb_info___7 {
	atomic_t count;
	int node;
	int flags;
	int fbcon_rotate_hint;
	struct mutex lock;
	struct mutex mm_lock;
	struct fb_var_screeninfo var;
	struct fb_fix_screeninfo fix;
	struct fb_monspecs monspecs;
	struct work_struct queue;
	struct fb_pixmap___7 pixmap;
	struct fb_pixmap___7 sprite;
	struct fb_cmap cmap;
	struct list_head modelist;
	struct fb_videomode *mode;
	struct backlight_device___7 *bl_dev;
	struct mutex bl_curve_mutex;
	u8 bl_curve[128];
	struct delayed_work deferred_work;
	struct fb_deferred_io___7 *fbdefio;
	struct fb_ops___7 *fbops;
	struct device___270 *device;
	struct device___270 *dev;
	int class_flag;
	struct fb_tile_ops___7 *tileops;
	union {
		char *screen_base;
		char *screen_buffer;
	};
	long unsigned int screen_size;
	void *pseudo_palette;
	u32 state;
	void *fbcon_par;
	void *par;
	struct apertures_struct *apertures;
	bool skip_vt_switch;
};

struct fb_deferred_io___7 {
	long unsigned int delay;
	struct mutex lock;
	struct list_head pagelist;
	void (*first_io)(struct fb_info___7 *);
	void (*deferred_io)(struct fb_info___7 *, struct list_head *);
};

struct fb_ops___7 {
	struct module___246 *owner;
	int (*fb_open)(struct fb_info___7 *, int);
	int (*fb_release)(struct fb_info___7 *, int);
	ssize_t (*fb_read)(struct fb_info___7 *, char *, size_t, loff_t *);
	ssize_t (*fb_write)(struct fb_info___7 *, const char *, size_t, loff_t *);
	int (*fb_check_var)(struct fb_var_screeninfo *, struct fb_info___7 *);
	int (*fb_set_par)(struct fb_info___7 *);
	int (*fb_setcolreg)(unsigned int, unsigned int, unsigned int, unsigned int, unsigned int, struct fb_info___7 *);
	int (*fb_setcmap)(struct fb_cmap *, struct fb_info___7 *);
	int (*fb_blank)(int, struct fb_info___7 *);
	int (*fb_pan_display)(struct fb_var_screeninfo *, struct fb_info___7 *);
	void (*fb_fillrect)(struct fb_info___7 *, const struct fb_fillrect *);
	void (*fb_copyarea)(struct fb_info___7 *, const struct fb_copyarea *);
	void (*fb_imageblit)(struct fb_info___7 *, const struct fb_image *);
	int (*fb_cursor)(struct fb_info___7 *, struct fb_cursor *);
	int (*fb_sync)(struct fb_info___7 *);
	int (*fb_ioctl)(struct fb_info___7 *, unsigned int, long unsigned int);
	int (*fb_compat_ioctl)(struct fb_info___7 *, unsigned int, long unsigned int);
	int (*fb_mmap)(struct fb_info___7 *, struct vm_area_struct___306 *);
	void (*fb_get_caps)(struct fb_info___7 *, struct fb_blit_caps *, struct fb_var_screeninfo *);
	void (*fb_destroy)(struct fb_info___7 *);
	int (*fb_debug_enter)(struct fb_info___7 *);
	int (*fb_debug_leave)(struct fb_info___7 *);
};

struct fb_tile_ops___7 {
	void (*fb_settile)(struct fb_info___7 *, struct fb_tilemap *);
	void (*fb_tilecopy)(struct fb_info___7 *, struct fb_tilearea *);
	void (*fb_tilefill)(struct fb_info___7 *, struct fb_tilerect *);
	void (*fb_tileblit)(struct fb_info___7 *, struct fb_tileblit *);
	void (*fb_tilecursor)(struct fb_info___7 *, struct fb_tilecursor *);
	int (*fb_get_tilemax)(struct fb_info___7 *);
};

enum {
	CLCD_CAP_RGB444 = 1,
	CLCD_CAP_RGB5551 = 2,
	CLCD_CAP_RGB565 = 4,
	CLCD_CAP_RGB888 = 8,
	CLCD_CAP_BGR444 = 16,
	CLCD_CAP_BGR5551 = 32,
	CLCD_CAP_BGR565 = 64,
	CLCD_CAP_BGR888 = 128,
	CLCD_CAP_444 = 17,
	CLCD_CAP_5551 = 34,
	CLCD_CAP_565 = 68,
	CLCD_CAP_888 = 136,
	CLCD_CAP_RGB = 15,
	CLCD_CAP_BGR = 240,
	CLCD_CAP_ALL = 255,
};

struct clcd_panel {
	struct fb_videomode mode;
	short int width;
	short int height;
	u32 tim2;
	u32 tim3;
	u32 cntl;
	u32 caps;
	unsigned int bpp: 8;
	unsigned int fixedtimings: 1;
	unsigned int grayscale: 1;
	unsigned int connector;
	struct backlight_device___7 *backlight;
	bool bgr_connection;
};

struct clcd_regs {
	u32 tim0;
	u32 tim1;
	u32 tim2;
	u32 tim3;
	u32 cntl;
	long unsigned int pixclock;
};

struct clcd_fb;

struct clcd_board {
	const char *name;
	u32 caps;
	int (*check)(struct clcd_fb *, struct fb_var_screeninfo *);
	void (*decode)(struct clcd_fb *, struct clcd_regs *);
	void (*disable)(struct clcd_fb *);
	void (*enable)(struct clcd_fb *);
	int (*setup)(struct clcd_fb *);
	int (*mmap)(struct clcd_fb *, struct vm_area_struct___306 *);
	void (*remove)(struct clcd_fb *);
};

struct clcd_vendor_data;

struct clcd_fb {
	struct fb_info___7 fb;
	struct amba_device___2 *dev;
	struct clk *clk;
	struct clcd_vendor_data *vendor;
	struct clcd_panel *panel;
	struct clcd_board *board;
	void *board_data;
	void *regs;
	u16 off_ienb;
	u16 off_cntl;
	u32 clcd_cntl;
	u32 cmap[16];
	bool clk_enabled;
};

struct clcd_vendor_data {
	bool clock_timregs;
	bool packed_24_bit_pixels;
	bool st_bitmux_control;
	int (*init_board)(struct amba_device___2 *, struct clcd_board *);
	int (*init_panel)(struct clcd_fb *, struct device_node___62 *);
};

struct kernel_param_ops___243 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___243 *);
	int (*get)(char *, const struct kernel_param___243 *);
	void (*free)(void *);
};

struct kparam_array___243;

struct kernel_param___243 {
	const char *name;
	struct module___246 *mod;
	const struct kernel_param_ops___243 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___243 *arr;
	};
};

struct kparam_array___243 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___243 *ops;
	void *elem;
};

struct module_attribute___243 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___243 *, struct module_kobject___243 *, char *);
	ssize_t (*store)(struct module_attribute___243 *, struct module_kobject___243 *, const char *, size_t);
	void (*setup)(struct module___246 *, const char *);
	int (*test)(struct module___246 *);
	void (*free)(struct module___246 *);
};

struct timing_entry {
	u32 min;
	u32 typ;
	u32 max;
};

struct display_timing {
	struct timing_entry pixelclock;
	struct timing_entry hactive;
	struct timing_entry hfront_porch;
	struct timing_entry hback_porch;
	struct timing_entry hsync_len;
	struct timing_entry vactive;
	struct timing_entry vfront_porch;
	struct timing_entry vback_porch;
	struct timing_entry vsync_len;
	enum display_flags flags;
};

struct file___306;

struct kiocb___306;

struct poll_table_struct___183;

struct vm_area_struct___307;

struct inode___306;

struct file_lock___306;

struct page___307;

struct seq_file___258;

struct file_operations___306 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___306 *, loff_t, int);
	ssize_t (*read)(struct file___306 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___306 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___306 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___306 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___306 *, bool);
	int (*iterate)(struct file___306 *, struct dir_context *);
	int (*iterate_shared)(struct file___306 *, struct dir_context *);
	__poll_t (*poll)(struct file___306 *, struct poll_table_struct___183 *);
	long int (*unlocked_ioctl)(struct file___306 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___306 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___306 *, struct vm_area_struct___307 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___306 *, struct file___306 *);
	int (*flush)(struct file___306 *, fl_owner_t);
	int (*release)(struct inode___306 *, struct file___306 *);
	int (*fsync)(struct file___306 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___306 *, int);
	int (*lock)(struct file___306 *, int, struct file_lock___306 *);
	ssize_t (*sendpage)(struct file___306 *, struct page___307 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___306 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___306 *, int, struct file_lock___306 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___306 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___306 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___306 *, long int, struct file_lock___306 **, void **);
	long int (*fallocate)(struct file___306 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___258 *, struct file___306 *);
	ssize_t (*copy_file_range)(struct file___306 *, loff_t, struct file___306 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___306 *, loff_t, struct file___306 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___306 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___306 {
	u64 seqnum;
	struct vm_area_struct___307 *vmas[4];
};

struct page_frag___306 {
	struct page___307 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___306;

struct pid___204;

struct cred___284;

struct nsproxy___251;

struct signal_struct___230;

struct vm_struct___222;

struct task_struct___307 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___307 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___306 *mm;
	struct mm_struct___306 *active_mm;
	struct vmacache___306 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___307 *real_parent;
	struct task_struct___307 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___307 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___204 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___204 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___204 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___284 *ptracer_cred;
	const struct cred___284 *real_cred;
	const struct cred___284 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___251 *nsproxy;
	struct signal_struct___230 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___307 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___82 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___306 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___307 *oom_reaper_list;
	struct vm_struct___222 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___131 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___305;

struct super_block___305;

struct dentry___306 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___306 *d_parent;
	struct qstr d_name;
	struct inode___306 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___305 *d_op;
	struct super_block___305 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct rw_semaphore___307 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___307 *owner;
};

struct address_space_operations___305;

struct address_space___305 {
	struct inode___306 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___307 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___305 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___305;

struct block_device___305;

struct cdev___56;

struct inode___306 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___305 *i_op;
	struct super_block___305 *i_sb;
	struct address_space___305 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___307 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___306 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___305 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___305 *i_bdev;
		struct cdev___56 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___306;

struct dentry_operations___305 {
	int (*d_revalidate)(struct dentry___306 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___306 *, unsigned int);
	int (*d_hash)(const struct dentry___306 *, struct qstr *);
	int (*d_compare)(const struct dentry___306 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___306 *);
	int (*d_init)(struct dentry___306 *);
	void (*d_release)(struct dentry___306 *);
	void (*d_prune)(struct dentry___306 *);
	void (*d_iput)(struct dentry___306 *, struct inode___306 *);
	char * (*d_dname)(struct dentry___306 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___306 *);
	int (*d_manage)(const struct path___306 *, bool);
	struct dentry___306 * (*d_real)(struct dentry___306 *, const struct inode___306 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___305;

struct mem_dqinfo___305 {
	struct quota_format_type___305 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___305;

struct quota_info___305 {
	unsigned int flags;
	struct rw_semaphore___307 dqio_sem;
	struct inode___306 *files[3];
	struct mem_dqinfo___305 info[3];
	const struct quota_format_ops___305 *ops[3];
};

struct rcuwait___305 {
	struct task_struct___307 *task;
};

struct percpu_rw_semaphore___305 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___307 rw_sem;
	struct rcuwait___305 writer;
	int readers_block;
};

struct sb_writers___305 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___305 rw_sem[3];
};

struct file_system_type___305;

struct super_operations___305;

struct dquot_operations___305;

struct quotactl_ops___305;

struct super_block___305 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___305 *s_type;
	const struct super_operations___305 *s_op;
	const struct dquot_operations___305 *dq_op;
	const struct quotactl_ops___305 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___306 *s_root;
	struct rw_semaphore___307 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___305 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___305 s_dquot;
	struct sb_writers___305 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___305 *s_d_op;
	int cleancache_poolid;
	struct shrinker___117 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct path___306 {
	struct vfsmount *mnt;
	struct dentry___306 *dentry;
};

typedef struct page___307 *pgtable_t___306;

struct dev_pagemap___295;

struct page___307 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___305 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___307 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___306 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___306 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___295 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___306;

struct lruvec___306 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___306 *pgdat;
};

struct zone___306 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___306 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___306 {
	struct zone___306 *zone;
	int zone_idx;
};

struct zonelist___306 {
	struct zoneref___306 _zonerefs[25];
};

struct pglist_data___306 {
	struct zone___306 node_zones[3];
	struct zonelist___306 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___307 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___307 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___306 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___307 {
	void *stack;
	struct task_struct___307 *task;
	long int status;
};

struct blocking_notifier_head___306 {
	struct rw_semaphore___307 rwsem;
	struct notifier_block *head;
};

struct pid_namespace___204;

struct upid___204 {
	int nr;
	struct pid_namespace___204 *ns;
};

struct pid_namespace___204 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___307 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___204 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___306 *proc_self;
	struct dentry___306 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___3 *user_ns;
	struct ucounts___2 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___9 ns;
};

struct pid___204 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___204 numbers[1];
};

struct vm_operations_struct___295;

struct vm_area_struct___307 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___307 *vm_next;
	struct vm_area_struct___307 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___306 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___295 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___306 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___306;

struct mm_struct___306 {
	struct {
		struct vm_area_struct___307 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___306 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___307 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___306 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___307 *owner;
		struct user_namespace___3 *user_ns;
		struct file___306 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___306 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___295)(struct vm_area_struct___307 *, long unsigned int, const struct page___307 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___295)(struct page___307 *, void *);

struct device___271;

struct dev_pagemap___295 {
	dev_page_fault_t___295 page_fault;
	dev_page_free_t___295 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___271 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct fown_struct___204 {
	rwlock_t lock;
	struct pid___204 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___306 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___306 f_path;
	struct inode___306 *f_inode;
	const struct file_operations___306 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___204 f_owner;
	const struct cred___284 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___305 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___295;

struct vm_operations_struct___295 {
	void (*open)(struct vm_area_struct___307 *);
	void (*close)(struct vm_area_struct___307 *);
	int (*split)(struct vm_area_struct___307 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___307 *);
	vm_fault_t (*fault)(struct vm_fault___295 *);
	vm_fault_t (*huge_fault)(struct vm_fault___295 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___295 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___307 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___295 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___295 *);
	int (*access)(struct vm_area_struct___307 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___307 *);
	int (*set_policy)(struct vm_area_struct___307 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___307 *, long unsigned int);
	struct page___307 * (*find_special_page)(struct vm_area_struct___307 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___306 {
	struct task_struct___307 *task;
	struct core_thread___306 *next;
};

struct core_state___306 {
	atomic_t nr_threads;
	struct core_thread___306 dumper;
	struct completion startup;
};

struct vm_fault___295 {
	struct vm_area_struct___307 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___307 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___307 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___306 prealloc_pte;
};

struct key___284;

struct user_struct___284 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___284 *uid_keyring;
	struct key___284 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___284 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___284 *session_keyring;
	struct key___284 *process_keyring;
	struct key___284 *thread_keyring;
	struct key___284 *request_key_auth;
	void *security;
	struct user_struct___284 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct nsproxy___251 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___204 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct signal_struct___230 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___307 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___307 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___204 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___204 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___306 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___204 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_struct___222 {
	struct vm_struct___222 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___307 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___242 {
	struct task_struct___307 task;
	long unsigned int stack[8192];
};

struct kiocb___306 {
	struct file___306 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___306 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___305 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___306 *ia_file;
};

struct dquot___305 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___305 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___305 {
	int qf_fmt_id;
	const struct quota_format_ops___305 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___305 *qf_next;
};

struct quota_format_ops___305 {
	int (*check_quota_file)(struct super_block___305 *, int);
	int (*read_file_info)(struct super_block___305 *, int);
	int (*write_file_info)(struct super_block___305 *, int);
	int (*free_file_info)(struct super_block___305 *, int);
	int (*read_dqblk)(struct dquot___305 *);
	int (*commit_dqblk)(struct dquot___305 *);
	int (*release_dqblk)(struct dquot___305 *);
	int (*get_next_id)(struct super_block___305 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___305 {
	int (*write_dquot)(struct dquot___305 *);
	struct dquot___305 * (*alloc_dquot)(struct super_block___305 *, int);
	void (*destroy_dquot)(struct dquot___305 *);
	int (*acquire_dquot)(struct dquot___305 *);
	int (*release_dquot)(struct dquot___305 *);
	int (*mark_dirty)(struct dquot___305 *);
	int (*write_info)(struct super_block___305 *, int);
	qsize_t * (*get_reserved_space)(struct inode___306 *);
	int (*get_projid)(struct inode___306 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___306 *, qsize_t *);
	int (*get_next_id)(struct super_block___305 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___305 {
	int (*quota_on)(struct super_block___305 *, int, int, const struct path___306 *);
	int (*quota_off)(struct super_block___305 *, int);
	int (*quota_enable)(struct super_block___305 *, unsigned int);
	int (*quota_disable)(struct super_block___305 *, unsigned int);
	int (*quota_sync)(struct super_block___305 *, int);
	int (*set_info)(struct super_block___305 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___305 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___305 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___305 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___305 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___305 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___305 {
	int (*writepage)(struct page___307 *, struct writeback_control___3 *);
	int (*readpage)(struct file___306 *, struct page___307 *);
	int (*writepages)(struct address_space___305 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___307 *);
	int (*readpages)(struct file___306 *, struct address_space___305 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___306 *, struct address_space___305 *, loff_t, unsigned int, unsigned int, struct page___307 **, void **);
	int (*write_end)(struct file___306 *, struct address_space___305 *, loff_t, unsigned int, unsigned int, struct page___307 *, void *);
	sector_t (*bmap)(struct address_space___305 *, sector_t);
	void (*invalidatepage)(struct page___307 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___307 *, gfp_t);
	void (*freepage)(struct page___307 *);
	ssize_t (*direct_IO)(struct kiocb___306 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___305 *, struct page___307 *, struct page___307 *, enum migrate_mode);
	bool (*isolate_page)(struct page___307 *, isolate_mode_t);
	void (*putback_page)(struct page___307 *);
	int (*launder_page)(struct page___307 *);
	int (*is_partially_uptodate)(struct page___307 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___307 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___305 *, struct page___307 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___306 *, sector_t *);
	void (*swap_deactivate)(struct file___306 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___305 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___306 *bd_inode;
	struct super_block___305 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___305 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___292;

struct kobj_type___292;

struct kernfs_node___300;

struct kobject___293 {
	const char *name;
	struct list_head entry;
	struct kobject___293 *parent;
	struct kset___292 *kset;
	struct kobj_type___292 *ktype;
	struct kernfs_node___300 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___56 {
	struct kobject___293 kobj;
	struct module___11 *owner;
	const struct file_operations___306 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___305 {
	struct dentry___306 * (*lookup)(struct inode___306 *, struct dentry___306 *, unsigned int);
	const char * (*get_link)(struct dentry___306 *, struct inode___306 *, struct delayed_call *);
	int (*permission)(struct inode___306 *, int);
	struct posix_acl * (*get_acl)(struct inode___306 *, int);
	int (*readlink)(struct dentry___306 *, char *, int);
	int (*create)(struct inode___306 *, struct dentry___306 *, umode_t, bool);
	int (*link)(struct dentry___306 *, struct inode___306 *, struct dentry___306 *);
	int (*unlink)(struct inode___306 *, struct dentry___306 *);
	int (*symlink)(struct inode___306 *, struct dentry___306 *, const char *);
	int (*mkdir)(struct inode___306 *, struct dentry___306 *, umode_t);
	int (*rmdir)(struct inode___306 *, struct dentry___306 *);
	int (*mknod)(struct inode___306 *, struct dentry___306 *, umode_t, dev_t);
	int (*rename)(struct inode___306 *, struct dentry___306 *, struct inode___306 *, struct dentry___306 *, unsigned int);
	int (*setattr)(struct dentry___306 *, struct iattr___305 *);
	int (*getattr)(const struct path___306 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___306 *, char *, size_t);
	int (*fiemap)(struct inode___306 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___306 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___306 *, struct dentry___306 *, struct file___306 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___306 *, struct dentry___306 *, umode_t);
	int (*set_acl)(struct inode___306 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___305 {
	void (*fl_copy_lock)(struct file_lock___306 *, struct file_lock___306 *);
	void (*fl_release_private)(struct file_lock___306 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___305;

struct lock_manager_operations___305;

struct file_lock___306 {
	struct file_lock___306 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___306 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___305 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___305 *fl_ops;
	const struct lock_manager_operations___305 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___305 {
	int (*lm_compare_owner)(struct file_lock___306 *, struct file_lock___306 *);
	long unsigned int (*lm_owner_key)(struct file_lock___306 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___306 *);
	int (*lm_grant)(struct file_lock___306 *, int);
	bool (*lm_break)(struct file_lock___306 *);
	int (*lm_change)(struct file_lock___306 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___306 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___305 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___305 *fa_next;
	struct file___306 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___305 {
	const char *name;
	int fs_flags;
	struct dentry___306 * (*mount)(struct file_system_type___305 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___305 *);
	struct module___11 *owner;
	struct file_system_type___305 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___305 {
	struct inode___306 * (*alloc_inode)(struct super_block___305 *);
	void (*destroy_inode)(struct inode___306 *);
	void (*dirty_inode)(struct inode___306 *, int);
	int (*write_inode)(struct inode___306 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___306 *);
	void (*evict_inode)(struct inode___306 *);
	void (*put_super)(struct super_block___305 *);
	int (*sync_fs)(struct super_block___305 *, int);
	int (*freeze_super)(struct super_block___305 *);
	int (*freeze_fs)(struct super_block___305 *);
	int (*thaw_super)(struct super_block___305 *);
	int (*unfreeze_fs)(struct super_block___305 *);
	int (*statfs)(struct dentry___306 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___305 *, int *, char *);
	void (*umount_begin)(struct super_block___305 *);
	int (*show_options)(struct seq_file___258 *, struct dentry___306 *);
	int (*show_devname)(struct seq_file___258 *, struct dentry___306 *);
	int (*show_path)(struct seq_file___258 *, struct dentry___306 *);
	int (*show_stats)(struct seq_file___258 *, struct dentry___306 *);
	ssize_t (*quota_read)(struct super_block___305 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___305 *, int, const char *, size_t, loff_t);
	struct dquot___305 ** (*get_dquots)(struct inode___306 *);
	int (*bdev_try_to_free_page)(struct super_block___305 *, struct page___307 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___305 *, struct shrink_control___117 *);
	long int (*free_cached_objects)(struct super_block___305 *, struct shrink_control___117 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___186)(struct file___306 *, wait_queue_head_t *, struct poll_table_struct___183 *);

struct poll_table_struct___183 {
	poll_queue_proc___186 _qproc;
	__poll_t _key;
};

struct seq_operations___257;

struct seq_file___258 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___257 *op;
	int poll_event;
	const struct file___306 *file;
	void *private;
};

struct dev_pm_info___271 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___271 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___271;

struct bus_type___271;

struct device_driver___271;

struct dev_pm_domain___271;

struct irq_domain___22;

struct dma_map_ops___89;

struct device_node___63;

struct fwnode_handle___205;

struct class___271;

struct attribute_group___270;

struct device___271 {
	struct device___271 *parent;
	struct device_private *p;
	struct kobject___293 kobj;
	const char *init_name;
	const struct device_type___271 *type;
	struct mutex mutex;
	struct bus_type___271 *bus;
	struct device_driver___271 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___271 power;
	struct dev_pm_domain___271 *pm_domain;
	struct irq_domain___22 *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___89 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___63 *of_node;
	struct fwnode_handle___205 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___271 *class;
	const struct attribute_group___270 **groups;
	void (*release)(struct device___271 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct kernfs_root___299;

struct kernfs_elem_dir___299 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___299 *root;
};

struct kernfs_syscall_ops___299;

struct kernfs_root___299 {
	struct kernfs_node___300 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___299 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___299 {
	struct kernfs_node___300 *target_kn;
};

struct kernfs_ops___299;

struct kernfs_elem_attr___299 {
	const struct kernfs_ops___299 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___300 *notify_next;
};

struct kernfs_node___300 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___300 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___299 dir;
		struct kernfs_elem_symlink___299 symlink;
		struct kernfs_elem_attr___299 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___299;

struct kernfs_ops___299 {
	int (*open)(struct kernfs_open_file___299 *);
	void (*release)(struct kernfs_open_file___299 *);
	int (*seq_show)(struct seq_file___258 *, void *);
	void * (*seq_start)(struct seq_file___258 *, loff_t *);
	void * (*seq_next)(struct seq_file___258 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___258 *, void *);
	ssize_t (*read)(struct kernfs_open_file___299 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___299 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___299 *, struct vm_area_struct___307 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___299 *, struct poll_table_struct___183 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___299 {
	int (*remount_fs)(struct kernfs_root___299 *, int *, char *);
	int (*show_options)(struct seq_file___258 *, struct kernfs_root___299 *);
	int (*mkdir)(struct kernfs_node___300 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___300 *);
	int (*rename)(struct kernfs_node___300 *, struct kernfs_node___300 *, const char *);
	int (*show_path)(struct seq_file___258 *, struct kernfs_node___300 *, struct kernfs_root___299 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___299 {
	struct kernfs_node___300 *kn;
	struct file___306 *file;
	struct seq_file___258 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___295 *vm_ops;
};

struct bin_attribute___269;

struct attribute_group___270 {
	const char *name;
	umode_t (*is_visible)(struct kobject___293 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___293 *, struct bin_attribute___269 *, int);
	struct attribute **attrs;
	struct bin_attribute___269 **bin_attrs;
};

struct bin_attribute___269 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___306 *, struct kobject___293 *, struct bin_attribute___269 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___306 *, struct kobject___293 *, struct bin_attribute___269 *, char *, loff_t, size_t);
	int (*mmap)(struct file___306 *, struct kobject___293 *, struct bin_attribute___269 *, struct vm_area_struct___307 *);
};

struct sysfs_ops___292 {
	ssize_t (*show)(struct kobject___293 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___293 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___292;

struct kset___292 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___293 kobj;
	const struct kset_uevent_ops___292 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___292 {
	void (*release)(struct kobject___293 *);
	const struct sysfs_ops___292 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___25 * (*child_ns_type)(struct kobject___293 *);
	const void * (*namespace)(struct kobject___293 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___292 {
	int (* const filter)(struct kset___292 *, struct kobject___293 *);
	const char * (* const name)(struct kset___292 *, struct kobject___293 *);
	int (* const uevent)(struct kset___292 *, struct kobject___293 *, struct kobj_uevent_env *);
};

struct kobj_attribute___285 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___293 *, struct kobj_attribute___285 *, char *);
	ssize_t (*store)(struct kobject___293 *, struct kobj_attribute___285 *, const char *, size_t);
};

struct dev_pm_ops___271 {
	int (*prepare)(struct device___271 *);
	void (*complete)(struct device___271 *);
	int (*suspend)(struct device___271 *);
	int (*resume)(struct device___271 *);
	int (*freeze)(struct device___271 *);
	int (*thaw)(struct device___271 *);
	int (*poweroff)(struct device___271 *);
	int (*restore)(struct device___271 *);
	int (*suspend_late)(struct device___271 *);
	int (*resume_early)(struct device___271 *);
	int (*freeze_late)(struct device___271 *);
	int (*thaw_early)(struct device___271 *);
	int (*poweroff_late)(struct device___271 *);
	int (*restore_early)(struct device___271 *);
	int (*suspend_noirq)(struct device___271 *);
	int (*resume_noirq)(struct device___271 *);
	int (*freeze_noirq)(struct device___271 *);
	int (*thaw_noirq)(struct device___271 *);
	int (*poweroff_noirq)(struct device___271 *);
	int (*restore_noirq)(struct device___271 *);
	int (*runtime_suspend)(struct device___271 *);
	int (*runtime_resume)(struct device___271 *);
	int (*runtime_idle)(struct device___271 *);
};

struct dev_pm_domain___271 {
	struct dev_pm_ops___271 ops;
	void (*detach)(struct device___271 *, bool);
	int (*activate)(struct device___271 *);
	void (*sync)(struct device___271 *);
	void (*dismiss)(struct device___271 *);
};

struct bus_type___271 {
	const char *name;
	const char *dev_name;
	struct device___271 *dev_root;
	const struct attribute_group___270 **bus_groups;
	const struct attribute_group___270 **dev_groups;
	const struct attribute_group___270 **drv_groups;
	int (*match)(struct device___271 *, struct device_driver___271 *);
	int (*uevent)(struct device___271 *, struct kobj_uevent_env *);
	int (*probe)(struct device___271 *);
	int (*remove)(struct device___271 *);
	void (*shutdown)(struct device___271 *);
	int (*online)(struct device___271 *);
	int (*offline)(struct device___271 *);
	int (*suspend)(struct device___271 *, pm_message_t);
	int (*resume)(struct device___271 *);
	int (*num_vf)(struct device___271 *);
	int (*dma_configure)(struct device___271 *);
	const struct dev_pm_ops___271 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___271 {
	const char *name;
	struct bus_type___271 *bus;
	struct module___11 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___271 *);
	int (*remove)(struct device___271 *);
	void (*shutdown)(struct device___271 *);
	int (*suspend)(struct device___271 *, pm_message_t);
	int (*resume)(struct device___271 *);
	const struct attribute_group___270 **groups;
	const struct dev_pm_ops___271 *pm;
	void (*coredump)(struct device___271 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___271 {
	const char *name;
	const struct attribute_group___270 **groups;
	int (*uevent)(struct device___271 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___271 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___271 *);
	const struct dev_pm_ops___271 *pm;
};

struct class___271 {
	const char *name;
	struct module___11 *owner;
	const struct attribute_group___270 **class_groups;
	const struct attribute_group___270 **dev_groups;
	struct kobject___293 *dev_kobj;
	int (*dev_uevent)(struct device___271 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___271 *, umode_t *);
	void (*class_release)(struct class___271 *);
	void (*dev_release)(struct device___271 *);
	int (*shutdown_pre)(struct device___271 *);
	const struct kobj_ns_type_operations___25 *ns_type;
	const void * (*namespace)(struct device___271 *);
	const struct dev_pm_ops___271 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct device_attribute___20 {
	struct attribute attr;
	ssize_t (*show)(struct device___271 *, struct device_attribute___20 *, char *);
	ssize_t (*store)(struct device___271 *, struct device_attribute___20 *, const char *, size_t);
};

struct irq_domain_ops___22;

struct irq_domain___22 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___22 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___205 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___2 *gc;
	struct irq_domain___22 *parent;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_direct_max_irq;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_tree_mutex;
	unsigned int linear_revmap[0];
};

struct dma_map_ops___89 {
	void * (*alloc)(struct device___271 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___271 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___271 *, struct vm_area_struct___307 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___271 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___271 *, struct page___307 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___271 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___271 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___271 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___271 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___271 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___271 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___271 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___271 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___271 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___271 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___271 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___271 *, u64);
	u64 (*get_required_mask)(struct device___271 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___205;

struct fwnode_handle___205 {
	struct fwnode_handle___205 *secondary;
	const struct fwnode_operations___205 *ops;
};

struct property___60;

struct device_node___63 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___205 fwnode;
	struct property___60 *properties;
	struct property___60 *deadprops;
	struct device_node___63 *parent;
	struct device_node___63 *child;
	struct device_node___63 *sibling;
	struct kobject___293 kobj;
	long unsigned int _flags;
	void *data;
};

typedef int (*key_restrict_link_func_t___285)(struct key___284 *, const struct key_type *, const union key_payload *, struct key___284 *);

struct key_restriction___284;

struct key___284 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___307 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___284 *restrict_link;
};

struct key_restriction___284 {
	key_restrict_link_func_t___285 check;
	struct key___284 *key;
	struct key_type *keytype;
};

struct seq_operations___257 {
	void * (*start)(struct seq_file___258 *, loff_t *);
	void (*stop)(struct seq_file___258 *, void *);
	void * (*next)(struct seq_file___258 *, void *, loff_t *);
	int (*show)(struct seq_file___258 *, void *);
};

typedef void compound_page_dtor___295(struct page___307 *);

struct fwnode_reference_args___205;

struct fwnode_endpoint___205;

struct fwnode_operations___205 {
	struct fwnode_handle___205 * (*get)(struct fwnode_handle___205 *);
	void (*put)(struct fwnode_handle___205 *);
	bool (*device_is_available)(const struct fwnode_handle___205 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___205 *, const struct device___271 *);
	bool (*property_present)(const struct fwnode_handle___205 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___205 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___205 *, const char *, const char **, size_t);
	struct fwnode_handle___205 * (*get_parent)(const struct fwnode_handle___205 *);
	struct fwnode_handle___205 * (*get_next_child_node)(const struct fwnode_handle___205 *, struct fwnode_handle___205 *);
	struct fwnode_handle___205 * (*get_named_child_node)(const struct fwnode_handle___205 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___205 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___205 *);
	struct fwnode_handle___205 * (*graph_get_next_endpoint)(const struct fwnode_handle___205 *, struct fwnode_handle___205 *);
	struct fwnode_handle___205 * (*graph_get_remote_endpoint)(const struct fwnode_handle___205 *);
	struct fwnode_handle___205 * (*graph_get_port_parent)(struct fwnode_handle___205 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___205 *, struct fwnode_endpoint___205 *);
};

struct fwnode_endpoint___205 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___205 *local_fwnode;
};

struct fwnode_reference_args___205 {
	struct fwnode_handle___205 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct property___60 {
	char *name;
	int length;
	void *value;
	struct property___60 *next;
	long unsigned int _flags;
	struct bin_attribute___269 attr;
};

struct irq_fwspec___22 {
	struct fwnode_handle___205 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___22 {
	int (*match)(struct irq_domain___22 *, struct device_node___63 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___22 *, struct irq_fwspec___22 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___22 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___22 *, unsigned int);
	int (*xlate)(struct irq_domain___22 *, struct device_node___63 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___22 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___22 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___22 *, struct irq_data___5 *, bool);
	void (*deactivate)(struct irq_domain___22 *, struct irq_data___5 *);
	int (*translate)(struct irq_domain___22 *, struct irq_fwspec___22 *, long unsigned int *, unsigned int *);
};

struct backlight_device___8;

struct fb_info___8;

struct backlight_ops___8 {
	unsigned int options;
	int (*update_status)(struct backlight_device___8 *);
	int (*get_brightness)(struct backlight_device___8 *);
	int (*check_fb)(struct backlight_device___8 *, struct fb_info___8 *);
};

struct backlight_device___8 {
	struct backlight_properties props;
	struct mutex update_lock;
	struct mutex ops_lock;
	const struct backlight_ops___8 *ops;
	struct notifier_block fb_notif;
	struct list_head entry;
	struct device___271 dev;
	bool fb_bl_on[32];
	int use_count;
};

struct fb_pixmap___8 {
	u8 *addr;
	u32 size;
	u32 offset;
	u32 buf_align;
	u32 scan_align;
	u32 access_align;
	u32 flags;
	u32 blit_x;
	u32 blit_y;
	void (*writeio)(struct fb_info___8 *, void *, void *, unsigned int);
	void (*readio)(struct fb_info___8 *, void *, void *, unsigned int);
};

struct fb_deferred_io___8;

struct fb_ops___8;

struct fb_tile_ops___8;

struct fb_info___8 {
	atomic_t count;
	int node;
	int flags;
	int fbcon_rotate_hint;
	struct mutex lock;
	struct mutex mm_lock;
	struct fb_var_screeninfo var;
	struct fb_fix_screeninfo fix;
	struct fb_monspecs monspecs;
	struct work_struct queue;
	struct fb_pixmap___8 pixmap;
	struct fb_pixmap___8 sprite;
	struct fb_cmap cmap;
	struct list_head modelist;
	struct fb_videomode *mode;
	struct backlight_device___8 *bl_dev;
	struct mutex bl_curve_mutex;
	u8 bl_curve[128];
	struct delayed_work deferred_work;
	struct fb_deferred_io___8 *fbdefio;
	struct fb_ops___8 *fbops;
	struct device___271 *device;
	struct device___271 *dev;
	int class_flag;
	struct fb_tile_ops___8 *tileops;
	union {
		char *screen_base;
		char *screen_buffer;
	};
	long unsigned int screen_size;
	void *pseudo_palette;
	u32 state;
	void *fbcon_par;
	void *par;
	struct apertures_struct *apertures;
	bool skip_vt_switch;
};

struct fb_deferred_io___8 {
	long unsigned int delay;
	struct mutex lock;
	struct list_head pagelist;
	void (*first_io)(struct fb_info___8 *);
	void (*deferred_io)(struct fb_info___8 *, struct list_head *);
};

struct fb_ops___8 {
	struct module___11 *owner;
	int (*fb_open)(struct fb_info___8 *, int);
	int (*fb_release)(struct fb_info___8 *, int);
	ssize_t (*fb_read)(struct fb_info___8 *, char *, size_t, loff_t *);
	ssize_t (*fb_write)(struct fb_info___8 *, const char *, size_t, loff_t *);
	int (*fb_check_var)(struct fb_var_screeninfo *, struct fb_info___8 *);
	int (*fb_set_par)(struct fb_info___8 *);
	int (*fb_setcolreg)(unsigned int, unsigned int, unsigned int, unsigned int, unsigned int, struct fb_info___8 *);
	int (*fb_setcmap)(struct fb_cmap *, struct fb_info___8 *);
	int (*fb_blank)(int, struct fb_info___8 *);
	int (*fb_pan_display)(struct fb_var_screeninfo *, struct fb_info___8 *);
	void (*fb_fillrect)(struct fb_info___8 *, const struct fb_fillrect *);
	void (*fb_copyarea)(struct fb_info___8 *, const struct fb_copyarea *);
	void (*fb_imageblit)(struct fb_info___8 *, const struct fb_image *);
	int (*fb_cursor)(struct fb_info___8 *, struct fb_cursor *);
	int (*fb_sync)(struct fb_info___8 *);
	int (*fb_ioctl)(struct fb_info___8 *, unsigned int, long unsigned int);
	int (*fb_compat_ioctl)(struct fb_info___8 *, unsigned int, long unsigned int);
	int (*fb_mmap)(struct fb_info___8 *, struct vm_area_struct___307 *);
	void (*fb_get_caps)(struct fb_info___8 *, struct fb_blit_caps *, struct fb_var_screeninfo *);
	void (*fb_destroy)(struct fb_info___8 *);
	int (*fb_debug_enter)(struct fb_info___8 *);
	int (*fb_debug_leave)(struct fb_info___8 *);
};

struct fb_tile_ops___8 {
	void (*fb_settile)(struct fb_info___8 *, struct fb_tilemap *);
	void (*fb_tilecopy)(struct fb_info___8 *, struct fb_tilearea *);
	void (*fb_tilefill)(struct fb_info___8 *, struct fb_tilerect *);
	void (*fb_tileblit)(struct fb_info___8 *, struct fb_tileblit *);
	void (*fb_tilecursor)(struct fb_info___8 *, struct fb_tilecursor *);
	int (*fb_get_tilemax)(struct fb_info___8 *);
};

struct pci_bus___26;

struct pci_slot___26 {
	struct pci_bus___26 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject___293 kobj;
};

struct pci_dev___26;

struct pci_ops___26;

struct pci_bus___26 {
	struct list_head node;
	struct pci_bus___26 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___26 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___26 *ops;
	struct msi_controller___2 *msi;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	int domain_nr;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___271 *bridge;
	struct device___271 dev;
	struct bin_attribute___269 *legacy_io;
	struct bin_attribute___269 *legacy_mem;
	unsigned int is_added: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
};

struct pci_driver___26;

struct pci_dev___26 {
	struct list_head bus_list;
	struct pci_bus___26 *bus;
	struct pci_bus___26 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___26 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u16 aer_cap;
	struct aer_stats *aer_stats;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	long unsigned int *dma_alias_mask;
	struct pci_driver___26 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	unsigned int imm_ready: 1;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int bridge_d3: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int hotplug_user_indicators: 1;
	unsigned int clear_retrain_link: 1;
	unsigned int d3_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	unsigned int ltr_path: 1;
	unsigned int eetlp_prefix_path: 1;
	pci_channel_state_t error_state;
	struct device___271 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int multifunction: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int ats_enabled: 1;
	unsigned int pasid_enabled: 1;
	unsigned int pri_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int reset_fn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int shpc_managed: 1;
	unsigned int is_thunderbolt: 1;
	unsigned int __aer_firmware_first_valid: 1;
	unsigned int __aer_firmware_first: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int irq_managed: 1;
	unsigned int has_secondary_link: 1;
	unsigned int non_compliant_bars: 1;
	unsigned int is_probed: 1;
	unsigned int link_active_reporting: 1;
	unsigned int untrusted: 1;
	unsigned int no_vf_scan: 1;
	unsigned int io_window: 1;
	unsigned int pref_window: 1;
	unsigned int pref_64_window: 1;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	struct bin_attribute___269 *rom_attr;
	int rom_attr_enabled;
	struct bin_attribute___269 *res_attr[17];
	struct bin_attribute___269 *res_attr_wc[17];
	unsigned int broken_cmd_compl: 1;
	const struct attribute_group___270 **msi_irq_groups;
	struct pci_vpd *vpd;
	union {
		struct pci_sriov *sriov;
		struct pci_dev___26 *physfn;
	};
	u16 ats_cap;
	u8 ats_stu;
	atomic_t ats_ref_cnt;
	u32 pri_reqs_alloc;
	u16 pasid_features;
	struct pci_p2pdma *p2pdma;
	phys_addr_t rom;
	size_t romlen;
	char *driver_override;
	long unsigned int priv_flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t pci_dev_extended_size_rh;
	struct pci_dev_extended_rh pci_dev_extended_rh;
};

struct pci_error_handlers___26;

struct pci_driver___26 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___26 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___26 *);
	int (*suspend)(struct pci_dev___26 *, pm_message_t);
	int (*suspend_late)(struct pci_dev___26 *, pm_message_t);
	int (*resume_early)(struct pci_dev___26 *);
	int (*resume)(struct pci_dev___26 *);
	void (*shutdown)(struct pci_dev___26 *);
	int (*sriov_configure)(struct pci_dev___26 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	const struct pci_error_handlers___26 *err_handler;
	const struct attribute_group___270 **groups;
	struct device_driver___271 driver;
	struct pci_dynids dynids;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct pci_ops___26 {
	int (*add_bus)(struct pci_bus___26 *);
	void (*remove_bus)(struct pci_bus___26 *);
	void * (*map_bus)(struct pci_bus___26 *, unsigned int, int);
	int (*read)(struct pci_bus___26 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___26 *, unsigned int, int, int, u32);
};

struct pci_error_handlers___26 {
	pci_ers_result_t (*error_detected)(struct pci_dev___26 *, enum pci_channel_state);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___26 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___26 *);
	void (*reset_prepare)(struct pci_dev___26 *);
	void (*reset_done)(struct pci_dev___26 *);
	void (*resume)(struct pci_dev___26 *);
};

struct pci_fixup___5 {
	u16 vendor;
	u16 device;
	u32 class;
	unsigned int class_shift;
	void (*hook)(struct pci_dev___26 *);
};

struct platform_device___12 {
	const char *name;
	int id;
	bool id_auto;
	struct device___271 dev;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct platform_driver___11 {
	int (*probe)(struct platform_device___12 *);
	int (*remove)(struct platform_device___12 *);
	void (*shutdown)(struct platform_device___12 *);
	int (*suspend)(struct platform_device___12 *, pm_message_t);
	int (*resume)(struct platform_device___12 *);
	struct device_driver___271 driver;
	const struct platform_device_id *id_table;
	bool prevent_deferred_probe;
};

enum drm_panel_orientation {
	DRM_MODE_PANEL_ORIENTATION_UNKNOWN = 4294967295,
	DRM_MODE_PANEL_ORIENTATION_NORMAL = 0,
	DRM_MODE_PANEL_ORIENTATION_BOTTOM_UP = 1,
	DRM_MODE_PANEL_ORIENTATION_LEFT_UP = 2,
	DRM_MODE_PANEL_ORIENTATION_RIGHT_UP = 3,
};

struct simplefb_format {
	const char *name;
	u32 bits_per_pixel;
	struct fb_bitfield red;
	struct fb_bitfield green;
	struct fb_bitfield blue;
	struct fb_bitfield transp;
	u32 fourcc;
};

struct simplefb_platform_data {
	u32 width;
	u32 height;
	u32 stride;
	const char *format;
};

struct platform_device___13 {
	const char *name;
	int id;
	bool id_auto;
	struct device___267 dev;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct platform_driver___12 {
	int (*probe)(struct platform_device___13 *);
	int (*remove)(struct platform_device___13 *);
	void (*shutdown)(struct platform_device___13 *);
	int (*suspend)(struct platform_device___13 *, pm_message_t);
	int (*resume)(struct platform_device___13 *);
	struct device_driver___267 driver;
	const struct platform_device_id *id_table;
	bool prevent_deferred_probe;
};

struct clk_hw___2;

struct clk_rate_request___2 {
	long unsigned int rate;
	long unsigned int min_rate;
	long unsigned int max_rate;
	long unsigned int best_parent_rate;
	struct clk_hw___2 *best_parent_hw;
};

struct clk_init_data___2;

struct clk_hw___2 {
	struct clk_core *core;
	struct clk *clk;
	const struct clk_init_data___2 *init;
};

struct clk_ops___2 {
	int (*prepare)(struct clk_hw___2 *);
	void (*unprepare)(struct clk_hw___2 *);
	int (*is_prepared)(struct clk_hw___2 *);
	void (*unprepare_unused)(struct clk_hw___2 *);
	int (*enable)(struct clk_hw___2 *);
	void (*disable)(struct clk_hw___2 *);
	int (*is_enabled)(struct clk_hw___2 *);
	void (*disable_unused)(struct clk_hw___2 *);
	long unsigned int (*recalc_rate)(struct clk_hw___2 *, long unsigned int);
	long int (*round_rate)(struct clk_hw___2 *, long unsigned int, long unsigned int *);
	int (*determine_rate)(struct clk_hw___2 *, struct clk_rate_request___2 *);
	int (*set_parent)(struct clk_hw___2 *, u8);
	u8 (*get_parent)(struct clk_hw___2 *);
	int (*set_rate)(struct clk_hw___2 *, long unsigned int, long unsigned int);
	int (*set_rate_and_parent)(struct clk_hw___2 *, long unsigned int, long unsigned int, u8);
	long unsigned int (*recalc_accuracy)(struct clk_hw___2 *, long unsigned int);
	int (*get_phase)(struct clk_hw___2 *);
	int (*set_phase)(struct clk_hw___2 *, int);
	void (*init)(struct clk_hw___2 *);
	void (*debug_init)(struct clk_hw___2 *, struct dentry___302 *);
};

struct clk_init_data___2 {
	const char *name;
	const struct clk_ops___2 *ops;
	const char * const *parent_names;
	u8 num_parents;
	long unsigned int flags;
};

struct node___182 {
	struct device___267 dev;
};

struct simplefb_params {
	u32 width;
	u32 height;
	u32 stride;
	struct simplefb_format *format;
};

struct simplefb_par {
	u32 palette[16];
	bool clks_enabled;
	unsigned int clk_count;
	struct clk **clks;
};

struct display_timings {
	unsigned int num_timings;
	unsigned int native_mode;
	struct display_timing **timings;
};

enum ipmi_addr_src {
	SI_INVALID = 0,
	SI_HOTMOD = 1,
	SI_HARDCODED = 2,
	SI_SPMI = 3,
	SI_ACPI = 4,
	SI_SMBIOS = 5,
	SI_PCI = 6,
	SI_DEVICETREE = 7,
	SI_PLATFORM = 8,
	SI_LAST = 9,
};

union ipmi_smi_info_union {
	struct {
		acpi_handle acpi_handle;
	} acpi_info;
};

struct dmi_header {
	u8 type;
	u8 length;
	u16 handle;
};

enum si_type {
	SI_TYPE_INVALID = 0,
	SI_KCS = 1,
	SI_SMIC = 2,
	SI_BT = 3,
};

enum ipmi_addr_space {
	IPMI_IO_ADDR_SPACE = 0,
	IPMI_MEM_ADDR_SPACE = 1,
};

struct si_sm_io {
	unsigned char (*inputb)(const struct si_sm_io *, unsigned int);
	void (*outputb)(const struct si_sm_io *, unsigned int, unsigned char);
	void *addr;
	unsigned int regspacing;
	unsigned int regsize;
	unsigned int regshift;
	enum ipmi_addr_space addr_space;
	long unsigned int addr_data;
	enum ipmi_addr_src addr_source;
	void (*addr_source_cleanup)(struct si_sm_io *);
	void *addr_source_data;
	union ipmi_smi_info_union addr_info;
	int (*io_setup)(struct si_sm_io *);
	void (*io_cleanup)(struct si_sm_io *);
	unsigned int io_size;
	int irq;
	int (*irq_setup)(struct si_sm_io *);
	void *irq_handler_data;
	void (*irq_cleanup)(struct si_sm_io *);
	u8 slave_addr;
	enum si_type si_type;
	struct device___8 *dev;
};

enum si_sm_result {
	SI_SM_CALL_WITHOUT_DELAY = 0,
	SI_SM_CALL_WITH_DELAY = 1,
	SI_SM_CALL_WITH_TICK_DELAY = 2,
	SI_SM_TRANSACTION_COMPLETE = 3,
	SI_SM_IDLE = 4,
	SI_SM_HOSED = 5,
	SI_SM_ATTN = 6,
};

struct si_sm_data;

struct si_sm_handlers {
	char *version;
	unsigned int (*init_data)(struct si_sm_data *, struct si_sm_io *);
	int (*start_transaction)(struct si_sm_data *, unsigned char *, unsigned int);
	int (*get_result)(struct si_sm_data *, unsigned char *, unsigned int);
	enum si_sm_result (*event)(struct si_sm_data *, long int);
	int (*detect)(struct si_sm_data *);
	void (*cleanup)(struct si_sm_data *);
	int (*size)();
};

struct ipmi_plat_data {
	unsigned int type;
	unsigned int space;
	long unsigned int addr;
	unsigned int regspacing;
	unsigned int regsize;
	unsigned int regshift;
	unsigned int irq;
	unsigned int slave_addr;
	enum ipmi_addr_src addr_source;
};

struct ipmi_dmi_info {
	enum si_type si_type;
	unsigned int space;
	long unsigned int addr;
	u8 slave_addr;
	struct ipmi_dmi_info *next;
};

enum dev_prop_type {
	DEV_PROP_U8 = 0,
	DEV_PROP_U16 = 1,
	DEV_PROP_U32 = 2,
	DEV_PROP_U64 = 3,
	DEV_PROP_STRING = 4,
	DEV_PROP_MAX = 5,
};

struct property_entry___2 {
	const char *name;
	size_t length;
	bool is_array;
	enum dev_prop_type type;
	union {
		union {
			const u8 *u8_data;
			const u16 *u16_data;
			const u32 *u32_data;
			const u64 *u64_data;
			const char * const *str;
		} pointer;
		union {
			u8 u8_data;
			u16 u16_data;
			u32 u32_data;
			u64 u64_data;
			const char *str;
		} value;
	};
};

struct si_sm_io___2 {
	unsigned char (*inputb)(const struct si_sm_io___2 *, unsigned int);
	void (*outputb)(const struct si_sm_io___2 *, unsigned int, unsigned char);
	void *addr;
	unsigned int regspacing;
	unsigned int regsize;
	unsigned int regshift;
	enum ipmi_addr_space addr_space;
	long unsigned int addr_data;
	enum ipmi_addr_src addr_source;
	void (*addr_source_cleanup)(struct si_sm_io___2 *);
	void *addr_source_data;
	union ipmi_smi_info_union addr_info;
	int (*io_setup)(struct si_sm_io___2 *);
	void (*io_cleanup)(struct si_sm_io___2 *);
	unsigned int io_size;
	int irq;
	int (*irq_setup)(struct si_sm_io___2 *);
	void *irq_handler_data;
	void (*irq_cleanup)(struct si_sm_io___2 *);
	u8 slave_addr;
	enum si_type si_type;
	struct device___245 *dev;
};

struct si_sm_handlers___2 {
	char *version;
	unsigned int (*init_data)(struct si_sm_data *, struct si_sm_io___2 *);
	int (*start_transaction)(struct si_sm_data *, unsigned char *, unsigned int);
	int (*get_result)(struct si_sm_data *, unsigned char *, unsigned int);
	enum si_sm_result (*event)(struct si_sm_data *, long int);
	int (*detect)(struct si_sm_data *);
	void (*cleanup)(struct si_sm_data *);
	int (*size)();
};

typedef u8 acpi_owner_id;

union acpi_name_union {
	u32 integer;
	char ascii[4];
};

struct acpi_table_desc {
	acpi_physical_address address;
	struct acpi_table_header *pointer;
	u32 length;
	union acpi_name_union signature;
	acpi_owner_id owner_id;
	u8 flags;
	u16 validation_count;
};

struct acpi_madt_local_apic {
	struct acpi_subtable_header header;
	u8 processor_id;
	u8 id;
	u32 lapic_flags;
};

struct acpi_madt_io_apic {
	struct acpi_subtable_header header;
	u8 id;
	u8 reserved;
	u32 address;
	u32 global_irq_base;
};

struct acpi_madt_interrupt_override {
	struct acpi_subtable_header header;
	u8 bus;
	u8 source_irq;
	u32 global_irq;
	u16 inti_flags;
} __attribute__((packed));

struct acpi_madt_nmi_source {
	struct acpi_subtable_header header;
	u16 inti_flags;
	u32 global_irq;
};

struct acpi_madt_local_apic_nmi {
	struct acpi_subtable_header header;
	u8 processor_id;
	u16 inti_flags;
	u8 lint;
} __attribute__((packed));

struct acpi_madt_local_apic_override {
	struct acpi_subtable_header header;
	u16 reserved;
	u64 address;
} __attribute__((packed));

struct acpi_madt_io_sapic {
	struct acpi_subtable_header header;
	u8 id;
	u8 reserved;
	u32 global_irq_base;
	u64 address;
};

struct acpi_madt_local_sapic {
	struct acpi_subtable_header header;
	u8 processor_id;
	u8 id;
	u8 eid;
	u8 reserved[3];
	u32 lapic_flags;
	u32 uid;
	char uid_string[1];
} __attribute__((packed));

struct acpi_madt_interrupt_source {
	struct acpi_subtable_header header;
	u16 inti_flags;
	u8 type;
	u8 id;
	u8 eid;
	u8 io_sapic_vector;
	u32 global_irq;
	u32 flags;
};

struct acpi_madt_local_x2apic {
	struct acpi_subtable_header header;
	u16 reserved;
	u32 local_apic_id;
	u32 lapic_flags;
	u32 uid;
};

struct acpi_madt_local_x2apic_nmi {
	struct acpi_subtable_header header;
	u16 inti_flags;
	u32 uid;
	u8 lint;
	u8 reserved[3];
};

struct acpi_subtable_proc {
	int id;
	acpi_tbl_entry_handler handler;
	int count;
};

struct cpio_data {
	void *data;
	size_t size;
	char name[18];
};

struct transaction;

struct acpi_ec {
	acpi_handle handle;
	u32 gpe;
	long unsigned int command_addr;
	long unsigned int data_addr;
	bool global_lock;
	long unsigned int flags;
	long unsigned int reference_count;
	struct mutex mutex;
	wait_queue_head_t wait;
	struct list_head list;
	struct transaction *curr;
	spinlock_t lock;
	struct work_struct work;
	long unsigned int timestamp;
	long unsigned int nr_pending_queries;
	bool busy_polling;
	unsigned int polling_guard;
};

typedef char *acpi_string;

struct acpi_osi_entry {
	char string[64];
	bool enable;
};

struct acpi_osi_config {
	u8 default_disabling;
	unsigned int linux_enable: 1;
	unsigned int linux_dmi: 1;
	unsigned int linux_cmdline: 1;
	unsigned int darwin_enable: 1;
	unsigned int darwin_dmi: 1;
	unsigned int darwin_cmdline: 1;
};

typedef u32 acpi_name;

struct acpi_predefined_names {
	const char *name;
	u8 type;
	char *val;
};

typedef u32 (*acpi_osd_handler)(void *);

typedef void (*acpi_osd_exec_callback)(void *);

typedef u32 (*acpi_sci_handler)(void *);

typedef u32 (*acpi_gpe_handler)(acpi_handle, u32, void *);

typedef void (*acpi_notify_handler)(acpi_handle, u32, void *);

typedef void (*acpi_object_handler)(acpi_handle, void *);

typedef acpi_status (*acpi_init_handler)(acpi_handle, u32);

typedef acpi_status (*acpi_exception_handler)(acpi_status, acpi_name, u16, u32, void *);

typedef acpi_status (*acpi_table_handler)(u32, void *, void *);

typedef acpi_status (*acpi_adr_space_handler)(u32, acpi_physical_address, u32, u64 *, void *, void *);

typedef acpi_status (*acpi_adr_space_setup)(acpi_handle, u32, void *, void **);

typedef u32 (*acpi_interface_handler)(acpi_string, u32);

struct acpi_pci_id {
	u16 segment;
	u16 bus;
	u16 device;
	u16 function;
};

struct acpi_mem_space_context {
	u32 length;
	acpi_physical_address address;
	acpi_physical_address mapped_physical_address;
	u8 *mapped_logical_address;
	acpi_size mapped_length;
};

typedef enum {
	OSL_GLOBAL_LOCK_HANDLER = 0,
	OSL_NOTIFY_HANDLER = 1,
	OSL_GPE_HANDLER = 2,
	OSL_DEBUGGER_MAIN_THREAD = 3,
	OSL_DEBUGGER_EXEC_THREAD = 4,
	OSL_EC_POLL_HANDLER = 5,
	OSL_EC_BURST_HANDLER = 6,
} acpi_execute_type;

struct acpi_rw_lock {
	void *writer_mutex;
	void *reader_mutex;
	u32 num_readers;
};

struct acpi_mutex_info {
	void *mutex;
	u32 use_count;
	u64 thread_id;
};

union acpi_operand_object;

struct acpi_namespace_node {
	union acpi_operand_object *object;
	u8 descriptor_type;
	u8 type;
	u8 flags;
	acpi_owner_id owner_id;
	union acpi_name_union name;
	struct acpi_namespace_node *parent;
	struct acpi_namespace_node *child;
	struct acpi_namespace_node *peer;
};

struct acpi_object_common {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
};

struct acpi_object_integer {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	u8 fill[3];
	u64 value;
};

struct acpi_object_string {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	char *pointer;
	u32 length;
};

struct acpi_object_buffer {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	u8 *pointer;
	u32 length;
	u32 aml_length;
	u8 *aml_start;
	struct acpi_namespace_node *node;
};

struct acpi_object_package {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	struct acpi_namespace_node *node;
	union acpi_operand_object **elements;
	u8 *aml_start;
	u32 aml_length;
	u32 count;
};

struct acpi_object_event {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	void *os_semaphore;
};

struct acpi_walk_state;

typedef acpi_status (*acpi_internal_method)(struct acpi_walk_state *);

struct acpi_object_method {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	u8 info_flags;
	u8 param_count;
	u8 sync_level;
	union acpi_operand_object *mutex;
	union acpi_operand_object *node;
	u8 *aml_start;
	union {
		acpi_internal_method implementation;
		union acpi_operand_object *handler;
	} dispatch;
	u32 aml_length;
	u8 thread_count;
	acpi_owner_id owner_id;
};

struct acpi_thread_state;

struct acpi_object_mutex {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	u8 sync_level;
	u16 acquisition_depth;
	void *os_mutex;
	u64 thread_id;
	struct acpi_thread_state *owner_thread;
	union acpi_operand_object *prev;
	union acpi_operand_object *next;
	struct acpi_namespace_node *node;
	u8 original_sync_level;
};

struct acpi_object_region {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	u8 space_id;
	struct acpi_namespace_node *node;
	union acpi_operand_object *handler;
	union acpi_operand_object *next;
	acpi_physical_address address;
	u32 length;
};

struct acpi_object_notify_common {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	union acpi_operand_object *notify_list[2];
	union acpi_operand_object *handler;
};

struct acpi_gpe_block_info;

struct acpi_object_device {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	union acpi_operand_object *notify_list[2];
	union acpi_operand_object *handler;
	struct acpi_gpe_block_info *gpe_block;
};

struct acpi_object_power_resource {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	union acpi_operand_object *notify_list[2];
	union acpi_operand_object *handler;
	u32 system_level;
	u32 resource_order;
};

struct acpi_object_processor {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	u8 proc_id;
	u8 length;
	union acpi_operand_object *notify_list[2];
	union acpi_operand_object *handler;
	acpi_io_address address;
};

struct acpi_object_thermal_zone {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	union acpi_operand_object *notify_list[2];
	union acpi_operand_object *handler;
};

struct acpi_object_field_common {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	u8 field_flags;
	u8 attribute;
	u8 access_byte_width;
	struct acpi_namespace_node *node;
	u32 bit_length;
	u32 base_byte_offset;
	u32 value;
	u8 start_field_bit_offset;
	u8 access_length;
	union acpi_operand_object *region_obj;
};

struct acpi_object_region_field {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	u8 field_flags;
	u8 attribute;
	u8 access_byte_width;
	struct acpi_namespace_node *node;
	u32 bit_length;
	u32 base_byte_offset;
	u32 value;
	u8 start_field_bit_offset;
	u8 access_length;
	u16 resource_length;
	union acpi_operand_object *region_obj;
	u8 *resource_buffer;
	u16 pin_number_index;
};

struct acpi_object_buffer_field {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	u8 field_flags;
	u8 attribute;
	u8 access_byte_width;
	struct acpi_namespace_node *node;
	u32 bit_length;
	u32 base_byte_offset;
	u32 value;
	u8 start_field_bit_offset;
	u8 access_length;
	union acpi_operand_object *buffer_obj;
};

struct acpi_object_bank_field {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	u8 field_flags;
	u8 attribute;
	u8 access_byte_width;
	struct acpi_namespace_node *node;
	u32 bit_length;
	u32 base_byte_offset;
	u32 value;
	u8 start_field_bit_offset;
	u8 access_length;
	union acpi_operand_object *region_obj;
	union acpi_operand_object *bank_obj;
};

struct acpi_object_index_field {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	u8 field_flags;
	u8 attribute;
	u8 access_byte_width;
	struct acpi_namespace_node *node;
	u32 bit_length;
	u32 base_byte_offset;
	u32 value;
	u8 start_field_bit_offset;
	u8 access_length;
	union acpi_operand_object *index_obj;
	union acpi_operand_object *data_obj;
};

struct acpi_object_notify_handler {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	struct acpi_namespace_node *node;
	u32 handler_type;
	acpi_notify_handler handler;
	void *context;
	union acpi_operand_object *next[2];
};

struct acpi_object_addr_handler {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	u8 space_id;
	u8 handler_flags;
	acpi_adr_space_handler handler;
	struct acpi_namespace_node *node;
	void *context;
	acpi_adr_space_setup setup;
	union acpi_operand_object *region_list;
	union acpi_operand_object *next;
};

struct acpi_object_reference {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	u8 class;
	u8 target_type;
	u8 resolved;
	void *object;
	struct acpi_namespace_node *node;
	union acpi_operand_object **where;
	u8 *index_pointer;
	u8 *aml;
	u32 value;
};

struct acpi_object_extra {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	struct acpi_namespace_node *method_REG;
	struct acpi_namespace_node *scope_node;
	void *region_context;
	u8 *aml_start;
	u32 aml_length;
};

struct acpi_object_data {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	acpi_object_handler handler;
	void *pointer;
};

struct acpi_object_cache_list {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	union acpi_operand_object *next;
};

union acpi_operand_object {
	struct acpi_object_common common;
	struct acpi_object_integer integer;
	struct acpi_object_string string;
	struct acpi_object_buffer buffer;
	struct acpi_object_package package;
	struct acpi_object_event event;
	struct acpi_object_method method;
	struct acpi_object_mutex mutex;
	struct acpi_object_region region;
	struct acpi_object_notify_common common_notify;
	struct acpi_object_device device;
	struct acpi_object_power_resource power_resource;
	struct acpi_object_processor processor;
	struct acpi_object_thermal_zone thermal_zone;
	struct acpi_object_field_common common_field;
	struct acpi_object_region_field field;
	struct acpi_object_buffer_field buffer_field;
	struct acpi_object_bank_field bank_field;
	struct acpi_object_index_field index_field;
	struct acpi_object_notify_handler notify;
	struct acpi_object_addr_handler address_space;
	struct acpi_object_reference reference;
	struct acpi_object_extra extra;
	struct acpi_object_data data;
	struct acpi_object_cache_list cache;
	struct acpi_namespace_node node;
};

struct acpi_table_list {
	struct acpi_table_desc *tables;
	u32 current_table_count;
	u32 max_table_count;
	u8 flags;
};

union acpi_parse_object;

union acpi_generic_state;

struct acpi_parse_state {
	u8 *aml_start;
	u8 *aml;
	u8 *aml_end;
	u8 *pkg_start;
	u8 *pkg_end;
	union acpi_parse_object *start_op;
	struct acpi_namespace_node *start_node;
	union acpi_generic_state *scope;
	union acpi_parse_object *start_scope;
	u32 aml_size;
};

typedef acpi_status (*acpi_parse_downwards)(struct acpi_walk_state *, union acpi_parse_object **);

typedef acpi_status (*acpi_parse_upwards)(struct acpi_walk_state *);

struct acpi_opcode_info;

struct acpi_walk_state {
	struct acpi_walk_state *next;
	u8 descriptor_type;
	u8 walk_type;
	u16 opcode;
	u8 next_op_info;
	u8 num_operands;
	u8 operand_index;
	acpi_owner_id owner_id;
	u8 last_predicate;
	u8 current_result;
	u8 return_used;
	u8 scope_depth;
	u8 pass_number;
	u8 namespace_override;
	u8 result_size;
	u8 result_count;
	u8 *aml;
	u32 arg_types;
	u32 method_breakpoint;
	u32 user_breakpoint;
	u32 parse_flags;
	struct acpi_parse_state parser_state;
	u32 prev_arg_types;
	u32 arg_count;
	struct acpi_namespace_node arguments[7];
	struct acpi_namespace_node local_variables[8];
	union acpi_operand_object *operands[9];
	union acpi_operand_object **params;
	u8 *aml_last_while;
	union acpi_operand_object **caller_return_desc;
	union acpi_generic_state *control_state;
	struct acpi_namespace_node *deferred_node;
	union acpi_operand_object *implicit_return_obj;
	struct acpi_namespace_node *method_call_node;
	union acpi_parse_object *method_call_op;
	union acpi_operand_object *method_desc;
	struct acpi_namespace_node *method_node;
	union acpi_parse_object *op;
	const struct acpi_opcode_info *op_info;
	union acpi_parse_object *origin;
	union acpi_operand_object *result_obj;
	union acpi_generic_state *results;
	union acpi_operand_object *return_desc;
	union acpi_generic_state *scope_info;
	union acpi_parse_object *prev_op;
	union acpi_parse_object *next_op;
	struct acpi_thread_state *thread;
	acpi_parse_downwards descending_callback;
	acpi_parse_upwards ascending_callback;
};

struct acpi_sci_handler_info {
	struct acpi_sci_handler_info *next;
	acpi_sci_handler address;
	void *context;
};

struct acpi_gpe_handler_info {
	acpi_gpe_handler address;
	void *context;
	struct acpi_namespace_node *method_node;
	u8 original_flags;
	u8 originally_enabled;
};

struct acpi_gpe_notify_info {
	struct acpi_namespace_node *device_node;
	struct acpi_gpe_notify_info *next;
};

union acpi_gpe_dispatch_info {
	struct acpi_namespace_node *method_node;
	struct acpi_gpe_handler_info *handler;
	struct acpi_gpe_notify_info *notify_list;
};

struct acpi_gpe_register_info;

struct acpi_gpe_event_info {
	union acpi_gpe_dispatch_info dispatch;
	struct acpi_gpe_register_info *register_info;
	u8 flags;
	u8 gpe_number;
	u8 runtime_count;
	u8 disable_for_dispatch;
};

struct acpi_gpe_register_info {
	struct acpi_generic_address status_address;
	struct acpi_generic_address enable_address;
	u16 base_gpe_number;
	u8 enable_for_wake;
	u8 enable_for_run;
	u8 mask_for_run;
	u8 enable_mask;
} __attribute__((packed));

struct acpi_gpe_xrupt_info;

struct acpi_gpe_block_info {
	struct acpi_namespace_node *node;
	struct acpi_gpe_block_info *previous;
	struct acpi_gpe_block_info *next;
	struct acpi_gpe_xrupt_info *xrupt_block;
	struct acpi_gpe_register_info *register_info;
	struct acpi_gpe_event_info *event_info;
	u64 address;
	u32 register_count;
	u16 gpe_count;
	u16 block_base_number;
	u8 space_id;
	u8 initialized;
};

struct acpi_gpe_xrupt_info {
	struct acpi_gpe_xrupt_info *previous;
	struct acpi_gpe_xrupt_info *next;
	struct acpi_gpe_block_info *gpe_block_list_head;
	u32 interrupt_number;
};

struct acpi_common_state {
	void *next;
	u8 descriptor_type;
	u8 flags;
	u16 value;
	u16 state;
};

struct acpi_update_state {
	void *next;
	u8 descriptor_type;
	u8 flags;
	u16 value;
	u16 state;
	union acpi_operand_object *object;
};

struct acpi_pkg_state {
	void *next;
	u8 descriptor_type;
	u8 flags;
	u16 value;
	u16 state;
	u32 index;
	union acpi_operand_object *source_object;
	union acpi_operand_object *dest_object;
	struct acpi_walk_state *walk_state;
	void *this_target_obj;
	u32 num_packages;
};

struct acpi_control_state {
	void *next;
	u8 descriptor_type;
	u8 flags;
	u16 value;
	u16 state;
	u16 opcode;
	union acpi_parse_object *predicate_op;
	u8 *aml_predicate_start;
	u8 *package_end;
	u64 loop_timeout;
};

union acpi_parse_value {
	u64 integer;
	u32 size;
	char *string;
	u8 *buffer;
	char *name;
	union acpi_parse_object *arg;
};

struct acpi_parse_obj_common {
	union acpi_parse_object *parent;
	u8 descriptor_type;
	u8 flags;
	u16 aml_opcode;
	u8 *aml;
	union acpi_parse_object *next;
	struct acpi_namespace_node *node;
	union acpi_parse_value value;
	u8 arg_list_length;
};

struct acpi_parse_obj_named {
	union acpi_parse_object *parent;
	u8 descriptor_type;
	u8 flags;
	u16 aml_opcode;
	u8 *aml;
	union acpi_parse_object *next;
	struct acpi_namespace_node *node;
	union acpi_parse_value value;
	u8 arg_list_length;
	char *path;
	u8 *data;
	u32 length;
	u32 name;
};

struct acpi_parse_obj_asl {
	union acpi_parse_object *parent;
	u8 descriptor_type;
	u8 flags;
	u16 aml_opcode;
	u8 *aml;
	union acpi_parse_object *next;
	struct acpi_namespace_node *node;
	union acpi_parse_value value;
	u8 arg_list_length;
	union acpi_parse_object *child;
	union acpi_parse_object *parent_method;
	char *filename;
	u8 file_changed;
	char *parent_filename;
	char *external_name;
	char *namepath;
	char name_seg[4];
	u32 extra_value;
	u32 column;
	u32 line_number;
	u32 logical_line_number;
	u32 logical_byte_offset;
	u32 end_line;
	u32 end_logical_line;
	u32 acpi_btype;
	u32 aml_length;
	u32 aml_subtree_length;
	u32 final_aml_length;
	u32 final_aml_offset;
	u32 compile_flags;
	u16 parse_opcode;
	u8 aml_opcode_length;
	u8 aml_pkg_len_bytes;
	u8 extra;
	char parse_op_name[20];
};

union acpi_parse_object {
	struct acpi_parse_obj_common common;
	struct acpi_parse_obj_named named;
	struct acpi_parse_obj_asl asl;
};

struct acpi_scope_state {
	void *next;
	u8 descriptor_type;
	u8 flags;
	u16 value;
	u16 state;
	struct acpi_namespace_node *node;
};

struct acpi_pscope_state {
	void *next;
	u8 descriptor_type;
	u8 flags;
	u16 value;
	u16 state;
	u32 arg_count;
	union acpi_parse_object *op;
	u8 *arg_end;
	u8 *pkg_end;
	u32 arg_list;
};

struct acpi_thread_state {
	void *next;
	u8 descriptor_type;
	u8 flags;
	u16 value;
	u16 state;
	u8 current_sync_level;
	struct acpi_walk_state *walk_state_list;
	union acpi_operand_object *acquired_mutex_list;
	u64 thread_id;
};

struct acpi_result_values {
	void *next;
	u8 descriptor_type;
	u8 flags;
	u16 value;
	u16 state;
	union acpi_operand_object *obj_desc[8];
};

struct acpi_global_notify_handler {
	acpi_notify_handler handler;
	void *context;
};

struct acpi_notify_info {
	void *next;
	u8 descriptor_type;
	u8 flags;
	u16 value;
	u16 state;
	u8 handler_list_id;
	struct acpi_namespace_node *node;
	union acpi_operand_object *handler_list_head;
	struct acpi_global_notify_handler *global;
};

union acpi_generic_state {
	struct acpi_common_state common;
	struct acpi_control_state control;
	struct acpi_update_state update;
	struct acpi_scope_state scope;
	struct acpi_pscope_state parse_scope;
	struct acpi_pkg_state pkg;
	struct acpi_thread_state thread;
	struct acpi_result_values results;
	struct acpi_notify_info notify;
};

struct acpi_address_range {
	struct acpi_address_range *next;
	struct acpi_namespace_node *region_node;
	acpi_physical_address start_address;
	acpi_physical_address end_address;
};

struct acpi_opcode_info {
	u32 parse_args;
	u32 runtime_args;
	u16 flags;
	u8 object_type;
	u8 class;
	u8 type;
};

struct acpi_comment_node {
	char *comment;
	struct acpi_comment_node *next;
};

struct acpi_bit_register_info {
	u8 parent_register;
	u8 bit_position;
	u16 access_bit_mask;
};

struct acpi_interface_info {
	char *name;
	struct acpi_interface_info *next;
	u8 flags;
	u8 value;
};

struct acpi_os_dpc {
	acpi_osd_exec_callback function;
	void *context;
	struct work_struct work;
};

struct acpi_ioremap {
	struct list_head list;
	void *virt;
	acpi_physical_address phys;
	acpi_size size;
	long unsigned int refcount;
};

struct acpi_hp_work {
	struct work_struct work;
	struct acpi_device___5 *adev;
	u32 src;
};

struct acpi_pld_info {
	u8 revision;
	u8 ignore_color;
	u8 red;
	u8 green;
	u8 blue;
	u16 width;
	u16 height;
	u8 user_visible;
	u8 dock;
	u8 lid;
	u8 panel;
	u8 vertical_position;
	u8 horizontal_position;
	u8 shape;
	u8 group_orientation;
	u8 group_token;
	u8 group_position;
	u8 bay;
	u8 ejectable;
	u8 ospm_eject_required;
	u8 cabinet_number;
	u8 card_cage_number;
	u8 reference;
	u8 rotation;
	u8 order;
	u8 reserved;
	u16 vertical_offset;
	u16 horizontal_offset;
};

struct acpi_handle_list {
	u32 count;
	acpi_handle handles[10];
};

enum acpi_predicate {
	all_versions = 0,
	less_than_or_equal = 1,
	equal = 2,
	greater_than_or_equal = 3,
};

struct acpi_platform_list {
	char oem_id[7];
	char oem_table_id[9];
	u32 oem_revision;
	char *table;
	enum acpi_predicate pred;
	char *reason;
	u32 data;
};

struct acpi_device_bus_id {
	char bus_id[15];
	unsigned int instance_no;
	struct list_head node;
};

struct acpi_dev_match_info {
	const char *dev_name;
	struct acpi_device___5 *adev;
	struct acpi_device_id hid[2];
	const char *uid;
	s64 hrv;
};

struct nvs_region {
	__u64 phys_start;
	__u64 size;
	struct list_head node;
};

struct acpi_hardware_id {
	struct list_head list;
	const char *id;
};

struct acpi_data_node {
	const char *name;
	acpi_handle handle;
	struct fwnode_handle___180 fwnode;
	struct fwnode_handle___180 *parent;
	struct acpi_device_data data;
	struct list_head sibling;
	struct kobject___270 kobj;
	struct completion kobj_done;
};

struct acpi_data_node_attr {
	struct attribute attr;
	ssize_t (*show)(struct acpi_data_node *, char *);
	ssize_t (*store)(struct acpi_data_node *, const char *, size_t);
};

struct module___247;

struct file___307;

struct kiocb___307;

struct poll_table_struct___184;

struct vm_area_struct___308;

struct inode___307;

struct file_lock___307;

struct page___308;

struct seq_file___259;

struct file_operations___307 {
	struct module___247 *owner;
	loff_t (*llseek)(struct file___307 *, loff_t, int);
	ssize_t (*read)(struct file___307 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___307 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___307 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___307 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___307 *, bool);
	int (*iterate)(struct file___307 *, struct dir_context *);
	int (*iterate_shared)(struct file___307 *, struct dir_context *);
	__poll_t (*poll)(struct file___307 *, struct poll_table_struct___184 *);
	long int (*unlocked_ioctl)(struct file___307 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___307 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___307 *, struct vm_area_struct___308 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___307 *, struct file___307 *);
	int (*flush)(struct file___307 *, fl_owner_t);
	int (*release)(struct inode___307 *, struct file___307 *);
	int (*fsync)(struct file___307 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___307 *, int);
	int (*lock)(struct file___307 *, int, struct file_lock___307 *);
	ssize_t (*sendpage)(struct file___307 *, struct page___308 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___307 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___307 *, int, struct file_lock___307 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___307 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___307 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___307 *, long int, struct file_lock___307 **, void **);
	long int (*fallocate)(struct file___307 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___259 *, struct file___307 *);
	ssize_t (*copy_file_range)(struct file___307 *, loff_t, struct file___307 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___307 *, loff_t, struct file___307 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___307 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___307 {
	u64 seqnum;
	struct vm_area_struct___308 *vmas[4];
};

struct page_frag___307 {
	struct page___308 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___307;

struct mem_cgroup___118;

struct cred___285;

struct nsproxy___252;

struct bio_list___150;

struct backing_dev_info___150;

struct css_set___209;

struct vm_struct___223;

struct task_struct___308 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___308 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___307 *mm;
	struct mm_struct___307 *active_mm;
	struct vmacache___307 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___308 *real_parent;
	struct task_struct___308 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___308 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___118 *active_memcg;
	long int rh_reserved2;
	struct pid___204 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___204 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___204 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___285 *ptracer_cred;
	const struct cred___285 *real_cred;
	const struct cred___285 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___252 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___308 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___150 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___150 *backing_dev_info;
	struct io_context___82 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___209 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___307 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___118 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___308 *oom_reaper_list;
	struct vm_struct___223 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___131 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___308 *pgtable_t___307;

struct address_space___306;

struct dev_pagemap___296;

struct page___308 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___306 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___308 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___307 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___307 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___296 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___118 *mem_cgroup;
};

struct pglist_data___307;

struct lruvec___307 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___307 *pgdat;
};

struct zone___307 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___307 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___307 {
	struct zone___307 *zone;
	int zone_idx;
};

struct zonelist___307 {
	struct zoneref___307 _zonerefs[25];
};

struct pglist_data___307 {
	struct zone___307 node_zones[3];
	struct zonelist___307 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___308 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___308 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___307 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___308 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___308 *owner;
};

struct secondary_data___308 {
	void *stack;
	struct task_struct___308 *task;
	long int status;
};

struct blocking_notifier_head___307 {
	struct rw_semaphore___308 rwsem;
	struct notifier_block *head;
};

struct cgroup___209;

struct cgroup_subsys___209;

struct cgroup_subsys_state___209 {
	struct cgroup___209 *cgroup;
	struct cgroup_subsys___209 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___209 *parent;
};

struct kernfs_node___301;

struct cgroup_file___209 {
	struct kernfs_node___301 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___118;

struct mem_cgroup___118 {
	struct cgroup_subsys_state___209 css;
	struct mem_cgroup_id___2 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___209 events_file;
	struct cgroup_file___209 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___308 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___118 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct key___285;

struct ucounts___224;

struct user_namespace___224 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___224 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___9 ns;
	long unsigned int flags;
	struct key___285 *persistent_keyring_register;
	struct rw_semaphore___308 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___224 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_root___300;

struct kernfs_elem_dir___300 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___300 *root;
};

struct kernfs_syscall_ops___300;

struct kernfs_root___300 {
	struct kernfs_node___301 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___300 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___300 {
	struct kernfs_node___301 *target_kn;
};

struct kernfs_ops___300;

struct kernfs_elem_attr___300 {
	const struct kernfs_ops___300 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___301 *notify_next;
};

struct kernfs_node___301 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___301 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___300 dir;
		struct kernfs_elem_symlink___300 symlink;
		struct kernfs_elem_attr___300 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___300;

struct kernfs_ops___300 {
	int (*open)(struct kernfs_open_file___300 *);
	void (*release)(struct kernfs_open_file___300 *);
	int (*seq_show)(struct seq_file___259 *, void *);
	void * (*seq_start)(struct seq_file___259 *, loff_t *);
	void * (*seq_next)(struct seq_file___259 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___259 *, void *);
	ssize_t (*read)(struct kernfs_open_file___300 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___300 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___300 *, struct vm_area_struct___308 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___300 *, struct poll_table_struct___184 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___300 {
	int (*remount_fs)(struct kernfs_root___300 *, int *, char *);
	int (*show_options)(struct seq_file___259 *, struct kernfs_root___300 *);
	int (*mkdir)(struct kernfs_node___301 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___301 *);
	int (*rename)(struct kernfs_node___301 *, struct kernfs_node___301 *, const char *);
	int (*show_path)(struct seq_file___259 *, struct kernfs_node___301 *, struct kernfs_root___300 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___258;

struct seq_file___259 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___258 *op;
	int poll_event;
	const struct file___307 *file;
	void *private;
};

struct vm_operations_struct___296;

struct kernfs_open_file___300 {
	struct kernfs_node___301 *kn;
	struct file___307 *file;
	struct seq_file___259 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___296 *vm_ops;
};

struct dentry___307;

struct path___307 {
	struct vfsmount *mnt;
	struct dentry___307 *dentry;
};

struct file___307 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___307 f_path;
	struct inode___307 *f_inode;
	const struct file_operations___307 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___204 f_owner;
	const struct cred___285 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___306 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___296;

struct vm_operations_struct___296 {
	void (*open)(struct vm_area_struct___308 *);
	void (*close)(struct vm_area_struct___308 *);
	int (*split)(struct vm_area_struct___308 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___308 *);
	vm_fault_t (*fault)(struct vm_fault___296 *);
	vm_fault_t (*huge_fault)(struct vm_fault___296 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___296 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___308 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___296 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___296 *);
	int (*access)(struct vm_area_struct___308 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___308 *);
	int (*set_policy)(struct vm_area_struct___308 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___308 *, long unsigned int);
	struct page___308 * (*find_special_page)(struct vm_area_struct___308 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___187)(struct file___307 *, wait_queue_head_t *, struct poll_table_struct___184 *);

struct poll_table_struct___184 {
	poll_queue_proc___187 _qproc;
	__poll_t _key;
};

struct vm_area_struct___308 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___308 *vm_next;
	struct vm_area_struct___308 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___307 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___296 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___307 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___294;

struct bin_attribute___270;

struct attribute_group___271 {
	const char *name;
	umode_t (*is_visible)(struct kobject___294 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___294 *, struct bin_attribute___270 *, int);
	struct attribute **attrs;
	struct bin_attribute___270 **bin_attrs;
};

struct kset___293;

struct kobj_type___293;

struct kobject___294 {
	const char *name;
	struct list_head entry;
	struct kobject___294 *parent;
	struct kset___293 *kset;
	struct kobj_type___293 *ktype;
	struct kernfs_node___301 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___270 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___307 *, struct kobject___294 *, struct bin_attribute___270 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___307 *, struct kobject___294 *, struct bin_attribute___270 *, char *, loff_t, size_t);
	int (*mmap)(struct file___307 *, struct kobject___294 *, struct bin_attribute___270 *, struct vm_area_struct___308 *);
};

struct sysfs_ops___293 {
	ssize_t (*show)(struct kobject___294 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___294 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___293;

struct kset___293 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___294 kobj;
	const struct kset_uevent_ops___293 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___293 {
	void (*release)(struct kobject___294 *);
	const struct sysfs_ops___293 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___25 * (*child_ns_type)(struct kobject___294 *);
	const void * (*namespace)(struct kobject___294 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___293 {
	int (* const filter)(struct kset___293 *, struct kobject___294 *);
	const char * (* const name)(struct kset___293 *, struct kobject___294 *);
	int (* const uevent)(struct kset___293 *, struct kobject___294 *, struct kobj_uevent_env *);
};

struct kobj_attribute___286 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___294 *, struct kobj_attribute___286 *, char *);
	ssize_t (*store)(struct kobject___294 *, struct kobj_attribute___286 *, const char *, size_t);
};

struct device___272;

struct dev_pm_ops___272 {
	int (*prepare)(struct device___272 *);
	void (*complete)(struct device___272 *);
	int (*suspend)(struct device___272 *);
	int (*resume)(struct device___272 *);
	int (*freeze)(struct device___272 *);
	int (*thaw)(struct device___272 *);
	int (*poweroff)(struct device___272 *);
	int (*restore)(struct device___272 *);
	int (*suspend_late)(struct device___272 *);
	int (*resume_early)(struct device___272 *);
	int (*freeze_late)(struct device___272 *);
	int (*thaw_early)(struct device___272 *);
	int (*poweroff_late)(struct device___272 *);
	int (*restore_early)(struct device___272 *);
	int (*suspend_noirq)(struct device___272 *);
	int (*resume_noirq)(struct device___272 *);
	int (*freeze_noirq)(struct device___272 *);
	int (*thaw_noirq)(struct device___272 *);
	int (*poweroff_noirq)(struct device___272 *);
	int (*restore_noirq)(struct device___272 *);
	int (*runtime_suspend)(struct device___272 *);
	int (*runtime_resume)(struct device___272 *);
	int (*runtime_idle)(struct device___272 *);
};

struct dev_pm_qos___11;

struct dev_pm_info___272 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___272 *, s32);
	struct dev_pm_qos___11 *qos;
};

struct device_type___272;

struct bus_type___272;

struct device_driver___272;

struct dev_pm_domain___272;

struct device_node___64;

struct fwnode_handle___206;

struct class___272;

struct device___272 {
	struct device___272 *parent;
	struct device_private *p;
	struct kobject___294 kobj;
	const char *init_name;
	const struct device_type___272 *type;
	struct mutex mutex;
	struct bus_type___272 *bus;
	struct device_driver___272 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___272 power;
	struct dev_pm_domain___272 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___64 *of_node;
	struct fwnode_handle___206 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___272 *class;
	const struct attribute_group___271 **groups;
	void (*release)(struct device___272 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct pm_domain_data {
	struct list_head list_node;
	struct device___272 *dev;
};

struct pm_qos_constraints___11 {
	struct plist_head list;
	s32 target_value;
	s32 default_value;
	s32 no_constraint_value;
	enum pm_qos_type type;
	struct blocking_notifier_head___307 *notifiers;
};

struct dev_pm_qos_request___11;

struct dev_pm_qos___11 {
	struct pm_qos_constraints___11 resume_latency;
	struct pm_qos_constraints___11 latency_tolerance;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___11 *resume_latency_req;
	struct dev_pm_qos_request___11 *latency_tolerance_req;
	struct dev_pm_qos_request___11 *flags_req;
};

struct dev_pm_domain___272 {
	struct dev_pm_ops___272 ops;
	void (*detach)(struct device___272 *, bool);
	int (*activate)(struct device___272 *);
	void (*sync)(struct device___272 *);
	void (*dismiss)(struct device___272 *);
};

struct user_struct___285 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___285 *uid_keyring;
	struct key___285 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___307;

struct mm_struct___307 {
	struct {
		struct vm_area_struct___308 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___307 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___308 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___307 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___308 *owner;
		struct user_namespace___224 *user_ns;
		struct file___307 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___307 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___285 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___285 *session_keyring;
	struct key___285 *process_keyring;
	struct key___285 *thread_keyring;
	struct key___285 *request_key_auth;
	void *security;
	struct user_struct___285 *user;
	struct user_namespace___224 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___209;

struct nsproxy___252 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___209 *cgroup_ns;
};

struct bio___150;

struct bio_list___150 {
	struct bio___150 *head;
	struct bio___150 *tail;
};

struct bdi_writeback_congested___150;

struct bdi_writeback___150 {
	struct backing_dev_info___150 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___150 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___209 *memcg_css;
	struct cgroup_subsys_state___209 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___150 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___150 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___272 *dev;
	struct device___272 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___307 *debug_dir;
	struct dentry___307 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___209 {
	struct cgroup_subsys_state___209 *subsys[13];
	refcount_t refcount;
	struct css_set___209 *dom_cset;
	struct cgroup___209 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___209 *mg_src_cgrp;
	struct cgroup___209 *mg_dst_cgrp;
	struct css_set___209 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct vm_struct___223 {
	struct vm_struct___223 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___308 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bus_type___272 {
	const char *name;
	const char *dev_name;
	struct device___272 *dev_root;
	const struct attribute_group___271 **bus_groups;
	const struct attribute_group___271 **dev_groups;
	const struct attribute_group___271 **drv_groups;
	int (*match)(struct device___272 *, struct device_driver___272 *);
	int (*uevent)(struct device___272 *, struct kobj_uevent_env *);
	int (*probe)(struct device___272 *);
	int (*remove)(struct device___272 *);
	void (*shutdown)(struct device___272 *);
	int (*online)(struct device___272 *);
	int (*offline)(struct device___272 *);
	int (*suspend)(struct device___272 *, pm_message_t);
	int (*resume)(struct device___272 *);
	int (*num_vf)(struct device___272 *);
	int (*dma_configure)(struct device___272 *);
	const struct dev_pm_ops___272 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___272 {
	const char *name;
	struct bus_type___272 *bus;
	struct module___247 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___272 *);
	int (*remove)(struct device___272 *);
	void (*shutdown)(struct device___272 *);
	int (*suspend)(struct device___272 *, pm_message_t);
	int (*resume)(struct device___272 *);
	const struct attribute_group___271 **groups;
	const struct dev_pm_ops___272 *pm;
	void (*coredump)(struct device___272 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___272 {
	const char *name;
	const struct attribute_group___271 **groups;
	int (*uevent)(struct device___272 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___272 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___272 *);
	const struct dev_pm_ops___272 *pm;
};

struct module_kobject___244 {
	struct kobject___294 kobj;
	struct module___247 *mod;
	struct kobject___294 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___244 {
	struct module___247 *mod;
	struct latch_tree_node node;
};

struct module_layout___244 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___244 mtn;
};

struct module_attribute___244;

struct kernel_param___244;

struct module___247 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___244 mkobj;
	struct module_attribute___244 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___294 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___244 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___244 core_layout;
	struct module_layout___244 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct class___272 {
	const char *name;
	struct module___247 *owner;
	const struct attribute_group___271 **class_groups;
	const struct attribute_group___271 **dev_groups;
	struct kobject___294 *dev_kobj;
	int (*dev_uevent)(struct device___272 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___272 *, umode_t *);
	void (*class_release)(struct class___272 *);
	void (*dev_release)(struct device___272 *);
	int (*shutdown_pre)(struct device___272 *);
	const struct kobj_ns_type_operations___25 *ns_type;
	const void * (*namespace)(struct device___272 *);
	const struct dev_pm_ops___272 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct fwnode_operations___206;

struct fwnode_handle___206 {
	struct fwnode_handle___206 *secondary;
	const struct fwnode_operations___206 *ops;
};

struct property___61;

struct device_node___64 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___206 fwnode;
	struct property___61 *properties;
	struct property___61 *deadprops;
	struct device_node___64 *parent;
	struct device_node___64 *child;
	struct device_node___64 *sibling;
	struct kobject___294 kobj;
	long unsigned int _flags;
	void *data;
};

struct fwnode_reference_args___206;

struct fwnode_endpoint___206;

struct fwnode_operations___206 {
	struct fwnode_handle___206 * (*get)(struct fwnode_handle___206 *);
	void (*put)(struct fwnode_handle___206 *);
	bool (*device_is_available)(const struct fwnode_handle___206 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___206 *, const struct device___272 *);
	bool (*property_present)(const struct fwnode_handle___206 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___206 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___206 *, const char *, const char **, size_t);
	struct fwnode_handle___206 * (*get_parent)(const struct fwnode_handle___206 *);
	struct fwnode_handle___206 * (*get_next_child_node)(const struct fwnode_handle___206 *, struct fwnode_handle___206 *);
	struct fwnode_handle___206 * (*get_named_child_node)(const struct fwnode_handle___206 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___206 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___206 *);
	struct fwnode_handle___206 * (*graph_get_next_endpoint)(const struct fwnode_handle___206 *, struct fwnode_handle___206 *);
	struct fwnode_handle___206 * (*graph_get_remote_endpoint)(const struct fwnode_handle___206 *);
	struct fwnode_handle___206 * (*graph_get_port_parent)(struct fwnode_handle___206 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___206 *, struct fwnode_endpoint___206 *);
};

struct fwnode_endpoint___206 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___206 *local_fwnode;
};

struct fwnode_reference_args___206 {
	struct fwnode_handle___206 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct kernel_param_ops___244 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___244 *);
	int (*get)(char *, const struct kernel_param___244 *);
	void (*free)(void *);
};

struct kparam_array___244;

struct kernel_param___244 {
	const char *name;
	struct module___247 *mod;
	const struct kernel_param_ops___244 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___244 *arr;
	};
};

struct kparam_array___244 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___244 *ops;
	void *elem;
};

struct module_attribute___244 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___244 *, struct module_kobject___244 *, char *);
	ssize_t (*store)(struct module_attribute___244 *, struct module_kobject___244 *, const char *, size_t);
	void (*setup)(struct module___247 *, const char *);
	int (*test)(struct module___247 *);
	void (*free)(struct module___247 *);
};

struct dentry_operations___306;

struct super_block___306;

struct dentry___307 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___307 *d_parent;
	struct qstr d_name;
	struct inode___307 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___306 *d_op;
	struct super_block___306 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___306;

struct address_space___306 {
	struct inode___307 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___308 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___306 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___306;

struct block_device___306;

struct cdev___57;

struct inode___307 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___306 *i_op;
	struct super_block___306 *i_sb;
	struct address_space___306 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___308 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___150 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___307 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___306 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___306 *i_bdev;
		struct cdev___57 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___306 {
	int (*d_revalidate)(struct dentry___307 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___307 *, unsigned int);
	int (*d_hash)(const struct dentry___307 *, struct qstr *);
	int (*d_compare)(const struct dentry___307 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___307 *);
	int (*d_init)(struct dentry___307 *);
	void (*d_release)(struct dentry___307 *);
	void (*d_prune)(struct dentry___307 *);
	void (*d_iput)(struct dentry___307 *, struct inode___307 *);
	char * (*d_dname)(struct dentry___307 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___307 *);
	int (*d_manage)(const struct path___307 *, bool);
	struct dentry___307 * (*d_real)(struct dentry___307 *, const struct inode___307 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___306;

struct mem_dqinfo___306 {
	struct quota_format_type___306 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___306;

struct quota_info___306 {
	unsigned int flags;
	struct rw_semaphore___308 dqio_sem;
	struct inode___307 *files[3];
	struct mem_dqinfo___306 info[3];
	const struct quota_format_ops___306 *ops[3];
};

struct rcuwait___306 {
	struct task_struct___308 *task;
};

struct percpu_rw_semaphore___306 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___308 rw_sem;
	struct rcuwait___306 writer;
	int readers_block;
};

struct sb_writers___306 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___306 rw_sem[3];
};

struct shrink_control___118;

struct shrinker___118 {
	long unsigned int (*count_objects)(struct shrinker___118 *, struct shrink_control___118 *);
	long unsigned int (*scan_objects)(struct shrinker___118 *, struct shrink_control___118 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___306;

struct super_operations___306;

struct dquot_operations___306;

struct quotactl_ops___306;

struct super_block___306 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___306 *s_type;
	const struct super_operations___306 *s_op;
	const struct dquot_operations___306 *dq_op;
	const struct quotactl_ops___306 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___307 *s_root;
	struct rw_semaphore___308 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___306 *s_bdev;
	struct backing_dev_info___150 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___306 s_dquot;
	struct sb_writers___306 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___306 *s_d_op;
	int cleancache_poolid;
	struct shrinker___118 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___224 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___118 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___118 *memcg;
};

typedef int (*dev_page_fault_t___296)(struct vm_area_struct___308 *, long unsigned int, const struct page___308 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___296)(struct page___308 *, void *);

struct dev_pagemap___296 {
	dev_page_fault_t___296 page_fault;
	dev_page_free_t___296 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___272 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___307 {
	struct task_struct___308 *task;
	struct core_thread___307 *next;
};

struct core_state___307 {
	atomic_t nr_threads;
	struct core_thread___307 dumper;
	struct completion startup;
};

struct vm_fault___296 {
	struct vm_area_struct___308 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___308 *cow_page;
	struct mem_cgroup___118 *memcg;
	struct page___308 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___307 prealloc_pte;
};

struct kiocb___307 {
	struct file___307 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___307 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___306 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___307 *ia_file;
};

struct dquot___306 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___306 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___306 {
	int qf_fmt_id;
	const struct quota_format_ops___306 *qf_ops;
	struct module___247 *qf_owner;
	struct quota_format_type___306 *qf_next;
};

struct quota_format_ops___306 {
	int (*check_quota_file)(struct super_block___306 *, int);
	int (*read_file_info)(struct super_block___306 *, int);
	int (*write_file_info)(struct super_block___306 *, int);
	int (*free_file_info)(struct super_block___306 *, int);
	int (*read_dqblk)(struct dquot___306 *);
	int (*commit_dqblk)(struct dquot___306 *);
	int (*release_dqblk)(struct dquot___306 *);
	int (*get_next_id)(struct super_block___306 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___306 {
	int (*write_dquot)(struct dquot___306 *);
	struct dquot___306 * (*alloc_dquot)(struct super_block___306 *, int);
	void (*destroy_dquot)(struct dquot___306 *);
	int (*acquire_dquot)(struct dquot___306 *);
	int (*release_dquot)(struct dquot___306 *);
	int (*mark_dirty)(struct dquot___306 *);
	int (*write_info)(struct super_block___306 *, int);
	qsize_t * (*get_reserved_space)(struct inode___307 *);
	int (*get_projid)(struct inode___307 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___307 *, qsize_t *);
	int (*get_next_id)(struct super_block___306 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___306 {
	int (*quota_on)(struct super_block___306 *, int, int, const struct path___307 *);
	int (*quota_off)(struct super_block___306 *, int);
	int (*quota_enable)(struct super_block___306 *, unsigned int);
	int (*quota_disable)(struct super_block___306 *, unsigned int);
	int (*quota_sync)(struct super_block___306 *, int);
	int (*set_info)(struct super_block___306 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___306 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___306 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___306 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___306 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___306 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___133;

struct swap_info_struct___76;

struct address_space_operations___306 {
	int (*writepage)(struct page___308 *, struct writeback_control___133 *);
	int (*readpage)(struct file___307 *, struct page___308 *);
	int (*writepages)(struct address_space___306 *, struct writeback_control___133 *);
	int (*set_page_dirty)(struct page___308 *);
	int (*readpages)(struct file___307 *, struct address_space___306 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___307 *, struct address_space___306 *, loff_t, unsigned int, unsigned int, struct page___308 **, void **);
	int (*write_end)(struct file___307 *, struct address_space___306 *, loff_t, unsigned int, unsigned int, struct page___308 *, void *);
	sector_t (*bmap)(struct address_space___306 *, sector_t);
	void (*invalidatepage)(struct page___308 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___308 *, gfp_t);
	void (*freepage)(struct page___308 *);
	ssize_t (*direct_IO)(struct kiocb___307 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___306 *, struct page___308 *, struct page___308 *, enum migrate_mode);
	bool (*isolate_page)(struct page___308 *, isolate_mode_t);
	void (*putback_page)(struct page___308 *);
	int (*launder_page)(struct page___308 *);
	int (*is_partially_uptodate)(struct page___308 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___308 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___306 *, struct page___308 *);
	int (*swap_activate)(struct swap_info_struct___76 *, struct file___307 *, sector_t *);
	void (*swap_deactivate)(struct file___307 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___133 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___150 *wb;
	struct inode___307 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct swap_info_struct___76 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___306 *bdev;
	struct file___307 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___306 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___307 *bd_inode;
	struct super_block___306 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___306 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___150 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___57 {
	struct kobject___294 kobj;
	struct module___247 *owner;
	const struct file_operations___307 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___306 {
	struct dentry___307 * (*lookup)(struct inode___307 *, struct dentry___307 *, unsigned int);
	const char * (*get_link)(struct dentry___307 *, struct inode___307 *, struct delayed_call *);
	int (*permission)(struct inode___307 *, int);
	struct posix_acl * (*get_acl)(struct inode___307 *, int);
	int (*readlink)(struct dentry___307 *, char *, int);
	int (*create)(struct inode___307 *, struct dentry___307 *, umode_t, bool);
	int (*link)(struct dentry___307 *, struct inode___307 *, struct dentry___307 *);
	int (*unlink)(struct inode___307 *, struct dentry___307 *);
	int (*symlink)(struct inode___307 *, struct dentry___307 *, const char *);
	int (*mkdir)(struct inode___307 *, struct dentry___307 *, umode_t);
	int (*rmdir)(struct inode___307 *, struct dentry___307 *);
	int (*mknod)(struct inode___307 *, struct dentry___307 *, umode_t, dev_t);
	int (*rename)(struct inode___307 *, struct dentry___307 *, struct inode___307 *, struct dentry___307 *, unsigned int);
	int (*setattr)(struct dentry___307 *, struct iattr___306 *);
	int (*getattr)(const struct path___307 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___307 *, char *, size_t);
	int (*fiemap)(struct inode___307 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___307 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___307 *, struct dentry___307 *, struct file___307 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___307 *, struct dentry___307 *, umode_t);
	int (*set_acl)(struct inode___307 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___306 {
	void (*fl_copy_lock)(struct file_lock___307 *, struct file_lock___307 *);
	void (*fl_release_private)(struct file_lock___307 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___306;

struct lock_manager_operations___306;

struct file_lock___307 {
	struct file_lock___307 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___307 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___306 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___306 *fl_ops;
	const struct lock_manager_operations___306 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___306 {
	int (*lm_compare_owner)(struct file_lock___307 *, struct file_lock___307 *);
	long unsigned int (*lm_owner_key)(struct file_lock___307 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___307 *);
	int (*lm_grant)(struct file_lock___307 *, int);
	bool (*lm_break)(struct file_lock___307 *);
	int (*lm_change)(struct file_lock___307 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___307 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___306 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___306 *fa_next;
	struct file___307 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___306 {
	const char *name;
	int fs_flags;
	struct dentry___307 * (*mount)(struct file_system_type___306 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___306 *);
	struct module___247 *owner;
	struct file_system_type___306 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___306 {
	struct inode___307 * (*alloc_inode)(struct super_block___306 *);
	void (*destroy_inode)(struct inode___307 *);
	void (*dirty_inode)(struct inode___307 *, int);
	int (*write_inode)(struct inode___307 *, struct writeback_control___133 *);
	int (*drop_inode)(struct inode___307 *);
	void (*evict_inode)(struct inode___307 *);
	void (*put_super)(struct super_block___306 *);
	int (*sync_fs)(struct super_block___306 *, int);
	int (*freeze_super)(struct super_block___306 *);
	int (*freeze_fs)(struct super_block___306 *);
	int (*thaw_super)(struct super_block___306 *);
	int (*unfreeze_fs)(struct super_block___306 *);
	int (*statfs)(struct dentry___307 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___306 *, int *, char *);
	void (*umount_begin)(struct super_block___306 *);
	int (*show_options)(struct seq_file___259 *, struct dentry___307 *);
	int (*show_devname)(struct seq_file___259 *, struct dentry___307 *);
	int (*show_path)(struct seq_file___259 *, struct dentry___307 *);
	int (*show_stats)(struct seq_file___259 *, struct dentry___307 *);
	ssize_t (*quota_read)(struct super_block___306 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___306 *, int, const char *, size_t, loff_t);
	struct dquot___306 ** (*get_dquots)(struct inode___307 *);
	int (*bdev_try_to_free_page)(struct super_block___306 *, struct page___308 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___306 *, struct shrink_control___118 *);
	long int (*free_cached_objects)(struct super_block___306 *, struct shrink_control___118 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___150(struct bio___150 *);

struct bio_vec___151 {
	struct page___308 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___150;

struct bio_set___150;

struct bio___150 {
	struct bio___150 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___150 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___150 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___151 *bi_io_vec;
	struct bio_set___150 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___151 bi_inline_vecs[0];
};

struct acpi_device___8;

struct acpi_hotplug_profile___8 {
	struct kobject___294 kobj;
	int (*scan_dependent)(struct acpi_device___8 *);
	void (*notify_online)(struct acpi_device___8 *);
	bool enabled: 1;
	bool demand_offline: 1;
};

struct acpi_device_wakeup_context___8 {
	void (*func)(struct acpi_device_wakeup_context___8 *);
	struct device___272 *dev;
};

struct acpi_device_wakeup___8 {
	acpi_handle gpe_device;
	u64 gpe_number;
	u64 sleep_state;
	struct list_head resources;
	struct acpi_device_wakeup_flags flags;
	struct acpi_device_wakeup_context___8 context;
	struct wakeup_source *ws;
	int prepare_count;
	int enable_count;
};

struct acpi_scan_handler___8;

struct acpi_hotplug_context___8;

struct acpi_driver___8;

struct acpi_device___8 {
	int device_type;
	acpi_handle handle;
	struct fwnode_handle___206 fwnode;
	struct acpi_device___8 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup___8 wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_device_data data;
	struct acpi_scan_handler___8 *handler;
	struct acpi_hotplug_context___8 *hp;
	struct acpi_driver___8 *driver;
	const struct acpi_gpio_mapping *driver_gpios;
	void *driver_data;
	struct device___272 dev;
	unsigned int physical_node_count;
	unsigned int dep_unmet;
	struct list_head physical_node_list;
	struct mutex physical_node_lock;
	void (*remove)(struct acpi_device___8 *);
};

struct acpi_scan_handler___8 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	bool (*match)(const char *, const struct acpi_device_id **);
	int (*attach)(struct acpi_device___8 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___8 *);
	void (*bind)(struct device___272 *);
	void (*unbind)(struct device___272 *);
	struct acpi_hotplug_profile___8 hotplug;
};

struct acpi_hotplug_context___8 {
	struct acpi_device___8 *self;
	int (*notify)(struct acpi_device___8 *, u32);
	void (*uevent)(struct acpi_device___8 *, u32);
	void (*fixup)(struct acpi_device___8 *);
};

typedef int (*acpi_op_add___8)(struct acpi_device___8 *);

typedef int (*acpi_op_remove___8)(struct acpi_device___8 *);

typedef void (*acpi_op_notify___8)(struct acpi_device___8 *, u32);

struct acpi_device_ops___8 {
	acpi_op_add___8 add;
	acpi_op_remove___8 remove;
	acpi_op_notify___8 notify;
};

struct acpi_driver___8 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___8 ops;
	struct device_driver___272 drv;
	struct module___247 *owner;
};

typedef int (*key_restrict_link_func_t___286)(struct key___285 *, const struct key_type *, const union key_payload *, struct key___285 *);

struct key_restriction___285;

struct key___285 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___308 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___285 *restrict_link;
};

struct key_restriction___285 {
	key_restrict_link_func_t___286 check;
	struct key___285 *key;
	struct key_type *keytype;
};

struct seq_operations___258 {
	void * (*start)(struct seq_file___259 *, loff_t *);
	void (*stop)(struct seq_file___259 *, void *);
	void * (*next)(struct seq_file___259 *, void *, loff_t *);
	int (*show)(struct seq_file___259 *, void *);
};

typedef void compound_page_dtor___296(struct page___308 *);

struct dev_pm_qos_request___11 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___272 *dev;
};

struct property___61 {
	char *name;
	int length;
	void *value;
	struct property___61 *next;
	long unsigned int _flags;
	struct bin_attribute___270 attr;
};

struct dev_power_governor {
	bool (*power_down_ok)(struct dev_pm_domain___272 *);
	bool (*suspend_ok)(struct device___272 *);
};

struct cgroup_namespace___209 {
	refcount_t count;
	struct ns_common___9 ns;
	struct user_namespace___224 *user_ns;
	struct ucounts___224 *ucounts;
	struct css_set___209 *root_cset;
};

struct ucounts___224 {
	struct hlist_node node;
	struct user_namespace___224 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___210;

struct bpf_map_ops___209 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___210 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___210 *, struct file___307 *);
	void (*map_free)(struct bpf_map___210 *);
	int (*map_get_next_key)(struct bpf_map___210 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___210 *);
	void * (*map_lookup_elem)(struct bpf_map___210 *, void *);
	int (*map_update_elem)(struct bpf_map___210 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___210 *, void *);
	int (*map_push_elem)(struct bpf_map___210 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___210 *, void *);
	int (*map_peek_elem)(struct bpf_map___210 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___210 *, struct file___307 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___210 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___210 *, void *, struct seq_file___259 *);
	int (*map_check_btf)(const struct bpf_map___210 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___210 {
	const struct bpf_map_ops___209 *ops;
	struct bpf_map___210 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___285 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___209;

typedef void (*kthread_work_func_t___209)(struct kthread_work___209 *);

struct kthread_worker___209;

struct kthread_work___209 {
	struct list_head node;
	kthread_work_func_t___209 func;
	struct kthread_worker___209 *worker;
	int canceling;
};

struct kthread_worker___209 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___308 *task;
	struct kthread_work___209 *current_work;
};

struct kthread_delayed_work___209 {
	struct kthread_work___209 work;
	struct timer_list timer;
};

struct psi_group___209 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___209 *poll_kworker;
	struct kthread_delayed_work___209 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___209;

struct cgroup_rstat_cpu___209;

struct cgroup___209 {
	struct cgroup_subsys_state___209 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___301 *kn;
	struct cgroup_file___209 procs_file;
	struct cgroup_file___209 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___209 *subsys[13];
	struct cgroup_root___209 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___209 *dom_cgrp;
	struct cgroup_rstat_cpu___209 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___35 bpf;
	atomic_t congestion_count;
	struct cgroup___209 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___209 psi;
	int ancestor_ids[0];
};

struct cftype___209;

struct cgroup_subsys___209 {
	struct cgroup_subsys_state___209 * (*css_alloc)(struct cgroup_subsys_state___209 *);
	int (*css_online)(struct cgroup_subsys_state___209 *);
	void (*css_offline)(struct cgroup_subsys_state___209 *);
	void (*css_released)(struct cgroup_subsys_state___209 *);
	void (*css_free)(struct cgroup_subsys_state___209 *);
	void (*css_reset)(struct cgroup_subsys_state___209 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___209 *, int);
	int (*css_extra_stat_show)(struct seq_file___259 *, struct cgroup_subsys_state___209 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___308 *);
	void (*cancel_fork)(struct task_struct___308 *);
	void (*fork)(struct task_struct___308 *);
	void (*exit)(struct task_struct___308 *);
	void (*free)(struct task_struct___308 *);
	void (*bind)(struct cgroup_subsys_state___209 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___209 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___209 *dfl_cftypes;
	struct cftype___209 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___209 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___209 *updated_children;
	struct cgroup___209 *updated_next;
};

struct cgroup_root___209 {
	struct kernfs_root___300 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___209 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___209 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___209 *ss;
	struct list_head node;
	struct kernfs_ops___300 *kf_ops;
	int (*open)(struct kernfs_open_file___300 *);
	void (*release)(struct kernfs_open_file___300 *);
	u64 (*read_u64)(struct cgroup_subsys_state___209 *, struct cftype___209 *);
	s64 (*read_s64)(struct cgroup_subsys_state___209 *, struct cftype___209 *);
	int (*seq_show)(struct seq_file___259 *, void *);
	void * (*seq_start)(struct seq_file___259 *, loff_t *);
	void * (*seq_next)(struct seq_file___259 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___259 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___209 *, struct cftype___209 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___209 *, struct cftype___209 *, s64);
	ssize_t (*write)(struct kernfs_open_file___300 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___300 *, struct poll_table_struct___184 *);
};

struct bdi_writeback_congested___150 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___150 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___150 {
	struct bio___150 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___151 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___151 bip_inline_vecs[0];
};

struct bio_set___150 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___150 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___118 {
	struct mem_cgroup___118 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___118 {
	struct lruvec___307 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___118 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___118 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct node___183 {
	struct device___272 dev;
};

struct module___248;

struct file___308;

struct kiocb___308;

struct poll_table_struct___185;

struct vm_area_struct___309;

struct inode___308;

struct file_lock___308;

struct page___309;

struct seq_file___260;

struct file_operations___308 {
	struct module___248 *owner;
	loff_t (*llseek)(struct file___308 *, loff_t, int);
	ssize_t (*read)(struct file___308 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___308 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___308 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___308 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___308 *, bool);
	int (*iterate)(struct file___308 *, struct dir_context *);
	int (*iterate_shared)(struct file___308 *, struct dir_context *);
	__poll_t (*poll)(struct file___308 *, struct poll_table_struct___185 *);
	long int (*unlocked_ioctl)(struct file___308 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___308 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___308 *, struct vm_area_struct___309 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___308 *, struct file___308 *);
	int (*flush)(struct file___308 *, fl_owner_t);
	int (*release)(struct inode___308 *, struct file___308 *);
	int (*fsync)(struct file___308 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___308 *, int);
	int (*lock)(struct file___308 *, int, struct file_lock___308 *);
	ssize_t (*sendpage)(struct file___308 *, struct page___309 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___308 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___308 *, int, struct file_lock___308 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___308 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___308 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___308 *, long int, struct file_lock___308 **, void **);
	long int (*fallocate)(struct file___308 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___260 *, struct file___308 *);
	ssize_t (*copy_file_range)(struct file___308 *, loff_t, struct file___308 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___308 *, loff_t, struct file___308 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___308 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___308 {
	u64 seqnum;
	struct vm_area_struct___309 *vmas[4];
};

struct page_frag___308 {
	struct page___309 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___308;

struct mem_cgroup___119;

struct cred___286;

struct nsproxy___253;

struct bio_list___151;

struct backing_dev_info___151;

struct css_set___210;

struct vm_struct___224;

struct task_struct___309 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___309 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___308 *mm;
	struct mm_struct___308 *active_mm;
	struct vmacache___308 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___309 *real_parent;
	struct task_struct___309 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___309 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___119 *active_memcg;
	long int rh_reserved2;
	struct pid___204 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___204 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___204 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___286 *ptracer_cred;
	const struct cred___286 *real_cred;
	const struct cred___286 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___253 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___309 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___151 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___151 *backing_dev_info;
	struct io_context___82 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___210 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___308 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___119 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___309 *oom_reaper_list;
	struct vm_struct___224 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___131 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rw_semaphore___309 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___309 *owner;
};

struct key___286;

struct ucounts___225;

struct user_namespace___225 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___225 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___9 ns;
	long unsigned int flags;
	struct key___286 *persistent_keyring_register;
	struct rw_semaphore___309 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___225 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___309 *pgtable_t___308;

struct address_space___307;

struct dev_pagemap___297;

struct page___309 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___307 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___309 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___308 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___308 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___297 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___119 *mem_cgroup;
};

struct pglist_data___308;

struct lruvec___308 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___308 *pgdat;
};

struct zone___308 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___308 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___308 {
	struct zone___308 *zone;
	int zone_idx;
};

struct zonelist___308 {
	struct zoneref___308 _zonerefs[25];
};

struct pglist_data___308 {
	struct zone___308 node_zones[3];
	struct zonelist___308 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___309 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___309 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___308 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___309 {
	void *stack;
	struct task_struct___309 *task;
	long int status;
};

struct blocking_notifier_head___308 {
	struct rw_semaphore___309 rwsem;
	struct notifier_block *head;
};

struct dentry___308;

struct path___308 {
	struct vfsmount *mnt;
	struct dentry___308 *dentry;
};

struct file___308 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___308 f_path;
	struct inode___308 *f_inode;
	const struct file_operations___308 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___204 f_owner;
	const struct cred___286 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___307 *f_mapping;
	errseq_t f_wb_err;
};

struct user_struct___286;

struct cred___286 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___286 *session_keyring;
	struct key___286 *process_keyring;
	struct key___286 *thread_keyring;
	struct key___286 *request_key_auth;
	void *security;
	struct user_struct___286 *user;
	struct user_namespace___225 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___301;

struct kernfs_elem_dir___301 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___301 *root;
};

struct kernfs_node___302;

struct kernfs_syscall_ops___301;

struct kernfs_root___301 {
	struct kernfs_node___302 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___301 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___301 {
	struct kernfs_node___302 *target_kn;
};

struct kernfs_ops___301;

struct kernfs_elem_attr___301 {
	const struct kernfs_ops___301 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___302 *notify_next;
};

struct kernfs_node___302 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___302 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___301 dir;
		struct kernfs_elem_symlink___301 symlink;
		struct kernfs_elem_attr___301 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___301;

struct kernfs_ops___301 {
	int (*open)(struct kernfs_open_file___301 *);
	void (*release)(struct kernfs_open_file___301 *);
	int (*seq_show)(struct seq_file___260 *, void *);
	void * (*seq_start)(struct seq_file___260 *, loff_t *);
	void * (*seq_next)(struct seq_file___260 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___260 *, void *);
	ssize_t (*read)(struct kernfs_open_file___301 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___301 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___301 *, struct vm_area_struct___309 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___301 *, struct poll_table_struct___185 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___301 {
	int (*remount_fs)(struct kernfs_root___301 *, int *, char *);
	int (*show_options)(struct seq_file___260 *, struct kernfs_root___301 *);
	int (*mkdir)(struct kernfs_node___302 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___302 *);
	int (*rename)(struct kernfs_node___302 *, struct kernfs_node___302 *, const char *);
	int (*show_path)(struct seq_file___260 *, struct kernfs_node___302 *, struct kernfs_root___301 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___259;

struct seq_file___260 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___259 *op;
	int poll_event;
	const struct file___308 *file;
	void *private;
};

struct vm_operations_struct___297;

struct kernfs_open_file___301 {
	struct kernfs_node___302 *kn;
	struct file___308 *file;
	struct seq_file___260 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___297 *vm_ops;
};

struct vm_fault___297;

struct vm_operations_struct___297 {
	void (*open)(struct vm_area_struct___309 *);
	void (*close)(struct vm_area_struct___309 *);
	int (*split)(struct vm_area_struct___309 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___309 *);
	vm_fault_t (*fault)(struct vm_fault___297 *);
	vm_fault_t (*huge_fault)(struct vm_fault___297 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___297 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___309 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___297 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___297 *);
	int (*access)(struct vm_area_struct___309 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___309 *);
	int (*set_policy)(struct vm_area_struct___309 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___309 *, long unsigned int);
	struct page___309 * (*find_special_page)(struct vm_area_struct___309 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___188)(struct file___308 *, wait_queue_head_t *, struct poll_table_struct___185 *);

struct poll_table_struct___185 {
	poll_queue_proc___188 _qproc;
	__poll_t _key;
};

struct vm_area_struct___309 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___309 *vm_next;
	struct vm_area_struct___309 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___308 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___297 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___308 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___295;

struct bin_attribute___271;

struct attribute_group___272 {
	const char *name;
	umode_t (*is_visible)(struct kobject___295 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___295 *, struct bin_attribute___271 *, int);
	struct attribute **attrs;
	struct bin_attribute___271 **bin_attrs;
};

struct kset___294;

struct kobj_type___294;

struct kobject___295 {
	const char *name;
	struct list_head entry;
	struct kobject___295 *parent;
	struct kset___294 *kset;
	struct kobj_type___294 *ktype;
	struct kernfs_node___302 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___271 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___308 *, struct kobject___295 *, struct bin_attribute___271 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___308 *, struct kobject___295 *, struct bin_attribute___271 *, char *, loff_t, size_t);
	int (*mmap)(struct file___308 *, struct kobject___295 *, struct bin_attribute___271 *, struct vm_area_struct___309 *);
};

struct sysfs_ops___294 {
	ssize_t (*show)(struct kobject___295 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___295 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___294;

struct kset___294 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___295 kobj;
	const struct kset_uevent_ops___294 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___294 {
	void (*release)(struct kobject___295 *);
	const struct sysfs_ops___294 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___25 * (*child_ns_type)(struct kobject___295 *);
	const void * (*namespace)(struct kobject___295 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___294 {
	int (* const filter)(struct kset___294 *, struct kobject___295 *);
	const char * (* const name)(struct kset___294 *, struct kobject___295 *);
	int (* const uevent)(struct kset___294 *, struct kobject___295 *, struct kobj_uevent_env *);
};

struct kobj_attribute___287 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___295 *, struct kobj_attribute___287 *, char *);
	ssize_t (*store)(struct kobject___295 *, struct kobj_attribute___287 *, const char *, size_t);
};

struct kernel_param___245;

struct kernel_param_ops___245 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___245 *);
	int (*get)(char *, const struct kernel_param___245 *);
	void (*free)(void *);
};

struct kparam_array___245;

struct kernel_param___245 {
	const char *name;
	struct module___248 *mod;
	const struct kernel_param_ops___245 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___245 *arr;
	};
};

struct kparam_array___245 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___245 *ops;
	void *elem;
};

struct module_kobject___245 {
	struct kobject___295 kobj;
	struct module___248 *mod;
	struct kobject___295 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___245 {
	struct module___248 *mod;
	struct latch_tree_node node;
};

struct module_layout___245 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___245 mtn;
};

struct module_attribute___245;

struct module___248 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___245 mkobj;
	struct module_attribute___245 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___295 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___245 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___245 core_layout;
	struct module_layout___245 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___245 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___245 *, struct module_kobject___245 *, char *);
	ssize_t (*store)(struct module_attribute___245 *, struct module_kobject___245 *, const char *, size_t);
	void (*setup)(struct module___248 *, const char *);
	int (*test)(struct module___248 *);
	void (*free)(struct module___248 *);
};

struct user_struct___286 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___286 *uid_keyring;
	struct key___286 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___308;

struct mm_struct___308 {
	struct {
		struct vm_area_struct___309 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___308 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___309 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___308 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___309 *owner;
		struct user_namespace___225 *user_ns;
		struct file___308 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___308 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup___210;

struct cgroup_subsys___210;

struct cgroup_subsys_state___210 {
	struct cgroup___210 *cgroup;
	struct cgroup_subsys___210 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___210 *parent;
};

struct cgroup_file___210 {
	struct kernfs_node___302 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___119;

struct mem_cgroup___119 {
	struct cgroup_subsys_state___210 css;
	struct mem_cgroup_id___2 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___210 events_file;
	struct cgroup_file___210 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___309 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___119 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cgroup_namespace___210;

struct nsproxy___253 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___210 *cgroup_ns;
};

struct bio___151;

struct bio_list___151 {
	struct bio___151 *head;
	struct bio___151 *tail;
};

struct bdi_writeback_congested___151;

struct bdi_writeback___151 {
	struct backing_dev_info___151 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___151 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___210 *memcg_css;
	struct cgroup_subsys_state___210 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___273;

struct backing_dev_info___151 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___151 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___273 *dev;
	struct device___273 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___308 *debug_dir;
	struct dentry___308 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___210 {
	struct cgroup_subsys_state___210 *subsys[13];
	refcount_t refcount;
	struct css_set___210 *dom_cset;
	struct cgroup___210 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___210 *mg_src_cgrp;
	struct cgroup___210 *mg_dst_cgrp;
	struct css_set___210 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct vm_struct___224 {
	struct vm_struct___224 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___309 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dev_pm_ops___273 {
	int (*prepare)(struct device___273 *);
	void (*complete)(struct device___273 *);
	int (*suspend)(struct device___273 *);
	int (*resume)(struct device___273 *);
	int (*freeze)(struct device___273 *);
	int (*thaw)(struct device___273 *);
	int (*poweroff)(struct device___273 *);
	int (*restore)(struct device___273 *);
	int (*suspend_late)(struct device___273 *);
	int (*resume_early)(struct device___273 *);
	int (*freeze_late)(struct device___273 *);
	int (*thaw_early)(struct device___273 *);
	int (*poweroff_late)(struct device___273 *);
	int (*restore_early)(struct device___273 *);
	int (*suspend_noirq)(struct device___273 *);
	int (*resume_noirq)(struct device___273 *);
	int (*freeze_noirq)(struct device___273 *);
	int (*thaw_noirq)(struct device___273 *);
	int (*poweroff_noirq)(struct device___273 *);
	int (*restore_noirq)(struct device___273 *);
	int (*runtime_suspend)(struct device___273 *);
	int (*runtime_resume)(struct device___273 *);
	int (*runtime_idle)(struct device___273 *);
};

struct dev_pm_info___273 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___273 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___273;

struct bus_type___273;

struct device_driver___273;

struct dev_pm_domain___273;

struct irq_domain___23;

struct dma_map_ops___90;

struct device_node___65;

struct fwnode_handle___207;

struct class___273;

struct device___273 {
	struct device___273 *parent;
	struct device_private *p;
	struct kobject___295 kobj;
	const char *init_name;
	const struct device_type___273 *type;
	struct mutex mutex;
	struct bus_type___273 *bus;
	struct device_driver___273 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___273 power;
	struct dev_pm_domain___273 *pm_domain;
	struct irq_domain___23 *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___90 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___65 *of_node;
	struct fwnode_handle___207 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___273 *class;
	const struct attribute_group___272 **groups;
	void (*release)(struct device___273 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___273 {
	struct dev_pm_ops___273 ops;
	void (*detach)(struct device___273 *, bool);
	int (*activate)(struct device___273 *);
	void (*sync)(struct device___273 *);
	void (*dismiss)(struct device___273 *);
};

struct bus_type___273 {
	const char *name;
	const char *dev_name;
	struct device___273 *dev_root;
	const struct attribute_group___272 **bus_groups;
	const struct attribute_group___272 **dev_groups;
	const struct attribute_group___272 **drv_groups;
	int (*match)(struct device___273 *, struct device_driver___273 *);
	int (*uevent)(struct device___273 *, struct kobj_uevent_env *);
	int (*probe)(struct device___273 *);
	int (*remove)(struct device___273 *);
	void (*shutdown)(struct device___273 *);
	int (*online)(struct device___273 *);
	int (*offline)(struct device___273 *);
	int (*suspend)(struct device___273 *, pm_message_t);
	int (*resume)(struct device___273 *);
	int (*num_vf)(struct device___273 *);
	int (*dma_configure)(struct device___273 *);
	const struct dev_pm_ops___273 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___273 {
	const char *name;
	struct bus_type___273 *bus;
	struct module___248 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___273 *);
	int (*remove)(struct device___273 *);
	void (*shutdown)(struct device___273 *);
	int (*suspend)(struct device___273 *, pm_message_t);
	int (*resume)(struct device___273 *);
	const struct attribute_group___272 **groups;
	const struct dev_pm_ops___273 *pm;
	void (*coredump)(struct device___273 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___273 {
	const char *name;
	const struct attribute_group___272 **groups;
	int (*uevent)(struct device___273 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___273 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___273 *);
	const struct dev_pm_ops___273 *pm;
};

struct class___273 {
	const char *name;
	struct module___248 *owner;
	const struct attribute_group___272 **class_groups;
	const struct attribute_group___272 **dev_groups;
	struct kobject___295 *dev_kobj;
	int (*dev_uevent)(struct device___273 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___273 *, umode_t *);
	void (*class_release)(struct class___273 *);
	void (*dev_release)(struct device___273 *);
	int (*shutdown_pre)(struct device___273 *);
	const struct kobj_ns_type_operations___25 *ns_type;
	const void * (*namespace)(struct device___273 *);
	const struct dev_pm_ops___273 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct irq_domain_ops___23;

struct irq_domain___23 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___23 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___207 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___2 *gc;
	struct irq_domain___23 *parent;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_direct_max_irq;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_tree_mutex;
	unsigned int linear_revmap[0];
};

struct dma_map_ops___90 {
	void * (*alloc)(struct device___273 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___273 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___273 *, struct vm_area_struct___309 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___273 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___273 *, struct page___309 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___273 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___273 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___273 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___273 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___273 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___273 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___273 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___273 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___273 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___273 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___273 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___273 *, u64);
	u64 (*get_required_mask)(struct device___273 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___207;

struct fwnode_handle___207 {
	struct fwnode_handle___207 *secondary;
	const struct fwnode_operations___207 *ops;
};

struct property___62;

struct device_node___65 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___207 fwnode;
	struct property___62 *properties;
	struct property___62 *deadprops;
	struct device_node___65 *parent;
	struct device_node___65 *child;
	struct device_node___65 *sibling;
	struct kobject___295 kobj;
	long unsigned int _flags;
	void *data;
};

struct dentry_operations___307;

struct super_block___307;

struct dentry___308 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___308 *d_parent;
	struct qstr d_name;
	struct inode___308 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___307 *d_op;
	struct super_block___307 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___307;

struct address_space___307 {
	struct inode___308 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___309 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___307 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___307;

struct block_device___307;

struct cdev___58;

struct inode___308 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___307 *i_op;
	struct super_block___307 *i_sb;
	struct address_space___307 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___309 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___151 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___308 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___307 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___307 *i_bdev;
		struct cdev___58 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___307 {
	int (*d_revalidate)(struct dentry___308 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___308 *, unsigned int);
	int (*d_hash)(const struct dentry___308 *, struct qstr *);
	int (*d_compare)(const struct dentry___308 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___308 *);
	int (*d_init)(struct dentry___308 *);
	void (*d_release)(struct dentry___308 *);
	void (*d_prune)(struct dentry___308 *);
	void (*d_iput)(struct dentry___308 *, struct inode___308 *);
	char * (*d_dname)(struct dentry___308 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___308 *);
	int (*d_manage)(const struct path___308 *, bool);
	struct dentry___308 * (*d_real)(struct dentry___308 *, const struct inode___308 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___307;

struct mem_dqinfo___307 {
	struct quota_format_type___307 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___307;

struct quota_info___307 {
	unsigned int flags;
	struct rw_semaphore___309 dqio_sem;
	struct inode___308 *files[3];
	struct mem_dqinfo___307 info[3];
	const struct quota_format_ops___307 *ops[3];
};

struct rcuwait___307 {
	struct task_struct___309 *task;
};

struct percpu_rw_semaphore___307 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___309 rw_sem;
	struct rcuwait___307 writer;
	int readers_block;
};

struct sb_writers___307 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___307 rw_sem[3];
};

struct shrink_control___119;

struct shrinker___119 {
	long unsigned int (*count_objects)(struct shrinker___119 *, struct shrink_control___119 *);
	long unsigned int (*scan_objects)(struct shrinker___119 *, struct shrink_control___119 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___307;

struct super_operations___307;

struct dquot_operations___307;

struct quotactl_ops___307;

struct super_block___307 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___307 *s_type;
	const struct super_operations___307 *s_op;
	const struct dquot_operations___307 *dq_op;
	const struct quotactl_ops___307 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___308 *s_root;
	struct rw_semaphore___309 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___307 *s_bdev;
	struct backing_dev_info___151 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___307 s_dquot;
	struct sb_writers___307 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___307 *s_d_op;
	int cleancache_poolid;
	struct shrinker___119 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___225 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___119 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___119 *memcg;
};

typedef int (*dev_page_fault_t___297)(struct vm_area_struct___309 *, long unsigned int, const struct page___309 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___297)(struct page___309 *, void *);

struct dev_pagemap___297 {
	dev_page_fault_t___297 page_fault;
	dev_page_free_t___297 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___273 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___308 {
	struct task_struct___309 *task;
	struct core_thread___308 *next;
};

struct core_state___308 {
	atomic_t nr_threads;
	struct core_thread___308 dumper;
	struct completion startup;
};

struct vm_fault___297 {
	struct vm_area_struct___309 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___309 *cow_page;
	struct mem_cgroup___119 *memcg;
	struct page___309 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___308 prealloc_pte;
};

struct kiocb___308 {
	struct file___308 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___308 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___307 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___308 *ia_file;
};

struct dquot___307 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___307 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___307 {
	int qf_fmt_id;
	const struct quota_format_ops___307 *qf_ops;
	struct module___248 *qf_owner;
	struct quota_format_type___307 *qf_next;
};

struct quota_format_ops___307 {
	int (*check_quota_file)(struct super_block___307 *, int);
	int (*read_file_info)(struct super_block___307 *, int);
	int (*write_file_info)(struct super_block___307 *, int);
	int (*free_file_info)(struct super_block___307 *, int);
	int (*read_dqblk)(struct dquot___307 *);
	int (*commit_dqblk)(struct dquot___307 *);
	int (*release_dqblk)(struct dquot___307 *);
	int (*get_next_id)(struct super_block___307 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___307 {
	int (*write_dquot)(struct dquot___307 *);
	struct dquot___307 * (*alloc_dquot)(struct super_block___307 *, int);
	void (*destroy_dquot)(struct dquot___307 *);
	int (*acquire_dquot)(struct dquot___307 *);
	int (*release_dquot)(struct dquot___307 *);
	int (*mark_dirty)(struct dquot___307 *);
	int (*write_info)(struct super_block___307 *, int);
	qsize_t * (*get_reserved_space)(struct inode___308 *);
	int (*get_projid)(struct inode___308 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___308 *, qsize_t *);
	int (*get_next_id)(struct super_block___307 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___307 {
	int (*quota_on)(struct super_block___307 *, int, int, const struct path___308 *);
	int (*quota_off)(struct super_block___307 *, int);
	int (*quota_enable)(struct super_block___307 *, unsigned int);
	int (*quota_disable)(struct super_block___307 *, unsigned int);
	int (*quota_sync)(struct super_block___307 *, int);
	int (*set_info)(struct super_block___307 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___307 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___307 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___307 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___307 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___307 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___134;

struct swap_info_struct___77;

struct address_space_operations___307 {
	int (*writepage)(struct page___309 *, struct writeback_control___134 *);
	int (*readpage)(struct file___308 *, struct page___309 *);
	int (*writepages)(struct address_space___307 *, struct writeback_control___134 *);
	int (*set_page_dirty)(struct page___309 *);
	int (*readpages)(struct file___308 *, struct address_space___307 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___308 *, struct address_space___307 *, loff_t, unsigned int, unsigned int, struct page___309 **, void **);
	int (*write_end)(struct file___308 *, struct address_space___307 *, loff_t, unsigned int, unsigned int, struct page___309 *, void *);
	sector_t (*bmap)(struct address_space___307 *, sector_t);
	void (*invalidatepage)(struct page___309 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___309 *, gfp_t);
	void (*freepage)(struct page___309 *);
	ssize_t (*direct_IO)(struct kiocb___308 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___307 *, struct page___309 *, struct page___309 *, enum migrate_mode);
	bool (*isolate_page)(struct page___309 *, isolate_mode_t);
	void (*putback_page)(struct page___309 *);
	int (*launder_page)(struct page___309 *);
	int (*is_partially_uptodate)(struct page___309 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___309 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___307 *, struct page___309 *);
	int (*swap_activate)(struct swap_info_struct___77 *, struct file___308 *, sector_t *);
	void (*swap_deactivate)(struct file___308 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___134 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___151 *wb;
	struct inode___308 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct swap_info_struct___77 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___307 *bdev;
	struct file___308 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___307 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___308 *bd_inode;
	struct super_block___307 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___307 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___151 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___58 {
	struct kobject___295 kobj;
	struct module___248 *owner;
	const struct file_operations___308 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___307 {
	struct dentry___308 * (*lookup)(struct inode___308 *, struct dentry___308 *, unsigned int);
	const char * (*get_link)(struct dentry___308 *, struct inode___308 *, struct delayed_call *);
	int (*permission)(struct inode___308 *, int);
	struct posix_acl * (*get_acl)(struct inode___308 *, int);
	int (*readlink)(struct dentry___308 *, char *, int);
	int (*create)(struct inode___308 *, struct dentry___308 *, umode_t, bool);
	int (*link)(struct dentry___308 *, struct inode___308 *, struct dentry___308 *);
	int (*unlink)(struct inode___308 *, struct dentry___308 *);
	int (*symlink)(struct inode___308 *, struct dentry___308 *, const char *);
	int (*mkdir)(struct inode___308 *, struct dentry___308 *, umode_t);
	int (*rmdir)(struct inode___308 *, struct dentry___308 *);
	int (*mknod)(struct inode___308 *, struct dentry___308 *, umode_t, dev_t);
	int (*rename)(struct inode___308 *, struct dentry___308 *, struct inode___308 *, struct dentry___308 *, unsigned int);
	int (*setattr)(struct dentry___308 *, struct iattr___307 *);
	int (*getattr)(const struct path___308 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___308 *, char *, size_t);
	int (*fiemap)(struct inode___308 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___308 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___308 *, struct dentry___308 *, struct file___308 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___308 *, struct dentry___308 *, umode_t);
	int (*set_acl)(struct inode___308 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___307 {
	void (*fl_copy_lock)(struct file_lock___308 *, struct file_lock___308 *);
	void (*fl_release_private)(struct file_lock___308 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___307;

struct lock_manager_operations___307;

struct file_lock___308 {
	struct file_lock___308 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___308 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___307 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___307 *fl_ops;
	const struct lock_manager_operations___307 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___307 {
	int (*lm_compare_owner)(struct file_lock___308 *, struct file_lock___308 *);
	long unsigned int (*lm_owner_key)(struct file_lock___308 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___308 *);
	int (*lm_grant)(struct file_lock___308 *, int);
	bool (*lm_break)(struct file_lock___308 *);
	int (*lm_change)(struct file_lock___308 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___308 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___307 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___307 *fa_next;
	struct file___308 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___307 {
	const char *name;
	int fs_flags;
	struct dentry___308 * (*mount)(struct file_system_type___307 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___307 *);
	struct module___248 *owner;
	struct file_system_type___307 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___307 {
	struct inode___308 * (*alloc_inode)(struct super_block___307 *);
	void (*destroy_inode)(struct inode___308 *);
	void (*dirty_inode)(struct inode___308 *, int);
	int (*write_inode)(struct inode___308 *, struct writeback_control___134 *);
	int (*drop_inode)(struct inode___308 *);
	void (*evict_inode)(struct inode___308 *);
	void (*put_super)(struct super_block___307 *);
	int (*sync_fs)(struct super_block___307 *, int);
	int (*freeze_super)(struct super_block___307 *);
	int (*freeze_fs)(struct super_block___307 *);
	int (*thaw_super)(struct super_block___307 *);
	int (*unfreeze_fs)(struct super_block___307 *);
	int (*statfs)(struct dentry___308 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___307 *, int *, char *);
	void (*umount_begin)(struct super_block___307 *);
	int (*show_options)(struct seq_file___260 *, struct dentry___308 *);
	int (*show_devname)(struct seq_file___260 *, struct dentry___308 *);
	int (*show_path)(struct seq_file___260 *, struct dentry___308 *);
	int (*show_stats)(struct seq_file___260 *, struct dentry___308 *);
	ssize_t (*quota_read)(struct super_block___307 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___307 *, int, const char *, size_t, loff_t);
	struct dquot___307 ** (*get_dquots)(struct inode___308 *);
	int (*bdev_try_to_free_page)(struct super_block___307 *, struct page___309 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___307 *, struct shrink_control___119 *);
	long int (*free_cached_objects)(struct super_block___307 *, struct shrink_control___119 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___151(struct bio___151 *);

struct bio_vec___152 {
	struct page___309 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___151;

struct bio_set___151;

struct bio___151 {
	struct bio___151 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___151 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___151 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___152 *bi_io_vec;
	struct bio_set___151 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___152 bi_inline_vecs[0];
};

struct fwnode_reference_args___207;

struct fwnode_endpoint___207;

struct fwnode_operations___207 {
	struct fwnode_handle___207 * (*get)(struct fwnode_handle___207 *);
	void (*put)(struct fwnode_handle___207 *);
	bool (*device_is_available)(const struct fwnode_handle___207 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___207 *, const struct device___273 *);
	bool (*property_present)(const struct fwnode_handle___207 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___207 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___207 *, const char *, const char **, size_t);
	struct fwnode_handle___207 * (*get_parent)(const struct fwnode_handle___207 *);
	struct fwnode_handle___207 * (*get_next_child_node)(const struct fwnode_handle___207 *, struct fwnode_handle___207 *);
	struct fwnode_handle___207 * (*get_named_child_node)(const struct fwnode_handle___207 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___207 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___207 *);
	struct fwnode_handle___207 * (*graph_get_next_endpoint)(const struct fwnode_handle___207 *, struct fwnode_handle___207 *);
	struct fwnode_handle___207 * (*graph_get_remote_endpoint)(const struct fwnode_handle___207 *);
	struct fwnode_handle___207 * (*graph_get_port_parent)(struct fwnode_handle___207 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___207 *, struct fwnode_endpoint___207 *);
};

struct fwnode_endpoint___207 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___207 *local_fwnode;
};

struct fwnode_reference_args___207 {
	struct fwnode_handle___207 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

typedef u32 (*acpi_event_handler)(void *);

enum acpi_bus_device_type {
	ACPI_BUS_TYPE_DEVICE = 0,
	ACPI_BUS_TYPE_POWER = 1,
	ACPI_BUS_TYPE_PROCESSOR = 2,
	ACPI_BUS_TYPE_THERMAL = 3,
	ACPI_BUS_TYPE_POWER_BUTTON = 4,
	ACPI_BUS_TYPE_SLEEP_BUTTON = 5,
	ACPI_BUS_TYPE_ECDT_EC = 6,
	ACPI_BUS_DEVICE_TYPE_COUNT = 7,
};

struct acpi_device___9;

struct acpi_hotplug_profile___9 {
	struct kobject___295 kobj;
	int (*scan_dependent)(struct acpi_device___9 *);
	void (*notify_online)(struct acpi_device___9 *);
	bool enabled: 1;
	bool demand_offline: 1;
};

struct acpi_device_wakeup_context___9 {
	void (*func)(struct acpi_device_wakeup_context___9 *);
	struct device___273 *dev;
};

struct acpi_device_wakeup___9 {
	acpi_handle gpe_device;
	u64 gpe_number;
	u64 sleep_state;
	struct list_head resources;
	struct acpi_device_wakeup_flags flags;
	struct acpi_device_wakeup_context___9 context;
	struct wakeup_source *ws;
	int prepare_count;
	int enable_count;
};

struct acpi_scan_handler___9;

struct acpi_hotplug_context___9;

struct acpi_driver___9;

struct acpi_device___9 {
	int device_type;
	acpi_handle handle;
	struct fwnode_handle___207 fwnode;
	struct acpi_device___9 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup___9 wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_device_data data;
	struct acpi_scan_handler___9 *handler;
	struct acpi_hotplug_context___9 *hp;
	struct acpi_driver___9 *driver;
	const struct acpi_gpio_mapping *driver_gpios;
	void *driver_data;
	struct device___273 dev;
	unsigned int physical_node_count;
	unsigned int dep_unmet;
	struct list_head physical_node_list;
	struct mutex physical_node_lock;
	void (*remove)(struct acpi_device___9 *);
};

struct acpi_scan_handler___9 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	bool (*match)(const char *, const struct acpi_device_id **);
	int (*attach)(struct acpi_device___9 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___9 *);
	void (*bind)(struct device___273 *);
	void (*unbind)(struct device___273 *);
	struct acpi_hotplug_profile___9 hotplug;
};

struct acpi_hotplug_context___9 {
	struct acpi_device___9 *self;
	int (*notify)(struct acpi_device___9 *, u32);
	void (*uevent)(struct acpi_device___9 *, u32);
	void (*fixup)(struct acpi_device___9 *);
};

typedef int (*acpi_op_add___9)(struct acpi_device___9 *);

typedef int (*acpi_op_remove___9)(struct acpi_device___9 *);

typedef void (*acpi_op_notify___9)(struct acpi_device___9 *, u32);

struct acpi_device_ops___9 {
	acpi_op_add___9 add;
	acpi_op_remove___9 remove;
	acpi_op_notify___9 notify;
};

struct acpi_driver___9 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___9 ops;
	struct device_driver___273 drv;
	struct module___248 *owner;
};

struct acpi_device_physical_node {
	unsigned int node_id;
	struct list_head node;
	struct device___273 *dev;
	bool put_online: 1;
};

typedef int (*key_restrict_link_func_t___287)(struct key___286 *, const struct key_type *, const union key_payload *, struct key___286 *);

struct key_restriction___286;

struct key___286 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___309 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___286 *restrict_link;
};

struct key_restriction___286 {
	key_restrict_link_func_t___287 check;
	struct key___286 *key;
	struct key_type *keytype;
};

struct seq_operations___259 {
	void * (*start)(struct seq_file___260 *, loff_t *);
	void (*stop)(struct seq_file___260 *, void *);
	void * (*next)(struct seq_file___260 *, void *, loff_t *);
	int (*show)(struct seq_file___260 *, void *);
};

typedef void compound_page_dtor___297(struct page___309 *);

struct acpi_osc_context {
	char *uuid_str;
	int rev;
	struct acpi_buffer cap;
	struct acpi_buffer ret;
};

struct cgroup_namespace___210 {
	refcount_t count;
	struct ns_common___9 ns;
	struct user_namespace___225 *user_ns;
	struct ucounts___225 *ucounts;
	struct css_set___210 *root_cset;
};

struct ucounts___225 {
	struct hlist_node node;
	struct user_namespace___225 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___211;

struct bpf_map_ops___210 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___211 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___211 *, struct file___308 *);
	void (*map_free)(struct bpf_map___211 *);
	int (*map_get_next_key)(struct bpf_map___211 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___211 *);
	void * (*map_lookup_elem)(struct bpf_map___211 *, void *);
	int (*map_update_elem)(struct bpf_map___211 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___211 *, void *);
	int (*map_push_elem)(struct bpf_map___211 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___211 *, void *);
	int (*map_peek_elem)(struct bpf_map___211 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___211 *, struct file___308 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___211 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___211 *, void *, struct seq_file___260 *);
	int (*map_check_btf)(const struct bpf_map___211 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___211 {
	const struct bpf_map_ops___210 *ops;
	struct bpf_map___211 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___286 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___210;

typedef void (*kthread_work_func_t___210)(struct kthread_work___210 *);

struct kthread_worker___210;

struct kthread_work___210 {
	struct list_head node;
	kthread_work_func_t___210 func;
	struct kthread_worker___210 *worker;
	int canceling;
};

struct kthread_worker___210 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___309 *task;
	struct kthread_work___210 *current_work;
};

struct kthread_delayed_work___210 {
	struct kthread_work___210 work;
	struct timer_list timer;
};

struct psi_group___210 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___210 *poll_kworker;
	struct kthread_delayed_work___210 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___210;

struct cgroup_rstat_cpu___210;

struct cgroup___210 {
	struct cgroup_subsys_state___210 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___302 *kn;
	struct cgroup_file___210 procs_file;
	struct cgroup_file___210 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___210 *subsys[13];
	struct cgroup_root___210 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___210 *dom_cgrp;
	struct cgroup_rstat_cpu___210 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___35 bpf;
	atomic_t congestion_count;
	struct cgroup___210 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___210 psi;
	int ancestor_ids[0];
};

struct cftype___210;

struct cgroup_subsys___210 {
	struct cgroup_subsys_state___210 * (*css_alloc)(struct cgroup_subsys_state___210 *);
	int (*css_online)(struct cgroup_subsys_state___210 *);
	void (*css_offline)(struct cgroup_subsys_state___210 *);
	void (*css_released)(struct cgroup_subsys_state___210 *);
	void (*css_free)(struct cgroup_subsys_state___210 *);
	void (*css_reset)(struct cgroup_subsys_state___210 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___210 *, int);
	int (*css_extra_stat_show)(struct seq_file___260 *, struct cgroup_subsys_state___210 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___309 *);
	void (*cancel_fork)(struct task_struct___309 *);
	void (*fork)(struct task_struct___309 *);
	void (*exit)(struct task_struct___309 *);
	void (*free)(struct task_struct___309 *);
	void (*bind)(struct cgroup_subsys_state___210 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___210 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___210 *dfl_cftypes;
	struct cftype___210 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___210 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___210 *updated_children;
	struct cgroup___210 *updated_next;
};

struct cgroup_root___210 {
	struct kernfs_root___301 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___210 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___210 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___210 *ss;
	struct list_head node;
	struct kernfs_ops___301 *kf_ops;
	int (*open)(struct kernfs_open_file___301 *);
	void (*release)(struct kernfs_open_file___301 *);
	u64 (*read_u64)(struct cgroup_subsys_state___210 *, struct cftype___210 *);
	s64 (*read_s64)(struct cgroup_subsys_state___210 *, struct cftype___210 *);
	int (*seq_show)(struct seq_file___260 *, void *);
	void * (*seq_start)(struct seq_file___260 *, loff_t *);
	void * (*seq_next)(struct seq_file___260 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___260 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___210 *, struct cftype___210 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___210 *, struct cftype___210 *, s64);
	ssize_t (*write)(struct kernfs_open_file___301 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___301 *, struct poll_table_struct___185 *);
};

struct bdi_writeback_congested___151 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___151 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___151 {
	struct bio___151 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___152 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___152 bip_inline_vecs[0];
};

struct bio_set___151 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___151 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___119 {
	struct mem_cgroup___119 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___119 {
	struct lruvec___308 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___119 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___119 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct node___184 {
	struct device___273 dev;
};

struct property___62 {
	char *name;
	int length;
	void *value;
	struct property___62 *next;
	long unsigned int _flags;
	struct bin_attribute___271 attr;
};

struct irq_fwspec___23 {
	struct fwnode_handle___207 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___23 {
	int (*match)(struct irq_domain___23 *, struct device_node___65 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___23 *, struct irq_fwspec___23 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___23 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___23 *, unsigned int);
	int (*xlate)(struct irq_domain___23 *, struct device_node___65 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___23 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___23 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___23 *, struct irq_data___5 *, bool);
	void (*deactivate)(struct irq_domain___23 *, struct irq_data___5 *);
	int (*translate)(struct irq_domain___23 *, struct irq_fwspec___23 *, long unsigned int *, unsigned int *);
};

struct acpi_device_physical_node___2 {
	unsigned int node_id;
	struct list_head node;
	struct device___272 *dev;
	bool put_online: 1;
};

struct acpi_bus_type___2 {
	struct list_head list;
	const char *name;
	bool (*match)(struct device___272 *);
	struct acpi_device___8 * (*find_companion)(struct device___272 *);
	void (*setup)(struct device___272 *);
	void (*cleanup)(struct device___272 *);
};

typedef void (*poll_queue_proc___189)(struct file___307 *, wait_queue_head_t *, struct poll_table_struct___12 *);

struct module___249;

struct file___309;

struct kiocb___309;

struct poll_table_struct___186;

struct vm_area_struct___310;

struct inode___309;

struct file_lock___309;

struct page___310;

struct seq_file___261;

struct file_operations___309 {
	struct module___249 *owner;
	loff_t (*llseek)(struct file___309 *, loff_t, int);
	ssize_t (*read)(struct file___309 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___309 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___309 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___309 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___309 *, bool);
	int (*iterate)(struct file___309 *, struct dir_context *);
	int (*iterate_shared)(struct file___309 *, struct dir_context *);
	__poll_t (*poll)(struct file___309 *, struct poll_table_struct___186 *);
	long int (*unlocked_ioctl)(struct file___309 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___309 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___309 *, struct vm_area_struct___310 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___309 *, struct file___309 *);
	int (*flush)(struct file___309 *, fl_owner_t);
	int (*release)(struct inode___309 *, struct file___309 *);
	int (*fsync)(struct file___309 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___309 *, int);
	int (*lock)(struct file___309 *, int, struct file_lock___309 *);
	ssize_t (*sendpage)(struct file___309 *, struct page___310 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___309 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___309 *, int, struct file_lock___309 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___309 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___309 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___309 *, long int, struct file_lock___309 **, void **);
	long int (*fallocate)(struct file___309 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___261 *, struct file___309 *);
	ssize_t (*copy_file_range)(struct file___309 *, loff_t, struct file___309 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___309 *, loff_t, struct file___309 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___309 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___309 {
	u64 seqnum;
	struct vm_area_struct___310 *vmas[4];
};

struct page_frag___309 {
	struct page___310 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___309;

struct cred___287;

struct vm_struct___225;

struct task_struct___310 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___310 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___309 *mm;
	struct mm_struct___309 *active_mm;
	struct vmacache___309 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___310 *real_parent;
	struct task_struct___310 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___310 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___204 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___204 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___204 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___287 *ptracer_cred;
	const struct cred___287 *real_cred;
	const struct cred___287 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___310 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___82 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___309 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___310 *oom_reaper_list;
	struct vm_struct___225 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___131 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___310 *pgtable_t___309;

struct address_space___308;

struct dev_pagemap___298;

struct page___310 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___308 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___310 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___309 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___309 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___298 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___309;

struct lruvec___309 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___309 *pgdat;
};

struct zone___309 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___309 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___309 {
	struct zone___309 *zone;
	int zone_idx;
};

struct zonelist___309 {
	struct zoneref___309 _zonerefs[25];
};

struct pglist_data___309 {
	struct zone___309 node_zones[3];
	struct zonelist___309 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___310 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___310 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___309 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___310 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___310 *owner;
};

struct secondary_data___310 {
	void *stack;
	struct task_struct___310 *task;
	long int status;
};

struct blocking_notifier_head___309 {
	struct rw_semaphore___310 rwsem;
	struct notifier_block *head;
};

struct dentry___309;

struct path___309 {
	struct vfsmount *mnt;
	struct dentry___309 *dentry;
};

struct file___309 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___309 f_path;
	struct inode___309 *f_inode;
	const struct file_operations___309 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___204 f_owner;
	const struct cred___287 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___308 *f_mapping;
	errseq_t f_wb_err;
};

struct key___287;

struct user_struct___287;

struct cred___287 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___287 *session_keyring;
	struct key___287 *process_keyring;
	struct key___287 *thread_keyring;
	struct key___287 *request_key_auth;
	void *security;
	struct user_struct___287 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___302;

struct kernfs_elem_dir___302 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___302 *root;
};

struct kernfs_node___303;

struct kernfs_syscall_ops___302;

struct kernfs_root___302 {
	struct kernfs_node___303 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___302 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___302 {
	struct kernfs_node___303 *target_kn;
};

struct kernfs_ops___302;

struct kernfs_elem_attr___302 {
	const struct kernfs_ops___302 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___303 *notify_next;
};

struct kernfs_node___303 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___303 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___302 dir;
		struct kernfs_elem_symlink___302 symlink;
		struct kernfs_elem_attr___302 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___302;

struct kernfs_ops___302 {
	int (*open)(struct kernfs_open_file___302 *);
	void (*release)(struct kernfs_open_file___302 *);
	int (*seq_show)(struct seq_file___261 *, void *);
	void * (*seq_start)(struct seq_file___261 *, loff_t *);
	void * (*seq_next)(struct seq_file___261 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___261 *, void *);
	ssize_t (*read)(struct kernfs_open_file___302 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___302 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___302 *, struct vm_area_struct___310 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___302 *, struct poll_table_struct___186 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___302 {
	int (*remount_fs)(struct kernfs_root___302 *, int *, char *);
	int (*show_options)(struct seq_file___261 *, struct kernfs_root___302 *);
	int (*mkdir)(struct kernfs_node___303 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___303 *);
	int (*rename)(struct kernfs_node___303 *, struct kernfs_node___303 *, const char *);
	int (*show_path)(struct seq_file___261 *, struct kernfs_node___303 *, struct kernfs_root___302 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___260;

struct seq_file___261 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___260 *op;
	int poll_event;
	const struct file___309 *file;
	void *private;
};

struct vm_operations_struct___298;

struct kernfs_open_file___302 {
	struct kernfs_node___303 *kn;
	struct file___309 *file;
	struct seq_file___261 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___298 *vm_ops;
};

struct vm_fault___298;

struct vm_operations_struct___298 {
	void (*open)(struct vm_area_struct___310 *);
	void (*close)(struct vm_area_struct___310 *);
	int (*split)(struct vm_area_struct___310 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___310 *);
	vm_fault_t (*fault)(struct vm_fault___298 *);
	vm_fault_t (*huge_fault)(struct vm_fault___298 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___298 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___310 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___298 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___298 *);
	int (*access)(struct vm_area_struct___310 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___310 *);
	int (*set_policy)(struct vm_area_struct___310 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___310 *, long unsigned int);
	struct page___310 * (*find_special_page)(struct vm_area_struct___310 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___190)(struct file___309 *, wait_queue_head_t *, struct poll_table_struct___186 *);

struct poll_table_struct___186 {
	poll_queue_proc___190 _qproc;
	__poll_t _key;
};

struct vm_area_struct___310 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___310 *vm_next;
	struct vm_area_struct___310 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___309 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___298 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___309 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___296;

struct bin_attribute___272;

struct attribute_group___273 {
	const char *name;
	umode_t (*is_visible)(struct kobject___296 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___296 *, struct bin_attribute___272 *, int);
	struct attribute **attrs;
	struct bin_attribute___272 **bin_attrs;
};

struct kset___295;

struct kobj_type___295;

struct kobject___296 {
	const char *name;
	struct list_head entry;
	struct kobject___296 *parent;
	struct kset___295 *kset;
	struct kobj_type___295 *ktype;
	struct kernfs_node___303 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___272 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___309 *, struct kobject___296 *, struct bin_attribute___272 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___309 *, struct kobject___296 *, struct bin_attribute___272 *, char *, loff_t, size_t);
	int (*mmap)(struct file___309 *, struct kobject___296 *, struct bin_attribute___272 *, struct vm_area_struct___310 *);
};

struct sysfs_ops___295 {
	ssize_t (*show)(struct kobject___296 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___296 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___295;

struct kset___295 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___296 kobj;
	const struct kset_uevent_ops___295 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___295 {
	void (*release)(struct kobject___296 *);
	const struct sysfs_ops___295 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___25 * (*child_ns_type)(struct kobject___296 *);
	const void * (*namespace)(struct kobject___296 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___295 {
	int (* const filter)(struct kset___295 *, struct kobject___296 *);
	const char * (* const name)(struct kset___295 *, struct kobject___296 *);
	int (* const uevent)(struct kset___295 *, struct kobject___296 *, struct kobj_uevent_env *);
};

struct kobj_attribute___288 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___296 *, struct kobj_attribute___288 *, char *);
	ssize_t (*store)(struct kobject___296 *, struct kobj_attribute___288 *, const char *, size_t);
};

struct kernel_param___246;

struct kernel_param_ops___246 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___246 *);
	int (*get)(char *, const struct kernel_param___246 *);
	void (*free)(void *);
};

struct kparam_array___246;

struct kernel_param___246 {
	const char *name;
	struct module___249 *mod;
	const struct kernel_param_ops___246 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___246 *arr;
	};
};

struct kparam_array___246 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___246 *ops;
	void *elem;
};

struct module_kobject___246 {
	struct kobject___296 kobj;
	struct module___249 *mod;
	struct kobject___296 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___246 {
	struct module___249 *mod;
	struct latch_tree_node node;
};

struct module_layout___246 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___246 mtn;
};

struct module_attribute___246;

struct module___249 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___246 mkobj;
	struct module_attribute___246 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___296 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___246 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___246 core_layout;
	struct module_layout___246 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___246 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___246 *, struct module_kobject___246 *, char *);
	ssize_t (*store)(struct module_attribute___246 *, struct module_kobject___246 *, const char *, size_t);
	void (*setup)(struct module___249 *, const char *);
	int (*test)(struct module___249 *);
	void (*free)(struct module___249 *);
};

struct device___274;

struct dev_pm_ops___274 {
	int (*prepare)(struct device___274 *);
	void (*complete)(struct device___274 *);
	int (*suspend)(struct device___274 *);
	int (*resume)(struct device___274 *);
	int (*freeze)(struct device___274 *);
	int (*thaw)(struct device___274 *);
	int (*poweroff)(struct device___274 *);
	int (*restore)(struct device___274 *);
	int (*suspend_late)(struct device___274 *);
	int (*resume_early)(struct device___274 *);
	int (*freeze_late)(struct device___274 *);
	int (*thaw_early)(struct device___274 *);
	int (*poweroff_late)(struct device___274 *);
	int (*restore_early)(struct device___274 *);
	int (*suspend_noirq)(struct device___274 *);
	int (*resume_noirq)(struct device___274 *);
	int (*freeze_noirq)(struct device___274 *);
	int (*thaw_noirq)(struct device___274 *);
	int (*poweroff_noirq)(struct device___274 *);
	int (*restore_noirq)(struct device___274 *);
	int (*runtime_suspend)(struct device___274 *);
	int (*runtime_resume)(struct device___274 *);
	int (*runtime_idle)(struct device___274 *);
};

struct dev_pm_info___274 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___274 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___274;

struct bus_type___274;

struct device_driver___274;

struct dev_pm_domain___274;

struct irq_domain___24;

struct dma_map_ops___91;

struct device_node___66;

struct fwnode_handle___208;

struct class___274;

struct device___274 {
	struct device___274 *parent;
	struct device_private *p;
	struct kobject___296 kobj;
	const char *init_name;
	const struct device_type___274 *type;
	struct mutex mutex;
	struct bus_type___274 *bus;
	struct device_driver___274 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___274 power;
	struct dev_pm_domain___274 *pm_domain;
	struct irq_domain___24 *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___91 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___66 *of_node;
	struct fwnode_handle___208 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___274 *class;
	const struct attribute_group___273 **groups;
	void (*release)(struct device___274 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___274 {
	struct dev_pm_ops___274 ops;
	void (*detach)(struct device___274 *, bool);
	int (*activate)(struct device___274 *);
	void (*sync)(struct device___274 *);
	void (*dismiss)(struct device___274 *);
};

struct user_struct___287 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___287 *uid_keyring;
	struct key___287 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___309;

struct mm_struct___309 {
	struct {
		struct vm_area_struct___310 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___309 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___310 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___309 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___310 *owner;
		struct user_namespace___3 *user_ns;
		struct file___309 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___309 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct vm_struct___225 {
	struct vm_struct___225 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___310 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bus_type___274 {
	const char *name;
	const char *dev_name;
	struct device___274 *dev_root;
	const struct attribute_group___273 **bus_groups;
	const struct attribute_group___273 **dev_groups;
	const struct attribute_group___273 **drv_groups;
	int (*match)(struct device___274 *, struct device_driver___274 *);
	int (*uevent)(struct device___274 *, struct kobj_uevent_env *);
	int (*probe)(struct device___274 *);
	int (*remove)(struct device___274 *);
	void (*shutdown)(struct device___274 *);
	int (*online)(struct device___274 *);
	int (*offline)(struct device___274 *);
	int (*suspend)(struct device___274 *, pm_message_t);
	int (*resume)(struct device___274 *);
	int (*num_vf)(struct device___274 *);
	int (*dma_configure)(struct device___274 *);
	const struct dev_pm_ops___274 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___274 {
	const char *name;
	struct bus_type___274 *bus;
	struct module___249 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___274 *);
	int (*remove)(struct device___274 *);
	void (*shutdown)(struct device___274 *);
	int (*suspend)(struct device___274 *, pm_message_t);
	int (*resume)(struct device___274 *);
	const struct attribute_group___273 **groups;
	const struct dev_pm_ops___274 *pm;
	void (*coredump)(struct device___274 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___274 {
	const char *name;
	const struct attribute_group___273 **groups;
	int (*uevent)(struct device___274 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___274 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___274 *);
	const struct dev_pm_ops___274 *pm;
};

struct class___274 {
	const char *name;
	struct module___249 *owner;
	const struct attribute_group___273 **class_groups;
	const struct attribute_group___273 **dev_groups;
	struct kobject___296 *dev_kobj;
	int (*dev_uevent)(struct device___274 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___274 *, umode_t *);
	void (*class_release)(struct class___274 *);
	void (*dev_release)(struct device___274 *);
	int (*shutdown_pre)(struct device___274 *);
	const struct kobj_ns_type_operations___25 *ns_type;
	const void * (*namespace)(struct device___274 *);
	const struct dev_pm_ops___274 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct irq_domain_ops___24;

struct irq_domain___24 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___24 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___208 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___2 *gc;
	struct irq_domain___24 *parent;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_direct_max_irq;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_tree_mutex;
	unsigned int linear_revmap[0];
};

struct dma_map_ops___91 {
	void * (*alloc)(struct device___274 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___274 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___274 *, struct vm_area_struct___310 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___274 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___274 *, struct page___310 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___274 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___274 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___274 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___274 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___274 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___274 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___274 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___274 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___274 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___274 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___274 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___274 *, u64);
	u64 (*get_required_mask)(struct device___274 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___208;

struct fwnode_handle___208 {
	struct fwnode_handle___208 *secondary;
	const struct fwnode_operations___208 *ops;
};

struct property___63;

struct device_node___66 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___208 fwnode;
	struct property___63 *properties;
	struct property___63 *deadprops;
	struct device_node___66 *parent;
	struct device_node___66 *child;
	struct device_node___66 *sibling;
	struct kobject___296 kobj;
	long unsigned int _flags;
	void *data;
};

struct fwnode_reference_args___208;

struct fwnode_endpoint___208;

struct fwnode_operations___208 {
	struct fwnode_handle___208 * (*get)(struct fwnode_handle___208 *);
	void (*put)(struct fwnode_handle___208 *);
	bool (*device_is_available)(const struct fwnode_handle___208 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___208 *, const struct device___274 *);
	bool (*property_present)(const struct fwnode_handle___208 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___208 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___208 *, const char *, const char **, size_t);
	struct fwnode_handle___208 * (*get_parent)(const struct fwnode_handle___208 *);
	struct fwnode_handle___208 * (*get_next_child_node)(const struct fwnode_handle___208 *, struct fwnode_handle___208 *);
	struct fwnode_handle___208 * (*get_named_child_node)(const struct fwnode_handle___208 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___208 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___208 *);
	struct fwnode_handle___208 * (*graph_get_next_endpoint)(const struct fwnode_handle___208 *, struct fwnode_handle___208 *);
	struct fwnode_handle___208 * (*graph_get_remote_endpoint)(const struct fwnode_handle___208 *);
	struct fwnode_handle___208 * (*graph_get_port_parent)(struct fwnode_handle___208 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___208 *, struct fwnode_endpoint___208 *);
};

struct fwnode_endpoint___208 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___208 *local_fwnode;
};

struct fwnode_reference_args___208 {
	struct fwnode_handle___208 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct acpi_pnp_device_id {
	u32 length;
	char *string;
};

struct acpi_pnp_device_id_list {
	u32 count;
	u32 list_size;
	struct acpi_pnp_device_id ids[1];
};

struct acpi_device_info {
	u32 info_size;
	u32 name;
	acpi_object_type type;
	u8 param_count;
	u16 valid;
	u8 flags;
	u8 highest_dstates[4];
	u8 lowest_dstates[5];
	u64 address;
	struct acpi_pnp_device_id hardware_id;
	struct acpi_pnp_device_id unique_id;
	struct acpi_pnp_device_id class_code;
	struct acpi_pnp_device_id_list compatible_id_list;
};

struct acpi_table_spcr {
	struct acpi_table_header header;
	u8 interface_type;
	u8 reserved[3];
	struct acpi_generic_address serial_port;
	u8 interrupt_type;
	u8 pc_interrupt;
	u32 interrupt;
	u8 baud_rate;
	u8 parity;
	u8 stop_bits;
	u8 flow_control;
	u8 terminal_type;
	u8 reserved1;
	u16 pci_device_id;
	u16 pci_vendor_id;
	u8 pci_bus;
	u8 pci_device;
	u8 pci_function;
	u32 pci_flags;
	u8 pci_segment;
	u32 reserved2;
} __attribute__((packed));

struct acpi_table_stao {
	struct acpi_table_header header;
	u8 ignore_uart;
} __attribute__((packed));

struct dentry_operations___308;

struct super_block___308;

struct dentry___309 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___309 *d_parent;
	struct qstr d_name;
	struct inode___309 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___308 *d_op;
	struct super_block___308 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___308;

struct address_space___308 {
	struct inode___309 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___310 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___308 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___308;

struct block_device___308;

struct cdev___59;

struct inode___309 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___308 *i_op;
	struct super_block___308 *i_sb;
	struct address_space___308 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___310 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___309 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___308 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___308 *i_bdev;
		struct cdev___59 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___308 {
	int (*d_revalidate)(struct dentry___309 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___309 *, unsigned int);
	int (*d_hash)(const struct dentry___309 *, struct qstr *);
	int (*d_compare)(const struct dentry___309 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___309 *);
	int (*d_init)(struct dentry___309 *);
	void (*d_release)(struct dentry___309 *);
	void (*d_prune)(struct dentry___309 *);
	void (*d_iput)(struct dentry___309 *, struct inode___309 *);
	char * (*d_dname)(struct dentry___309 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___309 *);
	int (*d_manage)(const struct path___309 *, bool);
	struct dentry___309 * (*d_real)(struct dentry___309 *, const struct inode___309 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___308;

struct mem_dqinfo___308 {
	struct quota_format_type___308 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___308;

struct quota_info___308 {
	unsigned int flags;
	struct rw_semaphore___310 dqio_sem;
	struct inode___309 *files[3];
	struct mem_dqinfo___308 info[3];
	const struct quota_format_ops___308 *ops[3];
};

struct rcuwait___308 {
	struct task_struct___310 *task;
};

struct percpu_rw_semaphore___308 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___310 rw_sem;
	struct rcuwait___308 writer;
	int readers_block;
};

struct sb_writers___308 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___308 rw_sem[3];
};

struct file_system_type___308;

struct super_operations___308;

struct dquot_operations___308;

struct quotactl_ops___308;

struct super_block___308 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___308 *s_type;
	const struct super_operations___308 *s_op;
	const struct dquot_operations___308 *dq_op;
	const struct quotactl_ops___308 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___309 *s_root;
	struct rw_semaphore___310 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___308 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___308 s_dquot;
	struct sb_writers___308 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___308 *s_d_op;
	int cleancache_poolid;
	struct shrinker___119 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

typedef int (*dev_page_fault_t___298)(struct vm_area_struct___310 *, long unsigned int, const struct page___310 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___298)(struct page___310 *, void *);

struct dev_pagemap___298 {
	dev_page_fault_t___298 page_fault;
	dev_page_free_t___298 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___274 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___309 {
	struct task_struct___310 *task;
	struct core_thread___309 *next;
};

struct core_state___309 {
	atomic_t nr_threads;
	struct core_thread___309 dumper;
	struct completion startup;
};

struct vm_fault___298 {
	struct vm_area_struct___310 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___310 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___310 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___309 prealloc_pte;
};

struct kiocb___309 {
	struct file___309 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___309 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___308 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___309 *ia_file;
};

struct dquot___308 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___308 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___308 {
	int qf_fmt_id;
	const struct quota_format_ops___308 *qf_ops;
	struct module___249 *qf_owner;
	struct quota_format_type___308 *qf_next;
};

struct quota_format_ops___308 {
	int (*check_quota_file)(struct super_block___308 *, int);
	int (*read_file_info)(struct super_block___308 *, int);
	int (*write_file_info)(struct super_block___308 *, int);
	int (*free_file_info)(struct super_block___308 *, int);
	int (*read_dqblk)(struct dquot___308 *);
	int (*commit_dqblk)(struct dquot___308 *);
	int (*release_dqblk)(struct dquot___308 *);
	int (*get_next_id)(struct super_block___308 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___308 {
	int (*write_dquot)(struct dquot___308 *);
	struct dquot___308 * (*alloc_dquot)(struct super_block___308 *, int);
	void (*destroy_dquot)(struct dquot___308 *);
	int (*acquire_dquot)(struct dquot___308 *);
	int (*release_dquot)(struct dquot___308 *);
	int (*mark_dirty)(struct dquot___308 *);
	int (*write_info)(struct super_block___308 *, int);
	qsize_t * (*get_reserved_space)(struct inode___309 *);
	int (*get_projid)(struct inode___309 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___309 *, qsize_t *);
	int (*get_next_id)(struct super_block___308 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___308 {
	int (*quota_on)(struct super_block___308 *, int, int, const struct path___309 *);
	int (*quota_off)(struct super_block___308 *, int);
	int (*quota_enable)(struct super_block___308 *, unsigned int);
	int (*quota_disable)(struct super_block___308 *, unsigned int);
	int (*quota_sync)(struct super_block___308 *, int);
	int (*set_info)(struct super_block___308 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___308 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___308 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___308 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___308 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___308 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___308 {
	int (*writepage)(struct page___310 *, struct writeback_control___3 *);
	int (*readpage)(struct file___309 *, struct page___310 *);
	int (*writepages)(struct address_space___308 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___310 *);
	int (*readpages)(struct file___309 *, struct address_space___308 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___309 *, struct address_space___308 *, loff_t, unsigned int, unsigned int, struct page___310 **, void **);
	int (*write_end)(struct file___309 *, struct address_space___308 *, loff_t, unsigned int, unsigned int, struct page___310 *, void *);
	sector_t (*bmap)(struct address_space___308 *, sector_t);
	void (*invalidatepage)(struct page___310 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___310 *, gfp_t);
	void (*freepage)(struct page___310 *);
	ssize_t (*direct_IO)(struct kiocb___309 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___308 *, struct page___310 *, struct page___310 *, enum migrate_mode);
	bool (*isolate_page)(struct page___310 *, isolate_mode_t);
	void (*putback_page)(struct page___310 *);
	int (*launder_page)(struct page___310 *);
	int (*is_partially_uptodate)(struct page___310 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___310 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___308 *, struct page___310 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___309 *, sector_t *);
	void (*swap_deactivate)(struct file___309 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___308 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___309 *bd_inode;
	struct super_block___308 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___308 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___59 {
	struct kobject___296 kobj;
	struct module___249 *owner;
	const struct file_operations___309 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___308 {
	struct dentry___309 * (*lookup)(struct inode___309 *, struct dentry___309 *, unsigned int);
	const char * (*get_link)(struct dentry___309 *, struct inode___309 *, struct delayed_call *);
	int (*permission)(struct inode___309 *, int);
	struct posix_acl * (*get_acl)(struct inode___309 *, int);
	int (*readlink)(struct dentry___309 *, char *, int);
	int (*create)(struct inode___309 *, struct dentry___309 *, umode_t, bool);
	int (*link)(struct dentry___309 *, struct inode___309 *, struct dentry___309 *);
	int (*unlink)(struct inode___309 *, struct dentry___309 *);
	int (*symlink)(struct inode___309 *, struct dentry___309 *, const char *);
	int (*mkdir)(struct inode___309 *, struct dentry___309 *, umode_t);
	int (*rmdir)(struct inode___309 *, struct dentry___309 *);
	int (*mknod)(struct inode___309 *, struct dentry___309 *, umode_t, dev_t);
	int (*rename)(struct inode___309 *, struct dentry___309 *, struct inode___309 *, struct dentry___309 *, unsigned int);
	int (*setattr)(struct dentry___309 *, struct iattr___308 *);
	int (*getattr)(const struct path___309 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___309 *, char *, size_t);
	int (*fiemap)(struct inode___309 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___309 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___309 *, struct dentry___309 *, struct file___309 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___309 *, struct dentry___309 *, umode_t);
	int (*set_acl)(struct inode___309 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___308 {
	void (*fl_copy_lock)(struct file_lock___309 *, struct file_lock___309 *);
	void (*fl_release_private)(struct file_lock___309 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___308;

struct lock_manager_operations___308;

struct file_lock___309 {
	struct file_lock___309 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___309 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___308 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___308 *fl_ops;
	const struct lock_manager_operations___308 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___308 {
	int (*lm_compare_owner)(struct file_lock___309 *, struct file_lock___309 *);
	long unsigned int (*lm_owner_key)(struct file_lock___309 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___309 *);
	int (*lm_grant)(struct file_lock___309 *, int);
	bool (*lm_break)(struct file_lock___309 *);
	int (*lm_change)(struct file_lock___309 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___309 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___308 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___308 *fa_next;
	struct file___309 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___308 {
	const char *name;
	int fs_flags;
	struct dentry___309 * (*mount)(struct file_system_type___308 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___308 *);
	struct module___249 *owner;
	struct file_system_type___308 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___308 {
	struct inode___309 * (*alloc_inode)(struct super_block___308 *);
	void (*destroy_inode)(struct inode___309 *);
	void (*dirty_inode)(struct inode___309 *, int);
	int (*write_inode)(struct inode___309 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___309 *);
	void (*evict_inode)(struct inode___309 *);
	void (*put_super)(struct super_block___308 *);
	int (*sync_fs)(struct super_block___308 *, int);
	int (*freeze_super)(struct super_block___308 *);
	int (*freeze_fs)(struct super_block___308 *);
	int (*thaw_super)(struct super_block___308 *);
	int (*unfreeze_fs)(struct super_block___308 *);
	int (*statfs)(struct dentry___309 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___308 *, int *, char *);
	void (*umount_begin)(struct super_block___308 *);
	int (*show_options)(struct seq_file___261 *, struct dentry___309 *);
	int (*show_devname)(struct seq_file___261 *, struct dentry___309 *);
	int (*show_path)(struct seq_file___261 *, struct dentry___309 *);
	int (*show_stats)(struct seq_file___261 *, struct dentry___309 *);
	ssize_t (*quota_read)(struct super_block___308 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___308 *, int, const char *, size_t, loff_t);
	struct dquot___308 ** (*get_dquots)(struct inode___309 *);
	int (*bdev_try_to_free_page)(struct super_block___308 *, struct page___310 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___308 *, struct shrink_control___119 *);
	long int (*free_cached_objects)(struct super_block___308 *, struct shrink_control___119 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct acpi_device___10;

struct acpi_hotplug_profile___10 {
	struct kobject___296 kobj;
	int (*scan_dependent)(struct acpi_device___10 *);
	void (*notify_online)(struct acpi_device___10 *);
	bool enabled: 1;
	bool demand_offline: 1;
};

struct acpi_device_wakeup_context___10 {
	void (*func)(struct acpi_device_wakeup_context___10 *);
	struct device___274 *dev;
};

struct acpi_device_wakeup___10 {
	acpi_handle gpe_device;
	u64 gpe_number;
	u64 sleep_state;
	struct list_head resources;
	struct acpi_device_wakeup_flags flags;
	struct acpi_device_wakeup_context___10 context;
	struct wakeup_source *ws;
	int prepare_count;
	int enable_count;
};

struct acpi_scan_handler___10;

struct acpi_hotplug_context___10;

struct acpi_driver___10;

struct acpi_device___10 {
	int device_type;
	acpi_handle handle;
	struct fwnode_handle___208 fwnode;
	struct acpi_device___10 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup___10 wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_device_data data;
	struct acpi_scan_handler___10 *handler;
	struct acpi_hotplug_context___10 *hp;
	struct acpi_driver___10 *driver;
	const struct acpi_gpio_mapping *driver_gpios;
	void *driver_data;
	struct device___274 dev;
	unsigned int physical_node_count;
	unsigned int dep_unmet;
	struct list_head physical_node_list;
	struct mutex physical_node_lock;
	void (*remove)(struct acpi_device___10 *);
};

struct acpi_scan_handler___10 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	bool (*match)(const char *, const struct acpi_device_id **);
	int (*attach)(struct acpi_device___10 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___10 *);
	void (*bind)(struct device___274 *);
	void (*unbind)(struct device___274 *);
	struct acpi_hotplug_profile___10 hotplug;
};

struct acpi_hotplug_context___10 {
	struct acpi_device___10 *self;
	int (*notify)(struct acpi_device___10 *, u32);
	void (*uevent)(struct acpi_device___10 *, u32);
	void (*fixup)(struct acpi_device___10 *);
};

typedef int (*acpi_op_add___10)(struct acpi_device___10 *);

typedef int (*acpi_op_remove___10)(struct acpi_device___10 *);

typedef void (*acpi_op_notify___10)(struct acpi_device___10 *, u32);

struct acpi_device_ops___10 {
	acpi_op_add___10 add;
	acpi_op_remove___10 remove;
	acpi_op_notify___10 notify;
};

struct acpi_driver___10 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___10 ops;
	struct device_driver___274 drv;
	struct module___249 *owner;
};

struct acpi_device_physical_node___3 {
	unsigned int node_id;
	struct list_head node;
	struct device___274 *dev;
	bool put_online: 1;
};

typedef int (*key_restrict_link_func_t___288)(struct key___287 *, const struct key_type *, const union key_payload *, struct key___287 *);

struct key_restriction___287;

struct key___287 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___310 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___287 *restrict_link;
};

struct key_restriction___287 {
	key_restrict_link_func_t___288 check;
	struct key___287 *key;
	struct key_type *keytype;
};

struct seq_operations___260 {
	void * (*start)(struct seq_file___261 *, loff_t *);
	void (*stop)(struct seq_file___261 *, void *);
	void * (*next)(struct seq_file___261 *, void *, loff_t *);
	int (*show)(struct seq_file___261 *, void *);
};

typedef void compound_page_dtor___298(struct page___310 *);

enum acpi_reconfig_event {
	ACPI_RECONFIG_DEVICE_ADD = 0,
	ACPI_RECONFIG_DEVICE_REMOVE = 1,
};

struct property___63 {
	char *name;
	int length;
	void *value;
	struct property___63 *next;
	long unsigned int _flags;
	struct bin_attribute___272 attr;
};

struct irq_fwspec___24 {
	struct fwnode_handle___208 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___24 {
	int (*match)(struct irq_domain___24 *, struct device_node___66 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___24 *, struct irq_fwspec___24 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___24 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___24 *, unsigned int);
	int (*xlate)(struct irq_domain___24 *, struct device_node___66 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___24 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___24 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___24 *, struct irq_data___5 *, bool);
	void (*deactivate)(struct irq_domain___24 *, struct irq_data___5 *);
	int (*translate)(struct irq_domain___24 *, struct irq_fwspec___24 *, long unsigned int *, unsigned int *);
};

struct acpi_dep_data {
	struct list_head node;
	acpi_handle master;
	acpi_handle slave;
};

struct acpi_table_events_work {
	struct work_struct work;
	void *table;
	u32 event;
};

struct resource_win {
	struct resource res;
	resource_size_t offset;
};

struct res_proc_context {
	struct list_head *list;
	int (*preproc)(struct acpi_resource *, void *);
	void *preproc_data;
	int count;
	int error;
};

struct acpi_table_madt {
	struct acpi_table_header header;
	u32 address;
	u32 flags;
};

typedef u32 acpi_event_status;

struct acpi_table_ecdt {
	struct acpi_table_header header;
	struct acpi_generic_address control;
	struct acpi_generic_address data;
	u32 uid;
	u8 gpe;
	u8 id[1];
} __attribute__((packed));

struct transaction {
	const u8 *wdata;
	u8 *rdata;
	short unsigned int irq_count;
	u8 command;
	u8 wi;
	u8 ri;
	u8 wlen;
	u8 rlen;
	u8 flags;
};

typedef int (*acpi_ec_query_func)(void *);

enum ec_command {
	ACPI_EC_COMMAND_READ = 128,
	ACPI_EC_COMMAND_WRITE = 129,
	ACPI_EC_BURST_ENABLE = 130,
	ACPI_EC_BURST_DISABLE = 131,
	ACPI_EC_COMMAND_QUERY = 132,
};

enum {
	EC_FLAGS_QUERY_ENABLED = 0,
	EC_FLAGS_QUERY_PENDING = 1,
	EC_FLAGS_QUERY_GUARDING = 2,
	EC_FLAGS_GPE_HANDLER_INSTALLED = 3,
	EC_FLAGS_EC_HANDLER_INSTALLED = 4,
	EC_FLAGS_EVT_HANDLER_INSTALLED = 5,
	EC_FLAGS_STARTED = 6,
	EC_FLAGS_STOPPED = 7,
	EC_FLAGS_GPE_MASKED = 8,
};

struct acpi_ec_query_handler {
	struct list_head node;
	acpi_ec_query_func func;
	acpi_handle handle;
	void *data;
	u8 query_bit;
	struct kref kref;
};

struct acpi_ec_query {
	struct transaction transaction;
	struct work_struct work;
	struct acpi_ec_query_handler *handler;
};

struct pci_bus___27;

struct pci_slot___27 {
	struct pci_bus___27 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject___296 kobj;
};

struct pci_dev___27;

struct pci_ops___27;

struct msi_controller___11;

struct pci_bus___27 {
	struct list_head node;
	struct pci_bus___27 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___27 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___27 *ops;
	struct msi_controller___11 *msi;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	int domain_nr;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___274 *bridge;
	struct device___274 dev;
	struct bin_attribute___272 *legacy_io;
	struct bin_attribute___272 *legacy_mem;
	unsigned int is_added: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
};

struct pci_driver___27;

struct pci_dev___27 {
	struct list_head bus_list;
	struct pci_bus___27 *bus;
	struct pci_bus___27 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___27 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u16 aer_cap;
	struct aer_stats *aer_stats;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	long unsigned int *dma_alias_mask;
	struct pci_driver___27 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	unsigned int imm_ready: 1;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int bridge_d3: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int hotplug_user_indicators: 1;
	unsigned int clear_retrain_link: 1;
	unsigned int d3_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	unsigned int ltr_path: 1;
	unsigned int eetlp_prefix_path: 1;
	pci_channel_state_t error_state;
	struct device___274 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int multifunction: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int ats_enabled: 1;
	unsigned int pasid_enabled: 1;
	unsigned int pri_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int reset_fn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int shpc_managed: 1;
	unsigned int is_thunderbolt: 1;
	unsigned int __aer_firmware_first_valid: 1;
	unsigned int __aer_firmware_first: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int irq_managed: 1;
	unsigned int has_secondary_link: 1;
	unsigned int non_compliant_bars: 1;
	unsigned int is_probed: 1;
	unsigned int link_active_reporting: 1;
	unsigned int untrusted: 1;
	unsigned int no_vf_scan: 1;
	unsigned int io_window: 1;
	unsigned int pref_window: 1;
	unsigned int pref_64_window: 1;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	struct bin_attribute___272 *rom_attr;
	int rom_attr_enabled;
	struct bin_attribute___272 *res_attr[17];
	struct bin_attribute___272 *res_attr_wc[17];
	unsigned int broken_cmd_compl: 1;
	const struct attribute_group___273 **msi_irq_groups;
	struct pci_vpd *vpd;
	union {
		struct pci_sriov *sriov;
		struct pci_dev___27 *physfn;
	};
	u16 ats_cap;
	u8 ats_stu;
	atomic_t ats_ref_cnt;
	u32 pri_reqs_alloc;
	u16 pasid_features;
	struct pci_p2pdma *p2pdma;
	phys_addr_t rom;
	size_t romlen;
	char *driver_override;
	long unsigned int priv_flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t pci_dev_extended_size_rh;
	struct pci_dev_extended_rh pci_dev_extended_rh;
};

struct pci_error_handlers___27;

struct pci_driver___27 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___27 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___27 *);
	int (*suspend)(struct pci_dev___27 *, pm_message_t);
	int (*suspend_late)(struct pci_dev___27 *, pm_message_t);
	int (*resume_early)(struct pci_dev___27 *);
	int (*resume)(struct pci_dev___27 *);
	void (*shutdown)(struct pci_dev___27 *);
	int (*sriov_configure)(struct pci_dev___27 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	const struct pci_error_handlers___27 *err_handler;
	const struct attribute_group___273 **groups;
	struct device_driver___274 driver;
	struct pci_dynids dynids;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct pci_host_bridge___9 {
	struct device___274 dev;
	struct pci_bus___27 *bus;
	struct pci_ops___27 *ops;
	void *sysdata;
	int busnr;
	struct list_head windows;
	u8 (*swizzle_irq)(struct pci_dev___27 *, u8 *);
	int (*map_irq)(const struct pci_dev___27 *, u8, u8);
	void (*release_fn)(struct pci_host_bridge___9 *);
	void *release_data;
	struct msi_controller___11 *msi;
	unsigned int ignore_reset_delay: 1;
	unsigned int no_ext_tags: 1;
	unsigned int native_aer: 1;
	unsigned int native_pcie_hotplug: 1;
	unsigned int native_shpc_hotplug: 1;
	unsigned int native_pme: 1;
	unsigned int native_ltr: 1;
	resource_size_t (*align_resource)(struct pci_dev___27 *, const struct resource *, resource_size_t, resource_size_t, resource_size_t);
	long: 64;
	long unsigned int private[0];
};

struct pci_ops___27 {
	int (*add_bus)(struct pci_bus___27 *);
	void (*remove_bus)(struct pci_bus___27 *);
	void * (*map_bus)(struct pci_bus___27 *, unsigned int, int);
	int (*read)(struct pci_bus___27 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___27 *, unsigned int, int, int, u32);
};

struct msi_desc___14;

struct msi_controller___11 {
	struct module___249 *owner;
	struct device___274 *dev;
	struct device_node___2 *of_node;
	struct list_head list;
	int (*setup_irq)(struct msi_controller___11 *, struct pci_dev___27 *, struct msi_desc___14 *);
	int (*setup_irqs)(struct msi_controller___11 *, struct pci_dev___27 *, int, int);
	void (*teardown_irq)(struct msi_controller___11 *, unsigned int);
};

struct pci_error_handlers___27 {
	pci_ers_result_t (*error_detected)(struct pci_dev___27 *, enum pci_channel_state);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___27 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___27 *);
	void (*reset_prepare)(struct pci_dev___27 *);
	void (*reset_done)(struct pci_dev___27 *);
	void (*resume)(struct pci_dev___27 *);
};

struct acpi_pci_root___4 {
	struct acpi_device___10 *device;
	struct pci_bus___27 *bus;
	u16 segment;
	struct resource secondary;
	u32 osc_support_set;
	u32 osc_control_set;
	phys_addr_t mcfg_addr;
};

struct acpi_pci_root_ops___2;

struct acpi_pci_root_info___2 {
	struct acpi_pci_root___4 *root;
	struct acpi_device___10 *bridge;
	struct acpi_pci_root_ops___2 *ops;
	struct list_head resources;
	char name[16];
};

struct acpi_pci_root_ops___2 {
	struct pci_ops___27 *pci_ops;
	int (*init_info)(struct acpi_pci_root_info___2 *);
	void (*release_info)(struct acpi_pci_root_info___2 *);
	int (*prepare_resources)(struct acpi_pci_root_info___2 *);
};

struct msi_desc___14 {
	struct list_head list;
	unsigned int irq;
	unsigned int nvec_used;
	struct device___274 *dev;
	struct msi_msg msg;
	struct irq_affinity_desc *affinity;
	const void *iommu_cookie;
	union {
		struct {
			u32 masked;
			struct {
				u8 is_msix: 1;
				u8 multiple: 3;
				u8 multi_cap: 3;
				u8 maskbit: 1;
				u8 is_64: 1;
				u16 entry_nr;
				unsigned int default_irq;
			} msi_attrib;
			union {
				u8 mask_pos;
				void *mask_base;
			};
		};
		struct platform_msi_desc platform;
		struct fsl_mc_msi_desc fsl_mc;
	};
};

struct pci_osc_bit_struct {
	u32 bit;
	char *desc;
};

struct acpi_handle_node {
	struct list_head node;
	acpi_handle handle;
};

struct irq_chip___22;

struct irq_data___22 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___11 *common;
	struct irq_chip___22 *chip;
	struct irq_domain *domain;
	struct irq_data___22 *parent_data;
	void *chip_data;
};

struct irq_chip___22 {
	struct device___274 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___22 *);
	void (*irq_shutdown)(struct irq_data___22 *);
	void (*irq_enable)(struct irq_data___22 *);
	void (*irq_disable)(struct irq_data___22 *);
	void (*irq_ack)(struct irq_data___22 *);
	void (*irq_mask)(struct irq_data___22 *);
	void (*irq_mask_ack)(struct irq_data___22 *);
	void (*irq_unmask)(struct irq_data___22 *);
	void (*irq_eoi)(struct irq_data___22 *);
	int (*irq_set_affinity)(struct irq_data___22 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___22 *);
	int (*irq_set_type)(struct irq_data___22 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___22 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___22 *);
	void (*irq_bus_sync_unlock)(struct irq_data___22 *);
	void (*irq_cpu_online)(struct irq_data___22 *);
	void (*irq_cpu_offline)(struct irq_data___22 *);
	void (*irq_suspend)(struct irq_data___22 *);
	void (*irq_resume)(struct irq_data___22 *);
	void (*irq_pm_shutdown)(struct irq_data___22 *);
	void (*irq_calc_mask)(struct irq_data___22 *);
	void (*irq_print_chip)(struct irq_data___22 *, struct seq_file___261 *);
	int (*irq_request_resources)(struct irq_data___22 *);
	void (*irq_release_resources)(struct irq_data___22 *);
	void (*irq_compose_msi_msg)(struct irq_data___22 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___22 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___22 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___22 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___22 *, void *);
	void (*ipi_send_single)(struct irq_data___22 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___22 *, const struct cpumask *);
	long unsigned int flags;
};

struct acpi_pci_link_irq {
	u32 active;
	u8 triggering;
	u8 polarity;
	u8 resource_type;
	u8 possible_count;
	u32 possible[16];
	u8 initialized: 1;
	u8 reserved: 7;
};

struct acpi_pci_link {
	struct list_head list;
	struct acpi_device___10 *device;
	struct acpi_pci_link_irq irq;
	int refcnt;
};

struct acpi_pci_routing_table {
	u32 length;
	u32 pin;
	u64 address;
	u32 source_index;
	char source[4];
};

struct acpi_prt_entry {
	struct acpi_pci_id id;
	u8 pin;
	acpi_handle link;
	u32 index;
};

struct prt_quirk {
	const struct dmi_system_id *system;
	unsigned int segment;
	unsigned int bus;
	unsigned int device;
	unsigned char pin;
	const char *source;
	const char *actual_source;
};

struct clk_init_data___3;

struct clk_hw___3 {
	struct clk_core *core;
	struct clk *clk;
	const struct clk_init_data___3 *init;
};

struct clk_rate_request___3 {
	long unsigned int rate;
	long unsigned int min_rate;
	long unsigned int max_rate;
	long unsigned int best_parent_rate;
	struct clk_hw___3 *best_parent_hw;
};

struct clk_ops___3 {
	int (*prepare)(struct clk_hw___3 *);
	void (*unprepare)(struct clk_hw___3 *);
	int (*is_prepared)(struct clk_hw___3 *);
	void (*unprepare_unused)(struct clk_hw___3 *);
	int (*enable)(struct clk_hw___3 *);
	void (*disable)(struct clk_hw___3 *);
	int (*is_enabled)(struct clk_hw___3 *);
	void (*disable_unused)(struct clk_hw___3 *);
	long unsigned int (*recalc_rate)(struct clk_hw___3 *, long unsigned int);
	long int (*round_rate)(struct clk_hw___3 *, long unsigned int, long unsigned int *);
	int (*determine_rate)(struct clk_hw___3 *, struct clk_rate_request___3 *);
	int (*set_parent)(struct clk_hw___3 *, u8);
	u8 (*get_parent)(struct clk_hw___3 *);
	int (*set_rate)(struct clk_hw___3 *, long unsigned int, long unsigned int);
	int (*set_rate_and_parent)(struct clk_hw___3 *, long unsigned int, long unsigned int, u8);
	long unsigned int (*recalc_accuracy)(struct clk_hw___3 *, long unsigned int);
	int (*get_phase)(struct clk_hw___3 *);
	int (*set_phase)(struct clk_hw___3 *, int);
	void (*init)(struct clk_hw___3 *);
	void (*debug_init)(struct clk_hw___3 *, struct dentry___307 *);
};

struct clk_init_data___3 {
	const char *name;
	const struct clk_ops___3 *ops;
	const char * const *parent_names;
	u8 num_parents;
	long unsigned int flags;
};

struct module___250;

struct file___310;

struct kiocb___310;

struct poll_table_struct___187;

struct vm_area_struct___311;

struct inode___310;

struct file_lock___310;

struct page___311;

struct seq_file___262;

struct file_operations___310 {
	struct module___250 *owner;
	loff_t (*llseek)(struct file___310 *, loff_t, int);
	ssize_t (*read)(struct file___310 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___310 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___310 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___310 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___310 *, bool);
	int (*iterate)(struct file___310 *, struct dir_context *);
	int (*iterate_shared)(struct file___310 *, struct dir_context *);
	__poll_t (*poll)(struct file___310 *, struct poll_table_struct___187 *);
	long int (*unlocked_ioctl)(struct file___310 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___310 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___310 *, struct vm_area_struct___311 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___310 *, struct file___310 *);
	int (*flush)(struct file___310 *, fl_owner_t);
	int (*release)(struct inode___310 *, struct file___310 *);
	int (*fsync)(struct file___310 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___310 *, int);
	int (*lock)(struct file___310 *, int, struct file_lock___310 *);
	ssize_t (*sendpage)(struct file___310 *, struct page___311 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___310 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___310 *, int, struct file_lock___310 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___310 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___310 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___310 *, long int, struct file_lock___310 **, void **);
	long int (*fallocate)(struct file___310 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___262 *, struct file___310 *);
	ssize_t (*copy_file_range)(struct file___310 *, loff_t, struct file___310 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___310 *, loff_t, struct file___310 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___310 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___311 *pgtable_t___310;

struct address_space___309;

struct mm_struct___310;

struct dev_pagemap___299;

struct page___311 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___309 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___311 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___310 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___310 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___299 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct vmacache___310 {
	u64 seqnum;
	struct vm_area_struct___311 *vmas[4];
};

struct vm_operations_struct___299;

struct vm_area_struct___311 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___311 *vm_next;
	struct vm_area_struct___311 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___310 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___299 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___310 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct page_frag___310 {
	struct page___311 *page;
	__u32 offset;
	__u32 size;
};

struct cred___288;

struct vm_struct___226;

struct task_struct___311 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___311 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___310 *mm;
	struct mm_struct___310 *active_mm;
	struct vmacache___310 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___311 *real_parent;
	struct task_struct___311 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___311 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___204 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___204 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___204 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___288 *ptracer_cred;
	const struct cred___288 *real_cred;
	const struct cred___288 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___311 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___82 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___310 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___311 *oom_reaper_list;
	struct vm_struct___226 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___131 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rw_semaphore___311 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___311 *owner;
};

struct core_state___310;

struct mm_struct___310 {
	struct {
		struct vm_area_struct___311 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___310 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___311 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___310 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___311 *owner;
		struct user_namespace___3 *user_ns;
		struct file___310 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___310 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct secondary_data___311 {
	void *stack;
	struct task_struct___311 *task;
	long int status;
};

struct address_space_operations___309;

struct address_space___309 {
	struct inode___310 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___311 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___309 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___299)(struct vm_area_struct___311 *, long unsigned int, const struct page___311 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___299)(struct page___311 *, void *);

struct device___275;

struct dev_pagemap___299 {
	dev_page_fault_t___299 page_fault;
	dev_page_free_t___299 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___275 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___310 {
	struct vfsmount *mnt;
	struct dentry___218 *dentry;
};

struct file___310 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___310 f_path;
	struct inode___310 *f_inode;
	const struct file_operations___310 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___204 f_owner;
	const struct cred___288 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___309 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___299;

struct vm_operations_struct___299 {
	void (*open)(struct vm_area_struct___311 *);
	void (*close)(struct vm_area_struct___311 *);
	int (*split)(struct vm_area_struct___311 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___311 *);
	vm_fault_t (*fault)(struct vm_fault___299 *);
	vm_fault_t (*huge_fault)(struct vm_fault___299 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___299 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___311 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___299 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___299 *);
	int (*access)(struct vm_area_struct___311 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___311 *);
	int (*set_policy)(struct vm_area_struct___311 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___311 *, long unsigned int);
	struct page___311 * (*find_special_page)(struct vm_area_struct___311 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___310 {
	struct task_struct___311 *task;
	struct core_thread___310 *next;
};

struct core_state___310 {
	atomic_t nr_threads;
	struct core_thread___310 dumper;
	struct completion startup;
};

struct vm_fault___299 {
	struct vm_area_struct___311 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___311 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___311 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___310 prealloc_pte;
};

struct key___288;

struct user_struct___288 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___288 *uid_keyring;
	struct key___288 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___288 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___288 *session_keyring;
	struct key___288 *process_keyring;
	struct key___288 *thread_keyring;
	struct key___288 *request_key_auth;
	void *security;
	struct user_struct___288 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct vm_struct___226 {
	struct vm_struct___226 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___311 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct fwnode_operations___209;

struct fwnode_handle___209 {
	struct fwnode_handle___209 *secondary;
	const struct fwnode_operations___209 *ops;
};

struct fwnode_reference_args___209;

struct fwnode_endpoint___209;

struct fwnode_operations___209 {
	struct fwnode_handle___209 * (*get)(struct fwnode_handle___209 *);
	void (*put)(struct fwnode_handle___209 *);
	bool (*device_is_available)(const struct fwnode_handle___209 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___209 *, const struct device___275 *);
	bool (*property_present)(const struct fwnode_handle___209 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___209 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___209 *, const char *, const char **, size_t);
	struct fwnode_handle___209 * (*get_parent)(const struct fwnode_handle___209 *);
	struct fwnode_handle___209 * (*get_next_child_node)(const struct fwnode_handle___209 *, struct fwnode_handle___209 *);
	struct fwnode_handle___209 * (*get_named_child_node)(const struct fwnode_handle___209 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___209 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___209 *);
	struct fwnode_handle___209 * (*graph_get_next_endpoint)(const struct fwnode_handle___209 *, struct fwnode_handle___209 *);
	struct fwnode_handle___209 * (*graph_get_remote_endpoint)(const struct fwnode_handle___209 *);
	struct fwnode_handle___209 * (*graph_get_port_parent)(struct fwnode_handle___209 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___209 *, struct fwnode_endpoint___209 *);
};

struct fwnode_endpoint___209 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___209 *local_fwnode;
};

struct fwnode_reference_args___209 {
	struct fwnode_handle___209 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct kset___296;

struct kobj_type___296;

struct kernfs_node___304;

struct kobject___297 {
	const char *name;
	struct list_head entry;
	struct kobject___297 *parent;
	struct kset___296 *kset;
	struct kobj_type___296 *ktype;
	struct kernfs_node___304 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct pm_subsys_data___2;

struct dev_pm_info___275 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___2 *subsys_data;
	void (*set_latency_tolerance)(struct device___275 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___275;

struct bus_type___275;

struct device_driver___275;

struct dev_pm_domain___275;

struct device_node___67;

struct class___275;

struct attribute_group___274;

struct device___275 {
	struct device___275 *parent;
	struct device_private *p;
	struct kobject___297 kobj;
	const char *init_name;
	const struct device_type___275 *type;
	struct mutex mutex;
	struct bus_type___275 *bus;
	struct device_driver___275 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___275 power;
	struct dev_pm_domain___275 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___67 *of_node;
	struct fwnode_handle___209 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___275 *class;
	const struct attribute_group___274 **groups;
	void (*release)(struct device___275 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct pglist_data___310;

struct lruvec___310 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___310 *pgdat;
};

struct zone___310 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___310 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___310 {
	struct zone___310 *zone;
	int zone_idx;
};

struct zonelist___310 {
	struct zoneref___310 _zonerefs[25];
};

struct pglist_data___310 {
	struct zone___310 node_zones[3];
	struct zonelist___310 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___311 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___311 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___310 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___310 {
	struct rw_semaphore___311 rwsem;
	struct notifier_block *head;
};

struct kernfs_root___303;

struct kernfs_elem_dir___303 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___303 *root;
};

struct kernfs_syscall_ops___303;

struct kernfs_root___303 {
	struct kernfs_node___304 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___303 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___303 {
	struct kernfs_node___304 *target_kn;
};

struct kernfs_ops___303;

struct kernfs_elem_attr___303 {
	const struct kernfs_ops___303 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___304 *notify_next;
};

struct kernfs_node___304 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___304 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___303 dir;
		struct kernfs_elem_symlink___303 symlink;
		struct kernfs_elem_attr___303 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___303;

struct kernfs_ops___303 {
	int (*open)(struct kernfs_open_file___303 *);
	void (*release)(struct kernfs_open_file___303 *);
	int (*seq_show)(struct seq_file___262 *, void *);
	void * (*seq_start)(struct seq_file___262 *, loff_t *);
	void * (*seq_next)(struct seq_file___262 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___262 *, void *);
	ssize_t (*read)(struct kernfs_open_file___303 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___303 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___303 *, struct vm_area_struct___311 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___303 *, struct poll_table_struct___187 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___303 {
	int (*remount_fs)(struct kernfs_root___303 *, int *, char *);
	int (*show_options)(struct seq_file___262 *, struct kernfs_root___303 *);
	int (*mkdir)(struct kernfs_node___304 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___304 *);
	int (*rename)(struct kernfs_node___304 *, struct kernfs_node___304 *, const char *);
	int (*show_path)(struct seq_file___262 *, struct kernfs_node___304 *, struct kernfs_root___303 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___261;

struct seq_file___262 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___261 *op;
	int poll_event;
	const struct file___310 *file;
	void *private;
};

struct kernfs_open_file___303 {
	struct kernfs_node___304 *kn;
	struct file___310 *file;
	struct seq_file___262 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___299 *vm_ops;
};

typedef void (*poll_queue_proc___191)(struct file___310 *, wait_queue_head_t *, struct poll_table_struct___187 *);

struct poll_table_struct___187 {
	poll_queue_proc___191 _qproc;
	__poll_t _key;
};

struct bin_attribute___273;

struct attribute_group___274 {
	const char *name;
	umode_t (*is_visible)(struct kobject___297 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___297 *, struct bin_attribute___273 *, int);
	struct attribute **attrs;
	struct bin_attribute___273 **bin_attrs;
};

struct bin_attribute___273 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___310 *, struct kobject___297 *, struct bin_attribute___273 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___310 *, struct kobject___297 *, struct bin_attribute___273 *, char *, loff_t, size_t);
	int (*mmap)(struct file___310 *, struct kobject___297 *, struct bin_attribute___273 *, struct vm_area_struct___311 *);
};

struct sysfs_ops___296 {
	ssize_t (*show)(struct kobject___297 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___297 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___296;

struct kset___296 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___297 kobj;
	const struct kset_uevent_ops___296 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___296 {
	void (*release)(struct kobject___297 *);
	const struct sysfs_ops___296 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___25 * (*child_ns_type)(struct kobject___297 *);
	const void * (*namespace)(struct kobject___297 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___296 {
	int (* const filter)(struct kset___296 *, struct kobject___297 *);
	const char * (* const name)(struct kset___296 *, struct kobject___297 *);
	int (* const uevent)(struct kset___296 *, struct kobject___297 *, struct kobj_uevent_env *);
};

struct kobj_attribute___289 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___297 *, struct kobj_attribute___289 *, char *);
	ssize_t (*store)(struct kobject___297 *, struct kobj_attribute___289 *, const char *, size_t);
};

struct property___64 {
	char *name;
	int length;
	void *value;
	struct property___64 *next;
	long unsigned int _flags;
	struct bin_attribute___273 attr;
};

struct device_node___67 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___209 fwnode;
	struct property___64 *properties;
	struct property___64 *deadprops;
	struct device_node___67 *parent;
	struct device_node___67 *child;
	struct device_node___67 *sibling;
	struct kobject___297 kobj;
	long unsigned int _flags;
	void *data;
};

struct clk_hw___4;

struct clk_rate_request___4 {
	long unsigned int rate;
	long unsigned int min_rate;
	long unsigned int max_rate;
	long unsigned int best_parent_rate;
	struct clk_hw___4 *best_parent_hw;
};

struct clk_init_data___4;

struct clk_hw___4 {
	struct clk_core *core;
	struct clk *clk;
	const struct clk_init_data___4 *init;
};

struct clk_ops___4 {
	int (*prepare)(struct clk_hw___4 *);
	void (*unprepare)(struct clk_hw___4 *);
	int (*is_prepared)(struct clk_hw___4 *);
	void (*unprepare_unused)(struct clk_hw___4 *);
	int (*enable)(struct clk_hw___4 *);
	void (*disable)(struct clk_hw___4 *);
	int (*is_enabled)(struct clk_hw___4 *);
	void (*disable_unused)(struct clk_hw___4 *);
	long unsigned int (*recalc_rate)(struct clk_hw___4 *, long unsigned int);
	long int (*round_rate)(struct clk_hw___4 *, long unsigned int, long unsigned int *);
	int (*determine_rate)(struct clk_hw___4 *, struct clk_rate_request___4 *);
	int (*set_parent)(struct clk_hw___4 *, u8);
	u8 (*get_parent)(struct clk_hw___4 *);
	int (*set_rate)(struct clk_hw___4 *, long unsigned int, long unsigned int);
	int (*set_rate_and_parent)(struct clk_hw___4 *, long unsigned int, long unsigned int, u8);
	long unsigned int (*recalc_accuracy)(struct clk_hw___4 *, long unsigned int);
	int (*get_phase)(struct clk_hw___4 *);
	int (*set_phase)(struct clk_hw___4 *, int);
	void (*init)(struct clk_hw___4 *);
	void (*debug_init)(struct clk_hw___4 *, struct dentry___218 *);
};

struct dentry_operations___309;

struct super_block___309;

struct dentry___218 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___218 *d_parent;
	struct qstr d_name;
	struct inode___310 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___309 *d_op;
	struct super_block___309 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct clk_init_data___4 {
	const char *name;
	const struct clk_ops___4 *ops;
	const char * const *parent_names;
	u8 num_parents;
	long unsigned int flags;
};

struct dev_pm_ops___275 {
	int (*prepare)(struct device___275 *);
	void (*complete)(struct device___275 *);
	int (*suspend)(struct device___275 *);
	int (*resume)(struct device___275 *);
	int (*freeze)(struct device___275 *);
	int (*thaw)(struct device___275 *);
	int (*poweroff)(struct device___275 *);
	int (*restore)(struct device___275 *);
	int (*suspend_late)(struct device___275 *);
	int (*resume_early)(struct device___275 *);
	int (*freeze_late)(struct device___275 *);
	int (*thaw_early)(struct device___275 *);
	int (*poweroff_late)(struct device___275 *);
	int (*restore_early)(struct device___275 *);
	int (*suspend_noirq)(struct device___275 *);
	int (*resume_noirq)(struct device___275 *);
	int (*freeze_noirq)(struct device___275 *);
	int (*thaw_noirq)(struct device___275 *);
	int (*poweroff_noirq)(struct device___275 *);
	int (*restore_noirq)(struct device___275 *);
	int (*runtime_suspend)(struct device___275 *);
	int (*runtime_resume)(struct device___275 *);
	int (*runtime_idle)(struct device___275 *);
};

struct pm_domain_data___2;

struct pm_subsys_data___2 {
	spinlock_t lock;
	unsigned int refcount;
	struct list_head clock_list;
	struct pm_domain_data___2 *domain_data;
};

struct pm_domain_data___2 {
	struct list_head list_node;
	struct device___275 *dev;
};

struct dev_pm_domain___275 {
	struct dev_pm_ops___275 ops;
	void (*detach)(struct device___275 *, bool);
	int (*activate)(struct device___275 *);
	void (*sync)(struct device___275 *);
	void (*dismiss)(struct device___275 *);
};

struct bus_type___275 {
	const char *name;
	const char *dev_name;
	struct device___275 *dev_root;
	const struct attribute_group___274 **bus_groups;
	const struct attribute_group___274 **dev_groups;
	const struct attribute_group___274 **drv_groups;
	int (*match)(struct device___275 *, struct device_driver___275 *);
	int (*uevent)(struct device___275 *, struct kobj_uevent_env *);
	int (*probe)(struct device___275 *);
	int (*remove)(struct device___275 *);
	void (*shutdown)(struct device___275 *);
	int (*online)(struct device___275 *);
	int (*offline)(struct device___275 *);
	int (*suspend)(struct device___275 *, pm_message_t);
	int (*resume)(struct device___275 *);
	int (*num_vf)(struct device___275 *);
	int (*dma_configure)(struct device___275 *);
	const struct dev_pm_ops___275 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___275 {
	const char *name;
	struct bus_type___275 *bus;
	struct module___250 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___275 *);
	int (*remove)(struct device___275 *);
	void (*shutdown)(struct device___275 *);
	int (*suspend)(struct device___275 *, pm_message_t);
	int (*resume)(struct device___275 *);
	const struct attribute_group___274 **groups;
	const struct dev_pm_ops___275 *pm;
	void (*coredump)(struct device___275 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___275 {
	const char *name;
	const struct attribute_group___274 **groups;
	int (*uevent)(struct device___275 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___275 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___275 *);
	const struct dev_pm_ops___275 *pm;
};

struct module_kobject___247 {
	struct kobject___297 kobj;
	struct module___250 *mod;
	struct kobject___297 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___247 {
	struct module___250 *mod;
	struct latch_tree_node node;
};

struct module_layout___247 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___247 mtn;
};

struct module_attribute___247;

struct kernel_param___247;

struct module___250 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___247 mkobj;
	struct module_attribute___247 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___297 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___247 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___247 core_layout;
	struct module_layout___247 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct class___275 {
	const char *name;
	struct module___250 *owner;
	const struct attribute_group___274 **class_groups;
	const struct attribute_group___274 **dev_groups;
	struct kobject___297 *dev_kobj;
	int (*dev_uevent)(struct device___275 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___275 *, umode_t *);
	void (*class_release)(struct class___275 *);
	void (*dev_release)(struct device___275 *);
	int (*shutdown_pre)(struct device___275 *);
	const struct kobj_ns_type_operations___25 *ns_type;
	const void * (*namespace)(struct device___275 *);
	const struct dev_pm_ops___275 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct platform_device___14 {
	const char *name;
	int id;
	bool id_auto;
	struct device___275 dev;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct dev_power_governor___2 {
	bool (*power_down_ok)(struct dev_pm_domain___275 *);
	bool (*suspend_ok)(struct device___275 *);
};

struct kernel_param_ops___247 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___247 *);
	int (*get)(char *, const struct kernel_param___247 *);
	void (*free)(void *);
};

struct kparam_array___247;

struct kernel_param___247 {
	const char *name;
	struct module___250 *mod;
	const struct kernel_param_ops___247 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___247 *arr;
	};
};

struct kparam_array___247 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___247 *ops;
	void *elem;
};

struct module_attribute___247 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___247 *, struct module_kobject___247 *, char *);
	ssize_t (*store)(struct module_attribute___247 *, struct module_kobject___247 *, const char *, size_t);
	void (*setup)(struct module___250 *, const char *);
	int (*test)(struct module___250 *);
	void (*free)(struct module___250 *);
};

struct inode_operations___309;

struct block_device___309;

struct cdev___60;

struct inode___310 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___309 *i_op;
	struct super_block___309 *i_sb;
	struct address_space___309 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___311 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___310 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___309 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___309 *i_bdev;
		struct cdev___60 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___309 {
	int (*d_revalidate)(struct dentry___218 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___218 *, unsigned int);
	int (*d_hash)(const struct dentry___218 *, struct qstr *);
	int (*d_compare)(const struct dentry___218 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___218 *);
	int (*d_init)(struct dentry___218 *);
	void (*d_release)(struct dentry___218 *);
	void (*d_prune)(struct dentry___218 *);
	void (*d_iput)(struct dentry___218 *, struct inode___310 *);
	char * (*d_dname)(struct dentry___218 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___310 *);
	int (*d_manage)(const struct path___310 *, bool);
	struct dentry___218 * (*d_real)(struct dentry___218 *, const struct inode___310 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___309;

struct mem_dqinfo___309 {
	struct quota_format_type___309 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___309;

struct quota_info___309 {
	unsigned int flags;
	struct rw_semaphore___311 dqio_sem;
	struct inode___310 *files[3];
	struct mem_dqinfo___309 info[3];
	const struct quota_format_ops___309 *ops[3];
};

struct rcuwait___309 {
	struct task_struct___311 *task;
};

struct percpu_rw_semaphore___309 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___311 rw_sem;
	struct rcuwait___309 writer;
	int readers_block;
};

struct sb_writers___309 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___309 rw_sem[3];
};

struct file_system_type___309;

struct super_operations___309;

struct dquot_operations___309;

struct quotactl_ops___309;

struct super_block___309 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___309 *s_type;
	const struct super_operations___309 *s_op;
	const struct dquot_operations___309 *dq_op;
	const struct quotactl_ops___309 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___218 *s_root;
	struct rw_semaphore___311 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___309 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___309 s_dquot;
	struct sb_writers___309 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___309 *s_d_op;
	int cleancache_poolid;
	struct shrinker___119 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___310 {
	struct file___310 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___310 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___309 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___310 *ia_file;
};

struct dquot___309 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___309 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___309 {
	int qf_fmt_id;
	const struct quota_format_ops___309 *qf_ops;
	struct module___250 *qf_owner;
	struct quota_format_type___309 *qf_next;
};

struct quota_format_ops___309 {
	int (*check_quota_file)(struct super_block___309 *, int);
	int (*read_file_info)(struct super_block___309 *, int);
	int (*write_file_info)(struct super_block___309 *, int);
	int (*free_file_info)(struct super_block___309 *, int);
	int (*read_dqblk)(struct dquot___309 *);
	int (*commit_dqblk)(struct dquot___309 *);
	int (*release_dqblk)(struct dquot___309 *);
	int (*get_next_id)(struct super_block___309 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___309 {
	int (*write_dquot)(struct dquot___309 *);
	struct dquot___309 * (*alloc_dquot)(struct super_block___309 *, int);
	void (*destroy_dquot)(struct dquot___309 *);
	int (*acquire_dquot)(struct dquot___309 *);
	int (*release_dquot)(struct dquot___309 *);
	int (*mark_dirty)(struct dquot___309 *);
	int (*write_info)(struct super_block___309 *, int);
	qsize_t * (*get_reserved_space)(struct inode___310 *);
	int (*get_projid)(struct inode___310 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___310 *, qsize_t *);
	int (*get_next_id)(struct super_block___309 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___309 {
	int (*quota_on)(struct super_block___309 *, int, int, const struct path___310 *);
	int (*quota_off)(struct super_block___309 *, int);
	int (*quota_enable)(struct super_block___309 *, unsigned int);
	int (*quota_disable)(struct super_block___309 *, unsigned int);
	int (*quota_sync)(struct super_block___309 *, int);
	int (*set_info)(struct super_block___309 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___309 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___309 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___309 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___309 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___309 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___309 {
	int (*writepage)(struct page___311 *, struct writeback_control___3 *);
	int (*readpage)(struct file___310 *, struct page___311 *);
	int (*writepages)(struct address_space___309 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___311 *);
	int (*readpages)(struct file___310 *, struct address_space___309 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___310 *, struct address_space___309 *, loff_t, unsigned int, unsigned int, struct page___311 **, void **);
	int (*write_end)(struct file___310 *, struct address_space___309 *, loff_t, unsigned int, unsigned int, struct page___311 *, void *);
	sector_t (*bmap)(struct address_space___309 *, sector_t);
	void (*invalidatepage)(struct page___311 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___311 *, gfp_t);
	void (*freepage)(struct page___311 *);
	ssize_t (*direct_IO)(struct kiocb___310 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___309 *, struct page___311 *, struct page___311 *, enum migrate_mode);
	bool (*isolate_page)(struct page___311 *, isolate_mode_t);
	void (*putback_page)(struct page___311 *);
	int (*launder_page)(struct page___311 *);
	int (*is_partially_uptodate)(struct page___311 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___311 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___309 *, struct page___311 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___310 *, sector_t *);
	void (*swap_deactivate)(struct file___310 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___309 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___310 *bd_inode;
	struct super_block___309 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___309 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___60 {
	struct kobject___297 kobj;
	struct module___250 *owner;
	const struct file_operations___310 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___309 {
	struct dentry___218 * (*lookup)(struct inode___310 *, struct dentry___218 *, unsigned int);
	const char * (*get_link)(struct dentry___218 *, struct inode___310 *, struct delayed_call *);
	int (*permission)(struct inode___310 *, int);
	struct posix_acl * (*get_acl)(struct inode___310 *, int);
	int (*readlink)(struct dentry___218 *, char *, int);
	int (*create)(struct inode___310 *, struct dentry___218 *, umode_t, bool);
	int (*link)(struct dentry___218 *, struct inode___310 *, struct dentry___218 *);
	int (*unlink)(struct inode___310 *, struct dentry___218 *);
	int (*symlink)(struct inode___310 *, struct dentry___218 *, const char *);
	int (*mkdir)(struct inode___310 *, struct dentry___218 *, umode_t);
	int (*rmdir)(struct inode___310 *, struct dentry___218 *);
	int (*mknod)(struct inode___310 *, struct dentry___218 *, umode_t, dev_t);
	int (*rename)(struct inode___310 *, struct dentry___218 *, struct inode___310 *, struct dentry___218 *, unsigned int);
	int (*setattr)(struct dentry___218 *, struct iattr___309 *);
	int (*getattr)(const struct path___310 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___218 *, char *, size_t);
	int (*fiemap)(struct inode___310 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___310 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___310 *, struct dentry___218 *, struct file___310 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___310 *, struct dentry___218 *, umode_t);
	int (*set_acl)(struct inode___310 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___309 {
	void (*fl_copy_lock)(struct file_lock___310 *, struct file_lock___310 *);
	void (*fl_release_private)(struct file_lock___310 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___309;

struct lock_manager_operations___309;

struct file_lock___310 {
	struct file_lock___310 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___310 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___309 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___309 *fl_ops;
	const struct lock_manager_operations___309 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___309 {
	int (*lm_compare_owner)(struct file_lock___310 *, struct file_lock___310 *);
	long unsigned int (*lm_owner_key)(struct file_lock___310 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___310 *);
	int (*lm_grant)(struct file_lock___310 *, int);
	bool (*lm_break)(struct file_lock___310 *);
	int (*lm_change)(struct file_lock___310 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___310 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___309 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___309 *fa_next;
	struct file___310 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___309 {
	const char *name;
	int fs_flags;
	struct dentry___218 * (*mount)(struct file_system_type___309 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___309 *);
	struct module___250 *owner;
	struct file_system_type___309 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___309 {
	struct inode___310 * (*alloc_inode)(struct super_block___309 *);
	void (*destroy_inode)(struct inode___310 *);
	void (*dirty_inode)(struct inode___310 *, int);
	int (*write_inode)(struct inode___310 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___310 *);
	void (*evict_inode)(struct inode___310 *);
	void (*put_super)(struct super_block___309 *);
	int (*sync_fs)(struct super_block___309 *, int);
	int (*freeze_super)(struct super_block___309 *);
	int (*freeze_fs)(struct super_block___309 *);
	int (*thaw_super)(struct super_block___309 *);
	int (*unfreeze_fs)(struct super_block___309 *);
	int (*statfs)(struct dentry___218 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___309 *, int *, char *);
	void (*umount_begin)(struct super_block___309 *);
	int (*show_options)(struct seq_file___262 *, struct dentry___218 *);
	int (*show_devname)(struct seq_file___262 *, struct dentry___218 *);
	int (*show_path)(struct seq_file___262 *, struct dentry___218 *);
	int (*show_stats)(struct seq_file___262 *, struct dentry___218 *);
	ssize_t (*quota_read)(struct super_block___309 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___309 *, int, const char *, size_t, loff_t);
	struct dquot___309 ** (*get_dquots)(struct inode___310 *);
	int (*bdev_try_to_free_page)(struct super_block___309 *, struct page___311 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___309 *, struct shrink_control___119 *);
	long int (*free_cached_objects)(struct super_block___309 *, struct shrink_control___119 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct acpi_device___11;

struct acpi_hotplug_profile___11 {
	struct kobject___297 kobj;
	int (*scan_dependent)(struct acpi_device___11 *);
	void (*notify_online)(struct acpi_device___11 *);
	bool enabled: 1;
	bool demand_offline: 1;
};

struct acpi_device_wakeup_context___11 {
	void (*func)(struct acpi_device_wakeup_context___11 *);
	struct device___275 *dev;
};

struct acpi_device_wakeup___11 {
	acpi_handle gpe_device;
	u64 gpe_number;
	u64 sleep_state;
	struct list_head resources;
	struct acpi_device_wakeup_flags flags;
	struct acpi_device_wakeup_context___11 context;
	struct wakeup_source *ws;
	int prepare_count;
	int enable_count;
};

struct acpi_scan_handler___11;

struct acpi_hotplug_context___11;

struct acpi_driver___11;

struct acpi_device___11 {
	int device_type;
	acpi_handle handle;
	struct fwnode_handle___209 fwnode;
	struct acpi_device___11 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup___11 wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_device_data data;
	struct acpi_scan_handler___11 *handler;
	struct acpi_hotplug_context___11 *hp;
	struct acpi_driver___11 *driver;
	const struct acpi_gpio_mapping *driver_gpios;
	void *driver_data;
	struct device___275 dev;
	unsigned int physical_node_count;
	unsigned int dep_unmet;
	struct list_head physical_node_list;
	struct mutex physical_node_lock;
	void (*remove)(struct acpi_device___11 *);
};

struct acpi_scan_handler___11 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	bool (*match)(const char *, const struct acpi_device_id **);
	int (*attach)(struct acpi_device___11 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___11 *);
	void (*bind)(struct device___275 *);
	void (*unbind)(struct device___275 *);
	struct acpi_hotplug_profile___11 hotplug;
};

struct acpi_hotplug_context___11 {
	struct acpi_device___11 *self;
	int (*notify)(struct acpi_device___11 *, u32);
	void (*uevent)(struct acpi_device___11 *, u32);
	void (*fixup)(struct acpi_device___11 *);
};

typedef int (*acpi_op_add___11)(struct acpi_device___11 *);

typedef int (*acpi_op_remove___11)(struct acpi_device___11 *);

typedef void (*acpi_op_notify___11)(struct acpi_device___11 *, u32);

struct acpi_device_ops___11 {
	acpi_op_add___11 add;
	acpi_op_remove___11 remove;
	acpi_op_notify___11 notify;
};

struct acpi_driver___11 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___11 ops;
	struct device_driver___275 drv;
	struct module___250 *owner;
};

typedef int (*key_restrict_link_func_t___289)(struct key___288 *, const struct key_type *, const union key_payload *, struct key___288 *);

struct key_restriction___288;

struct key___288 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___311 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___288 *restrict_link;
};

struct key_restriction___288 {
	key_restrict_link_func_t___289 check;
	struct key___288 *key;
	struct key_type *keytype;
};

struct seq_operations___261 {
	void * (*start)(struct seq_file___262 *, loff_t *);
	void (*stop)(struct seq_file___262 *, void *);
	void * (*next)(struct seq_file___262 *, void *, loff_t *);
	int (*show)(struct seq_file___262 *, void *);
};

typedef void compound_page_dtor___299(struct page___311 *);

struct apd_private_data;

struct apd_device_desc {
	unsigned int flags;
	unsigned int fixed_clk_rate;
	struct property_entry___2 *properties;
	int (*setup)(struct apd_private_data *);
};

struct apd_private_data {
	struct clk *clk;
	struct acpi_device___11 *adev;
	const struct apd_device_desc *dev_desc;
};

struct platform_device_info___2 {
	struct device___272 *parent;
	struct fwnode_handle___12 *fwnode;
	const char *name;
	int id;
	const struct resource *res;
	unsigned int num_res;
	const void *data;
	size_t size_data;
	u64 dma_mask;
	struct property_entry___2 *properties;
};

struct amba_device___3 {
	struct device___272 dev;
	struct resource res;
	struct clk *pclk;
	unsigned int periphid;
	unsigned int irq[9];
	char *driver_override;
};

struct device_attribute___21 {
	struct attribute attr;
	ssize_t (*show)(struct device___274 *, struct device_attribute___21 *, char *);
	ssize_t (*store)(struct device___274 *, struct device_attribute___21 *, const char *, size_t);
};

struct acpi_power_resource {
	struct acpi_device___10 device;
	struct list_head list_node;
	char *name;
	u32 system_level;
	u32 order;
	unsigned int ref_count;
	bool wakeup_enabled;
	struct mutex resource_lock;
};

struct acpi_power_resource_entry {
	struct list_head node;
	struct acpi_power_resource *resource;
};

struct module___251;

struct file___311;

struct kiocb___311;

struct iov_iter___138;

struct poll_table_struct___188;

struct vm_area_struct___312;

struct inode___311;

struct file_lock___311;

struct page___312;

struct pipe_inode_info___68;

struct seq_file___263;

struct file_operations___311 {
	struct module___251 *owner;
	loff_t (*llseek)(struct file___311 *, loff_t, int);
	ssize_t (*read)(struct file___311 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___311 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___311 *, struct iov_iter___138 *);
	ssize_t (*write_iter)(struct kiocb___311 *, struct iov_iter___138 *);
	int (*iopoll)(struct kiocb___311 *, bool);
	int (*iterate)(struct file___311 *, struct dir_context *);
	int (*iterate_shared)(struct file___311 *, struct dir_context *);
	__poll_t (*poll)(struct file___311 *, struct poll_table_struct___188 *);
	long int (*unlocked_ioctl)(struct file___311 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___311 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___311 *, struct vm_area_struct___312 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___311 *, struct file___311 *);
	int (*flush)(struct file___311 *, fl_owner_t);
	int (*release)(struct inode___311 *, struct file___311 *);
	int (*fsync)(struct file___311 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___311 *, int);
	int (*lock)(struct file___311 *, int, struct file_lock___311 *);
	ssize_t (*sendpage)(struct file___311 *, struct page___312 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___311 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___311 *, int, struct file_lock___311 *);
	ssize_t (*splice_write)(struct pipe_inode_info___68 *, struct file___311 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___311 *, loff_t *, struct pipe_inode_info___68 *, size_t, unsigned int);
	int (*setlease)(struct file___311 *, long int, struct file_lock___311 **, void **);
	long int (*fallocate)(struct file___311 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___263 *, struct file___311 *);
	ssize_t (*copy_file_range)(struct file___311 *, loff_t, struct file___311 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___311 *, loff_t, struct file___311 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___311 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___311 {
	u64 seqnum;
	struct vm_area_struct___312 *vmas[4];
};

struct page_frag___311 {
	struct page___312 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___311;

struct cred___289;

struct signal_struct___231;

struct vm_struct___227;

struct task_struct___312 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___312 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___311 *mm;
	struct mm_struct___311 *active_mm;
	struct vmacache___311 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___312 *real_parent;
	struct task_struct___312 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___312 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___204 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___204 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___204 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___289 *ptracer_cred;
	const struct cred___289 *real_cred;
	const struct cred___289 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___253 *nsproxy;
	struct signal_struct___231 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___312 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___82 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___68 *splice_pipe;
	struct page_frag___311 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___312 *oom_reaper_list;
	struct vm_struct___227 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___131 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___310;

struct super_block___310;

struct dentry___310 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___310 *d_parent;
	struct qstr d_name;
	struct inode___311 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___310 *d_op;
	struct super_block___310 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct rw_semaphore___312 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___312 *owner;
};

struct address_space_operations___310;

struct address_space___310 {
	struct inode___311 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___312 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___310 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___310;

struct block_device___310;

struct cdev___61;

struct inode___311 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___310 *i_op;
	struct super_block___310 *i_sb;
	struct address_space___310 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___312 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___311 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___310 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___68 *i_pipe;
		struct block_device___310 *i_bdev;
		struct cdev___61 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___311;

struct dentry_operations___310 {
	int (*d_revalidate)(struct dentry___310 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___310 *, unsigned int);
	int (*d_hash)(const struct dentry___310 *, struct qstr *);
	int (*d_compare)(const struct dentry___310 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___310 *);
	int (*d_init)(struct dentry___310 *);
	void (*d_release)(struct dentry___310 *);
	void (*d_prune)(struct dentry___310 *);
	void (*d_iput)(struct dentry___310 *, struct inode___311 *);
	char * (*d_dname)(struct dentry___310 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___311 *);
	int (*d_manage)(const struct path___311 *, bool);
	struct dentry___310 * (*d_real)(struct dentry___310 *, const struct inode___311 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___310;

struct mem_dqinfo___310 {
	struct quota_format_type___310 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___310;

struct quota_info___310 {
	unsigned int flags;
	struct rw_semaphore___312 dqio_sem;
	struct inode___311 *files[3];
	struct mem_dqinfo___310 info[3];
	const struct quota_format_ops___310 *ops[3];
};

struct rcuwait___310 {
	struct task_struct___312 *task;
};

struct percpu_rw_semaphore___310 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___312 rw_sem;
	struct rcuwait___310 writer;
	int readers_block;
};

struct sb_writers___310 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___310 rw_sem[3];
};

struct file_system_type___310;

struct super_operations___310;

struct dquot_operations___310;

struct quotactl_ops___310;

struct super_block___310 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___310 *s_type;
	const struct super_operations___310 *s_op;
	const struct dquot_operations___310 *dq_op;
	const struct quotactl_ops___310 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___310 *s_root;
	struct rw_semaphore___312 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___310 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___310 s_dquot;
	struct sb_writers___310 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___310 *s_d_op;
	int cleancache_poolid;
	struct shrinker___119 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct path___311 {
	struct vfsmount *mnt;
	struct dentry___310 *dentry;
};

typedef struct page___312 *pgtable_t___311;

struct dev_pagemap___300;

struct page___312 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___310 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___312 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___311 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___311 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___300 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___311;

struct lruvec___311 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___311 *pgdat;
};

struct zone___311 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___311 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___311 {
	struct zone___311 *zone;
	int zone_idx;
};

struct zonelist___311 {
	struct zoneref___311 _zonerefs[25];
};

struct pglist_data___311 {
	struct zone___311 node_zones[3];
	struct zonelist___311 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___312 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___312 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___311 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___312 {
	void *stack;
	struct task_struct___312 *task;
	long int status;
};

struct blocking_notifier_head___311 {
	struct rw_semaphore___312 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___300;

struct vm_area_struct___312 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___312 *vm_next;
	struct vm_area_struct___312 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___311 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___300 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___311 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___311;

struct mm_struct___311 {
	struct {
		struct vm_area_struct___312 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___311 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___312 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___311 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___312 *owner;
		struct user_namespace___3 *user_ns;
		struct file___311 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___311 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___300)(struct vm_area_struct___312 *, long unsigned int, const struct page___312 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___300)(struct page___312 *, void *);

struct device___276;

struct dev_pagemap___300 {
	dev_page_fault_t___300 page_fault;
	dev_page_free_t___300 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___276 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct file___311 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___311 f_path;
	struct inode___311 *f_inode;
	const struct file_operations___311 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___204 f_owner;
	const struct cred___289 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___310 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___300;

struct vm_operations_struct___300 {
	void (*open)(struct vm_area_struct___312 *);
	void (*close)(struct vm_area_struct___312 *);
	int (*split)(struct vm_area_struct___312 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___312 *);
	vm_fault_t (*fault)(struct vm_fault___300 *);
	vm_fault_t (*huge_fault)(struct vm_fault___300 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___300 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___312 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___300 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___300 *);
	int (*access)(struct vm_area_struct___312 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___312 *);
	int (*set_policy)(struct vm_area_struct___312 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___312 *, long unsigned int);
	struct page___312 * (*find_special_page)(struct vm_area_struct___312 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___311 {
	struct task_struct___312 *task;
	struct core_thread___311 *next;
};

struct core_state___311 {
	atomic_t nr_threads;
	struct core_thread___311 dumper;
	struct completion startup;
};

struct vm_fault___300 {
	struct vm_area_struct___312 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___312 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___312 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___311 prealloc_pte;
};

struct key___289;

struct user_struct___289 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___289 *uid_keyring;
	struct key___289 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___289 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___289 *session_keyring;
	struct key___289 *process_keyring;
	struct key___289 *thread_keyring;
	struct key___289 *request_key_auth;
	void *security;
	struct user_struct___289 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct signal_struct___231 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___312 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___312 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___204 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___204 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___311 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___204 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct fasync_struct___310;

struct pipe_buffer___68;

struct pipe_inode_info___68 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___312 *tmp_page;
	struct fasync_struct___310 *fasync_readers;
	struct fasync_struct___310 *fasync_writers;
	struct pipe_buffer___68 *bufs;
	struct user_struct___289 *user;
};

struct vm_struct___227 {
	struct vm_struct___227 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___312 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___243 {
	struct task_struct___312 task;
	long unsigned int stack[8192];
};

struct kiocb___311 {
	struct file___311 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___311 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___310 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___311 *ia_file;
};

struct dquot___310 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___310 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___310 {
	int qf_fmt_id;
	const struct quota_format_ops___310 *qf_ops;
	struct module___251 *qf_owner;
	struct quota_format_type___310 *qf_next;
};

struct quota_format_ops___310 {
	int (*check_quota_file)(struct super_block___310 *, int);
	int (*read_file_info)(struct super_block___310 *, int);
	int (*write_file_info)(struct super_block___310 *, int);
	int (*free_file_info)(struct super_block___310 *, int);
	int (*read_dqblk)(struct dquot___310 *);
	int (*commit_dqblk)(struct dquot___310 *);
	int (*release_dqblk)(struct dquot___310 *);
	int (*get_next_id)(struct super_block___310 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___310 {
	int (*write_dquot)(struct dquot___310 *);
	struct dquot___310 * (*alloc_dquot)(struct super_block___310 *, int);
	void (*destroy_dquot)(struct dquot___310 *);
	int (*acquire_dquot)(struct dquot___310 *);
	int (*release_dquot)(struct dquot___310 *);
	int (*mark_dirty)(struct dquot___310 *);
	int (*write_info)(struct super_block___310 *, int);
	qsize_t * (*get_reserved_space)(struct inode___311 *);
	int (*get_projid)(struct inode___311 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___311 *, qsize_t *);
	int (*get_next_id)(struct super_block___310 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___310 {
	int (*quota_on)(struct super_block___310 *, int, int, const struct path___311 *);
	int (*quota_off)(struct super_block___310 *, int);
	int (*quota_enable)(struct super_block___310 *, unsigned int);
	int (*quota_disable)(struct super_block___310 *, unsigned int);
	int (*quota_sync)(struct super_block___310 *, int);
	int (*set_info)(struct super_block___310 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___310 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___310 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___310 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___310 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___310 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___297;

struct kobj_type___297;

struct kernfs_node___305;

struct kobject___298 {
	const char *name;
	struct list_head entry;
	struct kobject___298 *parent;
	struct kset___297 *kset;
	struct kobj_type___297 *ktype;
	struct kernfs_node___305 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___248 {
	struct kobject___298 kobj;
	struct module___251 *mod;
	struct kobject___298 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___248 {
	struct module___251 *mod;
	struct latch_tree_node node;
};

struct module_layout___248 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___248 mtn;
};

struct module_attribute___248;

struct kernel_param___248;

struct module___251 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___248 mkobj;
	struct module_attribute___248 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___298 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___248 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___248 core_layout;
	struct module_layout___248 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___310 {
	int (*writepage)(struct page___312 *, struct writeback_control___3 *);
	int (*readpage)(struct file___311 *, struct page___312 *);
	int (*writepages)(struct address_space___310 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___312 *);
	int (*readpages)(struct file___311 *, struct address_space___310 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___311 *, struct address_space___310 *, loff_t, unsigned int, unsigned int, struct page___312 **, void **);
	int (*write_end)(struct file___311 *, struct address_space___310 *, loff_t, unsigned int, unsigned int, struct page___312 *, void *);
	sector_t (*bmap)(struct address_space___310 *, sector_t);
	void (*invalidatepage)(struct page___312 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___312 *, gfp_t);
	void (*freepage)(struct page___312 *);
	ssize_t (*direct_IO)(struct kiocb___311 *, struct iov_iter___138 *);
	int (*migratepage)(struct address_space___310 *, struct page___312 *, struct page___312 *, enum migrate_mode);
	bool (*isolate_page)(struct page___312 *, isolate_mode_t);
	void (*putback_page)(struct page___312 *);
	int (*launder_page)(struct page___312 *);
	int (*is_partially_uptodate)(struct page___312 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___312 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___310 *, struct page___312 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___311 *, sector_t *);
	void (*swap_deactivate)(struct file___311 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct iov_iter___138 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___3 *bvec;
		struct pipe_inode_info___68 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___310 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___311 *bd_inode;
	struct super_block___310 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___310 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___61 {
	struct kobject___298 kobj;
	struct module___251 *owner;
	const struct file_operations___311 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___310 {
	struct dentry___310 * (*lookup)(struct inode___311 *, struct dentry___310 *, unsigned int);
	const char * (*get_link)(struct dentry___310 *, struct inode___311 *, struct delayed_call *);
	int (*permission)(struct inode___311 *, int);
	struct posix_acl * (*get_acl)(struct inode___311 *, int);
	int (*readlink)(struct dentry___310 *, char *, int);
	int (*create)(struct inode___311 *, struct dentry___310 *, umode_t, bool);
	int (*link)(struct dentry___310 *, struct inode___311 *, struct dentry___310 *);
	int (*unlink)(struct inode___311 *, struct dentry___310 *);
	int (*symlink)(struct inode___311 *, struct dentry___310 *, const char *);
	int (*mkdir)(struct inode___311 *, struct dentry___310 *, umode_t);
	int (*rmdir)(struct inode___311 *, struct dentry___310 *);
	int (*mknod)(struct inode___311 *, struct dentry___310 *, umode_t, dev_t);
	int (*rename)(struct inode___311 *, struct dentry___310 *, struct inode___311 *, struct dentry___310 *, unsigned int);
	int (*setattr)(struct dentry___310 *, struct iattr___310 *);
	int (*getattr)(const struct path___311 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___310 *, char *, size_t);
	int (*fiemap)(struct inode___311 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___311 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___311 *, struct dentry___310 *, struct file___311 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___311 *, struct dentry___310 *, umode_t);
	int (*set_acl)(struct inode___311 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___310 {
	void (*fl_copy_lock)(struct file_lock___311 *, struct file_lock___311 *);
	void (*fl_release_private)(struct file_lock___311 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___310;

struct file_lock___311 {
	struct file_lock___311 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___311 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___310 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___310 *fl_ops;
	const struct lock_manager_operations___310 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___310 {
	int (*lm_compare_owner)(struct file_lock___311 *, struct file_lock___311 *);
	long unsigned int (*lm_owner_key)(struct file_lock___311 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___311 *);
	int (*lm_grant)(struct file_lock___311 *, int);
	bool (*lm_break)(struct file_lock___311 *);
	int (*lm_change)(struct file_lock___311 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___311 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___310 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___310 *fa_next;
	struct file___311 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___310 {
	const char *name;
	int fs_flags;
	struct dentry___310 * (*mount)(struct file_system_type___310 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___310 *);
	struct module___251 *owner;
	struct file_system_type___310 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___310 {
	struct inode___311 * (*alloc_inode)(struct super_block___310 *);
	void (*destroy_inode)(struct inode___311 *);
	void (*dirty_inode)(struct inode___311 *, int);
	int (*write_inode)(struct inode___311 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___311 *);
	void (*evict_inode)(struct inode___311 *);
	void (*put_super)(struct super_block___310 *);
	int (*sync_fs)(struct super_block___310 *, int);
	int (*freeze_super)(struct super_block___310 *);
	int (*freeze_fs)(struct super_block___310 *);
	int (*thaw_super)(struct super_block___310 *);
	int (*unfreeze_fs)(struct super_block___310 *);
	int (*statfs)(struct dentry___310 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___310 *, int *, char *);
	void (*umount_begin)(struct super_block___310 *);
	int (*show_options)(struct seq_file___263 *, struct dentry___310 *);
	int (*show_devname)(struct seq_file___263 *, struct dentry___310 *);
	int (*show_path)(struct seq_file___263 *, struct dentry___310 *);
	int (*show_stats)(struct seq_file___263 *, struct dentry___310 *);
	ssize_t (*quota_read)(struct super_block___310 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___310 *, int, const char *, size_t, loff_t);
	struct dquot___310 ** (*get_dquots)(struct inode___311 *);
	int (*bdev_try_to_free_page)(struct super_block___310 *, struct page___312 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___310 *, struct shrink_control___119 *);
	long int (*free_cached_objects)(struct super_block___310 *, struct shrink_control___119 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___192)(struct file___311 *, wait_queue_head_t *, struct poll_table_struct___188 *);

struct poll_table_struct___188 {
	poll_queue_proc___192 _qproc;
	__poll_t _key;
};

struct seq_operations___262;

struct seq_file___263 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___262 *op;
	int poll_event;
	const struct file___311 *file;
	void *private;
};

struct kernfs_root___304;

struct kernfs_elem_dir___304 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___304 *root;
};

struct kernfs_syscall_ops___304;

struct kernfs_root___304 {
	struct kernfs_node___305 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___304 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___304 {
	struct kernfs_node___305 *target_kn;
};

struct kernfs_ops___304;

struct kernfs_elem_attr___304 {
	const struct kernfs_ops___304 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___305 *notify_next;
};

struct kernfs_node___305 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___305 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___304 dir;
		struct kernfs_elem_symlink___304 symlink;
		struct kernfs_elem_attr___304 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___304;

struct kernfs_ops___304 {
	int (*open)(struct kernfs_open_file___304 *);
	void (*release)(struct kernfs_open_file___304 *);
	int (*seq_show)(struct seq_file___263 *, void *);
	void * (*seq_start)(struct seq_file___263 *, loff_t *);
	void * (*seq_next)(struct seq_file___263 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___263 *, void *);
	ssize_t (*read)(struct kernfs_open_file___304 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___304 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___304 *, struct vm_area_struct___312 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___304 *, struct poll_table_struct___188 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___304 {
	int (*remount_fs)(struct kernfs_root___304 *, int *, char *);
	int (*show_options)(struct seq_file___263 *, struct kernfs_root___304 *);
	int (*mkdir)(struct kernfs_node___305 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___305 *);
	int (*rename)(struct kernfs_node___305 *, struct kernfs_node___305 *, const char *);
	int (*show_path)(struct seq_file___263 *, struct kernfs_node___305 *, struct kernfs_root___304 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___304 {
	struct kernfs_node___305 *kn;
	struct file___311 *file;
	struct seq_file___263 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___300 *vm_ops;
};

struct bin_attribute___274;

struct attribute_group___275 {
	const char *name;
	umode_t (*is_visible)(struct kobject___298 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___298 *, struct bin_attribute___274 *, int);
	struct attribute **attrs;
	struct bin_attribute___274 **bin_attrs;
};

struct bin_attribute___274 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___311 *, struct kobject___298 *, struct bin_attribute___274 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___311 *, struct kobject___298 *, struct bin_attribute___274 *, char *, loff_t, size_t);
	int (*mmap)(struct file___311 *, struct kobject___298 *, struct bin_attribute___274 *, struct vm_area_struct___312 *);
};

struct sysfs_ops___297 {
	ssize_t (*show)(struct kobject___298 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___298 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___297;

struct kset___297 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___298 kobj;
	const struct kset_uevent_ops___297 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___297 {
	void (*release)(struct kobject___298 *);
	const struct sysfs_ops___297 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___25 * (*child_ns_type)(struct kobject___298 *);
	const void * (*namespace)(struct kobject___298 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___297 {
	int (* const filter)(struct kset___297 *, struct kobject___298 *);
	const char * (* const name)(struct kset___297 *, struct kobject___298 *);
	int (* const uevent)(struct kset___297 *, struct kobject___298 *, struct kobj_uevent_env *);
};

struct kobj_attribute___290 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___298 *, struct kobj_attribute___290 *, char *);
	ssize_t (*store)(struct kobject___298 *, struct kobj_attribute___290 *, const char *, size_t);
};

struct dev_pm_ops___276 {
	int (*prepare)(struct device___276 *);
	void (*complete)(struct device___276 *);
	int (*suspend)(struct device___276 *);
	int (*resume)(struct device___276 *);
	int (*freeze)(struct device___276 *);
	int (*thaw)(struct device___276 *);
	int (*poweroff)(struct device___276 *);
	int (*restore)(struct device___276 *);
	int (*suspend_late)(struct device___276 *);
	int (*resume_early)(struct device___276 *);
	int (*freeze_late)(struct device___276 *);
	int (*thaw_early)(struct device___276 *);
	int (*poweroff_late)(struct device___276 *);
	int (*restore_early)(struct device___276 *);
	int (*suspend_noirq)(struct device___276 *);
	int (*resume_noirq)(struct device___276 *);
	int (*freeze_noirq)(struct device___276 *);
	int (*thaw_noirq)(struct device___276 *);
	int (*poweroff_noirq)(struct device___276 *);
	int (*restore_noirq)(struct device___276 *);
	int (*runtime_suspend)(struct device___276 *);
	int (*runtime_resume)(struct device___276 *);
	int (*runtime_idle)(struct device___276 *);
};

struct dev_pm_info___276 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___2 *subsys_data;
	void (*set_latency_tolerance)(struct device___276 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___276;

struct bus_type___276;

struct device_driver___276;

struct dev_pm_domain___276;

struct dma_map_ops___92;

struct fwnode_handle___210;

struct class___276;

struct device___276 {
	struct device___276 *parent;
	struct device_private *p;
	struct kobject___298 kobj;
	const char *init_name;
	const struct device_type___276 *type;
	struct mutex mutex;
	struct bus_type___276 *bus;
	struct device_driver___276 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___276 power;
	struct dev_pm_domain___276 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___92 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___210 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___276 *class;
	const struct attribute_group___275 **groups;
	void (*release)(struct device___276 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___276 {
	struct dev_pm_ops___276 ops;
	void (*detach)(struct device___276 *, bool);
	int (*activate)(struct device___276 *);
	void (*sync)(struct device___276 *);
	void (*dismiss)(struct device___276 *);
};

struct bus_type___276 {
	const char *name;
	const char *dev_name;
	struct device___276 *dev_root;
	const struct attribute_group___275 **bus_groups;
	const struct attribute_group___275 **dev_groups;
	const struct attribute_group___275 **drv_groups;
	int (*match)(struct device___276 *, struct device_driver___276 *);
	int (*uevent)(struct device___276 *, struct kobj_uevent_env *);
	int (*probe)(struct device___276 *);
	int (*remove)(struct device___276 *);
	void (*shutdown)(struct device___276 *);
	int (*online)(struct device___276 *);
	int (*offline)(struct device___276 *);
	int (*suspend)(struct device___276 *, pm_message_t);
	int (*resume)(struct device___276 *);
	int (*num_vf)(struct device___276 *);
	int (*dma_configure)(struct device___276 *);
	const struct dev_pm_ops___276 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___276 {
	const char *name;
	struct bus_type___276 *bus;
	struct module___251 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___276 *);
	int (*remove)(struct device___276 *);
	void (*shutdown)(struct device___276 *);
	int (*suspend)(struct device___276 *, pm_message_t);
	int (*resume)(struct device___276 *);
	const struct attribute_group___275 **groups;
	const struct dev_pm_ops___276 *pm;
	void (*coredump)(struct device___276 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___276 {
	const char *name;
	const struct attribute_group___275 **groups;
	int (*uevent)(struct device___276 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___276 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___276 *);
	const struct dev_pm_ops___276 *pm;
};

struct class___276 {
	const char *name;
	struct module___251 *owner;
	const struct attribute_group___275 **class_groups;
	const struct attribute_group___275 **dev_groups;
	struct kobject___298 *dev_kobj;
	int (*dev_uevent)(struct device___276 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___276 *, umode_t *);
	void (*class_release)(struct class___276 *);
	void (*dev_release)(struct device___276 *);
	int (*shutdown_pre)(struct device___276 *);
	const struct kobj_ns_type_operations___25 *ns_type;
	const void * (*namespace)(struct device___276 *);
	const struct dev_pm_ops___276 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___92 {
	void * (*alloc)(struct device___276 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___276 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___276 *, struct vm_area_struct___312 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___276 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___276 *, struct page___312 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___276 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___276 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___276 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___276 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___276 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___276 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___276 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___276 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___276 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___276 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___276 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___276 *, u64);
	u64 (*get_required_mask)(struct device___276 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___210;

struct fwnode_handle___210 {
	struct fwnode_handle___210 *secondary;
	const struct fwnode_operations___210 *ops;
};

struct fwnode_reference_args___210;

struct fwnode_endpoint___210;

struct fwnode_operations___210 {
	struct fwnode_handle___210 * (*get)(struct fwnode_handle___210 *);
	void (*put)(struct fwnode_handle___210 *);
	bool (*device_is_available)(const struct fwnode_handle___210 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___210 *, const struct device___276 *);
	bool (*property_present)(const struct fwnode_handle___210 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___210 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___210 *, const char *, const char **, size_t);
	struct fwnode_handle___210 * (*get_parent)(const struct fwnode_handle___210 *);
	struct fwnode_handle___210 * (*get_next_child_node)(const struct fwnode_handle___210 *, struct fwnode_handle___210 *);
	struct fwnode_handle___210 * (*get_named_child_node)(const struct fwnode_handle___210 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___210 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___210 *);
	struct fwnode_handle___210 * (*graph_get_next_endpoint)(const struct fwnode_handle___210 *, struct fwnode_handle___210 *);
	struct fwnode_handle___210 * (*graph_get_remote_endpoint)(const struct fwnode_handle___210 *);
	struct fwnode_handle___210 * (*graph_get_port_parent)(struct fwnode_handle___210 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___210 *, struct fwnode_endpoint___210 *);
};

struct fwnode_endpoint___210 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___210 *local_fwnode;
};

struct fwnode_reference_args___210 {
	struct fwnode_handle___210 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct kernel_param_ops___248 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___248 *);
	int (*get)(char *, const struct kernel_param___248 *);
	void (*free)(void *);
};

struct kparam_array___248;

struct kernel_param___248 {
	const char *name;
	struct module___251 *mod;
	const struct kernel_param_ops___248 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___248 *arr;
	};
};

struct kparam_array___248 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___248 *ops;
	void *elem;
};

struct module_attribute___248 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___248 *, struct module_kobject___248 *, char *);
	ssize_t (*store)(struct module_attribute___248 *, struct module_kobject___248 *, const char *, size_t);
	void (*setup)(struct module___251 *, const char *);
	int (*test)(struct module___251 *);
	void (*free)(struct module___251 *);
};

struct acpi_device___12;

struct acpi_hotplug_profile___12 {
	struct kobject___298 kobj;
	int (*scan_dependent)(struct acpi_device___12 *);
	void (*notify_online)(struct acpi_device___12 *);
	bool enabled: 1;
	bool demand_offline: 1;
};

struct acpi_device_wakeup_context___12 {
	void (*func)(struct acpi_device_wakeup_context___12 *);
	struct device___276 *dev;
};

struct acpi_device_wakeup___12 {
	acpi_handle gpe_device;
	u64 gpe_number;
	u64 sleep_state;
	struct list_head resources;
	struct acpi_device_wakeup_flags flags;
	struct acpi_device_wakeup_context___12 context;
	struct wakeup_source *ws;
	int prepare_count;
	int enable_count;
};

struct acpi_scan_handler___12;

struct acpi_hotplug_context___12;

struct acpi_driver___12;

struct acpi_device___12 {
	int device_type;
	acpi_handle handle;
	struct fwnode_handle___210 fwnode;
	struct acpi_device___12 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup___12 wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_device_data data;
	struct acpi_scan_handler___12 *handler;
	struct acpi_hotplug_context___12 *hp;
	struct acpi_driver___12 *driver;
	const struct acpi_gpio_mapping *driver_gpios;
	void *driver_data;
	struct device___276 dev;
	unsigned int physical_node_count;
	unsigned int dep_unmet;
	struct list_head physical_node_list;
	struct mutex physical_node_lock;
	void (*remove)(struct acpi_device___12 *);
};

struct acpi_scan_handler___12 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	bool (*match)(const char *, const struct acpi_device_id **);
	int (*attach)(struct acpi_device___12 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___12 *);
	void (*bind)(struct device___276 *);
	void (*unbind)(struct device___276 *);
	struct acpi_hotplug_profile___12 hotplug;
};

struct acpi_hotplug_context___12 {
	struct acpi_device___12 *self;
	int (*notify)(struct acpi_device___12 *, u32);
	void (*uevent)(struct acpi_device___12 *, u32);
	void (*fixup)(struct acpi_device___12 *);
};

typedef int (*acpi_op_add___12)(struct acpi_device___12 *);

typedef int (*acpi_op_remove___12)(struct acpi_device___12 *);

typedef void (*acpi_op_notify___12)(struct acpi_device___12 *, u32);

struct acpi_device_ops___12 {
	acpi_op_add___12 add;
	acpi_op_remove___12 remove;
	acpi_op_notify___12 notify;
};

struct acpi_driver___12 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___12 ops;
	struct device_driver___276 drv;
	struct module___251 *owner;
};

struct acpi_bus_event {
	struct list_head node;
	acpi_device_class device_class;
	acpi_bus_id bus_id;
	u32 type;
	u32 data;
};

typedef int (*key_restrict_link_func_t___290)(struct key___289 *, const struct key_type *, const union key_payload *, struct key___289 *);

struct key_restriction___289;

struct key___289 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___312 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___289 *restrict_link;
};

struct key_restriction___289 {
	key_restrict_link_func_t___290 check;
	struct key___289 *key;
	struct key_type *keytype;
};

struct seq_operations___262 {
	void * (*start)(struct seq_file___263 *, loff_t *);
	void (*stop)(struct seq_file___263 *, void *);
	void * (*next)(struct seq_file___263 *, void *, loff_t *);
	int (*show)(struct seq_file___263 *, void *);
};

typedef void compound_page_dtor___300(struct page___312 *);

struct pipe_buf_operations___68;

struct pipe_buffer___68 {
	struct page___312 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___68 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___68 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___68 *, struct pipe_buffer___68 *);
	void (*release)(struct pipe_inode_info___68 *, struct pipe_buffer___68 *);
	int (*steal)(struct pipe_inode_info___68 *, struct pipe_buffer___68 *);
	union {
		bool (*get)(struct pipe_inode_info___68 *, struct pipe_buffer___68 *);
		struct {
			void (*get)(struct pipe_inode_info___68 *, struct pipe_buffer___68 *);
		} __UNIQUE_ID_rh_kabi_hide21;
		union {		};
	};
};

struct netlink_callback___37 {
	struct sk_buff *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___37 *);
	int (*dump)(struct sk_buff *, struct netlink_callback___37 *);
	int (*done)(struct netlink_callback___37 *);
	void *data;
	struct module___251 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct genl_ops___2;

struct genl_family___2 {
	int id;
	unsigned int hdrsize;
	char name[16];
	unsigned int version;
	unsigned int maxattr;
	bool netnsok;
	bool parallel_ops;
	int (*pre_doit)(const struct genl_ops___2 *, struct sk_buff *, struct genl_info *);
	void (*post_doit)(const struct genl_ops___2 *, struct sk_buff *, struct genl_info *);
	int (*mcast_bind)(struct net *, int);
	void (*mcast_unbind)(struct net *, int);
	struct nlattr **attrbuf;
	const struct genl_ops___2 *ops;
	const struct genl_multicast_group *mcgrps;
	unsigned int n_ops;
	unsigned int n_mcgrps;
	unsigned int mcgrp_offset;
	struct module___251 *module;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct genl_ops___2 {
	const struct nla_policy *policy;
	int (*doit)(struct sk_buff *, struct genl_info *);
	int (*start)(struct netlink_callback___37 *);
	int (*dumpit)(struct sk_buff *, struct netlink_callback___37 *);
	int (*done)(struct netlink_callback___37 *);
	u8 cmd;
	u8 internal_flags;
	u8 flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t genl_ops_extended_size_rh;
	struct genl_ops_extended_rh genl_ops_extended_rh;
};

struct acpi_genl_event {
	acpi_device_class device_class;
	char bus_id[15];
	u32 type;
	u32 data;
};

enum {
	ACPI_GENL_ATTR_UNSPEC = 0,
	ACPI_GENL_ATTR_EVENT = 1,
	__ACPI_GENL_ATTR_MAX = 2,
};

enum {
	ACPI_GENL_CMD_UNSPEC = 0,
	ACPI_GENL_CMD_EVENT = 1,
	__ACPI_GENL_CMD_MAX = 2,
};

struct acpi_ged_device {
	struct device___272 *dev;
	struct list_head event_list;
};

struct acpi_ged_event {
	struct list_head node;
	struct device___272 *dev;
	unsigned int gsi;
	unsigned int irq;
	acpi_handle handle;
};

typedef void (*acpi_gbl_event_handler)(u32, acpi_handle, u32, void *);

struct acpi_table_bert {
	struct acpi_table_header header;
	u32 region_length;
	u64 address;
};

struct acpi_table_attr {
	struct bin_attribute___270 attr;
	char name[4];
	int instance;
	char filename[8];
	struct list_head node;
};

struct acpi_data_attr {
	struct bin_attribute___270 attr;
	u64 addr;
};

struct acpi_data_obj {
	char *name;
	int (*fn)(void *, struct acpi_data_attr *);
};

struct event_counter {
	u32 count;
	u32 flags;
};

struct acpi_device_properties {
	const guid_t *guid;
	const union acpi_object *properties;
	struct list_head list;
};

struct acpi_table_slit {
	struct acpi_table_header header;
	u64 locality_count;
	u8 entry[1];
} __attribute__((packed));

struct acpi_table_srat {
	struct acpi_table_header header;
	u32 table_revision;
	u64 reserved;
};

struct acpi_srat_cpu_affinity {
	struct acpi_subtable_header header;
	u8 proximity_domain_lo;
	u8 apic_id;
	u32 flags;
	u8 local_sapic_eid;
	u8 proximity_domain_hi[3];
	u32 clock_domain;
};

struct acpi_srat_mem_affinity {
	struct acpi_subtable_header header;
	u32 proximity_domain;
	u16 reserved;
	u64 base_address;
	u64 length;
	u32 reserved1;
	u32 flags;
	u64 reserved2;
} __attribute__((packed));

struct acpi_srat_x2apic_cpu_affinity {
	struct acpi_subtable_header header;
	u16 reserved;
	u32 proximity_domain;
	u32 apic_id;
	u32 flags;
	u32 clock_domain;
	u32 reserved2;
};

struct acpi_lpat {
	int temp;
	int raw;
};

struct acpi_lpat_conversion_table {
	struct acpi_lpat *lpat;
	int lpat_count;
};

struct acpi_irq_parse_one_ctx {
	int rc;
	unsigned int index;
	long unsigned int *res_flags;
	struct irq_fwspec *fwspec;
	bool skip_producer_check;
};

enum {
	ACPI_REFCLASS_LOCAL = 0,
	ACPI_REFCLASS_ARG = 1,
	ACPI_REFCLASS_REFOF = 2,
	ACPI_REFCLASS_INDEX = 3,
	ACPI_REFCLASS_TABLE = 4,
	ACPI_REFCLASS_NAME = 5,
	ACPI_REFCLASS_DEBUG = 6,
	ACPI_REFCLASS_MAX = 6,
};

struct acpi_common_descriptor {
	void *common_pointer;
	u8 descriptor_type;
};

union acpi_descriptor {
	struct acpi_common_descriptor common;
	union acpi_operand_object object;
	struct acpi_namespace_node node;
	union acpi_parse_object op;
};

struct acpi_create_field_info {
	struct acpi_namespace_node *region_node;
	struct acpi_namespace_node *field_node;
	struct acpi_namespace_node *register_node;
	struct acpi_namespace_node *data_register_node;
	struct acpi_namespace_node *connection_node;
	u8 *resource_buffer;
	u32 bank_value;
	u32 field_bit_position;
	u32 field_bit_length;
	u16 resource_length;
	u16 pin_number_index;
	u8 field_flags;
	u8 attribute;
	u8 field_type;
	u8 access_length;
};

struct acpi_init_walk_info {
	u32 table_index;
	u32 object_count;
	u32 method_count;
	u32 serial_method_count;
	u32 non_serial_method_count;
	u32 serialized_method_count;
	u32 device_count;
	u32 op_region_count;
	u32 field_count;
	u32 buffer_count;
	u32 package_count;
	u32 op_region_init;
	u32 field_init;
	u32 buffer_init;
	u32 package_init;
	acpi_owner_id owner_id;
};

struct acpi_name_info {
	char name[4];
	u16 argument_list;
	u8 expected_btypes;
} __attribute__((packed));

struct acpi_package_info {
	u8 type;
	u8 object_type1;
	u8 count1;
	u8 object_type2;
	u8 count2;
	u16 reserved;
} __attribute__((packed));

struct acpi_package_info2 {
	u8 type;
	u8 count;
	u8 object_type[4];
	u8 reserved;
};

struct acpi_package_info3 {
	u8 type;
	u8 count;
	u8 object_type[2];
	u8 tail_object_type;
	u16 reserved;
} __attribute__((packed));

struct acpi_package_info4 {
	u8 type;
	u8 object_type1;
	u8 count1;
	u8 sub_object_types;
	u8 pkg_count;
	u16 reserved;
} __attribute__((packed));

union acpi_predefined_info {
	struct acpi_name_info info;
	struct acpi_package_info ret_info;
	struct acpi_package_info2 ret_info2;
	struct acpi_package_info3 ret_info3;
	struct acpi_package_info4 ret_info4;
};

struct acpi_evaluate_info {
	struct acpi_namespace_node *prefix_node;
	const char *relative_pathname;
	union acpi_operand_object **parameters;
	struct acpi_namespace_node *node;
	union acpi_operand_object *obj_desc;
	char *full_pathname;
	const union acpi_predefined_info *predefined;
	union acpi_operand_object *return_object;
	union acpi_operand_object *parent_package;
	u32 return_flags;
	u32 return_btype;
	u16 param_count;
	u8 pass_number;
	u8 return_object_type;
	u8 node_flags;
	u8 flags;
};

enum {
	AML_FIELD_ACCESS_ANY = 0,
	AML_FIELD_ACCESS_BYTE = 1,
	AML_FIELD_ACCESS_WORD = 2,
	AML_FIELD_ACCESS_DWORD = 3,
	AML_FIELD_ACCESS_QWORD = 4,
	AML_FIELD_ACCESS_BUFFER = 5,
};

typedef enum {
	ACPI_IMODE_LOAD_PASS1 = 1,
	ACPI_IMODE_LOAD_PASS2 = 2,
	ACPI_IMODE_EXECUTE = 3,
} acpi_interpreter_mode;

typedef acpi_status (*acpi_execute_op)(struct acpi_walk_state *);

struct acpi_reg_walk_info {
	acpi_adr_space_type space_id;
	u32 function;
	u32 reg_run_count;
};

enum {
	AML_FIELD_ATTRIB_QUICK = 2,
	AML_FIELD_ATTRIB_SEND_RCV = 4,
	AML_FIELD_ATTRIB_BYTE = 6,
	AML_FIELD_ATTRIB_WORD = 8,
	AML_FIELD_ATTRIB_BLOCK = 10,
	AML_FIELD_ATTRIB_MULTIBYTE = 11,
	AML_FIELD_ATTRIB_WORD_CALL = 12,
	AML_FIELD_ATTRIB_BLOCK_CALL = 13,
	AML_FIELD_ATTRIB_RAW_BYTES = 14,
	AML_FIELD_ATTRIB_RAW_PROCESS = 15,
};

enum {
	AML_FIELD_UPDATE_PRESERVE = 0,
	AML_FIELD_UPDATE_WRITE_AS_ONES = 32,
	AML_FIELD_UPDATE_WRITE_AS_ZEROS = 64,
};

struct acpi_signal_fatal_info {
	u32 type;
	u32 code;
	u32 argument;
};

enum {
	MATCH_MTR = 0,
	MATCH_MEQ = 1,
	MATCH_MLE = 2,
	MATCH_MLT = 3,
	MATCH_MGE = 4,
	MATCH_MGT = 5,
};

typedef enum {
	ACPI_TRACE_AML_METHOD = 0,
	ACPI_TRACE_AML_OPCODE = 1,
	ACPI_TRACE_AML_REGION = 2,
} acpi_trace_event_type;

struct acpi_pci_device {
	acpi_handle device;
	struct acpi_pci_device *next;
};

struct acpi_port_info {
	char *name;
	u16 start;
	u16 end;
	u8 osi_dependency;
};

typedef acpi_status (*acpi_sleep_function)(u8);

struct acpi_sleep_functions {
	acpi_sleep_function legacy_function;
	acpi_sleep_function extended_function;
};

struct acpi_device_walk_info {
	struct acpi_table_desc *table_desc;
	struct acpi_evaluate_info *evaluate_info;
	u32 device_count;
	u32 num_STA;
	u32 num_INI;
};

enum acpi_return_package_types {
	ACPI_PTYPE1_FIXED = 1,
	ACPI_PTYPE1_VAR = 2,
	ACPI_PTYPE1_OPTION = 3,
	ACPI_PTYPE2 = 4,
	ACPI_PTYPE2_COUNT = 5,
	ACPI_PTYPE2_PKG_COUNT = 6,
	ACPI_PTYPE2_FIXED = 7,
	ACPI_PTYPE2_MIN = 8,
	ACPI_PTYPE2_REV_FIXED = 9,
	ACPI_PTYPE2_FIX_VAR = 10,
	ACPI_PTYPE2_VAR_VAR = 11,
	ACPI_PTYPE2_UUID_PAIR = 12,
	ACPI_PTYPE_CUSTOM = 13,
};

typedef acpi_status (*acpi_object_converter)(struct acpi_namespace_node *, union acpi_operand_object *, union acpi_operand_object **);

struct acpi_simple_repair_info {
	char name[4];
	u32 unexpected_btypes;
	u32 package_index;
	acpi_object_converter object_converter;
};

typedef acpi_status (*acpi_repair_function)(struct acpi_evaluate_info *, union acpi_operand_object **);

struct acpi_repair_info {
	char name[4];
	acpi_repair_function repair_function;
};

struct acpi_namestring_info {
	const char *external_name;
	const char *next_external_char;
	char *internal_name;
	u32 length;
	u32 num_segments;
	u32 num_carats;
	u8 fully_qualified;
};

typedef acpi_status (*acpi_walk_callback)(acpi_handle, u32, void *, void **);

struct acpi_get_devices_info {
	acpi_walk_callback user_function;
	void *context;
	const char *hid;
};

struct aml_resource_small_header {
	u8 descriptor_type;
};

struct aml_resource_irq {
	u8 descriptor_type;
	u16 irq_mask;
	u8 flags;
} __attribute__((packed));

struct aml_resource_dma {
	u8 descriptor_type;
	u8 dma_channel_mask;
	u8 flags;
};

struct aml_resource_start_dependent {
	u8 descriptor_type;
	u8 flags;
};

struct aml_resource_end_dependent {
	u8 descriptor_type;
};

struct aml_resource_io {
	u8 descriptor_type;
	u8 flags;
	u16 minimum;
	u16 maximum;
	u8 alignment;
	u8 address_length;
};

struct aml_resource_fixed_io {
	u8 descriptor_type;
	u16 address;
	u8 address_length;
} __attribute__((packed));

struct aml_resource_vendor_small {
	u8 descriptor_type;
};

struct aml_resource_end_tag {
	u8 descriptor_type;
	u8 checksum;
};

struct aml_resource_fixed_dma {
	u8 descriptor_type;
	u16 request_lines;
	u16 channels;
	u8 width;
} __attribute__((packed));

struct aml_resource_large_header {
	u8 descriptor_type;
	u16 resource_length;
} __attribute__((packed));

struct aml_resource_memory24 {
	u8 descriptor_type;
	u16 resource_length;
	u8 flags;
	u16 minimum;
	u16 maximum;
	u16 alignment;
	u16 address_length;
} __attribute__((packed));

struct aml_resource_vendor_large {
	u8 descriptor_type;
	u16 resource_length;
} __attribute__((packed));

struct aml_resource_memory32 {
	u8 descriptor_type;
	u16 resource_length;
	u8 flags;
	u32 minimum;
	u32 maximum;
	u32 alignment;
	u32 address_length;
} __attribute__((packed));

struct aml_resource_fixed_memory32 {
	u8 descriptor_type;
	u16 resource_length;
	u8 flags;
	u32 address;
	u32 address_length;
} __attribute__((packed));

struct aml_resource_address {
	u8 descriptor_type;
	u16 resource_length;
	u8 resource_type;
	u8 flags;
	u8 specific_flags;
} __attribute__((packed));

struct aml_resource_extended_address64 {
	u8 descriptor_type;
	u16 resource_length;
	u8 resource_type;
	u8 flags;
	u8 specific_flags;
	u8 revision_ID;
	u8 reserved;
	u64 granularity;
	u64 minimum;
	u64 maximum;
	u64 translation_offset;
	u64 address_length;
	u64 type_specific;
} __attribute__((packed));

struct aml_resource_address64 {
	u8 descriptor_type;
	u16 resource_length;
	u8 resource_type;
	u8 flags;
	u8 specific_flags;
	u64 granularity;
	u64 minimum;
	u64 maximum;
	u64 translation_offset;
	u64 address_length;
} __attribute__((packed));

struct aml_resource_address32 {
	u8 descriptor_type;
	u16 resource_length;
	u8 resource_type;
	u8 flags;
	u8 specific_flags;
	u32 granularity;
	u32 minimum;
	u32 maximum;
	u32 translation_offset;
	u32 address_length;
} __attribute__((packed));

struct aml_resource_address16 {
	u8 descriptor_type;
	u16 resource_length;
	u8 resource_type;
	u8 flags;
	u8 specific_flags;
	u16 granularity;
	u16 minimum;
	u16 maximum;
	u16 translation_offset;
	u16 address_length;
} __attribute__((packed));

struct aml_resource_extended_irq {
	u8 descriptor_type;
	u16 resource_length;
	u8 flags;
	u8 interrupt_count;
	u32 interrupts[1];
} __attribute__((packed));

struct aml_resource_generic_register {
	u8 descriptor_type;
	u16 resource_length;
	u8 address_space_id;
	u8 bit_width;
	u8 bit_offset;
	u8 access_size;
	u64 address;
} __attribute__((packed));

struct aml_resource_gpio {
	u8 descriptor_type;
	u16 resource_length;
	u8 revision_id;
	u8 connection_type;
	u16 flags;
	u16 int_flags;
	u8 pin_config;
	u16 drive_strength;
	u16 debounce_timeout;
	u16 pin_table_offset;
	u8 res_source_index;
	u16 res_source_offset;
	u16 vendor_offset;
	u16 vendor_length;
} __attribute__((packed));

struct aml_resource_common_serialbus {
	u8 descriptor_type;
	u16 resource_length;
	u8 revision_id;
	u8 res_source_index;
	u8 type;
	u8 flags;
	u16 type_specific_flags;
	u8 type_revision_id;
	u16 type_data_length;
} __attribute__((packed));

struct aml_resource_i2c_serialbus {
	u8 descriptor_type;
	u16 resource_length;
	u8 revision_id;
	u8 res_source_index;
	u8 type;
	u8 flags;
	u16 type_specific_flags;
	u8 type_revision_id;
	u16 type_data_length;
	u32 connection_speed;
	u16 slave_address;
} __attribute__((packed));

struct aml_resource_spi_serialbus {
	u8 descriptor_type;
	u16 resource_length;
	u8 revision_id;
	u8 res_source_index;
	u8 type;
	u8 flags;
	u16 type_specific_flags;
	u8 type_revision_id;
	u16 type_data_length;
	u32 connection_speed;
	u8 data_bit_length;
	u8 clock_phase;
	u8 clock_polarity;
	u16 device_selection;
} __attribute__((packed));

struct aml_resource_uart_serialbus {
	u8 descriptor_type;
	u16 resource_length;
	u8 revision_id;
	u8 res_source_index;
	u8 type;
	u8 flags;
	u16 type_specific_flags;
	u8 type_revision_id;
	u16 type_data_length;
	u32 default_baud_rate;
	u16 rx_fifo_size;
	u16 tx_fifo_size;
	u8 parity;
	u8 lines_enabled;
} __attribute__((packed));

struct aml_resource_pin_function {
	u8 descriptor_type;
	u16 resource_length;
	u8 revision_id;
	u16 flags;
	u8 pin_config;
	u16 function_number;
	u16 pin_table_offset;
	u8 res_source_index;
	u16 res_source_offset;
	u16 vendor_offset;
	u16 vendor_length;
} __attribute__((packed));

struct aml_resource_pin_config {
	u8 descriptor_type;
	u16 resource_length;
	u8 revision_id;
	u16 flags;
	u8 pin_config_type;
	u32 pin_config_value;
	u16 pin_table_offset;
	u8 res_source_index;
	u16 res_source_offset;
	u16 vendor_offset;
	u16 vendor_length;
} __attribute__((packed));

struct aml_resource_pin_group {
	u8 descriptor_type;
	u16 resource_length;
	u8 revision_id;
	u16 flags;
	u16 pin_table_offset;
	u16 label_offset;
	u16 vendor_offset;
	u16 vendor_length;
} __attribute__((packed));

struct aml_resource_pin_group_function {
	u8 descriptor_type;
	u16 resource_length;
	u8 revision_id;
	u16 flags;
	u16 function_number;
	u8 res_source_index;
	u16 res_source_offset;
	u16 res_source_label_offset;
	u16 vendor_offset;
	u16 vendor_length;
} __attribute__((packed));

struct aml_resource_pin_group_config {
	u8 descriptor_type;
	u16 resource_length;
	u8 revision_id;
	u16 flags;
	u8 pin_config_type;
	u32 pin_config_value;
	u8 res_source_index;
	u16 res_source_offset;
	u16 res_source_label_offset;
	u16 vendor_offset;
	u16 vendor_length;
} __attribute__((packed));

union aml_resource {
	u8 descriptor_type;
	struct aml_resource_small_header small_header;
	struct aml_resource_large_header large_header;
	struct aml_resource_irq irq;
	struct aml_resource_dma dma;
	struct aml_resource_start_dependent start_dpf;
	struct aml_resource_end_dependent end_dpf;
	struct aml_resource_io io;
	struct aml_resource_fixed_io fixed_io;
	struct aml_resource_fixed_dma fixed_dma;
	struct aml_resource_vendor_small vendor_small;
	struct aml_resource_end_tag end_tag;
	struct aml_resource_memory24 memory24;
	struct aml_resource_generic_register generic_reg;
	struct aml_resource_vendor_large vendor_large;
	struct aml_resource_memory32 memory32;
	struct aml_resource_fixed_memory32 fixed_memory32;
	struct aml_resource_address16 address16;
	struct aml_resource_address32 address32;
	struct aml_resource_address64 address64;
	struct aml_resource_extended_address64 ext_address64;
	struct aml_resource_extended_irq extended_irq;
	struct aml_resource_gpio gpio;
	struct aml_resource_i2c_serialbus i2c_serial_bus;
	struct aml_resource_spi_serialbus spi_serial_bus;
	struct aml_resource_uart_serialbus uart_serial_bus;
	struct aml_resource_common_serialbus common_serial_bus;
	struct aml_resource_pin_function pin_function;
	struct aml_resource_pin_config pin_config;
	struct aml_resource_pin_group pin_group;
	struct aml_resource_pin_group_function pin_group_function;
	struct aml_resource_pin_group_config pin_group_config;
	struct aml_resource_address address;
	u32 dword_item;
	u16 word_item;
	u8 byte_item;
};

struct acpi_rsconvert_info {
	u8 opcode;
	u8 resource_offset;
	u8 aml_offset;
	u8 value;
};

enum {
	ACPI_RSC_INITGET = 0,
	ACPI_RSC_INITSET = 1,
	ACPI_RSC_FLAGINIT = 2,
	ACPI_RSC_1BITFLAG = 3,
	ACPI_RSC_2BITFLAG = 4,
	ACPI_RSC_3BITFLAG = 5,
	ACPI_RSC_ADDRESS = 6,
	ACPI_RSC_BITMASK = 7,
	ACPI_RSC_BITMASK16 = 8,
	ACPI_RSC_COUNT = 9,
	ACPI_RSC_COUNT16 = 10,
	ACPI_RSC_COUNT_GPIO_PIN = 11,
	ACPI_RSC_COUNT_GPIO_RES = 12,
	ACPI_RSC_COUNT_GPIO_VEN = 13,
	ACPI_RSC_COUNT_SERIAL_RES = 14,
	ACPI_RSC_COUNT_SERIAL_VEN = 15,
	ACPI_RSC_DATA8 = 16,
	ACPI_RSC_EXIT_EQ = 17,
	ACPI_RSC_EXIT_LE = 18,
	ACPI_RSC_EXIT_NE = 19,
	ACPI_RSC_LENGTH = 20,
	ACPI_RSC_MOVE_GPIO_PIN = 21,
	ACPI_RSC_MOVE_GPIO_RES = 22,
	ACPI_RSC_MOVE_SERIAL_RES = 23,
	ACPI_RSC_MOVE_SERIAL_VEN = 24,
	ACPI_RSC_MOVE8 = 25,
	ACPI_RSC_MOVE16 = 26,
	ACPI_RSC_MOVE32 = 27,
	ACPI_RSC_MOVE64 = 28,
	ACPI_RSC_SET8 = 29,
	ACPI_RSC_SOURCE = 30,
	ACPI_RSC_SOURCEX = 31,
};

typedef u16 acpi_rs_length;

typedef u32 acpi_rsdesc_size;

struct acpi_vendor_uuid {
	u8 subtype;
	u8 data[16];
};

typedef acpi_status (*acpi_walk_resource_callback)(struct acpi_resource *, void *);

struct acpi_vendor_walk_info {
	struct acpi_vendor_uuid *uuid;
	struct acpi_buffer *buffer;
	acpi_status status;
};

struct acpi_fadt_info {
	const char *name;
	u16 address64;
	u16 address32;
	u16 length;
	u8 default_length;
	u8 flags;
};

struct acpi_fadt_pm_info {
	struct acpi_generic_address *target;
	u16 source;
	u8 register_num;
};

struct acpi_table_rsdp {
	char signature[8];
	u8 checksum;
	char oem_id[6];
	u8 revision;
	u32 rsdt_physical_address;
	u32 length;
	u64 xsdt_physical_address;
	u8 extended_checksum;
	u8 reserved[3];
} __attribute__((packed));

struct acpi_pkg_info {
	u8 *free_space;
	acpi_size length;
	u32 object_space;
	u32 num_packages;
};

struct acpi_exception_info {
	char *name;
};

typedef acpi_status (*acpi_pkg_callback)(u8, union acpi_operand_object *, union acpi_generic_state *, void *);

typedef u32 acpi_mutex_handle;

typedef acpi_status (*acpi_walk_aml_callback)(u8 *, u32, u32, u8, void **);

struct acpi_table_mcfg {
	struct acpi_table_header header;
	u8 reserved[8];
};

struct acpi_mcfg_allocation {
	u64 address;
	u16 pci_segment;
	u8 start_bus_number;
	u8 end_bus_number;
	u32 reserved;
};

struct mcfg_entry {
	struct list_head list;
	phys_addr_t addr;
	u16 segment;
	u8 bus_start;
	u8 bus_end;
};

struct mcfg_fixup {
	char oem_id[7];
	char oem_table_id[9];
	u32 oem_revision;
	u16 segment;
	struct resource bus_range;
	struct pci_ecam_ops___2 *ops;
	struct resource cfgres;
};

struct input_id {
	__u16 bustype;
	__u16 vendor;
	__u16 product;
	__u16 version;
};

struct input_absinfo {
	__s32 value;
	__s32 minimum;
	__s32 maximum;
	__s32 fuzz;
	__s32 flat;
	__s32 resolution;
};

struct input_keymap_entry {
	__u8 flags;
	__u8 len;
	__u16 index;
	__u32 keycode;
	__u8 scancode[32];
};

struct ff_replay {
	__u16 length;
	__u16 delay;
};

struct ff_trigger {
	__u16 button;
	__u16 interval;
};

struct ff_envelope {
	__u16 attack_length;
	__u16 attack_level;
	__u16 fade_length;
	__u16 fade_level;
};

struct ff_constant_effect {
	__s16 level;
	struct ff_envelope envelope;
};

struct ff_ramp_effect {
	__s16 start_level;
	__s16 end_level;
	struct ff_envelope envelope;
};

struct ff_condition_effect {
	__u16 right_saturation;
	__u16 left_saturation;
	__s16 right_coeff;
	__s16 left_coeff;
	__u16 deadband;
	__s16 center;
};

struct ff_periodic_effect {
	__u16 waveform;
	__u16 period;
	__s16 magnitude;
	__s16 offset;
	__u16 phase;
	struct ff_envelope envelope;
	__u32 custom_len;
	__s16 *custom_data;
};

struct ff_rumble_effect {
	__u16 strong_magnitude;
	__u16 weak_magnitude;
};

struct ff_effect {
	__u16 type;
	__s16 id;
	__u16 direction;
	struct ff_trigger trigger;
	struct ff_replay replay;
	union {
		struct ff_constant_effect constant;
		struct ff_ramp_effect ramp;
		struct ff_periodic_effect periodic;
		struct ff_condition_effect condition[2];
		struct ff_rumble_effect rumble;
	} u;
};

struct input_device_id {
	kernel_ulong_t flags;
	__u16 bustype;
	__u16 vendor;
	__u16 product;
	__u16 version;
	kernel_ulong_t evbit[1];
	kernel_ulong_t keybit[12];
	kernel_ulong_t relbit[1];
	kernel_ulong_t absbit[1];
	kernel_ulong_t mscbit[1];
	kernel_ulong_t ledbit[1];
	kernel_ulong_t sndbit[1];
	kernel_ulong_t ffbit[2];
	kernel_ulong_t swbit[1];
	kernel_ulong_t propbit[1];
	kernel_ulong_t driver_info;
};

struct input_value {
	__u16 type;
	__u16 code;
	__s32 value;
};

struct ff_device;

struct input_mt;

struct input_handle;

struct input_dev {
	const char *name;
	const char *phys;
	const char *uniq;
	struct input_id id;
	long unsigned int propbit[1];
	long unsigned int evbit[1];
	long unsigned int keybit[12];
	long unsigned int relbit[1];
	long unsigned int absbit[1];
	long unsigned int mscbit[1];
	long unsigned int ledbit[1];
	long unsigned int sndbit[1];
	long unsigned int ffbit[2];
	long unsigned int swbit[1];
	unsigned int hint_events_per_packet;
	unsigned int keycodemax;
	unsigned int keycodesize;
	void *keycode;
	int (*setkeycode)(struct input_dev *, const struct input_keymap_entry *, unsigned int *);
	int (*getkeycode)(struct input_dev *, struct input_keymap_entry *);
	struct ff_device *ff;
	unsigned int repeat_key;
	struct timer_list timer;
	int rep[2];
	struct input_mt *mt;
	struct input_absinfo *absinfo;
	long unsigned int key[12];
	long unsigned int led[1];
	long unsigned int snd[1];
	long unsigned int sw[1];
	int (*open)(struct input_dev *);
	void (*close)(struct input_dev *);
	int (*flush)(struct input_dev *, struct file___309 *);
	int (*event)(struct input_dev *, unsigned int, unsigned int, int);
	struct input_handle *grab;
	spinlock_t event_lock;
	struct mutex mutex;
	unsigned int users;
	bool going_away;
	struct device___274 dev;
	struct list_head h_list;
	struct list_head node;
	unsigned int num_vals;
	unsigned int max_vals;
	struct input_value *vals;
	bool devres_managed;
};

struct ff_device {
	int (*upload)(struct input_dev *, struct ff_effect *, struct ff_effect *);
	int (*erase)(struct input_dev *, int);
	int (*playback)(struct input_dev *, int, int);
	void (*set_gain)(struct input_dev *, u16);
	void (*set_autocenter)(struct input_dev *, u16);
	void (*destroy)(struct ff_device *);
	void *private;
	long unsigned int ffbit[2];
	struct mutex mutex;
	int max_effects;
	struct ff_effect *effects;
	struct file___309 *effect_owners[0];
};

struct input_handler;

struct input_handle {
	void *private;
	int open;
	const char *name;
	struct input_dev *dev;
	struct input_handler *handler;
	struct list_head d_node;
	struct list_head h_node;
};

struct input_handler {
	void *private;
	void (*event)(struct input_handle *, unsigned int, unsigned int, int);
	void (*events)(struct input_handle *, const struct input_value *, unsigned int);
	bool (*filter)(struct input_handle *, unsigned int, unsigned int, int);
	bool (*match)(struct input_handler *, struct input_dev *);
	int (*connect)(struct input_handler *, struct input_dev *, const struct input_device_id *);
	void (*disconnect)(struct input_handle *);
	void (*start)(struct input_handle *);
	bool legacy_minors;
	int minor;
	const char *name;
	const struct input_device_id *id_table;
	struct list_head h_list;
	struct list_head node;
};

struct acpi_button {
	unsigned int type;
	struct input_dev *input;
	char phys[32];
	long unsigned int pushed;
	int last_state;
	ktime_t last_time;
	bool suspended;
};

struct thermal_zone_device___2;

struct thermal_cooling_device___2;

struct thermal_zone_device_ops___2 {
	int (*bind)(struct thermal_zone_device___2 *, struct thermal_cooling_device___2 *);
	int (*unbind)(struct thermal_zone_device___2 *, struct thermal_cooling_device___2 *);
	int (*get_temp)(struct thermal_zone_device___2 *, int *);
	int (*set_trips)(struct thermal_zone_device___2 *, int, int);
	int (*get_mode)(struct thermal_zone_device___2 *, enum thermal_device_mode *);
	int (*set_mode)(struct thermal_zone_device___2 *, enum thermal_device_mode);
	int (*get_trip_type)(struct thermal_zone_device___2 *, int, enum thermal_trip_type *);
	int (*get_trip_temp)(struct thermal_zone_device___2 *, int, int *);
	int (*set_trip_temp)(struct thermal_zone_device___2 *, int, int);
	int (*get_trip_hyst)(struct thermal_zone_device___2 *, int, int *);
	int (*set_trip_hyst)(struct thermal_zone_device___2 *, int, int);
	int (*get_crit_temp)(struct thermal_zone_device___2 *, int *);
	int (*set_emul_temp)(struct thermal_zone_device___2 *, int);
	int (*get_trend)(struct thermal_zone_device___2 *, int, enum thermal_trend *);
	int (*notify)(struct thermal_zone_device___2 *, int, enum thermal_trip_type);
};

struct thermal_attr___2;

struct thermal_zone_params___2;

struct thermal_governor___2;

struct thermal_zone_device___2 {
	int id;
	char type[20];
	struct device___274 device;
	struct attribute_group___273 trips_attribute_group;
	struct thermal_attr___2 *trip_temp_attrs;
	struct thermal_attr___2 *trip_type_attrs;
	struct thermal_attr___2 *trip_hyst_attrs;
	void *devdata;
	int trips;
	long unsigned int trips_disabled;
	int passive_delay;
	int polling_delay;
	int temperature;
	int last_temperature;
	int emul_temperature;
	int passive;
	int prev_low_trip;
	int prev_high_trip;
	unsigned int forced_passive;
	atomic_t need_update;
	struct thermal_zone_device_ops___2 *ops;
	struct thermal_zone_params___2 *tzp;
	struct thermal_governor___2 *governor;
	void *governor_data;
	struct list_head thermal_instances;
	struct ida ida;
	struct mutex lock;
	struct list_head node;
	struct delayed_work poll_queue;
	enum thermal_notify_event notify_event;
};

struct thermal_cooling_device_ops___2;

struct thermal_cooling_device___2 {
	int id;
	char type[20];
	struct device___274 device;
	struct device_node___66 *np;
	void *devdata;
	void *stats;
	const struct thermal_cooling_device_ops___2 *ops;
	bool updated;
	struct mutex lock;
	struct list_head thermal_instances;
	struct list_head node;
};

struct thermal_cooling_device_ops___2 {
	int (*get_max_state)(struct thermal_cooling_device___2 *, long unsigned int *);
	int (*get_cur_state)(struct thermal_cooling_device___2 *, long unsigned int *);
	int (*set_cur_state)(struct thermal_cooling_device___2 *, long unsigned int);
	int (*get_requested_power)(struct thermal_cooling_device___2 *, struct thermal_zone_device___2 *, u32 *);
	int (*state2power)(struct thermal_cooling_device___2 *, struct thermal_zone_device___2 *, long unsigned int, u32 *);
	int (*power2state)(struct thermal_cooling_device___2 *, struct thermal_zone_device___2 *, u32, long unsigned int *);
};

struct thermal_attr___2 {
	struct device_attribute___21 attr;
	char name[20];
};

struct thermal_bind_params___2;

struct thermal_zone_params___2 {
	char governor_name[20];
	bool no_hwmon;
	int num_tbps;
	struct thermal_bind_params___2 *tbp;
	u32 sustainable_power;
	s32 k_po;
	s32 k_pu;
	s32 k_i;
	s32 k_d;
	s32 integral_cutoff;
	int slope;
	int offset;
};

struct thermal_governor___2 {
	char name[20];
	int (*bind_to_tz)(struct thermal_zone_device___2 *);
	void (*unbind_from_tz)(struct thermal_zone_device___2 *);
	int (*throttle)(struct thermal_zone_device___2 *, int);
	struct list_head governor_list;
};

struct thermal_bind_params___2 {
	struct thermal_cooling_device___2 *cdev;
	int weight;
	int trip_mask;
	long unsigned int *binding_limits;
	int (*match)(struct thermal_zone_device___2 *, struct thermal_cooling_device___2 *);
};

struct platform_device___15 {
	const char *name;
	int id;
	bool id_auto;
	struct device___274 dev;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct platform_driver___13 {
	int (*probe)(struct platform_device___15 *);
	int (*remove)(struct platform_device___15 *);
	void (*shutdown)(struct platform_device___15 *);
	int (*suspend)(struct platform_device___15 *, pm_message_t);
	int (*resume)(struct platform_device___15 *);
	struct device_driver___274 driver;
	const struct platform_device_id *id_table;
	bool prevent_deferred_probe;
};

struct acpi_fan_fps {
	u64 control;
	u64 trip_point;
	u64 speed;
	u64 noise_level;
	u64 power;
};

struct acpi_fan_fif {
	u64 revision;
	u64 fine_grain_ctrl;
	u64 step_size;
	u64 low_speed_notification;
};

struct acpi_fan {
	bool acpi4;
	struct acpi_fan_fif fif;
	struct acpi_fan_fps *fps;
	int fps_count;
	struct thermal_cooling_device___2 *cdev;
};

struct acpi_pci_slot {
	struct pci_slot___20 *pci_slot;
	struct list_head list;
};

struct module___252;

struct file___312;

struct kiocb___312;

struct poll_table_struct___189;

struct vm_area_struct___313;

struct inode___312;

struct file_lock___312;

struct page___313;

struct seq_file___264;

struct file_operations___312 {
	struct module___252 *owner;
	loff_t (*llseek)(struct file___312 *, loff_t, int);
	ssize_t (*read)(struct file___312 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___312 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___312 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___312 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___312 *, bool);
	int (*iterate)(struct file___312 *, struct dir_context *);
	int (*iterate_shared)(struct file___312 *, struct dir_context *);
	__poll_t (*poll)(struct file___312 *, struct poll_table_struct___189 *);
	long int (*unlocked_ioctl)(struct file___312 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___312 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___312 *, struct vm_area_struct___313 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___312 *, struct file___312 *);
	int (*flush)(struct file___312 *, fl_owner_t);
	int (*release)(struct inode___312 *, struct file___312 *);
	int (*fsync)(struct file___312 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___312 *, int);
	int (*lock)(struct file___312 *, int, struct file_lock___312 *);
	ssize_t (*sendpage)(struct file___312 *, struct page___313 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___312 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___312 *, int, struct file_lock___312 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___312 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___312 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___312 *, long int, struct file_lock___312 **, void **);
	long int (*fallocate)(struct file___312 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___264 *, struct file___312 *);
	ssize_t (*copy_file_range)(struct file___312 *, loff_t, struct file___312 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___312 *, loff_t, struct file___312 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___312 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___312 {
	u64 seqnum;
	struct vm_area_struct___313 *vmas[4];
};

struct page_frag___312 {
	struct page___313 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___312;

struct cred___290;

struct vm_struct___228;

struct task_struct___313 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___313 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___312 *mm;
	struct mm_struct___312 *active_mm;
	struct vmacache___312 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___313 *real_parent;
	struct task_struct___313 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___313 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___204 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___204 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___204 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___290 *ptracer_cred;
	const struct cred___290 *real_cred;
	const struct cred___290 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___313 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___82 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___312 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___313 *oom_reaper_list;
	struct vm_struct___228 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___131 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___313 *pgtable_t___312;

struct address_space___311;

struct dev_pagemap___301;

struct page___313 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___311 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___313 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___312 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___312 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___301 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___312;

struct lruvec___312 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___312 *pgdat;
};

struct zone___312 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___312 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___312 {
	struct zone___312 *zone;
	int zone_idx;
};

struct zonelist___312 {
	struct zoneref___312 _zonerefs[25];
};

struct pglist_data___312 {
	struct zone___312 node_zones[3];
	struct zonelist___312 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___313 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___313 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___312 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___313 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___313 *owner;
};

struct secondary_data___313 {
	void *stack;
	struct task_struct___313 *task;
	long int status;
};

struct blocking_notifier_head___312 {
	struct rw_semaphore___313 rwsem;
	struct notifier_block *head;
};

struct dentry___311;

struct path___312 {
	struct vfsmount *mnt;
	struct dentry___311 *dentry;
};

struct file___312 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___312 f_path;
	struct inode___312 *f_inode;
	const struct file_operations___312 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___204 f_owner;
	const struct cred___290 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___311 *f_mapping;
	errseq_t f_wb_err;
};

struct key___290;

struct user_struct___290;

struct cred___290 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___290 *session_keyring;
	struct key___290 *process_keyring;
	struct key___290 *thread_keyring;
	struct key___290 *request_key_auth;
	void *security;
	struct user_struct___290 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___305;

struct kernfs_elem_dir___305 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___305 *root;
};

struct kernfs_node___306;

struct kernfs_syscall_ops___305;

struct kernfs_root___305 {
	struct kernfs_node___306 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___305 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___305 {
	struct kernfs_node___306 *target_kn;
};

struct kernfs_ops___305;

struct kernfs_elem_attr___305 {
	const struct kernfs_ops___305 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___306 *notify_next;
};

struct kernfs_node___306 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___306 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___305 dir;
		struct kernfs_elem_symlink___305 symlink;
		struct kernfs_elem_attr___305 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___305;

struct kernfs_ops___305 {
	int (*open)(struct kernfs_open_file___305 *);
	void (*release)(struct kernfs_open_file___305 *);
	int (*seq_show)(struct seq_file___264 *, void *);
	void * (*seq_start)(struct seq_file___264 *, loff_t *);
	void * (*seq_next)(struct seq_file___264 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___264 *, void *);
	ssize_t (*read)(struct kernfs_open_file___305 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___305 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___305 *, struct vm_area_struct___313 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___305 *, struct poll_table_struct___189 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___305 {
	int (*remount_fs)(struct kernfs_root___305 *, int *, char *);
	int (*show_options)(struct seq_file___264 *, struct kernfs_root___305 *);
	int (*mkdir)(struct kernfs_node___306 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___306 *);
	int (*rename)(struct kernfs_node___306 *, struct kernfs_node___306 *, const char *);
	int (*show_path)(struct seq_file___264 *, struct kernfs_node___306 *, struct kernfs_root___305 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___263;

struct seq_file___264 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___263 *op;
	int poll_event;
	const struct file___312 *file;
	void *private;
};

struct vm_operations_struct___301;

struct kernfs_open_file___305 {
	struct kernfs_node___306 *kn;
	struct file___312 *file;
	struct seq_file___264 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___301 *vm_ops;
};

struct vm_fault___301;

struct vm_operations_struct___301 {
	void (*open)(struct vm_area_struct___313 *);
	void (*close)(struct vm_area_struct___313 *);
	int (*split)(struct vm_area_struct___313 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___313 *);
	vm_fault_t (*fault)(struct vm_fault___301 *);
	vm_fault_t (*huge_fault)(struct vm_fault___301 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___301 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___313 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___301 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___301 *);
	int (*access)(struct vm_area_struct___313 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___313 *);
	int (*set_policy)(struct vm_area_struct___313 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___313 *, long unsigned int);
	struct page___313 * (*find_special_page)(struct vm_area_struct___313 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___193)(struct file___312 *, wait_queue_head_t *, struct poll_table_struct___189 *);

struct poll_table_struct___189 {
	poll_queue_proc___193 _qproc;
	__poll_t _key;
};

struct vm_area_struct___313 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___313 *vm_next;
	struct vm_area_struct___313 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___312 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___301 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___312 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___299;

struct bin_attribute___275;

struct attribute_group___276 {
	const char *name;
	umode_t (*is_visible)(struct kobject___299 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___299 *, struct bin_attribute___275 *, int);
	struct attribute **attrs;
	struct bin_attribute___275 **bin_attrs;
};

struct kset___298;

struct kobj_type___298;

struct kobject___299 {
	const char *name;
	struct list_head entry;
	struct kobject___299 *parent;
	struct kset___298 *kset;
	struct kobj_type___298 *ktype;
	struct kernfs_node___306 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___275 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___312 *, struct kobject___299 *, struct bin_attribute___275 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___312 *, struct kobject___299 *, struct bin_attribute___275 *, char *, loff_t, size_t);
	int (*mmap)(struct file___312 *, struct kobject___299 *, struct bin_attribute___275 *, struct vm_area_struct___313 *);
};

struct sysfs_ops___298 {
	ssize_t (*show)(struct kobject___299 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___299 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___298;

struct kset___298 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___299 kobj;
	const struct kset_uevent_ops___298 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___298 {
	void (*release)(struct kobject___299 *);
	const struct sysfs_ops___298 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___25 * (*child_ns_type)(struct kobject___299 *);
	const void * (*namespace)(struct kobject___299 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___298 {
	int (* const filter)(struct kset___298 *, struct kobject___299 *);
	const char * (* const name)(struct kset___298 *, struct kobject___299 *);
	int (* const uevent)(struct kset___298 *, struct kobject___299 *, struct kobj_uevent_env *);
};

struct kobj_attribute___291 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___299 *, struct kobj_attribute___291 *, char *);
	ssize_t (*store)(struct kobject___299 *, struct kobj_attribute___291 *, const char *, size_t);
};

struct kernel_param___249;

struct kernel_param_ops___249 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___249 *);
	int (*get)(char *, const struct kernel_param___249 *);
	void (*free)(void *);
};

struct kparam_array___249;

struct kernel_param___249 {
	const char *name;
	struct module___252 *mod;
	const struct kernel_param_ops___249 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___249 *arr;
	};
};

struct kparam_array___249 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___249 *ops;
	void *elem;
};

struct module_kobject___249 {
	struct kobject___299 kobj;
	struct module___252 *mod;
	struct kobject___299 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___249 {
	struct module___252 *mod;
	struct latch_tree_node node;
};

struct module_layout___249 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___249 mtn;
};

struct module_attribute___249;

struct module___252 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___249 mkobj;
	struct module_attribute___249 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___299 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___249 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___249 core_layout;
	struct module_layout___249 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___249 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___249 *, struct module_kobject___249 *, char *);
	ssize_t (*store)(struct module_attribute___249 *, struct module_kobject___249 *, const char *, size_t);
	void (*setup)(struct module___252 *, const char *);
	int (*test)(struct module___252 *);
	void (*free)(struct module___252 *);
};

struct cpufreq_governor___4;

struct cpufreq_policy___4 {
	cpumask_var_t cpus;
	cpumask_var_t related_cpus;
	cpumask_var_t real_cpus;
	unsigned int shared_type;
	unsigned int cpu;
	struct clk *clk;
	struct cpufreq_cpuinfo cpuinfo;
	unsigned int min;
	unsigned int max;
	unsigned int cur;
	unsigned int restore_freq;
	unsigned int suspend_freq;
	unsigned int policy;
	unsigned int last_policy;
	struct cpufreq_governor___4 *governor;
	void *governor_data;
	char last_governor[16];
	struct work_struct update;
	struct cpufreq_user_policy user_policy;
	struct cpufreq_frequency_table *freq_table;
	enum cpufreq_table_sorting freq_table_sorted;
	struct list_head policy_list;
	struct kobject___299 kobj;
	struct completion kobj_unregister;
	struct rw_semaphore___313 rwsem;
	bool fast_switch_possible;
	bool fast_switch_enabled;
	unsigned int transition_delay_us;
	bool dvfs_possible_from_any_cpu;
	unsigned int cached_target_freq;
	int cached_resolved_idx;
	bool transition_ongoing;
	spinlock_t transition_lock;
	wait_queue_head_t transition_wait;
	struct task_struct___313 *transition_task;
	struct cpufreq_stats *stats;
	void *driver_data;
};

struct cpufreq_governor___4 {
	char name[16];
	int (*init)(struct cpufreq_policy___4 *);
	void (*exit)(struct cpufreq_policy___4 *);
	int (*start)(struct cpufreq_policy___4 *);
	void (*stop)(struct cpufreq_policy___4 *);
	void (*limits)(struct cpufreq_policy___4 *);
	ssize_t (*show_setspeed)(struct cpufreq_policy___4 *, char *);
	int (*store_setspeed)(struct cpufreq_policy___4 *, unsigned int);
	bool dynamic_switching;
	struct list_head governor_list;
	struct module___252 *owner;
};

struct freq_attr___4 {
	struct attribute attr;
	ssize_t (*show)(struct cpufreq_policy___4 *, char *);
	ssize_t (*store)(struct cpufreq_policy___4 *, const char *, size_t);
};

struct device___277;

struct dev_pm_ops___277 {
	int (*prepare)(struct device___277 *);
	void (*complete)(struct device___277 *);
	int (*suspend)(struct device___277 *);
	int (*resume)(struct device___277 *);
	int (*freeze)(struct device___277 *);
	int (*thaw)(struct device___277 *);
	int (*poweroff)(struct device___277 *);
	int (*restore)(struct device___277 *);
	int (*suspend_late)(struct device___277 *);
	int (*resume_early)(struct device___277 *);
	int (*freeze_late)(struct device___277 *);
	int (*thaw_early)(struct device___277 *);
	int (*poweroff_late)(struct device___277 *);
	int (*restore_early)(struct device___277 *);
	int (*suspend_noirq)(struct device___277 *);
	int (*resume_noirq)(struct device___277 *);
	int (*freeze_noirq)(struct device___277 *);
	int (*thaw_noirq)(struct device___277 *);
	int (*poweroff_noirq)(struct device___277 *);
	int (*restore_noirq)(struct device___277 *);
	int (*runtime_suspend)(struct device___277 *);
	int (*runtime_resume)(struct device___277 *);
	int (*runtime_idle)(struct device___277 *);
};

struct dev_pm_info___277 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___2 *subsys_data;
	void (*set_latency_tolerance)(struct device___277 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___277;

struct bus_type___277;

struct device_driver___277;

struct dev_pm_domain___277;

struct device_node___68;

struct fwnode_handle___211;

struct class___277;

struct device___277 {
	struct device___277 *parent;
	struct device_private *p;
	struct kobject___299 kobj;
	const char *init_name;
	const struct device_type___277 *type;
	struct mutex mutex;
	struct bus_type___277 *bus;
	struct device_driver___277 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___277 power;
	struct dev_pm_domain___277 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___68 *of_node;
	struct fwnode_handle___211 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___277 *class;
	const struct attribute_group___276 **groups;
	void (*release)(struct device___277 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___277 {
	struct dev_pm_ops___277 ops;
	void (*detach)(struct device___277 *, bool);
	int (*activate)(struct device___277 *);
	void (*sync)(struct device___277 *);
	void (*dismiss)(struct device___277 *);
};

struct user_struct___290 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___290 *uid_keyring;
	struct key___290 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___312;

struct mm_struct___312 {
	struct {
		struct vm_area_struct___313 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___312 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___313 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___312 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___313 *owner;
		struct user_namespace___3 *user_ns;
		struct file___312 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___312 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct vm_struct___228 {
	struct vm_struct___228 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___313 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bus_type___277 {
	const char *name;
	const char *dev_name;
	struct device___277 *dev_root;
	const struct attribute_group___276 **bus_groups;
	const struct attribute_group___276 **dev_groups;
	const struct attribute_group___276 **drv_groups;
	int (*match)(struct device___277 *, struct device_driver___277 *);
	int (*uevent)(struct device___277 *, struct kobj_uevent_env *);
	int (*probe)(struct device___277 *);
	int (*remove)(struct device___277 *);
	void (*shutdown)(struct device___277 *);
	int (*online)(struct device___277 *);
	int (*offline)(struct device___277 *);
	int (*suspend)(struct device___277 *, pm_message_t);
	int (*resume)(struct device___277 *);
	int (*num_vf)(struct device___277 *);
	int (*dma_configure)(struct device___277 *);
	const struct dev_pm_ops___277 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___277 {
	const char *name;
	struct bus_type___277 *bus;
	struct module___252 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___277 *);
	int (*remove)(struct device___277 *);
	void (*shutdown)(struct device___277 *);
	int (*suspend)(struct device___277 *, pm_message_t);
	int (*resume)(struct device___277 *);
	const struct attribute_group___276 **groups;
	const struct dev_pm_ops___277 *pm;
	void (*coredump)(struct device___277 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___277 {
	const char *name;
	const struct attribute_group___276 **groups;
	int (*uevent)(struct device___277 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___277 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___277 *);
	const struct dev_pm_ops___277 *pm;
};

struct class___277 {
	const char *name;
	struct module___252 *owner;
	const struct attribute_group___276 **class_groups;
	const struct attribute_group___276 **dev_groups;
	struct kobject___299 *dev_kobj;
	int (*dev_uevent)(struct device___277 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___277 *, umode_t *);
	void (*class_release)(struct class___277 *);
	void (*dev_release)(struct device___277 *);
	int (*shutdown_pre)(struct device___277 *);
	const struct kobj_ns_type_operations___25 *ns_type;
	const void * (*namespace)(struct device___277 *);
	const struct dev_pm_ops___277 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct device_attribute___22 {
	struct attribute attr;
	ssize_t (*show)(struct device___277 *, struct device_attribute___22 *, char *);
	ssize_t (*store)(struct device___277 *, struct device_attribute___22 *, const char *, size_t);
};

struct fwnode_operations___211;

struct fwnode_handle___211 {
	struct fwnode_handle___211 *secondary;
	const struct fwnode_operations___211 *ops;
};

struct property___65;

struct device_node___68 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___211 fwnode;
	struct property___65 *properties;
	struct property___65 *deadprops;
	struct device_node___68 *parent;
	struct device_node___68 *child;
	struct device_node___68 *sibling;
	struct kobject___299 kobj;
	long unsigned int _flags;
	void *data;
};

struct node___185 {
	struct device___277 dev;
};

struct cpuidle_driver___5;

struct cpuidle_state___4 {
	char name[16];
	char desc[32];
	unsigned int flags;
	unsigned int exit_latency;
	int power_usage;
	unsigned int target_residency;
	bool disabled;
	int (*enter)(struct cpuidle_device *, struct cpuidle_driver___5 *, int);
	int (*enter_dead)(struct cpuidle_device *, int);
	void (*enter_s2idle)(struct cpuidle_device *, struct cpuidle_driver___5 *, int);
};

struct cpuidle_driver___5 {
	const char *name;
	struct module___252 *owner;
	int refcnt;
	unsigned int bctimer: 1;
	struct cpuidle_state___4 states[10];
	int state_count;
	int safe_state_index;
	struct cpumask *cpumask;
};

struct fwnode_reference_args___211;

struct fwnode_endpoint___211;

struct fwnode_operations___211 {
	struct fwnode_handle___211 * (*get)(struct fwnode_handle___211 *);
	void (*put)(struct fwnode_handle___211 *);
	bool (*device_is_available)(const struct fwnode_handle___211 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___211 *, const struct device___277 *);
	bool (*property_present)(const struct fwnode_handle___211 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___211 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___211 *, const char *, const char **, size_t);
	struct fwnode_handle___211 * (*get_parent)(const struct fwnode_handle___211 *);
	struct fwnode_handle___211 * (*get_next_child_node)(const struct fwnode_handle___211 *, struct fwnode_handle___211 *);
	struct fwnode_handle___211 * (*get_named_child_node)(const struct fwnode_handle___211 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___211 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___211 *);
	struct fwnode_handle___211 * (*graph_get_next_endpoint)(const struct fwnode_handle___211 *, struct fwnode_handle___211 *);
	struct fwnode_handle___211 * (*graph_get_remote_endpoint)(const struct fwnode_handle___211 *);
	struct fwnode_handle___211 * (*graph_get_port_parent)(struct fwnode_handle___211 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___211 *, struct fwnode_endpoint___211 *);
};

struct fwnode_endpoint___211 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___211 *local_fwnode;
};

struct fwnode_reference_args___211 {
	struct fwnode_handle___211 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct dentry_operations___311;

struct super_block___311;

struct dentry___311 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___311 *d_parent;
	struct qstr d_name;
	struct inode___312 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___311 *d_op;
	struct super_block___311 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___311;

struct address_space___311 {
	struct inode___312 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___313 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___311 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___311;

struct block_device___311;

struct cdev___62;

struct inode___312 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___311 *i_op;
	struct super_block___311 *i_sb;
	struct address_space___311 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___313 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___312 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___311 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___311 *i_bdev;
		struct cdev___62 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___311 {
	int (*d_revalidate)(struct dentry___311 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___311 *, unsigned int);
	int (*d_hash)(const struct dentry___311 *, struct qstr *);
	int (*d_compare)(const struct dentry___311 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___311 *);
	int (*d_init)(struct dentry___311 *);
	void (*d_release)(struct dentry___311 *);
	void (*d_prune)(struct dentry___311 *);
	void (*d_iput)(struct dentry___311 *, struct inode___312 *);
	char * (*d_dname)(struct dentry___311 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___312 *);
	int (*d_manage)(const struct path___312 *, bool);
	struct dentry___311 * (*d_real)(struct dentry___311 *, const struct inode___312 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___311;

struct mem_dqinfo___311 {
	struct quota_format_type___311 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___311;

struct quota_info___311 {
	unsigned int flags;
	struct rw_semaphore___313 dqio_sem;
	struct inode___312 *files[3];
	struct mem_dqinfo___311 info[3];
	const struct quota_format_ops___311 *ops[3];
};

struct rcuwait___311 {
	struct task_struct___313 *task;
};

struct percpu_rw_semaphore___311 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___313 rw_sem;
	struct rcuwait___311 writer;
	int readers_block;
};

struct sb_writers___311 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___311 rw_sem[3];
};

struct file_system_type___311;

struct super_operations___311;

struct dquot_operations___311;

struct quotactl_ops___311;

struct super_block___311 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___311 *s_type;
	const struct super_operations___311 *s_op;
	const struct dquot_operations___311 *dq_op;
	const struct quotactl_ops___311 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___311 *s_root;
	struct rw_semaphore___313 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___311 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___311 s_dquot;
	struct sb_writers___311 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___311 *s_d_op;
	int cleancache_poolid;
	struct shrinker___119 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

typedef int (*dev_page_fault_t___301)(struct vm_area_struct___313 *, long unsigned int, const struct page___313 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___301)(struct page___313 *, void *);

struct dev_pagemap___301 {
	dev_page_fault_t___301 page_fault;
	dev_page_free_t___301 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___277 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___312 {
	struct task_struct___313 *task;
	struct core_thread___312 *next;
};

struct core_state___312 {
	atomic_t nr_threads;
	struct core_thread___312 dumper;
	struct completion startup;
};

struct vm_fault___301 {
	struct vm_area_struct___313 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___313 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___313 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___312 prealloc_pte;
};

struct kiocb___312 {
	struct file___312 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___312 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___311 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___312 *ia_file;
};

struct dquot___311 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___311 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___311 {
	int qf_fmt_id;
	const struct quota_format_ops___311 *qf_ops;
	struct module___252 *qf_owner;
	struct quota_format_type___311 *qf_next;
};

struct quota_format_ops___311 {
	int (*check_quota_file)(struct super_block___311 *, int);
	int (*read_file_info)(struct super_block___311 *, int);
	int (*write_file_info)(struct super_block___311 *, int);
	int (*free_file_info)(struct super_block___311 *, int);
	int (*read_dqblk)(struct dquot___311 *);
	int (*commit_dqblk)(struct dquot___311 *);
	int (*release_dqblk)(struct dquot___311 *);
	int (*get_next_id)(struct super_block___311 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___311 {
	int (*write_dquot)(struct dquot___311 *);
	struct dquot___311 * (*alloc_dquot)(struct super_block___311 *, int);
	void (*destroy_dquot)(struct dquot___311 *);
	int (*acquire_dquot)(struct dquot___311 *);
	int (*release_dquot)(struct dquot___311 *);
	int (*mark_dirty)(struct dquot___311 *);
	int (*write_info)(struct super_block___311 *, int);
	qsize_t * (*get_reserved_space)(struct inode___312 *);
	int (*get_projid)(struct inode___312 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___312 *, qsize_t *);
	int (*get_next_id)(struct super_block___311 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___311 {
	int (*quota_on)(struct super_block___311 *, int, int, const struct path___312 *);
	int (*quota_off)(struct super_block___311 *, int);
	int (*quota_enable)(struct super_block___311 *, unsigned int);
	int (*quota_disable)(struct super_block___311 *, unsigned int);
	int (*quota_sync)(struct super_block___311 *, int);
	int (*set_info)(struct super_block___311 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___311 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___311 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___311 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___311 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___311 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___311 {
	int (*writepage)(struct page___313 *, struct writeback_control___3 *);
	int (*readpage)(struct file___312 *, struct page___313 *);
	int (*writepages)(struct address_space___311 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___313 *);
	int (*readpages)(struct file___312 *, struct address_space___311 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___312 *, struct address_space___311 *, loff_t, unsigned int, unsigned int, struct page___313 **, void **);
	int (*write_end)(struct file___312 *, struct address_space___311 *, loff_t, unsigned int, unsigned int, struct page___313 *, void *);
	sector_t (*bmap)(struct address_space___311 *, sector_t);
	void (*invalidatepage)(struct page___313 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___313 *, gfp_t);
	void (*freepage)(struct page___313 *);
	ssize_t (*direct_IO)(struct kiocb___312 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___311 *, struct page___313 *, struct page___313 *, enum migrate_mode);
	bool (*isolate_page)(struct page___313 *, isolate_mode_t);
	void (*putback_page)(struct page___313 *);
	int (*launder_page)(struct page___313 *);
	int (*is_partially_uptodate)(struct page___313 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___313 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___311 *, struct page___313 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___312 *, sector_t *);
	void (*swap_deactivate)(struct file___312 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___311 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___312 *bd_inode;
	struct super_block___311 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___311 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___62 {
	struct kobject___299 kobj;
	struct module___252 *owner;
	const struct file_operations___312 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___311 {
	struct dentry___311 * (*lookup)(struct inode___312 *, struct dentry___311 *, unsigned int);
	const char * (*get_link)(struct dentry___311 *, struct inode___312 *, struct delayed_call *);
	int (*permission)(struct inode___312 *, int);
	struct posix_acl * (*get_acl)(struct inode___312 *, int);
	int (*readlink)(struct dentry___311 *, char *, int);
	int (*create)(struct inode___312 *, struct dentry___311 *, umode_t, bool);
	int (*link)(struct dentry___311 *, struct inode___312 *, struct dentry___311 *);
	int (*unlink)(struct inode___312 *, struct dentry___311 *);
	int (*symlink)(struct inode___312 *, struct dentry___311 *, const char *);
	int (*mkdir)(struct inode___312 *, struct dentry___311 *, umode_t);
	int (*rmdir)(struct inode___312 *, struct dentry___311 *);
	int (*mknod)(struct inode___312 *, struct dentry___311 *, umode_t, dev_t);
	int (*rename)(struct inode___312 *, struct dentry___311 *, struct inode___312 *, struct dentry___311 *, unsigned int);
	int (*setattr)(struct dentry___311 *, struct iattr___311 *);
	int (*getattr)(const struct path___312 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___311 *, char *, size_t);
	int (*fiemap)(struct inode___312 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___312 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___312 *, struct dentry___311 *, struct file___312 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___312 *, struct dentry___311 *, umode_t);
	int (*set_acl)(struct inode___312 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___311 {
	void (*fl_copy_lock)(struct file_lock___312 *, struct file_lock___312 *);
	void (*fl_release_private)(struct file_lock___312 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___311;

struct lock_manager_operations___311;

struct file_lock___312 {
	struct file_lock___312 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___312 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___311 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___311 *fl_ops;
	const struct lock_manager_operations___311 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___311 {
	int (*lm_compare_owner)(struct file_lock___312 *, struct file_lock___312 *);
	long unsigned int (*lm_owner_key)(struct file_lock___312 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___312 *);
	int (*lm_grant)(struct file_lock___312 *, int);
	bool (*lm_break)(struct file_lock___312 *);
	int (*lm_change)(struct file_lock___312 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___312 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___311 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___311 *fa_next;
	struct file___312 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___311 {
	const char *name;
	int fs_flags;
	struct dentry___311 * (*mount)(struct file_system_type___311 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___311 *);
	struct module___252 *owner;
	struct file_system_type___311 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___311 {
	struct inode___312 * (*alloc_inode)(struct super_block___311 *);
	void (*destroy_inode)(struct inode___312 *);
	void (*dirty_inode)(struct inode___312 *, int);
	int (*write_inode)(struct inode___312 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___312 *);
	void (*evict_inode)(struct inode___312 *);
	void (*put_super)(struct super_block___311 *);
	int (*sync_fs)(struct super_block___311 *, int);
	int (*freeze_super)(struct super_block___311 *);
	int (*freeze_fs)(struct super_block___311 *);
	int (*thaw_super)(struct super_block___311 *);
	int (*unfreeze_fs)(struct super_block___311 *);
	int (*statfs)(struct dentry___311 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___311 *, int *, char *);
	void (*umount_begin)(struct super_block___311 *);
	int (*show_options)(struct seq_file___264 *, struct dentry___311 *);
	int (*show_devname)(struct seq_file___264 *, struct dentry___311 *);
	int (*show_path)(struct seq_file___264 *, struct dentry___311 *);
	int (*show_stats)(struct seq_file___264 *, struct dentry___311 *);
	ssize_t (*quota_read)(struct super_block___311 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___311 *, int, const char *, size_t, loff_t);
	struct dquot___311 ** (*get_dquots)(struct inode___312 *);
	int (*bdev_try_to_free_page)(struct super_block___311 *, struct page___313 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___311 *, struct shrink_control___119 *);
	long int (*free_cached_objects)(struct super_block___311 *, struct shrink_control___119 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct acpi_device___13;

struct acpi_hotplug_profile___13 {
	struct kobject___299 kobj;
	int (*scan_dependent)(struct acpi_device___13 *);
	void (*notify_online)(struct acpi_device___13 *);
	bool enabled: 1;
	bool demand_offline: 1;
};

struct acpi_device_wakeup_context___13 {
	void (*func)(struct acpi_device_wakeup_context___13 *);
	struct device___277 *dev;
};

struct acpi_device_wakeup___13 {
	acpi_handle gpe_device;
	u64 gpe_number;
	u64 sleep_state;
	struct list_head resources;
	struct acpi_device_wakeup_flags flags;
	struct acpi_device_wakeup_context___13 context;
	struct wakeup_source *ws;
	int prepare_count;
	int enable_count;
};

struct acpi_scan_handler___13;

struct acpi_hotplug_context___13;

struct acpi_driver___13;

struct acpi_device___13 {
	int device_type;
	acpi_handle handle;
	struct fwnode_handle___211 fwnode;
	struct acpi_device___13 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup___13 wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_device_data data;
	struct acpi_scan_handler___13 *handler;
	struct acpi_hotplug_context___13 *hp;
	struct acpi_driver___13 *driver;
	const struct acpi_gpio_mapping *driver_gpios;
	void *driver_data;
	struct device___277 dev;
	unsigned int physical_node_count;
	unsigned int dep_unmet;
	struct list_head physical_node_list;
	struct mutex physical_node_lock;
	void (*remove)(struct acpi_device___13 *);
};

struct acpi_scan_handler___13 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	bool (*match)(const char *, const struct acpi_device_id **);
	int (*attach)(struct acpi_device___13 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___13 *);
	void (*bind)(struct device___277 *);
	void (*unbind)(struct device___277 *);
	struct acpi_hotplug_profile___13 hotplug;
};

struct acpi_hotplug_context___13 {
	struct acpi_device___13 *self;
	int (*notify)(struct acpi_device___13 *, u32);
	void (*uevent)(struct acpi_device___13 *, u32);
	void (*fixup)(struct acpi_device___13 *);
};

typedef int (*acpi_op_add___13)(struct acpi_device___13 *);

typedef int (*acpi_op_remove___13)(struct acpi_device___13 *);

typedef void (*acpi_op_notify___13)(struct acpi_device___13 *, u32);

struct acpi_device_ops___13 {
	acpi_op_add___13 add;
	acpi_op_remove___13 remove;
	acpi_op_notify___13 notify;
};

struct acpi_driver___13 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___13 ops;
	struct device_driver___277 drv;
	struct module___252 *owner;
};

typedef int (*key_restrict_link_func_t___291)(struct key___290 *, const struct key_type *, const union key_payload *, struct key___290 *);

struct key_restriction___290;

struct key___290 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___313 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___290 *restrict_link;
};

struct key_restriction___290 {
	key_restrict_link_func_t___291 check;
	struct key___290 *key;
	struct key_type *keytype;
};

struct seq_operations___263 {
	void * (*start)(struct seq_file___264 *, loff_t *);
	void (*stop)(struct seq_file___264 *, void *);
	void * (*next)(struct seq_file___264 *, void *, loff_t *);
	int (*show)(struct seq_file___264 *, void *);
};

typedef void compound_page_dtor___301(struct page___313 *);

struct property___65 {
	char *name;
	int length;
	void *value;
	struct property___65 *next;
	long unsigned int _flags;
	struct bin_attribute___275 attr;
};

struct thermal_zone_device___3;

struct thermal_cooling_device___3;

struct thermal_zone_device_ops___3 {
	int (*bind)(struct thermal_zone_device___3 *, struct thermal_cooling_device___3 *);
	int (*unbind)(struct thermal_zone_device___3 *, struct thermal_cooling_device___3 *);
	int (*get_temp)(struct thermal_zone_device___3 *, int *);
	int (*set_trips)(struct thermal_zone_device___3 *, int, int);
	int (*get_mode)(struct thermal_zone_device___3 *, enum thermal_device_mode *);
	int (*set_mode)(struct thermal_zone_device___3 *, enum thermal_device_mode);
	int (*get_trip_type)(struct thermal_zone_device___3 *, int, enum thermal_trip_type *);
	int (*get_trip_temp)(struct thermal_zone_device___3 *, int, int *);
	int (*set_trip_temp)(struct thermal_zone_device___3 *, int, int);
	int (*get_trip_hyst)(struct thermal_zone_device___3 *, int, int *);
	int (*set_trip_hyst)(struct thermal_zone_device___3 *, int, int);
	int (*get_crit_temp)(struct thermal_zone_device___3 *, int *);
	int (*set_emul_temp)(struct thermal_zone_device___3 *, int);
	int (*get_trend)(struct thermal_zone_device___3 *, int, enum thermal_trend *);
	int (*notify)(struct thermal_zone_device___3 *, int, enum thermal_trip_type);
};

struct thermal_attr___3;

struct thermal_zone_params___3;

struct thermal_governor___3;

struct thermal_zone_device___3 {
	int id;
	char type[20];
	struct device___277 device;
	struct attribute_group___276 trips_attribute_group;
	struct thermal_attr___3 *trip_temp_attrs;
	struct thermal_attr___3 *trip_type_attrs;
	struct thermal_attr___3 *trip_hyst_attrs;
	void *devdata;
	int trips;
	long unsigned int trips_disabled;
	int passive_delay;
	int polling_delay;
	int temperature;
	int last_temperature;
	int emul_temperature;
	int passive;
	int prev_low_trip;
	int prev_high_trip;
	unsigned int forced_passive;
	atomic_t need_update;
	struct thermal_zone_device_ops___3 *ops;
	struct thermal_zone_params___3 *tzp;
	struct thermal_governor___3 *governor;
	void *governor_data;
	struct list_head thermal_instances;
	struct ida ida;
	struct mutex lock;
	struct list_head node;
	struct delayed_work poll_queue;
	enum thermal_notify_event notify_event;
};

struct thermal_cooling_device_ops___3;

struct thermal_cooling_device___3 {
	int id;
	char type[20];
	struct device___277 device;
	struct device_node___68 *np;
	void *devdata;
	void *stats;
	const struct thermal_cooling_device_ops___3 *ops;
	bool updated;
	struct mutex lock;
	struct list_head thermal_instances;
	struct list_head node;
};

struct thermal_cooling_device_ops___3 {
	int (*get_max_state)(struct thermal_cooling_device___3 *, long unsigned int *);
	int (*get_cur_state)(struct thermal_cooling_device___3 *, long unsigned int *);
	int (*set_cur_state)(struct thermal_cooling_device___3 *, long unsigned int);
	int (*get_requested_power)(struct thermal_cooling_device___3 *, struct thermal_zone_device___3 *, u32 *);
	int (*state2power)(struct thermal_cooling_device___3 *, struct thermal_zone_device___3 *, long unsigned int, u32 *);
	int (*power2state)(struct thermal_cooling_device___3 *, struct thermal_zone_device___3 *, u32, long unsigned int *);
};

struct thermal_attr___3 {
	struct device_attribute___22 attr;
	char name[20];
};

struct thermal_bind_params___3;

struct thermal_zone_params___3 {
	char governor_name[20];
	bool no_hwmon;
	int num_tbps;
	struct thermal_bind_params___3 *tbp;
	u32 sustainable_power;
	s32 k_po;
	s32 k_pu;
	s32 k_i;
	s32 k_d;
	s32 integral_cutoff;
	int slope;
	int offset;
};

struct thermal_governor___3 {
	char name[20];
	int (*bind_to_tz)(struct thermal_zone_device___3 *);
	void (*unbind_from_tz)(struct thermal_zone_device___3 *);
	int (*throttle)(struct thermal_zone_device___3 *, int);
	struct list_head governor_list;
};

struct thermal_bind_params___3 {
	struct thermal_cooling_device___3 *cdev;
	int weight;
	int trip_mask;
	long unsigned int *binding_limits;
	int (*match)(struct thermal_zone_device___3 *, struct thermal_cooling_device___3 *);
};

struct acpi_processor___2;

struct acpi_processor_throttling___2 {
	unsigned int state;
	unsigned int platform_limit;
	struct acpi_pct_register control_register;
	struct acpi_pct_register status_register;
	short: 16;
	unsigned int state_count;
	int: 32;
	struct acpi_processor_tx_tss *states_tss;
	struct acpi_tsd_package domain_info;
	cpumask_var_t shared_cpu_map;
	int (*acpi_processor_get_throttling)(struct acpi_processor___2 *);
	int (*acpi_processor_set_throttling)(struct acpi_processor___2 *, int, bool);
	u32 address;
	u8 duty_offset;
	u8 duty_width;
	u8 tsd_valid_flag;
	char: 8;
	unsigned int shared_type;
	struct acpi_processor_tx states[16];
	int: 32;
} __attribute__((packed));

struct acpi_processor___2 {
	acpi_handle handle;
	u32 acpi_id;
	phys_cpuid_t phys_id;
	u32 id;
	u32 pblk;
	int performance_platform_limit;
	int throttling_platform_limit;
	struct acpi_processor_flags flags;
	struct acpi_processor_power power;
	struct acpi_processor_performance *performance;
	struct acpi_processor_throttling___2 throttling;
	struct acpi_processor_limit limit;
	struct thermal_cooling_device___3 *cdev;
	struct device___277 *dev;
};

struct cpuidle_driver___6;

struct cpuidle_state___5 {
	char name[16];
	char desc[32];
	unsigned int flags;
	unsigned int exit_latency;
	int power_usage;
	unsigned int target_residency;
	bool disabled;
	int (*enter)(struct cpuidle_device *, struct cpuidle_driver___6 *, int);
	int (*enter_dead)(struct cpuidle_device *, int);
	void (*enter_s2idle)(struct cpuidle_device *, struct cpuidle_driver___6 *, int);
};

struct cpuidle_driver___6 {
	const char *name;
	struct module___249 *owner;
	int refcnt;
	unsigned int bctimer: 1;
	struct cpuidle_state___5 states[10];
	int state_count;
	int safe_state_index;
	struct cpumask *cpumask;
};

struct acpi_power_register {
	u8 descriptor;
	u16 length;
	u8 space_id;
	u8 bit_width;
	u8 bit_offset;
	u8 access_size;
	u64 address;
} __attribute__((packed));

struct acpi_processor___3;

struct acpi_processor_throttling___3 {
	unsigned int state;
	unsigned int platform_limit;
	struct acpi_pct_register control_register;
	struct acpi_pct_register status_register;
	short: 16;
	unsigned int state_count;
	int: 32;
	struct acpi_processor_tx_tss *states_tss;
	struct acpi_tsd_package domain_info;
	cpumask_var_t shared_cpu_map;
	int (*acpi_processor_get_throttling)(struct acpi_processor___3 *);
	int (*acpi_processor_set_throttling)(struct acpi_processor___3 *, int, bool);
	u32 address;
	u8 duty_offset;
	u8 duty_width;
	u8 tsd_valid_flag;
	char: 8;
	unsigned int shared_type;
	struct acpi_processor_tx states[16];
	int: 32;
} __attribute__((packed));

struct acpi_processor___3 {
	acpi_handle handle;
	u32 acpi_id;
	phys_cpuid_t phys_id;
	u32 id;
	u32 pblk;
	int performance_platform_limit;
	int throttling_platform_limit;
	struct acpi_processor_flags flags;
	struct acpi_processor_power power;
	struct acpi_processor_performance *performance;
	struct acpi_processor_throttling___3 throttling;
	struct acpi_processor_limit limit;
	struct thermal_cooling_device___2 *cdev;
	struct device___274 *dev;
};

struct acpi_lpi_states_array {
	unsigned int size;
	unsigned int composite_states_size;
	struct acpi_lpi_state *entries;
	struct acpi_lpi_state *composite_states[8];
};

struct container_dev {
	struct device___272 dev;
	int (*offline)(struct container_dev *);
};

struct acpi_thermal_state {
	u8 critical: 1;
	u8 hot: 1;
	u8 passive: 1;
	u8 active: 1;
	u8 reserved: 4;
	int active_index;
};

struct acpi_thermal_state_flags {
	u8 valid: 1;
	u8 enabled: 1;
	u8 reserved: 6;
};

struct acpi_thermal_critical {
	struct acpi_thermal_state_flags flags;
	long unsigned int temperature;
};

struct acpi_thermal_hot {
	struct acpi_thermal_state_flags flags;
	long unsigned int temperature;
};

struct acpi_thermal_passive {
	struct acpi_thermal_state_flags flags;
	long unsigned int temperature;
	long unsigned int tc1;
	long unsigned int tc2;
	long unsigned int tsp;
	struct acpi_handle_list devices;
};

struct acpi_thermal_active {
	struct acpi_thermal_state_flags flags;
	long unsigned int temperature;
	struct acpi_handle_list devices;
};

struct acpi_thermal_trips {
	struct acpi_thermal_critical critical;
	struct acpi_thermal_hot hot;
	struct acpi_thermal_passive passive;
	struct acpi_thermal_active active[10];
};

struct acpi_thermal_flags {
	u8 cooling_mode: 1;
	u8 devices: 1;
	u8 reserved: 6;
};

struct acpi_thermal {
	struct acpi_device___10 *device;
	acpi_bus_id name;
	long unsigned int temperature;
	long unsigned int last_temperature;
	long unsigned int polling_frequency;
	volatile u8 zombie;
	struct acpi_thermal_flags flags;
	struct acpi_thermal_state state;
	struct acpi_thermal_trips trips;
	struct acpi_handle_list devices;
	struct thermal_zone_device___2 *thermal_zone;
	int tz_enabled;
	int kelvin_offset;
	struct work_struct thermal_check_work;
};

struct module___253;

struct file___313;

struct kiocb___313;

struct poll_table_struct___190;

struct vm_area_struct___314;

struct inode___313;

struct file_lock___313;

struct page___314;

struct seq_file___265;

struct file_operations___313 {
	struct module___253 *owner;
	loff_t (*llseek)(struct file___313 *, loff_t, int);
	ssize_t (*read)(struct file___313 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___313 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___313 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___313 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___313 *, bool);
	int (*iterate)(struct file___313 *, struct dir_context *);
	int (*iterate_shared)(struct file___313 *, struct dir_context *);
	__poll_t (*poll)(struct file___313 *, struct poll_table_struct___190 *);
	long int (*unlocked_ioctl)(struct file___313 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___313 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___313 *, struct vm_area_struct___314 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___313 *, struct file___313 *);
	int (*flush)(struct file___313 *, fl_owner_t);
	int (*release)(struct inode___313 *, struct file___313 *);
	int (*fsync)(struct file___313 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___313 *, int);
	int (*lock)(struct file___313 *, int, struct file_lock___313 *);
	ssize_t (*sendpage)(struct file___313 *, struct page___314 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___313 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___313 *, int, struct file_lock___313 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___313 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___313 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___313 *, long int, struct file_lock___313 **, void **);
	long int (*fallocate)(struct file___313 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___265 *, struct file___313 *);
	ssize_t (*copy_file_range)(struct file___313 *, loff_t, struct file___313 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___313 *, loff_t, struct file___313 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___313 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___313 {
	u64 seqnum;
	struct vm_area_struct___314 *vmas[4];
};

struct page_frag___313 {
	struct page___314 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___313;

struct cred___291;

struct vm_struct___229;

struct task_struct___314 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___314 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___313 *mm;
	struct mm_struct___313 *active_mm;
	struct vmacache___313 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___314 *real_parent;
	struct task_struct___314 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___314 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___204 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___204 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___204 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___291 *ptracer_cred;
	const struct cred___291 *real_cred;
	const struct cred___291 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___314 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___82 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide21;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___313 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___314 *oom_reaper_list;
	struct vm_struct___229 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___131 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rw_semaphore___314 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___314 *owner;
};

struct secondary_data___314 {
	void *stack;
	struct task_struct___314 *task;
	long int status;
};

struct blocking_notifier_head___313 {
	struct rw_semaphore___314 rwsem;
	struct notifier_block *head;
};

typedef struct page___314 *pgtable_t___313;

struct address_space___312;

struct dev_pagemap___302;

struct page___314 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___312 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___314 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___313 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___313 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___302 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___313;

struct lruvec___313 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___313 *pgdat;
};

struct zone___313 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___313 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___313 {
	struct zone___313 *zone;
	int zone_idx;
};

struct zonelist___313 {
	struct zoneref___313 _zonerefs[25];
};

struct pglist_data___313 {
	struct zone___313 node_zones[3];
	struct zonelist___313 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___314 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___314 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___313 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct kernfs_root___306;

struct kernfs_elem_dir___306 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___306 *root;
};

struct kernfs_node___307;

struct kernfs_syscall_ops___306;

struct kernfs_root___306 {
	struct kernfs_node___307 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___306 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___306 {
	struct kernfs_node___307 *target_kn;
};

struct kernfs_ops___306;

struct kernfs_elem_attr___306 {
	const struct kernfs_ops___306 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___307 *notify_next;
};

struct kernfs_node___307 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___307 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___306 dir;
		struct kernfs_elem_symlink___306 symlink;
		struct kernfs_elem_attr___306 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___306;

struct kernfs_ops___306 {
	int (*open)(struct kernfs_open_file___306 *);
	void (*release)(struct kernfs_open_file___306 *);
	int (*seq_show)(struct seq_file___265 *, void *);
	void * (*seq_start)(struct seq_file___265 *, loff_t *);
	void * (*seq_next)(struct seq_file___265 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___265 *, void *);
	ssize_t (*read)(struct kernfs_open_file___306 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___306 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___306 *, struct vm_area_struct___314 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___306 *, struct poll_table_struct___190 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___306 {
	int (*remount_fs)(struct kernfs_root___306 *, int *, char *);
	int (*show_options)(struct seq_file___265 *, struct kernfs_root___306 *);
	int (*mkdir)(struct kernfs_node___307 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___307 *);
	int (*rename)(struct kernfs_node___307 *, struct kernfs_node___307 *, const char *);
	int (*show_path)(struct seq_file___265 *, struct kernfs_node___307 *, struct kernfs_root___306 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___264;

struct seq_file___265 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___264 *op;
	int poll_event;
	const struct file___313 *file;
	void *private;
};

struct vm_operations_struct___302;

struct kernfs_open_file___306 {
	struct kernfs_node___307 *kn;
	struct file___313 *file;
	struct seq_file___265 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___302 *vm_ops;
};

struct dentry___312;

struct path___313 {
	struct vfsmount *mnt;
	struct dentry___312 *dentry;
};

struct file___313 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___313 f_path;
	struct inode___313 *f_inode;
	const struct file_operations___313 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___204 f_owner;
	const struct cred___291 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___312 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___302;

struct vm_operations_struct___302 {
	void (*open)(struct vm_area_struct___314 *);
	void (*close)(struct vm_area_struct___314 *);
	int (*split)(struct vm_area_struct___314 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___314 *);
	vm_fault_t (*fault)(struct vm_fault___302 *);
	vm_fault_t (*huge_fault)(struct vm_fault___302 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___302 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___314 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___302 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___302 *);
	int (*access)(struct vm_area_struct___314 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___314 *);
	int (*set_policy)(struct vm_area_struct___314 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___314 *, long unsigned int);
	struct page___314 * (*find_special_page)(struct vm_area_struct___314 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___194)(struct file___313 *, wait_queue_head_t *, struct poll_table_struct___190 *);

struct poll_table_struct___190 {
	poll_queue_proc___194 _qproc;
	__poll_t _key;
};

struct vm_area_struct___314 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___314 *vm_next;
	struct vm_area_struct___314 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___313 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___302 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___313 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___300;

struct bin_attribute___276;

struct attribute_group___277 {
	const char *name;
	umode_t (*is_visible)(struct kobject___300 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___300 *, struct bin_attribute___276 *, int);
	struct attribute **attrs;
	struct bin_attribute___276 **bin_attrs;
};

struct kset___299;

struct kobj_type___299;

struct kobject___300 {
	const char *name;
	struct list_head entry;
	struct kobject___300 *parent;
	struct kset___299 *kset;
	struct kobj_type___299 *ktype;
	struct kernfs_node___307 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___276 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___313 *, struct kobject___300 *, struct bin_attribute___276 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___313 *, struct kobject___300 *, struct bin_attribute___276 *, char *, loff_t, size_t);
	int (*mmap)(struct file___313 *, struct kobject___300 *, struct bin_attribute___276 *, struct vm_area_struct___314 *);
};

struct sysfs_ops___299 {
	ssize_t (*show)(struct kobject___300 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___300 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___299;

struct kset___299 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___300 kobj;
	const struct kset_uevent_ops___299 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___299 {
	void (*release)(struct kobject___300 *);
	const struct sysfs_ops___299 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___25 * (*child_ns_type)(struct kobject___300 *);
	const void * (*namespace)(struct kobject___300 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___299 {
	int (* const filter)(struct kset___299 *, struct kobject___300 *);
	const char * (* const name)(struct kset___299 *, struct kobject___300 *);
	int (* const uevent)(struct kset___299 *, struct kobject___300 *, struct kobj_uevent_env *);
};

struct kobj_attribute___292 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___300 *, struct kobj_attribute___292 *, char *);
	ssize_t (*store)(struct kobject___300 *, struct kobj_attribute___292 *, const char *, size_t);
};

struct cpufreq_governor___5;

struct cpufreq_policy___5 {
	cpumask_var_t cpus;
	cpumask_var_t related_cpus;
	cpumask_var_t real_cpus;
	unsigned int shared_type;
	unsigned int cpu;
	struct clk *clk;
	struct cpufreq_cpuinfo cpuinfo;
	unsigned int min;
	unsigned int max;
	unsigned int cur;
	unsigned int restore_freq;
	unsigned int suspend_freq;
	unsigned int policy;
	unsigned int last_policy;
	struct cpufreq_governor___5 *governor;
	void *governor_data;
	char last_governor[16];
	struct work_struct update;
	struct cpufreq_user_policy user_policy;
	struct cpufreq_frequency_table *freq_table;
	enum cpufreq_table_sorting freq_table_sorted;
	struct list_head policy_list;
	struct kobject___300 kobj;
	struct completion kobj_unregister;
	struct rw_semaphore___314 rwsem;
	bool fast_switch_possible;
	bool fast_switch_enabled;
	unsigned int transition_delay_us;
	bool dvfs_possible_from_any_cpu;
	unsigned int cached_target_freq;
	int cached_resolved_idx;
	bool transition_ongoing;
	spinlock_t transition_lock;
	wait_queue_head_t transition_wait;
	struct task_struct___314 *transition_task;
	struct cpufreq_stats *stats;
	void *driver_data;
};

struct cpufreq_governor___5 {
	char name[16];
	int (*init)(struct cpufreq_policy___5 *);
	void (*exit)(struct cpufreq_policy___5 *);
	int (*start)(struct cpufreq_policy___5 *);
	void (*stop)(struct cpufreq_policy___5 *);
	void (*limits)(struct cpufreq_policy___5 *);
	ssize_t (*show_setspeed)(struct cpufreq_policy___5 *, char *);
	int (*store_setspeed)(struct cpufreq_policy___5 *, unsigned int);
	bool dynamic_switching;
	struct list_head governor_list;
	struct module___253 *owner;
};

struct freq_attr___5 {
	struct attribute attr;
	ssize_t (*show)(struct cpufreq_policy___5 *, char *);
	ssize_t (*store)(struct cpufreq_policy___5 *, const char *, size_t);
};

struct module_kobject___250 {
	struct kobject___300 kobj;
	struct module___253 *mod;
	struct kobject___300 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___250 {
	struct module___253 *mod;
	struct latch_tree_node node;
};

struct module_layout___250 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___250 mtn;
};

struct module_attribute___250;

struct kernel_param___250;

struct module___253 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___250 mkobj;
	struct module_attribute___250 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___300 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___250 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___250 core_layout;
	struct module_layout___250 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct core_state___313;

struct mm_struct___313 {
	struct {
		struct vm_area_struct___314 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___313 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___314 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___313 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___314 *owner;
		struct user_namespace___3 *user_ns;
		struct file___313 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___313 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___312;

struct address_space___312 {
	struct inode___313 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___314 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___312 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___302)(struct vm_area_struct___314 *, long unsigned int, const struct page___314 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___302)(struct page___314 *, void *);

struct device___278;

struct dev_pagemap___302 {
	dev_page_fault_t___302 page_fault;
	dev_page_free_t___302 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___278 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___313 {
	struct task_struct___314 *task;
	struct core_thread___313 *next;
};

struct core_state___313 {
	atomic_t nr_threads;
	struct core_thread___313 dumper;
	struct completion startup;
};

struct vm_fault___302 {
	struct vm_area_struct___314 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___314 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___314 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___313 prealloc_pte;
};

struct key___291;

struct user_struct___291 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___291 *uid_keyring;
	struct key___291 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___291 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___291 *session_keyring;
	struct key___291 *process_keyring;
	struct key___291 *thread_keyring;
	struct key___291 *request_key_auth;
	void *security;
	struct user_struct___291 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct vm_struct___229 {
	struct vm_struct___229 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___314 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct fwnode_operations___212;

struct fwnode_handle___212 {
	struct fwnode_handle___212 *secondary;
	const struct fwnode_operations___212 *ops;
};

struct fwnode_reference_args___212;

struct fwnode_endpoint___212;

struct fwnode_operations___212 {
	struct fwnode_handle___212 * (*get)(struct fwnode_handle___212 *);
	void (*put)(struct fwnode_handle___212 *);
	bool (*device_is_available)(const struct fwnode_handle___212 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___212 *, const struct device___278 *);
	bool (*property_present)(const struct fwnode_handle___212 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___212 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___212 *, const char *, const char **, size_t);
	struct fwnode_handle___212 * (*get_parent)(const struct fwnode_handle___212 *);
	struct fwnode_handle___212 * (*get_next_child_node)(const struct fwnode_handle___212 *, struct fwnode_handle___212 *);
	struct fwnode_handle___212 * (*get_named_child_node)(const struct fwnode_handle___212 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___212 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___212 *);
	struct fwnode_handle___212 * (*graph_get_next_endpoint)(const struct fwnode_handle___212 *, struct fwnode_handle___212 *);
	struct fwnode_handle___212 * (*graph_get_remote_endpoint)(const struct fwnode_handle___212 *);
	struct fwnode_handle___212 * (*graph_get_port_parent)(struct fwnode_handle___212 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___212 *, struct fwnode_endpoint___212 *);
};

struct fwnode_endpoint___212 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___212 *local_fwnode;
};

struct fwnode_reference_args___212 {
	struct fwnode_handle___212 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct dev_pm_info___278 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___2 *subsys_data;
	void (*set_latency_tolerance)(struct device___278 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___278;

struct bus_type___278;

struct device_driver___278;

struct dev_pm_domain___278;

struct device_node___69;

struct class___278;

struct device___278 {
	struct device___278 *parent;
	struct device_private *p;
	struct kobject___300 kobj;
	const char *init_name;
	const struct device_type___278 *type;
	struct mutex mutex;
	struct bus_type___278 *bus;
	struct device_driver___278 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___278 power;
	struct dev_pm_domain___278 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___69 *of_node;
	struct fwnode_handle___212 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___278 *class;
	const struct attribute_group___277 **groups;
	void (*release)(struct device___278 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_ops___278 {
	int (*prepare)(struct device___278 *);
	void (*complete)(struct device___278 *);
	int (*suspend)(struct device___278 *);
	int (*resume)(struct device___278 *);
	int (*freeze)(struct device___278 *);
	int (*thaw)(struct device___278 *);
	int (*poweroff)(struct device___278 *);
	int (*restore)(struct device___278 *);
	int (*suspend_late)(struct device___278 *);
	int (*resume_early)(struct device___278 *);
	int (*freeze_late)(struct device___278 *);
	int (*thaw_early)(struct device___278 *);
	int (*poweroff_late)(struct device___278 *);
	int (*restore_early)(struct device___278 *);
	int (*suspend_noirq)(struct device___278 *);
	int (*resume_noirq)(struct device___278 *);
	int (*freeze_noirq)(struct device___278 *);
	int (*thaw_noirq)(struct device___278 *);
	int (*poweroff_noirq)(struct device___278 *);
	int (*restore_noirq)(struct device___278 *);
	int (*runtime_suspend)(struct device___278 *);
	int (*runtime_resume)(struct device___278 *);
	int (*runtime_idle)(struct device___278 *);
};

struct dev_pm_domain___278 {
	struct dev_pm_ops___278 ops;
	void (*detach)(struct device___278 *, bool);
	int (*activate)(struct device___278 *);
	void (*sync)(struct device___278 *);
	void (*dismiss)(struct device___278 *);
};

struct bus_type___278 {
	const char *name;
	const char *dev_name;
	struct device___278 *dev_root;
	const struct attribute_group___277 **bus_groups;
	const struct attribute_group___277 **dev_groups;
	const struct attribute_group___277 **drv_groups;
	int (*match)(struct device___278 *, struct device_driver___278 *);
	int (*uevent)(struct device___278 *, struct kobj_uevent_env *);
	int (*probe)(struct device___278 *);
	int (*remove)(struct device___278 *);
	void (*shutdown)(struct device___278 *);
	int (*online)(struct device___278 *);
	int (*offline)(struct device___278 *);
	int (*suspend)(struct device___278 *, pm_message_t);
	int (*resume)(struct device___278 *);
	int (*num_vf)(struct device___278 *);
	int (*dma_configure)(struct device___278 *);
	const struct dev_pm_ops___278 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___278 {
	const char *name;
	struct bus_type___278 *bus;
	struct module___253 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___278 *);
	int (*remove)(struct device___278 *);
	void (*shutdown)(struct device___278 *);
	int (*suspend)(struct device___278 *, pm_message_t);
	int (*resume)(struct device___278 *);
	const struct attribute_group___277 **groups;
	const struct dev_pm_ops___278 *pm;
	void (*coredump)(struct device___278 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___278 {
	const char *name;
	const struct attribute_group___277 **groups;
	int (*uevent)(struct device___278 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___278 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___278 *);
	const struct dev_pm_ops___278 *pm;
};

struct class___278 {
	const char *name;
	struct module___253 *owner;
	const struct attribute_group___277 **class_groups;
	const struct attribute_group___277 **dev_groups;
	struct kobject___300 *dev_kobj;
	int (*dev_uevent)(struct device___278 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___278 *, umode_t *);
	void (*class_release)(struct class___278 *);
	void (*dev_release)(struct device___278 *);
	int (*shutdown_pre)(struct device___278 *);
	const struct kobj_ns_type_operations___25 *ns_type;
	const void * (*namespace)(struct device___278 *);
	const struct dev_pm_ops___278 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct device_attribute___23 {
	struct attribute attr;
	ssize_t (*show)(struct device___278 *, struct device_attribute___23 *, char *);
	ssize_t (*store)(struct device___278 *, struct device_attribute___23 *, const char *, size_t);
};

struct property___66;

struct device_node___69 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___212 fwnode;
	struct property___66 *properties;
	struct property___66 *deadprops;
	struct device_node___69 *parent;
	struct device_node___69 *child;
	struct device_node___69 *sibling;
	struct kobject___300 kobj;
	long unsigned int _flags;
	void *data;
};

struct acpi_pcct_hw_reduced {
	struct acpi_subtable_header header;
	u32 platform_interrupt;
	u8 flags;
	u8 reserved;
	u64 base_address;
	u64 length;
	struct acpi_generic_address doorbell_register;
	u64 preserve_mask;
	u64 write_mask;
	u32 latency;
	u32 max_access_rate;
	u16 min_turnaround_time;
} __attribute__((packed));

struct acpi_pcct_shared_memory {
	u32 signature;
	u16 command;
	u16 status;
};

struct kernel_param_ops___250 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___250 *);
	int (*get)(char *, const struct kernel_param___250 *);
	void (*free)(void *);
};

struct kparam_array___250;

struct kernel_param___250 {
	const char *name;
	struct module___253 *mod;
	const struct kernel_param_ops___250 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___250 *arr;
	};
};

struct kparam_array___250 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___250 *ops;
	void *elem;
};

struct module_attribute___250 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___250 *, struct module_kobject___250 *, char *);
	ssize_t (*store)(struct module_attribute___250 *, struct module_kobject___250 *, const char *, size_t);
	void (*setup)(struct module___253 *, const char *);
	int (*test)(struct module___253 *);
	void (*free)(struct module___253 *);
};

struct dentry_operations___312;

struct super_block___312;

struct dentry___312 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___312 *d_parent;
	struct qstr d_name;
	struct inode___313 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___312 *d_op;
	struct super_block___312 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___312;

struct block_device___312;

struct cdev___63;

struct inode___313 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___312 *i_op;
	struct super_block___312 *i_sb;
	struct address_space___312 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___314 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___313 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___312 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___312 *i_bdev;
		struct cdev___63 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___312 {
	int (*d_revalidate)(struct dentry___312 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___312 *, unsigned int);
	int (*d_hash)(const struct dentry___312 *, struct qstr *);
	int (*d_compare)(const struct dentry___312 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___312 *);
	int (*d_init)(struct dentry___312 *);
	void (*d_release)(struct dentry___312 *);
	void (*d_prune)(struct dentry___312 *);
	void (*d_iput)(struct dentry___312 *, struct inode___313 *);
	char * (*d_dname)(struct dentry___312 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___313 *);
	int (*d_manage)(const struct path___313 *, bool);
	struct dentry___312 * (*d_real)(struct dentry___312 *, const struct inode___313 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___312;

struct mem_dqinfo___312 {
	struct quota_format_type___312 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___312;

struct quota_info___312 {
	unsigned int flags;
	struct rw_semaphore___314 dqio_sem;
	struct inode___313 *files[3];
	struct mem_dqinfo___312 info[3];
	const struct quota_format_ops___312 *ops[3];
};

struct rcuwait___312 {
	struct task_struct___314 *task;
};

struct percpu_rw_semaphore___312 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___314 rw_sem;
	struct rcuwait___312 writer;
	int readers_block;
};

struct sb_writers___312 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___312 rw_sem[3];
};

struct file_system_type___312;

struct super_operations___312;

struct dquot_operations___312;

struct quotactl_ops___312;

struct super_block___312 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___312 *s_type;
	const struct super_operations___312 *s_op;
	const struct dquot_operations___312 *dq_op;
	const struct quotactl_ops___312 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___312 *s_root;
	struct rw_semaphore___314 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___312 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___312 s_dquot;
	struct sb_writers___312 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___312 *s_d_op;
	int cleancache_poolid;
	struct shrinker___119 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___313 {
	struct file___313 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___313 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___312 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___313 *ia_file;
};

struct dquot___312 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___312 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___312 {
	int qf_fmt_id;
	const struct quota_format_ops___312 *qf_ops;
	struct module___253 *qf_owner;
	struct quota_format_type___312 *qf_next;
};

struct quota_format_ops___312 {
	int (*check_quota_file)(struct super_block___312 *, int);
	int (*read_file_info)(struct super_block___312 *, int);
	int (*write_file_info)(struct super_block___312 *, int);
	int (*free_file_info)(struct super_block___312 *, int);
	int (*read_dqblk)(struct dquot___312 *);
	int (*commit_dqblk)(struct dquot___312 *);
	int (*release_dqblk)(struct dquot___312 *);
	int (*get_next_id)(struct super_block___312 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___312 {
	int (*write_dquot)(struct dquot___312 *);
	struct dquot___312 * (*alloc_dquot)(struct super_block___312 *, int);
	void (*destroy_dquot)(struct dquot___312 *);
	int (*acquire_dquot)(struct dquot___312 *);
	int (*release_dquot)(struct dquot___312 *);
	int (*mark_dirty)(struct dquot___312 *);
	int (*write_info)(struct super_block___312 *, int);
	qsize_t * (*get_reserved_space)(struct inode___313 *);
	int (*get_projid)(struct inode___313 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___313 *, qsize_t *);
	int (*get_next_id)(struct super_block___312 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___312 {
	int (*quota_on)(struct super_block___312 *, int, int, const struct path___313 *);
	int (*quota_off)(struct super_block___312 *, int);
	int (*quota_enable)(struct super_block___312 *, unsigned int);
	int (*quota_disable)(struct super_block___312 *, unsigned int);
	int (*quota_sync)(struct super_block___312 *, int);
	int (*set_info)(struct super_block___312 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___312 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___312 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___312 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___312 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___312 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___312 {
	int (*writepage)(struct page___314 *, struct writeback_control___3 *);
	int (*readpage)(struct file___313 *, struct page___314 *);
	int (*writepages)(struct address_space___312 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___314 *);
	int (*readpages)(struct file___313 *, struct address_space___312 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___313 *, struct address_space___312 *, loff_t, unsigned int, unsigned int, struct page___314 **, void **);
	int (*write_end)(struct file___313 *, struct address_space___312 *, loff_t, unsigned int, unsigned int, struct page___314 *, void *);
	sector_t (*bmap)(struct address_space___312 *, sector_t);
	void (*invalidatepage)(struct page___314 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___314 *, gfp_t);
	void (*freepage)(struct page___314 *);
	ssize_t (*direct_IO)(struct kiocb___313 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___312 *, struct page___314 *, struct page___314 *, enum migrate_mode);
	bool (*isolate_page)(struct page___314 *, isolate_mode_t);
	void (*putback_page)(struct page___314 *);
	int (*launder_page)(struct page___314 *);
	int (*is_partially_uptodate)(struct page___314 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___314 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___312 *, struct page___314 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___313 *, sector_t *);
	void (*swap_deactivate)(struct file___313 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___312 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___313 *bd_inode;
	struct super_block___312 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___312 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___63 {
	struct kobject___300 kobj;
	struct module___253 *owner;
	const struct file_operations___313 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___312 {
	struct dentry___312 * (*lookup)(struct inode___313 *, struct dentry___312 *, unsigned int);
	const char * (*get_link)(struct dentry___312 *, struct inode___313 *, struct delayed_call *);
	int (*permission)(struct inode___313 *, int);
	struct posix_acl * (*get_acl)(struct inode___313 *, int);
	int (*readlink)(struct dentry___312 *, char *, int);
	int (*create)(struct inode___313 *, struct dentry___312 *, umode_t, bool);
	int (*link)(struct dentry___312 *, struct inode___313 *, struct dentry___312 *);
	int (*unlink)(struct inode___313 *, struct dentry___312 *);
	int (*symlink)(struct inode___313 *, struct dentry___312 *, const char *);
	int (*mkdir)(struct inode___313 *, struct dentry___312 *, umode_t);
	int (*rmdir)(struct inode___313 *, struct dentry___312 *);
	int (*mknod)(struct inode___313 *, struct dentry___312 *, umode_t, dev_t);
	int (*rename)(struct inode___313 *, struct dentry___312 *, struct inode___313 *, struct dentry___312 *, unsigned int);
	int (*setattr)(struct dentry___312 *, struct iattr___312 *);
	int (*getattr)(const struct path___313 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___312 *, char *, size_t);
	int (*fiemap)(struct inode___313 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___313 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___313 *, struct dentry___312 *, struct file___313 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___313 *, struct dentry___312 *, umode_t);
	int (*set_acl)(struct inode___313 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___312 {
	void (*fl_copy_lock)(struct file_lock___313 *, struct file_lock___313 *);
	void (*fl_release_private)(struct file_lock___313 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___312;

struct lock_manager_operations___312;

struct file_lock___313 {
	struct file_lock___313 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___313 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___312 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___312 *fl_ops;
	const struct lock_manager_operations___312 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___312 {
	int (*lm_compare_owner)(struct file_lock___313 *, struct file_lock___313 *);
	long unsigned int (*lm_owner_key)(struct file_lock___313 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___313 *);
	int (*lm_grant)(struct file_lock___313 *, int);
	bool (*lm_break)(struct file_lock___313 *);
	int (*lm_change)(struct file_lock___313 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___313 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___312 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___312 *fa_next;
	struct file___313 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___312 {
	const char *name;
	int fs_flags;
	struct dentry___312 * (*mount)(struct file_system_type___312 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___312 *);
	struct module___253 *owner;
	struct file_system_type___312 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___312 {
	struct inode___313 * (*alloc_inode)(struct super_block___312 *);
	void (*destroy_inode)(struct inode___313 *);
	void (*dirty_inode)(struct inode___313 *, int);
	int (*write_inode)(struct inode___313 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___313 *);
	void (*evict_inode)(struct inode___313 *);
	void (*put_super)(struct super_block___312 *);
	int (*sync_fs)(struct super_block___312 *, int);
	int (*freeze_super)(struct super_block___312 *);
	int (*freeze_fs)(struct super_block___312 *);
	int (*thaw_super)(struct super_block___312 *);
	int (*unfreeze_fs)(struct super_block___312 *);
	int (*statfs)(struct dentry___312 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___312 *, int *, char *);
	void (*umount_begin)(struct super_block___312 *);
	int (*show_options)(struct seq_file___265 *, struct dentry___312 *);
	int (*show_devname)(struct seq_file___265 *, struct dentry___312 *);
	int (*show_path)(struct seq_file___265 *, struct dentry___312 *);
	int (*show_stats)(struct seq_file___265 *, struct dentry___312 *);
	ssize_t (*quota_read)(struct super_block___312 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___312 *, int, const char *, size_t, loff_t);
	struct dquot___312 ** (*get_dquots)(struct inode___313 *);
	int (*bdev_try_to_free_page)(struct super_block___312 *, struct page___314 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___312 *, struct shrink_control___119 *);
	long int (*free_cached_objects)(struct super_block___312 *, struct shrink_control___119 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*key_restrict_link_func_t___292)(struct key___291 *, const struct key_type *, const union key_payload *, struct key___291 *);

struct key_restriction___291;

struct key___291 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___314 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___291 *restrict_link;
};

struct key_restriction___291 {
	key_restrict_link_func_t___292 check;
	struct key___291 *key;
	struct key_type *keytype;
};

struct seq_operations___264 {
	void * (*start)(struct seq_file___265 *, loff_t *);
	void (*stop)(struct seq_file___265 *, void *);
	void * (*next)(struct seq_file___265 *, void *, loff_t *);
	int (*show)(struct seq_file___265 *, void *);
};

typedef void compound_page_dtor___302(struct page___314 *);

struct property___66 {
	char *name;
	int length;
	void *value;
	struct property___66 *next;
	long unsigned int _flags;
	struct bin_attribute___276 attr;
};

struct of_phandle_args___10 {
	struct device_node___69 *np;
	int args_count;
	uint32_t args[16];
};

struct mbox_chan;

struct mbox_chan_ops {
	int (*send_data)(struct mbox_chan *, void *);
	int (*startup)(struct mbox_chan *);
	void (*shutdown)(struct mbox_chan *);
	bool (*last_tx_done)(struct mbox_chan *);
	bool (*peek_data)(struct mbox_chan *);
};

struct mbox_controller;

struct mbox_client;

struct mbox_chan {
	struct mbox_controller *mbox;
	unsigned int txdone_method;
	struct mbox_client *cl;
	struct completion tx_complete;
	void *active_req;
	unsigned int msg_count;
	unsigned int msg_free;
	void *msg_data[20];
	spinlock_t lock;
	void *con_priv;
};

struct mbox_controller {
	struct device___278 *dev;
	const struct mbox_chan_ops *ops;
	struct mbox_chan *chans;
	int num_chans;
	bool txdone_irq;
	bool txdone_poll;
	unsigned int txpoll_period;
	struct mbox_chan * (*of_xlate)(struct mbox_controller *, const struct of_phandle_args___10 *);
	struct hrtimer poll_hrt;
	struct list_head node;
};

struct mbox_client {
	struct device___278 *dev;
	bool tx_block;
	long unsigned int tx_tout;
	bool knows_txdone;
	void (*rx_callback)(struct mbox_client *, void *);
	void (*tx_prepare)(struct mbox_client *, void *);
	void (*tx_done)(struct mbox_client *, void *, int);
};

struct node___186 {
	struct device___278 dev;
};

struct thermal_zone_device___4;

struct thermal_cooling_device___4;

struct thermal_zone_device_ops___4 {
	int (*bind)(struct thermal_zone_device___4 *, struct thermal_cooling_device___4 *);
	int (*unbind)(struct thermal_zone_device___4 *, struct thermal_cooling_device___4 *);
	int (*get_temp)(struct thermal_zone_device___4 *, int *);
	int (*set_trips)(struct thermal_zone_device___4 *, int, int);
	int (*get_mode)(struct thermal_zone_device___4 *, enum thermal_device_mode *);
	int (*set_mode)(struct thermal_zone_device___4 *, enum thermal_device_mode);
	int (*get_trip_type)(struct thermal_zone_device___4 *, int, enum thermal_trip_type *);
	int (*get_trip_temp)(struct thermal_zone_device___4 *, int, int *);
	int (*set_trip_temp)(struct thermal_zone_device___4 *, int, int);
	int (*get_trip_hyst)(struct thermal_zone_device___4 *, int, int *);
	int (*set_trip_hyst)(struct thermal_zone_device___4 *, int, int);
	int (*get_crit_temp)(struct thermal_zone_device___4 *, int *);
	int (*set_emul_temp)(struct thermal_zone_device___4 *, int);
	int (*get_trend)(struct thermal_zone_device___4 *, int, enum thermal_trend *);
	int (*notify)(struct thermal_zone_device___4 *, int, enum thermal_trip_type);
};

struct thermal_attr___4;

struct thermal_zone_params___4;

struct thermal_governor___4;

struct thermal_zone_device___4 {
	int id;
	char type[20];
	struct device___278 device;
	struct attribute_group___277 trips_attribute_group;
	struct thermal_attr___4 *trip_temp_attrs;
	struct thermal_attr___4 *trip_type_attrs;
	struct thermal_attr___4 *trip_hyst_attrs;
	void *devdata;
	int trips;
	long unsigned int trips_disabled;
	int passive_delay;
	int polling_delay;
	int temperature;
	int last_temperature;
	int emul_temperature;
	int passive;
	int prev_low_trip;
	int prev_high_trip;
	unsigned int forced_passive;
	atomic_t need_update;
	struct thermal_zone_device_ops___4 *ops;
	struct thermal_zone_params___4 *tzp;
	struct thermal_governor___4 *governor;
	void *governor_data;
	struct list_head thermal_instances;
	struct ida ida;
	struct mutex lock;
	struct list_head node;
	struct delayed_work poll_queue;
	enum thermal_notify_event notify_event;
};

struct thermal_cooling_device_ops___4;

struct thermal_cooling_device___4 {
	int id;
	char type[20];
	struct device___278 device;
	struct device_node___69 *np;
	void *devdata;
	void *stats;
	const struct thermal_cooling_device_ops___4 *ops;
	bool updated;
	struct mutex lock;
	struct list_head thermal_instances;
	struct list_head node;
};

struct thermal_cooling_device_ops___4 {
	int (*get_max_state)(struct thermal_cooling_device___4 *, long unsigned int *);
	int (*get_cur_state)(struct thermal_cooling_device___4 *, long unsigned int *);
	int (*set_cur_state)(struct thermal_cooling_device___4 *, long unsigned int);
	int (*get_requested_power)(struct thermal_cooling_device___4 *, struct thermal_zone_device___4 *, u32 *);
	int (*state2power)(struct thermal_cooling_device___4 *, struct thermal_zone_device___4 *, long unsigned int, u32 *);
	int (*power2state)(struct thermal_cooling_device___4 *, struct thermal_zone_device___4 *, u32, long unsigned int *);
};

struct thermal_attr___4 {
	struct device_attribute___23 attr;
	char name[20];
};

struct thermal_bind_params___4;

struct thermal_zone_params___4 {
	char governor_name[20];
	bool no_hwmon;
	int num_tbps;
	struct thermal_bind_params___4 *tbp;
	u32 sustainable_power;
	s32 k_po;
	s32 k_pu;
	s32 k_i;
	s32 k_d;
	s32 integral_cutoff;
	int slope;
	int offset;
};

struct thermal_governor___4 {
	char name[20];
	int (*bind_to_tz)(struct thermal_zone_device___4 *);
	void (*unbind_from_tz)(struct thermal_zone_device___4 *);
	int (*throttle)(struct thermal_zone_device___4 *, int);
	struct list_head governor_list;
};

struct thermal_bind_params___4 {
	struct thermal_cooling_device___4 *cdev;
	int weight;
	int trip_mask;
	long unsigned int *binding_limits;
	int (*match)(struct thermal_zone_device___4 *, struct thermal_cooling_device___4 *);
};

struct acpi_processor___4;

struct acpi_processor_throttling___4 {
	unsigned int state;
	unsigned int platform_limit;
	struct acpi_pct_register control_register;
	struct acpi_pct_register status_register;
	short: 16;
	unsigned int state_count;
	int: 32;
	struct acpi_processor_tx_tss *states_tss;
	struct acpi_tsd_package domain_info;
	cpumask_var_t shared_cpu_map;
	int (*acpi_processor_get_throttling)(struct acpi_processor___4 *);
	int (*acpi_processor_set_throttling)(struct acpi_processor___4 *, int, bool);
	u32 address;
	u8 duty_offset;
	u8 duty_width;
	u8 tsd_valid_flag;
	char: 8;
	unsigned int shared_type;
	struct acpi_processor_tx states[16];
	int: 32;
} __attribute__((packed));

struct acpi_processor___4 {
	acpi_handle handle;
	u32 acpi_id;
	phys_cpuid_t phys_id;
	u32 id;
	u32 pblk;
	int performance_platform_limit;
	int throttling_platform_limit;
	struct acpi_processor_flags flags;
	struct acpi_processor_power power;
	struct acpi_processor_performance *performance;
	struct acpi_processor_throttling___4 throttling;
	struct acpi_processor_limit limit;
	struct thermal_cooling_device___4 *cdev;
	struct device___278 *dev;
};

struct cpc_reg {
	u8 descriptor;
	u16 length;
	u8 space_id;
	u8 bit_width;
	u8 bit_offset;
	u8 access_width;
	u64 address;
} __attribute__((packed));

struct cpc_register_resource {
	acpi_object_type type;
	u64 *sys_mem_vaddr;
	union {
		struct cpc_reg reg;
		u64 int_value;
	} cpc_entry;
};

struct cpc_desc {
	int num_entries;
	int version;
	int cpu_id;
	int write_cmd_status;
	int write_cmd_id;
	struct cpc_register_resource cpc_regs[21];
	struct acpi_psd_package domain_info;
	struct kobject___300 kobj;
};

enum cppc_regs {
	HIGHEST_PERF = 0,
	NOMINAL_PERF = 1,
	LOW_NON_LINEAR_PERF = 2,
	LOWEST_PERF = 3,
	GUARANTEED_PERF = 4,
	DESIRED_PERF = 5,
	MIN_PERF = 6,
	MAX_PERF = 7,
	PERF_REDUC_TOLERANCE = 8,
	TIME_WINDOW = 9,
	CTR_WRAP_TIME = 10,
	REFERENCE_CTR = 11,
	DELIVERED_CTR = 12,
	PERF_LIMITED = 13,
	ENABLE = 14,
	AUTO_SEL_ENABLE = 15,
	AUTO_ACT_WINDOW = 16,
	ENERGY_PERF = 17,
	REFERENCE_PERF = 18,
	LOWEST_FREQ = 19,
	NOMINAL_FREQ = 20,
};

struct cppc_perf_caps {
	u32 guaranteed_perf;
	u32 highest_perf;
	u32 nominal_perf;
	u32 lowest_perf;
	u32 lowest_nonlinear_perf;
	u32 lowest_freq;
	u32 nominal_freq;
};

struct cppc_perf_ctrls {
	u32 max_perf;
	u32 min_perf;
	u32 desired_perf;
};

struct cppc_perf_fb_ctrs {
	u64 reference;
	u64 delivered;
	u64 reference_perf;
	u64 wraparound_time;
};

struct cppc_cpudata {
	int cpu;
	struct cppc_perf_caps perf_caps;
	struct cppc_perf_ctrls perf_ctrls;
	struct cppc_perf_fb_ctrs perf_fb_ctrs;
	struct cpufreq_policy___5 *cur_policy;
	unsigned int shared_type;
	cpumask_var_t shared_cpu_map;
};

struct cppc_pcc_data {
	struct mbox_chan *pcc_channel;
	void *pcc_comm_addr;
	bool pcc_channel_acquired;
	unsigned int deadline_us;
	unsigned int pcc_mpar;
	unsigned int pcc_mrtt;
	unsigned int pcc_nominal;
	bool pending_pcc_write_cmd;
	bool platform_owns_pcc;
	unsigned int pcc_write_cnt;
	struct rw_semaphore___314 pcc_lock;
	wait_queue_head_t pcc_write_wait_q;
	ktime_t last_cmd_cmpl_time;
	ktime_t last_mpar_reset;
	int mpar_count;
	int refcount;
};

struct cppc_attr {
	struct attribute attr;
	ssize_t (*show)(struct kobject___300 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___300 *, struct attribute *, const char *, ssize_t);
};

enum acpi_pptt_type {
	ACPI_PPTT_TYPE_PROCESSOR = 0,
	ACPI_PPTT_TYPE_CACHE = 1,
	ACPI_PPTT_TYPE_ID = 2,
	ACPI_PPTT_TYPE_RESERVED = 3,
};

struct acpi_pptt_processor {
	struct acpi_subtable_header header;
	u16 reserved;
	u32 flags;
	u32 parent;
	u32 acpi_processor_id;
	u32 number_of_priv_resources;
};

struct acpi_pptt_cache {
	struct acpi_subtable_header header;
	u16 reserved;
	u32 flags;
	u32 next_level_of_cache;
	u32 size;
	u32 number_of_sets;
	u8 associativity;
	u8 attributes;
	u16 line_size;
};

struct acpi_whea_header {
	u8 action;
	u8 instruction;
	u8 flags;
	u8 reserved;
	struct acpi_generic_address register_region;
	u64 value;
	u64 mask;
} __attribute__((packed));

struct cper_sec_mem_err {
	__u64 validation_bits;
	__u64 error_status;
	__u64 physical_addr;
	__u64 physical_addr_mask;
	__u16 node;
	__u16 card;
	__u16 module;
	__u16 bank;
	__u16 device;
	__u16 row;
	__u16 column;
	__u16 bit_pos;
	__u64 requestor_id;
	__u64 responder_id;
	__u64 target_id;
	__u8 error_type;
	__u8 reserved;
	__u16 rank;
	__u16 mem_array_handle;
	__u16 mem_dev_handle;
};

struct apei_exec_context;

typedef int (*apei_exec_ins_func_t)(struct apei_exec_context *, struct acpi_whea_header *);

struct apei_exec_ins_type;

struct apei_exec_context {
	u32 ip;
	u64 value;
	u64 var1;
	u64 var2;
	u64 src_base;
	u64 dst_base;
	struct apei_exec_ins_type *ins_table;
	u32 instructions;
	struct acpi_whea_header *action_table;
	u32 entries;
};

struct apei_exec_ins_type {
	u32 flags;
	apei_exec_ins_func_t run;
};

struct apei_resources {
	struct list_head iomem;
	struct list_head ioport;
};

typedef int (*apei_exec_entry_func_t)(struct apei_exec_context *, struct acpi_whea_header *, void *);

struct apei_res {
	struct list_head list;
	long unsigned int start;
	long unsigned int end;
};

struct acpi_table_hest {
	struct acpi_table_header header;
	u32 error_source_count;
};

struct acpi_hest_notify {
	u8 type;
	u8 length;
	u16 config_write_enable;
	u32 poll_interval;
	u32 vector;
	u32 polling_threshold_value;
	u32 polling_threshold_window;
	u32 error_threshold_value;
	u32 error_threshold_window;
};

struct acpi_hest_ia_machine_check {
	struct acpi_hest_header header;
	u16 reserved1;
	u8 flags;
	u8 enabled;
	u32 records_to_preallocate;
	u32 max_sections_per_record;
	u64 global_capability_data;
	u64 global_control_data;
	u8 num_hardware_banks;
	u8 reserved3[7];
};

struct acpi_hest_ia_corrected {
	struct acpi_hest_header header;
	u16 reserved1;
	u8 flags;
	u8 enabled;
	u32 records_to_preallocate;
	u32 max_sections_per_record;
	struct acpi_hest_notify notify;
	u8 num_hardware_banks;
	u8 reserved2[3];
};

struct acpi_hest_generic {
	struct acpi_hest_header header;
	u16 related_source_id;
	u8 reserved;
	u8 enabled;
	u32 records_to_preallocate;
	u32 max_sections_per_record;
	u32 max_raw_data_length;
	struct acpi_generic_address error_status_address;
	struct acpi_hest_notify notify;
	u32 error_block_length;
} __attribute__((packed));

enum hest_status {
	HEST_ENABLED = 0,
	HEST_DISABLED = 1,
	HEST_NOT_FOUND = 2,
};

typedef int (*apei_hest_func_t)(struct acpi_hest_header *, void *);

struct ghes_arr {
	struct platform_device___15 **ghes_devs;
	unsigned int count;
};

struct acpi_table_erst {
	struct acpi_table_header header;
	u32 header_length;
	u32 reserved;
	u32 entries;
};

enum acpi_erst_actions {
	ACPI_ERST_BEGIN_WRITE = 0,
	ACPI_ERST_BEGIN_READ = 1,
	ACPI_ERST_BEGIN_CLEAR = 2,
	ACPI_ERST_END = 3,
	ACPI_ERST_SET_RECORD_OFFSET = 4,
	ACPI_ERST_EXECUTE_OPERATION = 5,
	ACPI_ERST_CHECK_BUSY_STATUS = 6,
	ACPI_ERST_GET_COMMAND_STATUS = 7,
	ACPI_ERST_GET_RECORD_ID = 8,
	ACPI_ERST_SET_RECORD_ID = 9,
	ACPI_ERST_GET_RECORD_COUNT = 10,
	ACPI_ERST_BEGIN_DUMMY_WRIITE = 11,
	ACPI_ERST_NOT_USED = 12,
	ACPI_ERST_GET_ERROR_RANGE = 13,
	ACPI_ERST_GET_ERROR_LENGTH = 14,
	ACPI_ERST_GET_ERROR_ATTRIBUTES = 15,
	ACPI_ERST_EXECUTE_TIMINGS = 16,
	ACPI_ERST_ACTION_RESERVED = 17,
};

enum acpi_erst_instructions {
	ACPI_ERST_READ_REGISTER = 0,
	ACPI_ERST_READ_REGISTER_VALUE = 1,
	ACPI_ERST_WRITE_REGISTER = 2,
	ACPI_ERST_WRITE_REGISTER_VALUE = 3,
	ACPI_ERST_NOOP = 4,
	ACPI_ERST_LOAD_VAR1 = 5,
	ACPI_ERST_LOAD_VAR2 = 6,
	ACPI_ERST_STORE_VAR1 = 7,
	ACPI_ERST_ADD = 8,
	ACPI_ERST_SUBTRACT = 9,
	ACPI_ERST_ADD_VALUE = 10,
	ACPI_ERST_SUBTRACT_VALUE = 11,
	ACPI_ERST_STALL = 12,
	ACPI_ERST_STALL_WHILE_TRUE = 13,
	ACPI_ERST_SKIP_NEXT_IF_TRUE = 14,
	ACPI_ERST_GOTO = 15,
	ACPI_ERST_SET_SRC_ADDRESS_BASE = 16,
	ACPI_ERST_SET_DST_ADDRESS_BASE = 17,
	ACPI_ERST_MOVE_DATA = 18,
	ACPI_ERST_INSTRUCTION_RESERVED = 19,
};

struct pstore_info___2;

struct pstore_record___2 {
	struct pstore_info___2 *psi;
	enum pstore_type_id type;
	u64 id;
	struct timespec64 time;
	char *buf;
	ssize_t size;
	ssize_t ecc_notice_size;
	int count;
	enum kmsg_dump_reason reason;
	unsigned int part;
	bool compressed;
};

struct pstore_info___2 {
	struct module___249 *owner;
	char *name;
	spinlock_t buf_lock;
	char *buf;
	size_t bufsize;
	struct mutex read_mutex;
	int flags;
	void *data;
	int (*open)(struct pstore_info___2 *);
	int (*close)(struct pstore_info___2 *);
	ssize_t (*read)(struct pstore_record___2 *);
	int (*write)(struct pstore_record___2 *);
	int (*write_user)(struct pstore_record___2 *, const char *);
	int (*erase)(struct pstore_record___2 *);
};

struct cper_record_header {
	char signature[4];
	__u16 revision;
	__u32 signature_end;
	__u16 section_count;
	__u32 error_severity;
	__u32 validation_bits;
	__u32 record_length;
	__u64 timestamp;
	guid_t platform_id;
	guid_t partition_id;
	guid_t creator_id;
	guid_t notification_type;
	__u64 record_id;
	__u32 flags;
	__u64 persistence_information;
	__u8 reserved[12];
} __attribute__((packed));

struct cper_section_descriptor {
	__u32 section_offset;
	__u32 section_length;
	__u16 revision;
	__u8 validation_bits;
	__u8 reserved;
	__u32 flags;
	guid_t section_type;
	guid_t fru_id;
	__u32 section_severity;
	__u8 fru_text[20];
};

struct erst_erange {
	u64 base;
	u64 size;
	void *vaddr;
	u32 attr;
};

struct erst_record_id_cache {
	struct mutex lock;
	u64 *entries;
	int len;
	int size;
	int refcount;
};

struct cper_pstore_record {
	struct cper_record_header hdr;
	struct cper_section_descriptor sec_hdr;
	char data[0];
};

struct acpi_bert_region {
	u32 block_status;
	u32 raw_data_offset;
	u32 raw_data_length;
	u32 data_length;
	u32 error_severity;
};

struct acpi_hest_generic_status {
	u32 block_status;
	u32 raw_data_offset;
	u32 raw_data_length;
	u32 data_length;
	u32 error_severity;
};

struct module___254;

struct file___314;

struct kiocb___314;

struct poll_table_struct___191;

struct vm_area_struct___315;

struct inode___314;

struct file_lock___314;

struct page___315;

struct seq_file___266;

struct file_operations___314 {
	struct module___254 *owner;
	loff_t (*llseek)(struct file___314 *, loff_t, int);
	ssize_t (*read)(struct file___314 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___314 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___314 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___314 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___314 *, bool);
	int (*iterate)(struct file___314 *, struct dir_context *);
	int (*iterate_shared)(struct file___314 *, struct dir_context *);
	__poll_t (*poll)(struct file___314 *, struct poll_table_struct___191 *);
	long int (*unlocked_ioctl)(struct file___314 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___314 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___314 *, struct vm_area_struct___315 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___314 *, struct file___314 *);
	int (*flush)(struct file___314 *, fl_owner_t);
	int (*release)(struct inode___314 *, struct file___314 *);
	int (*fsync)(struct file___314 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___314 *, int);
	int (*lock)(struct file___314 *, int, struct file_lock___314 *);
	ssize_t (*sendpage)(struct file___314 *, struct page___315 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___314 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___314 *, int, struct file_lock___314 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___314 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___314 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___314 *, long int, struct file_lock___314 **, void **);
	long int (*fallocate)(struct file___314 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___266 *, struct file___314 *);
	ssize_t (*copy_file_range)(struct file___314 *, loff_t, struct file___314 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___314 *, loff_t, struct file___314 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___314 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernel_param___251;

struct kernel_param_ops___251 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___251 *);
	int (*get)(char *, const struct kernel_param___251 *);
	void (*free)(void *);
};

struct kparam_array___251;

struct kernel_param___251 {
	const char *name;
	struct module___254 *mod;
	const struct kernel_param_ops___251 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___251 *arr;
	};
};

struct kparam_array___251 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___251 *ops;
	void *elem;
};

struct kset___300;

struct kobj_type___300;

struct kernfs_node___308;

struct kobject___301 {
	const char *name;
	struct list_head entry;
	struct kobject___301 *parent;
	struct kset___300 *kset;
	struct kobj_type___300 *ktype;
	struct kernfs_node___308 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___251 {
	struct kobject___301 kobj;
	struct module___254 *mod;
	struct kobject___301 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___251 {
	struct module___254 *mod;
	struct latch_tree_node node;
};

struct module_layout___251 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___251 mtn;
};

struct module_attribute___251;

struct module___254 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___251 mkobj;
	struct module_attribute___251 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___301 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___251 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___251 core_layout;
	struct module_layout___251 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct vmacache___314 {
	u64 seqnum;
	struct vm_area_struct___315 *vmas[4];
};

struct page_frag___314 {
	struct page___315 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___314;

struct cred___292;

struct vm_struct___230;

struct task_struct___315 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___315 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___314 *mm;
	struct mm_struct___314 *active_mm;
	struct vmacache___314 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___315 *real_parent;
	struct task_struct___315 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___315 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___204 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___204 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___204 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___292 *ptracer_cred;
	const struct cred___292 *real_cred;
	const struct cred___292 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___315 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___82 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___314 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___315 *oom_reaper_list;
	struct vm_struct___230 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___131 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___315 *pgtable_t___314;

struct address_space___313;

struct dev_pagemap___303;

struct page___315 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___313 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___315 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___314 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___314 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___303 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___314;

struct lruvec___314 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___314 *pgdat;
};

struct zone___314 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___314 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___314 {
	struct zone___314 *zone;
	int zone_idx;
};

struct zonelist___314 {
	struct zoneref___314 _zonerefs[25];
};

struct pglist_data___314 {
	struct zone___314 node_zones[3];
	struct zonelist___314 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___315 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___315 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___314 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___315 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___315 *owner;
};

struct secondary_data___315 {
	void *stack;
	struct task_struct___315 *task;
	long int status;
};

struct blocking_notifier_head___314 {
	struct rw_semaphore___315 rwsem;
	struct notifier_block *head;
};

struct kernfs_root___307;

struct kernfs_elem_dir___307 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___307 *root;
};

struct kernfs_syscall_ops___307;

struct kernfs_root___307 {
	struct kernfs_node___308 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___307 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___307 {
	struct kernfs_node___308 *target_kn;
};

struct kernfs_ops___307;

struct kernfs_elem_attr___307 {
	const struct kernfs_ops___307 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___308 *notify_next;
};

struct kernfs_node___308 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___308 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___307 dir;
		struct kernfs_elem_symlink___307 symlink;
		struct kernfs_elem_attr___307 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___307;

struct kernfs_ops___307 {
	int (*open)(struct kernfs_open_file___307 *);
	void (*release)(struct kernfs_open_file___307 *);
	int (*seq_show)(struct seq_file___266 *, void *);
	void * (*seq_start)(struct seq_file___266 *, loff_t *);
	void * (*seq_next)(struct seq_file___266 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___266 *, void *);
	ssize_t (*read)(struct kernfs_open_file___307 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___307 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___307 *, struct vm_area_struct___315 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___307 *, struct poll_table_struct___191 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___307 {
	int (*remount_fs)(struct kernfs_root___307 *, int *, char *);
	int (*show_options)(struct seq_file___266 *, struct kernfs_root___307 *);
	int (*mkdir)(struct kernfs_node___308 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___308 *);
	int (*rename)(struct kernfs_node___308 *, struct kernfs_node___308 *, const char *);
	int (*show_path)(struct seq_file___266 *, struct kernfs_node___308 *, struct kernfs_root___307 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___265;

struct seq_file___266 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___265 *op;
	int poll_event;
	const struct file___314 *file;
	void *private;
};

struct vm_operations_struct___303;

struct kernfs_open_file___307 {
	struct kernfs_node___308 *kn;
	struct file___314 *file;
	struct seq_file___266 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___303 *vm_ops;
};

struct dentry___313;

struct path___314 {
	struct vfsmount *mnt;
	struct dentry___313 *dentry;
};

struct file___314 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___314 f_path;
	struct inode___314 *f_inode;
	const struct file_operations___314 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___204 f_owner;
	const struct cred___292 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___313 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___303;

struct vm_operations_struct___303 {
	void (*open)(struct vm_area_struct___315 *);
	void (*close)(struct vm_area_struct___315 *);
	int (*split)(struct vm_area_struct___315 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___315 *);
	vm_fault_t (*fault)(struct vm_fault___303 *);
	vm_fault_t (*huge_fault)(struct vm_fault___303 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___303 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___315 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___303 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___303 *);
	int (*access)(struct vm_area_struct___315 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___315 *);
	int (*set_policy)(struct vm_area_struct___315 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___315 *, long unsigned int);
	struct page___315 * (*find_special_page)(struct vm_area_struct___315 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___195)(struct file___314 *, wait_queue_head_t *, struct poll_table_struct___191 *);

struct poll_table_struct___191 {
	poll_queue_proc___195 _qproc;
	__poll_t _key;
};

struct vm_area_struct___315 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___315 *vm_next;
	struct vm_area_struct___315 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___314 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___303 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___314 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___277;

struct attribute_group___278 {
	const char *name;
	umode_t (*is_visible)(struct kobject___301 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___301 *, struct bin_attribute___277 *, int);
	struct attribute **attrs;
	struct bin_attribute___277 **bin_attrs;
};

struct bin_attribute___277 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___314 *, struct kobject___301 *, struct bin_attribute___277 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___314 *, struct kobject___301 *, struct bin_attribute___277 *, char *, loff_t, size_t);
	int (*mmap)(struct file___314 *, struct kobject___301 *, struct bin_attribute___277 *, struct vm_area_struct___315 *);
};

struct sysfs_ops___300 {
	ssize_t (*show)(struct kobject___301 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___301 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___300;

struct kset___300 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___301 kobj;
	const struct kset_uevent_ops___300 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___300 {
	void (*release)(struct kobject___301 *);
	const struct sysfs_ops___300 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___25 * (*child_ns_type)(struct kobject___301 *);
	const void * (*namespace)(struct kobject___301 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___300 {
	int (* const filter)(struct kset___300 *, struct kobject___301 *);
	const char * (* const name)(struct kset___300 *, struct kobject___301 *);
	int (* const uevent)(struct kset___300 *, struct kobject___301 *, struct kobj_uevent_env *);
};

struct kobj_attribute___293 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___301 *, struct kobj_attribute___293 *, char *);
	ssize_t (*store)(struct kobject___301 *, struct kobj_attribute___293 *, const char *, size_t);
};

struct device___279;

struct dev_pm_ops___279 {
	int (*prepare)(struct device___279 *);
	void (*complete)(struct device___279 *);
	int (*suspend)(struct device___279 *);
	int (*resume)(struct device___279 *);
	int (*freeze)(struct device___279 *);
	int (*thaw)(struct device___279 *);
	int (*poweroff)(struct device___279 *);
	int (*restore)(struct device___279 *);
	int (*suspend_late)(struct device___279 *);
	int (*resume_early)(struct device___279 *);
	int (*freeze_late)(struct device___279 *);
	int (*thaw_early)(struct device___279 *);
	int (*poweroff_late)(struct device___279 *);
	int (*restore_early)(struct device___279 *);
	int (*suspend_noirq)(struct device___279 *);
	int (*resume_noirq)(struct device___279 *);
	int (*freeze_noirq)(struct device___279 *);
	int (*thaw_noirq)(struct device___279 *);
	int (*poweroff_noirq)(struct device___279 *);
	int (*restore_noirq)(struct device___279 *);
	int (*runtime_suspend)(struct device___279 *);
	int (*runtime_resume)(struct device___279 *);
	int (*runtime_idle)(struct device___279 *);
};

struct dev_pm_info___279 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___2 *subsys_data;
	void (*set_latency_tolerance)(struct device___279 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___279;

struct bus_type___279;

struct device_driver___279;

struct dev_pm_domain___279;

struct dma_map_ops___93;

struct fwnode_handle___213;

struct class___279;

struct device___279 {
	struct device___279 *parent;
	struct device_private *p;
	struct kobject___301 kobj;
	const char *init_name;
	const struct device_type___279 *type;
	struct mutex mutex;
	struct bus_type___279 *bus;
	struct device_driver___279 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___279 power;
	struct dev_pm_domain___279 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___93 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___213 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___279 *class;
	const struct attribute_group___278 **groups;
	void (*release)(struct device___279 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___279 {
	struct dev_pm_ops___279 ops;
	void (*detach)(struct device___279 *, bool);
	int (*activate)(struct device___279 *);
	void (*sync)(struct device___279 *);
	void (*dismiss)(struct device___279 *);
};

struct key___292;

struct user_struct___292 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___292 *uid_keyring;
	struct key___292 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___314;

struct mm_struct___314 {
	struct {
		struct vm_area_struct___315 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___314 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___315 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___314 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___315 *owner;
		struct user_namespace___3 *user_ns;
		struct file___314 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___314 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___292 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___292 *session_keyring;
	struct key___292 *process_keyring;
	struct key___292 *thread_keyring;
	struct key___292 *request_key_auth;
	void *security;
	struct user_struct___292 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct vm_struct___230 {
	struct vm_struct___230 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___315 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bus_type___279 {
	const char *name;
	const char *dev_name;
	struct device___279 *dev_root;
	const struct attribute_group___278 **bus_groups;
	const struct attribute_group___278 **dev_groups;
	const struct attribute_group___278 **drv_groups;
	int (*match)(struct device___279 *, struct device_driver___279 *);
	int (*uevent)(struct device___279 *, struct kobj_uevent_env *);
	int (*probe)(struct device___279 *);
	int (*remove)(struct device___279 *);
	void (*shutdown)(struct device___279 *);
	int (*online)(struct device___279 *);
	int (*offline)(struct device___279 *);
	int (*suspend)(struct device___279 *, pm_message_t);
	int (*resume)(struct device___279 *);
	int (*num_vf)(struct device___279 *);
	int (*dma_configure)(struct device___279 *);
	const struct dev_pm_ops___279 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___279 {
	const char *name;
	struct bus_type___279 *bus;
	struct module___254 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___279 *);
	int (*remove)(struct device___279 *);
	void (*shutdown)(struct device___279 *);
	int (*suspend)(struct device___279 *, pm_message_t);
	int (*resume)(struct device___279 *);
	const struct attribute_group___278 **groups;
	const struct dev_pm_ops___279 *pm;
	void (*coredump)(struct device___279 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___279 {
	const char *name;
	const struct attribute_group___278 **groups;
	int (*uevent)(struct device___279 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___279 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___279 *);
	const struct dev_pm_ops___279 *pm;
};

struct class___279 {
	const char *name;
	struct module___254 *owner;
	const struct attribute_group___278 **class_groups;
	const struct attribute_group___278 **dev_groups;
	struct kobject___301 *dev_kobj;
	int (*dev_uevent)(struct device___279 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___279 *, umode_t *);
	void (*class_release)(struct class___279 *);
	void (*dev_release)(struct device___279 *);
	int (*shutdown_pre)(struct device___279 *);
	const struct kobj_ns_type_operations___25 *ns_type;
	const void * (*namespace)(struct device___279 *);
	const struct dev_pm_ops___279 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___93 {
	void * (*alloc)(struct device___279 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___279 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___279 *, struct vm_area_struct___315 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___279 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___279 *, struct page___315 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___279 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___279 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___279 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___279 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___279 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___279 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___279 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___279 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___279 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___279 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___279 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___279 *, u64);
	u64 (*get_required_mask)(struct device___279 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___213;

struct fwnode_handle___213 {
	struct fwnode_handle___213 *secondary;
	const struct fwnode_operations___213 *ops;
};

struct fwnode_reference_args___213;

struct fwnode_endpoint___213;

struct fwnode_operations___213 {
	struct fwnode_handle___213 * (*get)(struct fwnode_handle___213 *);
	void (*put)(struct fwnode_handle___213 *);
	bool (*device_is_available)(const struct fwnode_handle___213 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___213 *, const struct device___279 *);
	bool (*property_present)(const struct fwnode_handle___213 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___213 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___213 *, const char *, const char **, size_t);
	struct fwnode_handle___213 * (*get_parent)(const struct fwnode_handle___213 *);
	struct fwnode_handle___213 * (*get_next_child_node)(const struct fwnode_handle___213 *, struct fwnode_handle___213 *);
	struct fwnode_handle___213 * (*get_named_child_node)(const struct fwnode_handle___213 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___213 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___213 *);
	struct fwnode_handle___213 * (*graph_get_next_endpoint)(const struct fwnode_handle___213 *, struct fwnode_handle___213 *);
	struct fwnode_handle___213 * (*graph_get_remote_endpoint)(const struct fwnode_handle___213 *);
	struct fwnode_handle___213 * (*graph_get_port_parent)(struct fwnode_handle___213 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___213 *, struct fwnode_endpoint___213 *);
};

struct fwnode_endpoint___213 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___213 *local_fwnode;
};

struct fwnode_reference_args___213 {
	struct fwnode_handle___213 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

enum acpi_hest_notify_types {
	ACPI_HEST_NOTIFY_POLLED = 0,
	ACPI_HEST_NOTIFY_EXTERNAL = 1,
	ACPI_HEST_NOTIFY_LOCAL = 2,
	ACPI_HEST_NOTIFY_SCI = 3,
	ACPI_HEST_NOTIFY_NMI = 4,
	ACPI_HEST_NOTIFY_CMCI = 5,
	ACPI_HEST_NOTIFY_MCE = 6,
	ACPI_HEST_NOTIFY_GPIO = 7,
	ACPI_HEST_NOTIFY_SEA = 8,
	ACPI_HEST_NOTIFY_SEI = 9,
	ACPI_HEST_NOTIFY_GSIV = 10,
	ACPI_HEST_NOTIFY_SOFTWARE_DELEGATED = 11,
	ACPI_HEST_NOTIFY_RESERVED = 12,
};

struct acpi_hest_generic_v2 {
	struct acpi_hest_header header;
	u16 related_source_id;
	u8 reserved;
	u8 enabled;
	u32 records_to_preallocate;
	u32 max_sections_per_record;
	u32 max_raw_data_length;
	struct acpi_generic_address error_status_address;
	struct acpi_hest_notify notify;
	u32 error_block_length;
	struct acpi_generic_address read_ack_register;
	u64 read_ack_preserve;
	u64 read_ack_write;
} __attribute__((packed));

struct acpi_hest_generic_data {
	u8 section_type[16];
	u32 error_severity;
	u16 revision;
	u8 validation_bits;
	u8 flags;
	u32 error_data_length;
	u8 fru_id[16];
	u8 fru_text[20];
};

struct acpi_hest_generic_data_v300 {
	u8 section_type[16];
	u32 error_severity;
	u16 revision;
	u8 validation_bits;
	u8 flags;
	u32 error_data_length;
	u8 fru_id[16];
	u8 fru_text[20];
	u64 time_stamp;
};

struct module_attribute___251 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___251 *, struct module_kobject___251 *, char *);
	ssize_t (*store)(struct module_attribute___251 *, struct module_kobject___251 *, const char *, size_t);
	void (*setup)(struct module___254 *, const char *);
	int (*test)(struct module___254 *);
	void (*free)(struct module___254 *);
};

struct dentry_operations___313;

struct super_block___313;

struct dentry___313 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___313 *d_parent;
	struct qstr d_name;
	struct inode___314 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___313 *d_op;
	struct super_block___313 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___313;

struct address_space___313 {
	struct inode___314 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___315 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___313 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___313;

struct block_device___313;

struct cdev___64;

struct inode___314 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___313 *i_op;
	struct super_block___313 *i_sb;
	struct address_space___313 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___315 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___314 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___313 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___313 *i_bdev;
		struct cdev___64 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___313 {
	int (*d_revalidate)(struct dentry___313 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___313 *, unsigned int);
	int (*d_hash)(const struct dentry___313 *, struct qstr *);
	int (*d_compare)(const struct dentry___313 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___313 *);
	int (*d_init)(struct dentry___313 *);
	void (*d_release)(struct dentry___313 *);
	void (*d_prune)(struct dentry___313 *);
	void (*d_iput)(struct dentry___313 *, struct inode___314 *);
	char * (*d_dname)(struct dentry___313 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___314 *);
	int (*d_manage)(const struct path___314 *, bool);
	struct dentry___313 * (*d_real)(struct dentry___313 *, const struct inode___314 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___313;

struct mem_dqinfo___313 {
	struct quota_format_type___313 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___313;

struct quota_info___313 {
	unsigned int flags;
	struct rw_semaphore___315 dqio_sem;
	struct inode___314 *files[3];
	struct mem_dqinfo___313 info[3];
	const struct quota_format_ops___313 *ops[3];
};

struct rcuwait___313 {
	struct task_struct___315 *task;
};

struct percpu_rw_semaphore___313 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___315 rw_sem;
	struct rcuwait___313 writer;
	int readers_block;
};

struct sb_writers___313 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___313 rw_sem[3];
};

struct file_system_type___313;

struct super_operations___313;

struct dquot_operations___313;

struct quotactl_ops___313;

struct super_block___313 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___313 *s_type;
	const struct super_operations___313 *s_op;
	const struct dquot_operations___313 *dq_op;
	const struct quotactl_ops___313 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___313 *s_root;
	struct rw_semaphore___315 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___313 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___313 s_dquot;
	struct sb_writers___313 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___313 *s_d_op;
	int cleancache_poolid;
	struct shrinker___119 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

typedef int (*dev_page_fault_t___303)(struct vm_area_struct___315 *, long unsigned int, const struct page___315 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___303)(struct page___315 *, void *);

struct dev_pagemap___303 {
	dev_page_fault_t___303 page_fault;
	dev_page_free_t___303 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___279 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___314 {
	struct task_struct___315 *task;
	struct core_thread___314 *next;
};

struct core_state___314 {
	atomic_t nr_threads;
	struct core_thread___314 dumper;
	struct completion startup;
};

struct vm_fault___303 {
	struct vm_area_struct___315 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___315 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___315 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___314 prealloc_pte;
};

struct kiocb___314 {
	struct file___314 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___314 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___313 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___314 *ia_file;
};

struct dquot___313 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___313 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___313 {
	int qf_fmt_id;
	const struct quota_format_ops___313 *qf_ops;
	struct module___254 *qf_owner;
	struct quota_format_type___313 *qf_next;
};

struct quota_format_ops___313 {
	int (*check_quota_file)(struct super_block___313 *, int);
	int (*read_file_info)(struct super_block___313 *, int);
	int (*write_file_info)(struct super_block___313 *, int);
	int (*free_file_info)(struct super_block___313 *, int);
	int (*read_dqblk)(struct dquot___313 *);
	int (*commit_dqblk)(struct dquot___313 *);
	int (*release_dqblk)(struct dquot___313 *);
	int (*get_next_id)(struct super_block___313 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___313 {
	int (*write_dquot)(struct dquot___313 *);
	struct dquot___313 * (*alloc_dquot)(struct super_block___313 *, int);
	void (*destroy_dquot)(struct dquot___313 *);
	int (*acquire_dquot)(struct dquot___313 *);
	int (*release_dquot)(struct dquot___313 *);
	int (*mark_dirty)(struct dquot___313 *);
	int (*write_info)(struct super_block___313 *, int);
	qsize_t * (*get_reserved_space)(struct inode___314 *);
	int (*get_projid)(struct inode___314 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___314 *, qsize_t *);
	int (*get_next_id)(struct super_block___313 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___313 {
	int (*quota_on)(struct super_block___313 *, int, int, const struct path___314 *);
	int (*quota_off)(struct super_block___313 *, int);
	int (*quota_enable)(struct super_block___313 *, unsigned int);
	int (*quota_disable)(struct super_block___313 *, unsigned int);
	int (*quota_sync)(struct super_block___313 *, int);
	int (*set_info)(struct super_block___313 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___313 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___313 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___313 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___313 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___313 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___313 {
	int (*writepage)(struct page___315 *, struct writeback_control___3 *);
	int (*readpage)(struct file___314 *, struct page___315 *);
	int (*writepages)(struct address_space___313 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___315 *);
	int (*readpages)(struct file___314 *, struct address_space___313 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___314 *, struct address_space___313 *, loff_t, unsigned int, unsigned int, struct page___315 **, void **);
	int (*write_end)(struct file___314 *, struct address_space___313 *, loff_t, unsigned int, unsigned int, struct page___315 *, void *);
	sector_t (*bmap)(struct address_space___313 *, sector_t);
	void (*invalidatepage)(struct page___315 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___315 *, gfp_t);
	void (*freepage)(struct page___315 *);
	ssize_t (*direct_IO)(struct kiocb___314 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___313 *, struct page___315 *, struct page___315 *, enum migrate_mode);
	bool (*isolate_page)(struct page___315 *, isolate_mode_t);
	void (*putback_page)(struct page___315 *);
	int (*launder_page)(struct page___315 *);
	int (*is_partially_uptodate)(struct page___315 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___315 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___313 *, struct page___315 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___314 *, sector_t *);
	void (*swap_deactivate)(struct file___314 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___313 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___314 *bd_inode;
	struct super_block___313 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___313 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___64 {
	struct kobject___301 kobj;
	struct module___254 *owner;
	const struct file_operations___314 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___313 {
	struct dentry___313 * (*lookup)(struct inode___314 *, struct dentry___313 *, unsigned int);
	const char * (*get_link)(struct dentry___313 *, struct inode___314 *, struct delayed_call *);
	int (*permission)(struct inode___314 *, int);
	struct posix_acl * (*get_acl)(struct inode___314 *, int);
	int (*readlink)(struct dentry___313 *, char *, int);
	int (*create)(struct inode___314 *, struct dentry___313 *, umode_t, bool);
	int (*link)(struct dentry___313 *, struct inode___314 *, struct dentry___313 *);
	int (*unlink)(struct inode___314 *, struct dentry___313 *);
	int (*symlink)(struct inode___314 *, struct dentry___313 *, const char *);
	int (*mkdir)(struct inode___314 *, struct dentry___313 *, umode_t);
	int (*rmdir)(struct inode___314 *, struct dentry___313 *);
	int (*mknod)(struct inode___314 *, struct dentry___313 *, umode_t, dev_t);
	int (*rename)(struct inode___314 *, struct dentry___313 *, struct inode___314 *, struct dentry___313 *, unsigned int);
	int (*setattr)(struct dentry___313 *, struct iattr___313 *);
	int (*getattr)(const struct path___314 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___313 *, char *, size_t);
	int (*fiemap)(struct inode___314 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___314 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___314 *, struct dentry___313 *, struct file___314 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___314 *, struct dentry___313 *, umode_t);
	int (*set_acl)(struct inode___314 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___313 {
	void (*fl_copy_lock)(struct file_lock___314 *, struct file_lock___314 *);
	void (*fl_release_private)(struct file_lock___314 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___313;

struct lock_manager_operations___313;

struct file_lock___314 {
	struct file_lock___314 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___314 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___313 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___313 *fl_ops;
	const struct lock_manager_operations___313 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___313 {
	int (*lm_compare_owner)(struct file_lock___314 *, struct file_lock___314 *);
	long unsigned int (*lm_owner_key)(struct file_lock___314 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___314 *);
	int (*lm_grant)(struct file_lock___314 *, int);
	bool (*lm_break)(struct file_lock___314 *);
	int (*lm_change)(struct file_lock___314 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___314 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___313 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___313 *fa_next;
	struct file___314 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___313 {
	const char *name;
	int fs_flags;
	struct dentry___313 * (*mount)(struct file_system_type___313 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___313 *);
	struct module___254 *owner;
	struct file_system_type___313 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___313 {
	struct inode___314 * (*alloc_inode)(struct super_block___313 *);
	void (*destroy_inode)(struct inode___314 *);
	void (*dirty_inode)(struct inode___314 *, int);
	int (*write_inode)(struct inode___314 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___314 *);
	void (*evict_inode)(struct inode___314 *);
	void (*put_super)(struct super_block___313 *);
	int (*sync_fs)(struct super_block___313 *, int);
	int (*freeze_super)(struct super_block___313 *);
	int (*freeze_fs)(struct super_block___313 *);
	int (*thaw_super)(struct super_block___313 *);
	int (*unfreeze_fs)(struct super_block___313 *);
	int (*statfs)(struct dentry___313 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___313 *, int *, char *);
	void (*umount_begin)(struct super_block___313 *);
	int (*show_options)(struct seq_file___266 *, struct dentry___313 *);
	int (*show_devname)(struct seq_file___266 *, struct dentry___313 *);
	int (*show_path)(struct seq_file___266 *, struct dentry___313 *);
	int (*show_stats)(struct seq_file___266 *, struct dentry___313 *);
	ssize_t (*quota_read)(struct super_block___313 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___313 *, int, const char *, size_t, loff_t);
	struct dquot___313 ** (*get_dquots)(struct inode___314 *);
	int (*bdev_try_to_free_page)(struct super_block___313 *, struct page___315 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___313 *, struct shrink_control___119 *);
	long int (*free_cached_objects)(struct super_block___313 *, struct shrink_control___119 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*key_restrict_link_func_t___293)(struct key___292 *, const struct key_type *, const union key_payload *, struct key___292 *);

struct key_restriction___292;

struct key___292 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___315 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___292 *restrict_link;
};

struct key_restriction___292 {
	key_restrict_link_func_t___293 check;
	struct key___292 *key;
	struct key_type *keytype;
};

struct seq_operations___265 {
	void * (*start)(struct seq_file___266 *, loff_t *);
	void (*stop)(struct seq_file___266 *, void *);
	void * (*next)(struct seq_file___266 *, void *, loff_t *);
	int (*show)(struct seq_file___266 *, void *);
};

typedef void compound_page_dtor___303(struct page___315 *);

struct cper_sec_proc_arm {
	__u32 validation_bits;
	__u16 err_info_num;
	__u16 context_info_num;
	__u32 section_length;
	__u8 affinity_level;
	__u8 reserved[3];
	__u64 mpidr;
	__u64 midr;
	__u32 running_state;
	__u32 psci_state;
};

struct cper_sec_pcie {
	__u64 validation_bits;
	__u32 port_type;
	struct {
		__u8 minor;
		__u8 major;
		__u8 reserved[2];
	} version;
	__u16 command;
	__u16 status;
	__u32 reserved;
	struct {
		__u16 vendor_id;
		__u16 device_id;
		__u8 class_code[3];
		__u8 function;
		__u8 device;
		__u16 segment;
		__u8 bus;
		__u8 secondary_bus;
		__u16 slot;
		__u8 reserved;
	} __attribute__((packed)) device_id;
	struct {
		__u32 lower;
		__u32 upper;
	} serial_number;
	struct {
		__u16 secondary_status;
		__u16 control;
	} bridge;
	__u8 capability[60];
	__u8 aer_info[96];
};

struct platform_device___16 {
	const char *name;
	int id;
	bool id_auto;
	struct device___279 dev;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct platform_driver___14 {
	int (*probe)(struct platform_device___16 *);
	int (*remove)(struct platform_device___16 *);
	void (*shutdown)(struct platform_device___16 *);
	int (*suspend)(struct platform_device___16 *, pm_message_t);
	int (*resume)(struct platform_device___16 *);
	struct device_driver___279 driver;
	const struct platform_device_id *id_table;
	bool prevent_deferred_probe;
};

struct ghes {
	union {
		struct acpi_hest_generic *generic;
		struct acpi_hest_generic_v2 *generic_v2;
	};
	struct acpi_hest_generic_status *estatus;
	u64 buffer_paddr;
	long unsigned int flags;
	union {
		struct list_head list;
		struct timer_list timer;
		unsigned int irq;
	};
};

struct ghes_estatus_cache {
	u32 estatus_len;
	atomic_t count;
	struct acpi_hest_generic *generic;
	long long unsigned int time_in;
	struct callback_head rcu;
};

enum {
	GHES_SEV_NO = 0,
	GHES_SEV_CORRECTED = 1,
	GHES_SEV_RECOVERABLE = 2,
	GHES_SEV_PANIC = 3,
};

struct acpi_table_iort {
	struct acpi_table_header header;
	u32 node_count;
	u32 node_offset;
	u32 reserved;
};

struct acpi_iort_node {
	u8 type;
	u16 length;
	u8 revision;
	u32 reserved;
	u32 mapping_count;
	u32 mapping_offset;
	char node_data[1];
} __attribute__((packed));

enum acpi_iort_node_type {
	ACPI_IORT_NODE_ITS_GROUP = 0,
	ACPI_IORT_NODE_NAMED_COMPONENT = 1,
	ACPI_IORT_NODE_PCI_ROOT_COMPLEX = 2,
	ACPI_IORT_NODE_SMMU = 3,
	ACPI_IORT_NODE_SMMU_V3 = 4,
	ACPI_IORT_NODE_PMCG = 5,
};

struct acpi_iort_id_mapping {
	u32 input_base;
	u32 id_count;
	u32 output_base;
	u32 output_reference;
	u32 flags;
};

struct acpi_iort_its_group {
	u32 its_count;
	u32 identifiers[1];
};

struct acpi_iort_named_component {
	u32 node_flags;
	u64 memory_properties;
	u8 memory_address_limit;
	char device_name[1];
} __attribute__((packed));

struct acpi_iort_root_complex {
	u64 memory_properties;
	u32 ats_attribute;
	u32 pci_segment_number;
	u8 memory_address_limit;
	u8 reserved[3];
} __attribute__((packed));

struct acpi_iort_smmu {
	u64 base_address;
	u64 span;
	u32 model;
	u32 flags;
	u32 global_interrupt_offset;
	u32 context_interrupt_count;
	u32 context_interrupt_offset;
	u32 pmu_interrupt_count;
	u32 pmu_interrupt_offset;
	u64 interrupts[1];
} __attribute__((packed));

struct acpi_iort_smmu_v3 {
	u64 base_address;
	u32 flags;
	u32 reserved;
	u64 vatos_address;
	u32 model;
	u32 event_gsiv;
	u32 pri_gsiv;
	u32 gerr_gsiv;
	u32 sync_gsiv;
	u32 pxm;
	u32 id_mapping_index;
} __attribute__((packed));

typedef int (*iommu_fault_handler_t___6)(struct iommu_domain *, struct device___272 *, long unsigned int, int, void *);

struct iort_its_msi_chip {
	struct list_head list;
	struct fwnode_handle___12 *fw_node;
	phys_addr_t base_addr;
	u32 translation_id;
};

struct iort_fwnode {
	struct list_head list;
	struct acpi_iort_node *iort_node;
	struct fwnode_handle___12 *fwnode;
};

typedef acpi_status (*iort_find_node_callback)(struct acpi_iort_node *, void *);

struct iort_pci_alias_info {
	struct device___272 *dev;
	struct acpi_iort_node *node;
};

struct iort_dev_config {
	const char *name;
	int (*dev_init)(struct acpi_iort_node *);
	bool (*dev_is_coherent)(struct acpi_iort_node *);
	int (*dev_count_resources)(struct acpi_iort_node *);
	void (*dev_init_resources)(struct resource *, struct acpi_iort_node *);
	void (*dev_set_proximity)(struct device___272 *, struct acpi_iort_node *);
};

enum arch_timer_ppi_nr {
	ARCH_TIMER_PHYS_SECURE_PPI = 0,
	ARCH_TIMER_PHYS_NONSECURE_PPI = 1,
	ARCH_TIMER_VIRT_PPI = 2,
	ARCH_TIMER_HYP_PPI = 3,
	ARCH_TIMER_MAX_TIMER_PPI = 4,
};

struct arch_timer_mem_frame {
	bool valid;
	phys_addr_t cntbase;
	size_t size;
	int phys_irq;
	int virt_irq;
};

struct arch_timer_mem {
	phys_addr_t cntctlbase;
	size_t size;
	struct arch_timer_mem_frame frame[8];
};

struct acpi_table_gtdt {
	struct acpi_table_header header;
	u64 counter_block_addresss;
	u32 reserved;
	u32 secure_el1_interrupt;
	u32 secure_el1_flags;
	u32 non_secure_el1_interrupt;
	u32 non_secure_el1_flags;
	u32 virtual_timer_interrupt;
	u32 virtual_timer_flags;
	u32 non_secure_el2_interrupt;
	u32 non_secure_el2_flags;
	u64 counter_read_block_address;
	u32 platform_timer_count;
	u32 platform_timer_offset;
} __attribute__((packed));

struct acpi_gtdt_header {
	u8 type;
	u16 length;
} __attribute__((packed));

enum acpi_gtdt_type {
	ACPI_GTDT_TYPE_TIMER_BLOCK = 0,
	ACPI_GTDT_TYPE_WATCHDOG = 1,
	ACPI_GTDT_TYPE_RESERVED = 2,
};

struct acpi_gtdt_timer_block {
	struct acpi_gtdt_header header;
	u8 reserved;
	u64 block_address;
	u32 timer_count;
	u32 timer_offset;
} __attribute__((packed));

struct acpi_gtdt_timer_entry {
	u8 frame_number;
	u8 reserved[3];
	u64 base_address;
	u64 el0_base_address;
	u32 timer_interrupt;
	u32 timer_flags;
	u32 virtual_timer_interrupt;
	u32 virtual_timer_flags;
	u32 common_flags;
} __attribute__((packed));

struct acpi_gtdt_watchdog {
	struct acpi_gtdt_header header;
	u8 reserved;
	u64 refresh_frame_address;
	u64 control_frame_address;
	u32 timer_interrupt;
	u32 timer_flags;
} __attribute__((packed));

typedef void (*poll_queue_proc___196)(struct file___314 *, wait_queue_head_t *, struct poll_table_struct___12 *);

struct acpi_gtdt_descriptor {
	struct acpi_table_gtdt *gtdt;
	void *gtdt_end;
	void *platform_timer;
};

struct pnp_device_id {
	__u8 id[8];
	kernel_ulong_t driver_data;
};

struct pnp_card_device_id {
	__u8 id[8];
	kernel_ulong_t driver_data;
	struct {
		__u8 id[8];
	} devs[8];
};

struct pnp_protocol;

struct pnp_id;

struct pnp_card {
	struct device___272 dev;
	unsigned char number;
	struct list_head global_list;
	struct list_head protocol_list;
	struct list_head devices;
	struct pnp_protocol *protocol;
	struct pnp_id *id;
	char name[50];
	unsigned char pnpver;
	unsigned char productver;
	unsigned int serial;
	unsigned char checksum;
	struct proc_dir_entry *procdir;
};

struct pnp_dev;

struct pnp_protocol {
	struct list_head protocol_list;
	char *name;
	int (*get)(struct pnp_dev *);
	int (*set)(struct pnp_dev *);
	int (*disable)(struct pnp_dev *);
	bool (*can_wakeup)(struct pnp_dev *);
	int (*suspend)(struct pnp_dev *, pm_message_t);
	int (*resume)(struct pnp_dev *);
	unsigned char number;
	struct device___272 dev;
	struct list_head cards;
	struct list_head devices;
};

struct pnp_id {
	char id[8];
	struct pnp_id *next;
};

struct pnp_card_driver;

struct pnp_card_link {
	struct pnp_card *card;
	struct pnp_card_driver *driver;
	void *driver_data;
	pm_message_t pm_state;
};

struct pnp_driver {
	char *name;
	const struct pnp_device_id *id_table;
	unsigned int flags;
	int (*probe)(struct pnp_dev *, const struct pnp_device_id *);
	void (*remove)(struct pnp_dev *);
	void (*shutdown)(struct pnp_dev *);
	int (*suspend)(struct pnp_dev *, pm_message_t);
	int (*resume)(struct pnp_dev *);
	struct device_driver___272 driver;
};

struct pnp_card_driver {
	struct list_head global_list;
	char *name;
	const struct pnp_card_device_id *id_table;
	unsigned int flags;
	int (*probe)(struct pnp_card_link *, const struct pnp_card_device_id *);
	void (*remove)(struct pnp_card_link *);
	int (*suspend)(struct pnp_card_link *, pm_message_t);
	int (*resume)(struct pnp_card_link *);
	struct pnp_driver link;
};

struct pnp_dev {
	struct device___272 dev;
	u64 dma_mask;
	unsigned int number;
	int status;
	struct list_head global_list;
	struct list_head protocol_list;
	struct list_head card_list;
	struct list_head rdev_list;
	struct pnp_protocol *protocol;
	struct pnp_card *card;
	struct pnp_driver *driver;
	struct pnp_card_link *card_link;
	struct pnp_id *id;
	int active;
	int capabilities;
	unsigned int num_dependent_sets;
	struct list_head resources;
	struct list_head options;
	char name[50];
	int flags;
	struct proc_dir_entry *procent;
	void *data;
};

struct pnp_resource {
	struct list_head list;
	struct resource res;
};

struct consw___15 {
	struct module___249 *owner;
	const char * (*con_startup)();
	void (*con_init)(struct vc_data *, int);
	void (*con_deinit)(struct vc_data *);
	void (*con_clear)(struct vc_data *, int, int, int, int);
	void (*con_putc)(struct vc_data *, int, int, int);
	void (*con_putcs)(struct vc_data *, const short unsigned int *, int, int, int);
	void (*con_cursor)(struct vc_data *, int);
	bool (*con_scroll)(struct vc_data *, unsigned int, unsigned int, enum con_scroll, unsigned int);
	int (*con_switch)(struct vc_data *);
	int (*con_blank)(struct vc_data *, int, int);
	int (*con_font_set)(struct vc_data *, struct console_font *, unsigned int);
	int (*con_font_get)(struct vc_data *, struct console_font *);
	int (*con_font_default)(struct vc_data *, struct console_font *, char *);
	int (*con_font_copy)(struct vc_data *, int);
	int (*con_resize)(struct vc_data *, unsigned int, unsigned int, unsigned int);
	void (*con_set_palette)(struct vc_data *, const unsigned char *);
	void (*con_scrolldelta)(struct vc_data *, int);
	int (*con_set_origin)(struct vc_data *);
	void (*con_save_screen)(struct vc_data *);
	u8 (*con_build_attr)(struct vc_data *, u8, u8, u8, u8, u8, u8);
	void (*con_invert_region)(struct vc_data *, u16 *, int);
	u16 * (*con_screen_pos)(struct vc_data *, int);
	long unsigned int (*con_getxy)(struct vc_data *, long unsigned int, int *, int *);
	void (*con_flush_scrollback)(struct vc_data *);
	int (*con_debug_enter)(struct vc_data *);
	int (*con_debug_leave)(struct vc_data *);
};

struct pnp_protocol___2;

struct pnp_card___2 {
	struct device___274 dev;
	unsigned char number;
	struct list_head global_list;
	struct list_head protocol_list;
	struct list_head devices;
	struct pnp_protocol___2 *protocol;
	struct pnp_id *id;
	char name[50];
	unsigned char pnpver;
	unsigned char productver;
	unsigned int serial;
	unsigned char checksum;
	struct proc_dir_entry *procdir;
};

struct pnp_dev___2;

struct pnp_protocol___2 {
	struct list_head protocol_list;
	char *name;
	int (*get)(struct pnp_dev___2 *);
	int (*set)(struct pnp_dev___2 *);
	int (*disable)(struct pnp_dev___2 *);
	bool (*can_wakeup)(struct pnp_dev___2 *);
	int (*suspend)(struct pnp_dev___2 *, pm_message_t);
	int (*resume)(struct pnp_dev___2 *);
	unsigned char number;
	struct device___274 dev;
	struct list_head cards;
	struct list_head devices;
};

struct pnp_card_driver___2;

struct pnp_card_link___2 {
	struct pnp_card___2 *card;
	struct pnp_card_driver___2 *driver;
	void *driver_data;
	pm_message_t pm_state;
};

struct pnp_driver___2 {
	char *name;
	const struct pnp_device_id *id_table;
	unsigned int flags;
	int (*probe)(struct pnp_dev___2 *, const struct pnp_device_id *);
	void (*remove)(struct pnp_dev___2 *);
	void (*shutdown)(struct pnp_dev___2 *);
	int (*suspend)(struct pnp_dev___2 *, pm_message_t);
	int (*resume)(struct pnp_dev___2 *);
	struct device_driver___274 driver;
};

struct pnp_card_driver___2 {
	struct list_head global_list;
	char *name;
	const struct pnp_card_device_id *id_table;
	unsigned int flags;
	int (*probe)(struct pnp_card_link___2 *, const struct pnp_card_device_id *);
	void (*remove)(struct pnp_card_link___2 *);
	int (*suspend)(struct pnp_card_link___2 *, pm_message_t);
	int (*resume)(struct pnp_card_link___2 *);
	struct pnp_driver___2 link;
};

struct pnp_dev___2 {
	struct device___274 dev;
	u64 dma_mask;
	unsigned int number;
	int status;
	struct list_head global_list;
	struct list_head protocol_list;
	struct list_head card_list;
	struct list_head rdev_list;
	struct pnp_protocol___2 *protocol;
	struct pnp_card___2 *card;
	struct pnp_driver___2 *driver;
	struct pnp_card_link___2 *card_link;
	struct pnp_id *id;
	int active;
	int capabilities;
	unsigned int num_dependent_sets;
	struct list_head resources;
	struct list_head options;
	char name[50];
	int flags;
	struct proc_dir_entry *procent;
	void *data;
};

struct pnp_port {
	resource_size_t min;
	resource_size_t max;
	resource_size_t align;
	resource_size_t size;
	unsigned char flags;
};

typedef struct {
	long unsigned int bits[4];
} pnp_irq_mask_t;

struct pnp_irq {
	pnp_irq_mask_t map;
	unsigned char flags;
};

struct pnp_dma {
	unsigned char map;
	unsigned char flags;
};

struct pnp_mem {
	resource_size_t min;
	resource_size_t max;
	resource_size_t align;
	resource_size_t size;
	unsigned char flags;
};

struct pnp_option {
	struct list_head list;
	unsigned int flags;
	long unsigned int type;
	union {
		struct pnp_port port;
		struct pnp_irq irq;
		struct pnp_dma dma;
		struct pnp_mem mem;
	} u;
};

struct pnp_info_buffer {
	char *buffer;
	char *curr;
	long unsigned int size;
	long unsigned int len;
	int stop;
	int error;
};

typedef struct pnp_info_buffer pnp_info_buffer_t;

struct pnp_protocol___3;

struct pnp_card___3 {
	struct device___263 dev;
	unsigned char number;
	struct list_head global_list;
	struct list_head protocol_list;
	struct list_head devices;
	struct pnp_protocol___3 *protocol;
	struct pnp_id *id;
	char name[50];
	unsigned char pnpver;
	unsigned char productver;
	unsigned int serial;
	unsigned char checksum;
	struct proc_dir_entry *procdir;
};

struct pnp_dev___3;

struct pnp_protocol___3 {
	struct list_head protocol_list;
	char *name;
	int (*get)(struct pnp_dev___3 *);
	int (*set)(struct pnp_dev___3 *);
	int (*disable)(struct pnp_dev___3 *);
	bool (*can_wakeup)(struct pnp_dev___3 *);
	int (*suspend)(struct pnp_dev___3 *, pm_message_t);
	int (*resume)(struct pnp_dev___3 *);
	unsigned char number;
	struct device___263 dev;
	struct list_head cards;
	struct list_head devices;
};

struct pnp_card_driver___3;

struct pnp_card_link___3 {
	struct pnp_card___3 *card;
	struct pnp_card_driver___3 *driver;
	void *driver_data;
	pm_message_t pm_state;
};

struct pnp_driver___3 {
	char *name;
	const struct pnp_device_id *id_table;
	unsigned int flags;
	int (*probe)(struct pnp_dev___3 *, const struct pnp_device_id *);
	void (*remove)(struct pnp_dev___3 *);
	void (*shutdown)(struct pnp_dev___3 *);
	int (*suspend)(struct pnp_dev___3 *, pm_message_t);
	int (*resume)(struct pnp_dev___3 *);
	struct device_driver___263 driver;
};

struct pnp_card_driver___3 {
	struct list_head global_list;
	char *name;
	const struct pnp_card_device_id *id_table;
	unsigned int flags;
	int (*probe)(struct pnp_card_link___3 *, const struct pnp_card_device_id *);
	void (*remove)(struct pnp_card_link___3 *);
	int (*suspend)(struct pnp_card_link___3 *, pm_message_t);
	int (*resume)(struct pnp_card_link___3 *);
	struct pnp_driver___3 link;
};

struct pnp_dev___3 {
	struct device___263 dev;
	u64 dma_mask;
	unsigned int number;
	int status;
	struct list_head global_list;
	struct list_head protocol_list;
	struct list_head card_list;
	struct list_head rdev_list;
	struct pnp_protocol___3 *protocol;
	struct pnp_card___3 *card;
	struct pnp_driver___3 *driver;
	struct pnp_card_link___3 *card_link;
	struct pnp_id *id;
	int active;
	int capabilities;
	unsigned int num_dependent_sets;
	struct list_head resources;
	struct list_head options;
	char name[50];
	int flags;
	struct proc_dir_entry *procent;
	void *data;
};

struct pnp_fixup {
	char id[7];
	void (*quirk_function)(struct pnp_dev___3 *);
};

struct pnp_protocol___4;

struct pnp_card___4 {
	struct device___279 dev;
	unsigned char number;
	struct list_head global_list;
	struct list_head protocol_list;
	struct list_head devices;
	struct pnp_protocol___4 *protocol;
	struct pnp_id *id;
	char name[50];
	unsigned char pnpver;
	unsigned char productver;
	unsigned int serial;
	unsigned char checksum;
	struct proc_dir_entry *procdir;
};

struct pnp_dev___4;

struct pnp_protocol___4 {
	struct list_head protocol_list;
	char *name;
	int (*get)(struct pnp_dev___4 *);
	int (*set)(struct pnp_dev___4 *);
	int (*disable)(struct pnp_dev___4 *);
	bool (*can_wakeup)(struct pnp_dev___4 *);
	int (*suspend)(struct pnp_dev___4 *, pm_message_t);
	int (*resume)(struct pnp_dev___4 *);
	unsigned char number;
	struct device___279 dev;
	struct list_head cards;
	struct list_head devices;
};

struct pnp_card_driver___4;

struct pnp_card_link___4 {
	struct pnp_card___4 *card;
	struct pnp_card_driver___4 *driver;
	void *driver_data;
	pm_message_t pm_state;
};

struct pnp_driver___4 {
	char *name;
	const struct pnp_device_id *id_table;
	unsigned int flags;
	int (*probe)(struct pnp_dev___4 *, const struct pnp_device_id *);
	void (*remove)(struct pnp_dev___4 *);
	void (*shutdown)(struct pnp_dev___4 *);
	int (*suspend)(struct pnp_dev___4 *, pm_message_t);
	int (*resume)(struct pnp_dev___4 *);
	struct device_driver___279 driver;
};

struct pnp_card_driver___4 {
	struct list_head global_list;
	char *name;
	const struct pnp_card_device_id *id_table;
	unsigned int flags;
	int (*probe)(struct pnp_card_link___4 *, const struct pnp_card_device_id *);
	void (*remove)(struct pnp_card_link___4 *);
	int (*suspend)(struct pnp_card_link___4 *, pm_message_t);
	int (*resume)(struct pnp_card_link___4 *);
	struct pnp_driver___4 link;
};

struct pnp_dev___4 {
	struct device___279 dev;
	u64 dma_mask;
	unsigned int number;
	int status;
	struct list_head global_list;
	struct list_head protocol_list;
	struct list_head card_list;
	struct list_head rdev_list;
	struct pnp_protocol___4 *protocol;
	struct pnp_card___4 *card;
	struct pnp_driver___4 *driver;
	struct pnp_card_link___4 *card_link;
	struct pnp_id *id;
	int active;
	int capabilities;
	unsigned int num_dependent_sets;
	struct list_head resources;
	struct list_head options;
	char name[50];
	int flags;
	struct proc_dir_entry *procent;
	void *data;
};

struct acpipnp_parse_option_s {
	struct pnp_dev___4 *dev;
	unsigned int option_flags;
};

struct device___280;

struct dev_pm_ops___280 {
	int (*prepare)(struct device___280 *);
	void (*complete)(struct device___280 *);
	int (*suspend)(struct device___280 *);
	int (*resume)(struct device___280 *);
	int (*freeze)(struct device___280 *);
	int (*thaw)(struct device___280 *);
	int (*poweroff)(struct device___280 *);
	int (*restore)(struct device___280 *);
	int (*suspend_late)(struct device___280 *);
	int (*resume_early)(struct device___280 *);
	int (*freeze_late)(struct device___280 *);
	int (*thaw_early)(struct device___280 *);
	int (*poweroff_late)(struct device___280 *);
	int (*restore_early)(struct device___280 *);
	int (*suspend_noirq)(struct device___280 *);
	int (*resume_noirq)(struct device___280 *);
	int (*freeze_noirq)(struct device___280 *);
	int (*thaw_noirq)(struct device___280 *);
	int (*poweroff_noirq)(struct device___280 *);
	int (*restore_noirq)(struct device___280 *);
	int (*runtime_suspend)(struct device___280 *);
	int (*runtime_resume)(struct device___280 *);
	int (*runtime_idle)(struct device___280 *);
};

struct pm_subsys_data___3;

struct dev_pm_info___280 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___3 *subsys_data;
	void (*set_latency_tolerance)(struct device___280 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___280;

struct bus_type___280;

struct device_driver___280;

struct dev_pm_domain___280;

struct device_node___70;

struct fwnode_handle___214;

struct class___280;

struct device___280 {
	struct device___280 *parent;
	struct device_private *p;
	struct kobject___296 kobj;
	const char *init_name;
	const struct device_type___280 *type;
	struct mutex mutex;
	struct bus_type___280 *bus;
	struct device_driver___280 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___280 power;
	struct dev_pm_domain___280 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___70 *of_node;
	struct fwnode_handle___214 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___280 *class;
	const struct attribute_group___273 **groups;
	void (*release)(struct device___280 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct pm_domain_data___3;

struct pm_subsys_data___3 {
	spinlock_t lock;
	unsigned int refcount;
	struct list_head clock_list;
	struct pm_domain_data___3 *domain_data;
};

struct pm_domain_data___3 {
	struct list_head list_node;
	struct device___280 *dev;
};

struct dev_pm_domain___280 {
	struct dev_pm_ops___280 ops;
	void (*detach)(struct device___280 *, bool);
	int (*activate)(struct device___280 *);
	void (*sync)(struct device___280 *);
	void (*dismiss)(struct device___280 *);
};

struct bus_type___280 {
	const char *name;
	const char *dev_name;
	struct device___280 *dev_root;
	const struct attribute_group___273 **bus_groups;
	const struct attribute_group___273 **dev_groups;
	const struct attribute_group___273 **drv_groups;
	int (*match)(struct device___280 *, struct device_driver___280 *);
	int (*uevent)(struct device___280 *, struct kobj_uevent_env *);
	int (*probe)(struct device___280 *);
	int (*remove)(struct device___280 *);
	void (*shutdown)(struct device___280 *);
	int (*online)(struct device___280 *);
	int (*offline)(struct device___280 *);
	int (*suspend)(struct device___280 *, pm_message_t);
	int (*resume)(struct device___280 *);
	int (*num_vf)(struct device___280 *);
	int (*dma_configure)(struct device___280 *);
	const struct dev_pm_ops___280 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___280 {
	const char *name;
	struct bus_type___280 *bus;
	struct module___249 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___280 *);
	int (*remove)(struct device___280 *);
	void (*shutdown)(struct device___280 *);
	int (*suspend)(struct device___280 *, pm_message_t);
	int (*resume)(struct device___280 *);
	const struct attribute_group___273 **groups;
	const struct dev_pm_ops___280 *pm;
	void (*coredump)(struct device___280 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___280 {
	const char *name;
	const struct attribute_group___273 **groups;
	int (*uevent)(struct device___280 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___280 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___280 *);
	const struct dev_pm_ops___280 *pm;
};

struct class___280 {
	const char *name;
	struct module___249 *owner;
	const struct attribute_group___273 **class_groups;
	const struct attribute_group___273 **dev_groups;
	struct kobject___296 *dev_kobj;
	int (*dev_uevent)(struct device___280 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___280 *, umode_t *);
	void (*class_release)(struct class___280 *);
	void (*dev_release)(struct device___280 *);
	int (*shutdown_pre)(struct device___280 *);
	const struct kobj_ns_type_operations___25 *ns_type;
	const void * (*namespace)(struct device___280 *);
	const struct dev_pm_ops___280 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct device_attribute___24 {
	struct attribute attr;
	ssize_t (*show)(struct device___280 *, struct device_attribute___24 *, char *);
	ssize_t (*store)(struct device___280 *, struct device_attribute___24 *, const char *, size_t);
};

struct fwnode_operations___214;

struct fwnode_handle___214 {
	struct fwnode_handle___214 *secondary;
	const struct fwnode_operations___214 *ops;
};

struct device_node___70 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___214 fwnode;
	struct property___63 *properties;
	struct property___63 *deadprops;
	struct device_node___70 *parent;
	struct device_node___70 *child;
	struct device_node___70 *sibling;
	struct kobject___296 kobj;
	long unsigned int _flags;
	void *data;
};

struct fwnode_reference_args___214;

struct fwnode_endpoint___214;

struct fwnode_operations___214 {
	struct fwnode_handle___214 * (*get)(struct fwnode_handle___214 *);
	void (*put)(struct fwnode_handle___214 *);
	bool (*device_is_available)(const struct fwnode_handle___214 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___214 *, const struct device___280 *);
	bool (*property_present)(const struct fwnode_handle___214 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___214 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___214 *, const char *, const char **, size_t);
	struct fwnode_handle___214 * (*get_parent)(const struct fwnode_handle___214 *);
	struct fwnode_handle___214 * (*get_next_child_node)(const struct fwnode_handle___214 *, struct fwnode_handle___214 *);
	struct fwnode_handle___214 * (*get_named_child_node)(const struct fwnode_handle___214 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___214 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___214 *);
	struct fwnode_handle___214 * (*graph_get_next_endpoint)(const struct fwnode_handle___214 *, struct fwnode_handle___214 *);
	struct fwnode_handle___214 * (*graph_get_remote_endpoint)(const struct fwnode_handle___214 *);
	struct fwnode_handle___214 * (*graph_get_port_parent)(struct fwnode_handle___214 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___214 *, struct fwnode_endpoint___214 *);
};

struct fwnode_endpoint___214 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___214 *local_fwnode;
};

struct fwnode_reference_args___214 {
	struct fwnode_handle___214 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct dev_power_governor___3 {
	bool (*power_down_ok)(struct dev_pm_domain___280 *);
	bool (*suspend_ok)(struct device___280 *);
};

struct amba_device___4 {
	struct device___280 dev;
	struct resource res;
	struct clk *pclk;
	unsigned int periphid;
	unsigned int irq[9];
	char *driver_override;
};

struct amba_driver___3 {
	struct device_driver___280 drv;
	int (*probe)(struct amba_device___4 *, const struct amba_id *);
	int (*remove)(struct amba_device___4 *);
	void (*shutdown)(struct amba_device___4 *);
	const struct amba_id *id_table;
};

struct deferred_device {
	struct amba_device___4 *dev;
	struct resource *parent;
	struct list_head node;
};

struct find_data {
	struct amba_device___4 *dev;
	struct device___280 *parent;
	const char *busid;
	unsigned int id;
	unsigned int mask;
};

struct clk_bulk_data {
	const char *id;
	struct clk *clk;
};

typedef void (*dr_release_t___13)(struct device___280 *, void *);

struct clk_bulk_devres {
	struct clk_bulk_data *clks;
	int num_clks;
};

struct clk_lookup {
	struct list_head node;
	const char *dev_id;
	const char *con_id;
	struct clk *clk;
	struct clk_hw___4 *clk_hw;
};

struct clk_lookup_alloc {
	struct clk_lookup cl;
	char dev_id[20];
	char con_id[16];
};

struct module___255;

struct file___315;

struct kiocb___315;

struct poll_table_struct___192;

struct vm_area_struct___316;

struct inode___315;

struct file_lock___315;

struct page___316;

struct seq_file___267;

struct file_operations___315 {
	struct module___255 *owner;
	loff_t (*llseek)(struct file___315 *, loff_t, int);
	ssize_t (*read)(struct file___315 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___315 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___315 *, struct iov_iter___138 *);
	ssize_t (*write_iter)(struct kiocb___315 *, struct iov_iter___138 *);
	int (*iopoll)(struct kiocb___315 *, bool);
	int (*iterate)(struct file___315 *, struct dir_context *);
	int (*iterate_shared)(struct file___315 *, struct dir_context *);
	__poll_t (*poll)(struct file___315 *, struct poll_table_struct___192 *);
	long int (*unlocked_ioctl)(struct file___315 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___315 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___315 *, struct vm_area_struct___316 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___315 *, struct file___315 *);
	int (*flush)(struct file___315 *, fl_owner_t);
	int (*release)(struct inode___315 *, struct file___315 *);
	int (*fsync)(struct file___315 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___315 *, int);
	int (*lock)(struct file___315 *, int, struct file_lock___315 *);
	ssize_t (*sendpage)(struct file___315 *, struct page___316 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___315 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___315 *, int, struct file_lock___315 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___315 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___315 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___315 *, long int, struct file_lock___315 **, void **);
	long int (*fallocate)(struct file___315 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___267 *, struct file___315 *);
	ssize_t (*copy_file_range)(struct file___315 *, loff_t, struct file___315 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___315 *, loff_t, struct file___315 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___315 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct perf_event___132;

struct debug_info___132 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___132 *hbp_break[16];
	struct perf_event___132 *hbp_watch[16];
};

struct task_struct___316;

struct hw_perf_event___132 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___316 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___132)(struct perf_event___132 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___132;

struct perf_event_context___132;

struct fasync_struct___314;

struct pid_namespace___205;

struct trace_event_call___125;

struct perf_cgroup___132;

struct perf_event___132 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___132 *group_leader;
	struct pmu___132 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___132 hw;
	struct perf_event_context___132 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___132 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___316 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___314 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___132 *);
	struct callback_head callback_head;
	struct pid_namespace___205 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___132 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___132 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___125 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___132 *cgrp;
	struct list_head sb_list;
};

struct thread_struct___132 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___132 debug;
	long: 64;
};

struct vmacache___315 {
	u64 seqnum;
	struct vm_area_struct___316 *vmas[4];
};

struct page_frag___315 {
	struct page___316 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___315;

struct pid___205;

struct cred___293;

struct nsproxy___254;

struct signal_struct___232;

struct css_set___211;

struct vm_struct___231;

struct task_struct___316 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___316 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___315 *mm;
	struct mm_struct___315 *active_mm;
	struct vmacache___315 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___316 *real_parent;
	struct task_struct___316 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___316 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___205 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___205 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___205 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___293 *ptracer_cred;
	const struct cred___293 *real_cred;
	const struct cred___293 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___254 *nsproxy;
	struct signal_struct___232 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___316 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___82 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___211 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___132 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___315 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___316 *oom_reaper_list;
	struct vm_struct___231 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___132 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rw_semaphore___316 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___316 *owner;
};

struct secondary_data___316 {
	void *stack;
	struct task_struct___316 *task;
	long int status;
};

struct blocking_notifier_head___315 {
	struct rw_semaphore___316 rwsem;
	struct notifier_block *head;
};

struct clk_notifier {
	struct clk *clk;
	struct srcu_notifier_head notifier_head;
	struct list_head node;
};

struct clk {
	struct clk_core *core;
	const char *dev_id;
	const char *con_id;
	long unsigned int min_rate;
	long unsigned int max_rate;
	unsigned int exclusive_count;
	struct hlist_node clks_node;
};

struct clk_notifier_data {
	struct clk *clk;
	long unsigned int old_rate;
	long unsigned int new_rate;
};

typedef struct page___316 *pgtable_t___315;

struct address_space___314;

struct dev_pagemap___304;

struct page___316 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___314 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___316 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___315 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___315 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___304 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct vm_operations_struct___304;

struct vm_area_struct___316 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___316 *vm_next;
	struct vm_area_struct___316 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___315 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___304 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___315 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___315;

struct user_namespace___226;

struct mm_struct___315 {
	struct {
		struct vm_area_struct___316 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___315 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___316 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___315 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___316 *owner;
		struct user_namespace___226 *user_ns;
		struct file___315 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___315 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___314;

struct address_space___314 {
	struct inode___315 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___316 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___314 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___304)(struct vm_area_struct___316 *, long unsigned int, const struct page___316 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___304)(struct page___316 *, void *);

struct device___281;

struct dev_pagemap___304 {
	dev_page_fault_t___304 page_fault;
	dev_page_free_t___304 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___281 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct dentry___314;

struct path___315 {
	struct vfsmount *mnt;
	struct dentry___314 *dentry;
};

struct fown_struct___205 {
	rwlock_t lock;
	struct pid___205 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___315 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___315 f_path;
	struct inode___315 *f_inode;
	const struct file_operations___315 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___205 f_owner;
	const struct cred___293 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___314 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___304;

struct vm_operations_struct___304 {
	void (*open)(struct vm_area_struct___316 *);
	void (*close)(struct vm_area_struct___316 *);
	int (*split)(struct vm_area_struct___316 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___316 *);
	vm_fault_t (*fault)(struct vm_fault___304 *);
	vm_fault_t (*huge_fault)(struct vm_fault___304 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___304 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___316 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___304 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___304 *);
	int (*access)(struct vm_area_struct___316 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___316 *);
	int (*set_policy)(struct vm_area_struct___316 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___316 *, long unsigned int);
	struct page___316 * (*find_special_page)(struct vm_area_struct___316 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___315 {
	struct task_struct___316 *task;
	struct core_thread___315 *next;
};

struct core_state___315 {
	atomic_t nr_threads;
	struct core_thread___315 dumper;
	struct completion startup;
};

struct key___293;

struct ucounts___226;

struct user_namespace___226 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___226 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___9 ns;
	long unsigned int flags;
	struct key___293 *persistent_keyring_register;
	struct rw_semaphore___316 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___226 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___304 {
	struct vm_area_struct___316 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___316 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___316 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___315 prealloc_pte;
};

struct upid___205 {
	int nr;
	struct pid_namespace___205 *ns;
};

struct pid_namespace___205 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___316 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___205 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___314 *proc_self;
	struct dentry___314 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___226 *user_ns;
	struct ucounts___226 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___9 ns;
};

struct pid___205 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___205 numbers[1];
};

struct user_struct___293 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___293 *uid_keyring;
	struct key___293 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___293 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___293 *session_keyring;
	struct key___293 *process_keyring;
	struct key___293 *thread_keyring;
	struct key___293 *request_key_auth;
	void *security;
	struct user_struct___293 *user;
	struct user_namespace___226 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___211;

struct nsproxy___254 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___205 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___211 *cgroup_ns;
};

struct signal_struct___232 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___316 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___316 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___205 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___205 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___315 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___205 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___211;

struct cgroup___211;

struct css_set___211 {
	struct cgroup_subsys_state___211 *subsys[13];
	refcount_t refcount;
	struct css_set___211 *dom_cset;
	struct cgroup___211 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___211 *mg_src_cgrp;
	struct cgroup___211 *mg_dst_cgrp;
	struct css_set___211 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___132 {
	struct pmu___132 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___316 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___132 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___231 {
	struct vm_struct___231 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___316 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___244 {
	struct task_struct___316 task;
	long unsigned int stack[8192];
};

struct fwnode_operations___215;

struct fwnode_handle___215 {
	struct fwnode_handle___215 *secondary;
	const struct fwnode_operations___215 *ops;
};

struct fwnode_reference_args___215;

struct fwnode_endpoint___215;

struct fwnode_operations___215 {
	struct fwnode_handle___215 * (*get)(struct fwnode_handle___215 *);
	void (*put)(struct fwnode_handle___215 *);
	bool (*device_is_available)(const struct fwnode_handle___215 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___215 *, const struct device___281 *);
	bool (*property_present)(const struct fwnode_handle___215 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___215 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___215 *, const char *, const char **, size_t);
	struct fwnode_handle___215 * (*get_parent)(const struct fwnode_handle___215 *);
	struct fwnode_handle___215 * (*get_next_child_node)(const struct fwnode_handle___215 *, struct fwnode_handle___215 *);
	struct fwnode_handle___215 * (*get_named_child_node)(const struct fwnode_handle___215 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___215 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___215 *);
	struct fwnode_handle___215 * (*graph_get_next_endpoint)(const struct fwnode_handle___215 *, struct fwnode_handle___215 *);
	struct fwnode_handle___215 * (*graph_get_remote_endpoint)(const struct fwnode_handle___215 *);
	struct fwnode_handle___215 * (*graph_get_port_parent)(struct fwnode_handle___215 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___215 *, struct fwnode_endpoint___215 *);
};

struct fwnode_endpoint___215 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___215 *local_fwnode;
};

struct fwnode_reference_args___215 {
	struct fwnode_handle___215 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct kset___301;

struct kobj_type___301;

struct kernfs_node___309;

struct kobject___302 {
	const char *name;
	struct list_head entry;
	struct kobject___302 *parent;
	struct kset___301 *kset;
	struct kobj_type___301 *ktype;
	struct kernfs_node___309 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___281 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___3 *subsys_data;
	void (*set_latency_tolerance)(struct device___281 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___281;

struct bus_type___281;

struct device_driver___281;

struct dev_pm_domain___281;

struct device_node___71;

struct class___281;

struct attribute_group___279;

struct device___281 {
	struct device___281 *parent;
	struct device_private *p;
	struct kobject___302 kobj;
	const char *init_name;
	const struct device_type___281 *type;
	struct mutex mutex;
	struct bus_type___281 *bus;
	struct device_driver___281 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___281 power;
	struct dev_pm_domain___281 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___71 *of_node;
	struct fwnode_handle___215 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___281 *class;
	const struct attribute_group___279 **groups;
	void (*release)(struct device___281 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct pglist_data___315;

struct lruvec___315 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___315 *pgdat;
};

struct zone___315 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___315 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___315 {
	struct zone___315 *zone;
	int zone_idx;
};

struct zonelist___315 {
	struct zoneref___315 _zonerefs[25];
};

struct pglist_data___315 {
	struct zone___315 node_zones[3];
	struct zonelist___315 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___316 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___316 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___315 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct kernfs_root___308;

struct kernfs_elem_dir___308 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___308 *root;
};

struct kernfs_syscall_ops___308;

struct kernfs_root___308 {
	struct kernfs_node___309 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___308 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___308 {
	struct kernfs_node___309 *target_kn;
};

struct kernfs_ops___308;

struct kernfs_elem_attr___308 {
	const struct kernfs_ops___308 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___309 *notify_next;
};

struct kernfs_node___309 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___309 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___308 dir;
		struct kernfs_elem_symlink___308 symlink;
		struct kernfs_elem_attr___308 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___308;

struct kernfs_ops___308 {
	int (*open)(struct kernfs_open_file___308 *);
	void (*release)(struct kernfs_open_file___308 *);
	int (*seq_show)(struct seq_file___267 *, void *);
	void * (*seq_start)(struct seq_file___267 *, loff_t *);
	void * (*seq_next)(struct seq_file___267 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___267 *, void *);
	ssize_t (*read)(struct kernfs_open_file___308 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___308 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___308 *, struct vm_area_struct___316 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___308 *, struct poll_table_struct___192 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___308 {
	int (*remount_fs)(struct kernfs_root___308 *, int *, char *);
	int (*show_options)(struct seq_file___267 *, struct kernfs_root___308 *);
	int (*mkdir)(struct kernfs_node___309 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___309 *);
	int (*rename)(struct kernfs_node___309 *, struct kernfs_node___309 *, const char *);
	int (*show_path)(struct seq_file___267 *, struct kernfs_node___309 *, struct kernfs_root___308 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___266;

struct seq_file___267 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___266 *op;
	int poll_event;
	const struct file___315 *file;
	void *private;
};

struct kernfs_open_file___308 {
	struct kernfs_node___309 *kn;
	struct file___315 *file;
	struct seq_file___267 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___304 *vm_ops;
};

typedef void (*poll_queue_proc___197)(struct file___315 *, wait_queue_head_t *, struct poll_table_struct___192 *);

struct poll_table_struct___192 {
	poll_queue_proc___197 _qproc;
	__poll_t _key;
};

struct bin_attribute___278;

struct attribute_group___279 {
	const char *name;
	umode_t (*is_visible)(struct kobject___302 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___302 *, struct bin_attribute___278 *, int);
	struct attribute **attrs;
	struct bin_attribute___278 **bin_attrs;
};

struct bin_attribute___278 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___315 *, struct kobject___302 *, struct bin_attribute___278 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___315 *, struct kobject___302 *, struct bin_attribute___278 *, char *, loff_t, size_t);
	int (*mmap)(struct file___315 *, struct kobject___302 *, struct bin_attribute___278 *, struct vm_area_struct___316 *);
};

struct sysfs_ops___301 {
	ssize_t (*show)(struct kobject___302 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___302 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___301;

struct kset___301 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___302 kobj;
	const struct kset_uevent_ops___301 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___301 {
	void (*release)(struct kobject___302 *);
	const struct sysfs_ops___301 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___25 * (*child_ns_type)(struct kobject___302 *);
	const void * (*namespace)(struct kobject___302 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___301 {
	int (* const filter)(struct kset___301 *, struct kobject___302 *);
	const char * (* const name)(struct kset___301 *, struct kobject___302 *);
	int (* const uevent)(struct kset___301 *, struct kobject___302 *, struct kobj_uevent_env *);
};

struct kobj_attribute___294 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___302 *, struct kobj_attribute___294 *, char *);
	ssize_t (*store)(struct kobject___302 *, struct kobj_attribute___294 *, const char *, size_t);
};

struct property___67 {
	char *name;
	int length;
	void *value;
	struct property___67 *next;
	long unsigned int _flags;
	struct bin_attribute___278 attr;
};

struct device_node___71 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___215 fwnode;
	struct property___67 *properties;
	struct property___67 *deadprops;
	struct device_node___71 *parent;
	struct device_node___71 *child;
	struct device_node___71 *sibling;
	struct kobject___302 kobj;
	long unsigned int _flags;
	void *data;
};

struct of_phandle_args___11 {
	struct device_node___71 *np;
	int args_count;
	uint32_t args[16];
};

struct clk_hw___5;

struct clk_rate_request___5 {
	long unsigned int rate;
	long unsigned int min_rate;
	long unsigned int max_rate;
	long unsigned int best_parent_rate;
	struct clk_hw___5 *best_parent_hw;
};

struct clk_init_data___5;

struct clk_hw___5 {
	struct clk_core *core;
	struct clk *clk;
	const struct clk_init_data___5 *init;
};

struct clk_ops___5 {
	int (*prepare)(struct clk_hw___5 *);
	void (*unprepare)(struct clk_hw___5 *);
	int (*is_prepared)(struct clk_hw___5 *);
	void (*unprepare_unused)(struct clk_hw___5 *);
	int (*enable)(struct clk_hw___5 *);
	void (*disable)(struct clk_hw___5 *);
	int (*is_enabled)(struct clk_hw___5 *);
	void (*disable_unused)(struct clk_hw___5 *);
	long unsigned int (*recalc_rate)(struct clk_hw___5 *, long unsigned int);
	long int (*round_rate)(struct clk_hw___5 *, long unsigned int, long unsigned int *);
	int (*determine_rate)(struct clk_hw___5 *, struct clk_rate_request___5 *);
	int (*set_parent)(struct clk_hw___5 *, u8);
	u8 (*get_parent)(struct clk_hw___5 *);
	int (*set_rate)(struct clk_hw___5 *, long unsigned int, long unsigned int);
	int (*set_rate_and_parent)(struct clk_hw___5 *, long unsigned int, long unsigned int, u8);
	long unsigned int (*recalc_accuracy)(struct clk_hw___5 *, long unsigned int);
	int (*get_phase)(struct clk_hw___5 *);
	int (*set_phase)(struct clk_hw___5 *, int);
	void (*init)(struct clk_hw___5 *);
	void (*debug_init)(struct clk_hw___5 *, struct dentry___314 *);
};

struct dentry_operations___314;

struct super_block___314;

struct dentry___314 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___314 *d_parent;
	struct qstr d_name;
	struct inode___315 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___314 *d_op;
	struct super_block___314 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct clk_init_data___5 {
	const char *name;
	const struct clk_ops___5 *ops;
	const char * const *parent_names;
	u8 num_parents;
	long unsigned int flags;
};

struct clk_core {
	const char *name;
	const struct clk_ops___5 *ops;
	struct clk_hw___5 *hw;
	struct module___255 *owner;
	struct device___281 *dev;
	struct clk_core *parent;
	const char **parent_names;
	struct clk_core **parents;
	u8 num_parents;
	u8 new_parent_index;
	long unsigned int rate;
	long unsigned int req_rate;
	long unsigned int new_rate;
	struct clk_core *new_parent;
	struct clk_core *new_child;
	long unsigned int flags;
	bool orphan;
	unsigned int enable_count;
	unsigned int prepare_count;
	unsigned int protect_count;
	long unsigned int min_rate;
	long unsigned int max_rate;
	long unsigned int accuracy;
	int phase;
	struct hlist_head children;
	struct hlist_node child_node;
	struct hlist_head clks;
	unsigned int notifier_count;
	struct dentry___314 *dentry;
	struct hlist_node debug_node;
	struct kref ref;
};

struct clk_onecell_data {
	struct clk **clks;
	unsigned int clk_num;
};

struct clk_hw_onecell_data {
	unsigned int num;
	struct clk_hw___5 *hws[0];
};

struct kernel_param___252;

struct kernel_param_ops___252 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___252 *);
	int (*get)(char *, const struct kernel_param___252 *);
	void (*free)(void *);
};

struct kparam_array___252;

struct kernel_param___252 {
	const char *name;
	struct module___255 *mod;
	const struct kernel_param_ops___252 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___252 *arr;
	};
};

struct kparam_array___252 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___252 *ops;
	void *elem;
};

struct module_kobject___252 {
	struct kobject___302 kobj;
	struct module___255 *mod;
	struct kobject___302 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___252 {
	struct module___255 *mod;
	struct latch_tree_node node;
};

struct module_layout___252 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___252 mtn;
};

struct module_attribute___252;

struct module___255 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___252 mkobj;
	struct module_attribute___252 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___302 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___252 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___252 core_layout;
	struct module_layout___252 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___125 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___252 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___252 *, struct module_kobject___252 *, char *);
	ssize_t (*store)(struct module_attribute___252 *, struct module_kobject___252 *, const char *, size_t);
	void (*setup)(struct module___255 *, const char *);
	int (*test)(struct module___255 *);
	void (*free)(struct module___255 *);
};

struct trace_event_class___125;

struct trace_event_call___125 {
	struct list_head list;
	struct trace_event_class___125 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___13 event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___35 *prog_array;
	int (*perf_perm)(struct trace_event_call___125 *, struct perf_event___132 *);
};

struct dev_pm_ops___281 {
	int (*prepare)(struct device___281 *);
	void (*complete)(struct device___281 *);
	int (*suspend)(struct device___281 *);
	int (*resume)(struct device___281 *);
	int (*freeze)(struct device___281 *);
	int (*thaw)(struct device___281 *);
	int (*poweroff)(struct device___281 *);
	int (*restore)(struct device___281 *);
	int (*suspend_late)(struct device___281 *);
	int (*resume_early)(struct device___281 *);
	int (*freeze_late)(struct device___281 *);
	int (*thaw_early)(struct device___281 *);
	int (*poweroff_late)(struct device___281 *);
	int (*restore_early)(struct device___281 *);
	int (*suspend_noirq)(struct device___281 *);
	int (*resume_noirq)(struct device___281 *);
	int (*freeze_noirq)(struct device___281 *);
	int (*thaw_noirq)(struct device___281 *);
	int (*poweroff_noirq)(struct device___281 *);
	int (*restore_noirq)(struct device___281 *);
	int (*runtime_suspend)(struct device___281 *);
	int (*runtime_resume)(struct device___281 *);
	int (*runtime_idle)(struct device___281 *);
};

struct dev_pm_domain___281 {
	struct dev_pm_ops___281 ops;
	void (*detach)(struct device___281 *, bool);
	int (*activate)(struct device___281 *);
	void (*sync)(struct device___281 *);
	void (*dismiss)(struct device___281 *);
};

struct bus_type___281 {
	const char *name;
	const char *dev_name;
	struct device___281 *dev_root;
	const struct attribute_group___279 **bus_groups;
	const struct attribute_group___279 **dev_groups;
	const struct attribute_group___279 **drv_groups;
	int (*match)(struct device___281 *, struct device_driver___281 *);
	int (*uevent)(struct device___281 *, struct kobj_uevent_env *);
	int (*probe)(struct device___281 *);
	int (*remove)(struct device___281 *);
	void (*shutdown)(struct device___281 *);
	int (*online)(struct device___281 *);
	int (*offline)(struct device___281 *);
	int (*suspend)(struct device___281 *, pm_message_t);
	int (*resume)(struct device___281 *);
	int (*num_vf)(struct device___281 *);
	int (*dma_configure)(struct device___281 *);
	const struct dev_pm_ops___281 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___281 {
	const char *name;
	struct bus_type___281 *bus;
	struct module___255 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___281 *);
	int (*remove)(struct device___281 *);
	void (*shutdown)(struct device___281 *);
	int (*suspend)(struct device___281 *, pm_message_t);
	int (*resume)(struct device___281 *);
	const struct attribute_group___279 **groups;
	const struct dev_pm_ops___281 *pm;
	void (*coredump)(struct device___281 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___281 {
	const char *name;
	const struct attribute_group___279 **groups;
	int (*uevent)(struct device___281 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___281 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___281 *);
	const struct dev_pm_ops___281 *pm;
};

struct class___281 {
	const char *name;
	struct module___255 *owner;
	const struct attribute_group___279 **class_groups;
	const struct attribute_group___279 **dev_groups;
	struct kobject___302 *dev_kobj;
	int (*dev_uevent)(struct device___281 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___281 *, umode_t *);
	void (*class_release)(struct class___281 *);
	void (*dev_release)(struct device___281 *);
	int (*shutdown_pre)(struct device___281 *);
	const struct kobj_ns_type_operations___25 *ns_type;
	const void * (*namespace)(struct device___281 *);
	const struct dev_pm_ops___281 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

typedef void (*dr_release_t___14)(struct device___281 *, void *);

struct inode_operations___314;

struct block_device___314;

struct inode___315 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___314 *i_op;
	struct super_block___314 *i_sb;
	struct address_space___314 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___316 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___315 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___314 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___314 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___314 {
	int (*d_revalidate)(struct dentry___314 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___314 *, unsigned int);
	int (*d_hash)(const struct dentry___314 *, struct qstr *);
	int (*d_compare)(const struct dentry___314 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___314 *);
	int (*d_init)(struct dentry___314 *);
	void (*d_release)(struct dentry___314 *);
	void (*d_prune)(struct dentry___314 *);
	void (*d_iput)(struct dentry___314 *, struct inode___315 *);
	char * (*d_dname)(struct dentry___314 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___315 *);
	int (*d_manage)(const struct path___315 *, bool);
	struct dentry___314 * (*d_real)(struct dentry___314 *, const struct inode___315 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___314;

struct mem_dqinfo___314 {
	struct quota_format_type___314 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___314;

struct quota_info___314 {
	unsigned int flags;
	struct rw_semaphore___316 dqio_sem;
	struct inode___315 *files[3];
	struct mem_dqinfo___314 info[3];
	const struct quota_format_ops___314 *ops[3];
};

struct rcuwait___314 {
	struct task_struct___316 *task;
};

struct percpu_rw_semaphore___314 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___316 rw_sem;
	struct rcuwait___314 writer;
	int readers_block;
};

struct sb_writers___314 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___314 rw_sem[3];
};

struct file_system_type___314;

struct super_operations___314;

struct dquot_operations___314;

struct quotactl_ops___314;

struct super_block___314 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___314 *s_type;
	const struct super_operations___314 *s_op;
	const struct dquot_operations___314 *dq_op;
	const struct quotactl_ops___314 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___314 *s_root;
	struct rw_semaphore___316 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___314 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___314 s_dquot;
	struct sb_writers___314 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___314 *s_d_op;
	int cleancache_poolid;
	struct shrinker___119 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___226 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___315 {
	struct file___315 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___315 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___314 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___315 *ia_file;
};

struct dquot___314 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___314 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___314 {
	int qf_fmt_id;
	const struct quota_format_ops___314 *qf_ops;
	struct module___255 *qf_owner;
	struct quota_format_type___314 *qf_next;
};

struct quota_format_ops___314 {
	int (*check_quota_file)(struct super_block___314 *, int);
	int (*read_file_info)(struct super_block___314 *, int);
	int (*write_file_info)(struct super_block___314 *, int);
	int (*free_file_info)(struct super_block___314 *, int);
	int (*read_dqblk)(struct dquot___314 *);
	int (*commit_dqblk)(struct dquot___314 *);
	int (*release_dqblk)(struct dquot___314 *);
	int (*get_next_id)(struct super_block___314 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___314 {
	int (*write_dquot)(struct dquot___314 *);
	struct dquot___314 * (*alloc_dquot)(struct super_block___314 *, int);
	void (*destroy_dquot)(struct dquot___314 *);
	int (*acquire_dquot)(struct dquot___314 *);
	int (*release_dquot)(struct dquot___314 *);
	int (*mark_dirty)(struct dquot___314 *);
	int (*write_info)(struct super_block___314 *, int);
	qsize_t * (*get_reserved_space)(struct inode___315 *);
	int (*get_projid)(struct inode___315 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___315 *, qsize_t *);
	int (*get_next_id)(struct super_block___314 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___314 {
	int (*quota_on)(struct super_block___314 *, int, int, const struct path___315 *);
	int (*quota_off)(struct super_block___314 *, int);
	int (*quota_enable)(struct super_block___314 *, unsigned int);
	int (*quota_disable)(struct super_block___314 *, unsigned int);
	int (*quota_sync)(struct super_block___314 *, int);
	int (*set_info)(struct super_block___314 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___314 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___314 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___314 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___314 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___314 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___314 {
	int (*writepage)(struct page___316 *, struct writeback_control___3 *);
	int (*readpage)(struct file___315 *, struct page___316 *);
	int (*writepages)(struct address_space___314 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___316 *);
	int (*readpages)(struct file___315 *, struct address_space___314 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___315 *, struct address_space___314 *, loff_t, unsigned int, unsigned int, struct page___316 **, void **);
	int (*write_end)(struct file___315 *, struct address_space___314 *, loff_t, unsigned int, unsigned int, struct page___316 *, void *);
	sector_t (*bmap)(struct address_space___314 *, sector_t);
	void (*invalidatepage)(struct page___316 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___316 *, gfp_t);
	void (*freepage)(struct page___316 *);
	ssize_t (*direct_IO)(struct kiocb___315 *, struct iov_iter___138 *);
	int (*migratepage)(struct address_space___314 *, struct page___316 *, struct page___316 *, enum migrate_mode);
	bool (*isolate_page)(struct page___316 *, isolate_mode_t);
	void (*putback_page)(struct page___316 *);
	int (*launder_page)(struct page___316 *);
	int (*is_partially_uptodate)(struct page___316 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___316 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___314 *, struct page___316 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___315 *, sector_t *);
	void (*swap_deactivate)(struct file___315 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___314 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___315 *bd_inode;
	struct super_block___314 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___314 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___314 {
	struct dentry___314 * (*lookup)(struct inode___315 *, struct dentry___314 *, unsigned int);
	const char * (*get_link)(struct dentry___314 *, struct inode___315 *, struct delayed_call *);
	int (*permission)(struct inode___315 *, int);
	struct posix_acl * (*get_acl)(struct inode___315 *, int);
	int (*readlink)(struct dentry___314 *, char *, int);
	int (*create)(struct inode___315 *, struct dentry___314 *, umode_t, bool);
	int (*link)(struct dentry___314 *, struct inode___315 *, struct dentry___314 *);
	int (*unlink)(struct inode___315 *, struct dentry___314 *);
	int (*symlink)(struct inode___315 *, struct dentry___314 *, const char *);
	int (*mkdir)(struct inode___315 *, struct dentry___314 *, umode_t);
	int (*rmdir)(struct inode___315 *, struct dentry___314 *);
	int (*mknod)(struct inode___315 *, struct dentry___314 *, umode_t, dev_t);
	int (*rename)(struct inode___315 *, struct dentry___314 *, struct inode___315 *, struct dentry___314 *, unsigned int);
	int (*setattr)(struct dentry___314 *, struct iattr___314 *);
	int (*getattr)(const struct path___315 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___314 *, char *, size_t);
	int (*fiemap)(struct inode___315 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___315 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___315 *, struct dentry___314 *, struct file___315 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___315 *, struct dentry___314 *, umode_t);
	int (*set_acl)(struct inode___315 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___314 {
	void (*fl_copy_lock)(struct file_lock___315 *, struct file_lock___315 *);
	void (*fl_release_private)(struct file_lock___315 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___314;

struct file_lock___315 {
	struct file_lock___315 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___315 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___314 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___314 *fl_ops;
	const struct lock_manager_operations___314 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___314 {
	int (*lm_compare_owner)(struct file_lock___315 *, struct file_lock___315 *);
	long unsigned int (*lm_owner_key)(struct file_lock___315 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___315 *);
	int (*lm_grant)(struct file_lock___315 *, int);
	bool (*lm_break)(struct file_lock___315 *);
	int (*lm_change)(struct file_lock___315 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___315 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___314 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___314 *fa_next;
	struct file___315 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___314 {
	const char *name;
	int fs_flags;
	struct dentry___314 * (*mount)(struct file_system_type___314 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___314 *);
	struct module___255 *owner;
	struct file_system_type___314 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___314 {
	struct inode___315 * (*alloc_inode)(struct super_block___314 *);
	void (*destroy_inode)(struct inode___315 *);
	void (*dirty_inode)(struct inode___315 *, int);
	int (*write_inode)(struct inode___315 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___315 *);
	void (*evict_inode)(struct inode___315 *);
	void (*put_super)(struct super_block___314 *);
	int (*sync_fs)(struct super_block___314 *, int);
	int (*freeze_super)(struct super_block___314 *);
	int (*freeze_fs)(struct super_block___314 *);
	int (*thaw_super)(struct super_block___314 *);
	int (*unfreeze_fs)(struct super_block___314 *);
	int (*statfs)(struct dentry___314 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___314 *, int *, char *);
	void (*umount_begin)(struct super_block___314 *);
	int (*show_options)(struct seq_file___267 *, struct dentry___314 *);
	int (*show_devname)(struct seq_file___267 *, struct dentry___314 *);
	int (*show_path)(struct seq_file___267 *, struct dentry___314 *);
	int (*show_stats)(struct seq_file___267 *, struct dentry___314 *);
	ssize_t (*quota_read)(struct super_block___314 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___314 *, int, const char *, size_t, loff_t);
	struct dquot___314 ** (*get_dquots)(struct inode___315 *);
	int (*bdev_try_to_free_page)(struct super_block___314 *, struct page___316 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___314 *, struct shrink_control___119 *);
	long int (*free_cached_objects)(struct super_block___314 *, struct shrink_control___119 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___304(struct page___316 *);

typedef int (*key_restrict_link_func_t___294)(struct key___293 *, const struct key_type *, const union key_payload *, struct key___293 *);

struct key_restriction___293;

struct key___293 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___316 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___293 *restrict_link;
};

struct key_restriction___293 {
	key_restrict_link_func_t___294 check;
	struct key___293 *key;
	struct key_type *keytype;
};

struct seq_operations___266 {
	void * (*start)(struct seq_file___267 *, loff_t *);
	void (*stop)(struct seq_file___267 *, void *);
	void * (*next)(struct seq_file___267 *, void *, loff_t *);
	int (*show)(struct seq_file___267 *, void *);
};

struct cgroup_namespace___211 {
	refcount_t count;
	struct ns_common___9 ns;
	struct user_namespace___226 *user_ns;
	struct ucounts___226 *ucounts;
	struct css_set___211 *root_cset;
};

struct ucounts___226 {
	struct hlist_node node;
	struct user_namespace___226 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct node___187 {
	struct device___281 dev;
};

struct bpf_map___212;

struct bpf_map_ops___211 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___212 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___212 *, struct file___315 *);
	void (*map_free)(struct bpf_map___212 *);
	int (*map_get_next_key)(struct bpf_map___212 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___212 *);
	void * (*map_lookup_elem)(struct bpf_map___212 *, void *);
	int (*map_update_elem)(struct bpf_map___212 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___212 *, void *);
	int (*map_push_elem)(struct bpf_map___212 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___212 *, void *);
	int (*map_peek_elem)(struct bpf_map___212 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___212 *, struct file___315 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___212 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___212 *, void *, struct seq_file___267 *);
	int (*map_check_btf)(const struct bpf_map___212 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___212 {
	const struct bpf_map_ops___211 *ops;
	struct bpf_map___212 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___293 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___211;

typedef void (*kthread_work_func_t___211)(struct kthread_work___211 *);

struct kthread_worker___211;

struct kthread_work___211 {
	struct list_head node;
	kthread_work_func_t___211 func;
	struct kthread_worker___211 *worker;
	int canceling;
};

struct kthread_worker___211 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___316 *task;
	struct kthread_work___211 *current_work;
};

struct kthread_delayed_work___211 {
	struct kthread_work___211 work;
	struct timer_list timer;
};

struct psi_group___211 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___211 *poll_kworker;
	struct kthread_delayed_work___211 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___211 {
	struct kernfs_node___309 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___211;

struct cgroup_subsys_state___211 {
	struct cgroup___211 *cgroup;
	struct cgroup_subsys___211 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___211 *parent;
};

struct cgroup_root___211;

struct cgroup_rstat_cpu___211;

struct cgroup___211 {
	struct cgroup_subsys_state___211 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___309 *kn;
	struct cgroup_file___211 procs_file;
	struct cgroup_file___211 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___211 *subsys[13];
	struct cgroup_root___211 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___211 *dom_cgrp;
	struct cgroup_rstat_cpu___211 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___35 bpf;
	atomic_t congestion_count;
	struct cgroup___211 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___211 psi;
	int ancestor_ids[0];
};

struct cftype___211;

struct cgroup_subsys___211 {
	struct cgroup_subsys_state___211 * (*css_alloc)(struct cgroup_subsys_state___211 *);
	int (*css_online)(struct cgroup_subsys_state___211 *);
	void (*css_offline)(struct cgroup_subsys_state___211 *);
	void (*css_released)(struct cgroup_subsys_state___211 *);
	void (*css_free)(struct cgroup_subsys_state___211 *);
	void (*css_reset)(struct cgroup_subsys_state___211 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___211 *, int);
	int (*css_extra_stat_show)(struct seq_file___267 *, struct cgroup_subsys_state___211 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___316 *);
	void (*cancel_fork)(struct task_struct___316 *);
	void (*fork)(struct task_struct___316 *);
	void (*exit)(struct task_struct___316 *);
	void (*free)(struct task_struct___316 *);
	void (*bind)(struct cgroup_subsys_state___211 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___211 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___211 *dfl_cftypes;
	struct cftype___211 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___211 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___211 *updated_children;
	struct cgroup___211 *updated_next;
};

struct cgroup_root___211 {
	struct kernfs_root___308 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___211 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___211 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___211 *ss;
	struct list_head node;
	struct kernfs_ops___308 *kf_ops;
	int (*open)(struct kernfs_open_file___308 *);
	void (*release)(struct kernfs_open_file___308 *);
	u64 (*read_u64)(struct cgroup_subsys_state___211 *, struct cftype___211 *);
	s64 (*read_s64)(struct cgroup_subsys_state___211 *, struct cftype___211 *);
	int (*seq_show)(struct seq_file___267 *, void *);
	void * (*seq_start)(struct seq_file___267 *, loff_t *);
	void * (*seq_next)(struct seq_file___267 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___267 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___211 *, struct cftype___211 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___211 *, struct cftype___211 *, s64);
	ssize_t (*write)(struct kernfs_open_file___308 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___308 *, struct poll_table_struct___192 *);
};

struct perf_cpu_context___132;

struct pmu___132 {
	struct list_head entry;
	struct module___255 *module;
	struct device___281 *dev;
	const struct attribute_group___279 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___132 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___132 *);
	void (*pmu_disable)(struct pmu___132 *);
	int (*event_init)(struct perf_event___132 *);
	void (*event_mapped)(struct perf_event___132 *, struct mm_struct___315 *);
	void (*event_unmapped)(struct perf_event___132 *, struct mm_struct___315 *);
	int (*add)(struct perf_event___132 *, int);
	void (*del)(struct perf_event___132 *, int);
	void (*start)(struct perf_event___132 *, int);
	void (*stop)(struct perf_event___132 *, int);
	void (*read)(struct perf_event___132 *);
	void (*start_txn)(struct pmu___132 *, unsigned int);
	int (*commit_txn)(struct pmu___132 *);
	void (*cancel_txn)(struct pmu___132 *);
	int (*event_idx)(struct perf_event___132 *);
	void (*sched_task)(struct perf_event_context___132 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___132 *);
	int (*filter_match)(struct perf_event___132 *);
	int (*check_period)(struct perf_event___132 *, u64);
};

struct perf_cpu_context___132 {
	struct perf_event_context___132 ctx;
	struct perf_event_context___132 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___132 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___132 {
	struct cgroup_subsys_state___211 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___125 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___125 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___125 *);
	struct list_head * (*get_fields)(struct trace_event_call___125 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___125 *);
};

struct trace_event_file___49;

struct trace_event_buffer___41 {
	struct ring_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___49 *trace_file;
	void *entry;
	long unsigned int flags;
	int pc;
};

struct trace_event_file___49 {
	struct list_head list;
	struct trace_event_call___125 *event_call;
	struct event_filter *filter;
	struct dentry___314 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_clk {
	struct trace_entry ent;
	u32 __data_loc_name;
	char __data[0];
};

struct trace_event_raw_clk_rate {
	struct trace_entry ent;
	u32 __data_loc_name;
	long unsigned int rate;
	char __data[0];
};

struct trace_event_raw_clk_parent {
	struct trace_entry ent;
	u32 __data_loc_name;
	u32 __data_loc_pname;
	char __data[0];
};

struct trace_event_raw_clk_phase {
	struct trace_entry ent;
	u32 __data_loc_name;
	int phase;
	char __data[0];
};

struct trace_event_data_offsets_clk {
	u32 name;
};

struct trace_event_data_offsets_clk_rate {
	u32 name;
};

struct trace_event_data_offsets_clk_parent {
	u32 name;
	u32 pname;
};

struct trace_event_data_offsets_clk_phase {
	u32 name;
};

struct of_clk_provider {
	struct list_head link;
	struct device_node___71 *node;
	struct clk * (*get)(struct of_phandle_args___11 *, void *);
	struct clk_hw___5 * (*get_hw)(struct of_phandle_args___11 *, void *);
	void *data;
};

struct clock_provider {
	void (*clk_init_cb)(struct device_node___71 *);
	struct device_node___71 *np;
	struct list_head node;
};

struct clk_div_table {
	unsigned int val;
	unsigned int div;
};

struct clk_divider {
	struct clk_hw___5 hw;
	void *reg;
	u8 shift;
	u8 width;
	u8 flags;
	const struct clk_div_table *table;
	spinlock_t *lock;
};

typedef void (*of_init_fn_1)(struct device_node___70 *);

struct clk_fixed_factor {
	struct clk_hw___5 hw;
	unsigned int mult;
	unsigned int div;
};

typedef void (*of_init_fn_1___2)(struct device_node___71 *);

struct clk_fixed_rate {
	struct clk_hw___5 hw;
	long unsigned int fixed_rate;
	long unsigned int fixed_accuracy;
	u8 flags;
};

struct clk_gate {
	struct clk_hw___5 hw;
	void *reg;
	u8 bit_idx;
	u8 flags;
	spinlock_t *lock;
};

struct clk_multiplier {
	struct clk_hw___5 hw;
	void *reg;
	u8 shift;
	u8 width;
	u8 flags;
	spinlock_t *lock;
};

struct clk_mux {
	struct clk_hw___5 hw;
	void *reg;
	u32 *table;
	u32 mask;
	u8 shift;
	u8 flags;
	spinlock_t *lock;
};

struct clk_composite {
	struct clk_hw___5 hw;
	struct clk_ops___5 ops;
	struct clk_hw___5 *mux_hw;
	struct clk_hw___5 *rate_hw;
	struct clk_hw___5 *gate_hw;
	const struct clk_ops___5 *mux_ops;
	const struct clk_ops___5 *rate_ops;
	const struct clk_ops___5 *gate_ops;
};

struct clk_fractional_divider {
	struct clk_hw___5 hw;
	void *reg;
	u8 mshift;
	u8 mwidth;
	u32 mmask;
	u8 nshift;
	u8 nwidth;
	u32 nmask;
	u8 flags;
	void (*approximation)(struct clk_hw___5 *, long unsigned int, long unsigned int *, long unsigned int *, long unsigned int *);
	spinlock_t *lock;
};

struct clk_gpio {
	struct clk_hw___5 hw;
	struct gpio_desc *gpiod;
};

enum xgene_pll_type {
	PLL_TYPE_PCP = 0,
	PLL_TYPE_SOC = 1,
};

struct xgene_clk_pll {
	struct clk_hw___5 hw;
	void *reg;
	spinlock_t *lock;
	u32 pll_offset;
	enum xgene_pll_type type;
	int version;
};

struct xgene_clk_pmd {
	struct clk_hw___5 hw;
	void *reg;
	u8 shift;
	u32 mask;
	u64 denom;
	u32 flags;
	spinlock_t *lock;
};

struct xgene_dev_parameters {
	void *csr_reg;
	u32 reg_clk_offset;
	u32 reg_clk_mask;
	u32 reg_csr_offset;
	u32 reg_csr_mask;
	void *divider_reg;
	u32 reg_divider_offset;
	u32 reg_divider_shift;
	u32 reg_divider_width;
};

struct xgene_clk {
	struct clk_hw___5 hw;
	spinlock_t *lock;
	struct xgene_dev_parameters param;
};

enum iproc_arm_pll_fid {
	ARM_PLL_FID_CRYSTAL_CLK = 0,
	ARM_PLL_FID_SYS_CLK = 2,
	ARM_PLL_FID_CH0_SLOW_CLK = 6,
	ARM_PLL_FID_CH1_FAST_CLK = 7,
};

struct iproc_arm_pll {
	struct clk_hw___5 hw;
	void *base;
	long unsigned int rate;
};

struct iproc_pll_vco_param {
	long unsigned int rate;
	unsigned int ndiv_int;
	unsigned int ndiv_frac;
	unsigned int pdiv;
};

struct iproc_clk_reg_op {
	unsigned int offset;
	unsigned int shift;
	unsigned int width;
};

struct iproc_asiu_gate {
	unsigned int offset;
	unsigned int en_shift;
};

struct iproc_pll_aon_pwr_ctrl {
	unsigned int offset;
	unsigned int pwr_width;
	unsigned int pwr_shift;
	unsigned int iso_shift;
};

struct iproc_pll_reset_ctrl {
	unsigned int offset;
	unsigned int reset_shift;
	unsigned int p_reset_shift;
};

struct iproc_pll_dig_filter_ctrl {
	unsigned int offset;
	unsigned int ki_shift;
	unsigned int ki_width;
	unsigned int kp_shift;
	unsigned int kp_width;
	unsigned int ka_shift;
	unsigned int ka_width;
};

struct iproc_pll_sw_ctrl {
	unsigned int offset;
	unsigned int shift;
};

struct iproc_pll_vco_ctrl {
	unsigned int u_offset;
	unsigned int l_offset;
};

struct iproc_pll_ctrl {
	long unsigned int flags;
	struct iproc_pll_aon_pwr_ctrl aon;
	struct iproc_asiu_gate asiu;
	struct iproc_pll_reset_ctrl reset;
	struct iproc_pll_dig_filter_ctrl dig_filter;
	struct iproc_pll_sw_ctrl sw_ctrl;
	struct iproc_clk_reg_op ndiv_int;
	struct iproc_clk_reg_op ndiv_frac;
	struct iproc_clk_reg_op pdiv;
	struct iproc_pll_vco_ctrl vco_ctrl;
	struct iproc_clk_reg_op status;
	struct iproc_clk_reg_op macro_mode;
};

struct iproc_clk_enable_ctrl {
	unsigned int offset;
	unsigned int enable_shift;
	unsigned int hold_shift;
	unsigned int bypass_shift;
};

struct iproc_clk_ctrl {
	unsigned int channel;
	long unsigned int flags;
	struct iproc_clk_enable_ctrl enable;
	struct iproc_clk_reg_op mdiv;
};

enum kp_band {
	KP_BAND_MID = 0,
	KP_BAND_HIGH = 1,
	KP_BAND_HIGH_HIGH = 2,
};

enum vco_freq_range {
	VCO_LOW = 700000000,
	VCO_MID = 1200000000,
	VCO_HIGH = 2200000000,
	VCO_HIGH_HIGH = 3100000000,
	VCO_MAX = 4000000000,
};

struct iproc_pll {
	void *status_base;
	void *control_base;
	void *pwr_base;
	void *asiu_base;
	const struct iproc_pll_ctrl *ctrl;
	const struct iproc_pll_vco_param *vco_param;
	unsigned int num_vco_entries;
};

struct iproc_clk {
	struct clk_hw___5 hw;
	struct iproc_pll *pll;
	const struct iproc_clk_ctrl *ctrl;
};

struct iproc_asiu_div {
	unsigned int offset;
	unsigned int en_shift;
	unsigned int high_shift;
	unsigned int high_width;
	unsigned int low_shift;
	unsigned int low_width;
};

struct iproc_asiu;

struct iproc_asiu_clk {
	struct clk_hw___5 hw;
	const char *name;
	struct iproc_asiu *asiu;
	long unsigned int rate;
	struct iproc_asiu_div div;
	struct iproc_asiu_gate gate;
};

struct iproc_asiu {
	void *div_base;
	void *gate_base;
	struct clk_hw_onecell_data *clk_data;
	struct iproc_asiu_clk *clks;
};

struct hisi_clock_data {
	struct clk_onecell_data clk_data;
	void *base;
};

struct hisi_fixed_rate_clock {
	unsigned int id;
	char *name;
	const char *parent_name;
	long unsigned int flags;
	long unsigned int fixed_rate;
};

struct hisi_fixed_factor_clock {
	unsigned int id;
	char *name;
	const char *parent_name;
	long unsigned int mult;
	long unsigned int div;
	long unsigned int flags;
};

struct hisi_mux_clock {
	unsigned int id;
	const char *name;
	const char * const *parent_names;
	u8 num_parents;
	long unsigned int flags;
	long unsigned int offset;
	u8 shift;
	u8 width;
	u8 mux_flags;
	u32 *table;
	const char *alias;
};

struct hisi_phase_clock {
	unsigned int id;
	const char *name;
	const char *parent_names;
	long unsigned int flags;
	long unsigned int offset;
	u8 shift;
	u8 width;
	u32 *phase_degrees;
	u32 *phase_regvals;
	u8 phase_num;
};

struct hisi_divider_clock {
	unsigned int id;
	const char *name;
	const char *parent_name;
	long unsigned int flags;
	long unsigned int offset;
	u8 shift;
	u8 width;
	u8 div_flags;
	struct clk_div_table *table;
	const char *alias;
};

struct hi6220_divider_clock {
	unsigned int id;
	const char *name;
	const char *parent_name;
	long unsigned int flags;
	long unsigned int offset;
	u8 shift;
	u8 width;
	u32 mask_bit;
	const char *alias;
};

struct hisi_gate_clock {
	unsigned int id;
	const char *name;
	const char *parent_name;
	long unsigned int flags;
	long unsigned int offset;
	u8 bit_idx;
	u8 gate_flags;
	const char *alias;
};

struct clkgate_separated {
	struct clk_hw___5 hw;
	void *enable;
	u8 bit_idx;
	u8 flags;
	spinlock_t *lock;
};

struct hi6220_clk_divider {
	struct clk_hw___5 hw;
	void *reg;
	u8 shift;
	u8 width;
	u32 mask;
	const struct clk_div_table *table;
	spinlock_t *lock;
};

struct clk_hisi_phase {
	struct clk_hw___5 hw;
	void *reg;
	u32 *phase_degrees;
	u32 *phase_regvals;
	u8 phase_num;
	u32 mask;
	u8 shift;
	u8 flags;
	spinlock_t *lock;
};

struct hisi_crg_funcs {
	struct hisi_clock_data * (*register_clks)(struct platform_device___14 *);
	void (*unregister_clks)(struct platform_device___14 *);
};

struct hisi_reset_controller;

struct hisi_crg_dev {
	struct hisi_clock_data *clk_data;
	struct hisi_reset_controller *rstc;
	const struct hisi_crg_funcs *funcs;
};

struct hi3519_crg_data {
	struct hisi_clock_data *clk_data;
	struct hisi_reset_controller *rstc;
};

struct reset_controller_dev;

struct reset_control_ops {
	int (*reset)(struct reset_controller_dev *, long unsigned int);
	int (*assert)(struct reset_controller_dev *, long unsigned int);
	int (*deassert)(struct reset_controller_dev *, long unsigned int);
	int (*status)(struct reset_controller_dev *, long unsigned int);
};

struct reset_controller_dev {
	const struct reset_control_ops *ops;
	struct module___11 *owner;
	struct list_head list;
	struct list_head reset_control_head;
	struct device___281 *dev;
	struct device_node___71 *of_node;
	int of_reset_n_cells;
	int (*of_xlate)(struct reset_controller_dev *, const struct of_phandle_args___11 *);
	unsigned int nr_resets;
};

struct hisi_reset_controller___2 {
	spinlock_t lock;
	void *membase;
	struct reset_controller_dev rcdev;
};

struct mbox_client___2 {
	struct device___281 *dev;
	bool tx_block;
	long unsigned int tx_tout;
	bool knows_txdone;
	void (*rx_callback)(struct mbox_client___2 *, void *);
	void (*tx_prepare)(struct mbox_client___2 *, void *);
	void (*tx_done)(struct mbox_client___2 *, void *, int);
};

struct mbox_chan___2;

struct hi3660_stub_clk_chan {
	struct mbox_client___2 cl;
	struct mbox_chan___2 *mbox;
};

struct hi3660_stub_clk {
	unsigned int id;
	struct clk_hw___5 hw;
	unsigned int cmd;
	unsigned int msg[8];
	unsigned int rate;
};

struct clk_sp810;

struct clk_sp810_timerclken {
	struct clk_hw___5 hw;
	struct clk *clk;
	struct clk_sp810 *sp810;
	int channel;
};

struct clk_sp810 {
	struct device_node___71 *node;
	void *base;
	spinlock_t lock;
	struct clk_sp810_timerclken timerclken[4];
};

struct vexpress_osc {
	struct regmap *reg;
	struct clk_hw___5 hw;
	long unsigned int rate_min;
	long unsigned int rate_max;
};

typedef s32 dma_cookie_t;

enum dma_status {
	DMA_COMPLETE = 0,
	DMA_IN_PROGRESS = 1,
	DMA_PAUSED = 2,
	DMA_ERROR = 3,
};

enum dma_transaction_type {
	DMA_MEMCPY = 0,
	DMA_XOR = 1,
	DMA_PQ = 2,
	DMA_XOR_VAL = 3,
	DMA_PQ_VAL = 4,
	DMA_MEMSET = 5,
	DMA_MEMSET_SG = 6,
	DMA_INTERRUPT = 7,
	DMA_PRIVATE = 8,
	DMA_ASYNC_TX = 9,
	DMA_SLAVE = 10,
	DMA_CYCLIC = 11,
	DMA_INTERLEAVE = 12,
	DMA_TX_TYPE_END = 13,
};

enum dma_transfer_direction {
	DMA_MEM_TO_MEM = 0,
	DMA_MEM_TO_DEV = 1,
	DMA_DEV_TO_MEM = 2,
	DMA_DEV_TO_DEV = 3,
	DMA_TRANS_NONE = 4,
};

struct data_chunk {
	size_t size;
	size_t icg;
	size_t dst_icg;
	size_t src_icg;
};

struct dma_interleaved_template {
	dma_addr_t src_start;
	dma_addr_t dst_start;
	enum dma_transfer_direction dir;
	bool src_inc;
	bool dst_inc;
	bool src_sgl;
	bool dst_sgl;
	size_t numf;
	size_t frame_size;
	struct data_chunk sgl[0];
};

enum dma_ctrl_flags {
	DMA_PREP_INTERRUPT = 1,
	DMA_CTRL_ACK = 2,
	DMA_PREP_PQ_DISABLE_P = 4,
	DMA_PREP_PQ_DISABLE_Q = 8,
	DMA_PREP_CONTINUE = 16,
	DMA_PREP_FENCE = 32,
	DMA_CTRL_REUSE = 64,
	DMA_PREP_CMD = 128,
};

enum sum_check_bits {
	SUM_CHECK_P = 0,
	SUM_CHECK_Q = 1,
};

enum sum_check_flags {
	SUM_CHECK_P_RESULT = 1,
	SUM_CHECK_Q_RESULT = 2,
};

typedef struct {
	long unsigned int bits[1];
} dma_cap_mask_t;

struct dma_chan_percpu {
	long unsigned int memcpy_count;
	long unsigned int bytes_transferred;
};

struct dma_router {
	struct device___260 *dev;
	void (*route_free)(struct device___260 *, void *);
};

struct dma_device;

struct dma_chan_dev;

struct dma_chan {
	struct dma_device *device;
	dma_cookie_t cookie;
	dma_cookie_t completed_cookie;
	int chan_id;
	struct dma_chan_dev *dev;
	struct list_head device_node;
	struct dma_chan_percpu *local;
	int client_count;
	int table_count;
	struct dma_router *router;
	void *route_data;
	void *private;
};

typedef bool (*dma_filter_fn)(struct dma_chan *, void *);

struct dma_slave_map;

struct dma_filter {
	dma_filter_fn fn;
	int mapcnt;
	const struct dma_slave_map *map;
};

enum dmaengine_alignment {
	DMAENGINE_ALIGN_1_BYTE = 0,
	DMAENGINE_ALIGN_2_BYTES = 1,
	DMAENGINE_ALIGN_4_BYTES = 2,
	DMAENGINE_ALIGN_8_BYTES = 3,
	DMAENGINE_ALIGN_16_BYTES = 4,
	DMAENGINE_ALIGN_32_BYTES = 5,
	DMAENGINE_ALIGN_64_BYTES = 6,
};

enum dma_residue_granularity {
	DMA_RESIDUE_GRANULARITY_DESCRIPTOR = 0,
	DMA_RESIDUE_GRANULARITY_SEGMENT = 1,
	DMA_RESIDUE_GRANULARITY_BURST = 2,
};

struct dma_async_tx_descriptor;

struct dma_slave_config;

struct dma_tx_state;

struct dma_device {
	unsigned int chancnt;
	unsigned int privatecnt;
	struct list_head channels;
	struct list_head global_node;
	struct dma_filter filter;
	dma_cap_mask_t cap_mask;
	short unsigned int max_xor;
	short unsigned int max_pq;
	enum dmaengine_alignment copy_align;
	enum dmaengine_alignment xor_align;
	enum dmaengine_alignment pq_align;
	enum dmaengine_alignment fill_align;
	int dev_id;
	struct device___260 *dev;
	u32 src_addr_widths;
	u32 dst_addr_widths;
	u32 directions;
	u32 max_burst;
	bool descriptor_reuse;
	enum dma_residue_granularity residue_granularity;
	int (*device_alloc_chan_resources)(struct dma_chan *);
	void (*device_free_chan_resources)(struct dma_chan *);
	struct dma_async_tx_descriptor * (*device_prep_dma_memcpy)(struct dma_chan *, dma_addr_t, dma_addr_t, size_t, long unsigned int);
	struct dma_async_tx_descriptor * (*device_prep_dma_xor)(struct dma_chan *, dma_addr_t, dma_addr_t *, unsigned int, size_t, long unsigned int);
	struct dma_async_tx_descriptor * (*device_prep_dma_xor_val)(struct dma_chan *, dma_addr_t *, unsigned int, size_t, enum sum_check_flags *, long unsigned int);
	struct dma_async_tx_descriptor * (*device_prep_dma_pq)(struct dma_chan *, dma_addr_t *, dma_addr_t *, unsigned int, const unsigned char *, size_t, long unsigned int);
	struct dma_async_tx_descriptor * (*device_prep_dma_pq_val)(struct dma_chan *, dma_addr_t *, dma_addr_t *, unsigned int, const unsigned char *, size_t, enum sum_check_flags *, long unsigned int);
	struct dma_async_tx_descriptor * (*device_prep_dma_memset)(struct dma_chan *, dma_addr_t, int, size_t, long unsigned int);
	struct dma_async_tx_descriptor * (*device_prep_dma_memset_sg)(struct dma_chan *, struct scatterlist *, unsigned int, int, long unsigned int);
	struct dma_async_tx_descriptor * (*device_prep_dma_interrupt)(struct dma_chan *, long unsigned int);
	struct dma_async_tx_descriptor * (*device_prep_slave_sg)(struct dma_chan *, struct scatterlist *, unsigned int, enum dma_transfer_direction, long unsigned int, void *);
	struct dma_async_tx_descriptor * (*device_prep_dma_cyclic)(struct dma_chan *, dma_addr_t, size_t, size_t, enum dma_transfer_direction, long unsigned int);
	struct dma_async_tx_descriptor * (*device_prep_interleaved_dma)(struct dma_chan *, struct dma_interleaved_template *, long unsigned int);
	struct dma_async_tx_descriptor * (*device_prep_dma_imm_data)(struct dma_chan *, dma_addr_t, u64, long unsigned int);
	int (*device_config)(struct dma_chan *, struct dma_slave_config *);
	int (*device_pause)(struct dma_chan *);
	int (*device_resume)(struct dma_chan *);
	int (*device_terminate_all)(struct dma_chan *);
	void (*device_synchronize)(struct dma_chan *);
	enum dma_status (*device_tx_status)(struct dma_chan *, dma_cookie_t, struct dma_tx_state *);
	void (*device_issue_pending)(struct dma_chan *);
};

struct dma_chan_dev {
	struct dma_chan *chan;
	struct device___260 device;
	int dev_id;
	atomic_t *idr_ref;
};

enum dma_slave_buswidth {
	DMA_SLAVE_BUSWIDTH_UNDEFINED = 0,
	DMA_SLAVE_BUSWIDTH_1_BYTE = 1,
	DMA_SLAVE_BUSWIDTH_2_BYTES = 2,
	DMA_SLAVE_BUSWIDTH_3_BYTES = 3,
	DMA_SLAVE_BUSWIDTH_4_BYTES = 4,
	DMA_SLAVE_BUSWIDTH_8_BYTES = 8,
	DMA_SLAVE_BUSWIDTH_16_BYTES = 16,
	DMA_SLAVE_BUSWIDTH_32_BYTES = 32,
	DMA_SLAVE_BUSWIDTH_64_BYTES = 64,
};

struct dma_slave_config {
	enum dma_transfer_direction direction;
	phys_addr_t src_addr;
	phys_addr_t dst_addr;
	enum dma_slave_buswidth src_addr_width;
	enum dma_slave_buswidth dst_addr_width;
	u32 src_maxburst;
	u32 dst_maxburst;
	u32 src_port_window_size;
	u32 dst_port_window_size;
	bool device_fc;
	unsigned int slave_id;
};

struct dma_slave_caps {
	u32 src_addr_widths;
	u32 dst_addr_widths;
	u32 directions;
	u32 max_burst;
	bool cmd_pause;
	bool cmd_resume;
	bool cmd_terminate;
	enum dma_residue_granularity residue_granularity;
	bool descriptor_reuse;
};

typedef void (*dma_async_tx_callback)(void *);

enum dmaengine_tx_result {
	DMA_TRANS_NOERROR = 0,
	DMA_TRANS_READ_FAILED = 1,
	DMA_TRANS_WRITE_FAILED = 2,
	DMA_TRANS_ABORTED = 3,
};

struct dmaengine_result {
	enum dmaengine_tx_result result;
	u32 residue;
};

typedef void (*dma_async_tx_callback_result)(void *, const struct dmaengine_result *);

struct dmaengine_unmap_data {
	u8 map_cnt;
	u8 to_cnt;
	u8 from_cnt;
	u8 bidi_cnt;
	struct device___260 *dev;
	struct kref kref;
	size_t len;
	dma_addr_t addr[0];
};

struct dma_async_tx_descriptor {
	dma_cookie_t cookie;
	enum dma_ctrl_flags flags;
	dma_addr_t phys;
	struct dma_chan *chan;
	dma_cookie_t (*tx_submit)(struct dma_async_tx_descriptor *);
	int (*desc_free)(struct dma_async_tx_descriptor *);
	dma_async_tx_callback callback;
	dma_async_tx_callback_result callback_result;
	void *callback_param;
	struct dmaengine_unmap_data *unmap;
};

struct dma_tx_state {
	dma_cookie_t last;
	dma_cookie_t used;
	u32 residue;
};

struct dma_slave_map {
	const char *devname;
	const char *slave;
	void *param;
};

struct dma_chan_tbl_ent {
	struct dma_chan *chan;
};

struct dmaengine_unmap_pool {
	struct kmem_cache *cache;
	const char *name;
	mempool_t *pool;
	size_t size;
};

typedef void (*dr_release_t___15)(struct device___279 *, void *);

struct acpi_table_csrt {
	struct acpi_table_header header;
};

struct acpi_csrt_group {
	u32 length;
	u32 vendor_id;
	u32 subvendor_id;
	u16 device_id;
	u16 subdevice_id;
	u16 revision;
	u16 reserved;
	u32 shared_info_length;
};

struct acpi_csrt_shared_info {
	u16 major_version;
	u16 minor_version;
	u32 mmio_base_low;
	u32 mmio_base_high;
	u32 gsi_interrupt;
	u8 interrupt_polarity;
	u8 interrupt_mode;
	u8 num_channels;
	u8 dma_address_width;
	u16 base_request_line;
	u16 num_handshake_signals;
	u32 max_block_size;
};

struct dma_router___2 {
	struct device___279 *dev;
	void (*route_free)(struct device___279 *, void *);
};

struct dma_device___2;

struct dma_chan_dev___2;

struct dma_chan___2 {
	struct dma_device___2 *device;
	dma_cookie_t cookie;
	dma_cookie_t completed_cookie;
	int chan_id;
	struct dma_chan_dev___2 *dev;
	struct list_head device_node;
	struct dma_chan_percpu *local;
	int client_count;
	int table_count;
	struct dma_router___2 *router;
	void *route_data;
	void *private;
};

typedef bool (*dma_filter_fn___2)(struct dma_chan___2 *, void *);

struct dma_filter___2 {
	dma_filter_fn___2 fn;
	int mapcnt;
	const struct dma_slave_map *map;
};

struct dma_async_tx_descriptor___2;

struct dma_device___2 {
	unsigned int chancnt;
	unsigned int privatecnt;
	struct list_head channels;
	struct list_head global_node;
	struct dma_filter___2 filter;
	dma_cap_mask_t cap_mask;
	short unsigned int max_xor;
	short unsigned int max_pq;
	enum dmaengine_alignment copy_align;
	enum dmaengine_alignment xor_align;
	enum dmaengine_alignment pq_align;
	enum dmaengine_alignment fill_align;
	int dev_id;
	struct device___279 *dev;
	u32 src_addr_widths;
	u32 dst_addr_widths;
	u32 directions;
	u32 max_burst;
	bool descriptor_reuse;
	enum dma_residue_granularity residue_granularity;
	int (*device_alloc_chan_resources)(struct dma_chan___2 *);
	void (*device_free_chan_resources)(struct dma_chan___2 *);
	struct dma_async_tx_descriptor___2 * (*device_prep_dma_memcpy)(struct dma_chan___2 *, dma_addr_t, dma_addr_t, size_t, long unsigned int);
	struct dma_async_tx_descriptor___2 * (*device_prep_dma_xor)(struct dma_chan___2 *, dma_addr_t, dma_addr_t *, unsigned int, size_t, long unsigned int);
	struct dma_async_tx_descriptor___2 * (*device_prep_dma_xor_val)(struct dma_chan___2 *, dma_addr_t *, unsigned int, size_t, enum sum_check_flags *, long unsigned int);
	struct dma_async_tx_descriptor___2 * (*device_prep_dma_pq)(struct dma_chan___2 *, dma_addr_t *, dma_addr_t *, unsigned int, const unsigned char *, size_t, long unsigned int);
	struct dma_async_tx_descriptor___2 * (*device_prep_dma_pq_val)(struct dma_chan___2 *, dma_addr_t *, dma_addr_t *, unsigned int, const unsigned char *, size_t, enum sum_check_flags *, long unsigned int);
	struct dma_async_tx_descriptor___2 * (*device_prep_dma_memset)(struct dma_chan___2 *, dma_addr_t, int, size_t, long unsigned int);
	struct dma_async_tx_descriptor___2 * (*device_prep_dma_memset_sg)(struct dma_chan___2 *, struct scatterlist *, unsigned int, int, long unsigned int);
	struct dma_async_tx_descriptor___2 * (*device_prep_dma_interrupt)(struct dma_chan___2 *, long unsigned int);
	struct dma_async_tx_descriptor___2 * (*device_prep_slave_sg)(struct dma_chan___2 *, struct scatterlist *, unsigned int, enum dma_transfer_direction, long unsigned int, void *);
	struct dma_async_tx_descriptor___2 * (*device_prep_dma_cyclic)(struct dma_chan___2 *, dma_addr_t, size_t, size_t, enum dma_transfer_direction, long unsigned int);
	struct dma_async_tx_descriptor___2 * (*device_prep_interleaved_dma)(struct dma_chan___2 *, struct dma_interleaved_template *, long unsigned int);
	struct dma_async_tx_descriptor___2 * (*device_prep_dma_imm_data)(struct dma_chan___2 *, dma_addr_t, u64, long unsigned int);
	int (*device_config)(struct dma_chan___2 *, struct dma_slave_config *);
	int (*device_pause)(struct dma_chan___2 *);
	int (*device_resume)(struct dma_chan___2 *);
	int (*device_terminate_all)(struct dma_chan___2 *);
	void (*device_synchronize)(struct dma_chan___2 *);
	enum dma_status (*device_tx_status)(struct dma_chan___2 *, dma_cookie_t, struct dma_tx_state *);
	void (*device_issue_pending)(struct dma_chan___2 *);
};

struct dma_chan_dev___2 {
	struct dma_chan___2 *chan;
	struct device___279 device;
	int dev_id;
	atomic_t *idr_ref;
};

struct dmaengine_unmap_data___2 {
	u8 map_cnt;
	u8 to_cnt;
	u8 from_cnt;
	u8 bidi_cnt;
	struct device___279 *dev;
	struct kref kref;
	size_t len;
	dma_addr_t addr[0];
};

struct dma_async_tx_descriptor___2 {
	dma_cookie_t cookie;
	enum dma_ctrl_flags flags;
	dma_addr_t phys;
	struct dma_chan___2 *chan;
	dma_cookie_t (*tx_submit)(struct dma_async_tx_descriptor___2 *);
	int (*desc_free)(struct dma_async_tx_descriptor___2 *);
	dma_async_tx_callback callback;
	dma_async_tx_callback_result callback_result;
	void *callback_param;
	struct dmaengine_unmap_data___2 *unmap;
};

struct acpi_dma_spec {
	int chan_id;
	int slave_id;
	struct device___279 *dev;
};

struct acpi_dma {
	struct list_head dma_controllers;
	struct device___279 *dev;
	struct dma_chan___2 * (*acpi_dma_xlate)(struct acpi_dma_spec *, struct acpi_dma *);
	void *data;
	short unsigned int base_request_line;
	short unsigned int end_request_line;
};

struct acpi_dma_filter_info {
	dma_cap_mask_t dma_cap;
	dma_filter_fn___2 filter_fn;
};

struct acpi_dma_parser_data {
	struct acpi_dma_spec dma_spec;
	size_t index;
	size_t n;
};

struct of_dma {
	struct list_head of_dma_controllers;
	struct device_node___2 *of_node;
	struct dma_chan___2 * (*of_dma_xlate)(struct of_phandle_args___5 *, struct of_dma *);
	void * (*of_dma_route_allocate)(struct of_phandle_args___5 *, struct of_dma *);
	struct dma_router___2 *dma_router;
	void *of_dma_data;
};

struct of_dma_filter_info {
	dma_cap_mask_t dma_cap;
	dma_filter_fn___2 filter_fn;
};

struct device_attribute___25 {
	struct attribute attr;
	ssize_t (*show)(struct device___75 *, struct device_attribute___25 *, char *);
	ssize_t (*store)(struct device___75 *, struct device_attribute___25 *, const char *, size_t);
};

struct virtio_device___2;

typedef void vrh_callback_t___2(struct virtio_device___2 *, struct vringh *);

struct virtio_config_ops___2;

struct vringh_config_ops___2;

struct virtio_device___2 {
	int index;
	bool failed;
	bool config_enabled;
	bool config_change_pending;
	spinlock_t config_lock;
	struct device___75 dev;
	struct virtio_device_id id;
	const struct virtio_config_ops___2 *config;
	const struct vringh_config_ops___2 *vringh_config;
	struct list_head vqs;
	u64 features;
	void *priv;
};

struct vringh_config_ops___2 {
	int (*find_vrhs)(struct virtio_device___2 *, unsigned int, struct vringh **, vrh_callback_t___2 **);
	void (*del_vrhs)(struct virtio_device___2 *);
};

struct virtqueue___2 {
	struct list_head list;
	void (*callback)(struct virtqueue___2 *);
	const char *name;
	struct virtio_device___2 *vdev;
	unsigned int index;
	unsigned int num_free;
	void *priv;
};

typedef void vq_callback_t___2(struct virtqueue___2 *);

struct virtio_config_ops___2 {
	void (*get)(struct virtio_device___2 *, unsigned int, void *, unsigned int);
	void (*set)(struct virtio_device___2 *, unsigned int, const void *, unsigned int);
	u32 (*generation)(struct virtio_device___2 *);
	u8 (*get_status)(struct virtio_device___2 *);
	void (*set_status)(struct virtio_device___2 *, u8);
	void (*reset)(struct virtio_device___2 *);
	int (*find_vqs)(struct virtio_device___2 *, unsigned int, struct virtqueue___2 **, vq_callback_t___2 **, const char * const *, const bool *, struct irq_affinity___2 *);
	void (*del_vqs)(struct virtio_device___2 *);
	u64 (*get_features)(struct virtio_device___2 *);
	int (*finalize_features)(struct virtio_device___2 *);
	const char * (*bus_name)(struct virtio_device___2 *);
	int (*set_vq_affinity)(struct virtqueue___2 *, int);
	const struct cpumask * (*get_vq_affinity)(struct virtio_device___2 *, int);
};

struct virtio_driver {
	struct device_driver___75 driver;
	const struct virtio_device_id *id_table;
	const unsigned int *feature_table;
	unsigned int feature_table_size;
	const unsigned int *feature_table_legacy;
	unsigned int feature_table_size_legacy;
	int (*validate)(struct virtio_device___2 *);
	int (*probe)(struct virtio_device___2 *);
	void (*scan)(struct virtio_device___2 *);
	void (*remove)(struct virtio_device___2 *);
	void (*config_changed)(struct virtio_device___2 *);
	int (*freeze)(struct virtio_device___2 *);
	int (*restore)(struct virtio_device___2 *);
};

struct module___256;

struct file___316;

struct kiocb___316;

struct vm_area_struct___317;

struct inode___316;

struct file_lock___316;

struct page___317;

struct file_operations___316 {
	struct module___256 *owner;
	loff_t (*llseek)(struct file___316 *, loff_t, int);
	ssize_t (*read)(struct file___316 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___316 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___316 *, struct iov_iter___138 *);
	ssize_t (*write_iter)(struct kiocb___316 *, struct iov_iter___138 *);
	int (*iopoll)(struct kiocb___316 *, bool);
	int (*iterate)(struct file___316 *, struct dir_context *);
	int (*iterate_shared)(struct file___316 *, struct dir_context *);
	__poll_t (*poll)(struct file___316 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___316 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___316 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___316 *, struct vm_area_struct___317 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___316 *, struct file___316 *);
	int (*flush)(struct file___316 *, fl_owner_t);
	int (*release)(struct inode___316 *, struct file___316 *);
	int (*fsync)(struct file___316 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___316 *, int);
	int (*lock)(struct file___316 *, int, struct file_lock___316 *);
	ssize_t (*sendpage)(struct file___316 *, struct page___317 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___316 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___316 *, int, struct file_lock___316 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___316 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___316 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___316 *, long int, struct file_lock___316 **, void **);
	long int (*fallocate)(struct file___316 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___316 *);
	ssize_t (*copy_file_range)(struct file___316 *, loff_t, struct file___316 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___316 *, loff_t, struct file___316 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___316 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___316 {
	u64 seqnum;
	struct vm_area_struct___317 *vmas[4];
};

struct page_frag___316 {
	struct page___317 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___316;

struct vm_struct___232;

struct task_struct___317 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___317 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___316 *mm;
	struct mm_struct___316 *active_mm;
	struct vmacache___316 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___317 *real_parent;
	struct task_struct___317 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___317 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___205 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___205 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___205 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___2 *ptracer_cred;
	const struct cred___2 *real_cred;
	const struct cred___2 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___317 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___82 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___316 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___317 *oom_reaper_list;
	struct vm_struct___232 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___132 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___317 *pgtable_t___316;

struct address_space___315;

struct dev_pagemap___305;

struct page___317 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___315 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___317 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___316 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___316 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___305 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___316;

struct lruvec___316 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___316 *pgdat;
};

struct zone___316 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___316 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___316 {
	struct zone___316 *zone;
	int zone_idx;
};

struct zonelist___316 {
	struct zoneref___316 _zonerefs[25];
};

struct pglist_data___316 {
	struct zone___316 node_zones[3];
	struct zonelist___316 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___317 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___317 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___316 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___317 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___317 *owner;
};

struct secondary_data___317 {
	void *stack;
	struct task_struct___317 *task;
	long int status;
};

struct blocking_notifier_head___316 {
	struct rw_semaphore___317 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___305;

struct vm_area_struct___317 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___317 *vm_next;
	struct vm_area_struct___317 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___316 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___305 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___316 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___316;

struct mm_struct___316 {
	struct {
		struct vm_area_struct___317 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___316 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___317 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___316 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___317 *owner;
		struct user_namespace___3 *user_ns;
		struct file___316 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___316 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___315;

struct address_space___315 {
	struct inode___316 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___317 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___315 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___305)(struct vm_area_struct___317 *, long unsigned int, const struct page___317 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___305)(struct page___317 *, void *);

struct device___282;

struct dev_pagemap___305 {
	dev_page_fault_t___305 page_fault;
	dev_page_free_t___305 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___282 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct dentry___315;

struct path___316 {
	struct vfsmount *mnt;
	struct dentry___315 *dentry;
};

struct file___316 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___316 f_path;
	struct inode___316 *f_inode;
	const struct file_operations___316 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___205 f_owner;
	const struct cred___2 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___315 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___305;

struct vm_operations_struct___305 {
	void (*open)(struct vm_area_struct___317 *);
	void (*close)(struct vm_area_struct___317 *);
	int (*split)(struct vm_area_struct___317 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___317 *);
	vm_fault_t (*fault)(struct vm_fault___305 *);
	vm_fault_t (*huge_fault)(struct vm_fault___305 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___305 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___317 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___305 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___305 *);
	int (*access)(struct vm_area_struct___317 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___317 *);
	int (*set_policy)(struct vm_area_struct___317 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___317 *, long unsigned int);
	struct page___317 * (*find_special_page)(struct vm_area_struct___317 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___316 {
	struct task_struct___317 *task;
	struct core_thread___316 *next;
};

struct core_state___316 {
	atomic_t nr_threads;
	struct core_thread___316 dumper;
	struct completion startup;
};

struct vm_fault___305 {
	struct vm_area_struct___317 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___317 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___317 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___316 prealloc_pte;
};

struct vm_struct___232 {
	struct vm_struct___232 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___317 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct kset___302;

struct kobj_type___302;

struct kernfs_node___310;

struct kobject___303 {
	const char *name;
	struct list_head entry;
	struct kobject___303 *parent;
	struct kset___302 *kset;
	struct kobj_type___302 *ktype;
	struct kernfs_node___310 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___282 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___3 *subsys_data;
	void (*set_latency_tolerance)(struct device___282 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___282;

struct bus_type___282;

struct device_driver___282;

struct dev_pm_domain___282;

struct dma_map_ops___94;

struct fwnode_handle___216;

struct class___282;

struct attribute_group___280;

struct device___282 {
	struct device___282 *parent;
	struct device_private *p;
	struct kobject___303 kobj;
	const char *init_name;
	const struct device_type___282 *type;
	struct mutex mutex;
	struct bus_type___282 *bus;
	struct device_driver___282 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___282 power;
	struct dev_pm_domain___282 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___94 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___216 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___282 *class;
	const struct attribute_group___280 **groups;
	void (*release)(struct device___282 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___315;

struct super_block___315;

struct dentry___315 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___315 *d_parent;
	struct qstr d_name;
	struct inode___316 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___315 *d_op;
	struct super_block___315 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___315;

struct block_device___315;

struct inode___316 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___315 *i_op;
	struct super_block___315 *i_sb;
	struct address_space___315 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___317 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___316 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___315 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___315 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___315 {
	int (*d_revalidate)(struct dentry___315 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___315 *, unsigned int);
	int (*d_hash)(const struct dentry___315 *, struct qstr *);
	int (*d_compare)(const struct dentry___315 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___315 *);
	int (*d_init)(struct dentry___315 *);
	void (*d_release)(struct dentry___315 *);
	void (*d_prune)(struct dentry___315 *);
	void (*d_iput)(struct dentry___315 *, struct inode___316 *);
	char * (*d_dname)(struct dentry___315 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___316 *);
	int (*d_manage)(const struct path___316 *, bool);
	struct dentry___315 * (*d_real)(struct dentry___315 *, const struct inode___316 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___315;

struct mem_dqinfo___315 {
	struct quota_format_type___315 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___315;

struct quota_info___315 {
	unsigned int flags;
	struct rw_semaphore___317 dqio_sem;
	struct inode___316 *files[3];
	struct mem_dqinfo___315 info[3];
	const struct quota_format_ops___315 *ops[3];
};

struct rcuwait___315 {
	struct task_struct___317 *task;
};

struct percpu_rw_semaphore___315 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___317 rw_sem;
	struct rcuwait___315 writer;
	int readers_block;
};

struct sb_writers___315 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___315 rw_sem[3];
};

struct file_system_type___315;

struct super_operations___315;

struct dquot_operations___315;

struct quotactl_ops___315;

struct super_block___315 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___315 *s_type;
	const struct super_operations___315 *s_op;
	const struct dquot_operations___315 *dq_op;
	const struct quotactl_ops___315 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___315 *s_root;
	struct rw_semaphore___317 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___315 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___315 s_dquot;
	struct sb_writers___315 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___315 *s_d_op;
	int cleancache_poolid;
	struct shrinker___119 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___316 {
	struct file___316 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___316 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___315 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___316 *ia_file;
};

struct dquot___315 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___315 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___315 {
	int qf_fmt_id;
	const struct quota_format_ops___315 *qf_ops;
	struct module___256 *qf_owner;
	struct quota_format_type___315 *qf_next;
};

struct quota_format_ops___315 {
	int (*check_quota_file)(struct super_block___315 *, int);
	int (*read_file_info)(struct super_block___315 *, int);
	int (*write_file_info)(struct super_block___315 *, int);
	int (*free_file_info)(struct super_block___315 *, int);
	int (*read_dqblk)(struct dquot___315 *);
	int (*commit_dqblk)(struct dquot___315 *);
	int (*release_dqblk)(struct dquot___315 *);
	int (*get_next_id)(struct super_block___315 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___315 {
	int (*write_dquot)(struct dquot___315 *);
	struct dquot___315 * (*alloc_dquot)(struct super_block___315 *, int);
	void (*destroy_dquot)(struct dquot___315 *);
	int (*acquire_dquot)(struct dquot___315 *);
	int (*release_dquot)(struct dquot___315 *);
	int (*mark_dirty)(struct dquot___315 *);
	int (*write_info)(struct super_block___315 *, int);
	qsize_t * (*get_reserved_space)(struct inode___316 *);
	int (*get_projid)(struct inode___316 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___316 *, qsize_t *);
	int (*get_next_id)(struct super_block___315 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___315 {
	int (*quota_on)(struct super_block___315 *, int, int, const struct path___316 *);
	int (*quota_off)(struct super_block___315 *, int);
	int (*quota_enable)(struct super_block___315 *, unsigned int);
	int (*quota_disable)(struct super_block___315 *, unsigned int);
	int (*quota_sync)(struct super_block___315 *, int);
	int (*set_info)(struct super_block___315 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___315 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___315 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___315 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___315 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___315 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___253 {
	struct kobject___303 kobj;
	struct module___256 *mod;
	struct kobject___303 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___253 {
	struct module___256 *mod;
	struct latch_tree_node node;
};

struct module_layout___253 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___253 mtn;
};

struct module_attribute___253;

struct kernel_param___253;

struct module___256 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___253 mkobj;
	struct module_attribute___253 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___303 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___253 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___253 core_layout;
	struct module_layout___253 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___315 {
	int (*writepage)(struct page___317 *, struct writeback_control___3 *);
	int (*readpage)(struct file___316 *, struct page___317 *);
	int (*writepages)(struct address_space___315 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___317 *);
	int (*readpages)(struct file___316 *, struct address_space___315 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___316 *, struct address_space___315 *, loff_t, unsigned int, unsigned int, struct page___317 **, void **);
	int (*write_end)(struct file___316 *, struct address_space___315 *, loff_t, unsigned int, unsigned int, struct page___317 *, void *);
	sector_t (*bmap)(struct address_space___315 *, sector_t);
	void (*invalidatepage)(struct page___317 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___317 *, gfp_t);
	void (*freepage)(struct page___317 *);
	ssize_t (*direct_IO)(struct kiocb___316 *, struct iov_iter___138 *);
	int (*migratepage)(struct address_space___315 *, struct page___317 *, struct page___317 *, enum migrate_mode);
	bool (*isolate_page)(struct page___317 *, isolate_mode_t);
	void (*putback_page)(struct page___317 *);
	int (*launder_page)(struct page___317 *);
	int (*is_partially_uptodate)(struct page___317 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___317 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___315 *, struct page___317 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___316 *, sector_t *);
	void (*swap_deactivate)(struct file___316 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___315 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___316 *bd_inode;
	struct super_block___315 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___315 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___315 {
	struct dentry___315 * (*lookup)(struct inode___316 *, struct dentry___315 *, unsigned int);
	const char * (*get_link)(struct dentry___315 *, struct inode___316 *, struct delayed_call *);
	int (*permission)(struct inode___316 *, int);
	struct posix_acl * (*get_acl)(struct inode___316 *, int);
	int (*readlink)(struct dentry___315 *, char *, int);
	int (*create)(struct inode___316 *, struct dentry___315 *, umode_t, bool);
	int (*link)(struct dentry___315 *, struct inode___316 *, struct dentry___315 *);
	int (*unlink)(struct inode___316 *, struct dentry___315 *);
	int (*symlink)(struct inode___316 *, struct dentry___315 *, const char *);
	int (*mkdir)(struct inode___316 *, struct dentry___315 *, umode_t);
	int (*rmdir)(struct inode___316 *, struct dentry___315 *);
	int (*mknod)(struct inode___316 *, struct dentry___315 *, umode_t, dev_t);
	int (*rename)(struct inode___316 *, struct dentry___315 *, struct inode___316 *, struct dentry___315 *, unsigned int);
	int (*setattr)(struct dentry___315 *, struct iattr___315 *);
	int (*getattr)(const struct path___316 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___315 *, char *, size_t);
	int (*fiemap)(struct inode___316 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___316 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___316 *, struct dentry___315 *, struct file___316 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___316 *, struct dentry___315 *, umode_t);
	int (*set_acl)(struct inode___316 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___315 {
	void (*fl_copy_lock)(struct file_lock___316 *, struct file_lock___316 *);
	void (*fl_release_private)(struct file_lock___316 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___315;

struct lock_manager_operations___315;

struct file_lock___316 {
	struct file_lock___316 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___316 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___315 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___315 *fl_ops;
	const struct lock_manager_operations___315 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___315 {
	int (*lm_compare_owner)(struct file_lock___316 *, struct file_lock___316 *);
	long unsigned int (*lm_owner_key)(struct file_lock___316 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___316 *);
	int (*lm_grant)(struct file_lock___316 *, int);
	bool (*lm_break)(struct file_lock___316 *);
	int (*lm_change)(struct file_lock___316 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___316 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___315 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___315 *fa_next;
	struct file___316 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___315 {
	const char *name;
	int fs_flags;
	struct dentry___315 * (*mount)(struct file_system_type___315 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___315 *);
	struct module___256 *owner;
	struct file_system_type___315 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___315 {
	struct inode___316 * (*alloc_inode)(struct super_block___315 *);
	void (*destroy_inode)(struct inode___316 *);
	void (*dirty_inode)(struct inode___316 *, int);
	int (*write_inode)(struct inode___316 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___316 *);
	void (*evict_inode)(struct inode___316 *);
	void (*put_super)(struct super_block___315 *);
	int (*sync_fs)(struct super_block___315 *, int);
	int (*freeze_super)(struct super_block___315 *);
	int (*freeze_fs)(struct super_block___315 *);
	int (*thaw_super)(struct super_block___315 *);
	int (*unfreeze_fs)(struct super_block___315 *);
	int (*statfs)(struct dentry___315 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___315 *, int *, char *);
	void (*umount_begin)(struct super_block___315 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___315 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___315 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___315 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___315 *);
	ssize_t (*quota_read)(struct super_block___315 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___315 *, int, const char *, size_t, loff_t);
	struct dquot___315 ** (*get_dquots)(struct inode___316 *);
	int (*bdev_try_to_free_page)(struct super_block___315 *, struct page___317 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___315 *, struct shrink_control___119 *);
	long int (*free_cached_objects)(struct super_block___315 *, struct shrink_control___119 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_attribute___295 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___303 *, struct kobj_attribute___295 *, char *);
	ssize_t (*store)(struct kobject___303 *, struct kobj_attribute___295 *, const char *, size_t);
};

typedef void compound_page_dtor___305(struct page___317 *);

struct fwnode_operations___216;

struct fwnode_handle___216 {
	struct fwnode_handle___216 *secondary;
	const struct fwnode_operations___216 *ops;
};

struct fwnode_reference_args___216;

struct fwnode_endpoint___216;

struct fwnode_operations___216 {
	struct fwnode_handle___216 * (*get)(struct fwnode_handle___216 *);
	void (*put)(struct fwnode_handle___216 *);
	bool (*device_is_available)(const struct fwnode_handle___216 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___216 *, const struct device___282 *);
	bool (*property_present)(const struct fwnode_handle___216 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___216 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___216 *, const char *, const char **, size_t);
	struct fwnode_handle___216 * (*get_parent)(const struct fwnode_handle___216 *);
	struct fwnode_handle___216 * (*get_next_child_node)(const struct fwnode_handle___216 *, struct fwnode_handle___216 *);
	struct fwnode_handle___216 * (*get_named_child_node)(const struct fwnode_handle___216 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___216 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___216 *);
	struct fwnode_handle___216 * (*graph_get_next_endpoint)(const struct fwnode_handle___216 *, struct fwnode_handle___216 *);
	struct fwnode_handle___216 * (*graph_get_remote_endpoint)(const struct fwnode_handle___216 *);
	struct fwnode_handle___216 * (*graph_get_port_parent)(struct fwnode_handle___216 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___216 *, struct fwnode_endpoint___216 *);
};

struct fwnode_endpoint___216 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___216 *local_fwnode;
};

struct fwnode_reference_args___216 {
	struct fwnode_handle___216 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct kernfs_root___309;

struct kernfs_elem_dir___309 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___309 *root;
};

struct kernfs_syscall_ops___309;

struct kernfs_root___309 {
	struct kernfs_node___310 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___309 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___309 {
	struct kernfs_node___310 *target_kn;
};

struct kernfs_ops___309;

struct kernfs_elem_attr___309 {
	const struct kernfs_ops___309 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___310 *notify_next;
};

struct kernfs_node___310 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___310 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___309 dir;
		struct kernfs_elem_symlink___309 symlink;
		struct kernfs_elem_attr___309 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___309;

struct kernfs_ops___309 {
	int (*open)(struct kernfs_open_file___309 *);
	void (*release)(struct kernfs_open_file___309 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___309 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___309 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___309 *, struct vm_area_struct___317 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___309 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___309 {
	int (*remount_fs)(struct kernfs_root___309 *, int *, char *);
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___309 *);
	int (*mkdir)(struct kernfs_node___310 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___310 *);
	int (*rename)(struct kernfs_node___310 *, struct kernfs_node___310 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___310 *, struct kernfs_root___309 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___309 {
	struct kernfs_node___310 *kn;
	struct file___316 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___305 *vm_ops;
};

struct bin_attribute___279;

struct attribute_group___280 {
	const char *name;
	umode_t (*is_visible)(struct kobject___303 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___303 *, struct bin_attribute___279 *, int);
	struct attribute **attrs;
	struct bin_attribute___279 **bin_attrs;
};

struct bin_attribute___279 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___316 *, struct kobject___303 *, struct bin_attribute___279 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___316 *, struct kobject___303 *, struct bin_attribute___279 *, char *, loff_t, size_t);
	int (*mmap)(struct file___316 *, struct kobject___303 *, struct bin_attribute___279 *, struct vm_area_struct___317 *);
};

struct sysfs_ops___302 {
	ssize_t (*show)(struct kobject___303 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___303 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___302;

struct kset___302 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___303 kobj;
	const struct kset_uevent_ops___302 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___302 {
	void (*release)(struct kobject___303 *);
	const struct sysfs_ops___302 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___25 * (*child_ns_type)(struct kobject___303 *);
	const void * (*namespace)(struct kobject___303 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___302 {
	int (* const filter)(struct kset___302 *, struct kobject___303 *);
	const char * (* const name)(struct kset___302 *, struct kobject___303 *);
	int (* const uevent)(struct kset___302 *, struct kobject___303 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___282 {
	int (*prepare)(struct device___282 *);
	void (*complete)(struct device___282 *);
	int (*suspend)(struct device___282 *);
	int (*resume)(struct device___282 *);
	int (*freeze)(struct device___282 *);
	int (*thaw)(struct device___282 *);
	int (*poweroff)(struct device___282 *);
	int (*restore)(struct device___282 *);
	int (*suspend_late)(struct device___282 *);
	int (*resume_early)(struct device___282 *);
	int (*freeze_late)(struct device___282 *);
	int (*thaw_early)(struct device___282 *);
	int (*poweroff_late)(struct device___282 *);
	int (*restore_early)(struct device___282 *);
	int (*suspend_noirq)(struct device___282 *);
	int (*resume_noirq)(struct device___282 *);
	int (*freeze_noirq)(struct device___282 *);
	int (*thaw_noirq)(struct device___282 *);
	int (*poweroff_noirq)(struct device___282 *);
	int (*restore_noirq)(struct device___282 *);
	int (*runtime_suspend)(struct device___282 *);
	int (*runtime_resume)(struct device___282 *);
	int (*runtime_idle)(struct device___282 *);
};

struct dev_pm_domain___282 {
	struct dev_pm_ops___282 ops;
	void (*detach)(struct device___282 *, bool);
	int (*activate)(struct device___282 *);
	void (*sync)(struct device___282 *);
	void (*dismiss)(struct device___282 *);
};

struct bus_type___282 {
	const char *name;
	const char *dev_name;
	struct device___282 *dev_root;
	const struct attribute_group___280 **bus_groups;
	const struct attribute_group___280 **dev_groups;
	const struct attribute_group___280 **drv_groups;
	int (*match)(struct device___282 *, struct device_driver___282 *);
	int (*uevent)(struct device___282 *, struct kobj_uevent_env *);
	int (*probe)(struct device___282 *);
	int (*remove)(struct device___282 *);
	void (*shutdown)(struct device___282 *);
	int (*online)(struct device___282 *);
	int (*offline)(struct device___282 *);
	int (*suspend)(struct device___282 *, pm_message_t);
	int (*resume)(struct device___282 *);
	int (*num_vf)(struct device___282 *);
	int (*dma_configure)(struct device___282 *);
	const struct dev_pm_ops___282 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___282 {
	const char *name;
	struct bus_type___282 *bus;
	struct module___256 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___282 *);
	int (*remove)(struct device___282 *);
	void (*shutdown)(struct device___282 *);
	int (*suspend)(struct device___282 *, pm_message_t);
	int (*resume)(struct device___282 *);
	const struct attribute_group___280 **groups;
	const struct dev_pm_ops___282 *pm;
	void (*coredump)(struct device___282 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___282 {
	const char *name;
	const struct attribute_group___280 **groups;
	int (*uevent)(struct device___282 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___282 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___282 *);
	const struct dev_pm_ops___282 *pm;
};

struct class___282 {
	const char *name;
	struct module___256 *owner;
	const struct attribute_group___280 **class_groups;
	const struct attribute_group___280 **dev_groups;
	struct kobject___303 *dev_kobj;
	int (*dev_uevent)(struct device___282 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___282 *, umode_t *);
	void (*class_release)(struct class___282 *);
	void (*dev_release)(struct device___282 *);
	int (*shutdown_pre)(struct device___282 *);
	const struct kobj_ns_type_operations___25 *ns_type;
	const void * (*namespace)(struct device___282 *);
	const struct dev_pm_ops___282 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___94 {
	void * (*alloc)(struct device___282 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___282 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___282 *, struct vm_area_struct___317 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___282 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___282 *, struct page___317 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___282 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___282 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___282 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___282 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___282 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___282 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___282 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___282 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___282 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___282 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___282 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___282 *, u64);
	u64 (*get_required_mask)(struct device___282 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct virtio_device___3;

typedef void vrh_callback_t___3(struct virtio_device___3 *, struct vringh *);

struct virtio_config_ops___3;

struct vringh_config_ops___3;

struct virtio_device___3 {
	int index;
	bool failed;
	bool config_enabled;
	bool config_change_pending;
	spinlock_t config_lock;
	struct device___282 dev;
	struct virtio_device_id id;
	const struct virtio_config_ops___3 *config;
	const struct vringh_config_ops___3 *vringh_config;
	struct list_head vqs;
	u64 features;
	void *priv;
};

struct vringh_config_ops___3 {
	int (*find_vrhs)(struct virtio_device___3 *, unsigned int, struct vringh **, vrh_callback_t___3 **);
	void (*del_vrhs)(struct virtio_device___3 *);
};

struct virtqueue___3 {
	struct list_head list;
	void (*callback)(struct virtqueue___3 *);
	const char *name;
	struct virtio_device___3 *vdev;
	unsigned int index;
	unsigned int num_free;
	void *priv;
};

typedef void vq_callback_t___3(struct virtqueue___3 *);

struct virtio_config_ops___3 {
	void (*get)(struct virtio_device___3 *, unsigned int, void *, unsigned int);
	void (*set)(struct virtio_device___3 *, unsigned int, const void *, unsigned int);
	u32 (*generation)(struct virtio_device___3 *);
	u8 (*get_status)(struct virtio_device___3 *);
	void (*set_status)(struct virtio_device___3 *, u8);
	void (*reset)(struct virtio_device___3 *);
	int (*find_vqs)(struct virtio_device___3 *, unsigned int, struct virtqueue___3 **, vq_callback_t___3 **, const char * const *, const bool *, struct irq_affinity___2 *);
	void (*del_vqs)(struct virtio_device___3 *);
	u64 (*get_features)(struct virtio_device___3 *);
	int (*finalize_features)(struct virtio_device___3 *);
	const char * (*bus_name)(struct virtio_device___3 *);
	int (*set_vq_affinity)(struct virtqueue___3 *, int);
	const struct cpumask * (*get_vq_affinity)(struct virtio_device___3 *, int);
};

struct kernel_param_ops___253 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___253 *);
	int (*get)(char *, const struct kernel_param___253 *);
	void (*free)(void *);
};

struct kparam_array___253;

struct kernel_param___253 {
	const char *name;
	struct module___256 *mod;
	const struct kernel_param_ops___253 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___253 *arr;
	};
};

struct kparam_array___253 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___253 *ops;
	void *elem;
};

struct module_attribute___253 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___253 *, struct module_kobject___253 *, char *);
	ssize_t (*store)(struct module_attribute___253 *, struct module_kobject___253 *, const char *, size_t);
	void (*setup)(struct module___256 *, const char *);
	int (*test)(struct module___256 *);
	void (*free)(struct module___256 *);
};

struct vring_desc_state {
	void *data;
	struct vring_desc *indir_desc;
};

struct vring_virtqueue {
	struct virtqueue___3 vq;
	struct vring vring;
	bool weak_barriers;
	bool broken;
	bool indirect;
	bool event;
	unsigned int free_head;
	unsigned int num_added;
	u16 last_used_idx;
	u16 avail_flags_shadow;
	u16 avail_idx_shadow;
	bool (*notify)(struct virtqueue___3 *);
	bool we_own_ring;
	size_t queue_size_in_bytes;
	dma_addr_t queue_dma_addr;
	struct vring_desc_state desc_state[0];
};

struct virtio_device___4;

typedef void vrh_callback_t___4(struct virtio_device___4 *, struct vringh *);

struct virtio_config_ops___4;

struct vringh_config_ops___4;

struct virtio_device___4 {
	int index;
	bool failed;
	bool config_enabled;
	bool config_change_pending;
	spinlock_t config_lock;
	struct device___274 dev;
	struct virtio_device_id id;
	const struct virtio_config_ops___4 *config;
	const struct vringh_config_ops___4 *vringh_config;
	struct list_head vqs;
	u64 features;
	void *priv;
};

struct vringh_config_ops___4 {
	int (*find_vrhs)(struct virtio_device___4 *, unsigned int, struct vringh **, vrh_callback_t___4 **);
	void (*del_vrhs)(struct virtio_device___4 *);
};

struct virtqueue___4 {
	struct list_head list;
	void (*callback)(struct virtqueue___4 *);
	const char *name;
	struct virtio_device___4 *vdev;
	unsigned int index;
	unsigned int num_free;
	void *priv;
};

typedef void vq_callback_t___4(struct virtqueue___4 *);

struct virtio_config_ops___4 {
	void (*get)(struct virtio_device___4 *, unsigned int, void *, unsigned int);
	void (*set)(struct virtio_device___4 *, unsigned int, const void *, unsigned int);
	u32 (*generation)(struct virtio_device___4 *);
	u8 (*get_status)(struct virtio_device___4 *);
	void (*set_status)(struct virtio_device___4 *, u8);
	void (*reset)(struct virtio_device___4 *);
	int (*find_vqs)(struct virtio_device___4 *, unsigned int, struct virtqueue___4 **, vq_callback_t___4 **, const char * const *, const bool *, struct irq_affinity *);
	void (*del_vqs)(struct virtio_device___4 *);
	u64 (*get_features)(struct virtio_device___4 *);
	int (*finalize_features)(struct virtio_device___4 *);
	const char * (*bus_name)(struct virtio_device___4 *);
	int (*set_vq_affinity)(struct virtqueue___4 *, int);
	const struct cpumask * (*get_vq_affinity)(struct virtio_device___4 *, int);
};

struct virtio_pci_common_cfg {
	__le32 device_feature_select;
	__le32 device_feature;
	__le32 guest_feature_select;
	__le32 guest_feature;
	__le16 msix_config;
	__le16 num_queues;
	__u8 device_status;
	__u8 config_generation;
	__le16 queue_select;
	__le16 queue_size;
	__le16 queue_msix_vector;
	__le16 queue_enable;
	__le16 queue_notify_off;
	__le32 queue_desc_lo;
	__le32 queue_desc_hi;
	__le32 queue_avail_lo;
	__le32 queue_avail_hi;
	__le32 queue_used_lo;
	__le32 queue_used_hi;
};

struct virtio_pci_vq_info {
	struct virtqueue___4 *vq;
	struct list_head node;
	unsigned int msix_vector;
};

struct virtio_pci_device {
	struct virtio_device___4 vdev;
	struct pci_dev___27 *pci_dev;
	u8 *isr;
	struct virtio_pci_common_cfg *common;
	void *device;
	void *notify_base;
	size_t notify_len;
	size_t device_len;
	int notify_map_cap;
	u32 notify_offset_multiplier;
	int modern_bars;
	void *ioaddr;
	spinlock_t lock;
	struct list_head virtqueues;
	struct virtio_pci_vq_info **vqs;
	int msix_enabled;
	int intx_enabled;
	cpumask_var_t *msix_affinity_masks;
	char (*msix_names)[256];
	unsigned int msix_vectors;
	unsigned int msix_used_vectors;
	bool per_vq_vectors;
	struct virtqueue___4 * (*setup_vq)(struct virtio_pci_device *, struct virtio_pci_vq_info *, unsigned int, void (*)(struct virtqueue___4 *), const char *, bool, u16);
	void (*del_vq)(struct virtio_pci_vq_info *);
	u16 (*config_vector)(struct virtio_pci_device *, u16);
};

struct module_version_attribute___3 {
	struct module_attribute___246 mattr;
	const char *module_name;
	const char *version;
};

enum {
	VP_MSIX_CONFIG_VECTOR = 0,
	VP_MSIX_VQ_VECTOR = 1,
};

struct reset_controller_dev___2;

struct reset_control_ops___2 {
	int (*reset)(struct reset_controller_dev___2 *, long unsigned int);
	int (*assert)(struct reset_controller_dev___2 *, long unsigned int);
	int (*deassert)(struct reset_controller_dev___2 *, long unsigned int);
	int (*status)(struct reset_controller_dev___2 *, long unsigned int);
};

struct reset_controller_dev___2 {
	const struct reset_control_ops___2 *ops;
	struct module___254 *owner;
	struct list_head list;
	struct list_head reset_control_head;
	struct device___279 *dev;
	struct device_node___2 *of_node;
	int of_reset_n_cells;
	int (*of_xlate)(struct reset_controller_dev___2 *, const struct of_phandle_args___5 *);
	unsigned int nr_resets;
};

struct reset_control_lookup {
	struct list_head list;
	const char *provider;
	unsigned int index;
	const char *dev_id;
	const char *con_id;
};

struct reset_control {
	struct reset_controller_dev___2 *rcdev;
	struct list_head list;
	unsigned int id;
	struct kref refcnt;
	bool shared;
	bool array;
	atomic_t deassert_count;
	atomic_t triggered_count;
};

struct reset_control_array {
	struct reset_control base;
	unsigned int num_rstcs;
	struct reset_control *rstc[0];
};

struct module___257;

struct file___317;

struct kiocb___317;

struct poll_table_struct___193;

struct vm_area_struct___318;

struct inode___317;

struct file_lock___317;

struct page___318;

struct seq_file___268;

struct file_operations___317 {
	struct module___257 *owner;
	loff_t (*llseek)(struct file___317 *, loff_t, int);
	ssize_t (*read)(struct file___317 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___317 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___317 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___317 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___317 *, bool);
	int (*iterate)(struct file___317 *, struct dir_context *);
	int (*iterate_shared)(struct file___317 *, struct dir_context *);
	__poll_t (*poll)(struct file___317 *, struct poll_table_struct___193 *);
	long int (*unlocked_ioctl)(struct file___317 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___317 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___317 *, struct vm_area_struct___318 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___317 *, struct file___317 *);
	int (*flush)(struct file___317 *, fl_owner_t);
	int (*release)(struct inode___317 *, struct file___317 *);
	int (*fsync)(struct file___317 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___317 *, int);
	int (*lock)(struct file___317 *, int, struct file_lock___317 *);
	ssize_t (*sendpage)(struct file___317 *, struct page___318 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___317 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___317 *, int, struct file_lock___317 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___317 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___317 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___317 *, long int, struct file_lock___317 **, void **);
	long int (*fallocate)(struct file___317 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___268 *, struct file___317 *);
	ssize_t (*copy_file_range)(struct file___317 *, loff_t, struct file___317 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___317 *, loff_t, struct file___317 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___317 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct key___294;

struct user_struct___294 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___294 *uid_keyring;
	struct key___294 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vmacache___317 {
	u64 seqnum;
	struct vm_area_struct___318 *vmas[4];
};

struct page_frag___317 {
	struct page___318 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___317;

struct cred___294;

struct files_struct___17;

struct signal_struct___233;

struct task_struct___318 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___318 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___317 *mm;
	struct mm_struct___317 *active_mm;
	struct vmacache___317 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___318 *real_parent;
	struct task_struct___318 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___318 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___205 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___205 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___205 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___294 *ptracer_cred;
	const struct cred___294 *real_cred;
	const struct cred___294 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct___17 *files;
	struct nsproxy___254 *nsproxy;
	struct signal_struct___233 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___318 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___82 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___317 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___318 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___132 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct secondary_data___318 {
	void *stack;
	struct task_struct___318 *task;
	long int status;
};

typedef struct page___318 *pgtable_t___317;

struct address_space___316;

struct dev_pagemap___306;

struct page___318 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___316 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___318 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___317 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___317 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___306 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct vm_operations_struct___306;

struct vm_area_struct___318 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___318 *vm_next;
	struct vm_area_struct___318 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___317 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___306 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___317 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct rw_semaphore___318 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___318 *owner;
};

struct core_state___317;

struct mm_struct___317 {
	struct {
		struct vm_area_struct___318 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___317 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___318 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___317 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___318 *owner;
		struct user_namespace___3 *user_ns;
		struct file___317 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___317 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___294 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___294 *session_keyring;
	struct key___294 *process_keyring;
	struct key___294 *thread_keyring;
	struct key___294 *request_key_auth;
	void *security;
	struct user_struct___294 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct fdtable___17 {
	unsigned int max_fds;
	struct file___317 **fd;
	long unsigned int *close_on_exec;
	long unsigned int *open_fds;
	long unsigned int *full_fds_bits;
	struct callback_head rcu;
};

struct files_struct___17 {
	atomic_t count;
	bool resize_in_progress;
	wait_queue_head_t resize_wait;
	struct fdtable___17 *fdt;
	struct fdtable___17 fdtab;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t file_lock;
	unsigned int next_fd;
	long unsigned int close_on_exec_init[1];
	long unsigned int open_fds_init[1];
	long unsigned int full_fds_bits_init[1];
	struct file___317 *fd_array[64];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct tty_struct___22;

struct signal_struct___233 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___318 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___318 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___205 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___205 *tty_old_pgrp;
	int leader;
	struct tty_struct___22 *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___317 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___205 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

union thread_union___245 {
	struct task_struct___318 task;
	long unsigned int stack[8192];
};

typedef int (*key_restrict_link_func_t___295)(struct key___294 *, const struct key_type *, const union key_payload *, struct key___294 *);

struct key_restriction___294;

struct key___294 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___318 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___294 *restrict_link;
};

struct key_restriction___294 {
	key_restrict_link_func_t___295 check;
	struct key___294 *key;
	struct key_type *keytype;
};

struct device___283;

struct tty_driver___22;

struct tty_operations___22;

struct tty_ldisc___22;

struct fasync_struct___316;

struct tty_port___22;

struct tty_struct___22 {
	int magic;
	struct kref kref;
	struct device___283 *dev;
	struct tty_driver___22 *driver;
	const struct tty_operations___22 *ops;
	int index;
	struct ld_semaphore ldisc_sem;
	struct tty_ldisc___22 *ldisc;
	struct mutex atomic_write_lock;
	struct mutex legacy_mutex;
	struct mutex throttle_mutex;
	struct rw_semaphore___318 termios_rwsem;
	struct mutex winsize_mutex;
	spinlock_t ctrl_lock;
	spinlock_t flow_lock;
	struct ktermios termios;
	struct ktermios termios_locked;
	struct termiox *termiox;
	char name[64];
	struct pid___205 *pgrp;
	struct pid___205 *session;
	long unsigned int flags;
	int count;
	struct winsize winsize;
	long unsigned int stopped: 1;
	long unsigned int flow_stopped: 1;
	int: 30;
	long unsigned int unused: 62;
	int hw_stopped;
	long unsigned int ctrl_status: 8;
	long unsigned int packet: 1;
	int: 23;
	long unsigned int unused_ctrl: 55;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___22 *link;
	struct fasync_struct___316 *fasync;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	spinlock_t files_lock;
	struct list_head tty_files;
	int closing;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___22 *port;
};

struct dentry_operations___316;

struct super_block___316;

struct dentry___316 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___316 *d_parent;
	struct qstr d_name;
	struct inode___317 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___316 *d_op;
	struct super_block___316 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___316;

struct address_space___316 {
	struct inode___317 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___318 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___316 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___316;

struct block_device___316;

struct cdev___65;

struct inode___317 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___316 *i_op;
	struct super_block___316 *i_sb;
	struct address_space___316 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___318 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___317 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___316 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___316 *i_bdev;
		struct cdev___65 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___317;

struct dentry_operations___316 {
	int (*d_revalidate)(struct dentry___316 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___316 *, unsigned int);
	int (*d_hash)(const struct dentry___316 *, struct qstr *);
	int (*d_compare)(const struct dentry___316 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___316 *);
	int (*d_init)(struct dentry___316 *);
	void (*d_release)(struct dentry___316 *);
	void (*d_prune)(struct dentry___316 *);
	void (*d_iput)(struct dentry___316 *, struct inode___317 *);
	char * (*d_dname)(struct dentry___316 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___317 *);
	int (*d_manage)(const struct path___317 *, bool);
	struct dentry___316 * (*d_real)(struct dentry___316 *, const struct inode___317 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___316;

struct mem_dqinfo___316 {
	struct quota_format_type___316 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___316;

struct quota_info___316 {
	unsigned int flags;
	struct rw_semaphore___318 dqio_sem;
	struct inode___317 *files[3];
	struct mem_dqinfo___316 info[3];
	const struct quota_format_ops___316 *ops[3];
};

struct rcuwait___316 {
	struct task_struct___318 *task;
};

struct percpu_rw_semaphore___316 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___318 rw_sem;
	struct rcuwait___316 writer;
	int readers_block;
};

struct sb_writers___316 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___316 rw_sem[3];
};

struct file_system_type___316;

struct super_operations___316;

struct dquot_operations___316;

struct quotactl_ops___316;

struct super_block___316 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___316 *s_type;
	const struct super_operations___316 *s_op;
	const struct dquot_operations___316 *dq_op;
	const struct quotactl_ops___316 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___316 *s_root;
	struct rw_semaphore___318 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___316 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___316 s_dquot;
	struct sb_writers___316 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___316 *s_d_op;
	int cleancache_poolid;
	struct shrinker___119 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct path___317 {
	struct vfsmount *mnt;
	struct dentry___316 *dentry;
};

struct pglist_data___317;

struct lruvec___317 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___317 *pgdat;
};

struct zone___317 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___317 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___317 {
	struct zone___317 *zone;
	int zone_idx;
};

struct zonelist___317 {
	struct zoneref___317 _zonerefs[25];
};

struct pglist_data___317 {
	struct zone___317 node_zones[3];
	struct zonelist___317 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___318 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___318 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___317 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___317 {
	struct rw_semaphore___318 rwsem;
	struct notifier_block *head;
};

typedef int (*dev_page_fault_t___306)(struct vm_area_struct___318 *, long unsigned int, const struct page___318 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___306)(struct page___318 *, void *);

struct dev_pagemap___306 {
	dev_page_fault_t___306 page_fault;
	dev_page_free_t___306 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___283 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct file___317 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___317 f_path;
	struct inode___317 *f_inode;
	const struct file_operations___317 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___205 f_owner;
	const struct cred___294 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___316 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___306;

struct vm_operations_struct___306 {
	void (*open)(struct vm_area_struct___318 *);
	void (*close)(struct vm_area_struct___318 *);
	int (*split)(struct vm_area_struct___318 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___318 *);
	vm_fault_t (*fault)(struct vm_fault___306 *);
	vm_fault_t (*huge_fault)(struct vm_fault___306 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___306 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___318 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___306 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___306 *);
	int (*access)(struct vm_area_struct___318 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___318 *);
	int (*set_policy)(struct vm_area_struct___318 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___318 *, long unsigned int);
	struct page___318 * (*find_special_page)(struct vm_area_struct___318 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___317 {
	struct task_struct___318 *task;
	struct core_thread___317 *next;
};

struct core_state___317 {
	atomic_t nr_threads;
	struct core_thread___317 dumper;
	struct completion startup;
};

struct vm_fault___306 {
	struct vm_area_struct___318 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___318 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___318 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___317 prealloc_pte;
};

struct kiocb___317 {
	struct file___317 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___317 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___316 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___317 *ia_file;
};

struct dquot___316 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___316 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___316 {
	int qf_fmt_id;
	const struct quota_format_ops___316 *qf_ops;
	struct module___257 *qf_owner;
	struct quota_format_type___316 *qf_next;
};

struct quota_format_ops___316 {
	int (*check_quota_file)(struct super_block___316 *, int);
	int (*read_file_info)(struct super_block___316 *, int);
	int (*write_file_info)(struct super_block___316 *, int);
	int (*free_file_info)(struct super_block___316 *, int);
	int (*read_dqblk)(struct dquot___316 *);
	int (*commit_dqblk)(struct dquot___316 *);
	int (*release_dqblk)(struct dquot___316 *);
	int (*get_next_id)(struct super_block___316 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___316 {
	int (*write_dquot)(struct dquot___316 *);
	struct dquot___316 * (*alloc_dquot)(struct super_block___316 *, int);
	void (*destroy_dquot)(struct dquot___316 *);
	int (*acquire_dquot)(struct dquot___316 *);
	int (*release_dquot)(struct dquot___316 *);
	int (*mark_dirty)(struct dquot___316 *);
	int (*write_info)(struct super_block___316 *, int);
	qsize_t * (*get_reserved_space)(struct inode___317 *);
	int (*get_projid)(struct inode___317 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___317 *, qsize_t *);
	int (*get_next_id)(struct super_block___316 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___316 {
	int (*quota_on)(struct super_block___316 *, int, int, const struct path___317 *);
	int (*quota_off)(struct super_block___316 *, int);
	int (*quota_enable)(struct super_block___316 *, unsigned int);
	int (*quota_disable)(struct super_block___316 *, unsigned int);
	int (*quota_sync)(struct super_block___316 *, int);
	int (*set_info)(struct super_block___316 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___316 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___316 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___316 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___316 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___316 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___303;

struct kobj_type___303;

struct kernfs_node___311;

struct kobject___304 {
	const char *name;
	struct list_head entry;
	struct kobject___304 *parent;
	struct kset___303 *kset;
	struct kobj_type___303 *ktype;
	struct kernfs_node___311 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___254 {
	struct kobject___304 kobj;
	struct module___257 *mod;
	struct kobject___304 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___254 {
	struct module___257 *mod;
	struct latch_tree_node node;
};

struct module_layout___254 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___254 mtn;
};

struct module_attribute___254;

struct kernel_param___254;

struct module___257 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___254 mkobj;
	struct module_attribute___254 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___304 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___254 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___254 core_layout;
	struct module_layout___254 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___316 {
	int (*writepage)(struct page___318 *, struct writeback_control___3 *);
	int (*readpage)(struct file___317 *, struct page___318 *);
	int (*writepages)(struct address_space___316 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___318 *);
	int (*readpages)(struct file___317 *, struct address_space___316 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___317 *, struct address_space___316 *, loff_t, unsigned int, unsigned int, struct page___318 **, void **);
	int (*write_end)(struct file___317 *, struct address_space___316 *, loff_t, unsigned int, unsigned int, struct page___318 *, void *);
	sector_t (*bmap)(struct address_space___316 *, sector_t);
	void (*invalidatepage)(struct page___318 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___318 *, gfp_t);
	void (*freepage)(struct page___318 *);
	ssize_t (*direct_IO)(struct kiocb___317 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___316 *, struct page___318 *, struct page___318 *, enum migrate_mode);
	bool (*isolate_page)(struct page___318 *, isolate_mode_t);
	void (*putback_page)(struct page___318 *);
	int (*launder_page)(struct page___318 *);
	int (*is_partially_uptodate)(struct page___318 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___318 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___316 *, struct page___318 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___317 *, sector_t *);
	void (*swap_deactivate)(struct file___317 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___316 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___317 *bd_inode;
	struct super_block___316 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___316 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___65 {
	struct kobject___304 kobj;
	struct module___257 *owner;
	const struct file_operations___317 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___316 {
	struct dentry___316 * (*lookup)(struct inode___317 *, struct dentry___316 *, unsigned int);
	const char * (*get_link)(struct dentry___316 *, struct inode___317 *, struct delayed_call *);
	int (*permission)(struct inode___317 *, int);
	struct posix_acl * (*get_acl)(struct inode___317 *, int);
	int (*readlink)(struct dentry___316 *, char *, int);
	int (*create)(struct inode___317 *, struct dentry___316 *, umode_t, bool);
	int (*link)(struct dentry___316 *, struct inode___317 *, struct dentry___316 *);
	int (*unlink)(struct inode___317 *, struct dentry___316 *);
	int (*symlink)(struct inode___317 *, struct dentry___316 *, const char *);
	int (*mkdir)(struct inode___317 *, struct dentry___316 *, umode_t);
	int (*rmdir)(struct inode___317 *, struct dentry___316 *);
	int (*mknod)(struct inode___317 *, struct dentry___316 *, umode_t, dev_t);
	int (*rename)(struct inode___317 *, struct dentry___316 *, struct inode___317 *, struct dentry___316 *, unsigned int);
	int (*setattr)(struct dentry___316 *, struct iattr___316 *);
	int (*getattr)(const struct path___317 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___316 *, char *, size_t);
	int (*fiemap)(struct inode___317 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___317 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___317 *, struct dentry___316 *, struct file___317 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___317 *, struct dentry___316 *, umode_t);
	int (*set_acl)(struct inode___317 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___316 {
	void (*fl_copy_lock)(struct file_lock___317 *, struct file_lock___317 *);
	void (*fl_release_private)(struct file_lock___317 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___316;

struct file_lock___317 {
	struct file_lock___317 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___317 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___316 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___316 *fl_ops;
	const struct lock_manager_operations___316 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___316 {
	int (*lm_compare_owner)(struct file_lock___317 *, struct file_lock___317 *);
	long unsigned int (*lm_owner_key)(struct file_lock___317 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___317 *);
	int (*lm_grant)(struct file_lock___317 *, int);
	bool (*lm_break)(struct file_lock___317 *);
	int (*lm_change)(struct file_lock___317 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___317 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___316 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___316 *fa_next;
	struct file___317 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___316 {
	const char *name;
	int fs_flags;
	struct dentry___316 * (*mount)(struct file_system_type___316 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___316 *);
	struct module___257 *owner;
	struct file_system_type___316 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___316 {
	struct inode___317 * (*alloc_inode)(struct super_block___316 *);
	void (*destroy_inode)(struct inode___317 *);
	void (*dirty_inode)(struct inode___317 *, int);
	int (*write_inode)(struct inode___317 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___317 *);
	void (*evict_inode)(struct inode___317 *);
	void (*put_super)(struct super_block___316 *);
	int (*sync_fs)(struct super_block___316 *, int);
	int (*freeze_super)(struct super_block___316 *);
	int (*freeze_fs)(struct super_block___316 *);
	int (*thaw_super)(struct super_block___316 *);
	int (*unfreeze_fs)(struct super_block___316 *);
	int (*statfs)(struct dentry___316 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___316 *, int *, char *);
	void (*umount_begin)(struct super_block___316 *);
	int (*show_options)(struct seq_file___268 *, struct dentry___316 *);
	int (*show_devname)(struct seq_file___268 *, struct dentry___316 *);
	int (*show_path)(struct seq_file___268 *, struct dentry___316 *);
	int (*show_stats)(struct seq_file___268 *, struct dentry___316 *);
	ssize_t (*quota_read)(struct super_block___316 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___316 *, int, const char *, size_t, loff_t);
	struct dquot___316 ** (*get_dquots)(struct inode___317 *);
	int (*bdev_try_to_free_page)(struct super_block___316 *, struct page___318 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___316 *, struct shrink_control___119 *);
	long int (*free_cached_objects)(struct super_block___316 *, struct shrink_control___119 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___198)(struct file___317 *, wait_queue_head_t *, struct poll_table_struct___193 *);

struct poll_table_struct___193 {
	poll_queue_proc___198 _qproc;
	__poll_t _key;
};

struct seq_operations___267;

struct seq_file___268 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___267 *op;
	int poll_event;
	const struct file___317 *file;
	void *private;
};

struct kernfs_root___310;

struct kernfs_elem_dir___310 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___310 *root;
};

struct kernfs_syscall_ops___310;

struct kernfs_root___310 {
	struct kernfs_node___311 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___310 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___310 {
	struct kernfs_node___311 *target_kn;
};

struct kernfs_ops___310;

struct kernfs_elem_attr___310 {
	const struct kernfs_ops___310 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___311 *notify_next;
};

struct kernfs_node___311 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___311 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___310 dir;
		struct kernfs_elem_symlink___310 symlink;
		struct kernfs_elem_attr___310 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___310;

struct kernfs_ops___310 {
	int (*open)(struct kernfs_open_file___310 *);
	void (*release)(struct kernfs_open_file___310 *);
	int (*seq_show)(struct seq_file___268 *, void *);
	void * (*seq_start)(struct seq_file___268 *, loff_t *);
	void * (*seq_next)(struct seq_file___268 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___268 *, void *);
	ssize_t (*read)(struct kernfs_open_file___310 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___310 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___310 *, struct vm_area_struct___318 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___310 *, struct poll_table_struct___193 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___310 {
	int (*remount_fs)(struct kernfs_root___310 *, int *, char *);
	int (*show_options)(struct seq_file___268 *, struct kernfs_root___310 *);
	int (*mkdir)(struct kernfs_node___311 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___311 *);
	int (*rename)(struct kernfs_node___311 *, struct kernfs_node___311 *, const char *);
	int (*show_path)(struct seq_file___268 *, struct kernfs_node___311 *, struct kernfs_root___310 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___310 {
	struct kernfs_node___311 *kn;
	struct file___317 *file;
	struct seq_file___268 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___306 *vm_ops;
};

struct bin_attribute___280;

struct attribute_group___281 {
	const char *name;
	umode_t (*is_visible)(struct kobject___304 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___304 *, struct bin_attribute___280 *, int);
	struct attribute **attrs;
	struct bin_attribute___280 **bin_attrs;
};

struct bin_attribute___280 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___317 *, struct kobject___304 *, struct bin_attribute___280 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___317 *, struct kobject___304 *, struct bin_attribute___280 *, char *, loff_t, size_t);
	int (*mmap)(struct file___317 *, struct kobject___304 *, struct bin_attribute___280 *, struct vm_area_struct___318 *);
};

struct sysfs_ops___303 {
	ssize_t (*show)(struct kobject___304 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___304 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___303;

struct kset___303 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___304 kobj;
	const struct kset_uevent_ops___303 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___303 {
	void (*release)(struct kobject___304 *);
	const struct sysfs_ops___303 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___25 * (*child_ns_type)(struct kobject___304 *);
	const void * (*namespace)(struct kobject___304 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___303 {
	int (* const filter)(struct kset___303 *, struct kobject___304 *);
	const char * (* const name)(struct kset___303 *, struct kobject___304 *);
	int (* const uevent)(struct kset___303 *, struct kobject___304 *, struct kobj_uevent_env *);
};

struct kobj_attribute___296 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___304 *, struct kobj_attribute___296 *, char *);
	ssize_t (*store)(struct kobject___304 *, struct kobj_attribute___296 *, const char *, size_t);
};

struct dev_pm_ops___283 {
	int (*prepare)(struct device___283 *);
	void (*complete)(struct device___283 *);
	int (*suspend)(struct device___283 *);
	int (*resume)(struct device___283 *);
	int (*freeze)(struct device___283 *);
	int (*thaw)(struct device___283 *);
	int (*poweroff)(struct device___283 *);
	int (*restore)(struct device___283 *);
	int (*suspend_late)(struct device___283 *);
	int (*resume_early)(struct device___283 *);
	int (*freeze_late)(struct device___283 *);
	int (*thaw_early)(struct device___283 *);
	int (*poweroff_late)(struct device___283 *);
	int (*restore_early)(struct device___283 *);
	int (*suspend_noirq)(struct device___283 *);
	int (*resume_noirq)(struct device___283 *);
	int (*freeze_noirq)(struct device___283 *);
	int (*thaw_noirq)(struct device___283 *);
	int (*poweroff_noirq)(struct device___283 *);
	int (*restore_noirq)(struct device___283 *);
	int (*runtime_suspend)(struct device___283 *);
	int (*runtime_resume)(struct device___283 *);
	int (*runtime_idle)(struct device___283 *);
};

struct dev_pm_info___283 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___3 *subsys_data;
	void (*set_latency_tolerance)(struct device___283 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___283;

struct bus_type___283;

struct device_driver___283;

struct dev_pm_domain___283;

struct class___283;

struct device___283 {
	struct device___283 *parent;
	struct device_private *p;
	struct kobject___304 kobj;
	const char *init_name;
	const struct device_type___283 *type;
	struct mutex mutex;
	struct bus_type___283 *bus;
	struct device_driver___283 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___283 power;
	struct dev_pm_domain___283 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___283 *class;
	const struct attribute_group___281 **groups;
	void (*release)(struct device___283 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___283 {
	struct dev_pm_ops___283 ops;
	void (*detach)(struct device___283 *, bool);
	int (*activate)(struct device___283 *);
	void (*sync)(struct device___283 *);
	void (*dismiss)(struct device___283 *);
};

struct bus_type___283 {
	const char *name;
	const char *dev_name;
	struct device___283 *dev_root;
	const struct attribute_group___281 **bus_groups;
	const struct attribute_group___281 **dev_groups;
	const struct attribute_group___281 **drv_groups;
	int (*match)(struct device___283 *, struct device_driver___283 *);
	int (*uevent)(struct device___283 *, struct kobj_uevent_env *);
	int (*probe)(struct device___283 *);
	int (*remove)(struct device___283 *);
	void (*shutdown)(struct device___283 *);
	int (*online)(struct device___283 *);
	int (*offline)(struct device___283 *);
	int (*suspend)(struct device___283 *, pm_message_t);
	int (*resume)(struct device___283 *);
	int (*num_vf)(struct device___283 *);
	int (*dma_configure)(struct device___283 *);
	const struct dev_pm_ops___283 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___283 {
	const char *name;
	struct bus_type___283 *bus;
	struct module___257 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___283 *);
	int (*remove)(struct device___283 *);
	void (*shutdown)(struct device___283 *);
	int (*suspend)(struct device___283 *, pm_message_t);
	int (*resume)(struct device___283 *);
	const struct attribute_group___281 **groups;
	const struct dev_pm_ops___283 *pm;
	void (*coredump)(struct device___283 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___283 {
	const char *name;
	const struct attribute_group___281 **groups;
	int (*uevent)(struct device___283 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___283 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___283 *);
	const struct dev_pm_ops___283 *pm;
};

struct class___283 {
	const char *name;
	struct module___257 *owner;
	const struct attribute_group___281 **class_groups;
	const struct attribute_group___281 **dev_groups;
	struct kobject___304 *dev_kobj;
	int (*dev_uevent)(struct device___283 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___283 *, umode_t *);
	void (*class_release)(struct class___283 *);
	void (*dev_release)(struct device___283 *);
	int (*shutdown_pre)(struct device___283 *);
	const struct kobj_ns_type_operations___25 *ns_type;
	const void * (*namespace)(struct device___283 *);
	const struct dev_pm_ops___283 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct device_attribute___26 {
	struct attribute attr;
	ssize_t (*show)(struct device___283 *, struct device_attribute___26 *, char *);
	ssize_t (*store)(struct device___283 *, struct device_attribute___26 *, const char *, size_t);
};

struct seq_operations___267 {
	void * (*start)(struct seq_file___268 *, loff_t *);
	void (*stop)(struct seq_file___268 *, void *);
	void * (*next)(struct seq_file___268 *, void *, loff_t *);
	int (*show)(struct seq_file___268 *, void *);
};

struct tty_operations___22 {
	struct tty_struct___22 * (*lookup)(struct tty_driver___22 *, struct file___317 *, int);
	int (*install)(struct tty_driver___22 *, struct tty_struct___22 *);
	void (*remove)(struct tty_driver___22 *, struct tty_struct___22 *);
	int (*open)(struct tty_struct___22 *, struct file___317 *);
	void (*close)(struct tty_struct___22 *, struct file___317 *);
	void (*shutdown)(struct tty_struct___22 *);
	void (*cleanup)(struct tty_struct___22 *);
	int (*write)(struct tty_struct___22 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___22 *, unsigned char);
	void (*flush_chars)(struct tty_struct___22 *);
	int (*write_room)(struct tty_struct___22 *);
	int (*chars_in_buffer)(struct tty_struct___22 *);
	int (*ioctl)(struct tty_struct___22 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___22 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___22 *, struct ktermios *);
	void (*throttle)(struct tty_struct___22 *);
	void (*unthrottle)(struct tty_struct___22 *);
	void (*stop)(struct tty_struct___22 *);
	void (*start)(struct tty_struct___22 *);
	void (*hangup)(struct tty_struct___22 *);
	int (*break_ctl)(struct tty_struct___22 *, int);
	void (*flush_buffer)(struct tty_struct___22 *);
	void (*set_ldisc)(struct tty_struct___22 *);
	void (*wait_until_sent)(struct tty_struct___22 *, int);
	void (*send_xchar)(struct tty_struct___22 *, char);
	int (*tiocmget)(struct tty_struct___22 *);
	int (*tiocmset)(struct tty_struct___22 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___22 *, struct winsize *);
	int (*set_termiox)(struct tty_struct___22 *, struct termiox *);
	int (*get_icount)(struct tty_struct___22 *, struct serial_icounter_struct *);
	void (*show_fdinfo)(struct tty_struct___22 *, struct seq_file___268 *);
	int (*poll_init)(struct tty_driver___22 *, int, char *);
	int (*poll_get_char)(struct tty_driver___22 *, int);
	void (*poll_put_char)(struct tty_driver___22 *, int, char);
	int (*proc_show)(struct seq_file___268 *, void *);
};

struct tty_driver___22 {
	int magic;
	struct kref kref;
	struct cdev___65 **cdevs;
	struct module___257 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___22 *other;
	struct tty_struct___22 **ttys;
	struct tty_port___22 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___22 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___22;

struct tty_port_client_operations___22;

struct tty_port___22 {
	struct tty_bufhead buf;
	struct tty_struct___22 *tty;
	struct tty_struct___22 *itty;
	const struct tty_port_operations___22 *ops;
	const struct tty_port_client_operations___22 *client_ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	unsigned char low_latency: 1;
	struct mutex mutex;
	struct mutex buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
	void *client_data;
};

struct tty_ldisc_ops___22 {
	int magic;
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___22 *);
	void (*close)(struct tty_struct___22 *);
	void (*flush_buffer)(struct tty_struct___22 *);
	ssize_t (*read)(struct tty_struct___22 *, struct file___317 *, unsigned char *, size_t);
	ssize_t (*write)(struct tty_struct___22 *, struct file___317 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___22 *, struct file___317 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___22 *, struct file___317 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___22 *, struct ktermios *);
	__poll_t (*poll)(struct tty_struct___22 *, struct file___317 *, struct poll_table_struct___193 *);
	int (*hangup)(struct tty_struct___22 *);
	void (*receive_buf)(struct tty_struct___22 *, const unsigned char *, char *, int);
	void (*write_wakeup)(struct tty_struct___22 *);
	void (*dcd_change)(struct tty_struct___22 *, unsigned int);
	int (*receive_buf2)(struct tty_struct___22 *, const unsigned char *, char *, int);
	struct module___257 *owner;
	int refcount;
};

struct tty_ldisc___22 {
	struct tty_ldisc_ops___22 *ops;
	struct tty_struct___22 *tty;
};

struct tty_port_operations___22 {
	int (*carrier_raised)(struct tty_port___22 *);
	void (*dtr_rts)(struct tty_port___22 *, int);
	void (*shutdown)(struct tty_port___22 *);
	int (*activate)(struct tty_port___22 *, struct tty_struct___22 *);
	void (*destruct)(struct tty_port___22 *);
};

struct tty_port_client_operations___22 {
	int (*receive_buf)(struct tty_port___22 *, const unsigned char *, const unsigned char *, size_t);
	void (*write_wakeup)(struct tty_port___22 *);
};

struct tty_file_private___2 {
	struct tty_struct___22 *tty;
	struct file___317 *file;
	struct list_head list;
};

struct vc_data___4;

struct consw___16 {
	struct module___257 *owner;
	const char * (*con_startup)();
	void (*con_init)(struct vc_data___4 *, int);
	void (*con_deinit)(struct vc_data___4 *);
	void (*con_clear)(struct vc_data___4 *, int, int, int, int);
	void (*con_putc)(struct vc_data___4 *, int, int, int);
	void (*con_putcs)(struct vc_data___4 *, const short unsigned int *, int, int, int);
	void (*con_cursor)(struct vc_data___4 *, int);
	bool (*con_scroll)(struct vc_data___4 *, unsigned int, unsigned int, enum con_scroll, unsigned int);
	int (*con_switch)(struct vc_data___4 *);
	int (*con_blank)(struct vc_data___4 *, int, int);
	int (*con_font_set)(struct vc_data___4 *, struct console_font *, unsigned int);
	int (*con_font_get)(struct vc_data___4 *, struct console_font *);
	int (*con_font_default)(struct vc_data___4 *, struct console_font *, char *);
	int (*con_font_copy)(struct vc_data___4 *, int);
	int (*con_resize)(struct vc_data___4 *, unsigned int, unsigned int, unsigned int);
	void (*con_set_palette)(struct vc_data___4 *, const unsigned char *);
	void (*con_scrolldelta)(struct vc_data___4 *, int);
	int (*con_set_origin)(struct vc_data___4 *);
	void (*con_save_screen)(struct vc_data___4 *);
	u8 (*con_build_attr)(struct vc_data___4 *, u8, u8, u8, u8, u8, u8);
	void (*con_invert_region)(struct vc_data___4 *, u16 *, int);
	u16 * (*con_screen_pos)(struct vc_data___4 *, int);
	long unsigned int (*con_getxy)(struct vc_data___4 *, long unsigned int, int *, int *);
	void (*con_flush_scrollback)(struct vc_data___4 *);
	int (*con_debug_enter)(struct vc_data___4 *);
	int (*con_debug_leave)(struct vc_data___4 *);
};

struct vc_data___4 {
	struct tty_port___22 port;
	short unsigned int vc_num;
	unsigned int vc_cols;
	unsigned int vc_rows;
	unsigned int vc_size_row;
	unsigned int vc_scan_lines;
	long unsigned int vc_origin;
	long unsigned int vc_scr_end;
	long unsigned int vc_visible_origin;
	unsigned int vc_top;
	unsigned int vc_bottom;
	const struct consw___16 *vc_sw;
	short unsigned int *vc_screenbuf;
	unsigned int vc_screenbuf_size;
	unsigned char vc_mode;
	unsigned char vc_attr;
	unsigned char vc_def_color;
	unsigned char vc_color;
	unsigned char vc_s_color;
	unsigned char vc_ulcolor;
	unsigned char vc_itcolor;
	unsigned char vc_halfcolor;
	unsigned int vc_cursor_type;
	short unsigned int vc_complement_mask;
	short unsigned int vc_s_complement_mask;
	unsigned int vc_x;
	unsigned int vc_y;
	unsigned int vc_saved_x;
	unsigned int vc_saved_y;
	long unsigned int vc_pos;
	short unsigned int vc_hi_font_mask;
	struct console_font vc_font;
	short unsigned int vc_video_erase_char;
	unsigned int vc_state;
	unsigned int vc_npar;
	unsigned int vc_par[16];
	struct vt_mode vt_mode;
	struct pid___205 *vt_pid;
	int vt_newvt;
	wait_queue_head_t paste_wait;
	unsigned int vc_charset: 1;
	unsigned int vc_s_charset: 1;
	unsigned int vc_disp_ctrl: 1;
	unsigned int vc_toggle_meta: 1;
	unsigned int vc_decscnm: 1;
	unsigned int vc_decom: 1;
	unsigned int vc_decawm: 1;
	unsigned int vc_deccm: 1;
	unsigned int vc_decim: 1;
	unsigned int vc_intensity: 2;
	unsigned int vc_italic: 1;
	unsigned int vc_underline: 1;
	unsigned int vc_blink: 1;
	unsigned int vc_reverse: 1;
	unsigned int vc_s_intensity: 2;
	unsigned int vc_s_italic: 1;
	unsigned int vc_s_underline: 1;
	unsigned int vc_s_blink: 1;
	unsigned int vc_s_reverse: 1;
	unsigned int vc_ques: 1;
	unsigned int vc_need_wrap: 1;
	unsigned int vc_can_do_color: 1;
	unsigned int vc_report_mouse: 2;
	unsigned char vc_utf: 1;
	unsigned char vc_utf_count;
	int vc_utf_char;
	unsigned int vc_tab_stop[8];
	unsigned char vc_palette[48];
	short unsigned int *vc_translate;
	unsigned char vc_G0_charset;
	unsigned char vc_G1_charset;
	unsigned char vc_saved_G0;
	unsigned char vc_saved_G1;
	unsigned int vc_resize_user;
	unsigned int vc_bell_pitch;
	unsigned int vc_bell_duration;
	short unsigned int vc_cur_blink_ms;
	struct vc_data___4 **vc_display_fg;
	struct uni_pagedir *vc_uni_pagedir;
	struct uni_pagedir **vc_uni_pagedir_loc;
};

struct console___6 {
	char name[16];
	void (*write)(struct console___6 *, const char *, unsigned int);
	int (*read)(struct console___6 *, char *, unsigned int);
	struct tty_driver___22 * (*device)(struct console___6 *, int *);
	void (*unblank)();
	int (*setup)(struct console___6 *, char *);
	int (*match)(struct console___6 *, char *, int, char *);
	short int flags;
	short int index;
	int cflag;
	void *data;
	struct console___6 *next;
};

typedef void compound_page_dtor___306(struct page___318 *);

typedef struct poll_table_struct___193 poll_table___24;

struct kernel_param_ops___254 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___254 *);
	int (*get)(char *, const struct kernel_param___254 *);
	void (*free)(void *);
};

struct kparam_array___254;

struct kernel_param___254 {
	const char *name;
	struct module___257 *mod;
	const struct kernel_param_ops___254 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___254 *arr;
	};
};

struct kparam_array___254 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___254 *ops;
	void *elem;
};

struct module_attribute___254 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___254 *, struct module_kobject___254 *, char *);
	ssize_t (*store)(struct module_attribute___254 *, struct module_kobject___254 *, const char *, size_t);
	void (*setup)(struct module___257 *, const char *);
	int (*test)(struct module___257 *);
	void (*free)(struct module___257 *);
};

struct vc___3 {
	struct vc_data___4 *d;
	struct work_struct SAK_work;
};

struct module___258;

struct file___318;

struct kiocb___318;

struct poll_table_struct___194;

struct vm_area_struct___319;

struct inode___318;

struct file_lock___318;

struct page___319;

struct seq_file___269;

struct file_operations___318 {
	struct module___258 *owner;
	loff_t (*llseek)(struct file___318 *, loff_t, int);
	ssize_t (*read)(struct file___318 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___318 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___318 *, struct iov_iter___138 *);
	ssize_t (*write_iter)(struct kiocb___318 *, struct iov_iter___138 *);
	int (*iopoll)(struct kiocb___318 *, bool);
	int (*iterate)(struct file___318 *, struct dir_context *);
	int (*iterate_shared)(struct file___318 *, struct dir_context *);
	__poll_t (*poll)(struct file___318 *, struct poll_table_struct___194 *);
	long int (*unlocked_ioctl)(struct file___318 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___318 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___318 *, struct vm_area_struct___319 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___318 *, struct file___318 *);
	int (*flush)(struct file___318 *, fl_owner_t);
	int (*release)(struct inode___318 *, struct file___318 *);
	int (*fsync)(struct file___318 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___318 *, int);
	int (*lock)(struct file___318 *, int, struct file_lock___318 *);
	ssize_t (*sendpage)(struct file___318 *, struct page___319 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___318 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___318 *, int, struct file_lock___318 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___318 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___318 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___318 *, long int, struct file_lock___318 **, void **);
	long int (*fallocate)(struct file___318 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___269 *, struct file___318 *);
	ssize_t (*copy_file_range)(struct file___318 *, loff_t, struct file___318 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___318 *, loff_t, struct file___318 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___318 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct key___295;

struct user_struct___295 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___295 *uid_keyring;
	struct key___295 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vmacache___318 {
	u64 seqnum;
	struct vm_area_struct___319 *vmas[4];
};

struct page_frag___318 {
	struct page___319 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___318;

struct pid___206;

struct cred___295;

struct nsproxy___255;

struct signal_struct___234;

struct vm_struct___233;

struct task_struct___319 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___319 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___318 *mm;
	struct mm_struct___318 *active_mm;
	struct vmacache___318 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___319 *real_parent;
	struct task_struct___319 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___319 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___206 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___206 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___206 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___295 *ptracer_cred;
	const struct cred___295 *real_cred;
	const struct cred___295 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___255 *nsproxy;
	struct signal_struct___234 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___319 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___82 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___318 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___319 *oom_reaper_list;
	struct vm_struct___233 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___132 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___206;

struct upid___206 {
	int nr;
	struct pid_namespace___206 *ns;
};

struct dentry___317;

struct pid_namespace___206 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___319 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___206 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___317 *proc_self;
	struct dentry___317 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___3 *user_ns;
	struct ucounts___2 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___9 ns;
};

struct pid___206 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___206 numbers[1];
};

struct secondary_data___319 {
	void *stack;
	struct task_struct___319 *task;
	long int status;
};

typedef struct page___319 *pgtable_t___318;

struct address_space___317;

struct dev_pagemap___307;

struct page___319 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___317 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___319 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___318 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___318 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___307 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct vm_operations_struct___307;

struct vm_area_struct___319 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___319 *vm_next;
	struct vm_area_struct___319 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___318 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___307 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___318 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct rw_semaphore___319 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___319 *owner;
};

struct core_state___318;

struct mm_struct___318 {
	struct {
		struct vm_area_struct___319 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___318 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___319 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___318 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___319 *owner;
		struct user_namespace___3 *user_ns;
		struct file___318 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___318 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___295 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___295 *session_keyring;
	struct key___295 *process_keyring;
	struct key___295 *thread_keyring;
	struct key___295 *request_key_auth;
	void *security;
	struct user_struct___295 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct nsproxy___255 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___206 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct tty_struct___23;

struct signal_struct___234 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___319 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___319 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___206 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___206 *tty_old_pgrp;
	int leader;
	struct tty_struct___23 *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___318 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___206 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_struct___233 {
	struct vm_struct___233 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___319 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___246 {
	struct task_struct___319 task;
	long unsigned int stack[8192];
};

struct dentry_operations___317;

struct super_block___317;

struct dentry___317 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___317 *d_parent;
	struct qstr d_name;
	struct inode___318 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___317 *d_op;
	struct super_block___317 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___317;

struct address_space___317 {
	struct inode___318 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___319 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___317 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___317;

struct block_device___317;

struct cdev___66;

struct inode___318 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___317 *i_op;
	struct super_block___317 *i_sb;
	struct address_space___317 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___319 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___318 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___317 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___317 *i_bdev;
		struct cdev___66 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___318;

struct dentry_operations___317 {
	int (*d_revalidate)(struct dentry___317 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___317 *, unsigned int);
	int (*d_hash)(const struct dentry___317 *, struct qstr *);
	int (*d_compare)(const struct dentry___317 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___317 *);
	int (*d_init)(struct dentry___317 *);
	void (*d_release)(struct dentry___317 *);
	void (*d_prune)(struct dentry___317 *);
	void (*d_iput)(struct dentry___317 *, struct inode___318 *);
	char * (*d_dname)(struct dentry___317 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___318 *);
	int (*d_manage)(const struct path___318 *, bool);
	struct dentry___317 * (*d_real)(struct dentry___317 *, const struct inode___318 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___317;

struct mem_dqinfo___317 {
	struct quota_format_type___317 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___317;

struct quota_info___317 {
	unsigned int flags;
	struct rw_semaphore___319 dqio_sem;
	struct inode___318 *files[3];
	struct mem_dqinfo___317 info[3];
	const struct quota_format_ops___317 *ops[3];
};

struct rcuwait___317 {
	struct task_struct___319 *task;
};

struct percpu_rw_semaphore___317 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___319 rw_sem;
	struct rcuwait___317 writer;
	int readers_block;
};

struct sb_writers___317 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___317 rw_sem[3];
};

struct file_system_type___317;

struct super_operations___317;

struct dquot_operations___317;

struct quotactl_ops___317;

struct super_block___317 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___317 *s_type;
	const struct super_operations___317 *s_op;
	const struct dquot_operations___317 *dq_op;
	const struct quotactl_ops___317 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___317 *s_root;
	struct rw_semaphore___319 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___317 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___317 s_dquot;
	struct sb_writers___317 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___317 *s_d_op;
	int cleancache_poolid;
	struct shrinker___119 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct path___318 {
	struct vfsmount *mnt;
	struct dentry___317 *dentry;
};

struct pglist_data___318;

struct lruvec___318 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___318 *pgdat;
};

struct zone___318 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___318 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___318 {
	struct zone___318 *zone;
	int zone_idx;
};

struct zonelist___318 {
	struct zoneref___318 _zonerefs[25];
};

struct pglist_data___318 {
	struct zone___318 node_zones[3];
	struct zonelist___318 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___319 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___319 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___318 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___318 {
	struct rw_semaphore___319 rwsem;
	struct notifier_block *head;
};

typedef int (*dev_page_fault_t___307)(struct vm_area_struct___319 *, long unsigned int, const struct page___319 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___307)(struct page___319 *, void *);

struct device___284;

struct dev_pagemap___307 {
	dev_page_fault_t___307 page_fault;
	dev_page_free_t___307 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___284 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct fown_struct___206 {
	rwlock_t lock;
	struct pid___206 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___318 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___318 f_path;
	struct inode___318 *f_inode;
	const struct file_operations___318 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___206 f_owner;
	const struct cred___295 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___317 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___307;

struct vm_operations_struct___307 {
	void (*open)(struct vm_area_struct___319 *);
	void (*close)(struct vm_area_struct___319 *);
	int (*split)(struct vm_area_struct___319 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___319 *);
	vm_fault_t (*fault)(struct vm_fault___307 *);
	vm_fault_t (*huge_fault)(struct vm_fault___307 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___307 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___319 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___307 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___307 *);
	int (*access)(struct vm_area_struct___319 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___319 *);
	int (*set_policy)(struct vm_area_struct___319 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___319 *, long unsigned int);
	struct page___319 * (*find_special_page)(struct vm_area_struct___319 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___318 {
	struct task_struct___319 *task;
	struct core_thread___318 *next;
};

struct core_state___318 {
	atomic_t nr_threads;
	struct core_thread___318 dumper;
	struct completion startup;
};

struct vm_fault___307 {
	struct vm_area_struct___319 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___319 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___319 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___318 prealloc_pte;
};

struct kiocb___318 {
	struct file___318 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___318 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___317 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___318 *ia_file;
};

struct dquot___317 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___317 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___317 {
	int qf_fmt_id;
	const struct quota_format_ops___317 *qf_ops;
	struct module___258 *qf_owner;
	struct quota_format_type___317 *qf_next;
};

struct quota_format_ops___317 {
	int (*check_quota_file)(struct super_block___317 *, int);
	int (*read_file_info)(struct super_block___317 *, int);
	int (*write_file_info)(struct super_block___317 *, int);
	int (*free_file_info)(struct super_block___317 *, int);
	int (*read_dqblk)(struct dquot___317 *);
	int (*commit_dqblk)(struct dquot___317 *);
	int (*release_dqblk)(struct dquot___317 *);
	int (*get_next_id)(struct super_block___317 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___317 {
	int (*write_dquot)(struct dquot___317 *);
	struct dquot___317 * (*alloc_dquot)(struct super_block___317 *, int);
	void (*destroy_dquot)(struct dquot___317 *);
	int (*acquire_dquot)(struct dquot___317 *);
	int (*release_dquot)(struct dquot___317 *);
	int (*mark_dirty)(struct dquot___317 *);
	int (*write_info)(struct super_block___317 *, int);
	qsize_t * (*get_reserved_space)(struct inode___318 *);
	int (*get_projid)(struct inode___318 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___318 *, qsize_t *);
	int (*get_next_id)(struct super_block___317 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___317 {
	int (*quota_on)(struct super_block___317 *, int, int, const struct path___318 *);
	int (*quota_off)(struct super_block___317 *, int);
	int (*quota_enable)(struct super_block___317 *, unsigned int);
	int (*quota_disable)(struct super_block___317 *, unsigned int);
	int (*quota_sync)(struct super_block___317 *, int);
	int (*set_info)(struct super_block___317 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___317 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___317 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___317 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___317 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___317 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___304;

struct kobj_type___304;

struct kernfs_node___312;

struct kobject___305 {
	const char *name;
	struct list_head entry;
	struct kobject___305 *parent;
	struct kset___304 *kset;
	struct kobj_type___304 *ktype;
	struct kernfs_node___312 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___255 {
	struct kobject___305 kobj;
	struct module___258 *mod;
	struct kobject___305 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___255 {
	struct module___258 *mod;
	struct latch_tree_node node;
};

struct module_layout___255 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___255 mtn;
};

struct module_attribute___255;

struct kernel_param___255;

struct module___258 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___255 mkobj;
	struct module_attribute___255 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___305 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___255 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___255 core_layout;
	struct module_layout___255 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___317 {
	int (*writepage)(struct page___319 *, struct writeback_control___3 *);
	int (*readpage)(struct file___318 *, struct page___319 *);
	int (*writepages)(struct address_space___317 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___319 *);
	int (*readpages)(struct file___318 *, struct address_space___317 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___318 *, struct address_space___317 *, loff_t, unsigned int, unsigned int, struct page___319 **, void **);
	int (*write_end)(struct file___318 *, struct address_space___317 *, loff_t, unsigned int, unsigned int, struct page___319 *, void *);
	sector_t (*bmap)(struct address_space___317 *, sector_t);
	void (*invalidatepage)(struct page___319 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___319 *, gfp_t);
	void (*freepage)(struct page___319 *);
	ssize_t (*direct_IO)(struct kiocb___318 *, struct iov_iter___138 *);
	int (*migratepage)(struct address_space___317 *, struct page___319 *, struct page___319 *, enum migrate_mode);
	bool (*isolate_page)(struct page___319 *, isolate_mode_t);
	void (*putback_page)(struct page___319 *);
	int (*launder_page)(struct page___319 *);
	int (*is_partially_uptodate)(struct page___319 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___319 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___317 *, struct page___319 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___318 *, sector_t *);
	void (*swap_deactivate)(struct file___318 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___317 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___318 *bd_inode;
	struct super_block___317 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___317 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___66 {
	struct kobject___305 kobj;
	struct module___258 *owner;
	const struct file_operations___318 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___317 {
	struct dentry___317 * (*lookup)(struct inode___318 *, struct dentry___317 *, unsigned int);
	const char * (*get_link)(struct dentry___317 *, struct inode___318 *, struct delayed_call *);
	int (*permission)(struct inode___318 *, int);
	struct posix_acl * (*get_acl)(struct inode___318 *, int);
	int (*readlink)(struct dentry___317 *, char *, int);
	int (*create)(struct inode___318 *, struct dentry___317 *, umode_t, bool);
	int (*link)(struct dentry___317 *, struct inode___318 *, struct dentry___317 *);
	int (*unlink)(struct inode___318 *, struct dentry___317 *);
	int (*symlink)(struct inode___318 *, struct dentry___317 *, const char *);
	int (*mkdir)(struct inode___318 *, struct dentry___317 *, umode_t);
	int (*rmdir)(struct inode___318 *, struct dentry___317 *);
	int (*mknod)(struct inode___318 *, struct dentry___317 *, umode_t, dev_t);
	int (*rename)(struct inode___318 *, struct dentry___317 *, struct inode___318 *, struct dentry___317 *, unsigned int);
	int (*setattr)(struct dentry___317 *, struct iattr___317 *);
	int (*getattr)(const struct path___318 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___317 *, char *, size_t);
	int (*fiemap)(struct inode___318 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___318 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___318 *, struct dentry___317 *, struct file___318 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___318 *, struct dentry___317 *, umode_t);
	int (*set_acl)(struct inode___318 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___317 {
	void (*fl_copy_lock)(struct file_lock___318 *, struct file_lock___318 *);
	void (*fl_release_private)(struct file_lock___318 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___317;

struct lock_manager_operations___317;

struct file_lock___318 {
	struct file_lock___318 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___318 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___317 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___317 *fl_ops;
	const struct lock_manager_operations___317 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___317 {
	int (*lm_compare_owner)(struct file_lock___318 *, struct file_lock___318 *);
	long unsigned int (*lm_owner_key)(struct file_lock___318 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___318 *);
	int (*lm_grant)(struct file_lock___318 *, int);
	bool (*lm_break)(struct file_lock___318 *);
	int (*lm_change)(struct file_lock___318 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___318 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___317 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___317 *fa_next;
	struct file___318 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___317 {
	const char *name;
	int fs_flags;
	struct dentry___317 * (*mount)(struct file_system_type___317 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___317 *);
	struct module___258 *owner;
	struct file_system_type___317 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___317 {
	struct inode___318 * (*alloc_inode)(struct super_block___317 *);
	void (*destroy_inode)(struct inode___318 *);
	void (*dirty_inode)(struct inode___318 *, int);
	int (*write_inode)(struct inode___318 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___318 *);
	void (*evict_inode)(struct inode___318 *);
	void (*put_super)(struct super_block___317 *);
	int (*sync_fs)(struct super_block___317 *, int);
	int (*freeze_super)(struct super_block___317 *);
	int (*freeze_fs)(struct super_block___317 *);
	int (*thaw_super)(struct super_block___317 *);
	int (*unfreeze_fs)(struct super_block___317 *);
	int (*statfs)(struct dentry___317 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___317 *, int *, char *);
	void (*umount_begin)(struct super_block___317 *);
	int (*show_options)(struct seq_file___269 *, struct dentry___317 *);
	int (*show_devname)(struct seq_file___269 *, struct dentry___317 *);
	int (*show_path)(struct seq_file___269 *, struct dentry___317 *);
	int (*show_stats)(struct seq_file___269 *, struct dentry___317 *);
	ssize_t (*quota_read)(struct super_block___317 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___317 *, int, const char *, size_t, loff_t);
	struct dquot___317 ** (*get_dquots)(struct inode___318 *);
	int (*bdev_try_to_free_page)(struct super_block___317 *, struct page___319 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___317 *, struct shrink_control___119 *);
	long int (*free_cached_objects)(struct super_block___317 *, struct shrink_control___119 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___199)(struct file___318 *, wait_queue_head_t *, struct poll_table_struct___194 *);

struct poll_table_struct___194 {
	poll_queue_proc___199 _qproc;
	__poll_t _key;
};

struct seq_operations___268;

struct seq_file___269 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___268 *op;
	int poll_event;
	const struct file___318 *file;
	void *private;
};

struct kernfs_root___311;

struct kernfs_elem_dir___311 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___311 *root;
};

struct kernfs_syscall_ops___311;

struct kernfs_root___311 {
	struct kernfs_node___312 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___311 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___311 {
	struct kernfs_node___312 *target_kn;
};

struct kernfs_ops___311;

struct kernfs_elem_attr___311 {
	const struct kernfs_ops___311 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___312 *notify_next;
};

struct kernfs_node___312 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___312 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___311 dir;
		struct kernfs_elem_symlink___311 symlink;
		struct kernfs_elem_attr___311 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___311;

struct kernfs_ops___311 {
	int (*open)(struct kernfs_open_file___311 *);
	void (*release)(struct kernfs_open_file___311 *);
	int (*seq_show)(struct seq_file___269 *, void *);
	void * (*seq_start)(struct seq_file___269 *, loff_t *);
	void * (*seq_next)(struct seq_file___269 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___269 *, void *);
	ssize_t (*read)(struct kernfs_open_file___311 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___311 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___311 *, struct vm_area_struct___319 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___311 *, struct poll_table_struct___194 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___311 {
	int (*remount_fs)(struct kernfs_root___311 *, int *, char *);
	int (*show_options)(struct seq_file___269 *, struct kernfs_root___311 *);
	int (*mkdir)(struct kernfs_node___312 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___312 *);
	int (*rename)(struct kernfs_node___312 *, struct kernfs_node___312 *, const char *);
	int (*show_path)(struct seq_file___269 *, struct kernfs_node___312 *, struct kernfs_root___311 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___311 {
	struct kernfs_node___312 *kn;
	struct file___318 *file;
	struct seq_file___269 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___307 *vm_ops;
};

struct bin_attribute___281;

struct attribute_group___282 {
	const char *name;
	umode_t (*is_visible)(struct kobject___305 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___305 *, struct bin_attribute___281 *, int);
	struct attribute **attrs;
	struct bin_attribute___281 **bin_attrs;
};

struct bin_attribute___281 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___318 *, struct kobject___305 *, struct bin_attribute___281 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___318 *, struct kobject___305 *, struct bin_attribute___281 *, char *, loff_t, size_t);
	int (*mmap)(struct file___318 *, struct kobject___305 *, struct bin_attribute___281 *, struct vm_area_struct___319 *);
};

struct sysfs_ops___304 {
	ssize_t (*show)(struct kobject___305 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___305 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___304;

struct kset___304 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___305 kobj;
	const struct kset_uevent_ops___304 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___304 {
	void (*release)(struct kobject___305 *);
	const struct sysfs_ops___304 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___25 * (*child_ns_type)(struct kobject___305 *);
	const void * (*namespace)(struct kobject___305 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___304 {
	int (* const filter)(struct kset___304 *, struct kobject___305 *);
	const char * (* const name)(struct kset___304 *, struct kobject___305 *);
	int (* const uevent)(struct kset___304 *, struct kobject___305 *, struct kobj_uevent_env *);
};

struct kobj_attribute___297 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___305 *, struct kobj_attribute___297 *, char *);
	ssize_t (*store)(struct kobject___305 *, struct kobj_attribute___297 *, const char *, size_t);
};

struct dev_pm_ops___284 {
	int (*prepare)(struct device___284 *);
	void (*complete)(struct device___284 *);
	int (*suspend)(struct device___284 *);
	int (*resume)(struct device___284 *);
	int (*freeze)(struct device___284 *);
	int (*thaw)(struct device___284 *);
	int (*poweroff)(struct device___284 *);
	int (*restore)(struct device___284 *);
	int (*suspend_late)(struct device___284 *);
	int (*resume_early)(struct device___284 *);
	int (*freeze_late)(struct device___284 *);
	int (*thaw_early)(struct device___284 *);
	int (*poweroff_late)(struct device___284 *);
	int (*restore_early)(struct device___284 *);
	int (*suspend_noirq)(struct device___284 *);
	int (*resume_noirq)(struct device___284 *);
	int (*freeze_noirq)(struct device___284 *);
	int (*thaw_noirq)(struct device___284 *);
	int (*poweroff_noirq)(struct device___284 *);
	int (*restore_noirq)(struct device___284 *);
	int (*runtime_suspend)(struct device___284 *);
	int (*runtime_resume)(struct device___284 *);
	int (*runtime_idle)(struct device___284 *);
};

struct dev_pm_info___284 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___3 *subsys_data;
	void (*set_latency_tolerance)(struct device___284 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___284;

struct bus_type___284;

struct device_driver___284;

struct dev_pm_domain___284;

struct class___284;

struct device___284 {
	struct device___284 *parent;
	struct device_private *p;
	struct kobject___305 kobj;
	const char *init_name;
	const struct device_type___284 *type;
	struct mutex mutex;
	struct bus_type___284 *bus;
	struct device_driver___284 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___284 power;
	struct dev_pm_domain___284 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___284 *class;
	const struct attribute_group___282 **groups;
	void (*release)(struct device___284 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___284 {
	struct dev_pm_ops___284 ops;
	void (*detach)(struct device___284 *, bool);
	int (*activate)(struct device___284 *);
	void (*sync)(struct device___284 *);
	void (*dismiss)(struct device___284 *);
};

struct bus_type___284 {
	const char *name;
	const char *dev_name;
	struct device___284 *dev_root;
	const struct attribute_group___282 **bus_groups;
	const struct attribute_group___282 **dev_groups;
	const struct attribute_group___282 **drv_groups;
	int (*match)(struct device___284 *, struct device_driver___284 *);
	int (*uevent)(struct device___284 *, struct kobj_uevent_env *);
	int (*probe)(struct device___284 *);
	int (*remove)(struct device___284 *);
	void (*shutdown)(struct device___284 *);
	int (*online)(struct device___284 *);
	int (*offline)(struct device___284 *);
	int (*suspend)(struct device___284 *, pm_message_t);
	int (*resume)(struct device___284 *);
	int (*num_vf)(struct device___284 *);
	int (*dma_configure)(struct device___284 *);
	const struct dev_pm_ops___284 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___284 {
	const char *name;
	struct bus_type___284 *bus;
	struct module___258 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___284 *);
	int (*remove)(struct device___284 *);
	void (*shutdown)(struct device___284 *);
	int (*suspend)(struct device___284 *, pm_message_t);
	int (*resume)(struct device___284 *);
	const struct attribute_group___282 **groups;
	const struct dev_pm_ops___284 *pm;
	void (*coredump)(struct device___284 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___284 {
	const char *name;
	const struct attribute_group___282 **groups;
	int (*uevent)(struct device___284 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___284 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___284 *);
	const struct dev_pm_ops___284 *pm;
};

struct class___284 {
	const char *name;
	struct module___258 *owner;
	const struct attribute_group___282 **class_groups;
	const struct attribute_group___282 **dev_groups;
	struct kobject___305 *dev_kobj;
	int (*dev_uevent)(struct device___284 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___284 *, umode_t *);
	void (*class_release)(struct class___284 *);
	void (*dev_release)(struct device___284 *);
	int (*shutdown_pre)(struct device___284 *);
	const struct kobj_ns_type_operations___25 *ns_type;
	const void * (*namespace)(struct device___284 *);
	const struct dev_pm_ops___284 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

typedef int (*key_restrict_link_func_t___296)(struct key___295 *, const struct key_type *, const union key_payload *, struct key___295 *);

struct key_restriction___295;

struct key___295 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___319 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___295 *restrict_link;
};

struct key_restriction___295 {
	key_restrict_link_func_t___296 check;
	struct key___295 *key;
	struct key_type *keytype;
};

struct seq_operations___268 {
	void * (*start)(struct seq_file___269 *, loff_t *);
	void (*stop)(struct seq_file___269 *, void *);
	void * (*next)(struct seq_file___269 *, void *, loff_t *);
	int (*show)(struct seq_file___269 *, void *);
};

struct tty_driver___23;

struct tty_operations___23 {
	struct tty_struct___23 * (*lookup)(struct tty_driver___23 *, struct file___318 *, int);
	int (*install)(struct tty_driver___23 *, struct tty_struct___23 *);
	void (*remove)(struct tty_driver___23 *, struct tty_struct___23 *);
	int (*open)(struct tty_struct___23 *, struct file___318 *);
	void (*close)(struct tty_struct___23 *, struct file___318 *);
	void (*shutdown)(struct tty_struct___23 *);
	void (*cleanup)(struct tty_struct___23 *);
	int (*write)(struct tty_struct___23 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___23 *, unsigned char);
	void (*flush_chars)(struct tty_struct___23 *);
	int (*write_room)(struct tty_struct___23 *);
	int (*chars_in_buffer)(struct tty_struct___23 *);
	int (*ioctl)(struct tty_struct___23 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___23 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___23 *, struct ktermios *);
	void (*throttle)(struct tty_struct___23 *);
	void (*unthrottle)(struct tty_struct___23 *);
	void (*stop)(struct tty_struct___23 *);
	void (*start)(struct tty_struct___23 *);
	void (*hangup)(struct tty_struct___23 *);
	int (*break_ctl)(struct tty_struct___23 *, int);
	void (*flush_buffer)(struct tty_struct___23 *);
	void (*set_ldisc)(struct tty_struct___23 *);
	void (*wait_until_sent)(struct tty_struct___23 *, int);
	void (*send_xchar)(struct tty_struct___23 *, char);
	int (*tiocmget)(struct tty_struct___23 *);
	int (*tiocmset)(struct tty_struct___23 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___23 *, struct winsize *);
	int (*set_termiox)(struct tty_struct___23 *, struct termiox *);
	int (*get_icount)(struct tty_struct___23 *, struct serial_icounter_struct *);
	void (*show_fdinfo)(struct tty_struct___23 *, struct seq_file___269 *);
	int (*poll_init)(struct tty_driver___23 *, int, char *);
	int (*poll_get_char)(struct tty_driver___23 *, int);
	void (*poll_put_char)(struct tty_driver___23 *, int, char);
	int (*proc_show)(struct seq_file___269 *, void *);
};

struct tty_ldisc___23;

struct tty_port___23;

struct tty_struct___23 {
	int magic;
	struct kref kref;
	struct device___284 *dev;
	struct tty_driver___23 *driver;
	const struct tty_operations___23 *ops;
	int index;
	struct ld_semaphore ldisc_sem;
	struct tty_ldisc___23 *ldisc;
	struct mutex atomic_write_lock;
	struct mutex legacy_mutex;
	struct mutex throttle_mutex;
	struct rw_semaphore___319 termios_rwsem;
	struct mutex winsize_mutex;
	spinlock_t ctrl_lock;
	spinlock_t flow_lock;
	struct ktermios termios;
	struct ktermios termios_locked;
	struct termiox *termiox;
	char name[64];
	struct pid___206 *pgrp;
	struct pid___206 *session;
	long unsigned int flags;
	int count;
	struct winsize winsize;
	long unsigned int stopped: 1;
	long unsigned int flow_stopped: 1;
	int: 30;
	long unsigned int unused: 62;
	int hw_stopped;
	long unsigned int ctrl_status: 8;
	long unsigned int packet: 1;
	int: 23;
	long unsigned int unused_ctrl: 55;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___23 *link;
	struct fasync_struct___317 *fasync;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	spinlock_t files_lock;
	struct list_head tty_files;
	int closing;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___23 *port;
};

struct tty_driver___23 {
	int magic;
	struct kref kref;
	struct cdev___66 **cdevs;
	struct module___258 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___23 *other;
	struct tty_struct___23 **ttys;
	struct tty_port___23 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___23 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___23;

struct tty_port_client_operations___23;

struct tty_port___23 {
	struct tty_bufhead buf;
	struct tty_struct___23 *tty;
	struct tty_struct___23 *itty;
	const struct tty_port_operations___23 *ops;
	const struct tty_port_client_operations___23 *client_ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	unsigned char low_latency: 1;
	struct mutex mutex;
	struct mutex buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
	void *client_data;
};

struct tty_ldisc_ops___23 {
	int magic;
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___23 *);
	void (*close)(struct tty_struct___23 *);
	void (*flush_buffer)(struct tty_struct___23 *);
	ssize_t (*read)(struct tty_struct___23 *, struct file___318 *, unsigned char *, size_t);
	ssize_t (*write)(struct tty_struct___23 *, struct file___318 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___23 *, struct file___318 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___23 *, struct file___318 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___23 *, struct ktermios *);
	__poll_t (*poll)(struct tty_struct___23 *, struct file___318 *, struct poll_table_struct___194 *);
	int (*hangup)(struct tty_struct___23 *);
	void (*receive_buf)(struct tty_struct___23 *, const unsigned char *, char *, int);
	void (*write_wakeup)(struct tty_struct___23 *);
	void (*dcd_change)(struct tty_struct___23 *, unsigned int);
	int (*receive_buf2)(struct tty_struct___23 *, const unsigned char *, char *, int);
	struct module___258 *owner;
	int refcount;
};

struct tty_ldisc___23 {
	struct tty_ldisc_ops___23 *ops;
	struct tty_struct___23 *tty;
};

struct tty_port_operations___23 {
	int (*carrier_raised)(struct tty_port___23 *);
	void (*dtr_rts)(struct tty_port___23 *, int);
	void (*shutdown)(struct tty_port___23 *);
	int (*activate)(struct tty_port___23 *, struct tty_struct___23 *);
	void (*destruct)(struct tty_port___23 *);
};

struct tty_port_client_operations___23 {
	int (*receive_buf)(struct tty_port___23 *, const unsigned char *, const unsigned char *, size_t);
	void (*write_wakeup)(struct tty_port___23 *);
};

typedef void compound_page_dtor___307(struct page___319 *);

typedef struct poll_table_struct___194 poll_table___25;

struct kernel_param_ops___255 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___255 *);
	int (*get)(char *, const struct kernel_param___255 *);
	void (*free)(void *);
};

struct kparam_array___255;

struct kernel_param___255 {
	const char *name;
	struct module___258 *mod;
	const struct kernel_param_ops___255 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___255 *arr;
	};
};

struct kparam_array___255 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___255 *ops;
	void *elem;
};

struct module_attribute___255 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___255 *, struct module_kobject___255 *, char *);
	ssize_t (*store)(struct module_attribute___255 *, struct module_kobject___255 *, const char *, size_t);
	void (*setup)(struct module___258 *, const char *);
	int (*test)(struct module___258 *);
	void (*free)(struct module___258 *);
};

struct n_tty_data {
	size_t read_head;
	size_t commit_head;
	size_t canon_head;
	size_t echo_head;
	size_t echo_commit;
	size_t echo_mark;
	long unsigned int char_map[4];
	long unsigned int overrun_time;
	int num_overrun;
	bool no_room;
	unsigned char lnext: 1;
	unsigned char erasing: 1;
	unsigned char raw: 1;
	unsigned char real_raw: 1;
	unsigned char icanon: 1;
	unsigned char push: 1;
	char read_buf[4096];
	long unsigned int read_flags[64];
	unsigned char echo_buf[4096];
	size_t read_tail;
	size_t line_start;
	unsigned int column;
	unsigned int canon_column;
	size_t echo_tail;
	struct mutex atomic_read_lock;
	struct mutex output_lock;
};

enum {
	ERASE = 0,
	WERASE = 1,
	KILL = 2,
};

struct module___259;

struct file___319;

struct kiocb___319;

struct vm_area_struct___320;

struct inode___319;

struct file_lock___319;

struct page___320;

struct seq_file___270;

struct file_operations___319 {
	struct module___259 *owner;
	loff_t (*llseek)(struct file___319 *, loff_t, int);
	ssize_t (*read)(struct file___319 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___319 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___319 *, struct iov_iter___138 *);
	ssize_t (*write_iter)(struct kiocb___319 *, struct iov_iter___138 *);
	int (*iopoll)(struct kiocb___319 *, bool);
	int (*iterate)(struct file___319 *, struct dir_context *);
	int (*iterate_shared)(struct file___319 *, struct dir_context *);
	__poll_t (*poll)(struct file___319 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___319 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___319 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___319 *, struct vm_area_struct___320 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___319 *, struct file___319 *);
	int (*flush)(struct file___319 *, fl_owner_t);
	int (*release)(struct inode___319 *, struct file___319 *);
	int (*fsync)(struct file___319 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___319 *, int);
	int (*lock)(struct file___319 *, int, struct file_lock___319 *);
	ssize_t (*sendpage)(struct file___319 *, struct page___320 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___319 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___319 *, int, struct file_lock___319 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___319 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___319 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___319 *, long int, struct file_lock___319 **, void **);
	long int (*fallocate)(struct file___319 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___270 *, struct file___319 *);
	ssize_t (*copy_file_range)(struct file___319 *, loff_t, struct file___319 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___319 *, loff_t, struct file___319 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___319 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___319 {
	u64 seqnum;
	struct vm_area_struct___320 *vmas[4];
};

struct page_frag___319 {
	struct page___320 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___319;

struct cred___296;

struct signal_struct___235;

struct vm_struct___234;

struct task_struct___320 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___320 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___319 *mm;
	struct mm_struct___319 *active_mm;
	struct vmacache___319 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___320 *real_parent;
	struct task_struct___320 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___320 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___206 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___206 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___206 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___296 *ptracer_cred;
	const struct cred___296 *real_cred;
	const struct cred___296 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___235 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___320 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___82 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___319 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___320 *oom_reaper_list;
	struct vm_struct___234 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___132 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct secondary_data___320 {
	void *stack;
	struct task_struct___320 *task;
	long int status;
};

typedef struct page___320 *pgtable_t___319;

struct address_space___318;

struct dev_pagemap___308;

struct page___320 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___318 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___320 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___319 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___319 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___308 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct key___296;

struct user_struct___296 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___296 *uid_keyring;
	struct key___296 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___308;

struct vm_area_struct___320 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___320 *vm_next;
	struct vm_area_struct___320 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___319 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___308 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___319 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct rw_semaphore___320 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___320 *owner;
};

struct core_state___319;

struct mm_struct___319 {
	struct {
		struct vm_area_struct___320 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___319 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___320 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___319 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___320 *owner;
		struct user_namespace___3 *user_ns;
		struct file___319 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___319 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___296 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___296 *session_keyring;
	struct key___296 *process_keyring;
	struct key___296 *thread_keyring;
	struct key___296 *request_key_auth;
	void *security;
	struct user_struct___296 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct tty_struct___24;

struct signal_struct___235 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___320 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___320 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___206 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___206 *tty_old_pgrp;
	int leader;
	struct tty_struct___24 *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___319 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___206 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_struct___234 {
	struct vm_struct___234 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___320 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___247 {
	struct task_struct___320 task;
	long unsigned int stack[8192];
};

struct address_space_operations___318;

struct address_space___318 {
	struct inode___319 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___320 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___318 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___308)(struct vm_area_struct___320 *, long unsigned int, const struct page___320 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___308)(struct page___320 *, void *);

struct device___285;

struct dev_pagemap___308 {
	dev_page_fault_t___308 page_fault;
	dev_page_free_t___308 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___285 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct dentry___318;

struct path___319 {
	struct vfsmount *mnt;
	struct dentry___318 *dentry;
};

struct file___319 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___319 f_path;
	struct inode___319 *f_inode;
	const struct file_operations___319 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___206 f_owner;
	const struct cred___296 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___318 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___308;

struct vm_operations_struct___308 {
	void (*open)(struct vm_area_struct___320 *);
	void (*close)(struct vm_area_struct___320 *);
	int (*split)(struct vm_area_struct___320 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___320 *);
	vm_fault_t (*fault)(struct vm_fault___308 *);
	vm_fault_t (*huge_fault)(struct vm_fault___308 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___308 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___320 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___308 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___308 *);
	int (*access)(struct vm_area_struct___320 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___320 *);
	int (*set_policy)(struct vm_area_struct___320 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___320 *, long unsigned int);
	struct page___320 * (*find_special_page)(struct vm_area_struct___320 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___319 {
	struct task_struct___320 *task;
	struct core_thread___319 *next;
};

struct core_state___319 {
	atomic_t nr_threads;
	struct core_thread___319 dumper;
	struct completion startup;
};

struct vm_fault___308 {
	struct vm_area_struct___320 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___320 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___320 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___319 prealloc_pte;
};

struct termios {
	tcflag_t c_iflag;
	tcflag_t c_oflag;
	tcflag_t c_cflag;
	tcflag_t c_lflag;
	cc_t c_line;
	cc_t c_cc[19];
};

struct termios2 {
	tcflag_t c_iflag;
	tcflag_t c_oflag;
	tcflag_t c_cflag;
	tcflag_t c_lflag;
	cc_t c_line;
	cc_t c_cc[19];
	speed_t c_ispeed;
	speed_t c_ospeed;
};

struct termio {
	short unsigned int c_iflag;
	short unsigned int c_oflag;
	short unsigned int c_cflag;
	short unsigned int c_lflag;
	unsigned char c_line;
	unsigned char c_cc[8];
};

typedef int (*key_restrict_link_func_t___297)(struct key___296 *, const struct key_type *, const union key_payload *, struct key___296 *);

struct key_restriction___296;

struct key___296 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___320 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___296 *restrict_link;
};

struct key_restriction___296 {
	key_restrict_link_func_t___297 check;
	struct key___296 *key;
	struct key_type *keytype;
};

struct tty_driver___24;

struct tty_operations___24;

struct tty_ldisc___24;

struct fasync_struct___318;

struct tty_port___24;

struct tty_struct___24 {
	int magic;
	struct kref kref;
	struct device___285 *dev;
	struct tty_driver___24 *driver;
	const struct tty_operations___24 *ops;
	int index;
	struct ld_semaphore ldisc_sem;
	struct tty_ldisc___24 *ldisc;
	struct mutex atomic_write_lock;
	struct mutex legacy_mutex;
	struct mutex throttle_mutex;
	struct rw_semaphore___320 termios_rwsem;
	struct mutex winsize_mutex;
	spinlock_t ctrl_lock;
	spinlock_t flow_lock;
	struct ktermios termios;
	struct ktermios termios_locked;
	struct termiox *termiox;
	char name[64];
	struct pid___206 *pgrp;
	struct pid___206 *session;
	long unsigned int flags;
	int count;
	struct winsize winsize;
	long unsigned int stopped: 1;
	long unsigned int flow_stopped: 1;
	int: 30;
	long unsigned int unused: 62;
	int hw_stopped;
	long unsigned int ctrl_status: 8;
	long unsigned int packet: 1;
	int: 23;
	long unsigned int unused_ctrl: 55;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___24 *link;
	struct fasync_struct___318 *fasync;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	spinlock_t files_lock;
	struct list_head tty_files;
	int closing;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___24 *port;
};

struct dentry_operations___318;

struct super_block___318;

struct dentry___318 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___318 *d_parent;
	struct qstr d_name;
	struct inode___319 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___318 *d_op;
	struct super_block___318 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___318;

struct block_device___318;

struct cdev___67;

struct inode___319 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___318 *i_op;
	struct super_block___318 *i_sb;
	struct address_space___318 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___320 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___319 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___318 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___318 *i_bdev;
		struct cdev___67 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___318 {
	int (*d_revalidate)(struct dentry___318 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___318 *, unsigned int);
	int (*d_hash)(const struct dentry___318 *, struct qstr *);
	int (*d_compare)(const struct dentry___318 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___318 *);
	int (*d_init)(struct dentry___318 *);
	void (*d_release)(struct dentry___318 *);
	void (*d_prune)(struct dentry___318 *);
	void (*d_iput)(struct dentry___318 *, struct inode___319 *);
	char * (*d_dname)(struct dentry___318 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___319 *);
	int (*d_manage)(const struct path___319 *, bool);
	struct dentry___318 * (*d_real)(struct dentry___318 *, const struct inode___319 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___318;

struct mem_dqinfo___318 {
	struct quota_format_type___318 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___318;

struct quota_info___318 {
	unsigned int flags;
	struct rw_semaphore___320 dqio_sem;
	struct inode___319 *files[3];
	struct mem_dqinfo___318 info[3];
	const struct quota_format_ops___318 *ops[3];
};

struct rcuwait___318 {
	struct task_struct___320 *task;
};

struct percpu_rw_semaphore___318 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___320 rw_sem;
	struct rcuwait___318 writer;
	int readers_block;
};

struct sb_writers___318 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___318 rw_sem[3];
};

struct file_system_type___318;

struct super_operations___318;

struct dquot_operations___318;

struct quotactl_ops___318;

struct super_block___318 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___318 *s_type;
	const struct super_operations___318 *s_op;
	const struct dquot_operations___318 *dq_op;
	const struct quotactl_ops___318 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___318 *s_root;
	struct rw_semaphore___320 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___318 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___318 s_dquot;
	struct sb_writers___318 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___318 *s_d_op;
	int cleancache_poolid;
	struct shrinker___119 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct pglist_data___319;

struct lruvec___319 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___319 *pgdat;
};

struct zone___319 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___319 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___319 {
	struct zone___319 *zone;
	int zone_idx;
};

struct zonelist___319 {
	struct zoneref___319 _zonerefs[25];
};

struct pglist_data___319 {
	struct zone___319 node_zones[3];
	struct zonelist___319 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___320 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___320 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___319 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___319 {
	struct rw_semaphore___320 rwsem;
	struct notifier_block *head;
};

struct kiocb___319 {
	struct file___319 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___319 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___318 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___319 *ia_file;
};

struct dquot___318 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___318 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___318 {
	int qf_fmt_id;
	const struct quota_format_ops___318 *qf_ops;
	struct module___259 *qf_owner;
	struct quota_format_type___318 *qf_next;
};

struct quota_format_ops___318 {
	int (*check_quota_file)(struct super_block___318 *, int);
	int (*read_file_info)(struct super_block___318 *, int);
	int (*write_file_info)(struct super_block___318 *, int);
	int (*free_file_info)(struct super_block___318 *, int);
	int (*read_dqblk)(struct dquot___318 *);
	int (*commit_dqblk)(struct dquot___318 *);
	int (*release_dqblk)(struct dquot___318 *);
	int (*get_next_id)(struct super_block___318 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___318 {
	int (*write_dquot)(struct dquot___318 *);
	struct dquot___318 * (*alloc_dquot)(struct super_block___318 *, int);
	void (*destroy_dquot)(struct dquot___318 *);
	int (*acquire_dquot)(struct dquot___318 *);
	int (*release_dquot)(struct dquot___318 *);
	int (*mark_dirty)(struct dquot___318 *);
	int (*write_info)(struct super_block___318 *, int);
	qsize_t * (*get_reserved_space)(struct inode___319 *);
	int (*get_projid)(struct inode___319 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___319 *, qsize_t *);
	int (*get_next_id)(struct super_block___318 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___318 {
	int (*quota_on)(struct super_block___318 *, int, int, const struct path___319 *);
	int (*quota_off)(struct super_block___318 *, int);
	int (*quota_enable)(struct super_block___318 *, unsigned int);
	int (*quota_disable)(struct super_block___318 *, unsigned int);
	int (*quota_sync)(struct super_block___318 *, int);
	int (*set_info)(struct super_block___318 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___318 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___318 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___318 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___318 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___318 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___305;

struct kobj_type___305;

struct kernfs_node___313;

struct kobject___306 {
	const char *name;
	struct list_head entry;
	struct kobject___306 *parent;
	struct kset___305 *kset;
	struct kobj_type___305 *ktype;
	struct kernfs_node___313 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___256 {
	struct kobject___306 kobj;
	struct module___259 *mod;
	struct kobject___306 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___256 {
	struct module___259 *mod;
	struct latch_tree_node node;
};

struct module_layout___256 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___256 mtn;
};

struct module_attribute___256;

struct kernel_param___256;

struct module___259 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___256 mkobj;
	struct module_attribute___256 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___306 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___256 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___256 core_layout;
	struct module_layout___256 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___318 {
	int (*writepage)(struct page___320 *, struct writeback_control___3 *);
	int (*readpage)(struct file___319 *, struct page___320 *);
	int (*writepages)(struct address_space___318 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___320 *);
	int (*readpages)(struct file___319 *, struct address_space___318 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___319 *, struct address_space___318 *, loff_t, unsigned int, unsigned int, struct page___320 **, void **);
	int (*write_end)(struct file___319 *, struct address_space___318 *, loff_t, unsigned int, unsigned int, struct page___320 *, void *);
	sector_t (*bmap)(struct address_space___318 *, sector_t);
	void (*invalidatepage)(struct page___320 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___320 *, gfp_t);
	void (*freepage)(struct page___320 *);
	ssize_t (*direct_IO)(struct kiocb___319 *, struct iov_iter___138 *);
	int (*migratepage)(struct address_space___318 *, struct page___320 *, struct page___320 *, enum migrate_mode);
	bool (*isolate_page)(struct page___320 *, isolate_mode_t);
	void (*putback_page)(struct page___320 *);
	int (*launder_page)(struct page___320 *);
	int (*is_partially_uptodate)(struct page___320 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___320 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___318 *, struct page___320 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___319 *, sector_t *);
	void (*swap_deactivate)(struct file___319 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___318 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___319 *bd_inode;
	struct super_block___318 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___318 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___67 {
	struct kobject___306 kobj;
	struct module___259 *owner;
	const struct file_operations___319 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___318 {
	struct dentry___318 * (*lookup)(struct inode___319 *, struct dentry___318 *, unsigned int);
	const char * (*get_link)(struct dentry___318 *, struct inode___319 *, struct delayed_call *);
	int (*permission)(struct inode___319 *, int);
	struct posix_acl * (*get_acl)(struct inode___319 *, int);
	int (*readlink)(struct dentry___318 *, char *, int);
	int (*create)(struct inode___319 *, struct dentry___318 *, umode_t, bool);
	int (*link)(struct dentry___318 *, struct inode___319 *, struct dentry___318 *);
	int (*unlink)(struct inode___319 *, struct dentry___318 *);
	int (*symlink)(struct inode___319 *, struct dentry___318 *, const char *);
	int (*mkdir)(struct inode___319 *, struct dentry___318 *, umode_t);
	int (*rmdir)(struct inode___319 *, struct dentry___318 *);
	int (*mknod)(struct inode___319 *, struct dentry___318 *, umode_t, dev_t);
	int (*rename)(struct inode___319 *, struct dentry___318 *, struct inode___319 *, struct dentry___318 *, unsigned int);
	int (*setattr)(struct dentry___318 *, struct iattr___318 *);
	int (*getattr)(const struct path___319 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___318 *, char *, size_t);
	int (*fiemap)(struct inode___319 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___319 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___319 *, struct dentry___318 *, struct file___319 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___319 *, struct dentry___318 *, umode_t);
	int (*set_acl)(struct inode___319 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___318 {
	void (*fl_copy_lock)(struct file_lock___319 *, struct file_lock___319 *);
	void (*fl_release_private)(struct file_lock___319 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___318;

struct file_lock___319 {
	struct file_lock___319 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___319 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___318 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___318 *fl_ops;
	const struct lock_manager_operations___318 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___318 {
	int (*lm_compare_owner)(struct file_lock___319 *, struct file_lock___319 *);
	long unsigned int (*lm_owner_key)(struct file_lock___319 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___319 *);
	int (*lm_grant)(struct file_lock___319 *, int);
	bool (*lm_break)(struct file_lock___319 *);
	int (*lm_change)(struct file_lock___319 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___319 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___318 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___318 *fa_next;
	struct file___319 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___318 {
	const char *name;
	int fs_flags;
	struct dentry___318 * (*mount)(struct file_system_type___318 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___318 *);
	struct module___259 *owner;
	struct file_system_type___318 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___318 {
	struct inode___319 * (*alloc_inode)(struct super_block___318 *);
	void (*destroy_inode)(struct inode___319 *);
	void (*dirty_inode)(struct inode___319 *, int);
	int (*write_inode)(struct inode___319 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___319 *);
	void (*evict_inode)(struct inode___319 *);
	void (*put_super)(struct super_block___318 *);
	int (*sync_fs)(struct super_block___318 *, int);
	int (*freeze_super)(struct super_block___318 *);
	int (*freeze_fs)(struct super_block___318 *);
	int (*thaw_super)(struct super_block___318 *);
	int (*unfreeze_fs)(struct super_block___318 *);
	int (*statfs)(struct dentry___318 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___318 *, int *, char *);
	void (*umount_begin)(struct super_block___318 *);
	int (*show_options)(struct seq_file___270 *, struct dentry___318 *);
	int (*show_devname)(struct seq_file___270 *, struct dentry___318 *);
	int (*show_path)(struct seq_file___270 *, struct dentry___318 *);
	int (*show_stats)(struct seq_file___270 *, struct dentry___318 *);
	ssize_t (*quota_read)(struct super_block___318 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___318 *, int, const char *, size_t, loff_t);
	struct dquot___318 ** (*get_dquots)(struct inode___319 *);
	int (*bdev_try_to_free_page)(struct super_block___318 *, struct page___320 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___318 *, struct shrink_control___119 *);
	long int (*free_cached_objects)(struct super_block___318 *, struct shrink_control___119 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___269;

struct seq_file___270 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___269 *op;
	int poll_event;
	const struct file___319 *file;
	void *private;
};

struct kernfs_root___312;

struct kernfs_elem_dir___312 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___312 *root;
};

struct kernfs_syscall_ops___312;

struct kernfs_root___312 {
	struct kernfs_node___313 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___312 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___312 {
	struct kernfs_node___313 *target_kn;
};

struct kernfs_ops___312;

struct kernfs_elem_attr___312 {
	const struct kernfs_ops___312 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___313 *notify_next;
};

struct kernfs_node___313 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___313 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___312 dir;
		struct kernfs_elem_symlink___312 symlink;
		struct kernfs_elem_attr___312 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___312;

struct kernfs_ops___312 {
	int (*open)(struct kernfs_open_file___312 *);
	void (*release)(struct kernfs_open_file___312 *);
	int (*seq_show)(struct seq_file___270 *, void *);
	void * (*seq_start)(struct seq_file___270 *, loff_t *);
	void * (*seq_next)(struct seq_file___270 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___270 *, void *);
	ssize_t (*read)(struct kernfs_open_file___312 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___312 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___312 *, struct vm_area_struct___320 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___312 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___312 {
	int (*remount_fs)(struct kernfs_root___312 *, int *, char *);
	int (*show_options)(struct seq_file___270 *, struct kernfs_root___312 *);
	int (*mkdir)(struct kernfs_node___313 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___313 *);
	int (*rename)(struct kernfs_node___313 *, struct kernfs_node___313 *, const char *);
	int (*show_path)(struct seq_file___270 *, struct kernfs_node___313 *, struct kernfs_root___312 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___312 {
	struct kernfs_node___313 *kn;
	struct file___319 *file;
	struct seq_file___270 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___308 *vm_ops;
};

struct bin_attribute___282;

struct attribute_group___283 {
	const char *name;
	umode_t (*is_visible)(struct kobject___306 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___306 *, struct bin_attribute___282 *, int);
	struct attribute **attrs;
	struct bin_attribute___282 **bin_attrs;
};

struct bin_attribute___282 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___319 *, struct kobject___306 *, struct bin_attribute___282 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___319 *, struct kobject___306 *, struct bin_attribute___282 *, char *, loff_t, size_t);
	int (*mmap)(struct file___319 *, struct kobject___306 *, struct bin_attribute___282 *, struct vm_area_struct___320 *);
};

struct sysfs_ops___305 {
	ssize_t (*show)(struct kobject___306 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___306 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___305;

struct kset___305 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___306 kobj;
	const struct kset_uevent_ops___305 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___305 {
	void (*release)(struct kobject___306 *);
	const struct sysfs_ops___305 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___25 * (*child_ns_type)(struct kobject___306 *);
	const void * (*namespace)(struct kobject___306 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___305 {
	int (* const filter)(struct kset___305 *, struct kobject___306 *);
	const char * (* const name)(struct kset___305 *, struct kobject___306 *);
	int (* const uevent)(struct kset___305 *, struct kobject___306 *, struct kobj_uevent_env *);
};

struct kobj_attribute___298 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___306 *, struct kobj_attribute___298 *, char *);
	ssize_t (*store)(struct kobject___306 *, struct kobj_attribute___298 *, const char *, size_t);
};

struct dev_pm_ops___285 {
	int (*prepare)(struct device___285 *);
	void (*complete)(struct device___285 *);
	int (*suspend)(struct device___285 *);
	int (*resume)(struct device___285 *);
	int (*freeze)(struct device___285 *);
	int (*thaw)(struct device___285 *);
	int (*poweroff)(struct device___285 *);
	int (*restore)(struct device___285 *);
	int (*suspend_late)(struct device___285 *);
	int (*resume_early)(struct device___285 *);
	int (*freeze_late)(struct device___285 *);
	int (*thaw_early)(struct device___285 *);
	int (*poweroff_late)(struct device___285 *);
	int (*restore_early)(struct device___285 *);
	int (*suspend_noirq)(struct device___285 *);
	int (*resume_noirq)(struct device___285 *);
	int (*freeze_noirq)(struct device___285 *);
	int (*thaw_noirq)(struct device___285 *);
	int (*poweroff_noirq)(struct device___285 *);
	int (*restore_noirq)(struct device___285 *);
	int (*runtime_suspend)(struct device___285 *);
	int (*runtime_resume)(struct device___285 *);
	int (*runtime_idle)(struct device___285 *);
};

struct dev_pm_info___285 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___3 *subsys_data;
	void (*set_latency_tolerance)(struct device___285 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___285;

struct bus_type___285;

struct device_driver___285;

struct dev_pm_domain___285;

struct fwnode_handle___217;

struct class___285;

struct device___285 {
	struct device___285 *parent;
	struct device_private *p;
	struct kobject___306 kobj;
	const char *init_name;
	const struct device_type___285 *type;
	struct mutex mutex;
	struct bus_type___285 *bus;
	struct device_driver___285 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___285 power;
	struct dev_pm_domain___285 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___217 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___285 *class;
	const struct attribute_group___283 **groups;
	void (*release)(struct device___285 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___285 {
	struct dev_pm_ops___285 ops;
	void (*detach)(struct device___285 *, bool);
	int (*activate)(struct device___285 *);
	void (*sync)(struct device___285 *);
	void (*dismiss)(struct device___285 *);
};

struct bus_type___285 {
	const char *name;
	const char *dev_name;
	struct device___285 *dev_root;
	const struct attribute_group___283 **bus_groups;
	const struct attribute_group___283 **dev_groups;
	const struct attribute_group___283 **drv_groups;
	int (*match)(struct device___285 *, struct device_driver___285 *);
	int (*uevent)(struct device___285 *, struct kobj_uevent_env *);
	int (*probe)(struct device___285 *);
	int (*remove)(struct device___285 *);
	void (*shutdown)(struct device___285 *);
	int (*online)(struct device___285 *);
	int (*offline)(struct device___285 *);
	int (*suspend)(struct device___285 *, pm_message_t);
	int (*resume)(struct device___285 *);
	int (*num_vf)(struct device___285 *);
	int (*dma_configure)(struct device___285 *);
	const struct dev_pm_ops___285 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___285 {
	const char *name;
	struct bus_type___285 *bus;
	struct module___259 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___285 *);
	int (*remove)(struct device___285 *);
	void (*shutdown)(struct device___285 *);
	int (*suspend)(struct device___285 *, pm_message_t);
	int (*resume)(struct device___285 *);
	const struct attribute_group___283 **groups;
	const struct dev_pm_ops___285 *pm;
	void (*coredump)(struct device___285 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___285 {
	const char *name;
	const struct attribute_group___283 **groups;
	int (*uevent)(struct device___285 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___285 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___285 *);
	const struct dev_pm_ops___285 *pm;
};

struct class___285 {
	const char *name;
	struct module___259 *owner;
	const struct attribute_group___283 **class_groups;
	const struct attribute_group___283 **dev_groups;
	struct kobject___306 *dev_kobj;
	int (*dev_uevent)(struct device___285 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___285 *, umode_t *);
	void (*class_release)(struct class___285 *);
	void (*dev_release)(struct device___285 *);
	int (*shutdown_pre)(struct device___285 *);
	const struct kobj_ns_type_operations___25 *ns_type;
	const void * (*namespace)(struct device___285 *);
	const struct dev_pm_ops___285 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct fwnode_operations___217;

struct fwnode_handle___217 {
	struct fwnode_handle___217 *secondary;
	const struct fwnode_operations___217 *ops;
};

struct seq_operations___269 {
	void * (*start)(struct seq_file___270 *, loff_t *);
	void (*stop)(struct seq_file___270 *, void *);
	void * (*next)(struct seq_file___270 *, void *, loff_t *);
	int (*show)(struct seq_file___270 *, void *);
};

struct tty_operations___24 {
	struct tty_struct___24 * (*lookup)(struct tty_driver___24 *, struct file___319 *, int);
	int (*install)(struct tty_driver___24 *, struct tty_struct___24 *);
	void (*remove)(struct tty_driver___24 *, struct tty_struct___24 *);
	int (*open)(struct tty_struct___24 *, struct file___319 *);
	void (*close)(struct tty_struct___24 *, struct file___319 *);
	void (*shutdown)(struct tty_struct___24 *);
	void (*cleanup)(struct tty_struct___24 *);
	int (*write)(struct tty_struct___24 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___24 *, unsigned char);
	void (*flush_chars)(struct tty_struct___24 *);
	int (*write_room)(struct tty_struct___24 *);
	int (*chars_in_buffer)(struct tty_struct___24 *);
	int (*ioctl)(struct tty_struct___24 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___24 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___24 *, struct ktermios *);
	void (*throttle)(struct tty_struct___24 *);
	void (*unthrottle)(struct tty_struct___24 *);
	void (*stop)(struct tty_struct___24 *);
	void (*start)(struct tty_struct___24 *);
	void (*hangup)(struct tty_struct___24 *);
	int (*break_ctl)(struct tty_struct___24 *, int);
	void (*flush_buffer)(struct tty_struct___24 *);
	void (*set_ldisc)(struct tty_struct___24 *);
	void (*wait_until_sent)(struct tty_struct___24 *, int);
	void (*send_xchar)(struct tty_struct___24 *, char);
	int (*tiocmget)(struct tty_struct___24 *);
	int (*tiocmset)(struct tty_struct___24 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___24 *, struct winsize *);
	int (*set_termiox)(struct tty_struct___24 *, struct termiox *);
	int (*get_icount)(struct tty_struct___24 *, struct serial_icounter_struct *);
	void (*show_fdinfo)(struct tty_struct___24 *, struct seq_file___270 *);
	int (*poll_init)(struct tty_driver___24 *, int, char *);
	int (*poll_get_char)(struct tty_driver___24 *, int);
	void (*poll_put_char)(struct tty_driver___24 *, int, char);
	int (*proc_show)(struct seq_file___270 *, void *);
};

struct tty_driver___24 {
	int magic;
	struct kref kref;
	struct cdev___67 **cdevs;
	struct module___259 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___24 *other;
	struct tty_struct___24 **ttys;
	struct tty_port___24 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___24 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___24;

struct tty_port_client_operations___24;

struct tty_port___24 {
	struct tty_bufhead buf;
	struct tty_struct___24 *tty;
	struct tty_struct___24 *itty;
	const struct tty_port_operations___24 *ops;
	const struct tty_port_client_operations___24 *client_ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	unsigned char low_latency: 1;
	struct mutex mutex;
	struct mutex buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
	void *client_data;
};

struct tty_ldisc_ops___24 {
	int magic;
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___24 *);
	void (*close)(struct tty_struct___24 *);
	void (*flush_buffer)(struct tty_struct___24 *);
	ssize_t (*read)(struct tty_struct___24 *, struct file___319 *, unsigned char *, size_t);
	ssize_t (*write)(struct tty_struct___24 *, struct file___319 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___24 *, struct file___319 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___24 *, struct file___319 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___24 *, struct ktermios *);
	__poll_t (*poll)(struct tty_struct___24 *, struct file___319 *, struct poll_table_struct___6 *);
	int (*hangup)(struct tty_struct___24 *);
	void (*receive_buf)(struct tty_struct___24 *, const unsigned char *, char *, int);
	void (*write_wakeup)(struct tty_struct___24 *);
	void (*dcd_change)(struct tty_struct___24 *, unsigned int);
	int (*receive_buf2)(struct tty_struct___24 *, const unsigned char *, char *, int);
	struct module___259 *owner;
	int refcount;
};

struct tty_ldisc___24 {
	struct tty_ldisc_ops___24 *ops;
	struct tty_struct___24 *tty;
};

struct tty_port_operations___24 {
	int (*carrier_raised)(struct tty_port___24 *);
	void (*dtr_rts)(struct tty_port___24 *, int);
	void (*shutdown)(struct tty_port___24 *);
	int (*activate)(struct tty_port___24 *, struct tty_struct___24 *);
	void (*destruct)(struct tty_port___24 *);
};

struct tty_port_client_operations___24 {
	int (*receive_buf)(struct tty_port___24 *, const unsigned char *, const unsigned char *, size_t);
	void (*write_wakeup)(struct tty_port___24 *);
};

typedef void compound_page_dtor___308(struct page___320 *);

struct kernel_param_ops___256 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___256 *);
	int (*get)(char *, const struct kernel_param___256 *);
	void (*free)(void *);
};

struct kparam_array___256;

struct kernel_param___256 {
	const char *name;
	struct module___259 *mod;
	const struct kernel_param_ops___256 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___256 *arr;
	};
};

struct kparam_array___256 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___256 *ops;
	void *elem;
};

struct module_attribute___256 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___256 *, struct module_kobject___256 *, char *);
	ssize_t (*store)(struct module_attribute___256 *, struct module_kobject___256 *, const char *, size_t);
	void (*setup)(struct module___259 *, const char *);
	int (*test)(struct module___259 *);
	void (*free)(struct module___259 *);
};

struct fwnode_reference_args___217;

struct fwnode_endpoint___217;

struct fwnode_operations___217 {
	struct fwnode_handle___217 * (*get)(struct fwnode_handle___217 *);
	void (*put)(struct fwnode_handle___217 *);
	bool (*device_is_available)(const struct fwnode_handle___217 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___217 *, const struct device___285 *);
	bool (*property_present)(const struct fwnode_handle___217 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___217 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___217 *, const char *, const char **, size_t);
	struct fwnode_handle___217 * (*get_parent)(const struct fwnode_handle___217 *);
	struct fwnode_handle___217 * (*get_next_child_node)(const struct fwnode_handle___217 *, struct fwnode_handle___217 *);
	struct fwnode_handle___217 * (*get_named_child_node)(const struct fwnode_handle___217 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___217 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___217 *);
	struct fwnode_handle___217 * (*graph_get_next_endpoint)(const struct fwnode_handle___217 *, struct fwnode_handle___217 *);
	struct fwnode_handle___217 * (*graph_get_remote_endpoint)(const struct fwnode_handle___217 *);
	struct fwnode_handle___217 * (*graph_get_port_parent)(struct fwnode_handle___217 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___217 *, struct fwnode_endpoint___217 *);
};

struct fwnode_endpoint___217 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___217 *local_fwnode;
};

struct fwnode_reference_args___217 {
	struct fwnode_handle___217 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct module___260;

struct file___320;

struct kiocb___320;

struct poll_table_struct___195;

struct vm_area_struct___321;

struct inode___320;

struct file_lock___320;

struct page___321;

struct seq_file___271;

struct file_operations___320 {
	struct module___260 *owner;
	loff_t (*llseek)(struct file___320 *, loff_t, int);
	ssize_t (*read)(struct file___320 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___320 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___320 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___320 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___320 *, bool);
	int (*iterate)(struct file___320 *, struct dir_context *);
	int (*iterate_shared)(struct file___320 *, struct dir_context *);
	__poll_t (*poll)(struct file___320 *, struct poll_table_struct___195 *);
	long int (*unlocked_ioctl)(struct file___320 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___320 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___320 *, struct vm_area_struct___321 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___320 *, struct file___320 *);
	int (*flush)(struct file___320 *, fl_owner_t);
	int (*release)(struct inode___320 *, struct file___320 *);
	int (*fsync)(struct file___320 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___320 *, int);
	int (*lock)(struct file___320 *, int, struct file_lock___320 *);
	ssize_t (*sendpage)(struct file___320 *, struct page___321 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___320 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___320 *, int, struct file_lock___320 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___320 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___320 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___320 *, long int, struct file_lock___320 **, void **);
	long int (*fallocate)(struct file___320 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___271 *, struct file___320 *);
	ssize_t (*copy_file_range)(struct file___320 *, loff_t, struct file___320 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___320 *, loff_t, struct file___320 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___320 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___320 {
	u64 seqnum;
	struct vm_area_struct___321 *vmas[4];
};

struct page_frag___320 {
	struct page___321 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___320;

struct cred___297;

struct task_struct___321 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___321 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___320 *mm;
	struct mm_struct___320 *active_mm;
	struct vmacache___320 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___321 *real_parent;
	struct task_struct___321 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___321 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___206 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___206 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___206 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___297 *ptracer_cred;
	const struct cred___297 *real_cred;
	const struct cred___297 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___321 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___82 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___320 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___321 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___132 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___321 *pgtable_t___320;

struct address_space___319;

struct dev_pagemap___309;

struct page___321 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___319 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___321 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___320 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___320 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___309 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___320;

struct lruvec___320 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___320 *pgdat;
};

struct zone___320 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___320 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___320 {
	struct zone___320 *zone;
	int zone_idx;
};

struct zonelist___320 {
	struct zoneref___320 _zonerefs[25];
};

struct pglist_data___320 {
	struct zone___320 node_zones[3];
	struct zonelist___320 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___321 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___321 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___320 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___321 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___321 *owner;
};

struct secondary_data___321 {
	void *stack;
	struct task_struct___321 *task;
	long int status;
};

struct blocking_notifier_head___320 {
	struct rw_semaphore___321 rwsem;
	struct notifier_block *head;
};

struct dentry___319;

struct path___320 {
	struct vfsmount *mnt;
	struct dentry___319 *dentry;
};

struct file___320 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___320 f_path;
	struct inode___320 *f_inode;
	const struct file_operations___320 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___206 f_owner;
	const struct cred___297 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___319 *f_mapping;
	errseq_t f_wb_err;
};

struct key___297;

struct user_struct___297;

struct cred___297 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___297 *session_keyring;
	struct key___297 *process_keyring;
	struct key___297 *thread_keyring;
	struct key___297 *request_key_auth;
	void *security;
	struct user_struct___297 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct user_struct___297 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___297 *uid_keyring;
	struct key___297 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___309;

struct vm_area_struct___321 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___321 *vm_next;
	struct vm_area_struct___321 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___320 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___309 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___320 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___320;

struct mm_struct___320 {
	struct {
		struct vm_area_struct___321 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___320 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___321 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___320 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___321 *owner;
		struct user_namespace___3 *user_ns;
		struct file___320 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___320 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct dentry_operations___319;

struct super_block___319;

struct dentry___319 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___319 *d_parent;
	struct qstr d_name;
	struct inode___320 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___319 *d_op;
	struct super_block___319 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___319;

struct address_space___319 {
	struct inode___320 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___321 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___319 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___319;

struct block_device___319;

struct cdev___68;

struct inode___320 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___319 *i_op;
	struct super_block___319 *i_sb;
	struct address_space___319 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___321 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___320 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___319 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___319 *i_bdev;
		struct cdev___68 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___319 {
	int (*d_revalidate)(struct dentry___319 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___319 *, unsigned int);
	int (*d_hash)(const struct dentry___319 *, struct qstr *);
	int (*d_compare)(const struct dentry___319 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___319 *);
	int (*d_init)(struct dentry___319 *);
	void (*d_release)(struct dentry___319 *);
	void (*d_prune)(struct dentry___319 *);
	void (*d_iput)(struct dentry___319 *, struct inode___320 *);
	char * (*d_dname)(struct dentry___319 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___320 *);
	int (*d_manage)(const struct path___320 *, bool);
	struct dentry___319 * (*d_real)(struct dentry___319 *, const struct inode___320 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___319;

struct mem_dqinfo___319 {
	struct quota_format_type___319 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___319;

struct quota_info___319 {
	unsigned int flags;
	struct rw_semaphore___321 dqio_sem;
	struct inode___320 *files[3];
	struct mem_dqinfo___319 info[3];
	const struct quota_format_ops___319 *ops[3];
};

struct rcuwait___319 {
	struct task_struct___321 *task;
};

struct percpu_rw_semaphore___319 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___321 rw_sem;
	struct rcuwait___319 writer;
	int readers_block;
};

struct sb_writers___319 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___319 rw_sem[3];
};

struct file_system_type___319;

struct super_operations___319;

struct dquot_operations___319;

struct quotactl_ops___319;

struct super_block___319 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___319 *s_type;
	const struct super_operations___319 *s_op;
	const struct dquot_operations___319 *dq_op;
	const struct quotactl_ops___319 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___319 *s_root;
	struct rw_semaphore___321 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___319 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___319 s_dquot;
	struct sb_writers___319 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___319 *s_d_op;
	int cleancache_poolid;
	struct shrinker___119 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

typedef int (*dev_page_fault_t___309)(struct vm_area_struct___321 *, long unsigned int, const struct page___321 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___309)(struct page___321 *, void *);

struct device___286;

struct dev_pagemap___309 {
	dev_page_fault_t___309 page_fault;
	dev_page_free_t___309 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___286 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct vm_fault___309;

struct vm_operations_struct___309 {
	void (*open)(struct vm_area_struct___321 *);
	void (*close)(struct vm_area_struct___321 *);
	int (*split)(struct vm_area_struct___321 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___321 *);
	vm_fault_t (*fault)(struct vm_fault___309 *);
	vm_fault_t (*huge_fault)(struct vm_fault___309 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___309 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___321 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___309 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___309 *);
	int (*access)(struct vm_area_struct___321 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___321 *);
	int (*set_policy)(struct vm_area_struct___321 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___321 *, long unsigned int);
	struct page___321 * (*find_special_page)(struct vm_area_struct___321 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___320 {
	struct task_struct___321 *task;
	struct core_thread___320 *next;
};

struct core_state___320 {
	atomic_t nr_threads;
	struct core_thread___320 dumper;
	struct completion startup;
};

struct vm_fault___309 {
	struct vm_area_struct___321 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___321 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___321 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___320 prealloc_pte;
};

struct kiocb___320 {
	struct file___320 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___320 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___319 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___320 *ia_file;
};

struct dquot___319 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___319 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___319 {
	int qf_fmt_id;
	const struct quota_format_ops___319 *qf_ops;
	struct module___260 *qf_owner;
	struct quota_format_type___319 *qf_next;
};

struct quota_format_ops___319 {
	int (*check_quota_file)(struct super_block___319 *, int);
	int (*read_file_info)(struct super_block___319 *, int);
	int (*write_file_info)(struct super_block___319 *, int);
	int (*free_file_info)(struct super_block___319 *, int);
	int (*read_dqblk)(struct dquot___319 *);
	int (*commit_dqblk)(struct dquot___319 *);
	int (*release_dqblk)(struct dquot___319 *);
	int (*get_next_id)(struct super_block___319 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___319 {
	int (*write_dquot)(struct dquot___319 *);
	struct dquot___319 * (*alloc_dquot)(struct super_block___319 *, int);
	void (*destroy_dquot)(struct dquot___319 *);
	int (*acquire_dquot)(struct dquot___319 *);
	int (*release_dquot)(struct dquot___319 *);
	int (*mark_dirty)(struct dquot___319 *);
	int (*write_info)(struct super_block___319 *, int);
	qsize_t * (*get_reserved_space)(struct inode___320 *);
	int (*get_projid)(struct inode___320 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___320 *, qsize_t *);
	int (*get_next_id)(struct super_block___319 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___319 {
	int (*quota_on)(struct super_block___319 *, int, int, const struct path___320 *);
	int (*quota_off)(struct super_block___319 *, int);
	int (*quota_enable)(struct super_block___319 *, unsigned int);
	int (*quota_disable)(struct super_block___319 *, unsigned int);
	int (*quota_sync)(struct super_block___319 *, int);
	int (*set_info)(struct super_block___319 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___319 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___319 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___319 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___319 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___319 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___306;

struct kobj_type___306;

struct kernfs_node___314;

struct kobject___307 {
	const char *name;
	struct list_head entry;
	struct kobject___307 *parent;
	struct kset___306 *kset;
	struct kobj_type___306 *ktype;
	struct kernfs_node___314 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___257 {
	struct kobject___307 kobj;
	struct module___260 *mod;
	struct kobject___307 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___257 {
	struct module___260 *mod;
	struct latch_tree_node node;
};

struct module_layout___257 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___257 mtn;
};

struct module_attribute___257;

struct kernel_param___257;

struct module___260 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___257 mkobj;
	struct module_attribute___257 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___307 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___257 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___257 core_layout;
	struct module_layout___257 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___319 {
	int (*writepage)(struct page___321 *, struct writeback_control___3 *);
	int (*readpage)(struct file___320 *, struct page___321 *);
	int (*writepages)(struct address_space___319 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___321 *);
	int (*readpages)(struct file___320 *, struct address_space___319 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___320 *, struct address_space___319 *, loff_t, unsigned int, unsigned int, struct page___321 **, void **);
	int (*write_end)(struct file___320 *, struct address_space___319 *, loff_t, unsigned int, unsigned int, struct page___321 *, void *);
	sector_t (*bmap)(struct address_space___319 *, sector_t);
	void (*invalidatepage)(struct page___321 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___321 *, gfp_t);
	void (*freepage)(struct page___321 *);
	ssize_t (*direct_IO)(struct kiocb___320 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___319 *, struct page___321 *, struct page___321 *, enum migrate_mode);
	bool (*isolate_page)(struct page___321 *, isolate_mode_t);
	void (*putback_page)(struct page___321 *);
	int (*launder_page)(struct page___321 *);
	int (*is_partially_uptodate)(struct page___321 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___321 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___319 *, struct page___321 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___320 *, sector_t *);
	void (*swap_deactivate)(struct file___320 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___319 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___320 *bd_inode;
	struct super_block___319 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___319 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___68 {
	struct kobject___307 kobj;
	struct module___260 *owner;
	const struct file_operations___320 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___319 {
	struct dentry___319 * (*lookup)(struct inode___320 *, struct dentry___319 *, unsigned int);
	const char * (*get_link)(struct dentry___319 *, struct inode___320 *, struct delayed_call *);
	int (*permission)(struct inode___320 *, int);
	struct posix_acl * (*get_acl)(struct inode___320 *, int);
	int (*readlink)(struct dentry___319 *, char *, int);
	int (*create)(struct inode___320 *, struct dentry___319 *, umode_t, bool);
	int (*link)(struct dentry___319 *, struct inode___320 *, struct dentry___319 *);
	int (*unlink)(struct inode___320 *, struct dentry___319 *);
	int (*symlink)(struct inode___320 *, struct dentry___319 *, const char *);
	int (*mkdir)(struct inode___320 *, struct dentry___319 *, umode_t);
	int (*rmdir)(struct inode___320 *, struct dentry___319 *);
	int (*mknod)(struct inode___320 *, struct dentry___319 *, umode_t, dev_t);
	int (*rename)(struct inode___320 *, struct dentry___319 *, struct inode___320 *, struct dentry___319 *, unsigned int);
	int (*setattr)(struct dentry___319 *, struct iattr___319 *);
	int (*getattr)(const struct path___320 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___319 *, char *, size_t);
	int (*fiemap)(struct inode___320 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___320 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___320 *, struct dentry___319 *, struct file___320 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___320 *, struct dentry___319 *, umode_t);
	int (*set_acl)(struct inode___320 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___319 {
	void (*fl_copy_lock)(struct file_lock___320 *, struct file_lock___320 *);
	void (*fl_release_private)(struct file_lock___320 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___319;

struct lock_manager_operations___319;

struct file_lock___320 {
	struct file_lock___320 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___320 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___319 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___319 *fl_ops;
	const struct lock_manager_operations___319 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___319 {
	int (*lm_compare_owner)(struct file_lock___320 *, struct file_lock___320 *);
	long unsigned int (*lm_owner_key)(struct file_lock___320 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___320 *);
	int (*lm_grant)(struct file_lock___320 *, int);
	bool (*lm_break)(struct file_lock___320 *);
	int (*lm_change)(struct file_lock___320 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___320 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___319 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___319 *fa_next;
	struct file___320 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___319 {
	const char *name;
	int fs_flags;
	struct dentry___319 * (*mount)(struct file_system_type___319 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___319 *);
	struct module___260 *owner;
	struct file_system_type___319 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___319 {
	struct inode___320 * (*alloc_inode)(struct super_block___319 *);
	void (*destroy_inode)(struct inode___320 *);
	void (*dirty_inode)(struct inode___320 *, int);
	int (*write_inode)(struct inode___320 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___320 *);
	void (*evict_inode)(struct inode___320 *);
	void (*put_super)(struct super_block___319 *);
	int (*sync_fs)(struct super_block___319 *, int);
	int (*freeze_super)(struct super_block___319 *);
	int (*freeze_fs)(struct super_block___319 *);
	int (*thaw_super)(struct super_block___319 *);
	int (*unfreeze_fs)(struct super_block___319 *);
	int (*statfs)(struct dentry___319 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___319 *, int *, char *);
	void (*umount_begin)(struct super_block___319 *);
	int (*show_options)(struct seq_file___271 *, struct dentry___319 *);
	int (*show_devname)(struct seq_file___271 *, struct dentry___319 *);
	int (*show_path)(struct seq_file___271 *, struct dentry___319 *);
	int (*show_stats)(struct seq_file___271 *, struct dentry___319 *);
	ssize_t (*quota_read)(struct super_block___319 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___319 *, int, const char *, size_t, loff_t);
	struct dquot___319 ** (*get_dquots)(struct inode___320 *);
	int (*bdev_try_to_free_page)(struct super_block___319 *, struct page___321 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___319 *, struct shrink_control___119 *);
	long int (*free_cached_objects)(struct super_block___319 *, struct shrink_control___119 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___200)(struct file___320 *, wait_queue_head_t *, struct poll_table_struct___195 *);

struct poll_table_struct___195 {
	poll_queue_proc___200 _qproc;
	__poll_t _key;
};

struct seq_operations___270;

struct seq_file___271 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___270 *op;
	int poll_event;
	const struct file___320 *file;
	void *private;
};

struct kernfs_root___313;

struct kernfs_elem_dir___313 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___313 *root;
};

struct kernfs_syscall_ops___313;

struct kernfs_root___313 {
	struct kernfs_node___314 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___313 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___313 {
	struct kernfs_node___314 *target_kn;
};

struct kernfs_ops___313;

struct kernfs_elem_attr___313 {
	const struct kernfs_ops___313 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___314 *notify_next;
};

struct kernfs_node___314 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___314 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___313 dir;
		struct kernfs_elem_symlink___313 symlink;
		struct kernfs_elem_attr___313 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___313;

struct kernfs_ops___313 {
	int (*open)(struct kernfs_open_file___313 *);
	void (*release)(struct kernfs_open_file___313 *);
	int (*seq_show)(struct seq_file___271 *, void *);
	void * (*seq_start)(struct seq_file___271 *, loff_t *);
	void * (*seq_next)(struct seq_file___271 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___271 *, void *);
	ssize_t (*read)(struct kernfs_open_file___313 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___313 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___313 *, struct vm_area_struct___321 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___313 *, struct poll_table_struct___195 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___313 {
	int (*remount_fs)(struct kernfs_root___313 *, int *, char *);
	int (*show_options)(struct seq_file___271 *, struct kernfs_root___313 *);
	int (*mkdir)(struct kernfs_node___314 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___314 *);
	int (*rename)(struct kernfs_node___314 *, struct kernfs_node___314 *, const char *);
	int (*show_path)(struct seq_file___271 *, struct kernfs_node___314 *, struct kernfs_root___313 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___313 {
	struct kernfs_node___314 *kn;
	struct file___320 *file;
	struct seq_file___271 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___309 *vm_ops;
};

struct bin_attribute___283;

struct attribute_group___284 {
	const char *name;
	umode_t (*is_visible)(struct kobject___307 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___307 *, struct bin_attribute___283 *, int);
	struct attribute **attrs;
	struct bin_attribute___283 **bin_attrs;
};

struct bin_attribute___283 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___320 *, struct kobject___307 *, struct bin_attribute___283 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___320 *, struct kobject___307 *, struct bin_attribute___283 *, char *, loff_t, size_t);
	int (*mmap)(struct file___320 *, struct kobject___307 *, struct bin_attribute___283 *, struct vm_area_struct___321 *);
};

struct sysfs_ops___306 {
	ssize_t (*show)(struct kobject___307 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___307 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___306;

struct kset___306 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___307 kobj;
	const struct kset_uevent_ops___306 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___306 {
	void (*release)(struct kobject___307 *);
	const struct sysfs_ops___306 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___25 * (*child_ns_type)(struct kobject___307 *);
	const void * (*namespace)(struct kobject___307 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___306 {
	int (* const filter)(struct kset___306 *, struct kobject___307 *);
	const char * (* const name)(struct kset___306 *, struct kobject___307 *);
	int (* const uevent)(struct kset___306 *, struct kobject___307 *, struct kobj_uevent_env *);
};

struct kobj_attribute___299 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___307 *, struct kobj_attribute___299 *, char *);
	ssize_t (*store)(struct kobject___307 *, struct kobj_attribute___299 *, const char *, size_t);
};

struct dev_pm_ops___286 {
	int (*prepare)(struct device___286 *);
	void (*complete)(struct device___286 *);
	int (*suspend)(struct device___286 *);
	int (*resume)(struct device___286 *);
	int (*freeze)(struct device___286 *);
	int (*thaw)(struct device___286 *);
	int (*poweroff)(struct device___286 *);
	int (*restore)(struct device___286 *);
	int (*suspend_late)(struct device___286 *);
	int (*resume_early)(struct device___286 *);
	int (*freeze_late)(struct device___286 *);
	int (*thaw_early)(struct device___286 *);
	int (*poweroff_late)(struct device___286 *);
	int (*restore_early)(struct device___286 *);
	int (*suspend_noirq)(struct device___286 *);
	int (*resume_noirq)(struct device___286 *);
	int (*freeze_noirq)(struct device___286 *);
	int (*thaw_noirq)(struct device___286 *);
	int (*poweroff_noirq)(struct device___286 *);
	int (*restore_noirq)(struct device___286 *);
	int (*runtime_suspend)(struct device___286 *);
	int (*runtime_resume)(struct device___286 *);
	int (*runtime_idle)(struct device___286 *);
};

struct dev_pm_info___286 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___3 *subsys_data;
	void (*set_latency_tolerance)(struct device___286 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___286;

struct bus_type___286;

struct device_driver___286;

struct dev_pm_domain___286;

struct class___286;

struct device___286 {
	struct device___286 *parent;
	struct device_private *p;
	struct kobject___307 kobj;
	const char *init_name;
	const struct device_type___286 *type;
	struct mutex mutex;
	struct bus_type___286 *bus;
	struct device_driver___286 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___286 power;
	struct dev_pm_domain___286 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___286 *class;
	const struct attribute_group___284 **groups;
	void (*release)(struct device___286 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___286 {
	struct dev_pm_ops___286 ops;
	void (*detach)(struct device___286 *, bool);
	int (*activate)(struct device___286 *);
	void (*sync)(struct device___286 *);
	void (*dismiss)(struct device___286 *);
};

struct bus_type___286 {
	const char *name;
	const char *dev_name;
	struct device___286 *dev_root;
	const struct attribute_group___284 **bus_groups;
	const struct attribute_group___284 **dev_groups;
	const struct attribute_group___284 **drv_groups;
	int (*match)(struct device___286 *, struct device_driver___286 *);
	int (*uevent)(struct device___286 *, struct kobj_uevent_env *);
	int (*probe)(struct device___286 *);
	int (*remove)(struct device___286 *);
	void (*shutdown)(struct device___286 *);
	int (*online)(struct device___286 *);
	int (*offline)(struct device___286 *);
	int (*suspend)(struct device___286 *, pm_message_t);
	int (*resume)(struct device___286 *);
	int (*num_vf)(struct device___286 *);
	int (*dma_configure)(struct device___286 *);
	const struct dev_pm_ops___286 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___286 {
	const char *name;
	struct bus_type___286 *bus;
	struct module___260 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___286 *);
	int (*remove)(struct device___286 *);
	void (*shutdown)(struct device___286 *);
	int (*suspend)(struct device___286 *, pm_message_t);
	int (*resume)(struct device___286 *);
	const struct attribute_group___284 **groups;
	const struct dev_pm_ops___286 *pm;
	void (*coredump)(struct device___286 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___286 {
	const char *name;
	const struct attribute_group___284 **groups;
	int (*uevent)(struct device___286 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___286 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___286 *);
	const struct dev_pm_ops___286 *pm;
};

struct class___286 {
	const char *name;
	struct module___260 *owner;
	const struct attribute_group___284 **class_groups;
	const struct attribute_group___284 **dev_groups;
	struct kobject___307 *dev_kobj;
	int (*dev_uevent)(struct device___286 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___286 *, umode_t *);
	void (*class_release)(struct class___286 *);
	void (*dev_release)(struct device___286 *);
	int (*shutdown_pre)(struct device___286 *);
	const struct kobj_ns_type_operations___25 *ns_type;
	const void * (*namespace)(struct device___286 *);
	const struct dev_pm_ops___286 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

typedef int (*key_restrict_link_func_t___298)(struct key___297 *, const struct key_type *, const union key_payload *, struct key___297 *);

struct key_restriction___297;

struct key___297 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___321 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___297 *restrict_link;
};

struct key_restriction___297 {
	key_restrict_link_func_t___298 check;
	struct key___297 *key;
	struct key_type *keytype;
};

struct seq_operations___270 {
	void * (*start)(struct seq_file___271 *, loff_t *);
	void (*stop)(struct seq_file___271 *, void *);
	void * (*next)(struct seq_file___271 *, void *, loff_t *);
	int (*show)(struct seq_file___271 *, void *);
};

struct tty_struct___25;

struct tty_driver___25;

struct tty_operations___25 {
	struct tty_struct___25 * (*lookup)(struct tty_driver___25 *, struct file___320 *, int);
	int (*install)(struct tty_driver___25 *, struct tty_struct___25 *);
	void (*remove)(struct tty_driver___25 *, struct tty_struct___25 *);
	int (*open)(struct tty_struct___25 *, struct file___320 *);
	void (*close)(struct tty_struct___25 *, struct file___320 *);
	void (*shutdown)(struct tty_struct___25 *);
	void (*cleanup)(struct tty_struct___25 *);
	int (*write)(struct tty_struct___25 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___25 *, unsigned char);
	void (*flush_chars)(struct tty_struct___25 *);
	int (*write_room)(struct tty_struct___25 *);
	int (*chars_in_buffer)(struct tty_struct___25 *);
	int (*ioctl)(struct tty_struct___25 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___25 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___25 *, struct ktermios *);
	void (*throttle)(struct tty_struct___25 *);
	void (*unthrottle)(struct tty_struct___25 *);
	void (*stop)(struct tty_struct___25 *);
	void (*start)(struct tty_struct___25 *);
	void (*hangup)(struct tty_struct___25 *);
	int (*break_ctl)(struct tty_struct___25 *, int);
	void (*flush_buffer)(struct tty_struct___25 *);
	void (*set_ldisc)(struct tty_struct___25 *);
	void (*wait_until_sent)(struct tty_struct___25 *, int);
	void (*send_xchar)(struct tty_struct___25 *, char);
	int (*tiocmget)(struct tty_struct___25 *);
	int (*tiocmset)(struct tty_struct___25 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___25 *, struct winsize *);
	int (*set_termiox)(struct tty_struct___25 *, struct termiox *);
	int (*get_icount)(struct tty_struct___25 *, struct serial_icounter_struct *);
	void (*show_fdinfo)(struct tty_struct___25 *, struct seq_file___271 *);
	int (*poll_init)(struct tty_driver___25 *, int, char *);
	int (*poll_get_char)(struct tty_driver___25 *, int);
	void (*poll_put_char)(struct tty_driver___25 *, int, char);
	int (*proc_show)(struct seq_file___271 *, void *);
};

struct tty_ldisc___25;

struct tty_port___25;

struct tty_struct___25 {
	int magic;
	struct kref kref;
	struct device___286 *dev;
	struct tty_driver___25 *driver;
	const struct tty_operations___25 *ops;
	int index;
	struct ld_semaphore ldisc_sem;
	struct tty_ldisc___25 *ldisc;
	struct mutex atomic_write_lock;
	struct mutex legacy_mutex;
	struct mutex throttle_mutex;
	struct rw_semaphore___321 termios_rwsem;
	struct mutex winsize_mutex;
	spinlock_t ctrl_lock;
	spinlock_t flow_lock;
	struct ktermios termios;
	struct ktermios termios_locked;
	struct termiox *termiox;
	char name[64];
	struct pid___206 *pgrp;
	struct pid___206 *session;
	long unsigned int flags;
	int count;
	struct winsize winsize;
	long unsigned int stopped: 1;
	long unsigned int flow_stopped: 1;
	int: 30;
	long unsigned int unused: 62;
	int hw_stopped;
	long unsigned int ctrl_status: 8;
	long unsigned int packet: 1;
	int: 23;
	long unsigned int unused_ctrl: 55;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___25 *link;
	struct fasync_struct___319 *fasync;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	spinlock_t files_lock;
	struct list_head tty_files;
	int closing;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___25 *port;
};

struct tty_driver___25 {
	int magic;
	struct kref kref;
	struct cdev___68 **cdevs;
	struct module___260 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___25 *other;
	struct tty_struct___25 **ttys;
	struct tty_port___25 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___25 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___25;

struct tty_port_client_operations___25;

struct tty_port___25 {
	struct tty_bufhead buf;
	struct tty_struct___25 *tty;
	struct tty_struct___25 *itty;
	const struct tty_port_operations___25 *ops;
	const struct tty_port_client_operations___25 *client_ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	unsigned char low_latency: 1;
	struct mutex mutex;
	struct mutex buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
	void *client_data;
};

struct tty_ldisc_ops___25 {
	int magic;
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___25 *);
	void (*close)(struct tty_struct___25 *);
	void (*flush_buffer)(struct tty_struct___25 *);
	ssize_t (*read)(struct tty_struct___25 *, struct file___320 *, unsigned char *, size_t);
	ssize_t (*write)(struct tty_struct___25 *, struct file___320 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___25 *, struct file___320 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___25 *, struct file___320 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___25 *, struct ktermios *);
	__poll_t (*poll)(struct tty_struct___25 *, struct file___320 *, struct poll_table_struct___195 *);
	int (*hangup)(struct tty_struct___25 *);
	void (*receive_buf)(struct tty_struct___25 *, const unsigned char *, char *, int);
	void (*write_wakeup)(struct tty_struct___25 *);
	void (*dcd_change)(struct tty_struct___25 *, unsigned int);
	int (*receive_buf2)(struct tty_struct___25 *, const unsigned char *, char *, int);
	struct module___260 *owner;
	int refcount;
};

struct tty_ldisc___25 {
	struct tty_ldisc_ops___25 *ops;
	struct tty_struct___25 *tty;
};

struct tty_port_operations___25 {
	int (*carrier_raised)(struct tty_port___25 *);
	void (*dtr_rts)(struct tty_port___25 *, int);
	void (*shutdown)(struct tty_port___25 *);
	int (*activate)(struct tty_port___25 *, struct tty_struct___25 *);
	void (*destruct)(struct tty_port___25 *);
};

struct tty_port_client_operations___25 {
	int (*receive_buf)(struct tty_port___25 *, const unsigned char *, const unsigned char *, size_t);
	void (*write_wakeup)(struct tty_port___25 *);
};

typedef void compound_page_dtor___309(struct page___321 *);

struct kernel_param_ops___257 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___257 *);
	int (*get)(char *, const struct kernel_param___257 *);
	void (*free)(void *);
};

struct kparam_array___257;

struct kernel_param___257 {
	const char *name;
	struct module___260 *mod;
	const struct kernel_param_ops___257 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___257 *arr;
	};
};

struct kparam_array___257 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___257 *ops;
	void *elem;
};

struct module_attribute___257 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___257 *, struct module_kobject___257 *, char *);
	ssize_t (*store)(struct module_attribute___257 *, struct module_kobject___257 *, const char *, size_t);
	void (*setup)(struct module___260 *, const char *);
	int (*test)(struct module___260 *);
	void (*free)(struct module___260 *);
};

struct module___261;

struct file___321;

struct kiocb___321;

struct vm_area_struct___322;

struct inode___321;

struct file_lock___321;

struct page___322;

struct seq_file___272;

struct file_operations___321 {
	struct module___261 *owner;
	loff_t (*llseek)(struct file___321 *, loff_t, int);
	ssize_t (*read)(struct file___321 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___321 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___321 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___321 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___321 *, bool);
	int (*iterate)(struct file___321 *, struct dir_context *);
	int (*iterate_shared)(struct file___321 *, struct dir_context *);
	__poll_t (*poll)(struct file___321 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___321 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___321 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___321 *, struct vm_area_struct___322 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___321 *, struct file___321 *);
	int (*flush)(struct file___321 *, fl_owner_t);
	int (*release)(struct inode___321 *, struct file___321 *);
	int (*fsync)(struct file___321 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___321 *, int);
	int (*lock)(struct file___321 *, int, struct file_lock___321 *);
	ssize_t (*sendpage)(struct file___321 *, struct page___322 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___321 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___321 *, int, struct file_lock___321 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___321 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___321 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___321 *, long int, struct file_lock___321 **, void **);
	long int (*fallocate)(struct file___321 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___272 *, struct file___321 *);
	ssize_t (*copy_file_range)(struct file___321 *, loff_t, struct file___321 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___321 *, loff_t, struct file___321 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___321 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___321 {
	u64 seqnum;
	struct vm_area_struct___322 *vmas[4];
};

struct page_frag___321 {
	struct page___322 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___321;

struct cred___298;

struct signal_struct___236;

struct task_struct___322 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___322 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___321 *mm;
	struct mm_struct___321 *active_mm;
	struct vmacache___321 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___322 *real_parent;
	struct task_struct___322 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___322 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___206 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___206 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___206 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___298 *ptracer_cred;
	const struct cred___298 *real_cred;
	const struct cred___298 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___236 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___322 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___82 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___321 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___322 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___132 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___320;

struct super_block___320;

struct dentry___320 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___320 *d_parent;
	struct qstr d_name;
	struct inode___321 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___320 *d_op;
	struct super_block___320 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct rw_semaphore___322 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___322 *owner;
};

struct address_space_operations___320;

struct address_space___320 {
	struct inode___321 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___322 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___320 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___320;

struct block_device___320;

struct cdev___69;

struct inode___321 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___320 *i_op;
	struct super_block___320 *i_sb;
	struct address_space___320 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___322 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___321 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___320 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___320 *i_bdev;
		struct cdev___69 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___321;

struct dentry_operations___320 {
	int (*d_revalidate)(struct dentry___320 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___320 *, unsigned int);
	int (*d_hash)(const struct dentry___320 *, struct qstr *);
	int (*d_compare)(const struct dentry___320 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___320 *);
	int (*d_init)(struct dentry___320 *);
	void (*d_release)(struct dentry___320 *);
	void (*d_prune)(struct dentry___320 *);
	void (*d_iput)(struct dentry___320 *, struct inode___321 *);
	char * (*d_dname)(struct dentry___320 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___321 *);
	int (*d_manage)(const struct path___321 *, bool);
	struct dentry___320 * (*d_real)(struct dentry___320 *, const struct inode___321 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___320;

struct mem_dqinfo___320 {
	struct quota_format_type___320 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___320;

struct quota_info___320 {
	unsigned int flags;
	struct rw_semaphore___322 dqio_sem;
	struct inode___321 *files[3];
	struct mem_dqinfo___320 info[3];
	const struct quota_format_ops___320 *ops[3];
};

struct rcuwait___320 {
	struct task_struct___322 *task;
};

struct percpu_rw_semaphore___320 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___322 rw_sem;
	struct rcuwait___320 writer;
	int readers_block;
};

struct sb_writers___320 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___320 rw_sem[3];
};

struct file_system_type___320;

struct super_operations___320;

struct dquot_operations___320;

struct quotactl_ops___320;

struct super_block___320 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___320 *s_type;
	const struct super_operations___320 *s_op;
	const struct dquot_operations___320 *dq_op;
	const struct quotactl_ops___320 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___320 *s_root;
	struct rw_semaphore___322 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___320 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___320 s_dquot;
	struct sb_writers___320 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___320 *s_d_op;
	int cleancache_poolid;
	struct shrinker___119 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct path___321 {
	struct vfsmount *mnt;
	struct dentry___320 *dentry;
};

typedef struct page___322 *pgtable_t___321;

struct page___322 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___320 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___322 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___321 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___321 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___309 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___321;

struct lruvec___321 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___321 *pgdat;
};

struct zone___321 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___321 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___321 {
	struct zone___321 *zone;
	int zone_idx;
};

struct zonelist___321 {
	struct zoneref___321 _zonerefs[25];
};

struct pglist_data___321 {
	struct zone___321 node_zones[3];
	struct zonelist___321 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___322 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___322 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___321 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___322 {
	void *stack;
	struct task_struct___322 *task;
	long int status;
};

struct blocking_notifier_head___321 {
	struct rw_semaphore___322 rwsem;
	struct notifier_block *head;
};

struct vm_area_struct___322 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___322 *vm_next;
	struct vm_area_struct___322 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___321 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___13 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___321 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___321;

struct mm_struct___321 {
	struct {
		struct vm_area_struct___322 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___321 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___322 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___321 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___322 *owner;
		struct user_namespace___3 *user_ns;
		struct file___321 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___321 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct file___321 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___321 f_path;
	struct inode___321 *f_inode;
	const struct file_operations___321 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___206 f_owner;
	const struct cred___298 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___320 *f_mapping;
	errseq_t f_wb_err;
};

struct core_thread___321 {
	struct task_struct___322 *task;
	struct core_thread___321 *next;
};

struct core_state___321 {
	atomic_t nr_threads;
	struct core_thread___321 dumper;
	struct completion startup;
};

struct key___298;

struct user_struct___298 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___298 *uid_keyring;
	struct key___298 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___298 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___298 *session_keyring;
	struct key___298 *process_keyring;
	struct key___298 *thread_keyring;
	struct key___298 *request_key_auth;
	void *security;
	struct user_struct___298 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct tty_struct___26;

struct signal_struct___236 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___322 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___322 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___206 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___206 *tty_old_pgrp;
	int leader;
	struct tty_struct___26 *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___321 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___206 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

union thread_union___248 {
	struct task_struct___322 task;
	long unsigned int stack[8192];
};

struct kiocb___321 {
	struct file___321 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___321 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___320 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___321 *ia_file;
};

struct dquot___320 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___320 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___320 {
	int qf_fmt_id;
	const struct quota_format_ops___320 *qf_ops;
	struct module___261 *qf_owner;
	struct quota_format_type___320 *qf_next;
};

struct quota_format_ops___320 {
	int (*check_quota_file)(struct super_block___320 *, int);
	int (*read_file_info)(struct super_block___320 *, int);
	int (*write_file_info)(struct super_block___320 *, int);
	int (*free_file_info)(struct super_block___320 *, int);
	int (*read_dqblk)(struct dquot___320 *);
	int (*commit_dqblk)(struct dquot___320 *);
	int (*release_dqblk)(struct dquot___320 *);
	int (*get_next_id)(struct super_block___320 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___320 {
	int (*write_dquot)(struct dquot___320 *);
	struct dquot___320 * (*alloc_dquot)(struct super_block___320 *, int);
	void (*destroy_dquot)(struct dquot___320 *);
	int (*acquire_dquot)(struct dquot___320 *);
	int (*release_dquot)(struct dquot___320 *);
	int (*mark_dirty)(struct dquot___320 *);
	int (*write_info)(struct super_block___320 *, int);
	qsize_t * (*get_reserved_space)(struct inode___321 *);
	int (*get_projid)(struct inode___321 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___321 *, qsize_t *);
	int (*get_next_id)(struct super_block___320 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___320 {
	int (*quota_on)(struct super_block___320 *, int, int, const struct path___321 *);
	int (*quota_off)(struct super_block___320 *, int);
	int (*quota_enable)(struct super_block___320 *, unsigned int);
	int (*quota_disable)(struct super_block___320 *, unsigned int);
	int (*quota_sync)(struct super_block___320 *, int);
	int (*set_info)(struct super_block___320 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___320 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___320 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___320 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___320 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___320 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___307;

struct kobj_type___307;

struct kernfs_node___315;

struct kobject___308 {
	const char *name;
	struct list_head entry;
	struct kobject___308 *parent;
	struct kset___307 *kset;
	struct kobj_type___307 *ktype;
	struct kernfs_node___315 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___258 {
	struct kobject___308 kobj;
	struct module___261 *mod;
	struct kobject___308 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___258 {
	struct module___261 *mod;
	struct latch_tree_node node;
};

struct module_layout___258 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___258 mtn;
};

struct module_attribute___258;

struct kernel_param___258;

struct module___261 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___258 mkobj;
	struct module_attribute___258 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___308 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___258 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___258 core_layout;
	struct module_layout___258 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___320 {
	int (*writepage)(struct page___322 *, struct writeback_control___3 *);
	int (*readpage)(struct file___321 *, struct page___322 *);
	int (*writepages)(struct address_space___320 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___322 *);
	int (*readpages)(struct file___321 *, struct address_space___320 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___321 *, struct address_space___320 *, loff_t, unsigned int, unsigned int, struct page___322 **, void **);
	int (*write_end)(struct file___321 *, struct address_space___320 *, loff_t, unsigned int, unsigned int, struct page___322 *, void *);
	sector_t (*bmap)(struct address_space___320 *, sector_t);
	void (*invalidatepage)(struct page___322 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___322 *, gfp_t);
	void (*freepage)(struct page___322 *);
	ssize_t (*direct_IO)(struct kiocb___321 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___320 *, struct page___322 *, struct page___322 *, enum migrate_mode);
	bool (*isolate_page)(struct page___322 *, isolate_mode_t);
	void (*putback_page)(struct page___322 *);
	int (*launder_page)(struct page___322 *);
	int (*is_partially_uptodate)(struct page___322 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___322 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___320 *, struct page___322 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___321 *, sector_t *);
	void (*swap_deactivate)(struct file___321 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___320 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___321 *bd_inode;
	struct super_block___320 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___320 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___69 {
	struct kobject___308 kobj;
	struct module___261 *owner;
	const struct file_operations___321 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___320 {
	struct dentry___320 * (*lookup)(struct inode___321 *, struct dentry___320 *, unsigned int);
	const char * (*get_link)(struct dentry___320 *, struct inode___321 *, struct delayed_call *);
	int (*permission)(struct inode___321 *, int);
	struct posix_acl * (*get_acl)(struct inode___321 *, int);
	int (*readlink)(struct dentry___320 *, char *, int);
	int (*create)(struct inode___321 *, struct dentry___320 *, umode_t, bool);
	int (*link)(struct dentry___320 *, struct inode___321 *, struct dentry___320 *);
	int (*unlink)(struct inode___321 *, struct dentry___320 *);
	int (*symlink)(struct inode___321 *, struct dentry___320 *, const char *);
	int (*mkdir)(struct inode___321 *, struct dentry___320 *, umode_t);
	int (*rmdir)(struct inode___321 *, struct dentry___320 *);
	int (*mknod)(struct inode___321 *, struct dentry___320 *, umode_t, dev_t);
	int (*rename)(struct inode___321 *, struct dentry___320 *, struct inode___321 *, struct dentry___320 *, unsigned int);
	int (*setattr)(struct dentry___320 *, struct iattr___320 *);
	int (*getattr)(const struct path___321 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___320 *, char *, size_t);
	int (*fiemap)(struct inode___321 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___321 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___321 *, struct dentry___320 *, struct file___321 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___321 *, struct dentry___320 *, umode_t);
	int (*set_acl)(struct inode___321 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___320 {
	void (*fl_copy_lock)(struct file_lock___321 *, struct file_lock___321 *);
	void (*fl_release_private)(struct file_lock___321 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___320;

struct lock_manager_operations___320;

struct file_lock___321 {
	struct file_lock___321 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___321 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___320 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___320 *fl_ops;
	const struct lock_manager_operations___320 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___320 {
	int (*lm_compare_owner)(struct file_lock___321 *, struct file_lock___321 *);
	long unsigned int (*lm_owner_key)(struct file_lock___321 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___321 *);
	int (*lm_grant)(struct file_lock___321 *, int);
	bool (*lm_break)(struct file_lock___321 *);
	int (*lm_change)(struct file_lock___321 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___321 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___320 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___320 *fa_next;
	struct file___321 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___320 {
	const char *name;
	int fs_flags;
	struct dentry___320 * (*mount)(struct file_system_type___320 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___320 *);
	struct module___261 *owner;
	struct file_system_type___320 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___320 {
	struct inode___321 * (*alloc_inode)(struct super_block___320 *);
	void (*destroy_inode)(struct inode___321 *);
	void (*dirty_inode)(struct inode___321 *, int);
	int (*write_inode)(struct inode___321 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___321 *);
	void (*evict_inode)(struct inode___321 *);
	void (*put_super)(struct super_block___320 *);
	int (*sync_fs)(struct super_block___320 *, int);
	int (*freeze_super)(struct super_block___320 *);
	int (*freeze_fs)(struct super_block___320 *);
	int (*thaw_super)(struct super_block___320 *);
	int (*unfreeze_fs)(struct super_block___320 *);
	int (*statfs)(struct dentry___320 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___320 *, int *, char *);
	void (*umount_begin)(struct super_block___320 *);
	int (*show_options)(struct seq_file___272 *, struct dentry___320 *);
	int (*show_devname)(struct seq_file___272 *, struct dentry___320 *);
	int (*show_path)(struct seq_file___272 *, struct dentry___320 *);
	int (*show_stats)(struct seq_file___272 *, struct dentry___320 *);
	ssize_t (*quota_read)(struct super_block___320 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___320 *, int, const char *, size_t, loff_t);
	struct dquot___320 ** (*get_dquots)(struct inode___321 *);
	int (*bdev_try_to_free_page)(struct super_block___320 *, struct page___322 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___320 *, struct shrink_control___119 *);
	long int (*free_cached_objects)(struct super_block___320 *, struct shrink_control___119 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___271;

struct seq_file___272 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___271 *op;
	int poll_event;
	const struct file___321 *file;
	void *private;
};

struct kernfs_root___314;

struct kernfs_elem_dir___314 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___314 *root;
};

struct kernfs_syscall_ops___314;

struct kernfs_root___314 {
	struct kernfs_node___315 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___314 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___314 {
	struct kernfs_node___315 *target_kn;
};

struct kernfs_ops___314;

struct kernfs_elem_attr___314 {
	const struct kernfs_ops___314 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___315 *notify_next;
};

struct kernfs_node___315 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___315 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___314 dir;
		struct kernfs_elem_symlink___314 symlink;
		struct kernfs_elem_attr___314 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___314;

struct kernfs_ops___314 {
	int (*open)(struct kernfs_open_file___314 *);
	void (*release)(struct kernfs_open_file___314 *);
	int (*seq_show)(struct seq_file___272 *, void *);
	void * (*seq_start)(struct seq_file___272 *, loff_t *);
	void * (*seq_next)(struct seq_file___272 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___272 *, void *);
	ssize_t (*read)(struct kernfs_open_file___314 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___314 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___314 *, struct vm_area_struct___322 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___314 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___314 {
	int (*remount_fs)(struct kernfs_root___314 *, int *, char *);
	int (*show_options)(struct seq_file___272 *, struct kernfs_root___314 *);
	int (*mkdir)(struct kernfs_node___315 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___315 *);
	int (*rename)(struct kernfs_node___315 *, struct kernfs_node___315 *, const char *);
	int (*show_path)(struct seq_file___272 *, struct kernfs_node___315 *, struct kernfs_root___314 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___314 {
	struct kernfs_node___315 *kn;
	struct file___321 *file;
	struct seq_file___272 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___13 *vm_ops;
};

struct bin_attribute___284;

struct attribute_group___285 {
	const char *name;
	umode_t (*is_visible)(struct kobject___308 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___308 *, struct bin_attribute___284 *, int);
	struct attribute **attrs;
	struct bin_attribute___284 **bin_attrs;
};

struct bin_attribute___284 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___321 *, struct kobject___308 *, struct bin_attribute___284 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___321 *, struct kobject___308 *, struct bin_attribute___284 *, char *, loff_t, size_t);
	int (*mmap)(struct file___321 *, struct kobject___308 *, struct bin_attribute___284 *, struct vm_area_struct___322 *);
};

struct sysfs_ops___307 {
	ssize_t (*show)(struct kobject___308 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___308 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___307;

struct kset___307 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___308 kobj;
	const struct kset_uevent_ops___307 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___307 {
	void (*release)(struct kobject___308 *);
	const struct sysfs_ops___307 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___25 * (*child_ns_type)(struct kobject___308 *);
	const void * (*namespace)(struct kobject___308 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___307 {
	int (* const filter)(struct kset___307 *, struct kobject___308 *);
	const char * (* const name)(struct kset___307 *, struct kobject___308 *);
	int (* const uevent)(struct kset___307 *, struct kobject___308 *, struct kobj_uevent_env *);
};

struct device___287;

struct dev_pm_ops___287 {
	int (*prepare)(struct device___287 *);
	void (*complete)(struct device___287 *);
	int (*suspend)(struct device___287 *);
	int (*resume)(struct device___287 *);
	int (*freeze)(struct device___287 *);
	int (*thaw)(struct device___287 *);
	int (*poweroff)(struct device___287 *);
	int (*restore)(struct device___287 *);
	int (*suspend_late)(struct device___287 *);
	int (*resume_early)(struct device___287 *);
	int (*freeze_late)(struct device___287 *);
	int (*thaw_early)(struct device___287 *);
	int (*poweroff_late)(struct device___287 *);
	int (*restore_early)(struct device___287 *);
	int (*suspend_noirq)(struct device___287 *);
	int (*resume_noirq)(struct device___287 *);
	int (*freeze_noirq)(struct device___287 *);
	int (*thaw_noirq)(struct device___287 *);
	int (*poweroff_noirq)(struct device___287 *);
	int (*restore_noirq)(struct device___287 *);
	int (*runtime_suspend)(struct device___287 *);
	int (*runtime_resume)(struct device___287 *);
	int (*runtime_idle)(struct device___287 *);
};

struct dev_pm_info___287 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___3 *subsys_data;
	void (*set_latency_tolerance)(struct device___287 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___287;

struct bus_type___287;

struct device_driver___287;

struct dev_pm_domain___287;

struct class___287;

struct device___287 {
	struct device___287 *parent;
	struct device_private *p;
	struct kobject___308 kobj;
	const char *init_name;
	const struct device_type___287 *type;
	struct mutex mutex;
	struct bus_type___287 *bus;
	struct device_driver___287 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___287 power;
	struct dev_pm_domain___287 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___287 *class;
	const struct attribute_group___285 **groups;
	void (*release)(struct device___287 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___287 {
	struct dev_pm_ops___287 ops;
	void (*detach)(struct device___287 *, bool);
	int (*activate)(struct device___287 *);
	void (*sync)(struct device___287 *);
	void (*dismiss)(struct device___287 *);
};

struct bus_type___287 {
	const char *name;
	const char *dev_name;
	struct device___287 *dev_root;
	const struct attribute_group___285 **bus_groups;
	const struct attribute_group___285 **dev_groups;
	const struct attribute_group___285 **drv_groups;
	int (*match)(struct device___287 *, struct device_driver___287 *);
	int (*uevent)(struct device___287 *, struct kobj_uevent_env *);
	int (*probe)(struct device___287 *);
	int (*remove)(struct device___287 *);
	void (*shutdown)(struct device___287 *);
	int (*online)(struct device___287 *);
	int (*offline)(struct device___287 *);
	int (*suspend)(struct device___287 *, pm_message_t);
	int (*resume)(struct device___287 *);
	int (*num_vf)(struct device___287 *);
	int (*dma_configure)(struct device___287 *);
	const struct dev_pm_ops___287 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___287 {
	const char *name;
	struct bus_type___287 *bus;
	struct module___261 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___287 *);
	int (*remove)(struct device___287 *);
	void (*shutdown)(struct device___287 *);
	int (*suspend)(struct device___287 *, pm_message_t);
	int (*resume)(struct device___287 *);
	const struct attribute_group___285 **groups;
	const struct dev_pm_ops___287 *pm;
	void (*coredump)(struct device___287 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___287 {
	const char *name;
	const struct attribute_group___285 **groups;
	int (*uevent)(struct device___287 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___287 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___287 *);
	const struct dev_pm_ops___287 *pm;
};

struct class___287 {
	const char *name;
	struct module___261 *owner;
	const struct attribute_group___285 **class_groups;
	const struct attribute_group___285 **dev_groups;
	struct kobject___308 *dev_kobj;
	int (*dev_uevent)(struct device___287 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___287 *, umode_t *);
	void (*class_release)(struct class___287 *);
	void (*dev_release)(struct device___287 *);
	int (*shutdown_pre)(struct device___287 *);
	const struct kobj_ns_type_operations___25 *ns_type;
	const void * (*namespace)(struct device___287 *);
	const struct dev_pm_ops___287 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

typedef int (*key_restrict_link_func_t___299)(struct key___298 *, const struct key_type *, const union key_payload *, struct key___298 *);

struct key_restriction___298;

struct key___298 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___322 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___298 *restrict_link;
};

struct key_restriction___298 {
	key_restrict_link_func_t___299 check;
	struct key___298 *key;
	struct key_type *keytype;
};

struct seq_operations___271 {
	void * (*start)(struct seq_file___272 *, loff_t *);
	void (*stop)(struct seq_file___272 *, void *);
	void * (*next)(struct seq_file___272 *, void *, loff_t *);
	int (*show)(struct seq_file___272 *, void *);
};

struct tty_driver___26;

struct tty_operations___26 {
	struct tty_struct___26 * (*lookup)(struct tty_driver___26 *, struct file___321 *, int);
	int (*install)(struct tty_driver___26 *, struct tty_struct___26 *);
	void (*remove)(struct tty_driver___26 *, struct tty_struct___26 *);
	int (*open)(struct tty_struct___26 *, struct file___321 *);
	void (*close)(struct tty_struct___26 *, struct file___321 *);
	void (*shutdown)(struct tty_struct___26 *);
	void (*cleanup)(struct tty_struct___26 *);
	int (*write)(struct tty_struct___26 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___26 *, unsigned char);
	void (*flush_chars)(struct tty_struct___26 *);
	int (*write_room)(struct tty_struct___26 *);
	int (*chars_in_buffer)(struct tty_struct___26 *);
	int (*ioctl)(struct tty_struct___26 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___26 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___26 *, struct ktermios *);
	void (*throttle)(struct tty_struct___26 *);
	void (*unthrottle)(struct tty_struct___26 *);
	void (*stop)(struct tty_struct___26 *);
	void (*start)(struct tty_struct___26 *);
	void (*hangup)(struct tty_struct___26 *);
	int (*break_ctl)(struct tty_struct___26 *, int);
	void (*flush_buffer)(struct tty_struct___26 *);
	void (*set_ldisc)(struct tty_struct___26 *);
	void (*wait_until_sent)(struct tty_struct___26 *, int);
	void (*send_xchar)(struct tty_struct___26 *, char);
	int (*tiocmget)(struct tty_struct___26 *);
	int (*tiocmset)(struct tty_struct___26 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___26 *, struct winsize *);
	int (*set_termiox)(struct tty_struct___26 *, struct termiox *);
	int (*get_icount)(struct tty_struct___26 *, struct serial_icounter_struct *);
	void (*show_fdinfo)(struct tty_struct___26 *, struct seq_file___272 *);
	int (*poll_init)(struct tty_driver___26 *, int, char *);
	int (*poll_get_char)(struct tty_driver___26 *, int);
	void (*poll_put_char)(struct tty_driver___26 *, int, char);
	int (*proc_show)(struct seq_file___272 *, void *);
};

struct tty_ldisc___26;

struct tty_port___26;

struct tty_struct___26 {
	int magic;
	struct kref kref;
	struct device___287 *dev;
	struct tty_driver___26 *driver;
	const struct tty_operations___26 *ops;
	int index;
	struct ld_semaphore ldisc_sem;
	struct tty_ldisc___26 *ldisc;
	struct mutex atomic_write_lock;
	struct mutex legacy_mutex;
	struct mutex throttle_mutex;
	struct rw_semaphore___322 termios_rwsem;
	struct mutex winsize_mutex;
	spinlock_t ctrl_lock;
	spinlock_t flow_lock;
	struct ktermios termios;
	struct ktermios termios_locked;
	struct termiox *termiox;
	char name[64];
	struct pid___206 *pgrp;
	struct pid___206 *session;
	long unsigned int flags;
	int count;
	struct winsize winsize;
	long unsigned int stopped: 1;
	long unsigned int flow_stopped: 1;
	int: 30;
	long unsigned int unused: 62;
	int hw_stopped;
	long unsigned int ctrl_status: 8;
	long unsigned int packet: 1;
	int: 23;
	long unsigned int unused_ctrl: 55;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___26 *link;
	struct fasync_struct___320 *fasync;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	spinlock_t files_lock;
	struct list_head tty_files;
	int closing;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___26 *port;
};

struct tty_driver___26 {
	int magic;
	struct kref kref;
	struct cdev___69 **cdevs;
	struct module___261 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___26 *other;
	struct tty_struct___26 **ttys;
	struct tty_port___26 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___26 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___26;

struct tty_port_client_operations___26;

struct tty_port___26 {
	struct tty_bufhead buf;
	struct tty_struct___26 *tty;
	struct tty_struct___26 *itty;
	const struct tty_port_operations___26 *ops;
	const struct tty_port_client_operations___26 *client_ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	unsigned char low_latency: 1;
	struct mutex mutex;
	struct mutex buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
	void *client_data;
};

struct tty_ldisc_ops___26 {
	int magic;
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___26 *);
	void (*close)(struct tty_struct___26 *);
	void (*flush_buffer)(struct tty_struct___26 *);
	ssize_t (*read)(struct tty_struct___26 *, struct file___321 *, unsigned char *, size_t);
	ssize_t (*write)(struct tty_struct___26 *, struct file___321 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___26 *, struct file___321 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___26 *, struct file___321 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___26 *, struct ktermios *);
	__poll_t (*poll)(struct tty_struct___26 *, struct file___321 *, struct poll_table_struct___6 *);
	int (*hangup)(struct tty_struct___26 *);
	void (*receive_buf)(struct tty_struct___26 *, const unsigned char *, char *, int);
	void (*write_wakeup)(struct tty_struct___26 *);
	void (*dcd_change)(struct tty_struct___26 *, unsigned int);
	int (*receive_buf2)(struct tty_struct___26 *, const unsigned char *, char *, int);
	struct module___261 *owner;
	int refcount;
};

struct tty_ldisc___26 {
	struct tty_ldisc_ops___26 *ops;
	struct tty_struct___26 *tty;
};

struct tty_port_operations___26 {
	int (*carrier_raised)(struct tty_port___26 *);
	void (*dtr_rts)(struct tty_port___26 *, int);
	void (*shutdown)(struct tty_port___26 *);
	int (*activate)(struct tty_port___26 *, struct tty_struct___26 *);
	void (*destruct)(struct tty_port___26 *);
};

struct tty_port_client_operations___26 {
	int (*receive_buf)(struct tty_port___26 *, const unsigned char *, const unsigned char *, size_t);
	void (*write_wakeup)(struct tty_port___26 *);
};

struct kernel_param_ops___258 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___258 *);
	int (*get)(char *, const struct kernel_param___258 *);
	void (*free)(void *);
};

struct kparam_array___258;

struct kernel_param___258 {
	const char *name;
	struct module___261 *mod;
	const struct kernel_param_ops___258 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___258 *arr;
	};
};

struct kparam_array___258 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___258 *ops;
	void *elem;
};

struct module_attribute___258 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___258 *, struct module_kobject___258 *, char *);
	ssize_t (*store)(struct module_attribute___258 *, struct module_kobject___258 *, const char *, size_t);
	void (*setup)(struct module___261 *, const char *);
	int (*test)(struct module___261 *);
	void (*free)(struct module___261 *);
};

struct tty_struct___27;

struct tty_driver___27;

struct tty_operations___27 {
	struct tty_struct___27 * (*lookup)(struct tty_driver___27 *, struct file___311 *, int);
	int (*install)(struct tty_driver___27 *, struct tty_struct___27 *);
	void (*remove)(struct tty_driver___27 *, struct tty_struct___27 *);
	int (*open)(struct tty_struct___27 *, struct file___311 *);
	void (*close)(struct tty_struct___27 *, struct file___311 *);
	void (*shutdown)(struct tty_struct___27 *);
	void (*cleanup)(struct tty_struct___27 *);
	int (*write)(struct tty_struct___27 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___27 *, unsigned char);
	void (*flush_chars)(struct tty_struct___27 *);
	int (*write_room)(struct tty_struct___27 *);
	int (*chars_in_buffer)(struct tty_struct___27 *);
	int (*ioctl)(struct tty_struct___27 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___27 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___27 *, struct ktermios *);
	void (*throttle)(struct tty_struct___27 *);
	void (*unthrottle)(struct tty_struct___27 *);
	void (*stop)(struct tty_struct___27 *);
	void (*start)(struct tty_struct___27 *);
	void (*hangup)(struct tty_struct___27 *);
	int (*break_ctl)(struct tty_struct___27 *, int);
	void (*flush_buffer)(struct tty_struct___27 *);
	void (*set_ldisc)(struct tty_struct___27 *);
	void (*wait_until_sent)(struct tty_struct___27 *, int);
	void (*send_xchar)(struct tty_struct___27 *, char);
	int (*tiocmget)(struct tty_struct___27 *);
	int (*tiocmset)(struct tty_struct___27 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___27 *, struct winsize *);
	int (*set_termiox)(struct tty_struct___27 *, struct termiox *);
	int (*get_icount)(struct tty_struct___27 *, struct serial_icounter_struct *);
	void (*show_fdinfo)(struct tty_struct___27 *, struct seq_file___263 *);
	int (*poll_init)(struct tty_driver___27 *, int, char *);
	int (*poll_get_char)(struct tty_driver___27 *, int);
	void (*poll_put_char)(struct tty_driver___27 *, int, char);
	int (*proc_show)(struct seq_file___263 *, void *);
};

struct tty_ldisc___27;

struct tty_port___27;

struct tty_struct___27 {
	int magic;
	struct kref kref;
	struct device___276 *dev;
	struct tty_driver___27 *driver;
	const struct tty_operations___27 *ops;
	int index;
	struct ld_semaphore ldisc_sem;
	struct tty_ldisc___27 *ldisc;
	struct mutex atomic_write_lock;
	struct mutex legacy_mutex;
	struct mutex throttle_mutex;
	struct rw_semaphore___312 termios_rwsem;
	struct mutex winsize_mutex;
	spinlock_t ctrl_lock;
	spinlock_t flow_lock;
	struct ktermios termios;
	struct ktermios termios_locked;
	struct termiox *termiox;
	char name[64];
	struct pid___204 *pgrp;
	struct pid___204 *session;
	long unsigned int flags;
	int count;
	struct winsize winsize;
	long unsigned int stopped: 1;
	long unsigned int flow_stopped: 1;
	int: 30;
	long unsigned int unused: 62;
	int hw_stopped;
	long unsigned int ctrl_status: 8;
	long unsigned int packet: 1;
	int: 23;
	long unsigned int unused_ctrl: 55;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___27 *link;
	struct fasync_struct___310 *fasync;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	spinlock_t files_lock;
	struct list_head tty_files;
	int closing;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___27 *port;
};

struct tty_driver___27 {
	int magic;
	struct kref kref;
	struct cdev___61 **cdevs;
	struct module___251 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___27 *other;
	struct tty_struct___27 **ttys;
	struct tty_port___27 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___27 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___27;

struct tty_port_client_operations___27;

struct tty_port___27 {
	struct tty_bufhead buf;
	struct tty_struct___27 *tty;
	struct tty_struct___27 *itty;
	const struct tty_port_operations___27 *ops;
	const struct tty_port_client_operations___27 *client_ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	unsigned char low_latency: 1;
	struct mutex mutex;
	struct mutex buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
	void *client_data;
};

struct tty_ldisc_ops___27 {
	int magic;
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___27 *);
	void (*close)(struct tty_struct___27 *);
	void (*flush_buffer)(struct tty_struct___27 *);
	ssize_t (*read)(struct tty_struct___27 *, struct file___311 *, unsigned char *, size_t);
	ssize_t (*write)(struct tty_struct___27 *, struct file___311 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___27 *, struct file___311 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___27 *, struct file___311 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___27 *, struct ktermios *);
	__poll_t (*poll)(struct tty_struct___27 *, struct file___311 *, struct poll_table_struct___6 *);
	int (*hangup)(struct tty_struct___27 *);
	void (*receive_buf)(struct tty_struct___27 *, const unsigned char *, char *, int);
	void (*write_wakeup)(struct tty_struct___27 *);
	void (*dcd_change)(struct tty_struct___27 *, unsigned int);
	int (*receive_buf2)(struct tty_struct___27 *, const unsigned char *, char *, int);
	struct module___251 *owner;
	int refcount;
};

struct tty_ldisc___27 {
	struct tty_ldisc_ops___27 *ops;
	struct tty_struct___27 *tty;
};

struct tty_port_operations___27 {
	int (*carrier_raised)(struct tty_port___27 *);
	void (*dtr_rts)(struct tty_port___27 *, int);
	void (*shutdown)(struct tty_port___27 *);
	int (*activate)(struct tty_port___27 *, struct tty_struct___27 *);
	void (*destruct)(struct tty_port___27 *);
};

struct tty_port_client_operations___27 {
	int (*receive_buf)(struct tty_port___27 *, const unsigned char *, const unsigned char *, size_t);
	void (*write_wakeup)(struct tty_port___27 *);
};

struct ldsem_waiter {
	struct list_head list;
	struct task_struct___322 *task;
};

struct module___262;

struct file___322;

struct kiocb___322;

struct poll_table_struct___196;

struct vm_area_struct___323;

struct inode___322;

struct file_lock___322;

struct page___323;

struct seq_file___273;

struct file_operations___322 {
	struct module___262 *owner;
	loff_t (*llseek)(struct file___322 *, loff_t, int);
	ssize_t (*read)(struct file___322 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___322 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___322 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___322 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___322 *, bool);
	int (*iterate)(struct file___322 *, struct dir_context *);
	int (*iterate_shared)(struct file___322 *, struct dir_context *);
	__poll_t (*poll)(struct file___322 *, struct poll_table_struct___196 *);
	long int (*unlocked_ioctl)(struct file___322 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___322 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___322 *, struct vm_area_struct___323 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___322 *, struct file___322 *);
	int (*flush)(struct file___322 *, fl_owner_t);
	int (*release)(struct inode___322 *, struct file___322 *);
	int (*fsync)(struct file___322 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___322 *, int);
	int (*lock)(struct file___322 *, int, struct file_lock___322 *);
	ssize_t (*sendpage)(struct file___322 *, struct page___323 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___322 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___322 *, int, struct file_lock___322 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___322 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___322 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___322 *, long int, struct file_lock___322 **, void **);
	long int (*fallocate)(struct file___322 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___273 *, struct file___322 *);
	ssize_t (*copy_file_range)(struct file___322 *, loff_t, struct file___322 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___322 *, loff_t, struct file___322 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___322 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___322 {
	u64 seqnum;
	struct vm_area_struct___323 *vmas[4];
};

struct page_frag___322 {
	struct page___323 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___322;

struct cred___299;

struct signal_struct___237;

struct task_struct___323 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___323 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___322 *mm;
	struct mm_struct___322 *active_mm;
	struct vmacache___322 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___323 *real_parent;
	struct task_struct___323 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___323 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___206 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___206 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___206 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___299 *ptracer_cred;
	const struct cred___299 *real_cred;
	const struct cred___299 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___237 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___323 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___82 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___322 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___323 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___132 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___323 *pgtable_t___322;

struct address_space___321;

struct dev_pagemap___310;

struct page___323 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___321 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___323 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___322 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___322 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___310 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___322;

struct lruvec___322 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___322 *pgdat;
};

struct zone___322 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___322 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___322 {
	struct zone___322 *zone;
	int zone_idx;
};

struct zonelist___322 {
	struct zoneref___322 _zonerefs[25];
};

struct pglist_data___322 {
	struct zone___322 node_zones[3];
	struct zonelist___322 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___323 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___323 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___322 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___323 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___323 *owner;
};

struct secondary_data___323 {
	void *stack;
	struct task_struct___323 *task;
	long int status;
};

struct blocking_notifier_head___322 {
	struct rw_semaphore___323 rwsem;
	struct notifier_block *head;
};

struct vfsmount___66;

struct dentry___321;

struct path___322 {
	struct vfsmount___66 *mnt;
	struct dentry___321 *dentry;
};

struct file___322 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___322 f_path;
	struct inode___322 *f_inode;
	const struct file_operations___322 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___206 f_owner;
	const struct cred___299 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___321 *f_mapping;
	errseq_t f_wb_err;
};

struct key___299;

struct user_struct___299;

struct cred___299 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___299 *session_keyring;
	struct key___299 *process_keyring;
	struct key___299 *thread_keyring;
	struct key___299 *request_key_auth;
	void *security;
	struct user_struct___299 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___315;

struct kernfs_elem_dir___315 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___315 *root;
};

struct kernfs_node___316;

struct kernfs_syscall_ops___315;

struct kernfs_root___315 {
	struct kernfs_node___316 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___315 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___315 {
	struct kernfs_node___316 *target_kn;
};

struct kernfs_ops___315;

struct kernfs_elem_attr___315 {
	const struct kernfs_ops___315 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___316 *notify_next;
};

struct kernfs_node___316 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___316 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___315 dir;
		struct kernfs_elem_symlink___315 symlink;
		struct kernfs_elem_attr___315 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___315;

struct kernfs_ops___315 {
	int (*open)(struct kernfs_open_file___315 *);
	void (*release)(struct kernfs_open_file___315 *);
	int (*seq_show)(struct seq_file___273 *, void *);
	void * (*seq_start)(struct seq_file___273 *, loff_t *);
	void * (*seq_next)(struct seq_file___273 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___273 *, void *);
	ssize_t (*read)(struct kernfs_open_file___315 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___315 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___315 *, struct vm_area_struct___323 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___315 *, struct poll_table_struct___196 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___315 {
	int (*remount_fs)(struct kernfs_root___315 *, int *, char *);
	int (*show_options)(struct seq_file___273 *, struct kernfs_root___315 *);
	int (*mkdir)(struct kernfs_node___316 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___316 *);
	int (*rename)(struct kernfs_node___316 *, struct kernfs_node___316 *, const char *);
	int (*show_path)(struct seq_file___273 *, struct kernfs_node___316 *, struct kernfs_root___315 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___272;

struct seq_file___273 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___272 *op;
	int poll_event;
	const struct file___322 *file;
	void *private;
};

struct vm_operations_struct___310;

struct kernfs_open_file___315 {
	struct kernfs_node___316 *kn;
	struct file___322 *file;
	struct seq_file___273 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___310 *vm_ops;
};

struct vm_fault___310;

struct vm_operations_struct___310 {
	void (*open)(struct vm_area_struct___323 *);
	void (*close)(struct vm_area_struct___323 *);
	int (*split)(struct vm_area_struct___323 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___323 *);
	vm_fault_t (*fault)(struct vm_fault___310 *);
	vm_fault_t (*huge_fault)(struct vm_fault___310 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___310 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___323 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___310 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___310 *);
	int (*access)(struct vm_area_struct___323 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___323 *);
	int (*set_policy)(struct vm_area_struct___323 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___323 *, long unsigned int);
	struct page___323 * (*find_special_page)(struct vm_area_struct___323 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___201)(struct file___322 *, wait_queue_head_t *, struct poll_table_struct___196 *);

struct poll_table_struct___196 {
	poll_queue_proc___201 _qproc;
	__poll_t _key;
};

struct vm_area_struct___323 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___323 *vm_next;
	struct vm_area_struct___323 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___322 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___310 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___322 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___309;

struct bin_attribute___285;

struct attribute_group___286 {
	const char *name;
	umode_t (*is_visible)(struct kobject___309 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___309 *, struct bin_attribute___285 *, int);
	struct attribute **attrs;
	struct bin_attribute___285 **bin_attrs;
};

struct kset___308;

struct kobj_type___308;

struct kobject___309 {
	const char *name;
	struct list_head entry;
	struct kobject___309 *parent;
	struct kset___308 *kset;
	struct kobj_type___308 *ktype;
	struct kernfs_node___316 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___285 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___322 *, struct kobject___309 *, struct bin_attribute___285 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___322 *, struct kobject___309 *, struct bin_attribute___285 *, char *, loff_t, size_t);
	int (*mmap)(struct file___322 *, struct kobject___309 *, struct bin_attribute___285 *, struct vm_area_struct___323 *);
};

struct sysfs_ops___308 {
	ssize_t (*show)(struct kobject___309 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___309 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___308;

struct kset___308 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___309 kobj;
	const struct kset_uevent_ops___308 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___308 {
	void (*release)(struct kobject___309 *);
	const struct sysfs_ops___308 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___25 * (*child_ns_type)(struct kobject___309 *);
	const void * (*namespace)(struct kobject___309 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___308 {
	int (* const filter)(struct kset___308 *, struct kobject___309 *);
	const char * (* const name)(struct kset___308 *, struct kobject___309 *);
	int (* const uevent)(struct kset___308 *, struct kobject___309 *, struct kobj_uevent_env *);
};

struct kobj_attribute___300 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___309 *, struct kobj_attribute___300 *, char *);
	ssize_t (*store)(struct kobject___309 *, struct kobj_attribute___300 *, const char *, size_t);
};

struct kernel_param___259;

struct kernel_param_ops___259 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___259 *);
	int (*get)(char *, const struct kernel_param___259 *);
	void (*free)(void *);
};

struct kparam_array___259;

struct kernel_param___259 {
	const char *name;
	struct module___262 *mod;
	const struct kernel_param_ops___259 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___259 *arr;
	};
};

struct kparam_array___259 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___259 *ops;
	void *elem;
};

struct module_kobject___259 {
	struct kobject___309 kobj;
	struct module___262 *mod;
	struct kobject___309 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___259 {
	struct module___262 *mod;
	struct latch_tree_node node;
};

struct module_layout___259 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___259 mtn;
};

struct module_attribute___259;

struct module___262 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___259 mkobj;
	struct module_attribute___259 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___309 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___259 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___259 core_layout;
	struct module_layout___259 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___259 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___259 *, struct module_kobject___259 *, char *);
	ssize_t (*store)(struct module_attribute___259 *, struct module_kobject___259 *, const char *, size_t);
	void (*setup)(struct module___262 *, const char *);
	int (*test)(struct module___262 *);
	void (*free)(struct module___262 *);
};

struct dentry_operations___321;

struct super_block___321;

struct dentry___321 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___321 *d_parent;
	struct qstr d_name;
	struct inode___322 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___321 *d_op;
	struct super_block___321 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___321;

struct address_space___321 {
	struct inode___322 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___323 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___321 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___321;

struct block_device___321;

struct cdev___70;

struct inode___322 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___321 *i_op;
	struct super_block___321 *i_sb;
	struct address_space___321 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___323 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___322 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___321 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___321 *i_bdev;
		struct cdev___70 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___321 {
	int (*d_revalidate)(struct dentry___321 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___321 *, unsigned int);
	int (*d_hash)(const struct dentry___321 *, struct qstr *);
	int (*d_compare)(const struct dentry___321 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___321 *);
	int (*d_init)(struct dentry___321 *);
	void (*d_release)(struct dentry___321 *);
	void (*d_prune)(struct dentry___321 *);
	void (*d_iput)(struct dentry___321 *, struct inode___322 *);
	char * (*d_dname)(struct dentry___321 *, char *, int);
	struct vfsmount___66 * (*d_automount)(struct path___322 *);
	int (*d_manage)(const struct path___322 *, bool);
	struct dentry___321 * (*d_real)(struct dentry___321 *, const struct inode___322 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___321;

struct mem_dqinfo___321 {
	struct quota_format_type___321 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___321;

struct quota_info___321 {
	unsigned int flags;
	struct rw_semaphore___323 dqio_sem;
	struct inode___322 *files[3];
	struct mem_dqinfo___321 info[3];
	const struct quota_format_ops___321 *ops[3];
};

struct rcuwait___321 {
	struct task_struct___323 *task;
};

struct percpu_rw_semaphore___321 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___323 rw_sem;
	struct rcuwait___321 writer;
	int readers_block;
};

struct sb_writers___321 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___321 rw_sem[3];
};

struct file_system_type___321;

struct super_operations___321;

struct dquot_operations___321;

struct quotactl_ops___321;

struct super_block___321 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___321 *s_type;
	const struct super_operations___321 *s_op;
	const struct dquot_operations___321 *dq_op;
	const struct quotactl_ops___321 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___321 *s_root;
	struct rw_semaphore___323 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___321 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___321 s_dquot;
	struct sb_writers___321 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___321 *s_d_op;
	int cleancache_poolid;
	struct shrinker___119 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___66 {
	struct dentry___321 *mnt_root;
	struct super_block___321 *mnt_sb;
	int mnt_flags;
};

struct core_state___322;

struct mm_struct___322 {
	struct {
		struct vm_area_struct___323 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___322 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___323 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___322 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___323 *owner;
		struct user_namespace___3 *user_ns;
		struct file___322 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___322 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___310)(struct vm_area_struct___323 *, long unsigned int, const struct page___323 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___310)(struct page___323 *, void *);

struct device___288;

struct dev_pagemap___310 {
	dev_page_fault_t___310 page_fault;
	dev_page_free_t___310 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___288 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___322 {
	struct task_struct___323 *task;
	struct core_thread___322 *next;
};

struct core_state___322 {
	atomic_t nr_threads;
	struct core_thread___322 dumper;
	struct completion startup;
};

struct vm_fault___310 {
	struct vm_area_struct___323 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___323 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___323 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___322 prealloc_pte;
};

struct user_struct___299 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___299 *uid_keyring;
	struct key___299 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct tty_struct___28;

struct signal_struct___237 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___323 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___323 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___206 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___206 *tty_old_pgrp;
	int leader;
	struct tty_struct___28 *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___322 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___206 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

union thread_union___249 {
	struct task_struct___323 task;
	long unsigned int stack[8192];
};

struct kiocb___322 {
	struct file___322 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___322 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___321 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___322 *ia_file;
};

struct dquot___321 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___321 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___321 {
	int qf_fmt_id;
	const struct quota_format_ops___321 *qf_ops;
	struct module___262 *qf_owner;
	struct quota_format_type___321 *qf_next;
};

struct quota_format_ops___321 {
	int (*check_quota_file)(struct super_block___321 *, int);
	int (*read_file_info)(struct super_block___321 *, int);
	int (*write_file_info)(struct super_block___321 *, int);
	int (*free_file_info)(struct super_block___321 *, int);
	int (*read_dqblk)(struct dquot___321 *);
	int (*commit_dqblk)(struct dquot___321 *);
	int (*release_dqblk)(struct dquot___321 *);
	int (*get_next_id)(struct super_block___321 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___321 {
	int (*write_dquot)(struct dquot___321 *);
	struct dquot___321 * (*alloc_dquot)(struct super_block___321 *, int);
	void (*destroy_dquot)(struct dquot___321 *);
	int (*acquire_dquot)(struct dquot___321 *);
	int (*release_dquot)(struct dquot___321 *);
	int (*mark_dirty)(struct dquot___321 *);
	int (*write_info)(struct super_block___321 *, int);
	qsize_t * (*get_reserved_space)(struct inode___322 *);
	int (*get_projid)(struct inode___322 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___322 *, qsize_t *);
	int (*get_next_id)(struct super_block___321 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___321 {
	int (*quota_on)(struct super_block___321 *, int, int, const struct path___322 *);
	int (*quota_off)(struct super_block___321 *, int);
	int (*quota_enable)(struct super_block___321 *, unsigned int);
	int (*quota_disable)(struct super_block___321 *, unsigned int);
	int (*quota_sync)(struct super_block___321 *, int);
	int (*set_info)(struct super_block___321 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___321 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___321 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___321 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___321 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___321 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___321 {
	int (*writepage)(struct page___323 *, struct writeback_control___3 *);
	int (*readpage)(struct file___322 *, struct page___323 *);
	int (*writepages)(struct address_space___321 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___323 *);
	int (*readpages)(struct file___322 *, struct address_space___321 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___322 *, struct address_space___321 *, loff_t, unsigned int, unsigned int, struct page___323 **, void **);
	int (*write_end)(struct file___322 *, struct address_space___321 *, loff_t, unsigned int, unsigned int, struct page___323 *, void *);
	sector_t (*bmap)(struct address_space___321 *, sector_t);
	void (*invalidatepage)(struct page___323 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___323 *, gfp_t);
	void (*freepage)(struct page___323 *);
	ssize_t (*direct_IO)(struct kiocb___322 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___321 *, struct page___323 *, struct page___323 *, enum migrate_mode);
	bool (*isolate_page)(struct page___323 *, isolate_mode_t);
	void (*putback_page)(struct page___323 *);
	int (*launder_page)(struct page___323 *);
	int (*is_partially_uptodate)(struct page___323 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___323 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___321 *, struct page___323 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___322 *, sector_t *);
	void (*swap_deactivate)(struct file___322 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___321 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___322 *bd_inode;
	struct super_block___321 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___321 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___70 {
	struct kobject___309 kobj;
	struct module___262 *owner;
	const struct file_operations___322 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___321 {
	struct dentry___321 * (*lookup)(struct inode___322 *, struct dentry___321 *, unsigned int);
	const char * (*get_link)(struct dentry___321 *, struct inode___322 *, struct delayed_call *);
	int (*permission)(struct inode___322 *, int);
	struct posix_acl * (*get_acl)(struct inode___322 *, int);
	int (*readlink)(struct dentry___321 *, char *, int);
	int (*create)(struct inode___322 *, struct dentry___321 *, umode_t, bool);
	int (*link)(struct dentry___321 *, struct inode___322 *, struct dentry___321 *);
	int (*unlink)(struct inode___322 *, struct dentry___321 *);
	int (*symlink)(struct inode___322 *, struct dentry___321 *, const char *);
	int (*mkdir)(struct inode___322 *, struct dentry___321 *, umode_t);
	int (*rmdir)(struct inode___322 *, struct dentry___321 *);
	int (*mknod)(struct inode___322 *, struct dentry___321 *, umode_t, dev_t);
	int (*rename)(struct inode___322 *, struct dentry___321 *, struct inode___322 *, struct dentry___321 *, unsigned int);
	int (*setattr)(struct dentry___321 *, struct iattr___321 *);
	int (*getattr)(const struct path___322 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___321 *, char *, size_t);
	int (*fiemap)(struct inode___322 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___322 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___322 *, struct dentry___321 *, struct file___322 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___322 *, struct dentry___321 *, umode_t);
	int (*set_acl)(struct inode___322 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___321 {
	void (*fl_copy_lock)(struct file_lock___322 *, struct file_lock___322 *);
	void (*fl_release_private)(struct file_lock___322 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___321;

struct lock_manager_operations___321;

struct file_lock___322 {
	struct file_lock___322 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___322 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___321 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___321 *fl_ops;
	const struct lock_manager_operations___321 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___321 {
	int (*lm_compare_owner)(struct file_lock___322 *, struct file_lock___322 *);
	long unsigned int (*lm_owner_key)(struct file_lock___322 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___322 *);
	int (*lm_grant)(struct file_lock___322 *, int);
	bool (*lm_break)(struct file_lock___322 *);
	int (*lm_change)(struct file_lock___322 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___322 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___321 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___321 *fa_next;
	struct file___322 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___321 {
	const char *name;
	int fs_flags;
	struct dentry___321 * (*mount)(struct file_system_type___321 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___321 *);
	struct module___262 *owner;
	struct file_system_type___321 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___321 {
	struct inode___322 * (*alloc_inode)(struct super_block___321 *);
	void (*destroy_inode)(struct inode___322 *);
	void (*dirty_inode)(struct inode___322 *, int);
	int (*write_inode)(struct inode___322 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___322 *);
	void (*evict_inode)(struct inode___322 *);
	void (*put_super)(struct super_block___321 *);
	int (*sync_fs)(struct super_block___321 *, int);
	int (*freeze_super)(struct super_block___321 *);
	int (*freeze_fs)(struct super_block___321 *);
	int (*thaw_super)(struct super_block___321 *);
	int (*unfreeze_fs)(struct super_block___321 *);
	int (*statfs)(struct dentry___321 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___321 *, int *, char *);
	void (*umount_begin)(struct super_block___321 *);
	int (*show_options)(struct seq_file___273 *, struct dentry___321 *);
	int (*show_devname)(struct seq_file___273 *, struct dentry___321 *);
	int (*show_path)(struct seq_file___273 *, struct dentry___321 *);
	int (*show_stats)(struct seq_file___273 *, struct dentry___321 *);
	ssize_t (*quota_read)(struct super_block___321 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___321 *, int, const char *, size_t, loff_t);
	struct dquot___321 ** (*get_dquots)(struct inode___322 *);
	int (*bdev_try_to_free_page)(struct super_block___321 *, struct page___323 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___321 *, struct shrink_control___119 *);
	long int (*free_cached_objects)(struct super_block___321 *, struct shrink_control___119 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_ops___288 {
	int (*prepare)(struct device___288 *);
	void (*complete)(struct device___288 *);
	int (*suspend)(struct device___288 *);
	int (*resume)(struct device___288 *);
	int (*freeze)(struct device___288 *);
	int (*thaw)(struct device___288 *);
	int (*poweroff)(struct device___288 *);
	int (*restore)(struct device___288 *);
	int (*suspend_late)(struct device___288 *);
	int (*resume_early)(struct device___288 *);
	int (*freeze_late)(struct device___288 *);
	int (*thaw_early)(struct device___288 *);
	int (*poweroff_late)(struct device___288 *);
	int (*restore_early)(struct device___288 *);
	int (*suspend_noirq)(struct device___288 *);
	int (*resume_noirq)(struct device___288 *);
	int (*freeze_noirq)(struct device___288 *);
	int (*thaw_noirq)(struct device___288 *);
	int (*poweroff_noirq)(struct device___288 *);
	int (*restore_noirq)(struct device___288 *);
	int (*runtime_suspend)(struct device___288 *);
	int (*runtime_resume)(struct device___288 *);
	int (*runtime_idle)(struct device___288 *);
};

struct dev_pm_info___288 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___3 *subsys_data;
	void (*set_latency_tolerance)(struct device___288 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___288;

struct bus_type___288;

struct device_driver___288;

struct dev_pm_domain___288;

struct class___288;

struct device___288 {
	struct device___288 *parent;
	struct device_private *p;
	struct kobject___309 kobj;
	const char *init_name;
	const struct device_type___288 *type;
	struct mutex mutex;
	struct bus_type___288 *bus;
	struct device_driver___288 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___288 power;
	struct dev_pm_domain___288 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___288 *class;
	const struct attribute_group___286 **groups;
	void (*release)(struct device___288 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___288 {
	struct dev_pm_ops___288 ops;
	void (*detach)(struct device___288 *, bool);
	int (*activate)(struct device___288 *);
	void (*sync)(struct device___288 *);
	void (*dismiss)(struct device___288 *);
};

struct bus_type___288 {
	const char *name;
	const char *dev_name;
	struct device___288 *dev_root;
	const struct attribute_group___286 **bus_groups;
	const struct attribute_group___286 **dev_groups;
	const struct attribute_group___286 **drv_groups;
	int (*match)(struct device___288 *, struct device_driver___288 *);
	int (*uevent)(struct device___288 *, struct kobj_uevent_env *);
	int (*probe)(struct device___288 *);
	int (*remove)(struct device___288 *);
	void (*shutdown)(struct device___288 *);
	int (*online)(struct device___288 *);
	int (*offline)(struct device___288 *);
	int (*suspend)(struct device___288 *, pm_message_t);
	int (*resume)(struct device___288 *);
	int (*num_vf)(struct device___288 *);
	int (*dma_configure)(struct device___288 *);
	const struct dev_pm_ops___288 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___288 {
	const char *name;
	struct bus_type___288 *bus;
	struct module___262 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___288 *);
	int (*remove)(struct device___288 *);
	void (*shutdown)(struct device___288 *);
	int (*suspend)(struct device___288 *, pm_message_t);
	int (*resume)(struct device___288 *);
	const struct attribute_group___286 **groups;
	const struct dev_pm_ops___288 *pm;
	void (*coredump)(struct device___288 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___288 {
	const char *name;
	const struct attribute_group___286 **groups;
	int (*uevent)(struct device___288 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___288 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___288 *);
	const struct dev_pm_ops___288 *pm;
};

struct class___288 {
	const char *name;
	struct module___262 *owner;
	const struct attribute_group___286 **class_groups;
	const struct attribute_group___286 **dev_groups;
	struct kobject___309 *dev_kobj;
	int (*dev_uevent)(struct device___288 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___288 *, umode_t *);
	void (*class_release)(struct class___288 *);
	void (*dev_release)(struct device___288 *);
	int (*shutdown_pre)(struct device___288 *);
	const struct kobj_ns_type_operations___25 *ns_type;
	const void * (*namespace)(struct device___288 *);
	const struct dev_pm_ops___288 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

typedef int (*key_restrict_link_func_t___300)(struct key___299 *, const struct key_type *, const union key_payload *, struct key___299 *);

struct key_restriction___299;

struct key___299 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___323 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___299 *restrict_link;
};

struct key_restriction___299 {
	key_restrict_link_func_t___300 check;
	struct key___299 *key;
	struct key_type *keytype;
};

struct seq_operations___272 {
	void * (*start)(struct seq_file___273 *, loff_t *);
	void (*stop)(struct seq_file___273 *, void *);
	void * (*next)(struct seq_file___273 *, void *, loff_t *);
	int (*show)(struct seq_file___273 *, void *);
};

struct tty_driver___28;

struct tty_operations___28 {
	struct tty_struct___28 * (*lookup)(struct tty_driver___28 *, struct file___322 *, int);
	int (*install)(struct tty_driver___28 *, struct tty_struct___28 *);
	void (*remove)(struct tty_driver___28 *, struct tty_struct___28 *);
	int (*open)(struct tty_struct___28 *, struct file___322 *);
	void (*close)(struct tty_struct___28 *, struct file___322 *);
	void (*shutdown)(struct tty_struct___28 *);
	void (*cleanup)(struct tty_struct___28 *);
	int (*write)(struct tty_struct___28 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___28 *, unsigned char);
	void (*flush_chars)(struct tty_struct___28 *);
	int (*write_room)(struct tty_struct___28 *);
	int (*chars_in_buffer)(struct tty_struct___28 *);
	int (*ioctl)(struct tty_struct___28 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___28 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___28 *, struct ktermios *);
	void (*throttle)(struct tty_struct___28 *);
	void (*unthrottle)(struct tty_struct___28 *);
	void (*stop)(struct tty_struct___28 *);
	void (*start)(struct tty_struct___28 *);
	void (*hangup)(struct tty_struct___28 *);
	int (*break_ctl)(struct tty_struct___28 *, int);
	void (*flush_buffer)(struct tty_struct___28 *);
	void (*set_ldisc)(struct tty_struct___28 *);
	void (*wait_until_sent)(struct tty_struct___28 *, int);
	void (*send_xchar)(struct tty_struct___28 *, char);
	int (*tiocmget)(struct tty_struct___28 *);
	int (*tiocmset)(struct tty_struct___28 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___28 *, struct winsize *);
	int (*set_termiox)(struct tty_struct___28 *, struct termiox *);
	int (*get_icount)(struct tty_struct___28 *, struct serial_icounter_struct *);
	void (*show_fdinfo)(struct tty_struct___28 *, struct seq_file___273 *);
	int (*poll_init)(struct tty_driver___28 *, int, char *);
	int (*poll_get_char)(struct tty_driver___28 *, int);
	void (*poll_put_char)(struct tty_driver___28 *, int, char);
	int (*proc_show)(struct seq_file___273 *, void *);
};

struct tty_ldisc___28;

struct tty_port___28;

struct tty_struct___28 {
	int magic;
	struct kref kref;
	struct device___288 *dev;
	struct tty_driver___28 *driver;
	const struct tty_operations___28 *ops;
	int index;
	struct ld_semaphore ldisc_sem;
	struct tty_ldisc___28 *ldisc;
	struct mutex atomic_write_lock;
	struct mutex legacy_mutex;
	struct mutex throttle_mutex;
	struct rw_semaphore___323 termios_rwsem;
	struct mutex winsize_mutex;
	spinlock_t ctrl_lock;
	spinlock_t flow_lock;
	struct ktermios termios;
	struct ktermios termios_locked;
	struct termiox *termiox;
	char name[64];
	struct pid___206 *pgrp;
	struct pid___206 *session;
	long unsigned int flags;
	int count;
	struct winsize winsize;
	long unsigned int stopped: 1;
	long unsigned int flow_stopped: 1;
	int: 30;
	long unsigned int unused: 62;
	int hw_stopped;
	long unsigned int ctrl_status: 8;
	long unsigned int packet: 1;
	int: 23;
	long unsigned int unused_ctrl: 55;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___28 *link;
	struct fasync_struct___321 *fasync;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	spinlock_t files_lock;
	struct list_head tty_files;
	int closing;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___28 *port;
};

struct tty_driver___28 {
	int magic;
	struct kref kref;
	struct cdev___70 **cdevs;
	struct module___262 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___28 *other;
	struct tty_struct___28 **ttys;
	struct tty_port___28 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___28 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___28;

struct tty_port_client_operations___28;

struct tty_port___28 {
	struct tty_bufhead buf;
	struct tty_struct___28 *tty;
	struct tty_struct___28 *itty;
	const struct tty_port_operations___28 *ops;
	const struct tty_port_client_operations___28 *client_ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	unsigned char low_latency: 1;
	struct mutex mutex;
	struct mutex buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
	void *client_data;
};

struct tty_ldisc_ops___28 {
	int magic;
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___28 *);
	void (*close)(struct tty_struct___28 *);
	void (*flush_buffer)(struct tty_struct___28 *);
	ssize_t (*read)(struct tty_struct___28 *, struct file___322 *, unsigned char *, size_t);
	ssize_t (*write)(struct tty_struct___28 *, struct file___322 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___28 *, struct file___322 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___28 *, struct file___322 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___28 *, struct ktermios *);
	__poll_t (*poll)(struct tty_struct___28 *, struct file___322 *, struct poll_table_struct___196 *);
	int (*hangup)(struct tty_struct___28 *);
	void (*receive_buf)(struct tty_struct___28 *, const unsigned char *, char *, int);
	void (*write_wakeup)(struct tty_struct___28 *);
	void (*dcd_change)(struct tty_struct___28 *, unsigned int);
	int (*receive_buf2)(struct tty_struct___28 *, const unsigned char *, char *, int);
	struct module___262 *owner;
	int refcount;
};

struct tty_ldisc___28 {
	struct tty_ldisc_ops___28 *ops;
	struct tty_struct___28 *tty;
};

struct tty_port_operations___28 {
	int (*carrier_raised)(struct tty_port___28 *);
	void (*dtr_rts)(struct tty_port___28 *, int);
	void (*shutdown)(struct tty_port___28 *);
	int (*activate)(struct tty_port___28 *, struct tty_struct___28 *);
	void (*destruct)(struct tty_port___28 *);
};

struct tty_port_client_operations___28 {
	int (*receive_buf)(struct tty_port___28 *, const unsigned char *, const unsigned char *, size_t);
	void (*write_wakeup)(struct tty_port___28 *);
};

typedef void compound_page_dtor___310(struct page___323 *);

struct pts_fs_info___2;

struct tty_audit_buf {
	struct mutex mutex;
	dev_t dev;
	unsigned int icanon: 1;
	size_t valid;
	unsigned char *data;
};

struct module___263;

struct file___323;

struct kiocb___323;

struct iov_iter___139;

struct poll_table_struct___197;

struct vm_area_struct___324;

struct inode___323;

struct file_lock___323;

struct page___324;

struct seq_file___274;

struct file_operations___323 {
	struct module___263 *owner;
	loff_t (*llseek)(struct file___323 *, loff_t, int);
	ssize_t (*read)(struct file___323 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___323 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___323 *, struct iov_iter___139 *);
	ssize_t (*write_iter)(struct kiocb___323 *, struct iov_iter___139 *);
	int (*iopoll)(struct kiocb___323 *, bool);
	int (*iterate)(struct file___323 *, struct dir_context *);
	int (*iterate_shared)(struct file___323 *, struct dir_context *);
	__poll_t (*poll)(struct file___323 *, struct poll_table_struct___197 *);
	long int (*unlocked_ioctl)(struct file___323 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___323 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___323 *, struct vm_area_struct___324 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___323 *, struct file___323 *);
	int (*flush)(struct file___323 *, fl_owner_t);
	int (*release)(struct inode___323 *, struct file___323 *);
	int (*fsync)(struct file___323 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___323 *, int);
	int (*lock)(struct file___323 *, int, struct file_lock___323 *);
	ssize_t (*sendpage)(struct file___323 *, struct page___324 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___323 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___323 *, int, struct file_lock___323 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___323 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___323 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___323 *, long int, struct file_lock___323 **, void **);
	long int (*fallocate)(struct file___323 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___274 *, struct file___323 *);
	ssize_t (*copy_file_range)(struct file___323 *, loff_t, struct file___323 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___323 *, loff_t, struct file___323 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___323 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___323 {
	u64 seqnum;
	struct vm_area_struct___324 *vmas[4];
};

struct page_frag___323 {
	struct page___324 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___133;

struct debug_info___133 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___133 *hbp_break[16];
	struct perf_event___133 *hbp_watch[16];
};

struct thread_struct___133 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___133 debug;
	long: 64;
};

struct mm_struct___323;

struct mem_cgroup___120;

struct pid___207;

struct cred___300;

struct nsproxy___256;

struct signal_struct___238;

struct bio_list___152;

struct backing_dev_info___152;

struct css_set___212;

struct perf_event_context___133;

struct task_struct___324 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___324 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___323 *mm;
	struct mm_struct___323 *active_mm;
	struct vmacache___323 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___324 *real_parent;
	struct task_struct___324 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___324 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___120 *active_memcg;
	long int rh_reserved2;
	struct pid___207 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___207 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___207 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___300 *ptracer_cred;
	const struct cred___300 *real_cred;
	const struct cred___300 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___256 *nsproxy;
	struct signal_struct___238 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___324 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___152 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___152 *backing_dev_info;
	struct io_context___82 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___212 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___133 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___323 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___120 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___324 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___133 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___133 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___324 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___133)(struct perf_event___133 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___133;

struct fasync_struct___322;

struct pid_namespace___207;

struct trace_event_call___126;

struct perf_cgroup___133;

struct perf_event___133 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___133 *group_leader;
	struct pmu___133 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___133 hw;
	struct perf_event_context___133 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___133 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___324 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___322 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___133 *);
	struct callback_head callback_head;
	struct pid_namespace___207 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___133 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___133 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___126 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___133 *cgrp;
	struct list_head sb_list;
};

struct key___300;

struct user_struct___300 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___300 *uid_keyring;
	struct key___300 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct upid___207 {
	int nr;
	struct pid_namespace___207 *ns;
};

struct vfsmount___67;

struct dentry___322;

struct user_namespace___227;

struct ucounts___227;

struct pid_namespace___207 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___324 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___207 *parent;
	struct vfsmount___67 *proc_mnt;
	struct dentry___322 *proc_self;
	struct dentry___322 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___227 *user_ns;
	struct ucounts___227 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___9 ns;
};

struct pid___207 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___207 numbers[1];
};

struct rw_semaphore___324 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___324 *owner;
};

struct user_namespace___227 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___227 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___9 ns;
	long unsigned int flags;
	struct key___300 *persistent_keyring_register;
	struct rw_semaphore___324 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___227 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct secondary_data___324 {
	void *stack;
	struct task_struct___324 *task;
	long int status;
};

typedef struct page___324 *pgtable_t___323;

struct address_space___322;

struct dev_pagemap___311;

struct page___324 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___322 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___324 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___323 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___323 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___311 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___120 *mem_cgroup;
};

struct vm_operations_struct___311;

struct vm_area_struct___324 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___324 *vm_next;
	struct vm_area_struct___324 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___323 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___311 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___323 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___323;

struct mm_struct___323 {
	struct {
		struct vm_area_struct___324 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___323 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___324 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___323 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___324 *owner;
		struct user_namespace___227 *user_ns;
		struct file___323 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___323 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup___212;

struct cgroup_subsys___212;

struct cgroup_subsys_state___212 {
	struct cgroup___212 *cgroup;
	struct cgroup_subsys___212 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___212 *parent;
};

struct kernfs_node___317;

struct cgroup_file___212 {
	struct kernfs_node___317 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___120;

struct mem_cgroup___120 {
	struct cgroup_subsys_state___212 css;
	struct mem_cgroup_id___5 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___212 events_file;
	struct cgroup_file___212 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___324 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___120 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cred___300 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___300 *session_keyring;
	struct key___300 *process_keyring;
	struct key___300 *thread_keyring;
	struct key___300 *request_key_auth;
	void *security;
	struct user_struct___300 *user;
	struct user_namespace___227 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___212;

struct nsproxy___256 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___207 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___212 *cgroup_ns;
};

struct tty_struct___29;

struct signal_struct___238 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___324 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___324 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___207 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___207 *tty_old_pgrp;
	int leader;
	struct tty_struct___29 *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___323 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___207 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___152;

struct bio_list___152 {
	struct bio___152 *head;
	struct bio___152 *tail;
};

struct bdi_writeback_congested___152;

struct bdi_writeback___152 {
	struct backing_dev_info___152 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___152 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___212 *memcg_css;
	struct cgroup_subsys_state___212 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___289;

struct backing_dev_info___152 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___152 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___289 *dev;
	struct device___289 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___322 *debug_dir;
	struct dentry___322 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___212 {
	struct cgroup_subsys_state___212 *subsys[13];
	refcount_t refcount;
	struct css_set___212 *dom_cset;
	struct cgroup___212 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___212 *mg_src_cgrp;
	struct cgroup___212 *mg_dst_cgrp;
	struct css_set___212 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___133 {
	struct pmu___133 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___324 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___133 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

union thread_union___250 {
	struct task_struct___324 task;
	long unsigned int stack[8192];
};

typedef int (*key_restrict_link_func_t___301)(struct key___300 *, const struct key_type *, const union key_payload *, struct key___300 *);

struct key_restriction___300;

struct key___300 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___324 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___300 *restrict_link;
};

struct key_restriction___300 {
	key_restrict_link_func_t___301 check;
	struct key___300 *key;
	struct key_type *keytype;
};

struct tty_driver___29;

struct tty_operations___29;

struct tty_ldisc___29;

struct tty_port___29;

struct tty_struct___29 {
	int magic;
	struct kref kref;
	struct device___289 *dev;
	struct tty_driver___29 *driver;
	const struct tty_operations___29 *ops;
	int index;
	struct ld_semaphore ldisc_sem;
	struct tty_ldisc___29 *ldisc;
	struct mutex atomic_write_lock;
	struct mutex legacy_mutex;
	struct mutex throttle_mutex;
	struct rw_semaphore___324 termios_rwsem;
	struct mutex winsize_mutex;
	spinlock_t ctrl_lock;
	spinlock_t flow_lock;
	struct ktermios termios;
	struct ktermios termios_locked;
	struct termiox *termiox;
	char name[64];
	struct pid___207 *pgrp;
	struct pid___207 *session;
	long unsigned int flags;
	int count;
	struct winsize winsize;
	long unsigned int stopped: 1;
	long unsigned int flow_stopped: 1;
	int: 30;
	long unsigned int unused: 62;
	int hw_stopped;
	long unsigned int ctrl_status: 8;
	long unsigned int packet: 1;
	int: 23;
	long unsigned int unused_ctrl: 55;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___29 *link;
	struct fasync_struct___322 *fasync;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	spinlock_t files_lock;
	struct list_head tty_files;
	int closing;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___29 *port;
};

struct pglist_data___323;

struct lruvec___323 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___323 *pgdat;
};

struct zone___323 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___323 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___323 {
	struct zone___323 *zone;
	int zone_idx;
};

struct zonelist___323 {
	struct zoneref___323 _zonerefs[25];
};

struct pglist_data___323 {
	struct zone___323 node_zones[3];
	struct zonelist___323 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___324 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___324 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___323 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___323 {
	struct rw_semaphore___324 rwsem;
	struct notifier_block *head;
};

struct address_space_operations___322;

struct address_space___322 {
	struct inode___323 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___324 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___322 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___311)(struct vm_area_struct___324 *, long unsigned int, const struct page___324 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___311)(struct page___324 *, void *);

struct dev_pagemap___311 {
	dev_page_fault_t___311 page_fault;
	dev_page_free_t___311 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___289 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___323 {
	struct vfsmount___67 *mnt;
	struct dentry___322 *dentry;
};

struct fown_struct___207 {
	rwlock_t lock;
	struct pid___207 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___323 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___323 f_path;
	struct inode___323 *f_inode;
	const struct file_operations___323 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___207 f_owner;
	const struct cred___300 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___322 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___311;

struct vm_operations_struct___311 {
	void (*open)(struct vm_area_struct___324 *);
	void (*close)(struct vm_area_struct___324 *);
	int (*split)(struct vm_area_struct___324 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___324 *);
	vm_fault_t (*fault)(struct vm_fault___311 *);
	vm_fault_t (*huge_fault)(struct vm_fault___311 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___311 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___324 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___311 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___311 *);
	int (*access)(struct vm_area_struct___324 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___324 *);
	int (*set_policy)(struct vm_area_struct___324 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___324 *, long unsigned int);
	struct page___324 * (*find_special_page)(struct vm_area_struct___324 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___323 {
	struct task_struct___324 *task;
	struct core_thread___323 *next;
};

struct core_state___323 {
	atomic_t nr_threads;
	struct core_thread___323 dumper;
	struct completion startup;
};

struct vm_fault___311 {
	struct vm_area_struct___324 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___324 *cow_page;
	struct mem_cgroup___120 *memcg;
	struct page___324 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___323 prealloc_pte;
};

struct shrink_control___120 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___120 *memcg;
};

struct shrinker___120 {
	long unsigned int (*count_objects)(struct shrinker___120 *, struct shrink_control___120 *);
	long unsigned int (*scan_objects)(struct shrinker___120 *, struct shrink_control___120 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct kset___309;

struct kobj_type___309;

struct kobject___310 {
	const char *name;
	struct list_head entry;
	struct kobject___310 *parent;
	struct kset___309 *kset;
	struct kobj_type___309 *ktype;
	struct kernfs_node___317 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___289 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___3 *subsys_data;
	void (*set_latency_tolerance)(struct device___289 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___289;

struct bus_type___289;

struct device_driver___289;

struct dev_pm_domain___289;

struct device_node___72;

struct fwnode_handle___218;

struct class___289;

struct attribute_group___287;

struct device___289 {
	struct device___289 *parent;
	struct device_private *p;
	struct kobject___310 kobj;
	const char *init_name;
	const struct device_type___289 *type;
	struct mutex mutex;
	struct bus_type___289 *bus;
	struct device_driver___289 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___289 power;
	struct dev_pm_domain___289 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___72 *of_node;
	struct fwnode_handle___218 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___289 *class;
	const struct attribute_group___287 **groups;
	void (*release)(struct device___289 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___322;

struct super_block___322;

struct dentry___322 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___322 *d_parent;
	struct qstr d_name;
	struct inode___323 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___322 *d_op;
	struct super_block___322 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___322;

struct block_device___322;

struct cdev___71;

struct inode___323 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___322 *i_op;
	struct super_block___322 *i_sb;
	struct address_space___322 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___324 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___152 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___323 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___322 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___322 *i_bdev;
		struct cdev___71 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___322 {
	int (*d_revalidate)(struct dentry___322 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___322 *, unsigned int);
	int (*d_hash)(const struct dentry___322 *, struct qstr *);
	int (*d_compare)(const struct dentry___322 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___322 *);
	int (*d_init)(struct dentry___322 *);
	void (*d_release)(struct dentry___322 *);
	void (*d_prune)(struct dentry___322 *);
	void (*d_iput)(struct dentry___322 *, struct inode___323 *);
	char * (*d_dname)(struct dentry___322 *, char *, int);
	struct vfsmount___67 * (*d_automount)(struct path___323 *);
	int (*d_manage)(const struct path___323 *, bool);
	struct dentry___322 * (*d_real)(struct dentry___322 *, const struct inode___323 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___322;

struct mem_dqinfo___322 {
	struct quota_format_type___322 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___322;

struct quota_info___322 {
	unsigned int flags;
	struct rw_semaphore___324 dqio_sem;
	struct inode___323 *files[3];
	struct mem_dqinfo___322 info[3];
	const struct quota_format_ops___322 *ops[3];
};

struct rcuwait___322 {
	struct task_struct___324 *task;
};

struct percpu_rw_semaphore___322 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___324 rw_sem;
	struct rcuwait___322 writer;
	int readers_block;
};

struct sb_writers___322 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___322 rw_sem[3];
};

struct file_system_type___322;

struct super_operations___322;

struct dquot_operations___322;

struct quotactl_ops___322;

struct super_block___322 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___322 *s_type;
	const struct super_operations___322 *s_op;
	const struct dquot_operations___322 *dq_op;
	const struct quotactl_ops___322 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___322 *s_root;
	struct rw_semaphore___324 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___322 *s_bdev;
	struct backing_dev_info___152 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___322 s_dquot;
	struct sb_writers___322 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___322 *s_d_op;
	int cleancache_poolid;
	struct shrinker___120 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___227 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___67 {
	struct dentry___322 *mnt_root;
	struct super_block___322 *mnt_sb;
	int mnt_flags;
};

struct kiocb___323 {
	struct file___323 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___323 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___322 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___323 *ia_file;
};

struct dquot___322 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___322 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___322 {
	int qf_fmt_id;
	const struct quota_format_ops___322 *qf_ops;
	struct module___263 *qf_owner;
	struct quota_format_type___322 *qf_next;
};

struct quota_format_ops___322 {
	int (*check_quota_file)(struct super_block___322 *, int);
	int (*read_file_info)(struct super_block___322 *, int);
	int (*write_file_info)(struct super_block___322 *, int);
	int (*free_file_info)(struct super_block___322 *, int);
	int (*read_dqblk)(struct dquot___322 *);
	int (*commit_dqblk)(struct dquot___322 *);
	int (*release_dqblk)(struct dquot___322 *);
	int (*get_next_id)(struct super_block___322 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___322 {
	int (*write_dquot)(struct dquot___322 *);
	struct dquot___322 * (*alloc_dquot)(struct super_block___322 *, int);
	void (*destroy_dquot)(struct dquot___322 *);
	int (*acquire_dquot)(struct dquot___322 *);
	int (*release_dquot)(struct dquot___322 *);
	int (*mark_dirty)(struct dquot___322 *);
	int (*write_info)(struct super_block___322 *, int);
	qsize_t * (*get_reserved_space)(struct inode___323 *);
	int (*get_projid)(struct inode___323 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___323 *, qsize_t *);
	int (*get_next_id)(struct super_block___322 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___322 {
	int (*quota_on)(struct super_block___322 *, int, int, const struct path___323 *);
	int (*quota_off)(struct super_block___322 *, int);
	int (*quota_enable)(struct super_block___322 *, unsigned int);
	int (*quota_disable)(struct super_block___322 *, unsigned int);
	int (*quota_sync)(struct super_block___322 *, int);
	int (*set_info)(struct super_block___322 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___322 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___322 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___322 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___322 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___322 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___260 {
	struct kobject___310 kobj;
	struct module___263 *mod;
	struct kobject___310 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___260 {
	struct module___263 *mod;
	struct latch_tree_node node;
};

struct module_layout___260 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___260 mtn;
};

struct module_attribute___260;

struct kernel_param___260;

struct module___263 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___260 mkobj;
	struct module_attribute___260 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___310 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___260 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___260 core_layout;
	struct module_layout___260 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___126 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___135;

struct swap_info_struct___78;

struct address_space_operations___322 {
	int (*writepage)(struct page___324 *, struct writeback_control___135 *);
	int (*readpage)(struct file___323 *, struct page___324 *);
	int (*writepages)(struct address_space___322 *, struct writeback_control___135 *);
	int (*set_page_dirty)(struct page___324 *);
	int (*readpages)(struct file___323 *, struct address_space___322 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___323 *, struct address_space___322 *, loff_t, unsigned int, unsigned int, struct page___324 **, void **);
	int (*write_end)(struct file___323 *, struct address_space___322 *, loff_t, unsigned int, unsigned int, struct page___324 *, void *);
	sector_t (*bmap)(struct address_space___322 *, sector_t);
	void (*invalidatepage)(struct page___324 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___324 *, gfp_t);
	void (*freepage)(struct page___324 *);
	ssize_t (*direct_IO)(struct kiocb___323 *, struct iov_iter___139 *);
	int (*migratepage)(struct address_space___322 *, struct page___324 *, struct page___324 *, enum migrate_mode);
	bool (*isolate_page)(struct page___324 *, isolate_mode_t);
	void (*putback_page)(struct page___324 *);
	int (*launder_page)(struct page___324 *);
	int (*is_partially_uptodate)(struct page___324 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___324 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___322 *, struct page___324 *);
	int (*swap_activate)(struct swap_info_struct___78 *, struct file___323 *, sector_t *);
	void (*swap_deactivate)(struct file___323 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___135 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___152 *wb;
	struct inode___323 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___153;

struct iov_iter___139 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___153 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct swap_info_struct___78 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___322 *bdev;
	struct file___323 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___322 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___323 *bd_inode;
	struct super_block___322 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___322 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___152 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___71 {
	struct kobject___310 kobj;
	struct module___263 *owner;
	const struct file_operations___323 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___322 {
	struct dentry___322 * (*lookup)(struct inode___323 *, struct dentry___322 *, unsigned int);
	const char * (*get_link)(struct dentry___322 *, struct inode___323 *, struct delayed_call *);
	int (*permission)(struct inode___323 *, int);
	struct posix_acl * (*get_acl)(struct inode___323 *, int);
	int (*readlink)(struct dentry___322 *, char *, int);
	int (*create)(struct inode___323 *, struct dentry___322 *, umode_t, bool);
	int (*link)(struct dentry___322 *, struct inode___323 *, struct dentry___322 *);
	int (*unlink)(struct inode___323 *, struct dentry___322 *);
	int (*symlink)(struct inode___323 *, struct dentry___322 *, const char *);
	int (*mkdir)(struct inode___323 *, struct dentry___322 *, umode_t);
	int (*rmdir)(struct inode___323 *, struct dentry___322 *);
	int (*mknod)(struct inode___323 *, struct dentry___322 *, umode_t, dev_t);
	int (*rename)(struct inode___323 *, struct dentry___322 *, struct inode___323 *, struct dentry___322 *, unsigned int);
	int (*setattr)(struct dentry___322 *, struct iattr___322 *);
	int (*getattr)(const struct path___323 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___322 *, char *, size_t);
	int (*fiemap)(struct inode___323 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___323 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___323 *, struct dentry___322 *, struct file___323 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___323 *, struct dentry___322 *, umode_t);
	int (*set_acl)(struct inode___323 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___322 {
	void (*fl_copy_lock)(struct file_lock___323 *, struct file_lock___323 *);
	void (*fl_release_private)(struct file_lock___323 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___322;

struct file_lock___323 {
	struct file_lock___323 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___323 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___322 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___322 *fl_ops;
	const struct lock_manager_operations___322 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___322 {
	int (*lm_compare_owner)(struct file_lock___323 *, struct file_lock___323 *);
	long unsigned int (*lm_owner_key)(struct file_lock___323 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___323 *);
	int (*lm_grant)(struct file_lock___323 *, int);
	bool (*lm_break)(struct file_lock___323 *);
	int (*lm_change)(struct file_lock___323 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___323 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___322 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___322 *fa_next;
	struct file___323 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___322 {
	const char *name;
	int fs_flags;
	struct dentry___322 * (*mount)(struct file_system_type___322 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___322 *);
	struct module___263 *owner;
	struct file_system_type___322 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___322 {
	struct inode___323 * (*alloc_inode)(struct super_block___322 *);
	void (*destroy_inode)(struct inode___323 *);
	void (*dirty_inode)(struct inode___323 *, int);
	int (*write_inode)(struct inode___323 *, struct writeback_control___135 *);
	int (*drop_inode)(struct inode___323 *);
	void (*evict_inode)(struct inode___323 *);
	void (*put_super)(struct super_block___322 *);
	int (*sync_fs)(struct super_block___322 *, int);
	int (*freeze_super)(struct super_block___322 *);
	int (*freeze_fs)(struct super_block___322 *);
	int (*thaw_super)(struct super_block___322 *);
	int (*unfreeze_fs)(struct super_block___322 *);
	int (*statfs)(struct dentry___322 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___322 *, int *, char *);
	void (*umount_begin)(struct super_block___322 *);
	int (*show_options)(struct seq_file___274 *, struct dentry___322 *);
	int (*show_devname)(struct seq_file___274 *, struct dentry___322 *);
	int (*show_path)(struct seq_file___274 *, struct dentry___322 *);
	int (*show_stats)(struct seq_file___274 *, struct dentry___322 *);
	ssize_t (*quota_read)(struct super_block___322 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___322 *, int, const char *, size_t, loff_t);
	struct dquot___322 ** (*get_dquots)(struct inode___323 *);
	int (*bdev_try_to_free_page)(struct super_block___322 *, struct page___324 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___322 *, struct shrink_control___120 *);
	long int (*free_cached_objects)(struct super_block___322 *, struct shrink_control___120 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___202)(struct file___323 *, wait_queue_head_t *, struct poll_table_struct___197 *);

struct poll_table_struct___197 {
	poll_queue_proc___202 _qproc;
	__poll_t _key;
};

struct seq_operations___273;

struct seq_file___274 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___273 *op;
	int poll_event;
	const struct file___323 *file;
	void *private;
};

typedef void bio_end_io_t___152(struct bio___152 *);

struct bio_vec___153 {
	struct page___324 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___152;

struct bio_set___152;

struct bio___152 {
	struct bio___152 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___152 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___152 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___153 *bi_io_vec;
	struct bio_set___152 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___153 bi_inline_vecs[0];
};

struct kobj_attribute___301 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___310 *, struct kobj_attribute___301 *, char *);
	ssize_t (*store)(struct kobject___310 *, struct kobj_attribute___301 *, const char *, size_t);
};

typedef void compound_page_dtor___311(struct page___324 *);

struct kernfs_root___316;

struct kernfs_elem_dir___316 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___316 *root;
};

struct kernfs_syscall_ops___316;

struct kernfs_root___316 {
	struct kernfs_node___317 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___316 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___316 {
	struct kernfs_node___317 *target_kn;
};

struct kernfs_ops___316;

struct kernfs_elem_attr___316 {
	const struct kernfs_ops___316 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___317 *notify_next;
};

struct kernfs_node___317 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___317 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___316 dir;
		struct kernfs_elem_symlink___316 symlink;
		struct kernfs_elem_attr___316 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___316;

struct kernfs_ops___316 {
	int (*open)(struct kernfs_open_file___316 *);
	void (*release)(struct kernfs_open_file___316 *);
	int (*seq_show)(struct seq_file___274 *, void *);
	void * (*seq_start)(struct seq_file___274 *, loff_t *);
	void * (*seq_next)(struct seq_file___274 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___274 *, void *);
	ssize_t (*read)(struct kernfs_open_file___316 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___316 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___316 *, struct vm_area_struct___324 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___316 *, struct poll_table_struct___197 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___316 {
	int (*remount_fs)(struct kernfs_root___316 *, int *, char *);
	int (*show_options)(struct seq_file___274 *, struct kernfs_root___316 *);
	int (*mkdir)(struct kernfs_node___317 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___317 *);
	int (*rename)(struct kernfs_node___317 *, struct kernfs_node___317 *, const char *);
	int (*show_path)(struct seq_file___274 *, struct kernfs_node___317 *, struct kernfs_root___316 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___316 {
	struct kernfs_node___317 *kn;
	struct file___323 *file;
	struct seq_file___274 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___311 *vm_ops;
};

struct bin_attribute___286;

struct attribute_group___287 {
	const char *name;
	umode_t (*is_visible)(struct kobject___310 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___310 *, struct bin_attribute___286 *, int);
	struct attribute **attrs;
	struct bin_attribute___286 **bin_attrs;
};

struct bin_attribute___286 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___323 *, struct kobject___310 *, struct bin_attribute___286 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___323 *, struct kobject___310 *, struct bin_attribute___286 *, char *, loff_t, size_t);
	int (*mmap)(struct file___323 *, struct kobject___310 *, struct bin_attribute___286 *, struct vm_area_struct___324 *);
};

struct sysfs_ops___309 {
	ssize_t (*show)(struct kobject___310 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___310 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___309;

struct kset___309 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___310 kobj;
	const struct kset_uevent_ops___309 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___309 {
	void (*release)(struct kobject___310 *);
	const struct sysfs_ops___309 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___25 * (*child_ns_type)(struct kobject___310 *);
	const void * (*namespace)(struct kobject___310 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___309 {
	int (* const filter)(struct kset___309 *, struct kobject___310 *);
	const char * (* const name)(struct kset___309 *, struct kobject___310 *);
	int (* const uevent)(struct kset___309 *, struct kobject___310 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___289 {
	int (*prepare)(struct device___289 *);
	void (*complete)(struct device___289 *);
	int (*suspend)(struct device___289 *);
	int (*resume)(struct device___289 *);
	int (*freeze)(struct device___289 *);
	int (*thaw)(struct device___289 *);
	int (*poweroff)(struct device___289 *);
	int (*restore)(struct device___289 *);
	int (*suspend_late)(struct device___289 *);
	int (*resume_early)(struct device___289 *);
	int (*freeze_late)(struct device___289 *);
	int (*thaw_early)(struct device___289 *);
	int (*poweroff_late)(struct device___289 *);
	int (*restore_early)(struct device___289 *);
	int (*suspend_noirq)(struct device___289 *);
	int (*resume_noirq)(struct device___289 *);
	int (*freeze_noirq)(struct device___289 *);
	int (*thaw_noirq)(struct device___289 *);
	int (*poweroff_noirq)(struct device___289 *);
	int (*restore_noirq)(struct device___289 *);
	int (*runtime_suspend)(struct device___289 *);
	int (*runtime_resume)(struct device___289 *);
	int (*runtime_idle)(struct device___289 *);
};

struct dev_pm_domain___289 {
	struct dev_pm_ops___289 ops;
	void (*detach)(struct device___289 *, bool);
	int (*activate)(struct device___289 *);
	void (*sync)(struct device___289 *);
	void (*dismiss)(struct device___289 *);
};

struct bus_type___289 {
	const char *name;
	const char *dev_name;
	struct device___289 *dev_root;
	const struct attribute_group___287 **bus_groups;
	const struct attribute_group___287 **dev_groups;
	const struct attribute_group___287 **drv_groups;
	int (*match)(struct device___289 *, struct device_driver___289 *);
	int (*uevent)(struct device___289 *, struct kobj_uevent_env *);
	int (*probe)(struct device___289 *);
	int (*remove)(struct device___289 *);
	void (*shutdown)(struct device___289 *);
	int (*online)(struct device___289 *);
	int (*offline)(struct device___289 *);
	int (*suspend)(struct device___289 *, pm_message_t);
	int (*resume)(struct device___289 *);
	int (*num_vf)(struct device___289 *);
	int (*dma_configure)(struct device___289 *);
	const struct dev_pm_ops___289 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___289 {
	const char *name;
	struct bus_type___289 *bus;
	struct module___263 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___289 *);
	int (*remove)(struct device___289 *);
	void (*shutdown)(struct device___289 *);
	int (*suspend)(struct device___289 *, pm_message_t);
	int (*resume)(struct device___289 *);
	const struct attribute_group___287 **groups;
	const struct dev_pm_ops___289 *pm;
	void (*coredump)(struct device___289 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___289 {
	const char *name;
	const struct attribute_group___287 **groups;
	int (*uevent)(struct device___289 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___289 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___289 *);
	const struct dev_pm_ops___289 *pm;
};

struct class___289 {
	const char *name;
	struct module___263 *owner;
	const struct attribute_group___287 **class_groups;
	const struct attribute_group___287 **dev_groups;
	struct kobject___310 *dev_kobj;
	int (*dev_uevent)(struct device___289 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___289 *, umode_t *);
	void (*class_release)(struct class___289 *);
	void (*dev_release)(struct device___289 *);
	int (*shutdown_pre)(struct device___289 *);
	const struct kobj_ns_type_operations___25 *ns_type;
	const void * (*namespace)(struct device___289 *);
	const struct dev_pm_ops___289 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct fwnode_operations___218;

struct fwnode_handle___218 {
	struct fwnode_handle___218 *secondary;
	const struct fwnode_operations___218 *ops;
};

struct property___68;

struct device_node___72 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___218 fwnode;
	struct property___68 *properties;
	struct property___68 *deadprops;
	struct device_node___72 *parent;
	struct device_node___72 *child;
	struct device_node___72 *sibling;
	struct kobject___310 kobj;
	long unsigned int _flags;
	void *data;
};

struct seq_operations___273 {
	void * (*start)(struct seq_file___274 *, loff_t *);
	void (*stop)(struct seq_file___274 *, void *);
	void * (*next)(struct seq_file___274 *, void *, loff_t *);
	int (*show)(struct seq_file___274 *, void *);
};

struct tty_operations___29 {
	struct tty_struct___29 * (*lookup)(struct tty_driver___29 *, struct file___323 *, int);
	int (*install)(struct tty_driver___29 *, struct tty_struct___29 *);
	void (*remove)(struct tty_driver___29 *, struct tty_struct___29 *);
	int (*open)(struct tty_struct___29 *, struct file___323 *);
	void (*close)(struct tty_struct___29 *, struct file___323 *);
	void (*shutdown)(struct tty_struct___29 *);
	void (*cleanup)(struct tty_struct___29 *);
	int (*write)(struct tty_struct___29 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___29 *, unsigned char);
	void (*flush_chars)(struct tty_struct___29 *);
	int (*write_room)(struct tty_struct___29 *);
	int (*chars_in_buffer)(struct tty_struct___29 *);
	int (*ioctl)(struct tty_struct___29 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___29 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___29 *, struct ktermios *);
	void (*throttle)(struct tty_struct___29 *);
	void (*unthrottle)(struct tty_struct___29 *);
	void (*stop)(struct tty_struct___29 *);
	void (*start)(struct tty_struct___29 *);
	void (*hangup)(struct tty_struct___29 *);
	int (*break_ctl)(struct tty_struct___29 *, int);
	void (*flush_buffer)(struct tty_struct___29 *);
	void (*set_ldisc)(struct tty_struct___29 *);
	void (*wait_until_sent)(struct tty_struct___29 *, int);
	void (*send_xchar)(struct tty_struct___29 *, char);
	int (*tiocmget)(struct tty_struct___29 *);
	int (*tiocmset)(struct tty_struct___29 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___29 *, struct winsize *);
	int (*set_termiox)(struct tty_struct___29 *, struct termiox *);
	int (*get_icount)(struct tty_struct___29 *, struct serial_icounter_struct *);
	void (*show_fdinfo)(struct tty_struct___29 *, struct seq_file___274 *);
	int (*poll_init)(struct tty_driver___29 *, int, char *);
	int (*poll_get_char)(struct tty_driver___29 *, int);
	void (*poll_put_char)(struct tty_driver___29 *, int, char);
	int (*proc_show)(struct seq_file___274 *, void *);
};

struct tty_driver___29 {
	int magic;
	struct kref kref;
	struct cdev___71 **cdevs;
	struct module___263 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___29 *other;
	struct tty_struct___29 **ttys;
	struct tty_port___29 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___29 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___29;

struct tty_port_client_operations___29;

struct tty_port___29 {
	struct tty_bufhead buf;
	struct tty_struct___29 *tty;
	struct tty_struct___29 *itty;
	const struct tty_port_operations___29 *ops;
	const struct tty_port_client_operations___29 *client_ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	unsigned char low_latency: 1;
	struct mutex mutex;
	struct mutex buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
	void *client_data;
};

struct tty_ldisc_ops___29 {
	int magic;
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___29 *);
	void (*close)(struct tty_struct___29 *);
	void (*flush_buffer)(struct tty_struct___29 *);
	ssize_t (*read)(struct tty_struct___29 *, struct file___323 *, unsigned char *, size_t);
	ssize_t (*write)(struct tty_struct___29 *, struct file___323 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___29 *, struct file___323 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___29 *, struct file___323 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___29 *, struct ktermios *);
	__poll_t (*poll)(struct tty_struct___29 *, struct file___323 *, struct poll_table_struct___197 *);
	int (*hangup)(struct tty_struct___29 *);
	void (*receive_buf)(struct tty_struct___29 *, const unsigned char *, char *, int);
	void (*write_wakeup)(struct tty_struct___29 *);
	void (*dcd_change)(struct tty_struct___29 *, unsigned int);
	int (*receive_buf2)(struct tty_struct___29 *, const unsigned char *, char *, int);
	struct module___263 *owner;
	int refcount;
};

struct tty_ldisc___29 {
	struct tty_ldisc_ops___29 *ops;
	struct tty_struct___29 *tty;
};

struct tty_port_operations___29 {
	int (*carrier_raised)(struct tty_port___29 *);
	void (*dtr_rts)(struct tty_port___29 *, int);
	void (*shutdown)(struct tty_port___29 *);
	int (*activate)(struct tty_port___29 *, struct tty_struct___29 *);
	void (*destruct)(struct tty_port___29 *);
};

struct tty_port_client_operations___29 {
	int (*receive_buf)(struct tty_port___29 *, const unsigned char *, const unsigned char *, size_t);
	void (*write_wakeup)(struct tty_port___29 *);
};

struct vc_data___5 {
	struct tty_port___29 port;
	short unsigned int vc_num;
	unsigned int vc_cols;
	unsigned int vc_rows;
	unsigned int vc_size_row;
	unsigned int vc_scan_lines;
	long unsigned int vc_origin;
	long unsigned int vc_scr_end;
	long unsigned int vc_visible_origin;
	unsigned int vc_top;
	unsigned int vc_bottom;
	const struct consw___14 *vc_sw;
	short unsigned int *vc_screenbuf;
	unsigned int vc_screenbuf_size;
	unsigned char vc_mode;
	unsigned char vc_attr;
	unsigned char vc_def_color;
	unsigned char vc_color;
	unsigned char vc_s_color;
	unsigned char vc_ulcolor;
	unsigned char vc_itcolor;
	unsigned char vc_halfcolor;
	unsigned int vc_cursor_type;
	short unsigned int vc_complement_mask;
	short unsigned int vc_s_complement_mask;
	unsigned int vc_x;
	unsigned int vc_y;
	unsigned int vc_saved_x;
	unsigned int vc_saved_y;
	long unsigned int vc_pos;
	short unsigned int vc_hi_font_mask;
	struct console_font vc_font;
	short unsigned int vc_video_erase_char;
	unsigned int vc_state;
	unsigned int vc_npar;
	unsigned int vc_par[16];
	struct vt_mode vt_mode;
	struct pid___207 *vt_pid;
	int vt_newvt;
	wait_queue_head_t paste_wait;
	unsigned int vc_charset: 1;
	unsigned int vc_s_charset: 1;
	unsigned int vc_disp_ctrl: 1;
	unsigned int vc_toggle_meta: 1;
	unsigned int vc_decscnm: 1;
	unsigned int vc_decom: 1;
	unsigned int vc_decawm: 1;
	unsigned int vc_deccm: 1;
	unsigned int vc_decim: 1;
	unsigned int vc_intensity: 2;
	unsigned int vc_italic: 1;
	unsigned int vc_underline: 1;
	unsigned int vc_blink: 1;
	unsigned int vc_reverse: 1;
	unsigned int vc_s_intensity: 2;
	unsigned int vc_s_italic: 1;
	unsigned int vc_s_underline: 1;
	unsigned int vc_s_blink: 1;
	unsigned int vc_s_reverse: 1;
	unsigned int vc_ques: 1;
	unsigned int vc_need_wrap: 1;
	unsigned int vc_can_do_color: 1;
	unsigned int vc_report_mouse: 2;
	unsigned char vc_utf: 1;
	unsigned char vc_utf_count;
	int vc_utf_char;
	unsigned int vc_tab_stop[8];
	unsigned char vc_palette[48];
	short unsigned int *vc_translate;
	unsigned char vc_G0_charset;
	unsigned char vc_G1_charset;
	unsigned char vc_saved_G0;
	unsigned char vc_saved_G1;
	unsigned int vc_resize_user;
	unsigned int vc_bell_pitch;
	unsigned int vc_bell_duration;
	short unsigned int vc_cur_blink_ms;
	struct vc_data___5 **vc_display_fg;
	struct uni_pagedir *vc_uni_pagedir;
	struct uni_pagedir **vc_uni_pagedir_loc;
};

struct cgroup_namespace___212 {
	refcount_t count;
	struct ns_common___9 ns;
	struct user_namespace___227 *user_ns;
	struct ucounts___227 *ucounts;
	struct css_set___212 *root_cset;
};

struct ucounts___227 {
	struct hlist_node node;
	struct user_namespace___227 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct kernel_param_ops___260 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___260 *);
	int (*get)(char *, const struct kernel_param___260 *);
	void (*free)(void *);
};

struct kparam_array___260;

struct kernel_param___260 {
	const char *name;
	struct module___263 *mod;
	const struct kernel_param_ops___260 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___260 *arr;
	};
};

struct kparam_array___260 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___260 *ops;
	void *elem;
};

struct module_attribute___260 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___260 *, struct module_kobject___260 *, char *);
	ssize_t (*store)(struct module_attribute___260 *, struct module_kobject___260 *, const char *, size_t);
	void (*setup)(struct module___263 *, const char *);
	int (*test)(struct module___263 *);
	void (*free)(struct module___263 *);
};

struct trace_event_class___126;

struct trace_event_call___126 {
	struct list_head list;
	struct trace_event_class___126 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___13 event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___35 *prog_array;
	int (*perf_perm)(struct trace_event_call___126 *, struct perf_event___133 *);
};

struct node___188 {
	struct device___289 dev;
};

struct bpf_map___213;

struct bpf_map_ops___212 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___213 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___213 *, struct file___323 *);
	void (*map_free)(struct bpf_map___213 *);
	int (*map_get_next_key)(struct bpf_map___213 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___213 *);
	void * (*map_lookup_elem)(struct bpf_map___213 *, void *);
	int (*map_update_elem)(struct bpf_map___213 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___213 *, void *);
	int (*map_push_elem)(struct bpf_map___213 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___213 *, void *);
	int (*map_peek_elem)(struct bpf_map___213 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___213 *, struct file___323 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___213 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___213 *, void *, struct seq_file___274 *);
	int (*map_check_btf)(const struct bpf_map___213 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___213 {
	const struct bpf_map_ops___212 *ops;
	struct bpf_map___213 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___300 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___212;

typedef void (*kthread_work_func_t___212)(struct kthread_work___212 *);

struct kthread_worker___212;

struct kthread_work___212 {
	struct list_head node;
	kthread_work_func_t___212 func;
	struct kthread_worker___212 *worker;
	int canceling;
};

struct kthread_worker___212 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___324 *task;
	struct kthread_work___212 *current_work;
};

struct kthread_delayed_work___212 {
	struct kthread_work___212 work;
	struct timer_list timer;
};

struct psi_group___212 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___212 *poll_kworker;
	struct kthread_delayed_work___212 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___212;

struct cgroup_rstat_cpu___212;

struct cgroup___212 {
	struct cgroup_subsys_state___212 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___317 *kn;
	struct cgroup_file___212 procs_file;
	struct cgroup_file___212 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___212 *subsys[13];
	struct cgroup_root___212 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___212 *dom_cgrp;
	struct cgroup_rstat_cpu___212 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___35 bpf;
	atomic_t congestion_count;
	struct cgroup___212 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___212 psi;
	int ancestor_ids[0];
};

struct cftype___212;

struct cgroup_subsys___212 {
	struct cgroup_subsys_state___212 * (*css_alloc)(struct cgroup_subsys_state___212 *);
	int (*css_online)(struct cgroup_subsys_state___212 *);
	void (*css_offline)(struct cgroup_subsys_state___212 *);
	void (*css_released)(struct cgroup_subsys_state___212 *);
	void (*css_free)(struct cgroup_subsys_state___212 *);
	void (*css_reset)(struct cgroup_subsys_state___212 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___212 *, int);
	int (*css_extra_stat_show)(struct seq_file___274 *, struct cgroup_subsys_state___212 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___324 *);
	void (*cancel_fork)(struct task_struct___324 *);
	void (*fork)(struct task_struct___324 *);
	void (*exit)(struct task_struct___324 *);
	void (*free)(struct task_struct___324 *);
	void (*bind)(struct cgroup_subsys_state___212 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___212 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___212 *dfl_cftypes;
	struct cftype___212 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___212 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___212 *updated_children;
	struct cgroup___212 *updated_next;
};

struct cgroup_root___212 {
	struct kernfs_root___316 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___212 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___212 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___212 *ss;
	struct list_head node;
	struct kernfs_ops___316 *kf_ops;
	int (*open)(struct kernfs_open_file___316 *);
	void (*release)(struct kernfs_open_file___316 *);
	u64 (*read_u64)(struct cgroup_subsys_state___212 *, struct cftype___212 *);
	s64 (*read_s64)(struct cgroup_subsys_state___212 *, struct cftype___212 *);
	int (*seq_show)(struct seq_file___274 *, void *);
	void * (*seq_start)(struct seq_file___274 *, loff_t *);
	void * (*seq_next)(struct seq_file___274 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___274 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___212 *, struct cftype___212 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___212 *, struct cftype___212 *, s64);
	ssize_t (*write)(struct kernfs_open_file___316 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___316 *, struct poll_table_struct___197 *);
};

struct perf_cpu_context___133;

struct pmu___133 {
	struct list_head entry;
	struct module___263 *module;
	struct device___289 *dev;
	const struct attribute_group___287 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___133 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___133 *);
	void (*pmu_disable)(struct pmu___133 *);
	int (*event_init)(struct perf_event___133 *);
	void (*event_mapped)(struct perf_event___133 *, struct mm_struct___323 *);
	void (*event_unmapped)(struct perf_event___133 *, struct mm_struct___323 *);
	int (*add)(struct perf_event___133 *, int);
	void (*del)(struct perf_event___133 *, int);
	void (*start)(struct perf_event___133 *, int);
	void (*stop)(struct perf_event___133 *, int);
	void (*read)(struct perf_event___133 *);
	void (*start_txn)(struct pmu___133 *, unsigned int);
	int (*commit_txn)(struct pmu___133 *);
	void (*cancel_txn)(struct pmu___133 *);
	int (*event_idx)(struct perf_event___133 *);
	void (*sched_task)(struct perf_event_context___133 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___133 *);
	int (*filter_match)(struct perf_event___133 *);
	int (*check_period)(struct perf_event___133 *, u64);
};

struct perf_cpu_context___133 {
	struct perf_event_context___133 ctx;
	struct perf_event_context___133 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___133 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___133 {
	struct cgroup_subsys_state___212 css;
	struct perf_cgroup_info *info;
};

struct bdi_writeback_congested___152 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___152 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___152 {
	struct bio___152 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___153 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___153 bip_inline_vecs[0];
};

struct bio_set___152 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___152 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___120 {
	struct mem_cgroup___120 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___120 {
	struct lruvec___323 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___120 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___120 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct vc___4 {
	struct vc_data___5 *d;
	struct work_struct SAK_work;
};

struct vt_spawn_console___3 {
	spinlock_t lock;
	struct pid___207 *pid;
	int sig;
};

struct oom_control___4 {
	struct zonelist___323 *zonelist;
	nodemask_t *nodemask;
	struct mem_cgroup___120 *memcg;
	const gfp_t gfp_mask;
	const int order;
	long unsigned int totalpages;
	struct task_struct___324 *chosen;
	long unsigned int chosen_points;
};

struct ff_device___2;

struct input_handle___2;

struct input_dev___2 {
	const char *name;
	const char *phys;
	const char *uniq;
	struct input_id id;
	long unsigned int propbit[1];
	long unsigned int evbit[1];
	long unsigned int keybit[12];
	long unsigned int relbit[1];
	long unsigned int absbit[1];
	long unsigned int mscbit[1];
	long unsigned int ledbit[1];
	long unsigned int sndbit[1];
	long unsigned int ffbit[2];
	long unsigned int swbit[1];
	unsigned int hint_events_per_packet;
	unsigned int keycodemax;
	unsigned int keycodesize;
	void *keycode;
	int (*setkeycode)(struct input_dev___2 *, const struct input_keymap_entry *, unsigned int *);
	int (*getkeycode)(struct input_dev___2 *, struct input_keymap_entry *);
	struct ff_device___2 *ff;
	unsigned int repeat_key;
	struct timer_list timer;
	int rep[2];
	struct input_mt *mt;
	struct input_absinfo *absinfo;
	long unsigned int key[12];
	long unsigned int led[1];
	long unsigned int snd[1];
	long unsigned int sw[1];
	int (*open)(struct input_dev___2 *);
	void (*close)(struct input_dev___2 *);
	int (*flush)(struct input_dev___2 *, struct file___323 *);
	int (*event)(struct input_dev___2 *, unsigned int, unsigned int, int);
	struct input_handle___2 *grab;
	spinlock_t event_lock;
	struct mutex mutex;
	unsigned int users;
	bool going_away;
	struct device___289 dev;
	struct list_head h_list;
	struct list_head node;
	unsigned int num_vals;
	unsigned int max_vals;
	struct input_value *vals;
	bool devres_managed;
};

struct ff_device___2 {
	int (*upload)(struct input_dev___2 *, struct ff_effect *, struct ff_effect *);
	int (*erase)(struct input_dev___2 *, int);
	int (*playback)(struct input_dev___2 *, int, int);
	void (*set_gain)(struct input_dev___2 *, u16);
	void (*set_autocenter)(struct input_dev___2 *, u16);
	void (*destroy)(struct ff_device___2 *);
	void *private;
	long unsigned int ffbit[2];
	struct mutex mutex;
	int max_effects;
	struct ff_effect *effects;
	struct file___323 *effect_owners[0];
};

struct input_handler___2;

struct input_handle___2 {
	void *private;
	int open;
	const char *name;
	struct input_dev___2 *dev;
	struct input_handler___2 *handler;
	struct list_head d_node;
	struct list_head h_node;
};

struct input_handler___2 {
	void *private;
	void (*event)(struct input_handle___2 *, unsigned int, unsigned int, int);
	void (*events)(struct input_handle___2 *, const struct input_value *, unsigned int);
	bool (*filter)(struct input_handle___2 *, unsigned int, unsigned int, int);
	bool (*match)(struct input_handler___2 *, struct input_dev___2 *);
	int (*connect)(struct input_handler___2 *, struct input_dev___2 *, const struct input_device_id *);
	void (*disconnect)(struct input_handle___2 *);
	void (*start)(struct input_handle___2 *);
	bool legacy_minors;
	int minor;
	const char *name;
	const struct input_device_id *id_table;
	struct list_head h_list;
	struct list_head node;
};

struct trace_event_class___126 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___126 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___126 *);
	struct list_head * (*get_fields)(struct trace_event_call___126 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___126 *);
};

struct fwnode_reference_args___218;

struct fwnode_endpoint___218;

struct fwnode_operations___218 {
	struct fwnode_handle___218 * (*get)(struct fwnode_handle___218 *);
	void (*put)(struct fwnode_handle___218 *);
	bool (*device_is_available)(const struct fwnode_handle___218 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___218 *, const struct device___289 *);
	bool (*property_present)(const struct fwnode_handle___218 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___218 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___218 *, const char *, const char **, size_t);
	struct fwnode_handle___218 * (*get_parent)(const struct fwnode_handle___218 *);
	struct fwnode_handle___218 * (*get_next_child_node)(const struct fwnode_handle___218 *, struct fwnode_handle___218 *);
	struct fwnode_handle___218 * (*get_named_child_node)(const struct fwnode_handle___218 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___218 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___218 *);
	struct fwnode_handle___218 * (*graph_get_next_endpoint)(const struct fwnode_handle___218 *, struct fwnode_handle___218 *);
	struct fwnode_handle___218 * (*graph_get_remote_endpoint)(const struct fwnode_handle___218 *);
	struct fwnode_handle___218 * (*graph_get_port_parent)(struct fwnode_handle___218 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___218 *, struct fwnode_endpoint___218 *);
};

struct fwnode_endpoint___218 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___218 *local_fwnode;
};

struct fwnode_reference_args___218 {
	struct fwnode_handle___218 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct property___68 {
	char *name;
	int length;
	void *value;
	struct property___68 *next;
	long unsigned int _flags;
	struct bin_attribute___286 attr;
};

struct sysrq_state {
	struct input_handle___2 handle;
	struct work_struct reinject_work;
	long unsigned int key_down[12];
	unsigned int alt;
	unsigned int alt_use;
	bool active;
	bool need_reinject;
	bool reinjecting;
	bool reset_canceled;
	bool reset_requested;
	long unsigned int reset_keybit[12];
	int reset_seq_len;
	int reset_seq_cnt;
	int reset_seq_version;
	struct timer_list keyreset_timer;
};

struct module___264;

struct file___324;

struct kiocb___324;

struct iov_iter___140;

struct vm_area_struct___325;

struct inode___324;

struct file_lock___324;

struct page___325;

struct seq_file___275;

struct file_operations___324 {
	struct module___264 *owner;
	loff_t (*llseek)(struct file___324 *, loff_t, int);
	ssize_t (*read)(struct file___324 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___324 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___324 *, struct iov_iter___140 *);
	ssize_t (*write_iter)(struct kiocb___324 *, struct iov_iter___140 *);
	int (*iopoll)(struct kiocb___324 *, bool);
	int (*iterate)(struct file___324 *, struct dir_context *);
	int (*iterate_shared)(struct file___324 *, struct dir_context *);
	__poll_t (*poll)(struct file___324 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___324 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___324 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___324 *, struct vm_area_struct___325 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___324 *, struct file___324 *);
	int (*flush)(struct file___324 *, fl_owner_t);
	int (*release)(struct inode___324 *, struct file___324 *);
	int (*fsync)(struct file___324 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___324 *, int);
	int (*lock)(struct file___324 *, int, struct file_lock___324 *);
	ssize_t (*sendpage)(struct file___324 *, struct page___325 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___324 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___324 *, int, struct file_lock___324 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___324 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___324 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___324 *, long int, struct file_lock___324 **, void **);
	long int (*fallocate)(struct file___324 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___275 *, struct file___324 *);
	ssize_t (*copy_file_range)(struct file___324 *, loff_t, struct file___324 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___324 *, loff_t, struct file___324 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___324 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___324 {
	u64 seqnum;
	struct vm_area_struct___325 *vmas[4];
};

struct page_frag___324 {
	struct page___325 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___324;

struct mem_cgroup___121;

struct cred___301;

struct nsproxy___257;

struct signal_struct___239;

struct bio_list___153;

struct backing_dev_info___153;

struct css_set___213;

struct vm_struct___235;

struct task_struct___325 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___325 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___324 *mm;
	struct mm_struct___324 *active_mm;
	struct vmacache___324 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___325 *real_parent;
	struct task_struct___325 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___325 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___121 *active_memcg;
	long int rh_reserved2;
	struct pid___207 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___207 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___207 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___301 *ptracer_cred;
	const struct cred___301 *real_cred;
	const struct cred___301 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___257 *nsproxy;
	struct signal_struct___239 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___325 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___153 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___153 *backing_dev_info;
	struct io_context___82 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___213 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___324 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___121 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___325 *oom_reaper_list;
	struct vm_struct___235 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___133 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct key___301;

struct user_struct___301 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___301 *uid_keyring;
	struct key___301 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct rw_semaphore___325 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___325 *owner;
};

struct ucounts___228;

struct user_namespace___228 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___228 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___9 ns;
	long unsigned int flags;
	struct key___301 *persistent_keyring_register;
	struct rw_semaphore___325 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___228 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct secondary_data___325 {
	void *stack;
	struct task_struct___325 *task;
	long int status;
};

typedef struct page___325 *pgtable_t___324;

struct address_space___323;

struct dev_pagemap___312;

struct page___325 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___323 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___325 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___324 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___324 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___312 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___121 *mem_cgroup;
};

struct vm_operations_struct___312;

struct vm_area_struct___325 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___325 *vm_next;
	struct vm_area_struct___325 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___324 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___312 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___324 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___324;

struct mm_struct___324 {
	struct {
		struct vm_area_struct___325 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___324 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___325 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___324 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___325 *owner;
		struct user_namespace___228 *user_ns;
		struct file___324 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___324 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup___213;

struct cgroup_subsys___213;

struct cgroup_subsys_state___213 {
	struct cgroup___213 *cgroup;
	struct cgroup_subsys___213 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___213 *parent;
};

struct kernfs_node___318;

struct cgroup_file___213 {
	struct kernfs_node___318 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___121;

struct mem_cgroup___121 {
	struct cgroup_subsys_state___213 css;
	struct mem_cgroup_id___5 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___213 events_file;
	struct cgroup_file___213 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___325 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___121 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cred___301 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___301 *session_keyring;
	struct key___301 *process_keyring;
	struct key___301 *thread_keyring;
	struct key___301 *request_key_auth;
	void *security;
	struct user_struct___301 *user;
	struct user_namespace___228 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___213;

struct nsproxy___257 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___213 *cgroup_ns;
};

struct tty_struct___30;

struct signal_struct___239 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___325 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___325 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___207 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___207 *tty_old_pgrp;
	int leader;
	struct tty_struct___30 *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___324 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___207 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___153;

struct bio_list___153 {
	struct bio___153 *head;
	struct bio___153 *tail;
};

struct bdi_writeback_congested___153;

struct bdi_writeback___153 {
	struct backing_dev_info___153 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___153 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___213 *memcg_css;
	struct cgroup_subsys_state___213 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___290;

struct dentry___323;

struct backing_dev_info___153 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___153 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___290 *dev;
	struct device___290 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___323 *debug_dir;
	struct dentry___323 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___213 {
	struct cgroup_subsys_state___213 *subsys[13];
	refcount_t refcount;
	struct css_set___213 *dom_cset;
	struct cgroup___213 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___213 *mg_src_cgrp;
	struct cgroup___213 *mg_dst_cgrp;
	struct css_set___213 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct vm_struct___235 {
	struct vm_struct___235 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___325 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___251 {
	struct task_struct___325 task;
	long unsigned int stack[8192];
};

typedef int (*key_restrict_link_func_t___302)(struct key___301 *, const struct key_type *, const union key_payload *, struct key___301 *);

struct key_restriction___301;

struct key___301 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___325 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___301 *restrict_link;
};

struct key_restriction___301 {
	key_restrict_link_func_t___302 check;
	struct key___301 *key;
	struct key_type *keytype;
};

struct tty_driver___30;

struct tty_operations___30;

struct tty_ldisc___30;

struct fasync_struct___323;

struct tty_port___30;

struct tty_struct___30 {
	int magic;
	struct kref kref;
	struct device___290 *dev;
	struct tty_driver___30 *driver;
	const struct tty_operations___30 *ops;
	int index;
	struct ld_semaphore ldisc_sem;
	struct tty_ldisc___30 *ldisc;
	struct mutex atomic_write_lock;
	struct mutex legacy_mutex;
	struct mutex throttle_mutex;
	struct rw_semaphore___325 termios_rwsem;
	struct mutex winsize_mutex;
	spinlock_t ctrl_lock;
	spinlock_t flow_lock;
	struct ktermios termios;
	struct ktermios termios_locked;
	struct termiox *termiox;
	char name[64];
	struct pid___207 *pgrp;
	struct pid___207 *session;
	long unsigned int flags;
	int count;
	struct winsize winsize;
	long unsigned int stopped: 1;
	long unsigned int flow_stopped: 1;
	int: 30;
	long unsigned int unused: 62;
	int hw_stopped;
	long unsigned int ctrl_status: 8;
	long unsigned int packet: 1;
	int: 23;
	long unsigned int unused_ctrl: 55;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___30 *link;
	struct fasync_struct___323 *fasync;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	spinlock_t files_lock;
	struct list_head tty_files;
	int closing;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___30 *port;
};

struct dentry_operations___323;

struct super_block___323;

struct dentry___323 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___323 *d_parent;
	struct qstr d_name;
	struct inode___324 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___323 *d_op;
	struct super_block___323 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___323;

struct address_space___323 {
	struct inode___324 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___325 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___323 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___323;

struct block_device___323;

struct cdev___72;

struct inode___324 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___323 *i_op;
	struct super_block___323 *i_sb;
	struct address_space___323 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___325 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___153 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___324 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___323 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___323 *i_bdev;
		struct cdev___72 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___324;

struct dentry_operations___323 {
	int (*d_revalidate)(struct dentry___323 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___323 *, unsigned int);
	int (*d_hash)(const struct dentry___323 *, struct qstr *);
	int (*d_compare)(const struct dentry___323 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___323 *);
	int (*d_init)(struct dentry___323 *);
	void (*d_release)(struct dentry___323 *);
	void (*d_prune)(struct dentry___323 *);
	void (*d_iput)(struct dentry___323 *, struct inode___324 *);
	char * (*d_dname)(struct dentry___323 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___324 *);
	int (*d_manage)(const struct path___324 *, bool);
	struct dentry___323 * (*d_real)(struct dentry___323 *, const struct inode___324 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___323;

struct mem_dqinfo___323 {
	struct quota_format_type___323 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___323;

struct quota_info___323 {
	unsigned int flags;
	struct rw_semaphore___325 dqio_sem;
	struct inode___324 *files[3];
	struct mem_dqinfo___323 info[3];
	const struct quota_format_ops___323 *ops[3];
};

struct rcuwait___323 {
	struct task_struct___325 *task;
};

struct percpu_rw_semaphore___323 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___325 rw_sem;
	struct rcuwait___323 writer;
	int readers_block;
};

struct sb_writers___323 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___323 rw_sem[3];
};

struct shrink_control___121;

struct shrinker___121 {
	long unsigned int (*count_objects)(struct shrinker___121 *, struct shrink_control___121 *);
	long unsigned int (*scan_objects)(struct shrinker___121 *, struct shrink_control___121 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___323;

struct super_operations___323;

struct dquot_operations___323;

struct quotactl_ops___323;

struct super_block___323 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___323 *s_type;
	const struct super_operations___323 *s_op;
	const struct dquot_operations___323 *dq_op;
	const struct quotactl_ops___323 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___323 *s_root;
	struct rw_semaphore___325 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___323 *s_bdev;
	struct backing_dev_info___153 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___323 s_dquot;
	struct sb_writers___323 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___323 *s_d_op;
	int cleancache_poolid;
	struct shrinker___121 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___228 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct path___324 {
	struct vfsmount *mnt;
	struct dentry___323 *dentry;
};

struct shrink_control___121 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___121 *memcg;
};

struct pglist_data___324;

struct lruvec___324 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___324 *pgdat;
};

struct zone___324 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___324 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___324 {
	struct zone___324 *zone;
	int zone_idx;
};

struct zonelist___324 {
	struct zoneref___324 _zonerefs[25];
};

struct pglist_data___324 {
	struct zone___324 node_zones[3];
	struct zonelist___324 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___325 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___325 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___324 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___324 {
	struct rw_semaphore___325 rwsem;
	struct notifier_block *head;
};

typedef int (*dev_page_fault_t___312)(struct vm_area_struct___325 *, long unsigned int, const struct page___325 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___312)(struct page___325 *, void *);

struct dev_pagemap___312 {
	dev_page_fault_t___312 page_fault;
	dev_page_free_t___312 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___290 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct file___324 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___324 f_path;
	struct inode___324 *f_inode;
	const struct file_operations___324 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___207 f_owner;
	const struct cred___301 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___323 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___312;

struct vm_operations_struct___312 {
	void (*open)(struct vm_area_struct___325 *);
	void (*close)(struct vm_area_struct___325 *);
	int (*split)(struct vm_area_struct___325 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___325 *);
	vm_fault_t (*fault)(struct vm_fault___312 *);
	vm_fault_t (*huge_fault)(struct vm_fault___312 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___312 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___325 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___312 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___312 *);
	int (*access)(struct vm_area_struct___325 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___325 *);
	int (*set_policy)(struct vm_area_struct___325 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___325 *, long unsigned int);
	struct page___325 * (*find_special_page)(struct vm_area_struct___325 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___324 {
	struct task_struct___325 *task;
	struct core_thread___324 *next;
};

struct core_state___324 {
	atomic_t nr_threads;
	struct core_thread___324 dumper;
	struct completion startup;
};

struct vm_fault___312 {
	struct vm_area_struct___325 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___325 *cow_page;
	struct mem_cgroup___121 *memcg;
	struct page___325 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___324 prealloc_pte;
};

struct kiocb___324 {
	struct file___324 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___324 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___323 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___324 *ia_file;
};

struct dquot___323 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___323 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___323 {
	int qf_fmt_id;
	const struct quota_format_ops___323 *qf_ops;
	struct module___264 *qf_owner;
	struct quota_format_type___323 *qf_next;
};

struct quota_format_ops___323 {
	int (*check_quota_file)(struct super_block___323 *, int);
	int (*read_file_info)(struct super_block___323 *, int);
	int (*write_file_info)(struct super_block___323 *, int);
	int (*free_file_info)(struct super_block___323 *, int);
	int (*read_dqblk)(struct dquot___323 *);
	int (*commit_dqblk)(struct dquot___323 *);
	int (*release_dqblk)(struct dquot___323 *);
	int (*get_next_id)(struct super_block___323 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___323 {
	int (*write_dquot)(struct dquot___323 *);
	struct dquot___323 * (*alloc_dquot)(struct super_block___323 *, int);
	void (*destroy_dquot)(struct dquot___323 *);
	int (*acquire_dquot)(struct dquot___323 *);
	int (*release_dquot)(struct dquot___323 *);
	int (*mark_dirty)(struct dquot___323 *);
	int (*write_info)(struct super_block___323 *, int);
	qsize_t * (*get_reserved_space)(struct inode___324 *);
	int (*get_projid)(struct inode___324 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___324 *, qsize_t *);
	int (*get_next_id)(struct super_block___323 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___323 {
	int (*quota_on)(struct super_block___323 *, int, int, const struct path___324 *);
	int (*quota_off)(struct super_block___323 *, int);
	int (*quota_enable)(struct super_block___323 *, unsigned int);
	int (*quota_disable)(struct super_block___323 *, unsigned int);
	int (*quota_sync)(struct super_block___323 *, int);
	int (*set_info)(struct super_block___323 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___323 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___323 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___323 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___323 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___323 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___310;

struct kobj_type___310;

struct kobject___311 {
	const char *name;
	struct list_head entry;
	struct kobject___311 *parent;
	struct kset___310 *kset;
	struct kobj_type___310 *ktype;
	struct kernfs_node___318 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___261 {
	struct kobject___311 kobj;
	struct module___264 *mod;
	struct kobject___311 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___261 {
	struct module___264 *mod;
	struct latch_tree_node node;
};

struct module_layout___261 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___261 mtn;
};

struct module_attribute___261;

struct kernel_param___261;

struct module___264 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___261 mkobj;
	struct module_attribute___261 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___311 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___261 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___261 core_layout;
	struct module_layout___261 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___136;

struct swap_info_struct___79;

struct address_space_operations___323 {
	int (*writepage)(struct page___325 *, struct writeback_control___136 *);
	int (*readpage)(struct file___324 *, struct page___325 *);
	int (*writepages)(struct address_space___323 *, struct writeback_control___136 *);
	int (*set_page_dirty)(struct page___325 *);
	int (*readpages)(struct file___324 *, struct address_space___323 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___324 *, struct address_space___323 *, loff_t, unsigned int, unsigned int, struct page___325 **, void **);
	int (*write_end)(struct file___324 *, struct address_space___323 *, loff_t, unsigned int, unsigned int, struct page___325 *, void *);
	sector_t (*bmap)(struct address_space___323 *, sector_t);
	void (*invalidatepage)(struct page___325 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___325 *, gfp_t);
	void (*freepage)(struct page___325 *);
	ssize_t (*direct_IO)(struct kiocb___324 *, struct iov_iter___140 *);
	int (*migratepage)(struct address_space___323 *, struct page___325 *, struct page___325 *, enum migrate_mode);
	bool (*isolate_page)(struct page___325 *, isolate_mode_t);
	void (*putback_page)(struct page___325 *);
	int (*launder_page)(struct page___325 *);
	int (*is_partially_uptodate)(struct page___325 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___325 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___323 *, struct page___325 *);
	int (*swap_activate)(struct swap_info_struct___79 *, struct file___324 *, sector_t *);
	void (*swap_deactivate)(struct file___324 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___136 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___153 *wb;
	struct inode___324 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___154;

struct iov_iter___140 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___154 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct swap_info_struct___79 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___323 *bdev;
	struct file___324 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___323 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___324 *bd_inode;
	struct super_block___323 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___323 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___153 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___72 {
	struct kobject___311 kobj;
	struct module___264 *owner;
	const struct file_operations___324 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___323 {
	struct dentry___323 * (*lookup)(struct inode___324 *, struct dentry___323 *, unsigned int);
	const char * (*get_link)(struct dentry___323 *, struct inode___324 *, struct delayed_call *);
	int (*permission)(struct inode___324 *, int);
	struct posix_acl * (*get_acl)(struct inode___324 *, int);
	int (*readlink)(struct dentry___323 *, char *, int);
	int (*create)(struct inode___324 *, struct dentry___323 *, umode_t, bool);
	int (*link)(struct dentry___323 *, struct inode___324 *, struct dentry___323 *);
	int (*unlink)(struct inode___324 *, struct dentry___323 *);
	int (*symlink)(struct inode___324 *, struct dentry___323 *, const char *);
	int (*mkdir)(struct inode___324 *, struct dentry___323 *, umode_t);
	int (*rmdir)(struct inode___324 *, struct dentry___323 *);
	int (*mknod)(struct inode___324 *, struct dentry___323 *, umode_t, dev_t);
	int (*rename)(struct inode___324 *, struct dentry___323 *, struct inode___324 *, struct dentry___323 *, unsigned int);
	int (*setattr)(struct dentry___323 *, struct iattr___323 *);
	int (*getattr)(const struct path___324 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___323 *, char *, size_t);
	int (*fiemap)(struct inode___324 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___324 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___324 *, struct dentry___323 *, struct file___324 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___324 *, struct dentry___323 *, umode_t);
	int (*set_acl)(struct inode___324 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___323 {
	void (*fl_copy_lock)(struct file_lock___324 *, struct file_lock___324 *);
	void (*fl_release_private)(struct file_lock___324 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___323;

struct file_lock___324 {
	struct file_lock___324 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___324 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___323 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___323 *fl_ops;
	const struct lock_manager_operations___323 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___323 {
	int (*lm_compare_owner)(struct file_lock___324 *, struct file_lock___324 *);
	long unsigned int (*lm_owner_key)(struct file_lock___324 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___324 *);
	int (*lm_grant)(struct file_lock___324 *, int);
	bool (*lm_break)(struct file_lock___324 *);
	int (*lm_change)(struct file_lock___324 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___324 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___323 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___323 *fa_next;
	struct file___324 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___323 {
	const char *name;
	int fs_flags;
	struct dentry___323 * (*mount)(struct file_system_type___323 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___323 *);
	struct module___264 *owner;
	struct file_system_type___323 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___323 {
	struct inode___324 * (*alloc_inode)(struct super_block___323 *);
	void (*destroy_inode)(struct inode___324 *);
	void (*dirty_inode)(struct inode___324 *, int);
	int (*write_inode)(struct inode___324 *, struct writeback_control___136 *);
	int (*drop_inode)(struct inode___324 *);
	void (*evict_inode)(struct inode___324 *);
	void (*put_super)(struct super_block___323 *);
	int (*sync_fs)(struct super_block___323 *, int);
	int (*freeze_super)(struct super_block___323 *);
	int (*freeze_fs)(struct super_block___323 *);
	int (*thaw_super)(struct super_block___323 *);
	int (*unfreeze_fs)(struct super_block___323 *);
	int (*statfs)(struct dentry___323 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___323 *, int *, char *);
	void (*umount_begin)(struct super_block___323 *);
	int (*show_options)(struct seq_file___275 *, struct dentry___323 *);
	int (*show_devname)(struct seq_file___275 *, struct dentry___323 *);
	int (*show_path)(struct seq_file___275 *, struct dentry___323 *);
	int (*show_stats)(struct seq_file___275 *, struct dentry___323 *);
	ssize_t (*quota_read)(struct super_block___323 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___323 *, int, const char *, size_t, loff_t);
	struct dquot___323 ** (*get_dquots)(struct inode___324 *);
	int (*bdev_try_to_free_page)(struct super_block___323 *, struct page___325 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___323 *, struct shrink_control___121 *);
	long int (*free_cached_objects)(struct super_block___323 *, struct shrink_control___121 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___274;

struct seq_file___275 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___274 *op;
	int poll_event;
	const struct file___324 *file;
	void *private;
};

typedef void bio_end_io_t___153(struct bio___153 *);

struct bio_vec___154 {
	struct page___325 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___153;

struct bio_set___153;

struct bio___153 {
	struct bio___153 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___153 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___153 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___154 *bi_io_vec;
	struct bio_set___153 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___154 bi_inline_vecs[0];
};

struct kernfs_root___317;

struct kernfs_elem_dir___317 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___317 *root;
};

struct kernfs_syscall_ops___317;

struct kernfs_root___317 {
	struct kernfs_node___318 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___317 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___317 {
	struct kernfs_node___318 *target_kn;
};

struct kernfs_ops___317;

struct kernfs_elem_attr___317 {
	const struct kernfs_ops___317 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___318 *notify_next;
};

struct kernfs_node___318 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___318 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___317 dir;
		struct kernfs_elem_symlink___317 symlink;
		struct kernfs_elem_attr___317 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___317;

struct kernfs_ops___317 {
	int (*open)(struct kernfs_open_file___317 *);
	void (*release)(struct kernfs_open_file___317 *);
	int (*seq_show)(struct seq_file___275 *, void *);
	void * (*seq_start)(struct seq_file___275 *, loff_t *);
	void * (*seq_next)(struct seq_file___275 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___275 *, void *);
	ssize_t (*read)(struct kernfs_open_file___317 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___317 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___317 *, struct vm_area_struct___325 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___317 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___317 {
	int (*remount_fs)(struct kernfs_root___317 *, int *, char *);
	int (*show_options)(struct seq_file___275 *, struct kernfs_root___317 *);
	int (*mkdir)(struct kernfs_node___318 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___318 *);
	int (*rename)(struct kernfs_node___318 *, struct kernfs_node___318 *, const char *);
	int (*show_path)(struct seq_file___275 *, struct kernfs_node___318 *, struct kernfs_root___317 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___317 {
	struct kernfs_node___318 *kn;
	struct file___324 *file;
	struct seq_file___275 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___312 *vm_ops;
};

struct bin_attribute___287;

struct attribute_group___288 {
	const char *name;
	umode_t (*is_visible)(struct kobject___311 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___311 *, struct bin_attribute___287 *, int);
	struct attribute **attrs;
	struct bin_attribute___287 **bin_attrs;
};

struct bin_attribute___287 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___324 *, struct kobject___311 *, struct bin_attribute___287 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___324 *, struct kobject___311 *, struct bin_attribute___287 *, char *, loff_t, size_t);
	int (*mmap)(struct file___324 *, struct kobject___311 *, struct bin_attribute___287 *, struct vm_area_struct___325 *);
};

struct sysfs_ops___310 {
	ssize_t (*show)(struct kobject___311 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___311 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___310;

struct kset___310 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___311 kobj;
	const struct kset_uevent_ops___310 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___310 {
	void (*release)(struct kobject___311 *);
	const struct sysfs_ops___310 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___25 * (*child_ns_type)(struct kobject___311 *);
	const void * (*namespace)(struct kobject___311 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___310 {
	int (* const filter)(struct kset___310 *, struct kobject___311 *);
	const char * (* const name)(struct kset___310 *, struct kobject___311 *);
	int (* const uevent)(struct kset___310 *, struct kobject___311 *, struct kobj_uevent_env *);
};

struct kobj_attribute___302 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___311 *, struct kobj_attribute___302 *, char *);
	ssize_t (*store)(struct kobject___311 *, struct kobj_attribute___302 *, const char *, size_t);
};

struct dev_pm_ops___290 {
	int (*prepare)(struct device___290 *);
	void (*complete)(struct device___290 *);
	int (*suspend)(struct device___290 *);
	int (*resume)(struct device___290 *);
	int (*freeze)(struct device___290 *);
	int (*thaw)(struct device___290 *);
	int (*poweroff)(struct device___290 *);
	int (*restore)(struct device___290 *);
	int (*suspend_late)(struct device___290 *);
	int (*resume_early)(struct device___290 *);
	int (*freeze_late)(struct device___290 *);
	int (*thaw_early)(struct device___290 *);
	int (*poweroff_late)(struct device___290 *);
	int (*restore_early)(struct device___290 *);
	int (*suspend_noirq)(struct device___290 *);
	int (*resume_noirq)(struct device___290 *);
	int (*freeze_noirq)(struct device___290 *);
	int (*thaw_noirq)(struct device___290 *);
	int (*poweroff_noirq)(struct device___290 *);
	int (*restore_noirq)(struct device___290 *);
	int (*runtime_suspend)(struct device___290 *);
	int (*runtime_resume)(struct device___290 *);
	int (*runtime_idle)(struct device___290 *);
};

struct dev_pm_info___290 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___3 *subsys_data;
	void (*set_latency_tolerance)(struct device___290 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___290;

struct bus_type___290;

struct device_driver___290;

struct dev_pm_domain___290;

struct fwnode_handle___219;

struct class___290;

struct device___290 {
	struct device___290 *parent;
	struct device_private *p;
	struct kobject___311 kobj;
	const char *init_name;
	const struct device_type___290 *type;
	struct mutex mutex;
	struct bus_type___290 *bus;
	struct device_driver___290 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___290 power;
	struct dev_pm_domain___290 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___219 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___290 *class;
	const struct attribute_group___288 **groups;
	void (*release)(struct device___290 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___290 {
	struct dev_pm_ops___290 ops;
	void (*detach)(struct device___290 *, bool);
	int (*activate)(struct device___290 *);
	void (*sync)(struct device___290 *);
	void (*dismiss)(struct device___290 *);
};

struct bus_type___290 {
	const char *name;
	const char *dev_name;
	struct device___290 *dev_root;
	const struct attribute_group___288 **bus_groups;
	const struct attribute_group___288 **dev_groups;
	const struct attribute_group___288 **drv_groups;
	int (*match)(struct device___290 *, struct device_driver___290 *);
	int (*uevent)(struct device___290 *, struct kobj_uevent_env *);
	int (*probe)(struct device___290 *);
	int (*remove)(struct device___290 *);
	void (*shutdown)(struct device___290 *);
	int (*online)(struct device___290 *);
	int (*offline)(struct device___290 *);
	int (*suspend)(struct device___290 *, pm_message_t);
	int (*resume)(struct device___290 *);
	int (*num_vf)(struct device___290 *);
	int (*dma_configure)(struct device___290 *);
	const struct dev_pm_ops___290 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___290 {
	const char *name;
	struct bus_type___290 *bus;
	struct module___264 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___290 *);
	int (*remove)(struct device___290 *);
	void (*shutdown)(struct device___290 *);
	int (*suspend)(struct device___290 *, pm_message_t);
	int (*resume)(struct device___290 *);
	const struct attribute_group___288 **groups;
	const struct dev_pm_ops___290 *pm;
	void (*coredump)(struct device___290 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___290 {
	const char *name;
	const struct attribute_group___288 **groups;
	int (*uevent)(struct device___290 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___290 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___290 *);
	const struct dev_pm_ops___290 *pm;
};

struct class___290 {
	const char *name;
	struct module___264 *owner;
	const struct attribute_group___288 **class_groups;
	const struct attribute_group___288 **dev_groups;
	struct kobject___311 *dev_kobj;
	int (*dev_uevent)(struct device___290 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___290 *, umode_t *);
	void (*class_release)(struct class___290 *);
	void (*dev_release)(struct device___290 *);
	int (*shutdown_pre)(struct device___290 *);
	const struct kobj_ns_type_operations___25 *ns_type;
	const void * (*namespace)(struct device___290 *);
	const struct dev_pm_ops___290 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct fwnode_operations___219;

struct fwnode_handle___219 {
	struct fwnode_handle___219 *secondary;
	const struct fwnode_operations___219 *ops;
};

struct seq_operations___274 {
	void * (*start)(struct seq_file___275 *, loff_t *);
	void (*stop)(struct seq_file___275 *, void *);
	void * (*next)(struct seq_file___275 *, void *, loff_t *);
	int (*show)(struct seq_file___275 *, void *);
};

struct tty_operations___30 {
	struct tty_struct___30 * (*lookup)(struct tty_driver___30 *, struct file___324 *, int);
	int (*install)(struct tty_driver___30 *, struct tty_struct___30 *);
	void (*remove)(struct tty_driver___30 *, struct tty_struct___30 *);
	int (*open)(struct tty_struct___30 *, struct file___324 *);
	void (*close)(struct tty_struct___30 *, struct file___324 *);
	void (*shutdown)(struct tty_struct___30 *);
	void (*cleanup)(struct tty_struct___30 *);
	int (*write)(struct tty_struct___30 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___30 *, unsigned char);
	void (*flush_chars)(struct tty_struct___30 *);
	int (*write_room)(struct tty_struct___30 *);
	int (*chars_in_buffer)(struct tty_struct___30 *);
	int (*ioctl)(struct tty_struct___30 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___30 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___30 *, struct ktermios *);
	void (*throttle)(struct tty_struct___30 *);
	void (*unthrottle)(struct tty_struct___30 *);
	void (*stop)(struct tty_struct___30 *);
	void (*start)(struct tty_struct___30 *);
	void (*hangup)(struct tty_struct___30 *);
	int (*break_ctl)(struct tty_struct___30 *, int);
	void (*flush_buffer)(struct tty_struct___30 *);
	void (*set_ldisc)(struct tty_struct___30 *);
	void (*wait_until_sent)(struct tty_struct___30 *, int);
	void (*send_xchar)(struct tty_struct___30 *, char);
	int (*tiocmget)(struct tty_struct___30 *);
	int (*tiocmset)(struct tty_struct___30 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___30 *, struct winsize *);
	int (*set_termiox)(struct tty_struct___30 *, struct termiox *);
	int (*get_icount)(struct tty_struct___30 *, struct serial_icounter_struct *);
	void (*show_fdinfo)(struct tty_struct___30 *, struct seq_file___275 *);
	int (*poll_init)(struct tty_driver___30 *, int, char *);
	int (*poll_get_char)(struct tty_driver___30 *, int);
	void (*poll_put_char)(struct tty_driver___30 *, int, char);
	int (*proc_show)(struct seq_file___275 *, void *);
};

struct tty_driver___30 {
	int magic;
	struct kref kref;
	struct cdev___72 **cdevs;
	struct module___264 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___30 *other;
	struct tty_struct___30 **ttys;
	struct tty_port___30 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___30 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___30;

struct tty_port_client_operations___30;

struct tty_port___30 {
	struct tty_bufhead buf;
	struct tty_struct___30 *tty;
	struct tty_struct___30 *itty;
	const struct tty_port_operations___30 *ops;
	const struct tty_port_client_operations___30 *client_ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	unsigned char low_latency: 1;
	struct mutex mutex;
	struct mutex buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
	void *client_data;
};

struct tty_ldisc_ops___30 {
	int magic;
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___30 *);
	void (*close)(struct tty_struct___30 *);
	void (*flush_buffer)(struct tty_struct___30 *);
	ssize_t (*read)(struct tty_struct___30 *, struct file___324 *, unsigned char *, size_t);
	ssize_t (*write)(struct tty_struct___30 *, struct file___324 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___30 *, struct file___324 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___30 *, struct file___324 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___30 *, struct ktermios *);
	__poll_t (*poll)(struct tty_struct___30 *, struct file___324 *, struct poll_table_struct___6 *);
	int (*hangup)(struct tty_struct___30 *);
	void (*receive_buf)(struct tty_struct___30 *, const unsigned char *, char *, int);
	void (*write_wakeup)(struct tty_struct___30 *);
	void (*dcd_change)(struct tty_struct___30 *, unsigned int);
	int (*receive_buf2)(struct tty_struct___30 *, const unsigned char *, char *, int);
	struct module___264 *owner;
	int refcount;
};

struct tty_ldisc___30 {
	struct tty_ldisc_ops___30 *ops;
	struct tty_struct___30 *tty;
};

struct tty_port_operations___30 {
	int (*carrier_raised)(struct tty_port___30 *);
	void (*dtr_rts)(struct tty_port___30 *, int);
	void (*shutdown)(struct tty_port___30 *);
	int (*activate)(struct tty_port___30 *, struct tty_struct___30 *);
	void (*destruct)(struct tty_port___30 *);
};

struct tty_port_client_operations___30 {
	int (*receive_buf)(struct tty_port___30 *, const unsigned char *, const unsigned char *, size_t);
	void (*write_wakeup)(struct tty_port___30 *);
};

struct kernel_param_ops___261 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___261 *);
	int (*get)(char *, const struct kernel_param___261 *);
	void (*free)(void *);
};

struct kparam_array___261;

struct kernel_param___261 {
	const char *name;
	struct module___264 *mod;
	const struct kernel_param_ops___261 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___261 *arr;
	};
};

struct kparam_array___261 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___261 *ops;
	void *elem;
};

struct module_attribute___261 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___261 *, struct module_kobject___261 *, char *);
	ssize_t (*store)(struct module_attribute___261 *, struct module_kobject___261 *, const char *, size_t);
	void (*setup)(struct module___264 *, const char *);
	int (*test)(struct module___264 *);
	void (*free)(struct module___264 *);
};

struct consolefontdesc {
	short unsigned int charcount;
	short unsigned int charheight;
	char *chardata;
};

struct unipair {
	short unsigned int unicode;
	short unsigned int fontpos;
};

struct unimapdesc {
	short unsigned int entry_ct;
	struct unipair *entries;
};

struct kbdiacruc {
	unsigned int diacr;
	unsigned int base;
	unsigned int result;
};

struct kbd_repeat {
	int delay;
	int period;
};

struct console_font_op {
	unsigned int op;
	unsigned int flags;
	unsigned int width;
	unsigned int height;
	unsigned int charcount;
	unsigned char *data;
};

struct vt_stat {
	short unsigned int v_active;
	short unsigned int v_signal;
	short unsigned int v_state;
};

struct vt_sizes {
	short unsigned int v_rows;
	short unsigned int v_cols;
	short unsigned int v_scrollsize;
};

struct vt_consize {
	short unsigned int v_rows;
	short unsigned int v_cols;
	short unsigned int v_vlin;
	short unsigned int v_clin;
	short unsigned int v_vcol;
	short unsigned int v_ccol;
};

struct vt_event {
	unsigned int event;
	unsigned int oldev;
	unsigned int newev;
	unsigned int pad[4];
};

struct vt_setactivate {
	unsigned int console;
	struct vt_mode mode;
};

struct vc_data___6;

struct consw___17 {
	struct module___264 *owner;
	const char * (*con_startup)();
	void (*con_init)(struct vc_data___6 *, int);
	void (*con_deinit)(struct vc_data___6 *);
	void (*con_clear)(struct vc_data___6 *, int, int, int, int);
	void (*con_putc)(struct vc_data___6 *, int, int, int);
	void (*con_putcs)(struct vc_data___6 *, const short unsigned int *, int, int, int);
	void (*con_cursor)(struct vc_data___6 *, int);
	bool (*con_scroll)(struct vc_data___6 *, unsigned int, unsigned int, enum con_scroll, unsigned int);
	int (*con_switch)(struct vc_data___6 *);
	int (*con_blank)(struct vc_data___6 *, int, int);
	int (*con_font_set)(struct vc_data___6 *, struct console_font *, unsigned int);
	int (*con_font_get)(struct vc_data___6 *, struct console_font *);
	int (*con_font_default)(struct vc_data___6 *, struct console_font *, char *);
	int (*con_font_copy)(struct vc_data___6 *, int);
	int (*con_resize)(struct vc_data___6 *, unsigned int, unsigned int, unsigned int);
	void (*con_set_palette)(struct vc_data___6 *, const unsigned char *);
	void (*con_scrolldelta)(struct vc_data___6 *, int);
	int (*con_set_origin)(struct vc_data___6 *);
	void (*con_save_screen)(struct vc_data___6 *);
	u8 (*con_build_attr)(struct vc_data___6 *, u8, u8, u8, u8, u8, u8);
	void (*con_invert_region)(struct vc_data___6 *, u16 *, int);
	u16 * (*con_screen_pos)(struct vc_data___6 *, int);
	long unsigned int (*con_getxy)(struct vc_data___6 *, long unsigned int, int *, int *);
	void (*con_flush_scrollback)(struct vc_data___6 *);
	int (*con_debug_enter)(struct vc_data___6 *);
	int (*con_debug_leave)(struct vc_data___6 *);
};

struct vc_data___6 {
	struct tty_port___30 port;
	short unsigned int vc_num;
	unsigned int vc_cols;
	unsigned int vc_rows;
	unsigned int vc_size_row;
	unsigned int vc_scan_lines;
	long unsigned int vc_origin;
	long unsigned int vc_scr_end;
	long unsigned int vc_visible_origin;
	unsigned int vc_top;
	unsigned int vc_bottom;
	const struct consw___17 *vc_sw;
	short unsigned int *vc_screenbuf;
	unsigned int vc_screenbuf_size;
	unsigned char vc_mode;
	unsigned char vc_attr;
	unsigned char vc_def_color;
	unsigned char vc_color;
	unsigned char vc_s_color;
	unsigned char vc_ulcolor;
	unsigned char vc_itcolor;
	unsigned char vc_halfcolor;
	unsigned int vc_cursor_type;
	short unsigned int vc_complement_mask;
	short unsigned int vc_s_complement_mask;
	unsigned int vc_x;
	unsigned int vc_y;
	unsigned int vc_saved_x;
	unsigned int vc_saved_y;
	long unsigned int vc_pos;
	short unsigned int vc_hi_font_mask;
	struct console_font vc_font;
	short unsigned int vc_video_erase_char;
	unsigned int vc_state;
	unsigned int vc_npar;
	unsigned int vc_par[16];
	struct vt_mode vt_mode;
	struct pid___207 *vt_pid;
	int vt_newvt;
	wait_queue_head_t paste_wait;
	unsigned int vc_charset: 1;
	unsigned int vc_s_charset: 1;
	unsigned int vc_disp_ctrl: 1;
	unsigned int vc_toggle_meta: 1;
	unsigned int vc_decscnm: 1;
	unsigned int vc_decom: 1;
	unsigned int vc_decawm: 1;
	unsigned int vc_deccm: 1;
	unsigned int vc_decim: 1;
	unsigned int vc_intensity: 2;
	unsigned int vc_italic: 1;
	unsigned int vc_underline: 1;
	unsigned int vc_blink: 1;
	unsigned int vc_reverse: 1;
	unsigned int vc_s_intensity: 2;
	unsigned int vc_s_italic: 1;
	unsigned int vc_s_underline: 1;
	unsigned int vc_s_blink: 1;
	unsigned int vc_s_reverse: 1;
	unsigned int vc_ques: 1;
	unsigned int vc_need_wrap: 1;
	unsigned int vc_can_do_color: 1;
	unsigned int vc_report_mouse: 2;
	unsigned char vc_utf: 1;
	unsigned char vc_utf_count;
	int vc_utf_char;
	unsigned int vc_tab_stop[8];
	unsigned char vc_palette[48];
	short unsigned int *vc_translate;
	unsigned char vc_G0_charset;
	unsigned char vc_G1_charset;
	unsigned char vc_saved_G0;
	unsigned char vc_saved_G1;
	unsigned int vc_resize_user;
	unsigned int vc_bell_pitch;
	unsigned int vc_bell_duration;
	short unsigned int vc_cur_blink_ms;
	struct vc_data___6 **vc_display_fg;
	struct uni_pagedir *vc_uni_pagedir;
	struct uni_pagedir **vc_uni_pagedir_loc;
};

struct console___7 {
	char name[16];
	void (*write)(struct console___7 *, const char *, unsigned int);
	int (*read)(struct console___7 *, char *, unsigned int);
	struct tty_driver___30 * (*device)(struct console___7 *, int *);
	void (*unblank)();
	int (*setup)(struct console___7 *, char *);
	int (*match)(struct console___7 *, char *, int, char *);
	short int flags;
	short int index;
	int cflag;
	void *data;
	struct console___7 *next;
};

struct cgroup_namespace___213 {
	refcount_t count;
	struct ns_common___9 ns;
	struct user_namespace___228 *user_ns;
	struct ucounts___228 *ucounts;
	struct css_set___213 *root_cset;
};

struct ucounts___228 {
	struct hlist_node node;
	struct user_namespace___228 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___214;

struct bpf_map_ops___213 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___214 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___214 *, struct file___324 *);
	void (*map_free)(struct bpf_map___214 *);
	int (*map_get_next_key)(struct bpf_map___214 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___214 *);
	void * (*map_lookup_elem)(struct bpf_map___214 *, void *);
	int (*map_update_elem)(struct bpf_map___214 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___214 *, void *);
	int (*map_push_elem)(struct bpf_map___214 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___214 *, void *);
	int (*map_peek_elem)(struct bpf_map___214 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___214 *, struct file___324 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___214 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___214 *, void *, struct seq_file___275 *);
	int (*map_check_btf)(const struct bpf_map___214 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___214 {
	const struct bpf_map_ops___213 *ops;
	struct bpf_map___214 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___301 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___213;

typedef void (*kthread_work_func_t___213)(struct kthread_work___213 *);

struct kthread_worker___213;

struct kthread_work___213 {
	struct list_head node;
	kthread_work_func_t___213 func;
	struct kthread_worker___213 *worker;
	int canceling;
};

struct kthread_worker___213 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___325 *task;
	struct kthread_work___213 *current_work;
};

struct kthread_delayed_work___213 {
	struct kthread_work___213 work;
	struct timer_list timer;
};

struct psi_group___213 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___213 *poll_kworker;
	struct kthread_delayed_work___213 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___213;

struct cgroup_rstat_cpu___213;

struct cgroup___213 {
	struct cgroup_subsys_state___213 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___318 *kn;
	struct cgroup_file___213 procs_file;
	struct cgroup_file___213 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___213 *subsys[13];
	struct cgroup_root___213 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___213 *dom_cgrp;
	struct cgroup_rstat_cpu___213 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___35 bpf;
	atomic_t congestion_count;
	struct cgroup___213 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___213 psi;
	int ancestor_ids[0];
};

struct cftype___213;

struct cgroup_subsys___213 {
	struct cgroup_subsys_state___213 * (*css_alloc)(struct cgroup_subsys_state___213 *);
	int (*css_online)(struct cgroup_subsys_state___213 *);
	void (*css_offline)(struct cgroup_subsys_state___213 *);
	void (*css_released)(struct cgroup_subsys_state___213 *);
	void (*css_free)(struct cgroup_subsys_state___213 *);
	void (*css_reset)(struct cgroup_subsys_state___213 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___213 *, int);
	int (*css_extra_stat_show)(struct seq_file___275 *, struct cgroup_subsys_state___213 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___325 *);
	void (*cancel_fork)(struct task_struct___325 *);
	void (*fork)(struct task_struct___325 *);
	void (*exit)(struct task_struct___325 *);
	void (*free)(struct task_struct___325 *);
	void (*bind)(struct cgroup_subsys_state___213 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___213 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___213 *dfl_cftypes;
	struct cftype___213 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___213 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___213 *updated_children;
	struct cgroup___213 *updated_next;
};

struct cgroup_root___213 {
	struct kernfs_root___317 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___213 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___213 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___213 *ss;
	struct list_head node;
	struct kernfs_ops___317 *kf_ops;
	int (*open)(struct kernfs_open_file___317 *);
	void (*release)(struct kernfs_open_file___317 *);
	u64 (*read_u64)(struct cgroup_subsys_state___213 *, struct cftype___213 *);
	s64 (*read_s64)(struct cgroup_subsys_state___213 *, struct cftype___213 *);
	int (*seq_show)(struct seq_file___275 *, void *);
	void * (*seq_start)(struct seq_file___275 *, loff_t *);
	void * (*seq_next)(struct seq_file___275 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___275 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___213 *, struct cftype___213 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___213 *, struct cftype___213 *, s64);
	ssize_t (*write)(struct kernfs_open_file___317 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___317 *, struct poll_table_struct___6 *);
};

typedef void compound_page_dtor___312(struct page___325 *);

struct bdi_writeback_congested___153 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___153 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___153 {
	struct bio___153 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___154 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___154 bip_inline_vecs[0];
};

struct bio_set___153 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___153 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___121 {
	struct mem_cgroup___121 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___121 {
	struct lruvec___324 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___121 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___121 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct node___189 {
	struct device___290 dev;
};

struct fwnode_reference_args___219;

struct fwnode_endpoint___219;

struct fwnode_operations___219 {
	struct fwnode_handle___219 * (*get)(struct fwnode_handle___219 *);
	void (*put)(struct fwnode_handle___219 *);
	bool (*device_is_available)(const struct fwnode_handle___219 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___219 *, const struct device___290 *);
	bool (*property_present)(const struct fwnode_handle___219 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___219 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___219 *, const char *, const char **, size_t);
	struct fwnode_handle___219 * (*get_parent)(const struct fwnode_handle___219 *);
	struct fwnode_handle___219 * (*get_next_child_node)(const struct fwnode_handle___219 *, struct fwnode_handle___219 *);
	struct fwnode_handle___219 * (*get_named_child_node)(const struct fwnode_handle___219 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___219 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___219 *);
	struct fwnode_handle___219 * (*graph_get_next_endpoint)(const struct fwnode_handle___219 *, struct fwnode_handle___219 *);
	struct fwnode_handle___219 * (*graph_get_remote_endpoint)(const struct fwnode_handle___219 *);
	struct fwnode_handle___219 * (*graph_get_port_parent)(struct fwnode_handle___219 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___219 *, struct fwnode_endpoint___219 *);
};

struct fwnode_endpoint___219 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___219 *local_fwnode;
};

struct fwnode_reference_args___219 {
	struct fwnode_handle___219 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct vc___5 {
	struct vc_data___6 *d;
	struct work_struct SAK_work;
};

struct vt_event_wait {
	struct list_head list;
	struct vt_event event;
	int done;
};

struct vc_data {
	struct tty_port___25 port;
	short unsigned int vc_num;
	unsigned int vc_cols;
	unsigned int vc_rows;
	unsigned int vc_size_row;
	unsigned int vc_scan_lines;
	long unsigned int vc_origin;
	long unsigned int vc_scr_end;
	long unsigned int vc_visible_origin;
	unsigned int vc_top;
	unsigned int vc_bottom;
	const struct consw___15 *vc_sw;
	short unsigned int *vc_screenbuf;
	unsigned int vc_screenbuf_size;
	unsigned char vc_mode;
	unsigned char vc_attr;
	unsigned char vc_def_color;
	unsigned char vc_color;
	unsigned char vc_s_color;
	unsigned char vc_ulcolor;
	unsigned char vc_itcolor;
	unsigned char vc_halfcolor;
	unsigned int vc_cursor_type;
	short unsigned int vc_complement_mask;
	short unsigned int vc_s_complement_mask;
	unsigned int vc_x;
	unsigned int vc_y;
	unsigned int vc_saved_x;
	unsigned int vc_saved_y;
	long unsigned int vc_pos;
	short unsigned int vc_hi_font_mask;
	struct console_font vc_font;
	short unsigned int vc_video_erase_char;
	unsigned int vc_state;
	unsigned int vc_npar;
	unsigned int vc_par[16];
	struct vt_mode vt_mode;
	struct pid___206 *vt_pid;
	int vt_newvt;
	wait_queue_head_t paste_wait;
	unsigned int vc_charset: 1;
	unsigned int vc_s_charset: 1;
	unsigned int vc_disp_ctrl: 1;
	unsigned int vc_toggle_meta: 1;
	unsigned int vc_decscnm: 1;
	unsigned int vc_decom: 1;
	unsigned int vc_decawm: 1;
	unsigned int vc_deccm: 1;
	unsigned int vc_decim: 1;
	unsigned int vc_intensity: 2;
	unsigned int vc_italic: 1;
	unsigned int vc_underline: 1;
	unsigned int vc_blink: 1;
	unsigned int vc_reverse: 1;
	unsigned int vc_s_intensity: 2;
	unsigned int vc_s_italic: 1;
	unsigned int vc_s_underline: 1;
	unsigned int vc_s_blink: 1;
	unsigned int vc_s_reverse: 1;
	unsigned int vc_ques: 1;
	unsigned int vc_need_wrap: 1;
	unsigned int vc_can_do_color: 1;
	unsigned int vc_report_mouse: 2;
	unsigned char vc_utf: 1;
	unsigned char vc_utf_count;
	int vc_utf_char;
	unsigned int vc_tab_stop[8];
	unsigned char vc_palette[48];
	short unsigned int *vc_translate;
	unsigned char vc_G0_charset;
	unsigned char vc_G1_charset;
	unsigned char vc_saved_G0;
	unsigned char vc_saved_G1;
	unsigned int vc_resize_user;
	unsigned int vc_bell_pitch;
	unsigned int vc_bell_duration;
	short unsigned int vc_cur_blink_ms;
	struct vc_data **vc_display_fg;
	struct uni_pagedir *vc_uni_pagedir;
	struct uni_pagedir **vc_uni_pagedir_loc;
};

struct vc___6 {
	struct vc_data *d;
	struct work_struct SAK_work;
};

struct vt_notifier_param {
	struct vc_data *vc;
	unsigned int c;
};

struct console___8 {
	char name[16];
	void (*write)(struct console___8 *, const char *, unsigned int);
	int (*read)(struct console___8 *, char *, unsigned int);
	struct tty_driver___25 * (*device)(struct console___8 *, int *);
	void (*unblank)();
	int (*setup)(struct console___8 *, char *);
	int (*match)(struct console___8 *, char *, int, char *);
	short int flags;
	short int index;
	int cflag;
	void *data;
	struct console___8 *next;
};

typedef struct poll_table_struct___195 poll_table___26;

struct vcs_poll_data {
	struct notifier_block notifier;
	unsigned int cons_num;
	bool seen_last_update;
	wait_queue_head_t waitq;
	struct fasync_struct___319 *fasync;
};

struct tiocl_selection {
	short unsigned int xs;
	short unsigned int ys;
	short unsigned int xe;
	short unsigned int ye;
	short unsigned int sel_mode;
};

enum led_brightness {
	LED_OFF = 0,
	LED_ON = 1,
	LED_HALF = 127,
	LED_FULL = 255,
};

struct led_pattern;

struct led_trigger;

struct led_classdev {
	const char *name;
	enum led_brightness brightness;
	enum led_brightness max_brightness;
	int flags;
	long unsigned int work_flags;
	void (*brightness_set)(struct led_classdev *, enum led_brightness);
	int (*brightness_set_blocking)(struct led_classdev *, enum led_brightness);
	enum led_brightness (*brightness_get)(struct led_classdev *);
	int (*blink_set)(struct led_classdev *, long unsigned int *, long unsigned int *);
	int (*pattern_set)(struct led_classdev *, struct led_pattern *, u32, int);
	int (*pattern_clear)(struct led_classdev *);
	struct device___288 *dev;
	const struct attribute_group___286 **groups;
	struct list_head node;
	const char *default_trigger;
	long unsigned int blink_delay_on;
	long unsigned int blink_delay_off;
	struct timer_list blink_timer;
	int blink_brightness;
	int new_blink_brightness;
	void (*flash_resume)(struct led_classdev *);
	struct work_struct set_brightness_work;
	int delayed_set_value;
	struct rw_semaphore___323 trigger_lock;
	struct led_trigger *trigger;
	struct list_head trig_list;
	void *trigger_data;
	bool activated;
	struct mutex led_access;
};

struct led_pattern {
	u32 delta_t;
	int brightness;
};

struct led_trigger {
	const char *name;
	void (*activate)(struct led_classdev *);
	void (*deactivate)(struct led_classdev *);
	rwlock_t leddev_list_lock;
	struct list_head led_cdevs;
	struct list_head next_trig;
};

struct keyboard_notifier_param {
	struct vc_data___3 *vc;
	int down;
	int shift;
	int ledstate;
	unsigned int value;
};

struct kbd_struct {
	unsigned char lockstate;
	unsigned char slockstate;
	unsigned char ledmode: 1;
	unsigned char ledflagstate: 4;
	char: 3;
	unsigned char default_ledflagstate: 4;
	unsigned char kbdmode: 3;
	char: 1;
	unsigned char modeflags: 5;
};

struct kbentry {
	unsigned char kb_table;
	unsigned char kb_index;
	short unsigned int kb_value;
};

struct kbsentry {
	unsigned char kb_func;
	unsigned char kb_string[512];
};

struct kbdiacr {
	unsigned char diacr;
	unsigned char base;
	unsigned char result;
};

struct kbdiacrs {
	unsigned int kb_cnt;
	struct kbdiacr kbdiacr[256];
};

struct kbdiacrsuc {
	unsigned int kb_cnt;
	struct kbdiacruc kbdiacruc[256];
};

struct kbkeycode {
	unsigned int scancode;
	unsigned int keycode;
};

struct ff_device___3;

struct input_handle___3;

struct input_dev___3 {
	const char *name;
	const char *phys;
	const char *uniq;
	struct input_id id;
	long unsigned int propbit[1];
	long unsigned int evbit[1];
	long unsigned int keybit[12];
	long unsigned int relbit[1];
	long unsigned int absbit[1];
	long unsigned int mscbit[1];
	long unsigned int ledbit[1];
	long unsigned int sndbit[1];
	long unsigned int ffbit[2];
	long unsigned int swbit[1];
	unsigned int hint_events_per_packet;
	unsigned int keycodemax;
	unsigned int keycodesize;
	void *keycode;
	int (*setkeycode)(struct input_dev___3 *, const struct input_keymap_entry *, unsigned int *);
	int (*getkeycode)(struct input_dev___3 *, struct input_keymap_entry *);
	struct ff_device___3 *ff;
	unsigned int repeat_key;
	struct timer_list timer;
	int rep[2];
	struct input_mt *mt;
	struct input_absinfo *absinfo;
	long unsigned int key[12];
	long unsigned int led[1];
	long unsigned int snd[1];
	long unsigned int sw[1];
	int (*open)(struct input_dev___3 *);
	void (*close)(struct input_dev___3 *);
	int (*flush)(struct input_dev___3 *, struct file___322 *);
	int (*event)(struct input_dev___3 *, unsigned int, unsigned int, int);
	struct input_handle___3 *grab;
	spinlock_t event_lock;
	struct mutex mutex;
	unsigned int users;
	bool going_away;
	struct device___288 dev;
	struct list_head h_list;
	struct list_head node;
	unsigned int num_vals;
	unsigned int max_vals;
	struct input_value *vals;
	bool devres_managed;
};

struct ff_device___3 {
	int (*upload)(struct input_dev___3 *, struct ff_effect *, struct ff_effect *);
	int (*erase)(struct input_dev___3 *, int);
	int (*playback)(struct input_dev___3 *, int, int);
	void (*set_gain)(struct input_dev___3 *, u16);
	void (*set_autocenter)(struct input_dev___3 *, u16);
	void (*destroy)(struct ff_device___3 *);
	void *private;
	long unsigned int ffbit[2];
	struct mutex mutex;
	int max_effects;
	struct ff_effect *effects;
	struct file___322 *effect_owners[0];
};

struct input_handler___3;

struct input_handle___3 {
	void *private;
	int open;
	const char *name;
	struct input_dev___3 *dev;
	struct input_handler___3 *handler;
	struct list_head d_node;
	struct list_head h_node;
};

struct input_handler___3 {
	void *private;
	void (*event)(struct input_handle___3 *, unsigned int, unsigned int, int);
	void (*events)(struct input_handle___3 *, const struct input_value *, unsigned int);
	bool (*filter)(struct input_handle___3 *, unsigned int, unsigned int, int);
	bool (*match)(struct input_handler___3 *, struct input_dev___3 *);
	int (*connect)(struct input_handler___3 *, struct input_dev___3 *, const struct input_device_id *);
	void (*disconnect)(struct input_handle___3 *);
	void (*start)(struct input_handle___3 *);
	bool legacy_minors;
	int minor;
	const char *name;
	const struct input_device_id *id_table;
	struct list_head h_list;
	struct list_head node;
};

typedef void k_handler_fn(struct vc_data___3 *, unsigned char, char);

typedef void fn_handler_fn(struct vc_data___3 *);

struct getset_keycode_data {
	struct input_keymap_entry ke;
	int error;
};

struct kbd_led_trigger {
	struct led_trigger trigger;
	unsigned int mask;
};

struct uni_pagedir {
	u16 **uni_pgdir[32];
	long unsigned int refcount;
	long unsigned int sum;
	unsigned char *inverse_translations[4];
	u16 *inverse_trans_unicode;
};

struct vt_notifier_param___2 {
	struct vc_data___3 *vc;
	unsigned int c;
};

struct con_driver {
	const struct consw___14 *con;
	const char *desc;
	struct device___269 *dev;
	int node;
	int first;
	int last;
	int flag;
};

enum {
	blank_off = 0,
	blank_normal_wait = 1,
	blank_vesa_wait = 2,
};

struct rgb {
	u8 r;
	u8 g;
	u8 b;
};

enum {
	ESnormal = 0,
	ESesc = 1,
	ESsquare = 2,
	ESgetpars = 3,
	ESfunckey = 4,
	EShash = 5,
	ESsetG0 = 6,
	ESsetG1 = 7,
	ESpercent = 8,
	ESignore = 9,
	ESnonstd = 10,
	ESpalette = 11,
	ESosc = 12,
};

struct interval {
	uint32_t first;
	uint32_t last;
};

struct uart_port___4;

struct uart_ops___4 {
	unsigned int (*tx_empty)(struct uart_port___4 *);
	void (*set_mctrl)(struct uart_port___4 *, unsigned int);
	unsigned int (*get_mctrl)(struct uart_port___4 *);
	void (*stop_tx)(struct uart_port___4 *);
	void (*start_tx)(struct uart_port___4 *);
	void (*throttle)(struct uart_port___4 *);
	void (*unthrottle)(struct uart_port___4 *);
	void (*send_xchar)(struct uart_port___4 *, char);
	void (*stop_rx)(struct uart_port___4 *);
	void (*enable_ms)(struct uart_port___4 *);
	void (*break_ctl)(struct uart_port___4 *, int);
	int (*startup)(struct uart_port___4 *);
	void (*shutdown)(struct uart_port___4 *);
	void (*flush_buffer)(struct uart_port___4 *);
	void (*set_termios)(struct uart_port___4 *, struct ktermios *, struct ktermios *);
	void (*set_ldisc)(struct uart_port___4 *, struct ktermios *);
	void (*pm)(struct uart_port___4 *, unsigned int, unsigned int);
	const char * (*type)(struct uart_port___4 *);
	void (*release_port)(struct uart_port___4 *);
	int (*request_port)(struct uart_port___4 *);
	void (*config_port)(struct uart_port___4 *, int);
	int (*verify_port)(struct uart_port___4 *, struct serial_struct *);
	int (*ioctl)(struct uart_port___4 *, unsigned int, long unsigned int);
	int (*poll_init)(struct uart_port___4 *);
	void (*poll_put_char)(struct uart_port___4 *, unsigned char);
	int (*poll_get_char)(struct uart_port___4 *);
};

struct uart_state___4;

struct uart_port___4 {
	spinlock_t lock;
	long unsigned int iobase;
	unsigned char *membase;
	unsigned int (*serial_in)(struct uart_port___4 *, int);
	void (*serial_out)(struct uart_port___4 *, int, int);
	void (*set_termios)(struct uart_port___4 *, struct ktermios *, struct ktermios *);
	void (*set_ldisc)(struct uart_port___4 *, struct ktermios *);
	unsigned int (*get_mctrl)(struct uart_port___4 *);
	void (*set_mctrl)(struct uart_port___4 *, unsigned int);
	int (*startup)(struct uart_port___4 *);
	void (*shutdown)(struct uart_port___4 *);
	void (*throttle)(struct uart_port___4 *);
	void (*unthrottle)(struct uart_port___4 *);
	int (*handle_irq)(struct uart_port___4 *);
	void (*pm)(struct uart_port___4 *, unsigned int, unsigned int);
	void (*handle_break)(struct uart_port___4 *);
	int (*rs485_config)(struct uart_port___4 *, struct serial_rs485 *);
	unsigned int irq;
	long unsigned int irqflags;
	unsigned int uartclk;
	unsigned int fifosize;
	unsigned char x_char;
	unsigned char regshift;
	unsigned char iotype;
	unsigned char quirks;
	unsigned int read_status_mask;
	unsigned int ignore_status_mask;
	struct uart_state___4 *state;
	struct uart_icount icount;
	struct console___8 *cons;
	long unsigned int sysrq;
	upf_t flags;
	upstat_t status;
	int hw_stopped;
	unsigned int mctrl;
	unsigned int timeout;
	unsigned int type;
	const struct uart_ops___4 *ops;
	unsigned int custom_divisor;
	unsigned int line;
	unsigned int minor;
	resource_size_t mapbase;
	resource_size_t mapsize;
	struct device___286 *dev;
	unsigned char hub6;
	unsigned char suspended;
	unsigned char unused[2];
	const char *name;
	struct attribute_group___284 *attr_group;
	const struct attribute_group___284 **tty_groups;
	struct serial_rs485 rs485;
	void *private_data;
};

struct uart_state___4 {
	struct tty_port___25 port;
	enum uart_pm_state pm_state;
	struct circ_buf xmit;
	atomic_t refcount;
	wait_queue_head_t remove_wait;
	struct uart_port___4 *uart_port;
};

struct earlycon_device___4 {
	struct console___8 *con;
	struct uart_port___4 port;
	char options[16];
	unsigned int baud;
};

struct earlycon_id___4 {
	char name[15];
	char name_term;
	char compatible[128];
	int (*setup)(struct earlycon_device___4 *, const char *);
};

struct hv_ops;

struct hvc_struct {
	struct tty_port___25 port;
	spinlock_t lock;
	int index;
	int do_wakeup;
	char *outbuf;
	int outbuf_size;
	int n_outbuf;
	uint32_t vtermno;
	const struct hv_ops *ops;
	int irq_requested;
	int data;
	struct winsize ws;
	struct work_struct tty_resize;
	struct list_head next;
	long unsigned int flags;
};

struct hv_ops {
	int (*get_chars)(uint32_t, char *, int);
	int (*put_chars)(uint32_t, const char *, int);
	int (*notifier_add)(struct hvc_struct *, int);
	void (*notifier_del)(struct hvc_struct *, int);
	void (*notifier_hangup)(struct hvc_struct *, int);
	int (*tiocmget)(struct hvc_struct *);
	int (*tiocmset)(struct hvc_struct *, unsigned int, unsigned int);
	void (*dtr_rts)(struct hvc_struct *, int);
};

struct uart_port___5;

struct uart_ops___5 {
	unsigned int (*tx_empty)(struct uart_port___5 *);
	void (*set_mctrl)(struct uart_port___5 *, unsigned int);
	unsigned int (*get_mctrl)(struct uart_port___5 *);
	void (*stop_tx)(struct uart_port___5 *);
	void (*start_tx)(struct uart_port___5 *);
	void (*throttle)(struct uart_port___5 *);
	void (*unthrottle)(struct uart_port___5 *);
	void (*send_xchar)(struct uart_port___5 *, char);
	void (*stop_rx)(struct uart_port___5 *);
	void (*enable_ms)(struct uart_port___5 *);
	void (*break_ctl)(struct uart_port___5 *, int);
	int (*startup)(struct uart_port___5 *);
	void (*shutdown)(struct uart_port___5 *);
	void (*flush_buffer)(struct uart_port___5 *);
	void (*set_termios)(struct uart_port___5 *, struct ktermios *, struct ktermios *);
	void (*set_ldisc)(struct uart_port___5 *, struct ktermios *);
	void (*pm)(struct uart_port___5 *, unsigned int, unsigned int);
	const char * (*type)(struct uart_port___5 *);
	void (*release_port)(struct uart_port___5 *);
	int (*request_port)(struct uart_port___5 *);
	void (*config_port)(struct uart_port___5 *, int);
	int (*verify_port)(struct uart_port___5 *, struct serial_struct *);
	int (*ioctl)(struct uart_port___5 *, unsigned int, long unsigned int);
	int (*poll_init)(struct uart_port___5 *);
	void (*poll_put_char)(struct uart_port___5 *, unsigned char);
	int (*poll_get_char)(struct uart_port___5 *);
};

struct uart_state___5;

struct uart_port___5 {
	spinlock_t lock;
	long unsigned int iobase;
	unsigned char *membase;
	unsigned int (*serial_in)(struct uart_port___5 *, int);
	void (*serial_out)(struct uart_port___5 *, int, int);
	void (*set_termios)(struct uart_port___5 *, struct ktermios *, struct ktermios *);
	void (*set_ldisc)(struct uart_port___5 *, struct ktermios *);
	unsigned int (*get_mctrl)(struct uart_port___5 *);
	void (*set_mctrl)(struct uart_port___5 *, unsigned int);
	int (*startup)(struct uart_port___5 *);
	void (*shutdown)(struct uart_port___5 *);
	void (*throttle)(struct uart_port___5 *);
	void (*unthrottle)(struct uart_port___5 *);
	int (*handle_irq)(struct uart_port___5 *);
	void (*pm)(struct uart_port___5 *, unsigned int, unsigned int);
	void (*handle_break)(struct uart_port___5 *);
	int (*rs485_config)(struct uart_port___5 *, struct serial_rs485 *);
	unsigned int irq;
	long unsigned int irqflags;
	unsigned int uartclk;
	unsigned int fifosize;
	unsigned char x_char;
	unsigned char regshift;
	unsigned char iotype;
	unsigned char quirks;
	unsigned int read_status_mask;
	unsigned int ignore_status_mask;
	struct uart_state___5 *state;
	struct uart_icount icount;
	struct console___5 *cons;
	long unsigned int sysrq;
	upf_t flags;
	upstat_t status;
	int hw_stopped;
	unsigned int mctrl;
	unsigned int timeout;
	unsigned int type;
	const struct uart_ops___5 *ops;
	unsigned int custom_divisor;
	unsigned int line;
	unsigned int minor;
	resource_size_t mapbase;
	resource_size_t mapsize;
	struct device___269 *dev;
	unsigned char hub6;
	unsigned char suspended;
	unsigned char unused[2];
	const char *name;
	struct attribute_group___268 *attr_group;
	const struct attribute_group___268 **tty_groups;
	struct serial_rs485 rs485;
	void *private_data;
};

struct uart_state___5 {
	struct tty_port___21 port;
	enum uart_pm_state pm_state;
	struct circ_buf xmit;
	atomic_t refcount;
	wait_queue_head_t remove_wait;
	struct uart_port___5 *uart_port;
};

struct uart_driver {
	struct module___245 *owner;
	const char *driver_name;
	const char *dev_name;
	int major;
	int minor;
	int nr;
	struct console___5 *cons;
	struct uart_state___5 *state;
	struct tty_driver___21 *tty_driver;
};

struct earlycon_device___5 {
	struct console___5 *con;
	struct uart_port___5 port;
	char options[16];
	unsigned int baud;
};

struct earlycon_id___5 {
	char name[15];
	char name_term;
	char compatible[128];
	int (*setup)(struct earlycon_device___5 *, const char *);
};

struct irq_chip___23;

struct irq_data___23 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___11 *common;
	struct irq_chip___23 *chip;
	struct irq_domain *domain;
	struct irq_data___23 *parent_data;
	void *chip_data;
};

struct irq_chip___23 {
	struct device___269 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___23 *);
	void (*irq_shutdown)(struct irq_data___23 *);
	void (*irq_enable)(struct irq_data___23 *);
	void (*irq_disable)(struct irq_data___23 *);
	void (*irq_ack)(struct irq_data___23 *);
	void (*irq_mask)(struct irq_data___23 *);
	void (*irq_mask_ack)(struct irq_data___23 *);
	void (*irq_unmask)(struct irq_data___23 *);
	void (*irq_eoi)(struct irq_data___23 *);
	int (*irq_set_affinity)(struct irq_data___23 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___23 *);
	int (*irq_set_type)(struct irq_data___23 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___23 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___23 *);
	void (*irq_bus_sync_unlock)(struct irq_data___23 *);
	void (*irq_cpu_online)(struct irq_data___23 *);
	void (*irq_cpu_offline)(struct irq_data___23 *);
	void (*irq_suspend)(struct irq_data___23 *);
	void (*irq_resume)(struct irq_data___23 *);
	void (*irq_pm_shutdown)(struct irq_data___23 *);
	void (*irq_calc_mask)(struct irq_data___23 *);
	void (*irq_print_chip)(struct irq_data___23 *, struct seq_file___257 *);
	int (*irq_request_resources)(struct irq_data___23 *);
	void (*irq_release_resources)(struct irq_data___23 *);
	void (*irq_compose_msi_msg)(struct irq_data___23 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___23 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___23 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___23 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___23 *, void *);
	void (*ipi_send_single)(struct irq_data___23 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___23 *, const struct cpumask *);
	long unsigned int flags;
};

struct uart_match {
	struct uart_port___5 *port;
	struct uart_driver *driver;
};

struct consw___18 {
	struct module___250 *owner;
	const char * (*con_startup)();
	void (*con_init)(struct vc_data *, int);
	void (*con_deinit)(struct vc_data *);
	void (*con_clear)(struct vc_data *, int, int, int, int);
	void (*con_putc)(struct vc_data *, int, int, int);
	void (*con_putcs)(struct vc_data *, const short unsigned int *, int, int, int);
	void (*con_cursor)(struct vc_data *, int);
	bool (*con_scroll)(struct vc_data *, unsigned int, unsigned int, enum con_scroll, unsigned int);
	int (*con_switch)(struct vc_data *);
	int (*con_blank)(struct vc_data *, int, int);
	int (*con_font_set)(struct vc_data *, struct console_font *, unsigned int);
	int (*con_font_get)(struct vc_data *, struct console_font *);
	int (*con_font_default)(struct vc_data *, struct console_font *, char *);
	int (*con_font_copy)(struct vc_data *, int);
	int (*con_resize)(struct vc_data *, unsigned int, unsigned int, unsigned int);
	void (*con_set_palette)(struct vc_data *, const unsigned char *);
	void (*con_scrolldelta)(struct vc_data *, int);
	int (*con_set_origin)(struct vc_data *);
	void (*con_save_screen)(struct vc_data *);
	u8 (*con_build_attr)(struct vc_data *, u8, u8, u8, u8, u8, u8);
	void (*con_invert_region)(struct vc_data *, u16 *, int);
	u16 * (*con_screen_pos)(struct vc_data *, int);
	long unsigned int (*con_getxy)(struct vc_data *, long unsigned int, int *, int *);
	void (*con_flush_scrollback)(struct vc_data *);
	int (*con_debug_enter)(struct vc_data *);
	int (*con_debug_leave)(struct vc_data *);
};

struct tty_driver___31;

struct console___9 {
	char name[16];
	void (*write)(struct console___9 *, const char *, unsigned int);
	int (*read)(struct console___9 *, char *, unsigned int);
	struct tty_driver___31 * (*device)(struct console___9 *, int *);
	void (*unblank)();
	int (*setup)(struct console___9 *, char *);
	int (*match)(struct console___9 *, char *, int, char *);
	short int flags;
	short int index;
	int cflag;
	void *data;
	struct console___9 *next;
};

struct tty_struct___31;

struct tty_port___31;

struct tty_operations___31;

struct tty_driver___31 {
	int magic;
	struct kref kref;
	struct cdev___60 **cdevs;
	struct module___250 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___31 *other;
	struct tty_struct___31 **ttys;
	struct tty_port___31 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___31 *ops;
	struct list_head tty_drivers;
};

struct tty_operations___31 {
	struct tty_struct___31 * (*lookup)(struct tty_driver___31 *, struct file___310 *, int);
	int (*install)(struct tty_driver___31 *, struct tty_struct___31 *);
	void (*remove)(struct tty_driver___31 *, struct tty_struct___31 *);
	int (*open)(struct tty_struct___31 *, struct file___310 *);
	void (*close)(struct tty_struct___31 *, struct file___310 *);
	void (*shutdown)(struct tty_struct___31 *);
	void (*cleanup)(struct tty_struct___31 *);
	int (*write)(struct tty_struct___31 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___31 *, unsigned char);
	void (*flush_chars)(struct tty_struct___31 *);
	int (*write_room)(struct tty_struct___31 *);
	int (*chars_in_buffer)(struct tty_struct___31 *);
	int (*ioctl)(struct tty_struct___31 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___31 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___31 *, struct ktermios *);
	void (*throttle)(struct tty_struct___31 *);
	void (*unthrottle)(struct tty_struct___31 *);
	void (*stop)(struct tty_struct___31 *);
	void (*start)(struct tty_struct___31 *);
	void (*hangup)(struct tty_struct___31 *);
	int (*break_ctl)(struct tty_struct___31 *, int);
	void (*flush_buffer)(struct tty_struct___31 *);
	void (*set_ldisc)(struct tty_struct___31 *);
	void (*wait_until_sent)(struct tty_struct___31 *, int);
	void (*send_xchar)(struct tty_struct___31 *, char);
	int (*tiocmget)(struct tty_struct___31 *);
	int (*tiocmset)(struct tty_struct___31 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___31 *, struct winsize *);
	int (*set_termiox)(struct tty_struct___31 *, struct termiox *);
	int (*get_icount)(struct tty_struct___31 *, struct serial_icounter_struct *);
	void (*show_fdinfo)(struct tty_struct___31 *, struct seq_file___262 *);
	int (*poll_init)(struct tty_driver___31 *, int, char *);
	int (*poll_get_char)(struct tty_driver___31 *, int);
	void (*poll_put_char)(struct tty_driver___31 *, int, char);
	int (*proc_show)(struct seq_file___262 *, void *);
};

struct tty_ldisc___31;

struct tty_struct___31 {
	int magic;
	struct kref kref;
	struct device___275 *dev;
	struct tty_driver___31 *driver;
	const struct tty_operations___31 *ops;
	int index;
	struct ld_semaphore ldisc_sem;
	struct tty_ldisc___31 *ldisc;
	struct mutex atomic_write_lock;
	struct mutex legacy_mutex;
	struct mutex throttle_mutex;
	struct rw_semaphore___311 termios_rwsem;
	struct mutex winsize_mutex;
	spinlock_t ctrl_lock;
	spinlock_t flow_lock;
	struct ktermios termios;
	struct ktermios termios_locked;
	struct termiox *termiox;
	char name[64];
	struct pid___204 *pgrp;
	struct pid___204 *session;
	long unsigned int flags;
	int count;
	struct winsize winsize;
	long unsigned int stopped: 1;
	long unsigned int flow_stopped: 1;
	int: 30;
	long unsigned int unused: 62;
	int hw_stopped;
	long unsigned int ctrl_status: 8;
	long unsigned int packet: 1;
	int: 23;
	long unsigned int unused_ctrl: 55;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___31 *link;
	struct fasync_struct___309 *fasync;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	spinlock_t files_lock;
	struct list_head tty_files;
	int closing;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___31 *port;
};

struct tty_port_operations___31;

struct tty_port_client_operations___31;

struct tty_port___31 {
	struct tty_bufhead buf;
	struct tty_struct___31 *tty;
	struct tty_struct___31 *itty;
	const struct tty_port_operations___31 *ops;
	const struct tty_port_client_operations___31 *client_ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	unsigned char low_latency: 1;
	struct mutex mutex;
	struct mutex buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
	void *client_data;
};

struct tty_ldisc_ops___31 {
	int magic;
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___31 *);
	void (*close)(struct tty_struct___31 *);
	void (*flush_buffer)(struct tty_struct___31 *);
	ssize_t (*read)(struct tty_struct___31 *, struct file___310 *, unsigned char *, size_t);
	ssize_t (*write)(struct tty_struct___31 *, struct file___310 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___31 *, struct file___310 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___31 *, struct file___310 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___31 *, struct ktermios *);
	__poll_t (*poll)(struct tty_struct___31 *, struct file___310 *, struct poll_table_struct___187 *);
	int (*hangup)(struct tty_struct___31 *);
	void (*receive_buf)(struct tty_struct___31 *, const unsigned char *, char *, int);
	void (*write_wakeup)(struct tty_struct___31 *);
	void (*dcd_change)(struct tty_struct___31 *, unsigned int);
	int (*receive_buf2)(struct tty_struct___31 *, const unsigned char *, char *, int);
	struct module___250 *owner;
	int refcount;
};

struct tty_ldisc___31 {
	struct tty_ldisc_ops___31 *ops;
	struct tty_struct___31 *tty;
};

struct tty_port_operations___31 {
	int (*carrier_raised)(struct tty_port___31 *);
	void (*dtr_rts)(struct tty_port___31 *, int);
	void (*shutdown)(struct tty_port___31 *);
	int (*activate)(struct tty_port___31 *, struct tty_struct___31 *);
	void (*destruct)(struct tty_port___31 *);
};

struct tty_port_client_operations___31 {
	int (*receive_buf)(struct tty_port___31 *, const unsigned char *, const unsigned char *, size_t);
	void (*write_wakeup)(struct tty_port___31 *);
};

struct uart_port___6;

struct uart_ops___6 {
	unsigned int (*tx_empty)(struct uart_port___6 *);
	void (*set_mctrl)(struct uart_port___6 *, unsigned int);
	unsigned int (*get_mctrl)(struct uart_port___6 *);
	void (*stop_tx)(struct uart_port___6 *);
	void (*start_tx)(struct uart_port___6 *);
	void (*throttle)(struct uart_port___6 *);
	void (*unthrottle)(struct uart_port___6 *);
	void (*send_xchar)(struct uart_port___6 *, char);
	void (*stop_rx)(struct uart_port___6 *);
	void (*enable_ms)(struct uart_port___6 *);
	void (*break_ctl)(struct uart_port___6 *, int);
	int (*startup)(struct uart_port___6 *);
	void (*shutdown)(struct uart_port___6 *);
	void (*flush_buffer)(struct uart_port___6 *);
	void (*set_termios)(struct uart_port___6 *, struct ktermios *, struct ktermios *);
	void (*set_ldisc)(struct uart_port___6 *, struct ktermios *);
	void (*pm)(struct uart_port___6 *, unsigned int, unsigned int);
	const char * (*type)(struct uart_port___6 *);
	void (*release_port)(struct uart_port___6 *);
	int (*request_port)(struct uart_port___6 *);
	void (*config_port)(struct uart_port___6 *, int);
	int (*verify_port)(struct uart_port___6 *, struct serial_struct *);
	int (*ioctl)(struct uart_port___6 *, unsigned int, long unsigned int);
	int (*poll_init)(struct uart_port___6 *);
	void (*poll_put_char)(struct uart_port___6 *, unsigned char);
	int (*poll_get_char)(struct uart_port___6 *);
};

struct uart_state___6;

struct uart_port___6 {
	spinlock_t lock;
	long unsigned int iobase;
	unsigned char *membase;
	unsigned int (*serial_in)(struct uart_port___6 *, int);
	void (*serial_out)(struct uart_port___6 *, int, int);
	void (*set_termios)(struct uart_port___6 *, struct ktermios *, struct ktermios *);
	void (*set_ldisc)(struct uart_port___6 *, struct ktermios *);
	unsigned int (*get_mctrl)(struct uart_port___6 *);
	void (*set_mctrl)(struct uart_port___6 *, unsigned int);
	int (*startup)(struct uart_port___6 *);
	void (*shutdown)(struct uart_port___6 *);
	void (*throttle)(struct uart_port___6 *);
	void (*unthrottle)(struct uart_port___6 *);
	int (*handle_irq)(struct uart_port___6 *);
	void (*pm)(struct uart_port___6 *, unsigned int, unsigned int);
	void (*handle_break)(struct uart_port___6 *);
	int (*rs485_config)(struct uart_port___6 *, struct serial_rs485 *);
	unsigned int irq;
	long unsigned int irqflags;
	unsigned int uartclk;
	unsigned int fifosize;
	unsigned char x_char;
	unsigned char regshift;
	unsigned char iotype;
	unsigned char quirks;
	unsigned int read_status_mask;
	unsigned int ignore_status_mask;
	struct uart_state___6 *state;
	struct uart_icount icount;
	struct console___9 *cons;
	long unsigned int sysrq;
	upf_t flags;
	upstat_t status;
	int hw_stopped;
	unsigned int mctrl;
	unsigned int timeout;
	unsigned int type;
	const struct uart_ops___6 *ops;
	unsigned int custom_divisor;
	unsigned int line;
	unsigned int minor;
	resource_size_t mapbase;
	resource_size_t mapsize;
	struct device___275 *dev;
	unsigned char hub6;
	unsigned char suspended;
	unsigned char unused[2];
	const char *name;
	struct attribute_group___274 *attr_group;
	const struct attribute_group___274 **tty_groups;
	struct serial_rs485 rs485;
	void *private_data;
};

struct uart_state___6 {
	struct tty_port___31 port;
	enum uart_pm_state pm_state;
	struct circ_buf xmit;
	atomic_t refcount;
	wait_queue_head_t remove_wait;
	struct uart_port___6 *uart_port;
};

struct earlycon_device___6 {
	struct console___9 *con;
	struct uart_port___6 port;
	char options[16];
	unsigned int baud;
};

struct earlycon_id___6 {
	char name[15];
	char name_term;
	char compatible[128];
	int (*setup)(struct earlycon_device___6 *, const char *);
};

enum hwparam_type {
	hwparam_ioport = 0,
	hwparam_iomem = 1,
	hwparam_ioport_or_iomem = 2,
	hwparam_irq = 3,
	hwparam_dma = 4,
	hwparam_dma_addr = 5,
	hwparam_other = 6,
};

struct uart_port___7;

struct uart_ops___7 {
	unsigned int (*tx_empty)(struct uart_port___7 *);
	void (*set_mctrl)(struct uart_port___7 *, unsigned int);
	unsigned int (*get_mctrl)(struct uart_port___7 *);
	void (*stop_tx)(struct uart_port___7 *);
	void (*start_tx)(struct uart_port___7 *);
	void (*throttle)(struct uart_port___7 *);
	void (*unthrottle)(struct uart_port___7 *);
	void (*send_xchar)(struct uart_port___7 *, char);
	void (*stop_rx)(struct uart_port___7 *);
	void (*enable_ms)(struct uart_port___7 *);
	void (*break_ctl)(struct uart_port___7 *, int);
	int (*startup)(struct uart_port___7 *);
	void (*shutdown)(struct uart_port___7 *);
	void (*flush_buffer)(struct uart_port___7 *);
	void (*set_termios)(struct uart_port___7 *, struct ktermios *, struct ktermios *);
	void (*set_ldisc)(struct uart_port___7 *, struct ktermios *);
	void (*pm)(struct uart_port___7 *, unsigned int, unsigned int);
	const char * (*type)(struct uart_port___7 *);
	void (*release_port)(struct uart_port___7 *);
	int (*request_port)(struct uart_port___7 *);
	void (*config_port)(struct uart_port___7 *, int);
	int (*verify_port)(struct uart_port___7 *, struct serial_struct *);
	int (*ioctl)(struct uart_port___7 *, unsigned int, long unsigned int);
	int (*poll_init)(struct uart_port___7 *);
	void (*poll_put_char)(struct uart_port___7 *, unsigned char);
	int (*poll_get_char)(struct uart_port___7 *);
};

struct uart_state___7;

struct uart_port___7 {
	spinlock_t lock;
	long unsigned int iobase;
	unsigned char *membase;
	unsigned int (*serial_in)(struct uart_port___7 *, int);
	void (*serial_out)(struct uart_port___7 *, int, int);
	void (*set_termios)(struct uart_port___7 *, struct ktermios *, struct ktermios *);
	void (*set_ldisc)(struct uart_port___7 *, struct ktermios *);
	unsigned int (*get_mctrl)(struct uart_port___7 *);
	void (*set_mctrl)(struct uart_port___7 *, unsigned int);
	int (*startup)(struct uart_port___7 *);
	void (*shutdown)(struct uart_port___7 *);
	void (*throttle)(struct uart_port___7 *);
	void (*unthrottle)(struct uart_port___7 *);
	int (*handle_irq)(struct uart_port___7 *);
	void (*pm)(struct uart_port___7 *, unsigned int, unsigned int);
	void (*handle_break)(struct uart_port___7 *);
	int (*rs485_config)(struct uart_port___7 *, struct serial_rs485 *);
	unsigned int irq;
	long unsigned int irqflags;
	unsigned int uartclk;
	unsigned int fifosize;
	unsigned char x_char;
	unsigned char regshift;
	unsigned char iotype;
	unsigned char quirks;
	unsigned int read_status_mask;
	unsigned int ignore_status_mask;
	struct uart_state___7 *state;
	struct uart_icount icount;
	struct console___5 *cons;
	long unsigned int sysrq;
	upf_t flags;
	upstat_t status;
	int hw_stopped;
	unsigned int mctrl;
	unsigned int timeout;
	unsigned int type;
	const struct uart_ops___7 *ops;
	unsigned int custom_divisor;
	unsigned int line;
	unsigned int minor;
	resource_size_t mapbase;
	resource_size_t mapsize;
	struct device___274 *dev;
	unsigned char hub6;
	unsigned char suspended;
	unsigned char unused[2];
	const char *name;
	struct attribute_group___273 *attr_group;
	const struct attribute_group___273 **tty_groups;
	struct serial_rs485 rs485;
	void *private_data;
};

struct uart_state___7 {
	struct tty_port___21 port;
	enum uart_pm_state pm_state;
	struct circ_buf xmit;
	atomic_t refcount;
	wait_queue_head_t remove_wait;
	struct uart_port___7 *uart_port;
};

struct uart_driver___2 {
	struct module___249 *owner;
	const char *driver_name;
	const char *dev_name;
	int major;
	int minor;
	int nr;
	struct console___5 *cons;
	struct uart_state___7 *state;
	struct tty_driver___21 *tty_driver;
};

struct earlycon_device___7 {
	struct console___5 *con;
	struct uart_port___7 port;
	char options[16];
	unsigned int baud;
};

struct earlycon_id___7 {
	char name[15];
	char name_term;
	char compatible[128];
	int (*setup)(struct earlycon_device___7 *, const char *);
};

struct plat_serial8250_port___2 {
	long unsigned int iobase;
	void *membase;
	resource_size_t mapbase;
	unsigned int irq;
	long unsigned int irqflags;
	unsigned int uartclk;
	void *private_data;
	unsigned char regshift;
	unsigned char iotype;
	unsigned char hub6;
	upf_t flags;
	unsigned int type;
	unsigned int (*serial_in)(struct uart_port___7 *, int);
	void (*serial_out)(struct uart_port___7 *, int, int);
	void (*set_termios)(struct uart_port___7 *, struct ktermios *, struct ktermios *);
	void (*set_ldisc)(struct uart_port___7 *, struct ktermios *);
	unsigned int (*get_mctrl)(struct uart_port___7 *);
	int (*handle_irq)(struct uart_port___7 *);
	void (*pm)(struct uart_port___7 *, unsigned int, unsigned int);
	void (*handle_break)(struct uart_port___7 *);
};

enum {
	PLAT8250_DEV_LEGACY = 4294967295,
	PLAT8250_DEV_PLATFORM = 0,
	PLAT8250_DEV_PLATFORM1 = 1,
	PLAT8250_DEV_PLATFORM2 = 2,
	PLAT8250_DEV_FOURPORT = 3,
	PLAT8250_DEV_ACCENT = 4,
	PLAT8250_DEV_BOCA = 5,
	PLAT8250_DEV_EXAR_ST16C554 = 6,
	PLAT8250_DEV_HUB6 = 7,
	PLAT8250_DEV_AU1X00 = 8,
	PLAT8250_DEV_SM501 = 9,
};

struct uart_8250_port;

struct uart_8250_ops {
	int (*setup_irq)(struct uart_8250_port *);
	void (*release_irq)(struct uart_8250_port *);
};

struct uart_8250_dma;

struct uart_8250_em485;

struct uart_8250_port {
	struct uart_port___7 port;
	struct timer_list timer;
	struct list_head list;
	u32 capabilities;
	short unsigned int bugs;
	bool fifo_bug;
	unsigned int tx_loadsz;
	unsigned char acr;
	unsigned char fcr;
	unsigned char ier;
	unsigned char lcr;
	unsigned char mcr;
	unsigned char mcr_mask;
	unsigned char mcr_force;
	unsigned char cur_iotype;
	unsigned int rpm_tx_active;
	unsigned char canary;
	unsigned char probe;
	unsigned char lsr_saved_flags;
	unsigned char msr_saved_flags;
	struct uart_8250_dma *dma;
	const struct uart_8250_ops *ops;
	int (*dl_read)(struct uart_8250_port *);
	void (*dl_write)(struct uart_8250_port *, int);
	struct uart_8250_em485 *em485;
};

struct uart_8250_em485 {
	struct hrtimer start_tx_timer;
	struct hrtimer stop_tx_timer;
	struct hrtimer *active_timer;
	struct uart_8250_port *port;
};

struct dma_chan___3;

typedef bool (*dma_filter_fn___3)(struct dma_chan___3 *, void *);

struct uart_8250_dma {
	int (*tx_dma)(struct uart_8250_port *);
	int (*rx_dma)(struct uart_8250_port *);
	dma_filter_fn___3 fn;
	void *rx_param;
	void *tx_param;
	struct dma_slave_config rxconf;
	struct dma_slave_config txconf;
	struct dma_chan___3 *rxchan;
	struct dma_chan___3 *txchan;
	phys_addr_t rx_dma_addr;
	phys_addr_t tx_dma_addr;
	dma_addr_t rx_addr;
	dma_addr_t tx_addr;
	dma_cookie_t rx_cookie;
	dma_cookie_t tx_cookie;
	void *rx_buf;
	size_t rx_size;
	size_t tx_size;
	unsigned char tx_running;
	unsigned char tx_err;
	unsigned char rx_running;
};

struct dma_router___3 {
	struct device___274 *dev;
	void (*route_free)(struct device___274 *, void *);
};

struct dma_device___3;

struct dma_chan_dev___3;

struct dma_chan___3 {
	struct dma_device___3 *device;
	dma_cookie_t cookie;
	dma_cookie_t completed_cookie;
	int chan_id;
	struct dma_chan_dev___3 *dev;
	struct list_head device_node;
	struct dma_chan_percpu *local;
	int client_count;
	int table_count;
	struct dma_router___3 *router;
	void *route_data;
	void *private;
};

struct dma_filter___3 {
	dma_filter_fn___3 fn;
	int mapcnt;
	const struct dma_slave_map *map;
};

struct dma_async_tx_descriptor___3;

struct dma_device___3 {
	unsigned int chancnt;
	unsigned int privatecnt;
	struct list_head channels;
	struct list_head global_node;
	struct dma_filter___3 filter;
	dma_cap_mask_t cap_mask;
	short unsigned int max_xor;
	short unsigned int max_pq;
	enum dmaengine_alignment copy_align;
	enum dmaengine_alignment xor_align;
	enum dmaengine_alignment pq_align;
	enum dmaengine_alignment fill_align;
	int dev_id;
	struct device___274 *dev;
	u32 src_addr_widths;
	u32 dst_addr_widths;
	u32 directions;
	u32 max_burst;
	bool descriptor_reuse;
	enum dma_residue_granularity residue_granularity;
	int (*device_alloc_chan_resources)(struct dma_chan___3 *);
	void (*device_free_chan_resources)(struct dma_chan___3 *);
	struct dma_async_tx_descriptor___3 * (*device_prep_dma_memcpy)(struct dma_chan___3 *, dma_addr_t, dma_addr_t, size_t, long unsigned int);
	struct dma_async_tx_descriptor___3 * (*device_prep_dma_xor)(struct dma_chan___3 *, dma_addr_t, dma_addr_t *, unsigned int, size_t, long unsigned int);
	struct dma_async_tx_descriptor___3 * (*device_prep_dma_xor_val)(struct dma_chan___3 *, dma_addr_t *, unsigned int, size_t, enum sum_check_flags *, long unsigned int);
	struct dma_async_tx_descriptor___3 * (*device_prep_dma_pq)(struct dma_chan___3 *, dma_addr_t *, dma_addr_t *, unsigned int, const unsigned char *, size_t, long unsigned int);
	struct dma_async_tx_descriptor___3 * (*device_prep_dma_pq_val)(struct dma_chan___3 *, dma_addr_t *, dma_addr_t *, unsigned int, const unsigned char *, size_t, enum sum_check_flags *, long unsigned int);
	struct dma_async_tx_descriptor___3 * (*device_prep_dma_memset)(struct dma_chan___3 *, dma_addr_t, int, size_t, long unsigned int);
	struct dma_async_tx_descriptor___3 * (*device_prep_dma_memset_sg)(struct dma_chan___3 *, struct scatterlist *, unsigned int, int, long unsigned int);
	struct dma_async_tx_descriptor___3 * (*device_prep_dma_interrupt)(struct dma_chan___3 *, long unsigned int);
	struct dma_async_tx_descriptor___3 * (*device_prep_slave_sg)(struct dma_chan___3 *, struct scatterlist *, unsigned int, enum dma_transfer_direction, long unsigned int, void *);
	struct dma_async_tx_descriptor___3 * (*device_prep_dma_cyclic)(struct dma_chan___3 *, dma_addr_t, size_t, size_t, enum dma_transfer_direction, long unsigned int);
	struct dma_async_tx_descriptor___3 * (*device_prep_interleaved_dma)(struct dma_chan___3 *, struct dma_interleaved_template *, long unsigned int);
	struct dma_async_tx_descriptor___3 * (*device_prep_dma_imm_data)(struct dma_chan___3 *, dma_addr_t, u64, long unsigned int);
	int (*device_config)(struct dma_chan___3 *, struct dma_slave_config *);
	int (*device_pause)(struct dma_chan___3 *);
	int (*device_resume)(struct dma_chan___3 *);
	int (*device_terminate_all)(struct dma_chan___3 *);
	void (*device_synchronize)(struct dma_chan___3 *);
	enum dma_status (*device_tx_status)(struct dma_chan___3 *, dma_cookie_t, struct dma_tx_state *);
	void (*device_issue_pending)(struct dma_chan___3 *);
};

struct dma_chan_dev___3 {
	struct dma_chan___3 *chan;
	struct device___274 device;
	int dev_id;
	atomic_t *idr_ref;
};

struct dmaengine_unmap_data___3 {
	u8 map_cnt;
	u8 to_cnt;
	u8 from_cnt;
	u8 bidi_cnt;
	struct device___274 *dev;
	struct kref kref;
	size_t len;
	dma_addr_t addr[0];
};

struct dma_async_tx_descriptor___3 {
	dma_cookie_t cookie;
	enum dma_ctrl_flags flags;
	dma_addr_t phys;
	struct dma_chan___3 *chan;
	dma_cookie_t (*tx_submit)(struct dma_async_tx_descriptor___3 *);
	int (*desc_free)(struct dma_async_tx_descriptor___3 *);
	dma_async_tx_callback callback;
	dma_async_tx_callback_result callback_result;
	void *callback_param;
	struct dmaengine_unmap_data___3 *unmap;
};

struct old_serial_port {
	unsigned int uart;
	unsigned int baud_base;
	unsigned int port;
	unsigned int irq;
	upf_t flags;
	unsigned char io_type;
	unsigned char *iomem_base;
	short unsigned int iomem_reg_shift;
};

struct irq_info {
	struct hlist_node node;
	int irq;
	spinlock_t lock;
	struct list_head *head;
};

struct tty_driver___32;

struct console___10 {
	char name[16];
	void (*write)(struct console___10 *, const char *, unsigned int);
	int (*read)(struct console___10 *, char *, unsigned int);
	struct tty_driver___32 * (*device)(struct console___10 *, int *);
	void (*unblank)();
	int (*setup)(struct console___10 *, char *);
	int (*match)(struct console___10 *, char *, int, char *);
	short int flags;
	short int index;
	int cflag;
	void *data;
	struct console___10 *next;
};

struct tty_struct___32;

struct tty_port___32;

struct tty_operations___32;

struct tty_driver___32 {
	int magic;
	struct kref kref;
	struct cdev___59 **cdevs;
	struct module___249 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___32 *other;
	struct tty_struct___32 **ttys;
	struct tty_port___32 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___32 *ops;
	struct list_head tty_drivers;
};

struct tty_operations___32 {
	struct tty_struct___32 * (*lookup)(struct tty_driver___32 *, struct file___309 *, int);
	int (*install)(struct tty_driver___32 *, struct tty_struct___32 *);
	void (*remove)(struct tty_driver___32 *, struct tty_struct___32 *);
	int (*open)(struct tty_struct___32 *, struct file___309 *);
	void (*close)(struct tty_struct___32 *, struct file___309 *);
	void (*shutdown)(struct tty_struct___32 *);
	void (*cleanup)(struct tty_struct___32 *);
	int (*write)(struct tty_struct___32 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___32 *, unsigned char);
	void (*flush_chars)(struct tty_struct___32 *);
	int (*write_room)(struct tty_struct___32 *);
	int (*chars_in_buffer)(struct tty_struct___32 *);
	int (*ioctl)(struct tty_struct___32 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___32 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___32 *, struct ktermios *);
	void (*throttle)(struct tty_struct___32 *);
	void (*unthrottle)(struct tty_struct___32 *);
	void (*stop)(struct tty_struct___32 *);
	void (*start)(struct tty_struct___32 *);
	void (*hangup)(struct tty_struct___32 *);
	int (*break_ctl)(struct tty_struct___32 *, int);
	void (*flush_buffer)(struct tty_struct___32 *);
	void (*set_ldisc)(struct tty_struct___32 *);
	void (*wait_until_sent)(struct tty_struct___32 *, int);
	void (*send_xchar)(struct tty_struct___32 *, char);
	int (*tiocmget)(struct tty_struct___32 *);
	int (*tiocmset)(struct tty_struct___32 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___32 *, struct winsize *);
	int (*set_termiox)(struct tty_struct___32 *, struct termiox *);
	int (*get_icount)(struct tty_struct___32 *, struct serial_icounter_struct *);
	void (*show_fdinfo)(struct tty_struct___32 *, struct seq_file___261 *);
	int (*poll_init)(struct tty_driver___32 *, int, char *);
	int (*poll_get_char)(struct tty_driver___32 *, int);
	void (*poll_put_char)(struct tty_driver___32 *, int, char);
	int (*proc_show)(struct seq_file___261 *, void *);
};

struct tty_ldisc___32;

struct tty_struct___32 {
	int magic;
	struct kref kref;
	struct device___274 *dev;
	struct tty_driver___32 *driver;
	const struct tty_operations___32 *ops;
	int index;
	struct ld_semaphore ldisc_sem;
	struct tty_ldisc___32 *ldisc;
	struct mutex atomic_write_lock;
	struct mutex legacy_mutex;
	struct mutex throttle_mutex;
	struct rw_semaphore___310 termios_rwsem;
	struct mutex winsize_mutex;
	spinlock_t ctrl_lock;
	spinlock_t flow_lock;
	struct ktermios termios;
	struct ktermios termios_locked;
	struct termiox *termiox;
	char name[64];
	struct pid___204 *pgrp;
	struct pid___204 *session;
	long unsigned int flags;
	int count;
	struct winsize winsize;
	long unsigned int stopped: 1;
	long unsigned int flow_stopped: 1;
	int: 30;
	long unsigned int unused: 62;
	int hw_stopped;
	long unsigned int ctrl_status: 8;
	long unsigned int packet: 1;
	int: 23;
	long unsigned int unused_ctrl: 55;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___32 *link;
	struct fasync_struct___308 *fasync;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	spinlock_t files_lock;
	struct list_head tty_files;
	int closing;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___32 *port;
};

struct tty_port_operations___32;

struct tty_port_client_operations___32;

struct tty_port___32 {
	struct tty_bufhead buf;
	struct tty_struct___32 *tty;
	struct tty_struct___32 *itty;
	const struct tty_port_operations___32 *ops;
	const struct tty_port_client_operations___32 *client_ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	unsigned char low_latency: 1;
	struct mutex mutex;
	struct mutex buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
	void *client_data;
};

struct tty_ldisc_ops___32 {
	int magic;
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___32 *);
	void (*close)(struct tty_struct___32 *);
	void (*flush_buffer)(struct tty_struct___32 *);
	ssize_t (*read)(struct tty_struct___32 *, struct file___309 *, unsigned char *, size_t);
	ssize_t (*write)(struct tty_struct___32 *, struct file___309 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___32 *, struct file___309 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___32 *, struct file___309 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___32 *, struct ktermios *);
	__poll_t (*poll)(struct tty_struct___32 *, struct file___309 *, struct poll_table_struct___6 *);
	int (*hangup)(struct tty_struct___32 *);
	void (*receive_buf)(struct tty_struct___32 *, const unsigned char *, char *, int);
	void (*write_wakeup)(struct tty_struct___32 *);
	void (*dcd_change)(struct tty_struct___32 *, unsigned int);
	int (*receive_buf2)(struct tty_struct___32 *, const unsigned char *, char *, int);
	struct module___249 *owner;
	int refcount;
};

struct tty_ldisc___32 {
	struct tty_ldisc_ops___32 *ops;
	struct tty_struct___32 *tty;
};

struct tty_port_operations___32 {
	int (*carrier_raised)(struct tty_port___32 *);
	void (*dtr_rts)(struct tty_port___32 *, int);
	void (*shutdown)(struct tty_port___32 *);
	int (*activate)(struct tty_port___32 *, struct tty_struct___32 *);
	void (*destruct)(struct tty_port___32 *);
};

struct tty_port_client_operations___32 {
	int (*receive_buf)(struct tty_port___32 *, const unsigned char *, const unsigned char *, size_t);
	void (*write_wakeup)(struct tty_port___32 *);
};

struct serial8250_config {
	const char *name;
	short unsigned int fifo_size;
	short unsigned int tx_loadsz;
	unsigned char fcr;
	unsigned char rxtrig_bytes[4];
	unsigned int flags;
};

struct tty_struct___33;

struct tty_driver___33;

struct tty_operations___33 {
	struct tty_struct___33 * (*lookup)(struct tty_driver___33 *, struct file___293 *, int);
	int (*install)(struct tty_driver___33 *, struct tty_struct___33 *);
	void (*remove)(struct tty_driver___33 *, struct tty_struct___33 *);
	int (*open)(struct tty_struct___33 *, struct file___293 *);
	void (*close)(struct tty_struct___33 *, struct file___293 *);
	void (*shutdown)(struct tty_struct___33 *);
	void (*cleanup)(struct tty_struct___33 *);
	int (*write)(struct tty_struct___33 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___33 *, unsigned char);
	void (*flush_chars)(struct tty_struct___33 *);
	int (*write_room)(struct tty_struct___33 *);
	int (*chars_in_buffer)(struct tty_struct___33 *);
	int (*ioctl)(struct tty_struct___33 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___33 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___33 *, struct ktermios *);
	void (*throttle)(struct tty_struct___33 *);
	void (*unthrottle)(struct tty_struct___33 *);
	void (*stop)(struct tty_struct___33 *);
	void (*start)(struct tty_struct___33 *);
	void (*hangup)(struct tty_struct___33 *);
	int (*break_ctl)(struct tty_struct___33 *, int);
	void (*flush_buffer)(struct tty_struct___33 *);
	void (*set_ldisc)(struct tty_struct___33 *);
	void (*wait_until_sent)(struct tty_struct___33 *, int);
	void (*send_xchar)(struct tty_struct___33 *, char);
	int (*tiocmget)(struct tty_struct___33 *);
	int (*tiocmset)(struct tty_struct___33 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___33 *, struct winsize *);
	int (*set_termiox)(struct tty_struct___33 *, struct termiox *);
	int (*get_icount)(struct tty_struct___33 *, struct serial_icounter_struct *);
	void (*show_fdinfo)(struct tty_struct___33 *, struct seq_file___251 *);
	int (*poll_init)(struct tty_driver___33 *, int, char *);
	int (*poll_get_char)(struct tty_driver___33 *, int);
	void (*poll_put_char)(struct tty_driver___33 *, int, char);
	int (*proc_show)(struct seq_file___251 *, void *);
};

struct tty_ldisc___33;

struct tty_port___33;

struct tty_struct___33 {
	int magic;
	struct kref kref;
	struct device___258 *dev;
	struct tty_driver___33 *driver;
	const struct tty_operations___33 *ops;
	int index;
	struct ld_semaphore ldisc_sem;
	struct tty_ldisc___33 *ldisc;
	struct mutex atomic_write_lock;
	struct mutex legacy_mutex;
	struct mutex throttle_mutex;
	struct rw_semaphore___294 termios_rwsem;
	struct mutex winsize_mutex;
	spinlock_t ctrl_lock;
	spinlock_t flow_lock;
	struct ktermios termios;
	struct ktermios termios_locked;
	struct termiox *termiox;
	char name[64];
	struct pid___195 *pgrp;
	struct pid___195 *session;
	long unsigned int flags;
	int count;
	struct winsize winsize;
	long unsigned int stopped: 1;
	long unsigned int flow_stopped: 1;
	int: 30;
	long unsigned int unused: 62;
	int hw_stopped;
	long unsigned int ctrl_status: 8;
	long unsigned int packet: 1;
	int: 23;
	long unsigned int unused_ctrl: 55;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___33 *link;
	struct fasync_struct___292 *fasync;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	spinlock_t files_lock;
	struct list_head tty_files;
	int closing;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___33 *port;
};

struct tty_driver___33 {
	int magic;
	struct kref kref;
	struct cdev___51 **cdevs;
	struct module___11 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___33 *other;
	struct tty_struct___33 **ttys;
	struct tty_port___33 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___33 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___33;

struct tty_port_client_operations___33;

struct tty_port___33 {
	struct tty_bufhead buf;
	struct tty_struct___33 *tty;
	struct tty_struct___33 *itty;
	const struct tty_port_operations___33 *ops;
	const struct tty_port_client_operations___33 *client_ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	unsigned char low_latency: 1;
	struct mutex mutex;
	struct mutex buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
	void *client_data;
};

struct tty_ldisc_ops___33 {
	int magic;
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___33 *);
	void (*close)(struct tty_struct___33 *);
	void (*flush_buffer)(struct tty_struct___33 *);
	ssize_t (*read)(struct tty_struct___33 *, struct file___293 *, unsigned char *, size_t);
	ssize_t (*write)(struct tty_struct___33 *, struct file___293 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___33 *, struct file___293 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___33 *, struct file___293 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___33 *, struct ktermios *);
	__poll_t (*poll)(struct tty_struct___33 *, struct file___293 *, struct poll_table_struct___6 *);
	int (*hangup)(struct tty_struct___33 *);
	void (*receive_buf)(struct tty_struct___33 *, const unsigned char *, char *, int);
	void (*write_wakeup)(struct tty_struct___33 *);
	void (*dcd_change)(struct tty_struct___33 *, unsigned int);
	int (*receive_buf2)(struct tty_struct___33 *, const unsigned char *, char *, int);
	struct module___11 *owner;
	int refcount;
};

struct tty_ldisc___33 {
	struct tty_ldisc_ops___33 *ops;
	struct tty_struct___33 *tty;
};

struct tty_port_operations___33 {
	int (*carrier_raised)(struct tty_port___33 *);
	void (*dtr_rts)(struct tty_port___33 *, int);
	void (*shutdown)(struct tty_port___33 *);
	int (*activate)(struct tty_port___33 *, struct tty_struct___33 *);
	void (*destruct)(struct tty_port___33 *);
};

struct tty_port_client_operations___33 {
	int (*receive_buf)(struct tty_port___33 *, const unsigned char *, const unsigned char *, size_t);
	void (*write_wakeup)(struct tty_port___33 *);
};

struct uart_port___8;

struct uart_ops___8 {
	unsigned int (*tx_empty)(struct uart_port___8 *);
	void (*set_mctrl)(struct uart_port___8 *, unsigned int);
	unsigned int (*get_mctrl)(struct uart_port___8 *);
	void (*stop_tx)(struct uart_port___8 *);
	void (*start_tx)(struct uart_port___8 *);
	void (*throttle)(struct uart_port___8 *);
	void (*unthrottle)(struct uart_port___8 *);
	void (*send_xchar)(struct uart_port___8 *, char);
	void (*stop_rx)(struct uart_port___8 *);
	void (*enable_ms)(struct uart_port___8 *);
	void (*break_ctl)(struct uart_port___8 *, int);
	int (*startup)(struct uart_port___8 *);
	void (*shutdown)(struct uart_port___8 *);
	void (*flush_buffer)(struct uart_port___8 *);
	void (*set_termios)(struct uart_port___8 *, struct ktermios *, struct ktermios *);
	void (*set_ldisc)(struct uart_port___8 *, struct ktermios *);
	void (*pm)(struct uart_port___8 *, unsigned int, unsigned int);
	const char * (*type)(struct uart_port___8 *);
	void (*release_port)(struct uart_port___8 *);
	int (*request_port)(struct uart_port___8 *);
	void (*config_port)(struct uart_port___8 *, int);
	int (*verify_port)(struct uart_port___8 *, struct serial_struct *);
	int (*ioctl)(struct uart_port___8 *, unsigned int, long unsigned int);
	int (*poll_init)(struct uart_port___8 *);
	void (*poll_put_char)(struct uart_port___8 *, unsigned char);
	int (*poll_get_char)(struct uart_port___8 *);
};

struct uart_state___8;

struct uart_port___8 {
	spinlock_t lock;
	long unsigned int iobase;
	unsigned char *membase;
	unsigned int (*serial_in)(struct uart_port___8 *, int);
	void (*serial_out)(struct uart_port___8 *, int, int);
	void (*set_termios)(struct uart_port___8 *, struct ktermios *, struct ktermios *);
	void (*set_ldisc)(struct uart_port___8 *, struct ktermios *);
	unsigned int (*get_mctrl)(struct uart_port___8 *);
	void (*set_mctrl)(struct uart_port___8 *, unsigned int);
	int (*startup)(struct uart_port___8 *);
	void (*shutdown)(struct uart_port___8 *);
	void (*throttle)(struct uart_port___8 *);
	void (*unthrottle)(struct uart_port___8 *);
	int (*handle_irq)(struct uart_port___8 *);
	void (*pm)(struct uart_port___8 *, unsigned int, unsigned int);
	void (*handle_break)(struct uart_port___8 *);
	int (*rs485_config)(struct uart_port___8 *, struct serial_rs485 *);
	unsigned int irq;
	long unsigned int irqflags;
	unsigned int uartclk;
	unsigned int fifosize;
	unsigned char x_char;
	unsigned char regshift;
	unsigned char iotype;
	unsigned char quirks;
	unsigned int read_status_mask;
	unsigned int ignore_status_mask;
	struct uart_state___8 *state;
	struct uart_icount icount;
	struct console___2 *cons;
	long unsigned int sysrq;
	upf_t flags;
	upstat_t status;
	int hw_stopped;
	unsigned int mctrl;
	unsigned int timeout;
	unsigned int type;
	const struct uart_ops___8 *ops;
	unsigned int custom_divisor;
	unsigned int line;
	unsigned int minor;
	resource_size_t mapbase;
	resource_size_t mapsize;
	struct device___258 *dev;
	unsigned char hub6;
	unsigned char suspended;
	unsigned char unused[2];
	const char *name;
	struct attribute_group___257 *attr_group;
	const struct attribute_group___257 **tty_groups;
	struct serial_rs485 rs485;
	void *private_data;
};

struct uart_state___8 {
	struct tty_port___33 port;
	enum uart_pm_state pm_state;
	struct circ_buf xmit;
	atomic_t refcount;
	wait_queue_head_t remove_wait;
	struct uart_port___8 *uart_port;
};

struct earlycon_device___8 {
	struct console___2 *con;
	struct uart_port___8 port;
	char options[16];
	unsigned int baud;
};

struct earlycon_id___8 {
	char name[15];
	char name_term;
	char compatible[128];
	int (*setup)(struct earlycon_device___8 *, const char *);
};

struct uart_8250_port___2;

struct uart_8250_ops___2 {
	int (*setup_irq)(struct uart_8250_port___2 *);
	void (*release_irq)(struct uart_8250_port___2 *);
};

struct uart_8250_dma___2;

struct uart_8250_em485___2;

struct uart_8250_port___2 {
	struct uart_port___8 port;
	struct timer_list timer;
	struct list_head list;
	u32 capabilities;
	short unsigned int bugs;
	bool fifo_bug;
	unsigned int tx_loadsz;
	unsigned char acr;
	unsigned char fcr;
	unsigned char ier;
	unsigned char lcr;
	unsigned char mcr;
	unsigned char mcr_mask;
	unsigned char mcr_force;
	unsigned char cur_iotype;
	unsigned int rpm_tx_active;
	unsigned char canary;
	unsigned char probe;
	unsigned char lsr_saved_flags;
	unsigned char msr_saved_flags;
	struct uart_8250_dma___2 *dma;
	const struct uart_8250_ops___2 *ops;
	int (*dl_read)(struct uart_8250_port___2 *);
	void (*dl_write)(struct uart_8250_port___2 *, int);
	struct uart_8250_em485___2 *em485;
};

struct uart_8250_em485___2 {
	struct hrtimer start_tx_timer;
	struct hrtimer stop_tx_timer;
	struct hrtimer *active_timer;
	struct uart_8250_port___2 *port;
};

struct dma_chan___4;

typedef bool (*dma_filter_fn___4)(struct dma_chan___4 *, void *);

struct uart_8250_dma___2 {
	int (*tx_dma)(struct uart_8250_port___2 *);
	int (*rx_dma)(struct uart_8250_port___2 *);
	dma_filter_fn___4 fn;
	void *rx_param;
	void *tx_param;
	struct dma_slave_config rxconf;
	struct dma_slave_config txconf;
	struct dma_chan___4 *rxchan;
	struct dma_chan___4 *txchan;
	phys_addr_t rx_dma_addr;
	phys_addr_t tx_dma_addr;
	dma_addr_t rx_addr;
	dma_addr_t tx_addr;
	dma_cookie_t rx_cookie;
	dma_cookie_t tx_cookie;
	void *rx_buf;
	size_t rx_size;
	size_t tx_size;
	unsigned char tx_running;
	unsigned char tx_err;
	unsigned char rx_running;
};

struct dma_router___4 {
	struct device___258 *dev;
	void (*route_free)(struct device___258 *, void *);
};

struct dma_device___4;

struct dma_chan_dev___4;

struct dma_chan___4 {
	struct dma_device___4 *device;
	dma_cookie_t cookie;
	dma_cookie_t completed_cookie;
	int chan_id;
	struct dma_chan_dev___4 *dev;
	struct list_head device_node;
	struct dma_chan_percpu *local;
	int client_count;
	int table_count;
	struct dma_router___4 *router;
	void *route_data;
	void *private;
};

struct dma_filter___4 {
	dma_filter_fn___4 fn;
	int mapcnt;
	const struct dma_slave_map *map;
};

struct dma_async_tx_descriptor___4;

struct dma_device___4 {
	unsigned int chancnt;
	unsigned int privatecnt;
	struct list_head channels;
	struct list_head global_node;
	struct dma_filter___4 filter;
	dma_cap_mask_t cap_mask;
	short unsigned int max_xor;
	short unsigned int max_pq;
	enum dmaengine_alignment copy_align;
	enum dmaengine_alignment xor_align;
	enum dmaengine_alignment pq_align;
	enum dmaengine_alignment fill_align;
	int dev_id;
	struct device___258 *dev;
	u32 src_addr_widths;
	u32 dst_addr_widths;
	u32 directions;
	u32 max_burst;
	bool descriptor_reuse;
	enum dma_residue_granularity residue_granularity;
	int (*device_alloc_chan_resources)(struct dma_chan___4 *);
	void (*device_free_chan_resources)(struct dma_chan___4 *);
	struct dma_async_tx_descriptor___4 * (*device_prep_dma_memcpy)(struct dma_chan___4 *, dma_addr_t, dma_addr_t, size_t, long unsigned int);
	struct dma_async_tx_descriptor___4 * (*device_prep_dma_xor)(struct dma_chan___4 *, dma_addr_t, dma_addr_t *, unsigned int, size_t, long unsigned int);
	struct dma_async_tx_descriptor___4 * (*device_prep_dma_xor_val)(struct dma_chan___4 *, dma_addr_t *, unsigned int, size_t, enum sum_check_flags *, long unsigned int);
	struct dma_async_tx_descriptor___4 * (*device_prep_dma_pq)(struct dma_chan___4 *, dma_addr_t *, dma_addr_t *, unsigned int, const unsigned char *, size_t, long unsigned int);
	struct dma_async_tx_descriptor___4 * (*device_prep_dma_pq_val)(struct dma_chan___4 *, dma_addr_t *, dma_addr_t *, unsigned int, const unsigned char *, size_t, enum sum_check_flags *, long unsigned int);
	struct dma_async_tx_descriptor___4 * (*device_prep_dma_memset)(struct dma_chan___4 *, dma_addr_t, int, size_t, long unsigned int);
	struct dma_async_tx_descriptor___4 * (*device_prep_dma_memset_sg)(struct dma_chan___4 *, struct scatterlist *, unsigned int, int, long unsigned int);
	struct dma_async_tx_descriptor___4 * (*device_prep_dma_interrupt)(struct dma_chan___4 *, long unsigned int);
	struct dma_async_tx_descriptor___4 * (*device_prep_slave_sg)(struct dma_chan___4 *, struct scatterlist *, unsigned int, enum dma_transfer_direction, long unsigned int, void *);
	struct dma_async_tx_descriptor___4 * (*device_prep_dma_cyclic)(struct dma_chan___4 *, dma_addr_t, size_t, size_t, enum dma_transfer_direction, long unsigned int);
	struct dma_async_tx_descriptor___4 * (*device_prep_interleaved_dma)(struct dma_chan___4 *, struct dma_interleaved_template *, long unsigned int);
	struct dma_async_tx_descriptor___4 * (*device_prep_dma_imm_data)(struct dma_chan___4 *, dma_addr_t, u64, long unsigned int);
	int (*device_config)(struct dma_chan___4 *, struct dma_slave_config *);
	int (*device_pause)(struct dma_chan___4 *);
	int (*device_resume)(struct dma_chan___4 *);
	int (*device_terminate_all)(struct dma_chan___4 *);
	void (*device_synchronize)(struct dma_chan___4 *);
	enum dma_status (*device_tx_status)(struct dma_chan___4 *, dma_cookie_t, struct dma_tx_state *);
	void (*device_issue_pending)(struct dma_chan___4 *);
};

struct dma_chan_dev___4 {
	struct dma_chan___4 *chan;
	struct device___258 device;
	int dev_id;
	atomic_t *idr_ref;
};

struct dmaengine_unmap_data___4 {
	u8 map_cnt;
	u8 to_cnt;
	u8 from_cnt;
	u8 bidi_cnt;
	struct device___258 *dev;
	struct kref kref;
	size_t len;
	dma_addr_t addr[0];
};

struct dma_async_tx_descriptor___4 {
	dma_cookie_t cookie;
	enum dma_ctrl_flags flags;
	dma_addr_t phys;
	struct dma_chan___4 *chan;
	dma_cookie_t (*tx_submit)(struct dma_async_tx_descriptor___4 *);
	int (*desc_free)(struct dma_async_tx_descriptor___4 *);
	dma_async_tx_callback callback;
	dma_async_tx_callback_result callback_result;
	void *callback_param;
	struct dmaengine_unmap_data___4 *unmap;
};

struct pciserial_board {
	unsigned int flags;
	unsigned int num_ports;
	unsigned int base_baud;
	unsigned int uart_offset;
	unsigned int reg_shift;
	unsigned int first_offset;
};

struct serial_private;

struct pci_serial_quirk {
	u32 vendor;
	u32 device;
	u32 subvendor;
	u32 subdevice;
	int (*probe)(struct pci_dev___27 *);
	int (*init)(struct pci_dev___27 *);
	int (*setup)(struct serial_private *, const struct pciserial_board *, struct uart_8250_port *, int);
	void (*exit)(struct pci_dev___27 *);
};

struct serial_private {
	struct pci_dev___27 *dev;
	unsigned int nr;
	struct pci_serial_quirk *quirk;
	const struct pciserial_board *board;
	int line[0];
};

struct timedia_struct {
	int num;
	const short unsigned int *ids;
};

struct quatech_feature {
	u16 devid;
	bool amcc;
};

enum pci_board_num_t {
	pbn_default = 0,
	pbn_b0_1_115200 = 1,
	pbn_b0_2_115200 = 2,
	pbn_b0_4_115200 = 3,
	pbn_b0_5_115200 = 4,
	pbn_b0_8_115200 = 5,
	pbn_b0_1_921600 = 6,
	pbn_b0_2_921600 = 7,
	pbn_b0_4_921600 = 8,
	pbn_b0_2_1130000 = 9,
	pbn_b0_4_1152000 = 10,
	pbn_b0_4_1250000 = 11,
	pbn_b0_2_1843200 = 12,
	pbn_b0_4_1843200 = 13,
	pbn_b0_1_4000000 = 14,
	pbn_b0_bt_1_115200 = 15,
	pbn_b0_bt_2_115200 = 16,
	pbn_b0_bt_4_115200 = 17,
	pbn_b0_bt_8_115200 = 18,
	pbn_b0_bt_1_460800 = 19,
	pbn_b0_bt_2_460800 = 20,
	pbn_b0_bt_4_460800 = 21,
	pbn_b0_bt_1_921600 = 22,
	pbn_b0_bt_2_921600 = 23,
	pbn_b0_bt_4_921600 = 24,
	pbn_b0_bt_8_921600 = 25,
	pbn_b1_1_115200 = 26,
	pbn_b1_2_115200 = 27,
	pbn_b1_4_115200 = 28,
	pbn_b1_8_115200 = 29,
	pbn_b1_16_115200 = 30,
	pbn_b1_1_921600 = 31,
	pbn_b1_2_921600 = 32,
	pbn_b1_4_921600 = 33,
	pbn_b1_8_921600 = 34,
	pbn_b1_2_1250000 = 35,
	pbn_b1_bt_1_115200 = 36,
	pbn_b1_bt_2_115200 = 37,
	pbn_b1_bt_4_115200 = 38,
	pbn_b1_bt_2_921600 = 39,
	pbn_b1_1_1382400 = 40,
	pbn_b1_2_1382400 = 41,
	pbn_b1_4_1382400 = 42,
	pbn_b1_8_1382400 = 43,
	pbn_b2_1_115200 = 44,
	pbn_b2_2_115200 = 45,
	pbn_b2_4_115200 = 46,
	pbn_b2_8_115200 = 47,
	pbn_b2_1_460800 = 48,
	pbn_b2_4_460800 = 49,
	pbn_b2_8_460800 = 50,
	pbn_b2_16_460800 = 51,
	pbn_b2_1_921600 = 52,
	pbn_b2_4_921600 = 53,
	pbn_b2_8_921600 = 54,
	pbn_b2_8_1152000 = 55,
	pbn_b2_bt_1_115200 = 56,
	pbn_b2_bt_2_115200 = 57,
	pbn_b2_bt_4_115200 = 58,
	pbn_b2_bt_2_921600 = 59,
	pbn_b2_bt_4_921600 = 60,
	pbn_b3_2_115200 = 61,
	pbn_b3_4_115200 = 62,
	pbn_b3_8_115200 = 63,
	pbn_b4_bt_2_921600 = 64,
	pbn_b4_bt_4_921600 = 65,
	pbn_b4_bt_8_921600 = 66,
	pbn_panacom = 67,
	pbn_panacom2 = 68,
	pbn_panacom4 = 69,
	pbn_plx_romulus = 70,
	pbn_endrun_2_4000000 = 71,
	pbn_oxsemi = 72,
	pbn_oxsemi_1_4000000 = 73,
	pbn_oxsemi_2_4000000 = 74,
	pbn_oxsemi_4_4000000 = 75,
	pbn_oxsemi_8_4000000 = 76,
	pbn_intel_i960 = 77,
	pbn_sgi_ioc3 = 78,
	pbn_computone_4 = 79,
	pbn_computone_6 = 80,
	pbn_computone_8 = 81,
	pbn_sbsxrsio = 82,
	pbn_pasemi_1682M = 83,
	pbn_ni8430_2 = 84,
	pbn_ni8430_4 = 85,
	pbn_ni8430_8 = 86,
	pbn_ni8430_16 = 87,
	pbn_ADDIDATA_PCIe_1_3906250 = 88,
	pbn_ADDIDATA_PCIe_2_3906250 = 89,
	pbn_ADDIDATA_PCIe_4_3906250 = 90,
	pbn_ADDIDATA_PCIe_8_3906250 = 91,
	pbn_ce4100_1_115200 = 92,
	pbn_omegapci = 93,
	pbn_NETMOS9900_2s_115200 = 94,
	pbn_brcm_trumanage = 95,
	pbn_fintek_4 = 96,
	pbn_fintek_8 = 97,
	pbn_fintek_12 = 98,
	pbn_wch382_2 = 99,
	pbn_wch384_4 = 100,
	pbn_pericom_PI7C9X7951 = 101,
	pbn_pericom_PI7C9X7952 = 102,
	pbn_pericom_PI7C9X7954 = 103,
	pbn_pericom_PI7C9X7958 = 104,
};

struct uart_8250_port___3;

struct uart_8250_ops___3 {
	int (*setup_irq)(struct uart_8250_port___3 *);
	void (*release_irq)(struct uart_8250_port___3 *);
};

struct uart_8250_dma___3;

struct uart_8250_em485___3;

struct uart_8250_port___3 {
	struct uart_port port;
	struct timer_list timer;
	struct list_head list;
	u32 capabilities;
	short unsigned int bugs;
	bool fifo_bug;
	unsigned int tx_loadsz;
	unsigned char acr;
	unsigned char fcr;
	unsigned char ier;
	unsigned char lcr;
	unsigned char mcr;
	unsigned char mcr_mask;
	unsigned char mcr_force;
	unsigned char cur_iotype;
	unsigned int rpm_tx_active;
	unsigned char canary;
	unsigned char probe;
	unsigned char lsr_saved_flags;
	unsigned char msr_saved_flags;
	struct uart_8250_dma___3 *dma;
	const struct uart_8250_ops___3 *ops;
	int (*dl_read)(struct uart_8250_port___3 *);
	void (*dl_write)(struct uart_8250_port___3 *, int);
	struct uart_8250_em485___3 *em485;
};

struct uart_8250_em485___3 {
	struct hrtimer start_tx_timer;
	struct hrtimer stop_tx_timer;
	struct hrtimer *active_timer;
	struct uart_8250_port___3 *port;
};

struct uart_8250_dma___3 {
	int (*tx_dma)(struct uart_8250_port___3 *);
	int (*rx_dma)(struct uart_8250_port___3 *);
	dma_filter_fn___2 fn;
	void *rx_param;
	void *tx_param;
	struct dma_slave_config rxconf;
	struct dma_slave_config txconf;
	struct dma_chan___2 *rxchan;
	struct dma_chan___2 *txchan;
	phys_addr_t rx_dma_addr;
	phys_addr_t tx_dma_addr;
	dma_addr_t rx_addr;
	dma_addr_t tx_addr;
	dma_cookie_t rx_cookie;
	dma_cookie_t tx_cookie;
	void *rx_buf;
	size_t rx_size;
	size_t tx_size;
	unsigned char tx_running;
	unsigned char tx_err;
	unsigned char rx_running;
};

struct exar8250_platform {
	int (*rs485_config)(struct uart_port *, struct serial_rs485 *);
	int (*register_gpio)(struct pci_dev___8 *, struct uart_8250_port___3 *);
};

struct exar8250;

struct exar8250_board {
	unsigned int num_ports;
	unsigned int reg_shift;
	bool has_slave;
	int (*setup)(struct exar8250 *, struct pci_dev___8 *, struct uart_8250_port___3 *, int);
	void (*exit)(struct pci_dev___8 *);
};

struct exar8250 {
	unsigned int nr;
	struct exar8250_board *board;
	void *virt;
	int line[0];
};

struct reset_control___2;

struct dw8250_data {
	u8 usr_reg;
	int line;
	int msr_mask_on;
	int msr_mask_off;
	struct clk *clk;
	struct clk *pclk;
	struct reset_control___2 *rst;
	struct uart_8250_dma___3 dma;
	unsigned int skip_autocfg: 1;
	unsigned int uart_16550_compatible: 1;
};

struct consw___19 {
	struct module___226 *owner;
	const char * (*con_startup)();
	void (*con_init)(struct vc_data *, int);
	void (*con_deinit)(struct vc_data *);
	void (*con_clear)(struct vc_data *, int, int, int, int);
	void (*con_putc)(struct vc_data *, int, int, int);
	void (*con_putcs)(struct vc_data *, const short unsigned int *, int, int, int);
	void (*con_cursor)(struct vc_data *, int);
	bool (*con_scroll)(struct vc_data *, unsigned int, unsigned int, enum con_scroll, unsigned int);
	int (*con_switch)(struct vc_data *);
	int (*con_blank)(struct vc_data *, int, int);
	int (*con_font_set)(struct vc_data *, struct console_font *, unsigned int);
	int (*con_font_get)(struct vc_data *, struct console_font *);
	int (*con_font_default)(struct vc_data *, struct console_font *, char *);
	int (*con_font_copy)(struct vc_data *, int);
	int (*con_resize)(struct vc_data *, unsigned int, unsigned int, unsigned int);
	void (*con_set_palette)(struct vc_data *, const unsigned char *);
	void (*con_scrolldelta)(struct vc_data *, int);
	int (*con_set_origin)(struct vc_data *);
	void (*con_save_screen)(struct vc_data *);
	u8 (*con_build_attr)(struct vc_data *, u8, u8, u8, u8, u8, u8);
	void (*con_invert_region)(struct vc_data *, u16 *, int);
	u16 * (*con_screen_pos)(struct vc_data *, int);
	long unsigned int (*con_getxy)(struct vc_data *, long unsigned int, int *, int *);
	void (*con_flush_scrollback)(struct vc_data *);
	int (*con_debug_enter)(struct vc_data *);
	int (*con_debug_leave)(struct vc_data *);
};

struct tty_driver___34;

struct console___11 {
	char name[16];
	void (*write)(struct console___11 *, const char *, unsigned int);
	int (*read)(struct console___11 *, char *, unsigned int);
	struct tty_driver___34 * (*device)(struct console___11 *, int *);
	void (*unblank)();
	int (*setup)(struct console___11 *, char *);
	int (*match)(struct console___11 *, char *, int, char *);
	short int flags;
	short int index;
	int cflag;
	void *data;
	struct console___11 *next;
};

struct tty_struct___34;

struct tty_port___34;

struct tty_operations___34;

struct tty_driver___34 {
	int magic;
	struct kref kref;
	struct cdev___43 **cdevs;
	struct module___226 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___34 *other;
	struct tty_struct___34 **ttys;
	struct tty_port___34 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___34 *ops;
	struct list_head tty_drivers;
};

struct tty_operations___34 {
	struct tty_struct___34 * (*lookup)(struct tty_driver___34 *, struct file___280 *, int);
	int (*install)(struct tty_driver___34 *, struct tty_struct___34 *);
	void (*remove)(struct tty_driver___34 *, struct tty_struct___34 *);
	int (*open)(struct tty_struct___34 *, struct file___280 *);
	void (*close)(struct tty_struct___34 *, struct file___280 *);
	void (*shutdown)(struct tty_struct___34 *);
	void (*cleanup)(struct tty_struct___34 *);
	int (*write)(struct tty_struct___34 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___34 *, unsigned char);
	void (*flush_chars)(struct tty_struct___34 *);
	int (*write_room)(struct tty_struct___34 *);
	int (*chars_in_buffer)(struct tty_struct___34 *);
	int (*ioctl)(struct tty_struct___34 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___34 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___34 *, struct ktermios *);
	void (*throttle)(struct tty_struct___34 *);
	void (*unthrottle)(struct tty_struct___34 *);
	void (*stop)(struct tty_struct___34 *);
	void (*start)(struct tty_struct___34 *);
	void (*hangup)(struct tty_struct___34 *);
	int (*break_ctl)(struct tty_struct___34 *, int);
	void (*flush_buffer)(struct tty_struct___34 *);
	void (*set_ldisc)(struct tty_struct___34 *);
	void (*wait_until_sent)(struct tty_struct___34 *, int);
	void (*send_xchar)(struct tty_struct___34 *, char);
	int (*tiocmget)(struct tty_struct___34 *);
	int (*tiocmset)(struct tty_struct___34 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___34 *, struct winsize *);
	int (*set_termiox)(struct tty_struct___34 *, struct termiox *);
	int (*get_icount)(struct tty_struct___34 *, struct serial_icounter_struct *);
	void (*show_fdinfo)(struct tty_struct___34 *, struct seq_file___243 *);
	int (*poll_init)(struct tty_driver___34 *, int, char *);
	int (*poll_get_char)(struct tty_driver___34 *, int);
	void (*poll_put_char)(struct tty_driver___34 *, int, char);
	int (*proc_show)(struct seq_file___243 *, void *);
};

struct tty_ldisc___34;

struct tty_struct___34 {
	int magic;
	struct kref kref;
	struct device___242 *dev;
	struct tty_driver___34 *driver;
	const struct tty_operations___34 *ops;
	int index;
	struct ld_semaphore ldisc_sem;
	struct tty_ldisc___34 *ldisc;
	struct mutex atomic_write_lock;
	struct mutex legacy_mutex;
	struct mutex throttle_mutex;
	struct rw_semaphore___281 termios_rwsem;
	struct mutex winsize_mutex;
	spinlock_t ctrl_lock;
	spinlock_t flow_lock;
	struct ktermios termios;
	struct ktermios termios_locked;
	struct termiox *termiox;
	char name[64];
	struct pid___193 *pgrp;
	struct pid___193 *session;
	long unsigned int flags;
	int count;
	struct winsize winsize;
	long unsigned int stopped: 1;
	long unsigned int flow_stopped: 1;
	int: 30;
	long unsigned int unused: 62;
	int hw_stopped;
	long unsigned int ctrl_status: 8;
	long unsigned int packet: 1;
	int: 23;
	long unsigned int unused_ctrl: 55;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___34 *link;
	struct fasync_struct___279 *fasync;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	spinlock_t files_lock;
	struct list_head tty_files;
	int closing;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___34 *port;
};

struct tty_port_operations___34;

struct tty_port_client_operations___34;

struct tty_port___34 {
	struct tty_bufhead buf;
	struct tty_struct___34 *tty;
	struct tty_struct___34 *itty;
	const struct tty_port_operations___34 *ops;
	const struct tty_port_client_operations___34 *client_ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	unsigned char low_latency: 1;
	struct mutex mutex;
	struct mutex buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
	void *client_data;
};

struct tty_ldisc_ops___34 {
	int magic;
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___34 *);
	void (*close)(struct tty_struct___34 *);
	void (*flush_buffer)(struct tty_struct___34 *);
	ssize_t (*read)(struct tty_struct___34 *, struct file___280 *, unsigned char *, size_t);
	ssize_t (*write)(struct tty_struct___34 *, struct file___280 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___34 *, struct file___280 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___34 *, struct file___280 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___34 *, struct ktermios *);
	__poll_t (*poll)(struct tty_struct___34 *, struct file___280 *, struct poll_table_struct___6 *);
	int (*hangup)(struct tty_struct___34 *);
	void (*receive_buf)(struct tty_struct___34 *, const unsigned char *, char *, int);
	void (*write_wakeup)(struct tty_struct___34 *);
	void (*dcd_change)(struct tty_struct___34 *, unsigned int);
	int (*receive_buf2)(struct tty_struct___34 *, const unsigned char *, char *, int);
	struct module___226 *owner;
	int refcount;
};

struct tty_ldisc___34 {
	struct tty_ldisc_ops___34 *ops;
	struct tty_struct___34 *tty;
};

struct tty_port_operations___34 {
	int (*carrier_raised)(struct tty_port___34 *);
	void (*dtr_rts)(struct tty_port___34 *, int);
	void (*shutdown)(struct tty_port___34 *);
	int (*activate)(struct tty_port___34 *, struct tty_struct___34 *);
	void (*destruct)(struct tty_port___34 *);
};

struct tty_port_client_operations___34 {
	int (*receive_buf)(struct tty_port___34 *, const unsigned char *, const unsigned char *, size_t);
	void (*write_wakeup)(struct tty_port___34 *);
};

struct uart_port___9;

struct uart_ops___9 {
	unsigned int (*tx_empty)(struct uart_port___9 *);
	void (*set_mctrl)(struct uart_port___9 *, unsigned int);
	unsigned int (*get_mctrl)(struct uart_port___9 *);
	void (*stop_tx)(struct uart_port___9 *);
	void (*start_tx)(struct uart_port___9 *);
	void (*throttle)(struct uart_port___9 *);
	void (*unthrottle)(struct uart_port___9 *);
	void (*send_xchar)(struct uart_port___9 *, char);
	void (*stop_rx)(struct uart_port___9 *);
	void (*enable_ms)(struct uart_port___9 *);
	void (*break_ctl)(struct uart_port___9 *, int);
	int (*startup)(struct uart_port___9 *);
	void (*shutdown)(struct uart_port___9 *);
	void (*flush_buffer)(struct uart_port___9 *);
	void (*set_termios)(struct uart_port___9 *, struct ktermios *, struct ktermios *);
	void (*set_ldisc)(struct uart_port___9 *, struct ktermios *);
	void (*pm)(struct uart_port___9 *, unsigned int, unsigned int);
	const char * (*type)(struct uart_port___9 *);
	void (*release_port)(struct uart_port___9 *);
	int (*request_port)(struct uart_port___9 *);
	void (*config_port)(struct uart_port___9 *, int);
	int (*verify_port)(struct uart_port___9 *, struct serial_struct *);
	int (*ioctl)(struct uart_port___9 *, unsigned int, long unsigned int);
	int (*poll_init)(struct uart_port___9 *);
	void (*poll_put_char)(struct uart_port___9 *, unsigned char);
	int (*poll_get_char)(struct uart_port___9 *);
};

struct uart_state___9;

struct uart_port___9 {
	spinlock_t lock;
	long unsigned int iobase;
	unsigned char *membase;
	unsigned int (*serial_in)(struct uart_port___9 *, int);
	void (*serial_out)(struct uart_port___9 *, int, int);
	void (*set_termios)(struct uart_port___9 *, struct ktermios *, struct ktermios *);
	void (*set_ldisc)(struct uart_port___9 *, struct ktermios *);
	unsigned int (*get_mctrl)(struct uart_port___9 *);
	void (*set_mctrl)(struct uart_port___9 *, unsigned int);
	int (*startup)(struct uart_port___9 *);
	void (*shutdown)(struct uart_port___9 *);
	void (*throttle)(struct uart_port___9 *);
	void (*unthrottle)(struct uart_port___9 *);
	int (*handle_irq)(struct uart_port___9 *);
	void (*pm)(struct uart_port___9 *, unsigned int, unsigned int);
	void (*handle_break)(struct uart_port___9 *);
	int (*rs485_config)(struct uart_port___9 *, struct serial_rs485 *);
	unsigned int irq;
	long unsigned int irqflags;
	unsigned int uartclk;
	unsigned int fifosize;
	unsigned char x_char;
	unsigned char regshift;
	unsigned char iotype;
	unsigned char quirks;
	unsigned int read_status_mask;
	unsigned int ignore_status_mask;
	struct uart_state___9 *state;
	struct uart_icount icount;
	struct console___11 *cons;
	long unsigned int sysrq;
	upf_t flags;
	upstat_t status;
	int hw_stopped;
	unsigned int mctrl;
	unsigned int timeout;
	unsigned int type;
	const struct uart_ops___9 *ops;
	unsigned int custom_divisor;
	unsigned int line;
	unsigned int minor;
	resource_size_t mapbase;
	resource_size_t mapsize;
	struct device___242 *dev;
	unsigned char hub6;
	unsigned char suspended;
	unsigned char unused[2];
	const char *name;
	struct attribute_group___244 *attr_group;
	const struct attribute_group___244 **tty_groups;
	struct serial_rs485 rs485;
	void *private_data;
};

struct uart_state___9 {
	struct tty_port___34 port;
	enum uart_pm_state pm_state;
	struct circ_buf xmit;
	atomic_t refcount;
	wait_queue_head_t remove_wait;
	struct uart_port___9 *uart_port;
};

struct earlycon_device___9 {
	struct console___11 *con;
	struct uart_port___9 port;
	char options[16];
	unsigned int baud;
};

struct earlycon_id___9 {
	char name[15];
	char name_term;
	char compatible[128];
	int (*setup)(struct earlycon_device___9 *, const char *);
};

struct uart_8250_port___4;

struct uart_8250_ops___4 {
	int (*setup_irq)(struct uart_8250_port___4 *);
	void (*release_irq)(struct uart_8250_port___4 *);
};

struct uart_8250_dma___4;

struct uart_8250_em485___4;

struct uart_8250_port___4 {
	struct uart_port___9 port;
	struct timer_list timer;
	struct list_head list;
	u32 capabilities;
	short unsigned int bugs;
	bool fifo_bug;
	unsigned int tx_loadsz;
	unsigned char acr;
	unsigned char fcr;
	unsigned char ier;
	unsigned char lcr;
	unsigned char mcr;
	unsigned char mcr_mask;
	unsigned char mcr_force;
	unsigned char cur_iotype;
	unsigned int rpm_tx_active;
	unsigned char canary;
	unsigned char probe;
	unsigned char lsr_saved_flags;
	unsigned char msr_saved_flags;
	struct uart_8250_dma___4 *dma;
	const struct uart_8250_ops___4 *ops;
	int (*dl_read)(struct uart_8250_port___4 *);
	void (*dl_write)(struct uart_8250_port___4 *, int);
	struct uart_8250_em485___4 *em485;
};

struct uart_8250_em485___4 {
	struct hrtimer start_tx_timer;
	struct hrtimer stop_tx_timer;
	struct hrtimer *active_timer;
	struct uart_8250_port___4 *port;
};

struct dma_chan___5;

typedef bool (*dma_filter_fn___5)(struct dma_chan___5 *, void *);

struct uart_8250_dma___4 {
	int (*tx_dma)(struct uart_8250_port___4 *);
	int (*rx_dma)(struct uart_8250_port___4 *);
	dma_filter_fn___5 fn;
	void *rx_param;
	void *tx_param;
	struct dma_slave_config rxconf;
	struct dma_slave_config txconf;
	struct dma_chan___5 *rxchan;
	struct dma_chan___5 *txchan;
	phys_addr_t rx_dma_addr;
	phys_addr_t tx_dma_addr;
	dma_addr_t rx_addr;
	dma_addr_t tx_addr;
	dma_cookie_t rx_cookie;
	dma_cookie_t tx_cookie;
	void *rx_buf;
	size_t rx_size;
	size_t tx_size;
	unsigned char tx_running;
	unsigned char tx_err;
	unsigned char rx_running;
};

struct dma_router___5 {
	struct device___242 *dev;
	void (*route_free)(struct device___242 *, void *);
};

struct dma_device___5;

struct dma_chan_dev___5;

struct dma_chan___5 {
	struct dma_device___5 *device;
	dma_cookie_t cookie;
	dma_cookie_t completed_cookie;
	int chan_id;
	struct dma_chan_dev___5 *dev;
	struct list_head device_node;
	struct dma_chan_percpu *local;
	int client_count;
	int table_count;
	struct dma_router___5 *router;
	void *route_data;
	void *private;
};

struct dma_filter___5 {
	dma_filter_fn___5 fn;
	int mapcnt;
	const struct dma_slave_map *map;
};

struct dma_async_tx_descriptor___5;

struct dma_device___5 {
	unsigned int chancnt;
	unsigned int privatecnt;
	struct list_head channels;
	struct list_head global_node;
	struct dma_filter___5 filter;
	dma_cap_mask_t cap_mask;
	short unsigned int max_xor;
	short unsigned int max_pq;
	enum dmaengine_alignment copy_align;
	enum dmaengine_alignment xor_align;
	enum dmaengine_alignment pq_align;
	enum dmaengine_alignment fill_align;
	int dev_id;
	struct device___242 *dev;
	u32 src_addr_widths;
	u32 dst_addr_widths;
	u32 directions;
	u32 max_burst;
	bool descriptor_reuse;
	enum dma_residue_granularity residue_granularity;
	int (*device_alloc_chan_resources)(struct dma_chan___5 *);
	void (*device_free_chan_resources)(struct dma_chan___5 *);
	struct dma_async_tx_descriptor___5 * (*device_prep_dma_memcpy)(struct dma_chan___5 *, dma_addr_t, dma_addr_t, size_t, long unsigned int);
	struct dma_async_tx_descriptor___5 * (*device_prep_dma_xor)(struct dma_chan___5 *, dma_addr_t, dma_addr_t *, unsigned int, size_t, long unsigned int);
	struct dma_async_tx_descriptor___5 * (*device_prep_dma_xor_val)(struct dma_chan___5 *, dma_addr_t *, unsigned int, size_t, enum sum_check_flags *, long unsigned int);
	struct dma_async_tx_descriptor___5 * (*device_prep_dma_pq)(struct dma_chan___5 *, dma_addr_t *, dma_addr_t *, unsigned int, const unsigned char *, size_t, long unsigned int);
	struct dma_async_tx_descriptor___5 * (*device_prep_dma_pq_val)(struct dma_chan___5 *, dma_addr_t *, dma_addr_t *, unsigned int, const unsigned char *, size_t, enum sum_check_flags *, long unsigned int);
	struct dma_async_tx_descriptor___5 * (*device_prep_dma_memset)(struct dma_chan___5 *, dma_addr_t, int, size_t, long unsigned int);
	struct dma_async_tx_descriptor___5 * (*device_prep_dma_memset_sg)(struct dma_chan___5 *, struct scatterlist *, unsigned int, int, long unsigned int);
	struct dma_async_tx_descriptor___5 * (*device_prep_dma_interrupt)(struct dma_chan___5 *, long unsigned int);
	struct dma_async_tx_descriptor___5 * (*device_prep_slave_sg)(struct dma_chan___5 *, struct scatterlist *, unsigned int, enum dma_transfer_direction, long unsigned int, void *);
	struct dma_async_tx_descriptor___5 * (*device_prep_dma_cyclic)(struct dma_chan___5 *, dma_addr_t, size_t, size_t, enum dma_transfer_direction, long unsigned int);
	struct dma_async_tx_descriptor___5 * (*device_prep_interleaved_dma)(struct dma_chan___5 *, struct dma_interleaved_template *, long unsigned int);
	struct dma_async_tx_descriptor___5 * (*device_prep_dma_imm_data)(struct dma_chan___5 *, dma_addr_t, u64, long unsigned int);
	int (*device_config)(struct dma_chan___5 *, struct dma_slave_config *);
	int (*device_pause)(struct dma_chan___5 *);
	int (*device_resume)(struct dma_chan___5 *);
	int (*device_terminate_all)(struct dma_chan___5 *);
	void (*device_synchronize)(struct dma_chan___5 *);
	enum dma_status (*device_tx_status)(struct dma_chan___5 *, dma_cookie_t, struct dma_tx_state *);
	void (*device_issue_pending)(struct dma_chan___5 *);
};

struct dma_chan_dev___5 {
	struct dma_chan___5 *chan;
	struct device___242 device;
	int dev_id;
	atomic_t *idr_ref;
};

struct dmaengine_unmap_data___5 {
	u8 map_cnt;
	u8 to_cnt;
	u8 from_cnt;
	u8 bidi_cnt;
	struct device___242 *dev;
	struct kref kref;
	size_t len;
	dma_addr_t addr[0];
};

struct dma_async_tx_descriptor___5 {
	dma_cookie_t cookie;
	enum dma_ctrl_flags flags;
	dma_addr_t phys;
	struct dma_chan___5 *chan;
	dma_cookie_t (*tx_submit)(struct dma_async_tx_descriptor___5 *);
	int (*desc_free)(struct dma_async_tx_descriptor___5 *);
	dma_async_tx_callback callback;
	dma_async_tx_callback_result callback_result;
	void *callback_param;
	struct dmaengine_unmap_data___5 *unmap;
};

struct of_serial_info {
	struct clk *clk;
	struct reset_control___2 *rst;
	int type;
	int line;
};

struct module___265;

struct file___325;

struct kiocb___325;

struct poll_table_struct___198;

struct vm_area_struct___326;

struct inode___325;

struct file_lock___325;

struct page___326;

struct seq_file___276;

struct file_operations___325 {
	struct module___265 *owner;
	loff_t (*llseek)(struct file___325 *, loff_t, int);
	ssize_t (*read)(struct file___325 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___325 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___325 *, struct iov_iter___140 *);
	ssize_t (*write_iter)(struct kiocb___325 *, struct iov_iter___140 *);
	int (*iopoll)(struct kiocb___325 *, bool);
	int (*iterate)(struct file___325 *, struct dir_context *);
	int (*iterate_shared)(struct file___325 *, struct dir_context *);
	__poll_t (*poll)(struct file___325 *, struct poll_table_struct___198 *);
	long int (*unlocked_ioctl)(struct file___325 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___325 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___325 *, struct vm_area_struct___326 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___325 *, struct file___325 *);
	int (*flush)(struct file___325 *, fl_owner_t);
	int (*release)(struct inode___325 *, struct file___325 *);
	int (*fsync)(struct file___325 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___325 *, int);
	int (*lock)(struct file___325 *, int, struct file_lock___325 *);
	ssize_t (*sendpage)(struct file___325 *, struct page___326 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___325 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___325 *, int, struct file_lock___325 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___325 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___325 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___325 *, long int, struct file_lock___325 **, void **);
	long int (*fallocate)(struct file___325 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___276 *, struct file___325 *);
	ssize_t (*copy_file_range)(struct file___325 *, loff_t, struct file___325 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___325 *, loff_t, struct file___325 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___325 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___325 {
	u64 seqnum;
	struct vm_area_struct___326 *vmas[4];
};

struct page_frag___325 {
	struct page___326 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___325;

struct cred___302;

struct vm_struct___236;

struct task_struct___326 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___326 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___325 *mm;
	struct mm_struct___325 *active_mm;
	struct vmacache___325 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___326 *real_parent;
	struct task_struct___326 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___326 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___207 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___207 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___207 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___302 *ptracer_cred;
	const struct cred___302 *real_cred;
	const struct cred___302 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___326 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___82 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___325 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___326 *oom_reaper_list;
	struct vm_struct___236 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___133 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___326 *pgtable_t___325;

struct address_space___324;

struct dev_pagemap___313;

struct page___326 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___324 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___326 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___325 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___325 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___313 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___325;

struct lruvec___325 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___325 *pgdat;
};

struct zone___325 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___325 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___325 {
	struct zone___325 *zone;
	int zone_idx;
};

struct zonelist___325 {
	struct zoneref___325 _zonerefs[25];
};

struct pglist_data___325 {
	struct zone___325 node_zones[3];
	struct zonelist___325 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___326 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___326 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___325 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___326 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___326 *owner;
};

struct secondary_data___326 {
	void *stack;
	struct task_struct___326 *task;
	long int status;
};

struct blocking_notifier_head___325 {
	struct rw_semaphore___326 rwsem;
	struct notifier_block *head;
};

struct dentry___324;

struct path___325 {
	struct vfsmount *mnt;
	struct dentry___324 *dentry;
};

struct file___325 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___325 f_path;
	struct inode___325 *f_inode;
	const struct file_operations___325 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___207 f_owner;
	const struct cred___302 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___324 *f_mapping;
	errseq_t f_wb_err;
};

struct key___302;

struct user_struct___302;

struct cred___302 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___302 *session_keyring;
	struct key___302 *process_keyring;
	struct key___302 *thread_keyring;
	struct key___302 *request_key_auth;
	void *security;
	struct user_struct___302 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___318;

struct kernfs_elem_dir___318 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___318 *root;
};

struct kernfs_node___319;

struct kernfs_syscall_ops___318;

struct kernfs_root___318 {
	struct kernfs_node___319 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___318 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___318 {
	struct kernfs_node___319 *target_kn;
};

struct kernfs_ops___318;

struct kernfs_elem_attr___318 {
	const struct kernfs_ops___318 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___319 *notify_next;
};

struct kernfs_node___319 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___319 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___318 dir;
		struct kernfs_elem_symlink___318 symlink;
		struct kernfs_elem_attr___318 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___318;

struct kernfs_ops___318 {
	int (*open)(struct kernfs_open_file___318 *);
	void (*release)(struct kernfs_open_file___318 *);
	int (*seq_show)(struct seq_file___276 *, void *);
	void * (*seq_start)(struct seq_file___276 *, loff_t *);
	void * (*seq_next)(struct seq_file___276 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___276 *, void *);
	ssize_t (*read)(struct kernfs_open_file___318 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___318 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___318 *, struct vm_area_struct___326 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___318 *, struct poll_table_struct___198 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___318 {
	int (*remount_fs)(struct kernfs_root___318 *, int *, char *);
	int (*show_options)(struct seq_file___276 *, struct kernfs_root___318 *);
	int (*mkdir)(struct kernfs_node___319 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___319 *);
	int (*rename)(struct kernfs_node___319 *, struct kernfs_node___319 *, const char *);
	int (*show_path)(struct seq_file___276 *, struct kernfs_node___319 *, struct kernfs_root___318 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___275;

struct seq_file___276 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___275 *op;
	int poll_event;
	const struct file___325 *file;
	void *private;
};

struct vm_operations_struct___313;

struct kernfs_open_file___318 {
	struct kernfs_node___319 *kn;
	struct file___325 *file;
	struct seq_file___276 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___313 *vm_ops;
};

struct vm_fault___313;

struct vm_operations_struct___313 {
	void (*open)(struct vm_area_struct___326 *);
	void (*close)(struct vm_area_struct___326 *);
	int (*split)(struct vm_area_struct___326 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___326 *);
	vm_fault_t (*fault)(struct vm_fault___313 *);
	vm_fault_t (*huge_fault)(struct vm_fault___313 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___313 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___326 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___313 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___313 *);
	int (*access)(struct vm_area_struct___326 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___326 *);
	int (*set_policy)(struct vm_area_struct___326 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___326 *, long unsigned int);
	struct page___326 * (*find_special_page)(struct vm_area_struct___326 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___203)(struct file___325 *, wait_queue_head_t *, struct poll_table_struct___198 *);

struct poll_table_struct___198 {
	poll_queue_proc___203 _qproc;
	__poll_t _key;
};

struct vm_area_struct___326 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___326 *vm_next;
	struct vm_area_struct___326 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___325 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___313 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___325 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___312;

struct bin_attribute___288;

struct attribute_group___289 {
	const char *name;
	umode_t (*is_visible)(struct kobject___312 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___312 *, struct bin_attribute___288 *, int);
	struct attribute **attrs;
	struct bin_attribute___288 **bin_attrs;
};

struct kset___311;

struct kobj_type___311;

struct kobject___312 {
	const char *name;
	struct list_head entry;
	struct kobject___312 *parent;
	struct kset___311 *kset;
	struct kobj_type___311 *ktype;
	struct kernfs_node___319 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___288 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___325 *, struct kobject___312 *, struct bin_attribute___288 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___325 *, struct kobject___312 *, struct bin_attribute___288 *, char *, loff_t, size_t);
	int (*mmap)(struct file___325 *, struct kobject___312 *, struct bin_attribute___288 *, struct vm_area_struct___326 *);
};

struct sysfs_ops___311 {
	ssize_t (*show)(struct kobject___312 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___312 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___311;

struct kset___311 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___312 kobj;
	const struct kset_uevent_ops___311 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___311 {
	void (*release)(struct kobject___312 *);
	const struct sysfs_ops___311 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___25 * (*child_ns_type)(struct kobject___312 *);
	const void * (*namespace)(struct kobject___312 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___311 {
	int (* const filter)(struct kset___311 *, struct kobject___312 *);
	const char * (* const name)(struct kset___311 *, struct kobject___312 *);
	int (* const uevent)(struct kset___311 *, struct kobject___312 *, struct kobj_uevent_env *);
};

struct kobj_attribute___303 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___312 *, struct kobj_attribute___303 *, char *);
	ssize_t (*store)(struct kobject___312 *, struct kobj_attribute___303 *, const char *, size_t);
};

struct kernel_param___262;

struct kernel_param_ops___262 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___262 *);
	int (*get)(char *, const struct kernel_param___262 *);
	void (*free)(void *);
};

struct kparam_array___262;

struct kernel_param___262 {
	const char *name;
	struct module___265 *mod;
	const struct kernel_param_ops___262 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___262 *arr;
	};
};

struct kparam_array___262 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___262 *ops;
	void *elem;
};

struct module_kobject___262 {
	struct kobject___312 kobj;
	struct module___265 *mod;
	struct kobject___312 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___262 {
	struct module___265 *mod;
	struct latch_tree_node node;
};

struct module_layout___262 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___262 mtn;
};

struct module_attribute___262;

struct module___265 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___262 mkobj;
	struct module_attribute___262 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___312 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___262 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___262 core_layout;
	struct module_layout___262 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___262 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___262 *, struct module_kobject___262 *, char *);
	ssize_t (*store)(struct module_attribute___262 *, struct module_kobject___262 *, const char *, size_t);
	void (*setup)(struct module___265 *, const char *);
	int (*test)(struct module___265 *);
	void (*free)(struct module___265 *);
};

struct consw___20 {
	struct module___265 *owner;
	const char * (*con_startup)();
	void (*con_init)(struct vc_data *, int);
	void (*con_deinit)(struct vc_data *);
	void (*con_clear)(struct vc_data *, int, int, int, int);
	void (*con_putc)(struct vc_data *, int, int, int);
	void (*con_putcs)(struct vc_data *, const short unsigned int *, int, int, int);
	void (*con_cursor)(struct vc_data *, int);
	bool (*con_scroll)(struct vc_data *, unsigned int, unsigned int, enum con_scroll, unsigned int);
	int (*con_switch)(struct vc_data *);
	int (*con_blank)(struct vc_data *, int, int);
	int (*con_font_set)(struct vc_data *, struct console_font *, unsigned int);
	int (*con_font_get)(struct vc_data *, struct console_font *);
	int (*con_font_default)(struct vc_data *, struct console_font *, char *);
	int (*con_font_copy)(struct vc_data *, int);
	int (*con_resize)(struct vc_data *, unsigned int, unsigned int, unsigned int);
	void (*con_set_palette)(struct vc_data *, const unsigned char *);
	void (*con_scrolldelta)(struct vc_data *, int);
	int (*con_set_origin)(struct vc_data *);
	void (*con_save_screen)(struct vc_data *);
	u8 (*con_build_attr)(struct vc_data *, u8, u8, u8, u8, u8, u8);
	void (*con_invert_region)(struct vc_data *, u16 *, int);
	u16 * (*con_screen_pos)(struct vc_data *, int);
	long unsigned int (*con_getxy)(struct vc_data *, long unsigned int, int *, int *);
	void (*con_flush_scrollback)(struct vc_data *);
	int (*con_debug_enter)(struct vc_data *);
	int (*con_debug_leave)(struct vc_data *);
};

struct tty_driver___35;

struct console___12 {
	char name[16];
	void (*write)(struct console___12 *, const char *, unsigned int);
	int (*read)(struct console___12 *, char *, unsigned int);
	struct tty_driver___35 * (*device)(struct console___12 *, int *);
	void (*unblank)();
	int (*setup)(struct console___12 *, char *);
	int (*match)(struct console___12 *, char *, int, char *);
	short int flags;
	short int index;
	int cflag;
	void *data;
	struct console___12 *next;
};

struct cdev___73;

struct tty_struct___35;

struct tty_port___35;

struct tty_operations___35;

struct tty_driver___35 {
	int magic;
	struct kref kref;
	struct cdev___73 **cdevs;
	struct module___265 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___35 *other;
	struct tty_struct___35 **ttys;
	struct tty_port___35 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___35 *ops;
	struct list_head tty_drivers;
};

struct device___291;

struct dev_pm_ops___291 {
	int (*prepare)(struct device___291 *);
	void (*complete)(struct device___291 *);
	int (*suspend)(struct device___291 *);
	int (*resume)(struct device___291 *);
	int (*freeze)(struct device___291 *);
	int (*thaw)(struct device___291 *);
	int (*poweroff)(struct device___291 *);
	int (*restore)(struct device___291 *);
	int (*suspend_late)(struct device___291 *);
	int (*resume_early)(struct device___291 *);
	int (*freeze_late)(struct device___291 *);
	int (*thaw_early)(struct device___291 *);
	int (*poweroff_late)(struct device___291 *);
	int (*restore_early)(struct device___291 *);
	int (*suspend_noirq)(struct device___291 *);
	int (*resume_noirq)(struct device___291 *);
	int (*freeze_noirq)(struct device___291 *);
	int (*thaw_noirq)(struct device___291 *);
	int (*poweroff_noirq)(struct device___291 *);
	int (*restore_noirq)(struct device___291 *);
	int (*runtime_suspend)(struct device___291 *);
	int (*runtime_resume)(struct device___291 *);
	int (*runtime_idle)(struct device___291 *);
};

struct dev_pm_info___291 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___3 *subsys_data;
	void (*set_latency_tolerance)(struct device___291 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___291;

struct bus_type___291;

struct device_driver___291;

struct dev_pm_domain___291;

struct dma_map_ops___95;

struct device_node___73;

struct fwnode_handle___220;

struct class___291;

struct device___291 {
	struct device___291 *parent;
	struct device_private *p;
	struct kobject___312 kobj;
	const char *init_name;
	const struct device_type___291 *type;
	struct mutex mutex;
	struct bus_type___291 *bus;
	struct device_driver___291 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___291 power;
	struct dev_pm_domain___291 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___95 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___73 *of_node;
	struct fwnode_handle___220 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___291 *class;
	const struct attribute_group___289 **groups;
	void (*release)(struct device___291 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___291 {
	struct dev_pm_ops___291 ops;
	void (*detach)(struct device___291 *, bool);
	int (*activate)(struct device___291 *);
	void (*sync)(struct device___291 *);
	void (*dismiss)(struct device___291 *);
};

struct user_struct___302 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___302 *uid_keyring;
	struct key___302 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___325;

struct mm_struct___325 {
	struct {
		struct vm_area_struct___326 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___325 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___326 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___325 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___326 *owner;
		struct user_namespace___3 *user_ns;
		struct file___325 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___325 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct vm_struct___236 {
	struct vm_struct___236 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___326 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bus_type___291 {
	const char *name;
	const char *dev_name;
	struct device___291 *dev_root;
	const struct attribute_group___289 **bus_groups;
	const struct attribute_group___289 **dev_groups;
	const struct attribute_group___289 **drv_groups;
	int (*match)(struct device___291 *, struct device_driver___291 *);
	int (*uevent)(struct device___291 *, struct kobj_uevent_env *);
	int (*probe)(struct device___291 *);
	int (*remove)(struct device___291 *);
	void (*shutdown)(struct device___291 *);
	int (*online)(struct device___291 *);
	int (*offline)(struct device___291 *);
	int (*suspend)(struct device___291 *, pm_message_t);
	int (*resume)(struct device___291 *);
	int (*num_vf)(struct device___291 *);
	int (*dma_configure)(struct device___291 *);
	const struct dev_pm_ops___291 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___291 {
	const char *name;
	struct bus_type___291 *bus;
	struct module___265 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___291 *);
	int (*remove)(struct device___291 *);
	void (*shutdown)(struct device___291 *);
	int (*suspend)(struct device___291 *, pm_message_t);
	int (*resume)(struct device___291 *);
	const struct attribute_group___289 **groups;
	const struct dev_pm_ops___291 *pm;
	void (*coredump)(struct device___291 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___291 {
	const char *name;
	const struct attribute_group___289 **groups;
	int (*uevent)(struct device___291 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___291 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___291 *);
	const struct dev_pm_ops___291 *pm;
};

struct class___291 {
	const char *name;
	struct module___265 *owner;
	const struct attribute_group___289 **class_groups;
	const struct attribute_group___289 **dev_groups;
	struct kobject___312 *dev_kobj;
	int (*dev_uevent)(struct device___291 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___291 *, umode_t *);
	void (*class_release)(struct class___291 *);
	void (*dev_release)(struct device___291 *);
	int (*shutdown_pre)(struct device___291 *);
	const struct kobj_ns_type_operations___25 *ns_type;
	const void * (*namespace)(struct device___291 *);
	const struct dev_pm_ops___291 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___95 {
	void * (*alloc)(struct device___291 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___291 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___291 *, struct vm_area_struct___326 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___291 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___291 *, struct page___326 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___291 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___291 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___291 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___291 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___291 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___291 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___291 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___291 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___291 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___291 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___291 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___291 *, u64);
	u64 (*get_required_mask)(struct device___291 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___220;

struct fwnode_handle___220 {
	struct fwnode_handle___220 *secondary;
	const struct fwnode_operations___220 *ops;
};

struct property___69;

struct device_node___73 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___220 fwnode;
	struct property___69 *properties;
	struct property___69 *deadprops;
	struct device_node___73 *parent;
	struct device_node___73 *child;
	struct device_node___73 *sibling;
	struct kobject___312 kobj;
	long unsigned int _flags;
	void *data;
};

struct dentry_operations___324;

struct super_block___324;

struct dentry___324 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___324 *d_parent;
	struct qstr d_name;
	struct inode___325 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___324 *d_op;
	struct super_block___324 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___324;

struct address_space___324 {
	struct inode___325 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___326 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___324 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___324;

struct block_device___324;

struct inode___325 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___324 *i_op;
	struct super_block___324 *i_sb;
	struct address_space___324 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___326 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___325 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___324 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___324 *i_bdev;
		struct cdev___73 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___324 {
	int (*d_revalidate)(struct dentry___324 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___324 *, unsigned int);
	int (*d_hash)(const struct dentry___324 *, struct qstr *);
	int (*d_compare)(const struct dentry___324 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___324 *);
	int (*d_init)(struct dentry___324 *);
	void (*d_release)(struct dentry___324 *);
	void (*d_prune)(struct dentry___324 *);
	void (*d_iput)(struct dentry___324 *, struct inode___325 *);
	char * (*d_dname)(struct dentry___324 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___325 *);
	int (*d_manage)(const struct path___325 *, bool);
	struct dentry___324 * (*d_real)(struct dentry___324 *, const struct inode___325 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___324;

struct mem_dqinfo___324 {
	struct quota_format_type___324 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___324;

struct quota_info___324 {
	unsigned int flags;
	struct rw_semaphore___326 dqio_sem;
	struct inode___325 *files[3];
	struct mem_dqinfo___324 info[3];
	const struct quota_format_ops___324 *ops[3];
};

struct rcuwait___324 {
	struct task_struct___326 *task;
};

struct percpu_rw_semaphore___324 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___326 rw_sem;
	struct rcuwait___324 writer;
	int readers_block;
};

struct sb_writers___324 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___324 rw_sem[3];
};

struct file_system_type___324;

struct super_operations___324;

struct dquot_operations___324;

struct quotactl_ops___324;

struct super_block___324 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___324 *s_type;
	const struct super_operations___324 *s_op;
	const struct dquot_operations___324 *dq_op;
	const struct quotactl_ops___324 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___324 *s_root;
	struct rw_semaphore___326 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___324 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___324 s_dquot;
	struct sb_writers___324 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___324 *s_d_op;
	int cleancache_poolid;
	struct shrinker___121 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

typedef int (*dev_page_fault_t___313)(struct vm_area_struct___326 *, long unsigned int, const struct page___326 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___313)(struct page___326 *, void *);

struct dev_pagemap___313 {
	dev_page_fault_t___313 page_fault;
	dev_page_free_t___313 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___291 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___325 {
	struct task_struct___326 *task;
	struct core_thread___325 *next;
};

struct core_state___325 {
	atomic_t nr_threads;
	struct core_thread___325 dumper;
	struct completion startup;
};

struct vm_fault___313 {
	struct vm_area_struct___326 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___326 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___326 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___325 prealloc_pte;
};

struct kiocb___325 {
	struct file___325 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___325 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___324 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___325 *ia_file;
};

struct dquot___324 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___324 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___324 {
	int qf_fmt_id;
	const struct quota_format_ops___324 *qf_ops;
	struct module___265 *qf_owner;
	struct quota_format_type___324 *qf_next;
};

struct quota_format_ops___324 {
	int (*check_quota_file)(struct super_block___324 *, int);
	int (*read_file_info)(struct super_block___324 *, int);
	int (*write_file_info)(struct super_block___324 *, int);
	int (*free_file_info)(struct super_block___324 *, int);
	int (*read_dqblk)(struct dquot___324 *);
	int (*commit_dqblk)(struct dquot___324 *);
	int (*release_dqblk)(struct dquot___324 *);
	int (*get_next_id)(struct super_block___324 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___324 {
	int (*write_dquot)(struct dquot___324 *);
	struct dquot___324 * (*alloc_dquot)(struct super_block___324 *, int);
	void (*destroy_dquot)(struct dquot___324 *);
	int (*acquire_dquot)(struct dquot___324 *);
	int (*release_dquot)(struct dquot___324 *);
	int (*mark_dirty)(struct dquot___324 *);
	int (*write_info)(struct super_block___324 *, int);
	qsize_t * (*get_reserved_space)(struct inode___325 *);
	int (*get_projid)(struct inode___325 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___325 *, qsize_t *);
	int (*get_next_id)(struct super_block___324 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___324 {
	int (*quota_on)(struct super_block___324 *, int, int, const struct path___325 *);
	int (*quota_off)(struct super_block___324 *, int);
	int (*quota_enable)(struct super_block___324 *, unsigned int);
	int (*quota_disable)(struct super_block___324 *, unsigned int);
	int (*quota_sync)(struct super_block___324 *, int);
	int (*set_info)(struct super_block___324 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___324 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___324 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___324 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___324 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___324 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___324 {
	int (*writepage)(struct page___326 *, struct writeback_control___3 *);
	int (*readpage)(struct file___325 *, struct page___326 *);
	int (*writepages)(struct address_space___324 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___326 *);
	int (*readpages)(struct file___325 *, struct address_space___324 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___325 *, struct address_space___324 *, loff_t, unsigned int, unsigned int, struct page___326 **, void **);
	int (*write_end)(struct file___325 *, struct address_space___324 *, loff_t, unsigned int, unsigned int, struct page___326 *, void *);
	sector_t (*bmap)(struct address_space___324 *, sector_t);
	void (*invalidatepage)(struct page___326 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___326 *, gfp_t);
	void (*freepage)(struct page___326 *);
	ssize_t (*direct_IO)(struct kiocb___325 *, struct iov_iter___140 *);
	int (*migratepage)(struct address_space___324 *, struct page___326 *, struct page___326 *, enum migrate_mode);
	bool (*isolate_page)(struct page___326 *, isolate_mode_t);
	void (*putback_page)(struct page___326 *);
	int (*launder_page)(struct page___326 *);
	int (*is_partially_uptodate)(struct page___326 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___326 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___324 *, struct page___326 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___325 *, sector_t *);
	void (*swap_deactivate)(struct file___325 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___324 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___325 *bd_inode;
	struct super_block___324 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___324 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___73 {
	struct kobject___312 kobj;
	struct module___265 *owner;
	const struct file_operations___325 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___324 {
	struct dentry___324 * (*lookup)(struct inode___325 *, struct dentry___324 *, unsigned int);
	const char * (*get_link)(struct dentry___324 *, struct inode___325 *, struct delayed_call *);
	int (*permission)(struct inode___325 *, int);
	struct posix_acl * (*get_acl)(struct inode___325 *, int);
	int (*readlink)(struct dentry___324 *, char *, int);
	int (*create)(struct inode___325 *, struct dentry___324 *, umode_t, bool);
	int (*link)(struct dentry___324 *, struct inode___325 *, struct dentry___324 *);
	int (*unlink)(struct inode___325 *, struct dentry___324 *);
	int (*symlink)(struct inode___325 *, struct dentry___324 *, const char *);
	int (*mkdir)(struct inode___325 *, struct dentry___324 *, umode_t);
	int (*rmdir)(struct inode___325 *, struct dentry___324 *);
	int (*mknod)(struct inode___325 *, struct dentry___324 *, umode_t, dev_t);
	int (*rename)(struct inode___325 *, struct dentry___324 *, struct inode___325 *, struct dentry___324 *, unsigned int);
	int (*setattr)(struct dentry___324 *, struct iattr___324 *);
	int (*getattr)(const struct path___325 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___324 *, char *, size_t);
	int (*fiemap)(struct inode___325 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___325 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___325 *, struct dentry___324 *, struct file___325 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___325 *, struct dentry___324 *, umode_t);
	int (*set_acl)(struct inode___325 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___324 {
	void (*fl_copy_lock)(struct file_lock___325 *, struct file_lock___325 *);
	void (*fl_release_private)(struct file_lock___325 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___324;

struct lock_manager_operations___324;

struct file_lock___325 {
	struct file_lock___325 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___325 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___324 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___324 *fl_ops;
	const struct lock_manager_operations___324 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___324 {
	int (*lm_compare_owner)(struct file_lock___325 *, struct file_lock___325 *);
	long unsigned int (*lm_owner_key)(struct file_lock___325 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___325 *);
	int (*lm_grant)(struct file_lock___325 *, int);
	bool (*lm_break)(struct file_lock___325 *);
	int (*lm_change)(struct file_lock___325 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___325 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___324 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___324 *fa_next;
	struct file___325 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___324 {
	const char *name;
	int fs_flags;
	struct dentry___324 * (*mount)(struct file_system_type___324 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___324 *);
	struct module___265 *owner;
	struct file_system_type___324 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___324 {
	struct inode___325 * (*alloc_inode)(struct super_block___324 *);
	void (*destroy_inode)(struct inode___325 *);
	void (*dirty_inode)(struct inode___325 *, int);
	int (*write_inode)(struct inode___325 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___325 *);
	void (*evict_inode)(struct inode___325 *);
	void (*put_super)(struct super_block___324 *);
	int (*sync_fs)(struct super_block___324 *, int);
	int (*freeze_super)(struct super_block___324 *);
	int (*freeze_fs)(struct super_block___324 *);
	int (*thaw_super)(struct super_block___324 *);
	int (*unfreeze_fs)(struct super_block___324 *);
	int (*statfs)(struct dentry___324 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___324 *, int *, char *);
	void (*umount_begin)(struct super_block___324 *);
	int (*show_options)(struct seq_file___276 *, struct dentry___324 *);
	int (*show_devname)(struct seq_file___276 *, struct dentry___324 *);
	int (*show_path)(struct seq_file___276 *, struct dentry___324 *);
	int (*show_stats)(struct seq_file___276 *, struct dentry___324 *);
	ssize_t (*quota_read)(struct super_block___324 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___324 *, int, const char *, size_t, loff_t);
	struct dquot___324 ** (*get_dquots)(struct inode___325 *);
	int (*bdev_try_to_free_page)(struct super_block___324 *, struct page___326 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___324 *, struct shrink_control___121 *);
	long int (*free_cached_objects)(struct super_block___324 *, struct shrink_control___121 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*key_restrict_link_func_t___303)(struct key___302 *, const struct key_type *, const union key_payload *, struct key___302 *);

struct key_restriction___302;

struct key___302 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___326 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___302 *restrict_link;
};

struct key_restriction___302 {
	key_restrict_link_func_t___303 check;
	struct key___302 *key;
	struct key_type *keytype;
};

struct seq_operations___275 {
	void * (*start)(struct seq_file___276 *, loff_t *);
	void (*stop)(struct seq_file___276 *, void *);
	void * (*next)(struct seq_file___276 *, void *, loff_t *);
	int (*show)(struct seq_file___276 *, void *);
};

struct tty_operations___35 {
	struct tty_struct___35 * (*lookup)(struct tty_driver___35 *, struct file___325 *, int);
	int (*install)(struct tty_driver___35 *, struct tty_struct___35 *);
	void (*remove)(struct tty_driver___35 *, struct tty_struct___35 *);
	int (*open)(struct tty_struct___35 *, struct file___325 *);
	void (*close)(struct tty_struct___35 *, struct file___325 *);
	void (*shutdown)(struct tty_struct___35 *);
	void (*cleanup)(struct tty_struct___35 *);
	int (*write)(struct tty_struct___35 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___35 *, unsigned char);
	void (*flush_chars)(struct tty_struct___35 *);
	int (*write_room)(struct tty_struct___35 *);
	int (*chars_in_buffer)(struct tty_struct___35 *);
	int (*ioctl)(struct tty_struct___35 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___35 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___35 *, struct ktermios *);
	void (*throttle)(struct tty_struct___35 *);
	void (*unthrottle)(struct tty_struct___35 *);
	void (*stop)(struct tty_struct___35 *);
	void (*start)(struct tty_struct___35 *);
	void (*hangup)(struct tty_struct___35 *);
	int (*break_ctl)(struct tty_struct___35 *, int);
	void (*flush_buffer)(struct tty_struct___35 *);
	void (*set_ldisc)(struct tty_struct___35 *);
	void (*wait_until_sent)(struct tty_struct___35 *, int);
	void (*send_xchar)(struct tty_struct___35 *, char);
	int (*tiocmget)(struct tty_struct___35 *);
	int (*tiocmset)(struct tty_struct___35 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___35 *, struct winsize *);
	int (*set_termiox)(struct tty_struct___35 *, struct termiox *);
	int (*get_icount)(struct tty_struct___35 *, struct serial_icounter_struct *);
	void (*show_fdinfo)(struct tty_struct___35 *, struct seq_file___276 *);
	int (*poll_init)(struct tty_driver___35 *, int, char *);
	int (*poll_get_char)(struct tty_driver___35 *, int);
	void (*poll_put_char)(struct tty_driver___35 *, int, char);
	int (*proc_show)(struct seq_file___276 *, void *);
};

struct tty_ldisc___35;

struct tty_struct___35 {
	int magic;
	struct kref kref;
	struct device___291 *dev;
	struct tty_driver___35 *driver;
	const struct tty_operations___35 *ops;
	int index;
	struct ld_semaphore ldisc_sem;
	struct tty_ldisc___35 *ldisc;
	struct mutex atomic_write_lock;
	struct mutex legacy_mutex;
	struct mutex throttle_mutex;
	struct rw_semaphore___326 termios_rwsem;
	struct mutex winsize_mutex;
	spinlock_t ctrl_lock;
	spinlock_t flow_lock;
	struct ktermios termios;
	struct ktermios termios_locked;
	struct termiox *termiox;
	char name[64];
	struct pid___207 *pgrp;
	struct pid___207 *session;
	long unsigned int flags;
	int count;
	struct winsize winsize;
	long unsigned int stopped: 1;
	long unsigned int flow_stopped: 1;
	int: 30;
	long unsigned int unused: 62;
	int hw_stopped;
	long unsigned int ctrl_status: 8;
	long unsigned int packet: 1;
	int: 23;
	long unsigned int unused_ctrl: 55;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___35 *link;
	struct fasync_struct___324 *fasync;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	spinlock_t files_lock;
	struct list_head tty_files;
	int closing;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___35 *port;
};

struct tty_port_operations___35;

struct tty_port_client_operations___35;

struct tty_port___35 {
	struct tty_bufhead buf;
	struct tty_struct___35 *tty;
	struct tty_struct___35 *itty;
	const struct tty_port_operations___35 *ops;
	const struct tty_port_client_operations___35 *client_ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	unsigned char low_latency: 1;
	struct mutex mutex;
	struct mutex buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
	void *client_data;
};

struct tty_ldisc_ops___35 {
	int magic;
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___35 *);
	void (*close)(struct tty_struct___35 *);
	void (*flush_buffer)(struct tty_struct___35 *);
	ssize_t (*read)(struct tty_struct___35 *, struct file___325 *, unsigned char *, size_t);
	ssize_t (*write)(struct tty_struct___35 *, struct file___325 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___35 *, struct file___325 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___35 *, struct file___325 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___35 *, struct ktermios *);
	__poll_t (*poll)(struct tty_struct___35 *, struct file___325 *, struct poll_table_struct___198 *);
	int (*hangup)(struct tty_struct___35 *);
	void (*receive_buf)(struct tty_struct___35 *, const unsigned char *, char *, int);
	void (*write_wakeup)(struct tty_struct___35 *);
	void (*dcd_change)(struct tty_struct___35 *, unsigned int);
	int (*receive_buf2)(struct tty_struct___35 *, const unsigned char *, char *, int);
	struct module___265 *owner;
	int refcount;
};

struct tty_ldisc___35 {
	struct tty_ldisc_ops___35 *ops;
	struct tty_struct___35 *tty;
};

struct tty_port_operations___35 {
	int (*carrier_raised)(struct tty_port___35 *);
	void (*dtr_rts)(struct tty_port___35 *, int);
	void (*shutdown)(struct tty_port___35 *);
	int (*activate)(struct tty_port___35 *, struct tty_struct___35 *);
	void (*destruct)(struct tty_port___35 *);
};

struct tty_port_client_operations___35 {
	int (*receive_buf)(struct tty_port___35 *, const unsigned char *, const unsigned char *, size_t);
	void (*write_wakeup)(struct tty_port___35 *);
};

struct uart_port___10;

struct uart_ops___10 {
	unsigned int (*tx_empty)(struct uart_port___10 *);
	void (*set_mctrl)(struct uart_port___10 *, unsigned int);
	unsigned int (*get_mctrl)(struct uart_port___10 *);
	void (*stop_tx)(struct uart_port___10 *);
	void (*start_tx)(struct uart_port___10 *);
	void (*throttle)(struct uart_port___10 *);
	void (*unthrottle)(struct uart_port___10 *);
	void (*send_xchar)(struct uart_port___10 *, char);
	void (*stop_rx)(struct uart_port___10 *);
	void (*enable_ms)(struct uart_port___10 *);
	void (*break_ctl)(struct uart_port___10 *, int);
	int (*startup)(struct uart_port___10 *);
	void (*shutdown)(struct uart_port___10 *);
	void (*flush_buffer)(struct uart_port___10 *);
	void (*set_termios)(struct uart_port___10 *, struct ktermios *, struct ktermios *);
	void (*set_ldisc)(struct uart_port___10 *, struct ktermios *);
	void (*pm)(struct uart_port___10 *, unsigned int, unsigned int);
	const char * (*type)(struct uart_port___10 *);
	void (*release_port)(struct uart_port___10 *);
	int (*request_port)(struct uart_port___10 *);
	void (*config_port)(struct uart_port___10 *, int);
	int (*verify_port)(struct uart_port___10 *, struct serial_struct *);
	int (*ioctl)(struct uart_port___10 *, unsigned int, long unsigned int);
	int (*poll_init)(struct uart_port___10 *);
	void (*poll_put_char)(struct uart_port___10 *, unsigned char);
	int (*poll_get_char)(struct uart_port___10 *);
};

struct uart_state___10;

struct uart_port___10 {
	spinlock_t lock;
	long unsigned int iobase;
	unsigned char *membase;
	unsigned int (*serial_in)(struct uart_port___10 *, int);
	void (*serial_out)(struct uart_port___10 *, int, int);
	void (*set_termios)(struct uart_port___10 *, struct ktermios *, struct ktermios *);
	void (*set_ldisc)(struct uart_port___10 *, struct ktermios *);
	unsigned int (*get_mctrl)(struct uart_port___10 *);
	void (*set_mctrl)(struct uart_port___10 *, unsigned int);
	int (*startup)(struct uart_port___10 *);
	void (*shutdown)(struct uart_port___10 *);
	void (*throttle)(struct uart_port___10 *);
	void (*unthrottle)(struct uart_port___10 *);
	int (*handle_irq)(struct uart_port___10 *);
	void (*pm)(struct uart_port___10 *, unsigned int, unsigned int);
	void (*handle_break)(struct uart_port___10 *);
	int (*rs485_config)(struct uart_port___10 *, struct serial_rs485 *);
	unsigned int irq;
	long unsigned int irqflags;
	unsigned int uartclk;
	unsigned int fifosize;
	unsigned char x_char;
	unsigned char regshift;
	unsigned char iotype;
	unsigned char quirks;
	unsigned int read_status_mask;
	unsigned int ignore_status_mask;
	struct uart_state___10 *state;
	struct uart_icount icount;
	struct console___12 *cons;
	long unsigned int sysrq;
	upf_t flags;
	upstat_t status;
	int hw_stopped;
	unsigned int mctrl;
	unsigned int timeout;
	unsigned int type;
	const struct uart_ops___10 *ops;
	unsigned int custom_divisor;
	unsigned int line;
	unsigned int minor;
	resource_size_t mapbase;
	resource_size_t mapsize;
	struct device___291 *dev;
	unsigned char hub6;
	unsigned char suspended;
	unsigned char unused[2];
	const char *name;
	struct attribute_group___289 *attr_group;
	const struct attribute_group___289 **tty_groups;
	struct serial_rs485 rs485;
	void *private_data;
};

struct uart_state___10 {
	struct tty_port___35 port;
	enum uart_pm_state pm_state;
	struct circ_buf xmit;
	atomic_t refcount;
	wait_queue_head_t remove_wait;
	struct uart_port___10 *uart_port;
};

struct uart_driver___3 {
	struct module___265 *owner;
	const char *driver_name;
	const char *dev_name;
	int major;
	int minor;
	int nr;
	struct console___12 *cons;
	struct uart_state___10 *state;
	struct tty_driver___35 *tty_driver;
};

struct earlycon_device___10 {
	struct console___12 *con;
	struct uart_port___10 port;
	char options[16];
	unsigned int baud;
};

struct earlycon_id___10 {
	char name[15];
	char name_term;
	char compatible[128];
	int (*setup)(struct earlycon_device___10 *, const char *);
};

struct amba_device___5 {
	struct device___291 dev;
	struct resource res;
	struct clk *pclk;
	unsigned int periphid;
	unsigned int irq[9];
	char *driver_override;
};

struct amba_driver___4 {
	struct device_driver___291 drv;
	int (*probe)(struct amba_device___5 *, const struct amba_id *);
	int (*remove)(struct amba_device___5 *);
	void (*shutdown)(struct amba_device___5 *);
	const struct amba_id *id_table;
};

enum amba_vendor {
	AMBA_VENDOR_ARM = 65,
	AMBA_VENDOR_ST = 128,
	AMBA_VENDOR_QCOM = 81,
	AMBA_VENDOR_LSI = 182,
	AMBA_VENDOR_LINUX = 254,
};

struct dma_chan___6;

struct amba_pl011_data {
	bool (*dma_filter)(struct dma_chan___6 *, void *);
	void *dma_rx_param;
	void *dma_tx_param;
	bool dma_rx_poll_enable;
	unsigned int dma_rx_poll_rate;
	unsigned int dma_rx_poll_timeout;
	void (*init)();
	void (*exit)();
};

struct dma_device___6;

struct dma_chan_dev___6;

struct dma_router___6;

struct dma_chan___6 {
	struct dma_device___6 *device;
	dma_cookie_t cookie;
	dma_cookie_t completed_cookie;
	int chan_id;
	struct dma_chan_dev___6 *dev;
	struct list_head device_node;
	struct dma_chan_percpu *local;
	int client_count;
	int table_count;
	struct dma_router___6 *router;
	void *route_data;
	void *private;
};

typedef void compound_page_dtor___313(struct page___326 *);

struct fwnode_reference_args___220;

struct fwnode_endpoint___220;

struct fwnode_operations___220 {
	struct fwnode_handle___220 * (*get)(struct fwnode_handle___220 *);
	void (*put)(struct fwnode_handle___220 *);
	bool (*device_is_available)(const struct fwnode_handle___220 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___220 *, const struct device___291 *);
	bool (*property_present)(const struct fwnode_handle___220 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___220 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___220 *, const char *, const char **, size_t);
	struct fwnode_handle___220 * (*get_parent)(const struct fwnode_handle___220 *);
	struct fwnode_handle___220 * (*get_next_child_node)(const struct fwnode_handle___220 *, struct fwnode_handle___220 *);
	struct fwnode_handle___220 * (*get_named_child_node)(const struct fwnode_handle___220 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___220 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___220 *);
	struct fwnode_handle___220 * (*graph_get_next_endpoint)(const struct fwnode_handle___220 *, struct fwnode_handle___220 *);
	struct fwnode_handle___220 * (*graph_get_remote_endpoint)(const struct fwnode_handle___220 *);
	struct fwnode_handle___220 * (*graph_get_port_parent)(struct fwnode_handle___220 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___220 *, struct fwnode_endpoint___220 *);
};

struct fwnode_endpoint___220 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___220 *local_fwnode;
};

struct fwnode_reference_args___220 {
	struct fwnode_handle___220 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct dma_router___6 {
	struct device___291 *dev;
	void (*route_free)(struct device___291 *, void *);
};

typedef bool (*dma_filter_fn___6)(struct dma_chan___6 *, void *);

struct dma_filter___6 {
	dma_filter_fn___6 fn;
	int mapcnt;
	const struct dma_slave_map *map;
};

struct dma_async_tx_descriptor___6;

struct dma_device___6 {
	unsigned int chancnt;
	unsigned int privatecnt;
	struct list_head channels;
	struct list_head global_node;
	struct dma_filter___6 filter;
	dma_cap_mask_t cap_mask;
	short unsigned int max_xor;
	short unsigned int max_pq;
	enum dmaengine_alignment copy_align;
	enum dmaengine_alignment xor_align;
	enum dmaengine_alignment pq_align;
	enum dmaengine_alignment fill_align;
	int dev_id;
	struct device___291 *dev;
	u32 src_addr_widths;
	u32 dst_addr_widths;
	u32 directions;
	u32 max_burst;
	bool descriptor_reuse;
	enum dma_residue_granularity residue_granularity;
	int (*device_alloc_chan_resources)(struct dma_chan___6 *);
	void (*device_free_chan_resources)(struct dma_chan___6 *);
	struct dma_async_tx_descriptor___6 * (*device_prep_dma_memcpy)(struct dma_chan___6 *, dma_addr_t, dma_addr_t, size_t, long unsigned int);
	struct dma_async_tx_descriptor___6 * (*device_prep_dma_xor)(struct dma_chan___6 *, dma_addr_t, dma_addr_t *, unsigned int, size_t, long unsigned int);
	struct dma_async_tx_descriptor___6 * (*device_prep_dma_xor_val)(struct dma_chan___6 *, dma_addr_t *, unsigned int, size_t, enum sum_check_flags *, long unsigned int);
	struct dma_async_tx_descriptor___6 * (*device_prep_dma_pq)(struct dma_chan___6 *, dma_addr_t *, dma_addr_t *, unsigned int, const unsigned char *, size_t, long unsigned int);
	struct dma_async_tx_descriptor___6 * (*device_prep_dma_pq_val)(struct dma_chan___6 *, dma_addr_t *, dma_addr_t *, unsigned int, const unsigned char *, size_t, enum sum_check_flags *, long unsigned int);
	struct dma_async_tx_descriptor___6 * (*device_prep_dma_memset)(struct dma_chan___6 *, dma_addr_t, int, size_t, long unsigned int);
	struct dma_async_tx_descriptor___6 * (*device_prep_dma_memset_sg)(struct dma_chan___6 *, struct scatterlist *, unsigned int, int, long unsigned int);
	struct dma_async_tx_descriptor___6 * (*device_prep_dma_interrupt)(struct dma_chan___6 *, long unsigned int);
	struct dma_async_tx_descriptor___6 * (*device_prep_slave_sg)(struct dma_chan___6 *, struct scatterlist *, unsigned int, enum dma_transfer_direction, long unsigned int, void *);
	struct dma_async_tx_descriptor___6 * (*device_prep_dma_cyclic)(struct dma_chan___6 *, dma_addr_t, size_t, size_t, enum dma_transfer_direction, long unsigned int);
	struct dma_async_tx_descriptor___6 * (*device_prep_interleaved_dma)(struct dma_chan___6 *, struct dma_interleaved_template *, long unsigned int);
	struct dma_async_tx_descriptor___6 * (*device_prep_dma_imm_data)(struct dma_chan___6 *, dma_addr_t, u64, long unsigned int);
	int (*device_config)(struct dma_chan___6 *, struct dma_slave_config *);
	int (*device_pause)(struct dma_chan___6 *);
	int (*device_resume)(struct dma_chan___6 *);
	int (*device_terminate_all)(struct dma_chan___6 *);
	void (*device_synchronize)(struct dma_chan___6 *);
	enum dma_status (*device_tx_status)(struct dma_chan___6 *, dma_cookie_t, struct dma_tx_state *);
	void (*device_issue_pending)(struct dma_chan___6 *);
};

struct dma_chan_dev___6 {
	struct dma_chan___6 *chan;
	struct device___291 device;
	int dev_id;
	atomic_t *idr_ref;
};

struct dmaengine_unmap_data___6 {
	u8 map_cnt;
	u8 to_cnt;
	u8 from_cnt;
	u8 bidi_cnt;
	struct device___291 *dev;
	struct kref kref;
	size_t len;
	dma_addr_t addr[0];
};

struct dma_async_tx_descriptor___6 {
	dma_cookie_t cookie;
	enum dma_ctrl_flags flags;
	dma_addr_t phys;
	struct dma_chan___6 *chan;
	dma_cookie_t (*tx_submit)(struct dma_async_tx_descriptor___6 *);
	int (*desc_free)(struct dma_async_tx_descriptor___6 *);
	dma_async_tx_callback callback;
	dma_async_tx_callback_result callback_result;
	void *callback_param;
	struct dmaengine_unmap_data___6 *unmap;
};

struct property___69 {
	char *name;
	int length;
	void *value;
	struct property___69 *next;
	long unsigned int _flags;
	struct bin_attribute___288 attr;
};

struct node___190 {
	struct device___291 dev;
};

struct platform_device___17 {
	const char *name;
	int id;
	bool id_auto;
	struct device___291 dev;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct platform_driver___15 {
	int (*probe)(struct platform_device___17 *);
	int (*remove)(struct platform_device___17 *);
	void (*shutdown)(struct platform_device___17 *);
	int (*suspend)(struct platform_device___17 *, pm_message_t);
	int (*resume)(struct platform_device___17 *);
	struct device_driver___291 driver;
	const struct platform_device_id *id_table;
	bool prevent_deferred_probe;
};

enum {
	REG_DR = 0,
	REG_ST_DMAWM = 1,
	REG_ST_TIMEOUT = 2,
	REG_FR = 3,
	REG_LCRH_RX = 4,
	REG_LCRH_TX = 5,
	REG_IBRD = 6,
	REG_FBRD = 7,
	REG_CR = 8,
	REG_IFLS = 9,
	REG_IMSC = 10,
	REG_RIS = 11,
	REG_MIS = 12,
	REG_ICR = 13,
	REG_DMACR = 14,
	REG_ST_XFCR = 15,
	REG_ST_XON1 = 16,
	REG_ST_XON2 = 17,
	REG_ST_XOFF1 = 18,
	REG_ST_XOFF2 = 19,
	REG_ST_ITCR = 20,
	REG_ST_ITIP = 21,
	REG_ST_ABCR = 22,
	REG_ST_ABIMSC = 23,
	REG_ARRAY_SIZE = 24,
};

struct vendor_data {
	const u16 *reg_offset;
	unsigned int ifls;
	unsigned int fr_busy;
	unsigned int fr_dsr;
	unsigned int fr_cts;
	unsigned int fr_ri;
	unsigned int inv_fr;
	bool access_32b;
	bool oversampling;
	bool dma_threshold;
	bool cts_event_workaround;
	bool always_enabled;
	bool fixed_options;
	unsigned int (*get_fifosize)(struct amba_device___5 *);
};

struct pl011_sgbuf {
	struct scatterlist sg;
	char *buf;
};

struct pl011_dmarx_data {
	struct dma_chan___6 *chan;
	struct completion complete;
	bool use_buf_b;
	struct pl011_sgbuf sgbuf_a;
	struct pl011_sgbuf sgbuf_b;
	dma_cookie_t cookie;
	bool running;
	struct timer_list timer;
	unsigned int last_residue;
	long unsigned int last_jiffies;
	bool auto_poll_rate;
	unsigned int poll_rate;
	unsigned int poll_timeout;
};

struct pl011_dmatx_data {
	struct dma_chan___6 *chan;
	struct scatterlist sg;
	char *buf;
	bool queued;
};

struct uart_amba_port {
	struct uart_port___10 port;
	const u16 *reg_offset;
	struct clk *clk;
	const struct vendor_data *vendor;
	unsigned int dmacr;
	unsigned int im;
	unsigned int old_status;
	unsigned int fifosize;
	unsigned int old_cr;
	unsigned int fixed_baud;
	char type[12];
	bool using_tx_dma;
	bool using_rx_dma;
	struct pl011_dmarx_data dmarx;
	struct pl011_dmatx_data dmatx;
	bool dma_probed;
};

struct vc_data___7;

struct consw___21 {
	struct module___263 *owner;
	const char * (*con_startup)();
	void (*con_init)(struct vc_data___7 *, int);
	void (*con_deinit)(struct vc_data___7 *);
	void (*con_clear)(struct vc_data___7 *, int, int, int, int);
	void (*con_putc)(struct vc_data___7 *, int, int, int);
	void (*con_putcs)(struct vc_data___7 *, const short unsigned int *, int, int, int);
	void (*con_cursor)(struct vc_data___7 *, int);
	bool (*con_scroll)(struct vc_data___7 *, unsigned int, unsigned int, enum con_scroll, unsigned int);
	int (*con_switch)(struct vc_data___7 *);
	int (*con_blank)(struct vc_data___7 *, int, int);
	int (*con_font_set)(struct vc_data___7 *, struct console_font *, unsigned int);
	int (*con_font_get)(struct vc_data___7 *, struct console_font *);
	int (*con_font_default)(struct vc_data___7 *, struct console_font *, char *);
	int (*con_font_copy)(struct vc_data___7 *, int);
	int (*con_resize)(struct vc_data___7 *, unsigned int, unsigned int, unsigned int);
	void (*con_set_palette)(struct vc_data___7 *, const unsigned char *);
	void (*con_scrolldelta)(struct vc_data___7 *, int);
	int (*con_set_origin)(struct vc_data___7 *);
	void (*con_save_screen)(struct vc_data___7 *);
	u8 (*con_build_attr)(struct vc_data___7 *, u8, u8, u8, u8, u8, u8);
	void (*con_invert_region)(struct vc_data___7 *, u16 *, int);
	u16 * (*con_screen_pos)(struct vc_data___7 *, int);
	long unsigned int (*con_getxy)(struct vc_data___7 *, long unsigned int, int *, int *);
	void (*con_flush_scrollback)(struct vc_data___7 *);
	int (*con_debug_enter)(struct vc_data___7 *);
	int (*con_debug_leave)(struct vc_data___7 *);
};

struct vc_data___7 {
	struct tty_port___29 port;
	short unsigned int vc_num;
	unsigned int vc_cols;
	unsigned int vc_rows;
	unsigned int vc_size_row;
	unsigned int vc_scan_lines;
	long unsigned int vc_origin;
	long unsigned int vc_scr_end;
	long unsigned int vc_visible_origin;
	unsigned int vc_top;
	unsigned int vc_bottom;
	const struct consw___21 *vc_sw;
	short unsigned int *vc_screenbuf;
	unsigned int vc_screenbuf_size;
	unsigned char vc_mode;
	unsigned char vc_attr;
	unsigned char vc_def_color;
	unsigned char vc_color;
	unsigned char vc_s_color;
	unsigned char vc_ulcolor;
	unsigned char vc_itcolor;
	unsigned char vc_halfcolor;
	unsigned int vc_cursor_type;
	short unsigned int vc_complement_mask;
	short unsigned int vc_s_complement_mask;
	unsigned int vc_x;
	unsigned int vc_y;
	unsigned int vc_saved_x;
	unsigned int vc_saved_y;
	long unsigned int vc_pos;
	short unsigned int vc_hi_font_mask;
	struct console_font vc_font;
	short unsigned int vc_video_erase_char;
	unsigned int vc_state;
	unsigned int vc_npar;
	unsigned int vc_par[16];
	struct vt_mode vt_mode;
	struct pid___207 *vt_pid;
	int vt_newvt;
	wait_queue_head_t paste_wait;
	unsigned int vc_charset: 1;
	unsigned int vc_s_charset: 1;
	unsigned int vc_disp_ctrl: 1;
	unsigned int vc_toggle_meta: 1;
	unsigned int vc_decscnm: 1;
	unsigned int vc_decom: 1;
	unsigned int vc_decawm: 1;
	unsigned int vc_deccm: 1;
	unsigned int vc_decim: 1;
	unsigned int vc_intensity: 2;
	unsigned int vc_italic: 1;
	unsigned int vc_underline: 1;
	unsigned int vc_blink: 1;
	unsigned int vc_reverse: 1;
	unsigned int vc_s_intensity: 2;
	unsigned int vc_s_italic: 1;
	unsigned int vc_s_underline: 1;
	unsigned int vc_s_blink: 1;
	unsigned int vc_s_reverse: 1;
	unsigned int vc_ques: 1;
	unsigned int vc_need_wrap: 1;
	unsigned int vc_can_do_color: 1;
	unsigned int vc_report_mouse: 2;
	unsigned char vc_utf: 1;
	unsigned char vc_utf_count;
	int vc_utf_char;
	unsigned int vc_tab_stop[8];
	unsigned char vc_palette[48];
	short unsigned int *vc_translate;
	unsigned char vc_G0_charset;
	unsigned char vc_G1_charset;
	unsigned char vc_saved_G0;
	unsigned char vc_saved_G1;
	unsigned int vc_resize_user;
	unsigned int vc_bell_pitch;
	unsigned int vc_bell_duration;
	short unsigned int vc_cur_blink_ms;
	struct vc_data___7 **vc_display_fg;
	struct uni_pagedir *vc_uni_pagedir;
	struct uni_pagedir **vc_uni_pagedir_loc;
};

struct console___13 {
	char name[16];
	void (*write)(struct console___13 *, const char *, unsigned int);
	int (*read)(struct console___13 *, char *, unsigned int);
	struct tty_driver___29 * (*device)(struct console___13 *, int *);
	void (*unblank)();
	int (*setup)(struct console___13 *, char *);
	int (*match)(struct console___13 *, char *, int, char *);
	short int flags;
	short int index;
	int cflag;
	void *data;
	struct console___13 *next;
};

struct vc___7 {
	struct vc_data___7 *d;
	struct work_struct SAK_work;
};

struct file___326;

struct kiocb___326;

struct iov_iter___141;

struct vm_area_struct___327;

struct inode___326;

struct file_lock___326;

struct page___327;

struct pipe_inode_info___69;

struct seq_file___277;

struct file_operations___326 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___326 *, loff_t, int);
	ssize_t (*read)(struct file___326 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___326 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___326 *, struct iov_iter___141 *);
	ssize_t (*write_iter)(struct kiocb___326 *, struct iov_iter___141 *);
	int (*iopoll)(struct kiocb___326 *, bool);
	int (*iterate)(struct file___326 *, struct dir_context *);
	int (*iterate_shared)(struct file___326 *, struct dir_context *);
	__poll_t (*poll)(struct file___326 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___326 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___326 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___326 *, struct vm_area_struct___327 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___326 *, struct file___326 *);
	int (*flush)(struct file___326 *, fl_owner_t);
	int (*release)(struct inode___326 *, struct file___326 *);
	int (*fsync)(struct file___326 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___326 *, int);
	int (*lock)(struct file___326 *, int, struct file_lock___326 *);
	ssize_t (*sendpage)(struct file___326 *, struct page___327 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___326 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___326 *, int, struct file_lock___326 *);
	ssize_t (*splice_write)(struct pipe_inode_info___69 *, struct file___326 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___326 *, loff_t *, struct pipe_inode_info___69 *, size_t, unsigned int);
	int (*setlease)(struct file___326 *, long int, struct file_lock___326 **, void **);
	long int (*fallocate)(struct file___326 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___277 *, struct file___326 *);
	ssize_t (*copy_file_range)(struct file___326 *, loff_t, struct file___326 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___326 *, loff_t, struct file___326 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___326 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___326 {
	u64 seqnum;
	struct vm_area_struct___327 *vmas[4];
};

struct page_frag___326 {
	struct page___327 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___326;

struct mem_cgroup___122;

struct pid___208;

struct cred___303;

struct nsproxy___258;

struct signal_struct___240;

struct bio_list___154;

struct backing_dev_info___154;

struct io_context___83;

struct css_set___214;

struct request_queue___79;

struct vm_struct___237;

struct task_struct___327 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___327 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___326 *mm;
	struct mm_struct___326 *active_mm;
	struct vmacache___326 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___327 *real_parent;
	struct task_struct___327 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___327 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___122 *active_memcg;
	long int rh_reserved2;
	struct pid___208 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___208 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___208 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___303 *ptracer_cred;
	const struct cred___303 *real_cred;
	const struct cred___303 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___258 *nsproxy;
	struct signal_struct___240 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___327 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___154 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___154 *backing_dev_info;
	struct io_context___83 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___214 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___69 *splice_pipe;
	struct page_frag___326 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___122 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___79 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___327 *oom_reaper_list;
	struct vm_struct___237 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___133 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___327 *pgtable_t___326;

struct address_space___325;

struct dev_pagemap___314;

struct page___327 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___325 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___327 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___326 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___326 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___314 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___122 *mem_cgroup;
};

struct pglist_data___326;

struct lruvec___326 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___326 *pgdat;
};

struct zone___326 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___326 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___326 {
	struct zone___326 *zone;
	int zone_idx;
};

struct zonelist___326 {
	struct zoneref___326 _zonerefs[25];
};

struct pglist_data___326 {
	struct zone___326 node_zones[3];
	struct zonelist___326 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___327 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___327 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___326 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___327 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___327 *owner;
};

struct secondary_data___327 {
	void *stack;
	struct task_struct___327 *task;
	long int status;
};

struct blocking_notifier_head___326 {
	struct rw_semaphore___327 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___314;

struct vm_area_struct___327 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___327 *vm_next;
	struct vm_area_struct___327 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___326 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___314 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___326 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___326;

struct user_namespace___229;

struct mm_struct___326 {
	struct {
		struct vm_area_struct___327 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___326 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___327 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___326 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___327 *owner;
		struct user_namespace___229 *user_ns;
		struct file___326 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___326 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___325;

struct address_space___325 {
	struct inode___326 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___327 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___325 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___314)(struct vm_area_struct___327 *, long unsigned int, const struct page___327 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___314)(struct page___327 *, void *);

struct device___292;

struct dev_pagemap___314 {
	dev_page_fault_t___314 page_fault;
	dev_page_free_t___314 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___292 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct cgroup___214;

struct cgroup_subsys___214;

struct cgroup_subsys_state___214 {
	struct cgroup___214 *cgroup;
	struct cgroup_subsys___214 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___214 *parent;
};

struct kernfs_node___320;

struct cgroup_file___214 {
	struct kernfs_node___320 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___122;

struct mem_cgroup___122 {
	struct cgroup_subsys_state___214 css;
	struct mem_cgroup_id___3 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___214 events_file;
	struct cgroup_file___214 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___327 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___122 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry___325;

struct path___326 {
	struct vfsmount *mnt;
	struct dentry___325 *dentry;
};

struct fown_struct___208 {
	rwlock_t lock;
	struct pid___208 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___326 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___326 f_path;
	struct inode___326 *f_inode;
	const struct file_operations___326 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___208 f_owner;
	const struct cred___303 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___325 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___314;

struct vm_operations_struct___314 {
	void (*open)(struct vm_area_struct___327 *);
	void (*close)(struct vm_area_struct___327 *);
	int (*split)(struct vm_area_struct___327 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___327 *);
	vm_fault_t (*fault)(struct vm_fault___314 *);
	vm_fault_t (*huge_fault)(struct vm_fault___314 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___314 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___327 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___314 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___314 *);
	int (*access)(struct vm_area_struct___327 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___327 *);
	int (*set_policy)(struct vm_area_struct___327 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___327 *, long unsigned int);
	struct page___327 * (*find_special_page)(struct vm_area_struct___327 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___326 {
	struct task_struct___327 *task;
	struct core_thread___326 *next;
};

struct core_state___326 {
	atomic_t nr_threads;
	struct core_thread___326 dumper;
	struct completion startup;
};

struct key___303;

struct ucounts___229;

struct user_namespace___229 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___229 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___9 ns;
	long unsigned int flags;
	struct key___303 *persistent_keyring_register;
	struct rw_semaphore___327 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___229 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___314 {
	struct vm_area_struct___327 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___327 *cow_page;
	struct mem_cgroup___122 *memcg;
	struct page___327 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___326 prealloc_pte;
};

struct shrink_control___122 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___122 *memcg;
};

struct shrinker___122 {
	long unsigned int (*count_objects)(struct shrinker___122 *, struct shrink_control___122 *);
	long unsigned int (*scan_objects)(struct shrinker___122 *, struct shrink_control___122 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct pid_namespace___208;

struct upid___208 {
	int nr;
	struct pid_namespace___208 *ns;
};

struct pid_namespace___208 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___327 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___208 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___325 *proc_self;
	struct dentry___325 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___229 *user_ns;
	struct ucounts___229 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___9 ns;
};

struct pid___208 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___208 numbers[1];
};

struct user_struct___303 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___303 *uid_keyring;
	struct key___303 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___303 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___303 *session_keyring;
	struct key___303 *process_keyring;
	struct key___303 *thread_keyring;
	struct key___303 *request_key_auth;
	void *security;
	struct user_struct___303 *user;
	struct user_namespace___229 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___214;

struct nsproxy___258 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___208 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___214 *cgroup_ns;
};

struct tty_struct___36;

struct signal_struct___240 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___327 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___327 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___208 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___208 *tty_old_pgrp;
	int leader;
	struct tty_struct___36 *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___326 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___208 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___154;

struct bio_list___154 {
	struct bio___154 *head;
	struct bio___154 *tail;
};

struct bdi_writeback_congested___154;

struct bdi_writeback___154 {
	struct backing_dev_info___154 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___154 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___214 *memcg_css;
	struct cgroup_subsys_state___214 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___154 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___154 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___292 *dev;
	struct device___292 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___325 *debug_dir;
	struct dentry___325 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___83;

struct io_context___83 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___83 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___214 {
	struct cgroup_subsys_state___214 *subsys[13];
	refcount_t refcount;
	struct css_set___214 *dom_cset;
	struct cgroup___214 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___214 *mg_src_cgrp;
	struct cgroup___214 *mg_dst_cgrp;
	struct css_set___214 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___325;

struct pipe_buffer___69;

struct pipe_inode_info___69 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___327 *tmp_page;
	struct fasync_struct___325 *fasync_readers;
	struct fasync_struct___325 *fasync_writers;
	struct pipe_buffer___69 *bufs;
	struct user_struct___303 *user;
};

typedef blk_qc_t make_request_fn___79(struct request_queue___79 *, struct bio___154 *);

struct request___79;

typedef int dma_drain_needed_fn___79(struct request___79 *);

struct kset___312;

struct kobj_type___312;

struct kobject___313 {
	const char *name;
	struct list_head entry;
	struct kobject___313 *parent;
	struct kset___312 *kset;
	struct kobj_type___312 *ktype;
	struct kernfs_node___320 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___79;

struct bsg_class_device___79 {
	struct device___292 *class_dev;
	int minor;
	struct request_queue___79 *queue;
	const struct bsg_ops___79 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___154 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___154 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___79;

struct blkcg_gq___55;

struct request_queue___79 {
	struct list_head queue_head;
	struct request___79 *last_merge;
	struct elevator_queue___79 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___79 *make_request_fn;
	dma_drain_needed_fn___79 *dma_drain_needed;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___154 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___313 kobj;
	struct kobject___313 *mq_kobj;
	struct blk_integrity integrity;
	struct device___292 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___55 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	struct bsg_class_device___79 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___154 bio_split;
	struct dentry___325 *debugfs_dir;
	struct dentry___325 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___237 {
	struct vm_struct___237 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___327 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___252 {
	struct task_struct___327 task;
	long unsigned int stack[8192];
};

struct dev_pm_info___292 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___3 *subsys_data;
	void (*set_latency_tolerance)(struct device___292 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___292;

struct bus_type___292;

struct device_driver___292;

struct dev_pm_domain___292;

struct fwnode_handle___221;

struct class___292;

struct attribute_group___290;

struct device___292 {
	struct device___292 *parent;
	struct device_private *p;
	struct kobject___313 kobj;
	const char *init_name;
	const struct device_type___292 *type;
	struct mutex mutex;
	struct bus_type___292 *bus;
	struct device_driver___292 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___292 power;
	struct dev_pm_domain___292 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___221 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___292 *class;
	const struct attribute_group___290 **groups;
	void (*release)(struct device___292 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___325;

struct super_block___325;

struct dentry___325 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___325 *d_parent;
	struct qstr d_name;
	struct inode___326 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___325 *d_op;
	struct super_block___325 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___325;

struct block_device___325;

struct cdev___74;

struct inode___326 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___325 *i_op;
	struct super_block___325 *i_sb;
	struct address_space___325 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___327 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___154 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___326 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___325 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___69 *i_pipe;
		struct block_device___325 *i_bdev;
		struct cdev___74 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___325 {
	int (*d_revalidate)(struct dentry___325 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___325 *, unsigned int);
	int (*d_hash)(const struct dentry___325 *, struct qstr *);
	int (*d_compare)(const struct dentry___325 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___325 *);
	int (*d_init)(struct dentry___325 *);
	void (*d_release)(struct dentry___325 *);
	void (*d_prune)(struct dentry___325 *);
	void (*d_iput)(struct dentry___325 *, struct inode___326 *);
	char * (*d_dname)(struct dentry___325 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___326 *);
	int (*d_manage)(const struct path___326 *, bool);
	struct dentry___325 * (*d_real)(struct dentry___325 *, const struct inode___326 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___325;

struct mem_dqinfo___325 {
	struct quota_format_type___325 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___325;

struct quota_info___325 {
	unsigned int flags;
	struct rw_semaphore___327 dqio_sem;
	struct inode___326 *files[3];
	struct mem_dqinfo___325 info[3];
	const struct quota_format_ops___325 *ops[3];
};

struct rcuwait___325 {
	struct task_struct___327 *task;
};

struct percpu_rw_semaphore___325 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___327 rw_sem;
	struct rcuwait___325 writer;
	int readers_block;
};

struct sb_writers___325 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___325 rw_sem[3];
};

struct file_system_type___325;

struct super_operations___325;

struct dquot_operations___325;

struct quotactl_ops___325;

struct xattr_handler___25;

struct super_block___325 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___325 *s_type;
	const struct super_operations___325 *s_op;
	const struct dquot_operations___325 *dq_op;
	const struct quotactl_ops___325 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___325 *s_root;
	struct rw_semaphore___327 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___25 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___325 *s_bdev;
	struct backing_dev_info___154 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___325 s_dquot;
	struct sb_writers___325 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___325 *s_d_op;
	int cleancache_poolid;
	struct shrinker___122 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___229 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct io_cq___83 {
	struct request_queue___79 *q;
	struct io_context___83 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___326 {
	struct file___326 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___326 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___325 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___326 *ia_file;
};

struct dquot___325 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___325 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___325 {
	int qf_fmt_id;
	const struct quota_format_ops___325 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___325 *qf_next;
};

struct quota_format_ops___325 {
	int (*check_quota_file)(struct super_block___325 *, int);
	int (*read_file_info)(struct super_block___325 *, int);
	int (*write_file_info)(struct super_block___325 *, int);
	int (*free_file_info)(struct super_block___325 *, int);
	int (*read_dqblk)(struct dquot___325 *);
	int (*commit_dqblk)(struct dquot___325 *);
	int (*release_dqblk)(struct dquot___325 *);
	int (*get_next_id)(struct super_block___325 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___325 {
	int (*write_dquot)(struct dquot___325 *);
	struct dquot___325 * (*alloc_dquot)(struct super_block___325 *, int);
	void (*destroy_dquot)(struct dquot___325 *);
	int (*acquire_dquot)(struct dquot___325 *);
	int (*release_dquot)(struct dquot___325 *);
	int (*mark_dirty)(struct dquot___325 *);
	int (*write_info)(struct super_block___325 *, int);
	qsize_t * (*get_reserved_space)(struct inode___326 *);
	int (*get_projid)(struct inode___326 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___326 *, qsize_t *);
	int (*get_next_id)(struct super_block___325 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___325 {
	int (*quota_on)(struct super_block___325 *, int, int, const struct path___326 *);
	int (*quota_off)(struct super_block___325 *, int);
	int (*quota_enable)(struct super_block___325 *, unsigned int);
	int (*quota_disable)(struct super_block___325 *, unsigned int);
	int (*quota_sync)(struct super_block___325 *, int);
	int (*set_info)(struct super_block___325 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___325 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___325 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___325 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___325 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___325 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___137;

struct swap_info_struct___80;

struct address_space_operations___325 {
	int (*writepage)(struct page___327 *, struct writeback_control___137 *);
	int (*readpage)(struct file___326 *, struct page___327 *);
	int (*writepages)(struct address_space___325 *, struct writeback_control___137 *);
	int (*set_page_dirty)(struct page___327 *);
	int (*readpages)(struct file___326 *, struct address_space___325 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___326 *, struct address_space___325 *, loff_t, unsigned int, unsigned int, struct page___327 **, void **);
	int (*write_end)(struct file___326 *, struct address_space___325 *, loff_t, unsigned int, unsigned int, struct page___327 *, void *);
	sector_t (*bmap)(struct address_space___325 *, sector_t);
	void (*invalidatepage)(struct page___327 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___327 *, gfp_t);
	void (*freepage)(struct page___327 *);
	ssize_t (*direct_IO)(struct kiocb___326 *, struct iov_iter___141 *);
	int (*migratepage)(struct address_space___325 *, struct page___327 *, struct page___327 *, enum migrate_mode);
	bool (*isolate_page)(struct page___327 *, isolate_mode_t);
	void (*putback_page)(struct page___327 *);
	int (*launder_page)(struct page___327 *);
	int (*is_partially_uptodate)(struct page___327 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___327 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___325 *, struct page___327 *);
	int (*swap_activate)(struct swap_info_struct___80 *, struct file___326 *, sector_t *);
	void (*swap_deactivate)(struct file___326 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___137 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___154 *wb;
	struct inode___326 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___155;

struct iov_iter___141 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___155 *bvec;
		struct pipe_inode_info___69 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct swap_info_struct___80 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___325 *bdev;
	struct file___326 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct hd_struct___80;

struct gendisk___80;

struct block_device___325 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___326 *bd_inode;
	struct super_block___325 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___325 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___80 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___80 *bd_disk;
	struct request_queue___79 *bd_queue;
	struct backing_dev_info___154 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct hd_struct___80 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___292 __dev;
	struct kobject___313 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___80;

struct block_device_operations___80;

struct gendisk___80 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___80 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___80 *part_tbl;
	struct hd_struct___80 part0;
	const struct block_device_operations___80 *fops;
	struct request_queue___79 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___327 lookup_sem;
	struct kobject___313 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___313 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___74 {
	struct kobject___313 kobj;
	struct module___11 *owner;
	const struct file_operations___326 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___325 {
	struct dentry___325 * (*lookup)(struct inode___326 *, struct dentry___325 *, unsigned int);
	const char * (*get_link)(struct dentry___325 *, struct inode___326 *, struct delayed_call *);
	int (*permission)(struct inode___326 *, int);
	struct posix_acl * (*get_acl)(struct inode___326 *, int);
	int (*readlink)(struct dentry___325 *, char *, int);
	int (*create)(struct inode___326 *, struct dentry___325 *, umode_t, bool);
	int (*link)(struct dentry___325 *, struct inode___326 *, struct dentry___325 *);
	int (*unlink)(struct inode___326 *, struct dentry___325 *);
	int (*symlink)(struct inode___326 *, struct dentry___325 *, const char *);
	int (*mkdir)(struct inode___326 *, struct dentry___325 *, umode_t);
	int (*rmdir)(struct inode___326 *, struct dentry___325 *);
	int (*mknod)(struct inode___326 *, struct dentry___325 *, umode_t, dev_t);
	int (*rename)(struct inode___326 *, struct dentry___325 *, struct inode___326 *, struct dentry___325 *, unsigned int);
	int (*setattr)(struct dentry___325 *, struct iattr___325 *);
	int (*getattr)(const struct path___326 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___325 *, char *, size_t);
	int (*fiemap)(struct inode___326 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___326 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___326 *, struct dentry___325 *, struct file___326 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___326 *, struct dentry___325 *, umode_t);
	int (*set_acl)(struct inode___326 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___325 {
	void (*fl_copy_lock)(struct file_lock___326 *, struct file_lock___326 *);
	void (*fl_release_private)(struct file_lock___326 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___325;

struct file_lock___326 {
	struct file_lock___326 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___326 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___325 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___325 *fl_ops;
	const struct lock_manager_operations___325 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___325 {
	int (*lm_compare_owner)(struct file_lock___326 *, struct file_lock___326 *);
	long unsigned int (*lm_owner_key)(struct file_lock___326 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___326 *);
	int (*lm_grant)(struct file_lock___326 *, int);
	bool (*lm_break)(struct file_lock___326 *);
	int (*lm_change)(struct file_lock___326 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___326 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___325 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___325 *fa_next;
	struct file___326 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___325 {
	const char *name;
	int fs_flags;
	struct dentry___325 * (*mount)(struct file_system_type___325 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___325 *);
	struct module___11 *owner;
	struct file_system_type___325 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___325 {
	struct inode___326 * (*alloc_inode)(struct super_block___325 *);
	void (*destroy_inode)(struct inode___326 *);
	void (*dirty_inode)(struct inode___326 *, int);
	int (*write_inode)(struct inode___326 *, struct writeback_control___137 *);
	int (*drop_inode)(struct inode___326 *);
	void (*evict_inode)(struct inode___326 *);
	void (*put_super)(struct super_block___325 *);
	int (*sync_fs)(struct super_block___325 *, int);
	int (*freeze_super)(struct super_block___325 *);
	int (*freeze_fs)(struct super_block___325 *);
	int (*thaw_super)(struct super_block___325 *);
	int (*unfreeze_fs)(struct super_block___325 *);
	int (*statfs)(struct dentry___325 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___325 *, int *, char *);
	void (*umount_begin)(struct super_block___325 *);
	int (*show_options)(struct seq_file___277 *, struct dentry___325 *);
	int (*show_devname)(struct seq_file___277 *, struct dentry___325 *);
	int (*show_path)(struct seq_file___277 *, struct dentry___325 *);
	int (*show_stats)(struct seq_file___277 *, struct dentry___325 *);
	ssize_t (*quota_read)(struct super_block___325 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___325 *, int, const char *, size_t, loff_t);
	struct dquot___325 ** (*get_dquots)(struct inode___326 *);
	int (*bdev_try_to_free_page)(struct super_block___325 *, struct page___327 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___325 *, struct shrink_control___122 *);
	long int (*free_cached_objects)(struct super_block___325 *, struct shrink_control___122 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct xattr_handler___25 {
	const char *name;
	const char *prefix;
	int flags;
	bool (*list)(struct dentry___325 *);
	int (*get)(const struct xattr_handler___25 *, struct dentry___325 *, struct inode___326 *, const char *, void *, size_t);
	int (*set)(const struct xattr_handler___25 *, struct dentry___325 *, struct inode___326 *, const char *, const void *, size_t, int);
};

struct seq_operations___276;

struct seq_file___277 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___276 *op;
	int poll_event;
	const struct file___326 *file;
	void *private;
};

typedef void bio_end_io_t___154(struct bio___154 *);

struct bio_vec___155 {
	struct page___327 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___154;

struct bio___154 {
	struct bio___154 *bi_next;
	struct gendisk___80 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___154 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___55 *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___154 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___155 *bi_io_vec;
	struct bio_set___154 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___155 bi_inline_vecs[0];
};

struct kobj_attribute___304 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___313 *, struct kobj_attribute___304 *, char *);
	ssize_t (*store)(struct kobject___313 *, struct kobj_attribute___304 *, const char *, size_t);
};

typedef void compound_page_dtor___314(struct page___327 *);

struct kernfs_root___319;

struct kernfs_elem_dir___319 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___319 *root;
};

struct kernfs_syscall_ops___319;

struct kernfs_root___319 {
	struct kernfs_node___320 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___319 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___319 {
	struct kernfs_node___320 *target_kn;
};

struct kernfs_ops___319;

struct kernfs_elem_attr___319 {
	const struct kernfs_ops___319 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___320 *notify_next;
};

struct kernfs_node___320 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___320 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___319 dir;
		struct kernfs_elem_symlink___319 symlink;
		struct kernfs_elem_attr___319 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___319;

struct kernfs_ops___319 {
	int (*open)(struct kernfs_open_file___319 *);
	void (*release)(struct kernfs_open_file___319 *);
	int (*seq_show)(struct seq_file___277 *, void *);
	void * (*seq_start)(struct seq_file___277 *, loff_t *);
	void * (*seq_next)(struct seq_file___277 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___277 *, void *);
	ssize_t (*read)(struct kernfs_open_file___319 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___319 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___319 *, struct vm_area_struct___327 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___319 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___319 {
	int (*remount_fs)(struct kernfs_root___319 *, int *, char *);
	int (*show_options)(struct seq_file___277 *, struct kernfs_root___319 *);
	int (*mkdir)(struct kernfs_node___320 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___320 *);
	int (*rename)(struct kernfs_node___320 *, struct kernfs_node___320 *, const char *);
	int (*show_path)(struct seq_file___277 *, struct kernfs_node___320 *, struct kernfs_root___319 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___319 {
	struct kernfs_node___320 *kn;
	struct file___326 *file;
	struct seq_file___277 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___314 *vm_ops;
};

struct bin_attribute___289;

struct attribute_group___290 {
	const char *name;
	umode_t (*is_visible)(struct kobject___313 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___313 *, struct bin_attribute___289 *, int);
	struct attribute **attrs;
	struct bin_attribute___289 **bin_attrs;
};

struct bin_attribute___289 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___326 *, struct kobject___313 *, struct bin_attribute___289 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___326 *, struct kobject___313 *, struct bin_attribute___289 *, char *, loff_t, size_t);
	int (*mmap)(struct file___326 *, struct kobject___313 *, struct bin_attribute___289 *, struct vm_area_struct___327 *);
};

struct sysfs_ops___312 {
	ssize_t (*show)(struct kobject___313 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___313 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___312;

struct kset___312 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___313 kobj;
	const struct kset_uevent_ops___312 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___312 {
	void (*release)(struct kobject___313 *);
	const struct sysfs_ops___312 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___25 * (*child_ns_type)(struct kobject___313 *);
	const void * (*namespace)(struct kobject___313 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___312 {
	int (* const filter)(struct kset___312 *, struct kobject___313 *);
	const char * (* const name)(struct kset___312 *, struct kobject___313 *);
	int (* const uevent)(struct kset___312 *, struct kobject___313 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___292 {
	int (*prepare)(struct device___292 *);
	void (*complete)(struct device___292 *);
	int (*suspend)(struct device___292 *);
	int (*resume)(struct device___292 *);
	int (*freeze)(struct device___292 *);
	int (*thaw)(struct device___292 *);
	int (*poweroff)(struct device___292 *);
	int (*restore)(struct device___292 *);
	int (*suspend_late)(struct device___292 *);
	int (*resume_early)(struct device___292 *);
	int (*freeze_late)(struct device___292 *);
	int (*thaw_early)(struct device___292 *);
	int (*poweroff_late)(struct device___292 *);
	int (*restore_early)(struct device___292 *);
	int (*suspend_noirq)(struct device___292 *);
	int (*resume_noirq)(struct device___292 *);
	int (*freeze_noirq)(struct device___292 *);
	int (*thaw_noirq)(struct device___292 *);
	int (*poweroff_noirq)(struct device___292 *);
	int (*restore_noirq)(struct device___292 *);
	int (*runtime_suspend)(struct device___292 *);
	int (*runtime_resume)(struct device___292 *);
	int (*runtime_idle)(struct device___292 *);
};

struct dev_pm_domain___292 {
	struct dev_pm_ops___292 ops;
	void (*detach)(struct device___292 *, bool);
	int (*activate)(struct device___292 *);
	void (*sync)(struct device___292 *);
	void (*dismiss)(struct device___292 *);
};

struct bus_type___292 {
	const char *name;
	const char *dev_name;
	struct device___292 *dev_root;
	const struct attribute_group___290 **bus_groups;
	const struct attribute_group___290 **dev_groups;
	const struct attribute_group___290 **drv_groups;
	int (*match)(struct device___292 *, struct device_driver___292 *);
	int (*uevent)(struct device___292 *, struct kobj_uevent_env *);
	int (*probe)(struct device___292 *);
	int (*remove)(struct device___292 *);
	void (*shutdown)(struct device___292 *);
	int (*online)(struct device___292 *);
	int (*offline)(struct device___292 *);
	int (*suspend)(struct device___292 *, pm_message_t);
	int (*resume)(struct device___292 *);
	int (*num_vf)(struct device___292 *);
	int (*dma_configure)(struct device___292 *);
	const struct dev_pm_ops___292 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___292 {
	const char *name;
	struct bus_type___292 *bus;
	struct module___11 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___292 *);
	int (*remove)(struct device___292 *);
	void (*shutdown)(struct device___292 *);
	int (*suspend)(struct device___292 *, pm_message_t);
	int (*resume)(struct device___292 *);
	const struct attribute_group___290 **groups;
	const struct dev_pm_ops___292 *pm;
	void (*coredump)(struct device___292 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___292 {
	const char *name;
	const struct attribute_group___290 **groups;
	int (*uevent)(struct device___292 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___292 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___292 *);
	const struct dev_pm_ops___292 *pm;
};

struct class___292 {
	const char *name;
	struct module___11 *owner;
	const struct attribute_group___290 **class_groups;
	const struct attribute_group___290 **dev_groups;
	struct kobject___313 *dev_kobj;
	int (*dev_uevent)(struct device___292 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___292 *, umode_t *);
	void (*class_release)(struct class___292 *);
	void (*dev_release)(struct device___292 *);
	int (*shutdown_pre)(struct device___292 *);
	const struct kobj_ns_type_operations___25 *ns_type;
	const void * (*namespace)(struct device___292 *);
	const struct dev_pm_ops___292 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct fwnode_operations___221;

struct fwnode_handle___221 {
	struct fwnode_handle___221 *secondary;
	const struct fwnode_operations___221 *ops;
};

typedef int (*key_restrict_link_func_t___304)(struct key___303 *, const struct key_type *, const union key_payload *, struct key___303 *);

struct key_restriction___303;

struct key___303 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___327 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___303 *restrict_link;
};

struct key_restriction___303 {
	key_restrict_link_func_t___304 check;
	struct key___303 *key;
	struct key_type *keytype;
};

struct seq_operations___276 {
	void * (*start)(struct seq_file___277 *, loff_t *);
	void (*stop)(struct seq_file___277 *, void *);
	void * (*next)(struct seq_file___277 *, void *, loff_t *);
	int (*show)(struct seq_file___277 *, void *);
};

struct tty_driver___36;

struct tty_operations___36 {
	struct tty_struct___36 * (*lookup)(struct tty_driver___36 *, struct file___326 *, int);
	int (*install)(struct tty_driver___36 *, struct tty_struct___36 *);
	void (*remove)(struct tty_driver___36 *, struct tty_struct___36 *);
	int (*open)(struct tty_struct___36 *, struct file___326 *);
	void (*close)(struct tty_struct___36 *, struct file___326 *);
	void (*shutdown)(struct tty_struct___36 *);
	void (*cleanup)(struct tty_struct___36 *);
	int (*write)(struct tty_struct___36 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___36 *, unsigned char);
	void (*flush_chars)(struct tty_struct___36 *);
	int (*write_room)(struct tty_struct___36 *);
	int (*chars_in_buffer)(struct tty_struct___36 *);
	int (*ioctl)(struct tty_struct___36 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___36 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___36 *, struct ktermios *);
	void (*throttle)(struct tty_struct___36 *);
	void (*unthrottle)(struct tty_struct___36 *);
	void (*stop)(struct tty_struct___36 *);
	void (*start)(struct tty_struct___36 *);
	void (*hangup)(struct tty_struct___36 *);
	int (*break_ctl)(struct tty_struct___36 *, int);
	void (*flush_buffer)(struct tty_struct___36 *);
	void (*set_ldisc)(struct tty_struct___36 *);
	void (*wait_until_sent)(struct tty_struct___36 *, int);
	void (*send_xchar)(struct tty_struct___36 *, char);
	int (*tiocmget)(struct tty_struct___36 *);
	int (*tiocmset)(struct tty_struct___36 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___36 *, struct winsize *);
	int (*set_termiox)(struct tty_struct___36 *, struct termiox *);
	int (*get_icount)(struct tty_struct___36 *, struct serial_icounter_struct *);
	void (*show_fdinfo)(struct tty_struct___36 *, struct seq_file___277 *);
	int (*poll_init)(struct tty_driver___36 *, int, char *);
	int (*poll_get_char)(struct tty_driver___36 *, int);
	void (*poll_put_char)(struct tty_driver___36 *, int, char);
	int (*proc_show)(struct seq_file___277 *, void *);
};

struct tty_ldisc___36;

struct tty_port___36;

struct tty_struct___36 {
	int magic;
	struct kref kref;
	struct device___292 *dev;
	struct tty_driver___36 *driver;
	const struct tty_operations___36 *ops;
	int index;
	struct ld_semaphore ldisc_sem;
	struct tty_ldisc___36 *ldisc;
	struct mutex atomic_write_lock;
	struct mutex legacy_mutex;
	struct mutex throttle_mutex;
	struct rw_semaphore___327 termios_rwsem;
	struct mutex winsize_mutex;
	spinlock_t ctrl_lock;
	spinlock_t flow_lock;
	struct ktermios termios;
	struct ktermios termios_locked;
	struct termiox *termiox;
	char name[64];
	struct pid___208 *pgrp;
	struct pid___208 *session;
	long unsigned int flags;
	int count;
	struct winsize winsize;
	long unsigned int stopped: 1;
	long unsigned int flow_stopped: 1;
	int: 30;
	long unsigned int unused: 62;
	int hw_stopped;
	long unsigned int ctrl_status: 8;
	long unsigned int packet: 1;
	int: 23;
	long unsigned int unused_ctrl: 55;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___36 *link;
	struct fasync_struct___325 *fasync;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	spinlock_t files_lock;
	struct list_head tty_files;
	int closing;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___36 *port;
};

struct tty_driver___36 {
	int magic;
	struct kref kref;
	struct cdev___74 **cdevs;
	struct module___11 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___36 *other;
	struct tty_struct___36 **ttys;
	struct tty_port___36 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___36 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___36;

struct tty_port_client_operations___36;

struct tty_port___36 {
	struct tty_bufhead buf;
	struct tty_struct___36 *tty;
	struct tty_struct___36 *itty;
	const struct tty_port_operations___36 *ops;
	const struct tty_port_client_operations___36 *client_ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	unsigned char low_latency: 1;
	struct mutex mutex;
	struct mutex buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
	void *client_data;
};

struct tty_ldisc_ops___36 {
	int magic;
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___36 *);
	void (*close)(struct tty_struct___36 *);
	void (*flush_buffer)(struct tty_struct___36 *);
	ssize_t (*read)(struct tty_struct___36 *, struct file___326 *, unsigned char *, size_t);
	ssize_t (*write)(struct tty_struct___36 *, struct file___326 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___36 *, struct file___326 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___36 *, struct file___326 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___36 *, struct ktermios *);
	__poll_t (*poll)(struct tty_struct___36 *, struct file___326 *, struct poll_table_struct___6 *);
	int (*hangup)(struct tty_struct___36 *);
	void (*receive_buf)(struct tty_struct___36 *, const unsigned char *, char *, int);
	void (*write_wakeup)(struct tty_struct___36 *);
	void (*dcd_change)(struct tty_struct___36 *, unsigned int);
	int (*receive_buf2)(struct tty_struct___36 *, const unsigned char *, char *, int);
	struct module___11 *owner;
	int refcount;
};

struct tty_ldisc___36 {
	struct tty_ldisc_ops___36 *ops;
	struct tty_struct___36 *tty;
};

struct tty_port_operations___36 {
	int (*carrier_raised)(struct tty_port___36 *);
	void (*dtr_rts)(struct tty_port___36 *, int);
	void (*shutdown)(struct tty_port___36 *);
	int (*activate)(struct tty_port___36 *, struct tty_struct___36 *);
	void (*destruct)(struct tty_port___36 *);
};

struct tty_port_client_operations___36 {
	int (*receive_buf)(struct tty_port___36 *, const unsigned char *, const unsigned char *, size_t);
	void (*write_wakeup)(struct tty_port___36 *);
};

struct cgroup_namespace___214 {
	refcount_t count;
	struct ns_common___9 ns;
	struct user_namespace___229 *user_ns;
	struct ucounts___229 *ucounts;
	struct css_set___214 *root_cset;
};

struct ucounts___229 {
	struct hlist_node node;
	struct user_namespace___229 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bio_integrity_payload___154 {
	struct bio___154 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___155 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___155 bip_inline_vecs[0];
};

struct blkcg___55;

struct blkg_policy_data___55;

struct blkcg_gq___55 {
	struct request_queue___79 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___55 *blkcg;
	struct bdi_writeback_congested___154 *wb_congested;
	struct blkcg_gq___55 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_rwstat stat_bytes;
	struct blkg_rwstat stat_ios;
	struct blkg_policy_data___55 *pd[5];
	struct callback_head callback_head;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
};

struct disk_part_tbl___80 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___80 *last_lookup;
	struct hd_struct___80 *part[0];
};

struct block_device_operations___80 {
	int (*open)(struct block_device___325 *, fmode_t);
	void (*release)(struct gendisk___80 *, fmode_t);
	int (*rw_page)(struct block_device___325 *, sector_t, struct page___327 *, unsigned int);
	int (*ioctl)(struct block_device___325 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___325 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___80 *, unsigned int);
	int (*media_changed)(struct gendisk___80 *);
	void (*unlock_native_capacity)(struct gendisk___80 *);
	int (*revalidate_disk)(struct gendisk___80 *);
	int (*getgeo)(struct block_device___325 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___325 *, long unsigned int);
	int (*report_zones)(struct gendisk___80 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___11 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bdi_writeback_congested___154 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___154 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bsg_ops___79 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___79 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___79 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___79 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___79(struct request___79 *, blk_status_t);

struct request___79 {
	struct request_queue___79 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___154 *bio;
	struct bio___154 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___155 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___83 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___79 *saved_end_io;
		} flush;
	};
	struct gendisk___80 *rq_disk;
	struct hd_struct___80 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___79 *end_io;
	void *end_io_data;
	struct request___79 *next_rq;
};

struct fwnode_reference_args___221;

struct fwnode_endpoint___221;

struct fwnode_operations___221 {
	struct fwnode_handle___221 * (*get)(struct fwnode_handle___221 *);
	void (*put)(struct fwnode_handle___221 *);
	bool (*device_is_available)(const struct fwnode_handle___221 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___221 *, const struct device___292 *);
	bool (*property_present)(const struct fwnode_handle___221 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___221 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___221 *, const char *, const char **, size_t);
	struct fwnode_handle___221 * (*get_parent)(const struct fwnode_handle___221 *);
	struct fwnode_handle___221 * (*get_next_child_node)(const struct fwnode_handle___221 *, struct fwnode_handle___221 *);
	struct fwnode_handle___221 * (*get_named_child_node)(const struct fwnode_handle___221 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___221 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___221 *);
	struct fwnode_handle___221 * (*graph_get_next_endpoint)(const struct fwnode_handle___221 *, struct fwnode_handle___221 *);
	struct fwnode_handle___221 * (*graph_get_remote_endpoint)(const struct fwnode_handle___221 *);
	struct fwnode_handle___221 * (*graph_get_port_parent)(struct fwnode_handle___221 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___221 *, struct fwnode_endpoint___221 *);
};

struct fwnode_endpoint___221 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___221 *local_fwnode;
};

struct fwnode_reference_args___221 {
	struct fwnode_handle___221 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct elevator_type___79;

struct elevator_mq_ops___79 {
	int (*init_sched)(struct request_queue___79 *, struct elevator_type___79 *);
	void (*exit_sched)(struct elevator_queue___79 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	bool (*allow_merge)(struct request_queue___79 *, struct request___79 *, struct bio___154 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx *, struct bio___154 *);
	int (*request_merge)(struct request_queue___79 *, struct request___79 **, struct bio___154 *);
	void (*request_merged)(struct request_queue___79 *, struct request___79 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___79 *, struct request___79 *, struct request___79 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___79 *, struct bio___154 *);
	void (*finish_request)(struct request___79 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___79 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___79 *, u64);
	void (*started_request)(struct request___79 *);
	void (*requeue_request)(struct request___79 *);
	struct request___79 * (*former_request)(struct request_queue___79 *, struct request___79 *);
	struct request___79 * (*next_request)(struct request_queue___79 *, struct request___79 *);
	void (*init_icq)(struct io_cq___83 *);
	void (*exit_icq)(struct io_cq___83 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___79;

struct elevator_type___79 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___79 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___79 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___11 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___79 {
	struct elevator_type___79 *type;
	void *elevator_data;
	struct kobject___313 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___79 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___79 *, char *);
	ssize_t (*store)(struct elevator_queue___79 *, const char *, size_t);
};

struct bpf_map___215;

struct bpf_map_ops___214 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___215 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___215 *, struct file___326 *);
	void (*map_free)(struct bpf_map___215 *);
	int (*map_get_next_key)(struct bpf_map___215 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___215 *);
	void * (*map_lookup_elem)(struct bpf_map___215 *, void *);
	int (*map_update_elem)(struct bpf_map___215 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___215 *, void *);
	int (*map_push_elem)(struct bpf_map___215 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___215 *, void *);
	int (*map_peek_elem)(struct bpf_map___215 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___215 *, struct file___326 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___215 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___215 *, void *, struct seq_file___277 *);
	int (*map_check_btf)(const struct bpf_map___215 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___215 {
	const struct bpf_map_ops___214 *ops;
	struct bpf_map___215 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___303 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___214;

typedef void (*kthread_work_func_t___214)(struct kthread_work___214 *);

struct kthread_worker___214;

struct kthread_work___214 {
	struct list_head node;
	kthread_work_func_t___214 func;
	struct kthread_worker___214 *worker;
	int canceling;
};

struct kthread_worker___214 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___327 *task;
	struct kthread_work___214 *current_work;
};

struct kthread_delayed_work___214 {
	struct kthread_work___214 work;
	struct timer_list timer;
};

struct psi_group___214 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___214 *poll_kworker;
	struct kthread_delayed_work___214 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___214;

struct cgroup_rstat_cpu___214;

struct cgroup___214 {
	struct cgroup_subsys_state___214 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___320 *kn;
	struct cgroup_file___214 procs_file;
	struct cgroup_file___214 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___214 *subsys[13];
	struct cgroup_root___214 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___214 *dom_cgrp;
	struct cgroup_rstat_cpu___214 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___35 bpf;
	atomic_t congestion_count;
	struct cgroup___214 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___214 psi;
	int ancestor_ids[0];
};

struct cftype___214;

struct cgroup_subsys___214 {
	struct cgroup_subsys_state___214 * (*css_alloc)(struct cgroup_subsys_state___214 *);
	int (*css_online)(struct cgroup_subsys_state___214 *);
	void (*css_offline)(struct cgroup_subsys_state___214 *);
	void (*css_released)(struct cgroup_subsys_state___214 *);
	void (*css_free)(struct cgroup_subsys_state___214 *);
	void (*css_reset)(struct cgroup_subsys_state___214 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___214 *, int);
	int (*css_extra_stat_show)(struct seq_file___277 *, struct cgroup_subsys_state___214 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___327 *);
	void (*cancel_fork)(struct task_struct___327 *);
	void (*fork)(struct task_struct___327 *);
	void (*exit)(struct task_struct___327 *);
	void (*free)(struct task_struct___327 *);
	void (*bind)(struct cgroup_subsys_state___214 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___214 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___214 *dfl_cftypes;
	struct cftype___214 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___214 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___214 *updated_children;
	struct cgroup___214 *updated_next;
};

struct cgroup_root___214 {
	struct kernfs_root___319 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___214 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___214 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___214 *ss;
	struct list_head node;
	struct kernfs_ops___319 *kf_ops;
	int (*open)(struct kernfs_open_file___319 *);
	void (*release)(struct kernfs_open_file___319 *);
	u64 (*read_u64)(struct cgroup_subsys_state___214 *, struct cftype___214 *);
	s64 (*read_s64)(struct cgroup_subsys_state___214 *, struct cftype___214 *);
	int (*seq_show)(struct seq_file___277 *, void *);
	void * (*seq_start)(struct seq_file___277 *, loff_t *);
	void * (*seq_next)(struct seq_file___277 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___277 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___214 *, struct cftype___214 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___214 *, struct cftype___214 *, s64);
	ssize_t (*write)(struct kernfs_open_file___319 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___319 *, struct poll_table_struct___6 *);
};

struct blkcg_policy_data___55;

struct blkcg___55 {
	struct cgroup_subsys_state___214 css;
	spinlock_t lock;
	struct xarray blkg_tree;
	struct blkcg_gq___55 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___55 *cpd[5];
	struct list_head all_blkcgs_node;
	struct list_head cgwb_list;
	refcount_t cgwb_refcnt;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct blkcg_policy_data___55 {
	struct blkcg___55 *blkcg;
	int plid;
};

struct blkg_policy_data___55 {
	struct blkcg_gq___55 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___122 {
	struct mem_cgroup___122 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___122 {
	struct lruvec___326 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___122 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___122 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct node___191 {
	struct device___292 dev;
};

struct pipe_buf_operations___69;

struct pipe_buffer___69 {
	struct page___327 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___69 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___69 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___69 *, struct pipe_buffer___69 *);
	void (*release)(struct pipe_inode_info___69 *, struct pipe_buffer___69 *);
	int (*steal)(struct pipe_inode_info___69 *, struct pipe_buffer___69 *);
	union {
		bool (*get)(struct pipe_inode_info___69 *, struct pipe_buffer___69 *);
		struct {
			void (*get)(struct pipe_inode_info___69 *, struct pipe_buffer___69 *);
		} __UNIQUE_ID_rh_kabi_hide42;
		union {		};
	};
};

struct splice_desc___2 {
	size_t total_len;
	unsigned int len;
	unsigned int flags;
	union {
		void *userptr;
		struct file___326 *file;
		void *data;
	} u;
	loff_t pos;
	loff_t *opos;
	size_t num_spliced;
	bool need_wakeup;
};

struct memdev {
	const char *name;
	umode_t mode;
	const struct file_operations___326 *fops;
	fmode_t fmode;
};

struct module___266;

struct file___327;

struct kiocb___327;

struct iov_iter___142;

struct poll_table_struct___199;

struct vm_area_struct___328;

struct inode___327;

struct file_lock___327;

struct page___328;

struct seq_file___278;

struct file_operations___327 {
	struct module___266 *owner;
	loff_t (*llseek)(struct file___327 *, loff_t, int);
	ssize_t (*read)(struct file___327 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___327 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___327 *, struct iov_iter___142 *);
	ssize_t (*write_iter)(struct kiocb___327 *, struct iov_iter___142 *);
	int (*iopoll)(struct kiocb___327 *, bool);
	int (*iterate)(struct file___327 *, struct dir_context *);
	int (*iterate_shared)(struct file___327 *, struct dir_context *);
	__poll_t (*poll)(struct file___327 *, struct poll_table_struct___199 *);
	long int (*unlocked_ioctl)(struct file___327 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___327 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___327 *, struct vm_area_struct___328 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___327 *, struct file___327 *);
	int (*flush)(struct file___327 *, fl_owner_t);
	int (*release)(struct inode___327 *, struct file___327 *);
	int (*fsync)(struct file___327 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___327 *, int);
	int (*lock)(struct file___327 *, int, struct file_lock___327 *);
	ssize_t (*sendpage)(struct file___327 *, struct page___328 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___327 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___327 *, int, struct file_lock___327 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___327 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___327 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___327 *, long int, struct file_lock___327 **, void **);
	long int (*fallocate)(struct file___327 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___278 *, struct file___327 *);
	ssize_t (*copy_file_range)(struct file___327 *, loff_t, struct file___327 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___327 *, loff_t, struct file___327 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___327 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___327 {
	u64 seqnum;
	struct vm_area_struct___328 *vmas[4];
};

struct page_frag___327 {
	struct page___328 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___134;

struct debug_info___134 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___134 *hbp_break[16];
	struct perf_event___134 *hbp_watch[16];
};

struct thread_struct___134 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___134 debug;
	long: 64;
};

struct mm_struct___327;

struct pid___209;

struct cred___304;

struct nsproxy___259;

struct signal_struct___241;

struct bio_list___155;

struct backing_dev_info___155;

struct css_set___215;

struct perf_event_context___134;

struct vm_struct___238;

struct task_struct___328 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___328 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___327 *mm;
	struct mm_struct___327 *active_mm;
	struct vmacache___327 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___328 *real_parent;
	struct task_struct___328 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___328 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___209 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___209 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___209 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___304 *ptracer_cred;
	const struct cred___304 *real_cred;
	const struct cred___304 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___259 *nsproxy;
	struct signal_struct___241 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___328 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___155 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___155 *backing_dev_info;
	struct io_context___83 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___215 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___134 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___327 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___328 *oom_reaper_list;
	struct vm_struct___238 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___134 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___134 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___328 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___134)(struct perf_event___134 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___134;

struct fasync_struct___326;

struct pid_namespace___209;

struct trace_event_call___127;

struct perf_cgroup___134;

struct perf_event___134 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___134 *group_leader;
	struct pmu___134 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___134 hw;
	struct perf_event_context___134 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___134 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___328 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___326 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___134 *);
	struct callback_head callback_head;
	struct pid_namespace___209 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___134 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___134 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___127 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___134 *cgrp;
	struct list_head sb_list;
};

struct upid___209 {
	int nr;
	struct pid_namespace___209 *ns;
};

struct dentry___326;

struct user_namespace___230;

struct ucounts___230;

struct pid_namespace___209 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___328 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___209 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___326 *proc_self;
	struct dentry___326 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___230 *user_ns;
	struct ucounts___230 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___9 ns;
};

struct pid___209 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___209 numbers[1];
};

struct rw_semaphore___328 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___328 *owner;
};

struct key___304;

struct user_namespace___230 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___230 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___9 ns;
	long unsigned int flags;
	struct key___304 *persistent_keyring_register;
	struct rw_semaphore___328 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___230 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct secondary_data___328 {
	void *stack;
	struct task_struct___328 *task;
	long int status;
};

typedef long unsigned int cycles_t;

typedef struct page___328 *pgtable_t___327;

struct address_space___326;

struct dev_pagemap___315;

struct page___328 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___326 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___328 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___327 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___327 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___315 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct user_struct___304 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___304 *uid_keyring;
	struct key___304 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___315;

struct vm_area_struct___328 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___328 *vm_next;
	struct vm_area_struct___328 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___327 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___315 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___327 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___327;

struct mm_struct___327 {
	struct {
		struct vm_area_struct___328 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___327 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___328 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___327 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___328 *owner;
		struct user_namespace___230 *user_ns;
		struct file___327 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___327 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___304 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___304 *session_keyring;
	struct key___304 *process_keyring;
	struct key___304 *thread_keyring;
	struct key___304 *request_key_auth;
	void *security;
	struct user_struct___304 *user;
	struct user_namespace___230 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct uts_namespace___25;

struct cgroup_namespace___215;

struct nsproxy___259 {
	atomic_t count;
	struct uts_namespace___25 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___209 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___215 *cgroup_ns;
};

struct signal_struct___241 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___328 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___328 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___209 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___209 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___327 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___209 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___155;

struct bio_list___155 {
	struct bio___155 *head;
	struct bio___155 *tail;
};

struct bdi_writeback_congested___155;

struct cgroup_subsys_state___215;

struct bdi_writeback___155 {
	struct backing_dev_info___155 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___155 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___215 *memcg_css;
	struct cgroup_subsys_state___215 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___293;

struct backing_dev_info___155 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___155 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___293 *dev;
	struct device___293 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___326 *debug_dir;
	struct dentry___326 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup___215;

struct css_set___215 {
	struct cgroup_subsys_state___215 *subsys[13];
	refcount_t refcount;
	struct css_set___215 *dom_cset;
	struct cgroup___215 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___215 *mg_src_cgrp;
	struct cgroup___215 *mg_dst_cgrp;
	struct css_set___215 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___134 {
	struct pmu___134 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___328 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___134 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___238 {
	struct vm_struct___238 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___328 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___253 {
	struct task_struct___328 task;
	long unsigned int stack[8192];
};

struct uts_namespace___25 {
	struct kref kref;
	struct new_utsname name;
	struct user_namespace___230 *user_ns;
	struct ucounts___230 *ucounts;
	struct ns_common___9 ns;
};

struct cgroup_namespace___215 {
	refcount_t count;
	struct ns_common___9 ns;
	struct user_namespace___230 *user_ns;
	struct ucounts___230 *ucounts;
	struct css_set___215 *root_cset;
};

struct ucounts___230 {
	struct hlist_node node;
	struct user_namespace___230 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct pglist_data___327;

struct lruvec___327 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___327 *pgdat;
};

struct zone___327 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___327 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___327 {
	struct zone___327 *zone;
	int zone_idx;
};

struct zonelist___327 {
	struct zoneref___327 _zonerefs[25];
};

struct pglist_data___327 {
	struct zone___327 node_zones[3];
	struct zonelist___327 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___328 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___328 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___327 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___327 {
	struct rw_semaphore___328 rwsem;
	struct notifier_block *head;
};

struct path___327 {
	struct vfsmount *mnt;
	struct dentry___326 *dentry;
};

struct fown_struct___209 {
	rwlock_t lock;
	struct pid___209 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___327 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___327 f_path;
	struct inode___327 *f_inode;
	const struct file_operations___327 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___209 f_owner;
	const struct cred___304 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___326 *f_mapping;
	errseq_t f_wb_err;
};

struct kernfs_root___320;

struct kernfs_elem_dir___320 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___320 *root;
};

struct kernfs_node___321;

struct kernfs_syscall_ops___320;

struct kernfs_root___320 {
	struct kernfs_node___321 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___320 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___320 {
	struct kernfs_node___321 *target_kn;
};

struct kernfs_ops___320;

struct kernfs_elem_attr___320 {
	const struct kernfs_ops___320 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___321 *notify_next;
};

struct kernfs_node___321 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___321 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___320 dir;
		struct kernfs_elem_symlink___320 symlink;
		struct kernfs_elem_attr___320 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___320;

struct kernfs_ops___320 {
	int (*open)(struct kernfs_open_file___320 *);
	void (*release)(struct kernfs_open_file___320 *);
	int (*seq_show)(struct seq_file___278 *, void *);
	void * (*seq_start)(struct seq_file___278 *, loff_t *);
	void * (*seq_next)(struct seq_file___278 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___278 *, void *);
	ssize_t (*read)(struct kernfs_open_file___320 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___320 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___320 *, struct vm_area_struct___328 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___320 *, struct poll_table_struct___199 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___320 {
	int (*remount_fs)(struct kernfs_root___320 *, int *, char *);
	int (*show_options)(struct seq_file___278 *, struct kernfs_root___320 *);
	int (*mkdir)(struct kernfs_node___321 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___321 *);
	int (*rename)(struct kernfs_node___321 *, struct kernfs_node___321 *, const char *);
	int (*show_path)(struct seq_file___278 *, struct kernfs_node___321 *, struct kernfs_root___320 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___277;

struct seq_file___278 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___277 *op;
	int poll_event;
	const struct file___327 *file;
	void *private;
};

struct kernfs_open_file___320 {
	struct kernfs_node___321 *kn;
	struct file___327 *file;
	struct seq_file___278 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___315 *vm_ops;
};

struct vm_fault___315;

struct vm_operations_struct___315 {
	void (*open)(struct vm_area_struct___328 *);
	void (*close)(struct vm_area_struct___328 *);
	int (*split)(struct vm_area_struct___328 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___328 *);
	vm_fault_t (*fault)(struct vm_fault___315 *);
	vm_fault_t (*huge_fault)(struct vm_fault___315 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___315 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___328 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___315 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___315 *);
	int (*access)(struct vm_area_struct___328 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___328 *);
	int (*set_policy)(struct vm_area_struct___328 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___328 *, long unsigned int);
	struct page___328 * (*find_special_page)(struct vm_area_struct___328 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___204)(struct file___327 *, wait_queue_head_t *, struct poll_table_struct___199 *);

struct poll_table_struct___199 {
	poll_queue_proc___204 _qproc;
	__poll_t _key;
};

struct kobject___314;

struct bin_attribute___290;

struct attribute_group___291 {
	const char *name;
	umode_t (*is_visible)(struct kobject___314 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___314 *, struct bin_attribute___290 *, int);
	struct attribute **attrs;
	struct bin_attribute___290 **bin_attrs;
};

struct kset___313;

struct kobj_type___313;

struct kobject___314 {
	const char *name;
	struct list_head entry;
	struct kobject___314 *parent;
	struct kset___313 *kset;
	struct kobj_type___313 *ktype;
	struct kernfs_node___321 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___290 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___327 *, struct kobject___314 *, struct bin_attribute___290 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___327 *, struct kobject___314 *, struct bin_attribute___290 *, char *, loff_t, size_t);
	int (*mmap)(struct file___327 *, struct kobject___314 *, struct bin_attribute___290 *, struct vm_area_struct___328 *);
};

struct sysfs_ops___313 {
	ssize_t (*show)(struct kobject___314 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___314 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___313;

struct kset___313 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___314 kobj;
	const struct kset_uevent_ops___313 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___313 {
	void (*release)(struct kobject___314 *);
	const struct sysfs_ops___313 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___25 * (*child_ns_type)(struct kobject___314 *);
	const void * (*namespace)(struct kobject___314 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___313 {
	int (* const filter)(struct kset___313 *, struct kobject___314 *);
	const char * (* const name)(struct kset___313 *, struct kobject___314 *);
	int (* const uevent)(struct kset___313 *, struct kobject___314 *, struct kobj_uevent_env *);
};

struct kobj_attribute___305 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___314 *, struct kobj_attribute___305 *, char *);
	ssize_t (*store)(struct kobject___314 *, struct kobj_attribute___305 *, const char *, size_t);
};

struct kernel_param___263;

struct kernel_param_ops___263 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___263 *);
	int (*get)(char *, const struct kernel_param___263 *);
	void (*free)(void *);
};

struct kparam_array___263;

struct kernel_param___263 {
	const char *name;
	struct module___266 *mod;
	const struct kernel_param_ops___263 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___263 *arr;
	};
};

struct kparam_array___263 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___263 *ops;
	void *elem;
};

struct module_kobject___263 {
	struct kobject___314 kobj;
	struct module___266 *mod;
	struct kobject___314 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___263 {
	struct module___266 *mod;
	struct latch_tree_node node;
};

struct module_layout___263 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___263 mtn;
};

struct module_attribute___263;

struct module___266 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___263 mkobj;
	struct module_attribute___263 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___314 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___263 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___263 core_layout;
	struct module_layout___263 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___127 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___263 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___263 *, struct module_kobject___263 *, char *);
	ssize_t (*store)(struct module_attribute___263 *, struct module_kobject___263 *, const char *, size_t);
	void (*setup)(struct module___266 *, const char *);
	int (*test)(struct module___266 *);
	void (*free)(struct module___266 *);
};

struct trace_event_class___127;

struct trace_event_call___127 {
	struct list_head list;
	struct trace_event_class___127 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___13 event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___35 *prog_array;
	int (*perf_perm)(struct trace_event_call___127 *, struct perf_event___134 *);
};

struct random_ready_callback___2 {
	struct list_head list;
	void (*func)(struct random_ready_callback___2 *);
	struct module___266 *owner;
};

struct dentry_operations___326;

struct super_block___326;

struct dentry___326 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___326 *d_parent;
	struct qstr d_name;
	struct inode___327 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___326 *d_op;
	struct super_block___326 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___326;

struct address_space___326 {
	struct inode___327 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___328 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___326 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___326;

struct block_device___326;

struct inode___327 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___326 *i_op;
	struct super_block___326 *i_sb;
	struct address_space___326 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___328 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___155 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___327 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___326 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___326 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___326 {
	int (*d_revalidate)(struct dentry___326 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___326 *, unsigned int);
	int (*d_hash)(const struct dentry___326 *, struct qstr *);
	int (*d_compare)(const struct dentry___326 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___326 *);
	int (*d_init)(struct dentry___326 *);
	void (*d_release)(struct dentry___326 *);
	void (*d_prune)(struct dentry___326 *);
	void (*d_iput)(struct dentry___326 *, struct inode___327 *);
	char * (*d_dname)(struct dentry___326 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___327 *);
	int (*d_manage)(const struct path___327 *, bool);
	struct dentry___326 * (*d_real)(struct dentry___326 *, const struct inode___327 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___326;

struct mem_dqinfo___326 {
	struct quota_format_type___326 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___326;

struct quota_info___326 {
	unsigned int flags;
	struct rw_semaphore___328 dqio_sem;
	struct inode___327 *files[3];
	struct mem_dqinfo___326 info[3];
	const struct quota_format_ops___326 *ops[3];
};

struct rcuwait___326 {
	struct task_struct___328 *task;
};

struct percpu_rw_semaphore___326 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___328 rw_sem;
	struct rcuwait___326 writer;
	int readers_block;
};

struct sb_writers___326 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___326 rw_sem[3];
};

struct file_system_type___326;

struct super_operations___326;

struct dquot_operations___326;

struct quotactl_ops___326;

struct super_block___326 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___326 *s_type;
	const struct super_operations___326 *s_op;
	const struct dquot_operations___326 *dq_op;
	const struct quotactl_ops___326 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___326 *s_root;
	struct rw_semaphore___328 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___326 *s_bdev;
	struct backing_dev_info___155 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___326 s_dquot;
	struct sb_writers___326 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___326 *s_d_op;
	int cleancache_poolid;
	struct shrinker___122 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___230 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

typedef int (*dev_page_fault_t___315)(struct vm_area_struct___328 *, long unsigned int, const struct page___328 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___315)(struct page___328 *, void *);

struct dev_pagemap___315 {
	dev_page_fault_t___315 page_fault;
	dev_page_free_t___315 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___293 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___327 {
	struct task_struct___328 *task;
	struct core_thread___327 *next;
};

struct core_state___327 {
	atomic_t nr_threads;
	struct core_thread___327 dumper;
	struct completion startup;
};

struct vm_fault___315 {
	struct vm_area_struct___328 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___328 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___328 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___327 prealloc_pte;
};

struct kiocb___327 {
	struct file___327 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___327 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___326 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___327 *ia_file;
};

struct dquot___326 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___326 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___326 {
	int qf_fmt_id;
	const struct quota_format_ops___326 *qf_ops;
	struct module___266 *qf_owner;
	struct quota_format_type___326 *qf_next;
};

struct quota_format_ops___326 {
	int (*check_quota_file)(struct super_block___326 *, int);
	int (*read_file_info)(struct super_block___326 *, int);
	int (*write_file_info)(struct super_block___326 *, int);
	int (*free_file_info)(struct super_block___326 *, int);
	int (*read_dqblk)(struct dquot___326 *);
	int (*commit_dqblk)(struct dquot___326 *);
	int (*release_dqblk)(struct dquot___326 *);
	int (*get_next_id)(struct super_block___326 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___326 {
	int (*write_dquot)(struct dquot___326 *);
	struct dquot___326 * (*alloc_dquot)(struct super_block___326 *, int);
	void (*destroy_dquot)(struct dquot___326 *);
	int (*acquire_dquot)(struct dquot___326 *);
	int (*release_dquot)(struct dquot___326 *);
	int (*mark_dirty)(struct dquot___326 *);
	int (*write_info)(struct super_block___326 *, int);
	qsize_t * (*get_reserved_space)(struct inode___327 *);
	int (*get_projid)(struct inode___327 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___327 *, qsize_t *);
	int (*get_next_id)(struct super_block___326 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___326 {
	int (*quota_on)(struct super_block___326 *, int, int, const struct path___327 *);
	int (*quota_off)(struct super_block___326 *, int);
	int (*quota_enable)(struct super_block___326 *, unsigned int);
	int (*quota_disable)(struct super_block___326 *, unsigned int);
	int (*quota_sync)(struct super_block___326 *, int);
	int (*set_info)(struct super_block___326 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___326 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___326 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___326 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___326 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___326 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___138;

struct address_space_operations___326 {
	int (*writepage)(struct page___328 *, struct writeback_control___138 *);
	int (*readpage)(struct file___327 *, struct page___328 *);
	int (*writepages)(struct address_space___326 *, struct writeback_control___138 *);
	int (*set_page_dirty)(struct page___328 *);
	int (*readpages)(struct file___327 *, struct address_space___326 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___327 *, struct address_space___326 *, loff_t, unsigned int, unsigned int, struct page___328 **, void **);
	int (*write_end)(struct file___327 *, struct address_space___326 *, loff_t, unsigned int, unsigned int, struct page___328 *, void *);
	sector_t (*bmap)(struct address_space___326 *, sector_t);
	void (*invalidatepage)(struct page___328 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___328 *, gfp_t);
	void (*freepage)(struct page___328 *);
	ssize_t (*direct_IO)(struct kiocb___327 *, struct iov_iter___142 *);
	int (*migratepage)(struct address_space___326 *, struct page___328 *, struct page___328 *, enum migrate_mode);
	bool (*isolate_page)(struct page___328 *, isolate_mode_t);
	void (*putback_page)(struct page___328 *);
	int (*launder_page)(struct page___328 *);
	int (*is_partially_uptodate)(struct page___328 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___328 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___326 *, struct page___328 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___327 *, sector_t *);
	void (*swap_deactivate)(struct file___327 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___138 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___155 *wb;
	struct inode___327 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___156;

struct iov_iter___142 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___156 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct hd_struct___81;

struct gendisk___81;

struct block_device___326 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___327 *bd_inode;
	struct super_block___326 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___326 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___81 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___81 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___155 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___293 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___3 *subsys_data;
	void (*set_latency_tolerance)(struct device___293 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___293;

struct bus_type___293;

struct device_driver___293;

struct dev_pm_domain___293;

struct fwnode_handle___222;

struct class___293;

struct device___293 {
	struct device___293 *parent;
	struct device_private *p;
	struct kobject___314 kobj;
	const char *init_name;
	const struct device_type___293 *type;
	struct mutex mutex;
	struct bus_type___293 *bus;
	struct device_driver___293 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___293 power;
	struct dev_pm_domain___293 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___222 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___293 *class;
	const struct attribute_group___291 **groups;
	void (*release)(struct device___293 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___81 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___293 __dev;
	struct kobject___314 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___81;

struct timer_rand_state___2;

struct gendisk___81 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___81 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___81 *part_tbl;
	struct hd_struct___81 part0;
	const struct block_device_operations___13 *fops;
	struct request_queue___3 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___328 lookup_sem;
	struct kobject___314 *slave_dir;
	struct timer_rand_state___2 *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___314 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___326 {
	struct dentry___326 * (*lookup)(struct inode___327 *, struct dentry___326 *, unsigned int);
	const char * (*get_link)(struct dentry___326 *, struct inode___327 *, struct delayed_call *);
	int (*permission)(struct inode___327 *, int);
	struct posix_acl * (*get_acl)(struct inode___327 *, int);
	int (*readlink)(struct dentry___326 *, char *, int);
	int (*create)(struct inode___327 *, struct dentry___326 *, umode_t, bool);
	int (*link)(struct dentry___326 *, struct inode___327 *, struct dentry___326 *);
	int (*unlink)(struct inode___327 *, struct dentry___326 *);
	int (*symlink)(struct inode___327 *, struct dentry___326 *, const char *);
	int (*mkdir)(struct inode___327 *, struct dentry___326 *, umode_t);
	int (*rmdir)(struct inode___327 *, struct dentry___326 *);
	int (*mknod)(struct inode___327 *, struct dentry___326 *, umode_t, dev_t);
	int (*rename)(struct inode___327 *, struct dentry___326 *, struct inode___327 *, struct dentry___326 *, unsigned int);
	int (*setattr)(struct dentry___326 *, struct iattr___326 *);
	int (*getattr)(const struct path___327 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___326 *, char *, size_t);
	int (*fiemap)(struct inode___327 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___327 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___327 *, struct dentry___326 *, struct file___327 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___327 *, struct dentry___326 *, umode_t);
	int (*set_acl)(struct inode___327 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___326 {
	void (*fl_copy_lock)(struct file_lock___327 *, struct file_lock___327 *);
	void (*fl_release_private)(struct file_lock___327 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___326;

struct file_lock___327 {
	struct file_lock___327 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___327 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___326 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___326 *fl_ops;
	const struct lock_manager_operations___326 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___326 {
	int (*lm_compare_owner)(struct file_lock___327 *, struct file_lock___327 *);
	long unsigned int (*lm_owner_key)(struct file_lock___327 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___327 *);
	int (*lm_grant)(struct file_lock___327 *, int);
	bool (*lm_break)(struct file_lock___327 *);
	int (*lm_change)(struct file_lock___327 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___327 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___326 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___326 *fa_next;
	struct file___327 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___326 {
	const char *name;
	int fs_flags;
	struct dentry___326 * (*mount)(struct file_system_type___326 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___326 *);
	struct module___266 *owner;
	struct file_system_type___326 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___326 {
	struct inode___327 * (*alloc_inode)(struct super_block___326 *);
	void (*destroy_inode)(struct inode___327 *);
	void (*dirty_inode)(struct inode___327 *, int);
	int (*write_inode)(struct inode___327 *, struct writeback_control___138 *);
	int (*drop_inode)(struct inode___327 *);
	void (*evict_inode)(struct inode___327 *);
	void (*put_super)(struct super_block___326 *);
	int (*sync_fs)(struct super_block___326 *, int);
	int (*freeze_super)(struct super_block___326 *);
	int (*freeze_fs)(struct super_block___326 *);
	int (*thaw_super)(struct super_block___326 *);
	int (*unfreeze_fs)(struct super_block___326 *);
	int (*statfs)(struct dentry___326 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___326 *, int *, char *);
	void (*umount_begin)(struct super_block___326 *);
	int (*show_options)(struct seq_file___278 *, struct dentry___326 *);
	int (*show_devname)(struct seq_file___278 *, struct dentry___326 *);
	int (*show_path)(struct seq_file___278 *, struct dentry___326 *);
	int (*show_stats)(struct seq_file___278 *, struct dentry___326 *);
	ssize_t (*quota_read)(struct super_block___326 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___326 *, int, const char *, size_t, loff_t);
	struct dquot___326 ** (*get_dquots)(struct inode___327 *);
	int (*bdev_try_to_free_page)(struct super_block___326 *, struct page___328 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___326 *, struct shrink_control___122 *);
	long int (*free_cached_objects)(struct super_block___326 *, struct shrink_control___122 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___155(struct bio___155 *);

struct bio_vec___156 {
	struct page___328 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___155;

struct bio_set___155;

struct bio___155 {
	struct bio___155 *bi_next;
	struct gendisk___81 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___155 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___155 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___156 *bi_io_vec;
	struct bio_set___155 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___156 bi_inline_vecs[0];
};

typedef struct poll_table_struct___199 poll_table___27;

struct bio_integrity_payload___155 {
	struct bio___155 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___156 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___156 bip_inline_vecs[0];
};

struct bio_set___155 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___155 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_ops___293;

struct device_type___293 {
	const char *name;
	const struct attribute_group___291 **groups;
	int (*uevent)(struct device___293 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___293 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___293 *);
	const struct dev_pm_ops___293 *pm;
};

struct class___293 {
	const char *name;
	struct module___266 *owner;
	const struct attribute_group___291 **class_groups;
	const struct attribute_group___291 **dev_groups;
	struct kobject___314 *dev_kobj;
	int (*dev_uevent)(struct device___293 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___293 *, umode_t *);
	void (*class_release)(struct class___293 *);
	void (*dev_release)(struct device___293 *);
	int (*shutdown_pre)(struct device___293 *);
	const struct kobj_ns_type_operations___25 *ns_type;
	const void * (*namespace)(struct device___293 *);
	const struct dev_pm_ops___293 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dev_pm_ops___293 {
	int (*prepare)(struct device___293 *);
	void (*complete)(struct device___293 *);
	int (*suspend)(struct device___293 *);
	int (*resume)(struct device___293 *);
	int (*freeze)(struct device___293 *);
	int (*thaw)(struct device___293 *);
	int (*poweroff)(struct device___293 *);
	int (*restore)(struct device___293 *);
	int (*suspend_late)(struct device___293 *);
	int (*resume_early)(struct device___293 *);
	int (*freeze_late)(struct device___293 *);
	int (*thaw_early)(struct device___293 *);
	int (*poweroff_late)(struct device___293 *);
	int (*restore_early)(struct device___293 *);
	int (*suspend_noirq)(struct device___293 *);
	int (*resume_noirq)(struct device___293 *);
	int (*freeze_noirq)(struct device___293 *);
	int (*thaw_noirq)(struct device___293 *);
	int (*poweroff_noirq)(struct device___293 *);
	int (*restore_noirq)(struct device___293 *);
	int (*runtime_suspend)(struct device___293 *);
	int (*runtime_resume)(struct device___293 *);
	int (*runtime_idle)(struct device___293 *);
};

struct dev_pm_domain___293 {
	struct dev_pm_ops___293 ops;
	void (*detach)(struct device___293 *, bool);
	int (*activate)(struct device___293 *);
	void (*sync)(struct device___293 *);
	void (*dismiss)(struct device___293 *);
};

struct bus_type___293 {
	const char *name;
	const char *dev_name;
	struct device___293 *dev_root;
	const struct attribute_group___291 **bus_groups;
	const struct attribute_group___291 **dev_groups;
	const struct attribute_group___291 **drv_groups;
	int (*match)(struct device___293 *, struct device_driver___293 *);
	int (*uevent)(struct device___293 *, struct kobj_uevent_env *);
	int (*probe)(struct device___293 *);
	int (*remove)(struct device___293 *);
	void (*shutdown)(struct device___293 *);
	int (*online)(struct device___293 *);
	int (*offline)(struct device___293 *);
	int (*suspend)(struct device___293 *, pm_message_t);
	int (*resume)(struct device___293 *);
	int (*num_vf)(struct device___293 *);
	int (*dma_configure)(struct device___293 *);
	const struct dev_pm_ops___293 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___293 {
	const char *name;
	struct bus_type___293 *bus;
	struct module___266 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___293 *);
	int (*remove)(struct device___293 *);
	void (*shutdown)(struct device___293 *);
	int (*suspend)(struct device___293 *, pm_message_t);
	int (*resume)(struct device___293 *);
	const struct attribute_group___291 **groups;
	const struct dev_pm_ops___293 *pm;
	void (*coredump)(struct device___293 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct fwnode_operations___222;

struct fwnode_handle___222 {
	struct fwnode_handle___222 *secondary;
	const struct fwnode_operations___222 *ops;
};

struct disk_part_tbl___81 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___81 *last_lookup;
	struct hd_struct___81 *part[0];
};

struct timer_rand_state___2 {
	cycles_t last_time;
	long int last_delta;
	long int last_delta2;
};

typedef void compound_page_dtor___315(struct page___328 *);

struct kthread_work___215;

typedef void (*kthread_work_func_t___215)(struct kthread_work___215 *);

struct kthread_worker___215;

struct kthread_work___215 {
	struct list_head node;
	kthread_work_func_t___215 func;
	struct kthread_worker___215 *worker;
	int canceling;
};

struct kthread_worker___215 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___328 *task;
	struct kthread_work___215 *current_work;
};

struct kthread_delayed_work___215 {
	struct kthread_work___215 work;
	struct timer_list timer;
};

typedef int (*key_restrict_link_func_t___305)(struct key___304 *, const struct key_type *, const union key_payload *, struct key___304 *);

struct key_restriction___304;

struct key___304 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___328 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___304 *restrict_link;
};

struct key_restriction___304 {
	key_restrict_link_func_t___305 check;
	struct key___304 *key;
	struct key_type *keytype;
};

struct irq_chip___24;

struct irq_data___24 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___11 *common;
	struct irq_chip___24 *chip;
	struct irq_domain *domain;
	struct irq_data___24 *parent_data;
	void *chip_data;
};

struct fwnode_reference_args___222;

struct fwnode_endpoint___222;

struct fwnode_operations___222 {
	struct fwnode_handle___222 * (*get)(struct fwnode_handle___222 *);
	void (*put)(struct fwnode_handle___222 *);
	bool (*device_is_available)(const struct fwnode_handle___222 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___222 *, const struct device___293 *);
	bool (*property_present)(const struct fwnode_handle___222 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___222 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___222 *, const char *, const char **, size_t);
	struct fwnode_handle___222 * (*get_parent)(const struct fwnode_handle___222 *);
	struct fwnode_handle___222 * (*get_next_child_node)(const struct fwnode_handle___222 *, struct fwnode_handle___222 *);
	struct fwnode_handle___222 * (*get_named_child_node)(const struct fwnode_handle___222 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___222 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___222 *);
	struct fwnode_handle___222 * (*graph_get_next_endpoint)(const struct fwnode_handle___222 *, struct fwnode_handle___222 *);
	struct fwnode_handle___222 * (*graph_get_remote_endpoint)(const struct fwnode_handle___222 *);
	struct fwnode_handle___222 * (*graph_get_port_parent)(struct fwnode_handle___222 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___222 *, struct fwnode_endpoint___222 *);
};

struct fwnode_endpoint___222 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___222 *local_fwnode;
};

struct fwnode_reference_args___222 {
	struct fwnode_handle___222 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct irq_chip___24 {
	struct device___293 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___24 *);
	void (*irq_shutdown)(struct irq_data___24 *);
	void (*irq_enable)(struct irq_data___24 *);
	void (*irq_disable)(struct irq_data___24 *);
	void (*irq_ack)(struct irq_data___24 *);
	void (*irq_mask)(struct irq_data___24 *);
	void (*irq_mask_ack)(struct irq_data___24 *);
	void (*irq_unmask)(struct irq_data___24 *);
	void (*irq_eoi)(struct irq_data___24 *);
	int (*irq_set_affinity)(struct irq_data___24 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___24 *);
	int (*irq_set_type)(struct irq_data___24 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___24 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___24 *);
	void (*irq_bus_sync_unlock)(struct irq_data___24 *);
	void (*irq_cpu_online)(struct irq_data___24 *);
	void (*irq_cpu_offline)(struct irq_data___24 *);
	void (*irq_suspend)(struct irq_data___24 *);
	void (*irq_resume)(struct irq_data___24 *);
	void (*irq_pm_shutdown)(struct irq_data___24 *);
	void (*irq_calc_mask)(struct irq_data___24 *);
	void (*irq_print_chip)(struct irq_data___24 *, struct seq_file___278 *);
	int (*irq_request_resources)(struct irq_data___24 *);
	void (*irq_release_resources)(struct irq_data___24 *);
	void (*irq_compose_msi_msg)(struct irq_data___24 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___24 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___24 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___24 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___24 *, void *);
	void (*ipi_send_single)(struct irq_data___24 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___24 *, const struct cpumask *);
	long unsigned int flags;
};

struct seq_operations___277 {
	void * (*start)(struct seq_file___278 *, loff_t *);
	void (*stop)(struct seq_file___278 *, void *);
	void * (*next)(struct seq_file___278 *, void *, loff_t *);
	int (*show)(struct seq_file___278 *, void *);
};

struct node___192 {
	struct device___293 dev;
};

struct bpf_map___216;

struct bpf_map_ops___215 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___216 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___216 *, struct file___327 *);
	void (*map_free)(struct bpf_map___216 *);
	int (*map_get_next_key)(struct bpf_map___216 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___216 *);
	void * (*map_lookup_elem)(struct bpf_map___216 *, void *);
	int (*map_update_elem)(struct bpf_map___216 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___216 *, void *);
	int (*map_push_elem)(struct bpf_map___216 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___216 *, void *);
	int (*map_peek_elem)(struct bpf_map___216 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___216 *, struct file___327 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___216 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___216 *, void *, struct seq_file___278 *);
	int (*map_check_btf)(const struct bpf_map___216 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___216 {
	const struct bpf_map_ops___215 *ops;
	struct bpf_map___216 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___304 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct psi_group___215 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___215 *poll_kworker;
	struct kthread_delayed_work___215 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___215 {
	struct kernfs_node___321 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___215;

struct cgroup_subsys_state___215 {
	struct cgroup___215 *cgroup;
	struct cgroup_subsys___215 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___215 *parent;
};

struct cgroup_root___215;

struct cgroup_rstat_cpu___215;

struct cgroup___215 {
	struct cgroup_subsys_state___215 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___321 *kn;
	struct cgroup_file___215 procs_file;
	struct cgroup_file___215 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___215 *subsys[13];
	struct cgroup_root___215 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___215 *dom_cgrp;
	struct cgroup_rstat_cpu___215 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___35 bpf;
	atomic_t congestion_count;
	struct cgroup___215 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___215 psi;
	int ancestor_ids[0];
};

struct cftype___215;

struct cgroup_subsys___215 {
	struct cgroup_subsys_state___215 * (*css_alloc)(struct cgroup_subsys_state___215 *);
	int (*css_online)(struct cgroup_subsys_state___215 *);
	void (*css_offline)(struct cgroup_subsys_state___215 *);
	void (*css_released)(struct cgroup_subsys_state___215 *);
	void (*css_free)(struct cgroup_subsys_state___215 *);
	void (*css_reset)(struct cgroup_subsys_state___215 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___215 *, int);
	int (*css_extra_stat_show)(struct seq_file___278 *, struct cgroup_subsys_state___215 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___328 *);
	void (*cancel_fork)(struct task_struct___328 *);
	void (*fork)(struct task_struct___328 *);
	void (*exit)(struct task_struct___328 *);
	void (*free)(struct task_struct___328 *);
	void (*bind)(struct cgroup_subsys_state___215 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___215 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___215 *dfl_cftypes;
	struct cftype___215 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___215 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___215 *updated_children;
	struct cgroup___215 *updated_next;
};

struct cgroup_root___215 {
	struct kernfs_root___320 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___215 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___215 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___215 *ss;
	struct list_head node;
	struct kernfs_ops___320 *kf_ops;
	int (*open)(struct kernfs_open_file___320 *);
	void (*release)(struct kernfs_open_file___320 *);
	u64 (*read_u64)(struct cgroup_subsys_state___215 *, struct cftype___215 *);
	s64 (*read_s64)(struct cgroup_subsys_state___215 *, struct cftype___215 *);
	int (*seq_show)(struct seq_file___278 *, void *);
	void * (*seq_start)(struct seq_file___278 *, loff_t *);
	void * (*seq_next)(struct seq_file___278 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___278 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___215 *, struct cftype___215 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___215 *, struct cftype___215 *, s64);
	ssize_t (*write)(struct kernfs_open_file___320 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___320 *, struct poll_table_struct___199 *);
};

struct perf_cpu_context___134;

struct pmu___134 {
	struct list_head entry;
	struct module___266 *module;
	struct device___293 *dev;
	const struct attribute_group___291 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___134 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___134 *);
	void (*pmu_disable)(struct pmu___134 *);
	int (*event_init)(struct perf_event___134 *);
	void (*event_mapped)(struct perf_event___134 *, struct mm_struct___327 *);
	void (*event_unmapped)(struct perf_event___134 *, struct mm_struct___327 *);
	int (*add)(struct perf_event___134 *, int);
	void (*del)(struct perf_event___134 *, int);
	void (*start)(struct perf_event___134 *, int);
	void (*stop)(struct perf_event___134 *, int);
	void (*read)(struct perf_event___134 *);
	void (*start_txn)(struct pmu___134 *, unsigned int);
	int (*commit_txn)(struct pmu___134 *);
	void (*cancel_txn)(struct pmu___134 *);
	int (*event_idx)(struct perf_event___134 *);
	void (*sched_task)(struct perf_event_context___134 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___134 *);
	int (*filter_match)(struct perf_event___134 *);
	int (*check_period)(struct perf_event___134 *, u64);
};

struct perf_cpu_context___134 {
	struct perf_event_context___134 ctx;
	struct perf_event_context___134 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___134 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___134 {
	struct cgroup_subsys_state___215 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___127 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___127 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___127 *);
	struct list_head * (*get_fields)(struct trace_event_call___127 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___127 *);
};

struct trace_event_file___50;

struct trace_event_buffer___42 {
	struct ring_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___50 *trace_file;
	void *entry;
	long unsigned int flags;
	int pc;
};

struct trace_event_file___50 {
	struct list_head list;
	struct trace_event_call___127 *event_call;
	struct event_filter *filter;
	struct dentry___326 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct syscall_metadata___65 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___127 *enter_event;
	struct trace_event_call___127 *exit_event;
};

struct bdi_writeback_congested___155 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___155 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct trace_event_raw_add_device_randomness {
	struct trace_entry ent;
	int bytes;
	long unsigned int IP;
	char __data[0];
};

struct trace_event_raw_random__mix_pool_bytes {
	struct trace_entry ent;
	const char *pool_name;
	int bytes;
	long unsigned int IP;
	char __data[0];
};

struct trace_event_raw_credit_entropy_bits {
	struct trace_entry ent;
	const char *pool_name;
	int bits;
	int entropy_count;
	int entropy_total;
	long unsigned int IP;
	char __data[0];
};

struct trace_event_raw_push_to_pool {
	struct trace_entry ent;
	const char *pool_name;
	int pool_bits;
	int input_bits;
	char __data[0];
};

struct trace_event_raw_debit_entropy {
	struct trace_entry ent;
	const char *pool_name;
	int debit_bits;
	char __data[0];
};

struct trace_event_raw_add_input_randomness {
	struct trace_entry ent;
	int input_bits;
	char __data[0];
};

struct trace_event_raw_add_disk_randomness {
	struct trace_entry ent;
	dev_t dev;
	int input_bits;
	char __data[0];
};

struct trace_event_raw_xfer_secondary_pool {
	struct trace_entry ent;
	const char *pool_name;
	int xfer_bits;
	int request_bits;
	int pool_entropy;
	int input_entropy;
	char __data[0];
};

struct trace_event_raw_random__get_random_bytes {
	struct trace_entry ent;
	int nbytes;
	long unsigned int IP;
	char __data[0];
};

struct trace_event_raw_random__extract_entropy {
	struct trace_entry ent;
	const char *pool_name;
	int nbytes;
	int entropy_count;
	long unsigned int IP;
	char __data[0];
};

struct trace_event_raw_random_read {
	struct trace_entry ent;
	int got_bits;
	int need_bits;
	int pool_left;
	int input_left;
	char __data[0];
};

struct trace_event_raw_urandom_read {
	struct trace_entry ent;
	int got_bits;
	int pool_left;
	int input_left;
	char __data[0];
};

struct trace_event_data_offsets_add_device_randomness {};

struct trace_event_data_offsets_random__mix_pool_bytes {};

struct trace_event_data_offsets_credit_entropy_bits {};

struct trace_event_data_offsets_push_to_pool {};

struct trace_event_data_offsets_debit_entropy {};

struct trace_event_data_offsets_add_input_randomness {};

struct trace_event_data_offsets_add_disk_randomness {};

struct trace_event_data_offsets_xfer_secondary_pool {};

struct trace_event_data_offsets_random__get_random_bytes {};

struct trace_event_data_offsets_random__extract_entropy {};

struct trace_event_data_offsets_random_read {};

struct trace_event_data_offsets_urandom_read {};

struct poolinfo {
	int poolbitshift;
	int poolwords;
	int poolbytes;
	int poolbits;
	int poolfracbits;
	int tap1;
	int tap2;
	int tap3;
	int tap4;
	int tap5;
};

struct crng_state {
	__u32 state[16];
	long unsigned int init_time;
	spinlock_t lock;
};

struct entropy_store {
	const struct poolinfo *poolinfo;
	__u32 *pool;
	const char *name;
	struct entropy_store *pull;
	struct work_struct push_work;
	long unsigned int last_pulled;
	spinlock_t lock;
	short unsigned int add_ptr;
	short unsigned int input_rotate;
	int entropy_count;
	int entropy_total;
	unsigned int initialized: 1;
	unsigned int last_data_init: 1;
	__u8 last_data[10];
};

struct fast_pool {
	__u32 pool[4];
	long unsigned int last;
	short unsigned int reg_idx;
	unsigned char count;
};

struct batched_entropy {
	union {
		u64 entropy_u64[8];
		u32 entropy_u32[16];
	};
	unsigned int position;
};

struct miscdevice___5 {
	int minor;
	const char *name;
	const struct file_operations___325 *fops;
	struct list_head list;
	struct device___291 *parent;
	struct device___291 *this_device;
	const struct attribute_group___289 **groups;
	const char *nodename;
	umode_t mode;
};

struct module___267;

struct file___328;

struct kiocb___328;

struct iov_iter___143;

struct vm_area_struct___329;

struct inode___328;

struct file_lock___328;

struct page___329;

struct seq_file___279;

struct file_operations___328 {
	struct module___267 *owner;
	loff_t (*llseek)(struct file___328 *, loff_t, int);
	ssize_t (*read)(struct file___328 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___328 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___328 *, struct iov_iter___143 *);
	ssize_t (*write_iter)(struct kiocb___328 *, struct iov_iter___143 *);
	int (*iopoll)(struct kiocb___328 *, bool);
	int (*iterate)(struct file___328 *, struct dir_context *);
	int (*iterate_shared)(struct file___328 *, struct dir_context *);
	__poll_t (*poll)(struct file___328 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___328 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___328 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___328 *, struct vm_area_struct___329 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___328 *, struct file___328 *);
	int (*flush)(struct file___328 *, fl_owner_t);
	int (*release)(struct inode___328 *, struct file___328 *);
	int (*fsync)(struct file___328 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___328 *, int);
	int (*lock)(struct file___328 *, int, struct file_lock___328 *);
	ssize_t (*sendpage)(struct file___328 *, struct page___329 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___328 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___328 *, int, struct file_lock___328 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___328 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___328 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___328 *, long int, struct file_lock___328 **, void **);
	long int (*fallocate)(struct file___328 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___279 *, struct file___328 *);
	ssize_t (*copy_file_range)(struct file___328 *, loff_t, struct file___328 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___328 *, loff_t, struct file___328 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___328 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___328 {
	u64 seqnum;
	struct vm_area_struct___329 *vmas[4];
};

struct page_frag___328 {
	struct page___329 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___328;

struct cred___305;

struct nsproxy___260;

struct bio_list___156;

struct backing_dev_info___156;

struct io_context___84;

struct css_set___216;

struct request_queue___80;

struct vm_struct___239;

struct task_struct___329 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___329 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___328 *mm;
	struct mm_struct___328 *active_mm;
	struct vmacache___328 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___329 *real_parent;
	struct task_struct___329 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___329 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___209 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___209 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___209 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___305 *ptracer_cred;
	const struct cred___305 *real_cred;
	const struct cred___305 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___260 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___329 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___156 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___156 *backing_dev_info;
	struct io_context___84 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___216 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___328 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___80 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___329 *oom_reaper_list;
	struct vm_struct___239 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___134 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___327;

struct super_block___327;

struct dentry___327 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___327 *d_parent;
	struct qstr d_name;
	struct inode___328 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___327 *d_op;
	struct super_block___327 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct rw_semaphore___329 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___329 *owner;
};

struct address_space_operations___327;

struct address_space___327 {
	struct inode___328 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___329 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___327 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___327;

struct bdi_writeback___156;

struct block_device___327;

struct cdev___75;

struct inode___328 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___327 *i_op;
	struct super_block___327 *i_sb;
	struct address_space___327 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___329 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___156 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___328 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___327 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___327 *i_bdev;
		struct cdev___75 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___328;

struct dentry_operations___327 {
	int (*d_revalidate)(struct dentry___327 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___327 *, unsigned int);
	int (*d_hash)(const struct dentry___327 *, struct qstr *);
	int (*d_compare)(const struct dentry___327 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___327 *);
	int (*d_init)(struct dentry___327 *);
	void (*d_release)(struct dentry___327 *);
	void (*d_prune)(struct dentry___327 *);
	void (*d_iput)(struct dentry___327 *, struct inode___328 *);
	char * (*d_dname)(struct dentry___327 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___328 *);
	int (*d_manage)(const struct path___328 *, bool);
	struct dentry___327 * (*d_real)(struct dentry___327 *, const struct inode___328 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___327;

struct mem_dqinfo___327 {
	struct quota_format_type___327 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___327;

struct quota_info___327 {
	unsigned int flags;
	struct rw_semaphore___329 dqio_sem;
	struct inode___328 *files[3];
	struct mem_dqinfo___327 info[3];
	const struct quota_format_ops___327 *ops[3];
};

struct rcuwait___327 {
	struct task_struct___329 *task;
};

struct percpu_rw_semaphore___327 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___329 rw_sem;
	struct rcuwait___327 writer;
	int readers_block;
};

struct sb_writers___327 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___327 rw_sem[3];
};

struct file_system_type___327;

struct super_operations___327;

struct dquot_operations___327;

struct quotactl_ops___327;

struct user_namespace___231;

struct super_block___327 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___327 *s_type;
	const struct super_operations___327 *s_op;
	const struct dquot_operations___327 *dq_op;
	const struct quotactl_ops___327 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___327 *s_root;
	struct rw_semaphore___329 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___327 *s_bdev;
	struct backing_dev_info___156 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___327 s_dquot;
	struct sb_writers___327 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___327 *s_d_op;
	int cleancache_poolid;
	struct shrinker___122 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___231 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct path___328 {
	struct vfsmount *mnt;
	struct dentry___327 *dentry;
};

struct key___305;

struct ucounts___231;

struct user_namespace___231 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___231 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___9 ns;
	long unsigned int flags;
	struct key___305 *persistent_keyring_register;
	struct rw_semaphore___329 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___231 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___329 *pgtable_t___328;

struct dev_pagemap___316;

struct page___329 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___327 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___329 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___328 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___328 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___316 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___328;

struct lruvec___328 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___328 *pgdat;
};

struct zone___328 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___328 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___328 {
	struct zone___328 *zone;
	int zone_idx;
};

struct zonelist___328 {
	struct zoneref___328 _zonerefs[25];
};

struct pglist_data___328 {
	struct zone___328 node_zones[3];
	struct zonelist___328 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___329 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___329 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___328 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___329 {
	void *stack;
	struct task_struct___329 *task;
	long int status;
};

struct blocking_notifier_head___328 {
	struct rw_semaphore___329 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___316;

struct vm_area_struct___329 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___329 *vm_next;
	struct vm_area_struct___329 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___328 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___316 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___328 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___328;

struct mm_struct___328 {
	struct {
		struct vm_area_struct___329 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___328 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___329 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___328 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___329 *owner;
		struct user_namespace___231 *user_ns;
		struct file___328 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___328 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___316)(struct vm_area_struct___329 *, long unsigned int, const struct page___329 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___316)(struct page___329 *, void *);

struct device___294;

struct dev_pagemap___316 {
	dev_page_fault_t___316 page_fault;
	dev_page_free_t___316 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___294 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct file___328 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___328 f_path;
	struct inode___328 *f_inode;
	const struct file_operations___328 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___209 f_owner;
	const struct cred___305 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___327 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___316;

struct vm_operations_struct___316 {
	void (*open)(struct vm_area_struct___329 *);
	void (*close)(struct vm_area_struct___329 *);
	int (*split)(struct vm_area_struct___329 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___329 *);
	vm_fault_t (*fault)(struct vm_fault___316 *);
	vm_fault_t (*huge_fault)(struct vm_fault___316 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___316 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___329 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___316 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___316 *);
	int (*access)(struct vm_area_struct___329 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___329 *);
	int (*set_policy)(struct vm_area_struct___329 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___329 *, long unsigned int);
	struct page___329 * (*find_special_page)(struct vm_area_struct___329 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___328 {
	struct task_struct___329 *task;
	struct core_thread___328 *next;
};

struct core_state___328 {
	atomic_t nr_threads;
	struct core_thread___328 dumper;
	struct completion startup;
};

struct vm_fault___316 {
	struct vm_area_struct___329 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___329 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___329 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___328 prealloc_pte;
};

struct user_struct___305 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___305 *uid_keyring;
	struct key___305 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___305 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___305 *session_keyring;
	struct key___305 *process_keyring;
	struct key___305 *thread_keyring;
	struct key___305 *request_key_auth;
	void *security;
	struct user_struct___305 *user;
	struct user_namespace___231 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___216;

struct nsproxy___260 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___216 *cgroup_ns;
};

struct bio___156;

struct bio_list___156 {
	struct bio___156 *head;
	struct bio___156 *tail;
};

struct bdi_writeback_congested___156;

struct cgroup_subsys_state___216;

struct bdi_writeback___156 {
	struct backing_dev_info___156 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___156 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___216 *memcg_css;
	struct cgroup_subsys_state___216 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___156 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___156 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___294 *dev;
	struct device___294 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___327 *debug_dir;
	struct dentry___327 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___84;

struct io_context___84 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___84 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___216;

struct css_set___216 {
	struct cgroup_subsys_state___216 *subsys[13];
	refcount_t refcount;
	struct css_set___216 *dom_cset;
	struct cgroup___216 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___216 *mg_src_cgrp;
	struct cgroup___216 *mg_dst_cgrp;
	struct css_set___216 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

typedef blk_qc_t make_request_fn___80(struct request_queue___80 *, struct bio___156 *);

struct request___80;

typedef int dma_drain_needed_fn___80(struct request___80 *);

struct kset___314;

struct kobj_type___314;

struct kernfs_node___322;

struct kobject___315 {
	const char *name;
	struct list_head entry;
	struct kobject___315 *parent;
	struct kset___314 *kset;
	struct kobj_type___314 *ktype;
	struct kernfs_node___322 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___80;

struct bsg_class_device___80 {
	struct device___294 *class_dev;
	int minor;
	struct request_queue___80 *queue;
	const struct bsg_ops___80 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___156 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___156 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___80;

struct blkcg_gq___56;

struct request_queue___80 {
	struct list_head queue_head;
	struct request___80 *last_merge;
	struct elevator_queue___80 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___80 *make_request_fn;
	dma_drain_needed_fn___80 *dma_drain_needed;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___156 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___315 kobj;
	struct kobject___315 *mq_kobj;
	struct blk_integrity integrity;
	struct device___294 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___56 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	struct bsg_class_device___80 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___156 bio_split;
	struct dentry___327 *debugfs_dir;
	struct dentry___327 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___239 {
	struct vm_struct___239 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___329 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct io_cq___84 {
	struct request_queue___80 *q;
	struct io_context___84 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___328 {
	struct file___328 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___328 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___327 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___328 *ia_file;
};

struct dquot___327 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___327 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___327 {
	int qf_fmt_id;
	const struct quota_format_ops___327 *qf_ops;
	struct module___267 *qf_owner;
	struct quota_format_type___327 *qf_next;
};

struct quota_format_ops___327 {
	int (*check_quota_file)(struct super_block___327 *, int);
	int (*read_file_info)(struct super_block___327 *, int);
	int (*write_file_info)(struct super_block___327 *, int);
	int (*free_file_info)(struct super_block___327 *, int);
	int (*read_dqblk)(struct dquot___327 *);
	int (*commit_dqblk)(struct dquot___327 *);
	int (*release_dqblk)(struct dquot___327 *);
	int (*get_next_id)(struct super_block___327 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___327 {
	int (*write_dquot)(struct dquot___327 *);
	struct dquot___327 * (*alloc_dquot)(struct super_block___327 *, int);
	void (*destroy_dquot)(struct dquot___327 *);
	int (*acquire_dquot)(struct dquot___327 *);
	int (*release_dquot)(struct dquot___327 *);
	int (*mark_dirty)(struct dquot___327 *);
	int (*write_info)(struct super_block___327 *, int);
	qsize_t * (*get_reserved_space)(struct inode___328 *);
	int (*get_projid)(struct inode___328 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___328 *, qsize_t *);
	int (*get_next_id)(struct super_block___327 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___327 {
	int (*quota_on)(struct super_block___327 *, int, int, const struct path___328 *);
	int (*quota_off)(struct super_block___327 *, int);
	int (*quota_enable)(struct super_block___327 *, unsigned int);
	int (*quota_disable)(struct super_block___327 *, unsigned int);
	int (*quota_sync)(struct super_block___327 *, int);
	int (*set_info)(struct super_block___327 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___327 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___327 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___327 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___327 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___327 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___264 {
	struct kobject___315 kobj;
	struct module___267 *mod;
	struct kobject___315 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___264 {
	struct module___267 *mod;
	struct latch_tree_node node;
};

struct module_layout___264 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___264 mtn;
};

struct module_attribute___264;

struct kernel_param___264;

struct module___267 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___264 mkobj;
	struct module_attribute___264 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___315 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___264 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___264 core_layout;
	struct module_layout___264 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide40;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide41;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___139;

struct address_space_operations___327 {
	int (*writepage)(struct page___329 *, struct writeback_control___139 *);
	int (*readpage)(struct file___328 *, struct page___329 *);
	int (*writepages)(struct address_space___327 *, struct writeback_control___139 *);
	int (*set_page_dirty)(struct page___329 *);
	int (*readpages)(struct file___328 *, struct address_space___327 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___328 *, struct address_space___327 *, loff_t, unsigned int, unsigned int, struct page___329 **, void **);
	int (*write_end)(struct file___328 *, struct address_space___327 *, loff_t, unsigned int, unsigned int, struct page___329 *, void *);
	sector_t (*bmap)(struct address_space___327 *, sector_t);
	void (*invalidatepage)(struct page___329 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___329 *, gfp_t);
	void (*freepage)(struct page___329 *);
	ssize_t (*direct_IO)(struct kiocb___328 *, struct iov_iter___143 *);
	int (*migratepage)(struct address_space___327 *, struct page___329 *, struct page___329 *, enum migrate_mode);
	bool (*isolate_page)(struct page___329 *, isolate_mode_t);
	void (*putback_page)(struct page___329 *);
	int (*launder_page)(struct page___329 *);
	int (*is_partially_uptodate)(struct page___329 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___329 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___327 *, struct page___329 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___328 *, sector_t *);
	void (*swap_deactivate)(struct file___328 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___139 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___156 *wb;
	struct inode___328 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___157;

struct iov_iter___143 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___157 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct hd_struct___82;

struct gendisk___82;

struct block_device___327 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___328 *bd_inode;
	struct super_block___327 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___327 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___82 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___82 *bd_disk;
	struct request_queue___80 *bd_queue;
	struct backing_dev_info___156 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___294 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___3 *subsys_data;
	void (*set_latency_tolerance)(struct device___294 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___294;

struct bus_type___294;

struct device_driver___294;

struct dev_pm_domain___294;

struct fwnode_handle___223;

struct class___294;

struct attribute_group___292;

struct device___294 {
	struct device___294 *parent;
	struct device_private *p;
	struct kobject___315 kobj;
	const char *init_name;
	const struct device_type___294 *type;
	struct mutex mutex;
	struct bus_type___294 *bus;
	struct device_driver___294 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___294 power;
	struct dev_pm_domain___294 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___223 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___294 *class;
	const struct attribute_group___292 **groups;
	void (*release)(struct device___294 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___82 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___294 __dev;
	struct kobject___315 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___82;

struct block_device_operations___81;

struct gendisk___82 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___82 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___82 *part_tbl;
	struct hd_struct___82 part0;
	const struct block_device_operations___81 *fops;
	struct request_queue___80 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___329 lookup_sem;
	struct kobject___315 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___315 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___75 {
	struct kobject___315 kobj;
	struct module___267 *owner;
	const struct file_operations___328 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___327 {
	struct dentry___327 * (*lookup)(struct inode___328 *, struct dentry___327 *, unsigned int);
	const char * (*get_link)(struct dentry___327 *, struct inode___328 *, struct delayed_call *);
	int (*permission)(struct inode___328 *, int);
	struct posix_acl * (*get_acl)(struct inode___328 *, int);
	int (*readlink)(struct dentry___327 *, char *, int);
	int (*create)(struct inode___328 *, struct dentry___327 *, umode_t, bool);
	int (*link)(struct dentry___327 *, struct inode___328 *, struct dentry___327 *);
	int (*unlink)(struct inode___328 *, struct dentry___327 *);
	int (*symlink)(struct inode___328 *, struct dentry___327 *, const char *);
	int (*mkdir)(struct inode___328 *, struct dentry___327 *, umode_t);
	int (*rmdir)(struct inode___328 *, struct dentry___327 *);
	int (*mknod)(struct inode___328 *, struct dentry___327 *, umode_t, dev_t);
	int (*rename)(struct inode___328 *, struct dentry___327 *, struct inode___328 *, struct dentry___327 *, unsigned int);
	int (*setattr)(struct dentry___327 *, struct iattr___327 *);
	int (*getattr)(const struct path___328 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___327 *, char *, size_t);
	int (*fiemap)(struct inode___328 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___328 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___328 *, struct dentry___327 *, struct file___328 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___328 *, struct dentry___327 *, umode_t);
	int (*set_acl)(struct inode___328 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___327 {
	void (*fl_copy_lock)(struct file_lock___328 *, struct file_lock___328 *);
	void (*fl_release_private)(struct file_lock___328 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___327;

struct lock_manager_operations___327;

struct file_lock___328 {
	struct file_lock___328 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___328 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___327 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___327 *fl_ops;
	const struct lock_manager_operations___327 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___327 {
	int (*lm_compare_owner)(struct file_lock___328 *, struct file_lock___328 *);
	long unsigned int (*lm_owner_key)(struct file_lock___328 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___328 *);
	int (*lm_grant)(struct file_lock___328 *, int);
	bool (*lm_break)(struct file_lock___328 *);
	int (*lm_change)(struct file_lock___328 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___328 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___327 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___327 *fa_next;
	struct file___328 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___327 {
	const char *name;
	int fs_flags;
	struct dentry___327 * (*mount)(struct file_system_type___327 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___327 *);
	struct module___267 *owner;
	struct file_system_type___327 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___327 {
	struct inode___328 * (*alloc_inode)(struct super_block___327 *);
	void (*destroy_inode)(struct inode___328 *);
	void (*dirty_inode)(struct inode___328 *, int);
	int (*write_inode)(struct inode___328 *, struct writeback_control___139 *);
	int (*drop_inode)(struct inode___328 *);
	void (*evict_inode)(struct inode___328 *);
	void (*put_super)(struct super_block___327 *);
	int (*sync_fs)(struct super_block___327 *, int);
	int (*freeze_super)(struct super_block___327 *);
	int (*freeze_fs)(struct super_block___327 *);
	int (*thaw_super)(struct super_block___327 *);
	int (*unfreeze_fs)(struct super_block___327 *);
	int (*statfs)(struct dentry___327 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___327 *, int *, char *);
	void (*umount_begin)(struct super_block___327 *);
	int (*show_options)(struct seq_file___279 *, struct dentry___327 *);
	int (*show_devname)(struct seq_file___279 *, struct dentry___327 *);
	int (*show_path)(struct seq_file___279 *, struct dentry___327 *);
	int (*show_stats)(struct seq_file___279 *, struct dentry___327 *);
	ssize_t (*quota_read)(struct super_block___327 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___327 *, int, const char *, size_t, loff_t);
	struct dquot___327 ** (*get_dquots)(struct inode___328 *);
	int (*bdev_try_to_free_page)(struct super_block___327 *, struct page___329 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___327 *, struct shrink_control___122 *);
	long int (*free_cached_objects)(struct super_block___327 *, struct shrink_control___122 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___278;

struct seq_file___279 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___278 *op;
	int poll_event;
	const struct file___328 *file;
	void *private;
};

typedef void bio_end_io_t___156(struct bio___156 *);

struct bio_vec___157 {
	struct page___329 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___156;

struct bio___156 {
	struct bio___156 *bi_next;
	struct gendisk___82 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___156 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___56 *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___156 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___157 *bi_io_vec;
	struct bio_set___156 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___157 bi_inline_vecs[0];
};

struct bio_integrity_payload___156 {
	struct bio___156 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___157 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___157 bip_inline_vecs[0];
};

struct blkcg___56;

struct blkg_policy_data___56;

struct blkcg_gq___56 {
	struct request_queue___80 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___56 *blkcg;
	struct bdi_writeback_congested___156 *wb_congested;
	struct blkcg_gq___56 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_rwstat stat_bytes;
	struct blkg_rwstat stat_ios;
	struct blkg_policy_data___56 *pd[5];
	struct callback_head callback_head;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
};

struct dev_pm_ops___294;

struct device_type___294 {
	const char *name;
	const struct attribute_group___292 **groups;
	int (*uevent)(struct device___294 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___294 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___294 *);
	const struct dev_pm_ops___294 *pm;
};

struct class___294 {
	const char *name;
	struct module___267 *owner;
	const struct attribute_group___292 **class_groups;
	const struct attribute_group___292 **dev_groups;
	struct kobject___315 *dev_kobj;
	int (*dev_uevent)(struct device___294 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___294 *, umode_t *);
	void (*class_release)(struct class___294 *);
	void (*dev_release)(struct device___294 *);
	int (*shutdown_pre)(struct device___294 *);
	const struct kobj_ns_type_operations___25 *ns_type;
	const void * (*namespace)(struct device___294 *);
	const struct dev_pm_ops___294 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct kernfs_root___321;

struct kernfs_elem_dir___321 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___321 *root;
};

struct kernfs_syscall_ops___321;

struct kernfs_root___321 {
	struct kernfs_node___322 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___321 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___321 {
	struct kernfs_node___322 *target_kn;
};

struct kernfs_ops___321;

struct kernfs_elem_attr___321 {
	const struct kernfs_ops___321 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___322 *notify_next;
};

struct kernfs_node___322 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___322 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___321 dir;
		struct kernfs_elem_symlink___321 symlink;
		struct kernfs_elem_attr___321 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___321;

struct kernfs_ops___321 {
	int (*open)(struct kernfs_open_file___321 *);
	void (*release)(struct kernfs_open_file___321 *);
	int (*seq_show)(struct seq_file___279 *, void *);
	void * (*seq_start)(struct seq_file___279 *, loff_t *);
	void * (*seq_next)(struct seq_file___279 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___279 *, void *);
	ssize_t (*read)(struct kernfs_open_file___321 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___321 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___321 *, struct vm_area_struct___329 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___321 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___321 {
	int (*remount_fs)(struct kernfs_root___321 *, int *, char *);
	int (*show_options)(struct seq_file___279 *, struct kernfs_root___321 *);
	int (*mkdir)(struct kernfs_node___322 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___322 *);
	int (*rename)(struct kernfs_node___322 *, struct kernfs_node___322 *, const char *);
	int (*show_path)(struct seq_file___279 *, struct kernfs_node___322 *, struct kernfs_root___321 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___321 {
	struct kernfs_node___322 *kn;
	struct file___328 *file;
	struct seq_file___279 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___316 *vm_ops;
};

struct bin_attribute___291;

struct attribute_group___292 {
	const char *name;
	umode_t (*is_visible)(struct kobject___315 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___315 *, struct bin_attribute___291 *, int);
	struct attribute **attrs;
	struct bin_attribute___291 **bin_attrs;
};

struct bin_attribute___291 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___328 *, struct kobject___315 *, struct bin_attribute___291 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___328 *, struct kobject___315 *, struct bin_attribute___291 *, char *, loff_t, size_t);
	int (*mmap)(struct file___328 *, struct kobject___315 *, struct bin_attribute___291 *, struct vm_area_struct___329 *);
};

struct sysfs_ops___314 {
	ssize_t (*show)(struct kobject___315 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___315 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___314;

struct kset___314 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___315 kobj;
	const struct kset_uevent_ops___314 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___314 {
	void (*release)(struct kobject___315 *);
	const struct sysfs_ops___314 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___25 * (*child_ns_type)(struct kobject___315 *);
	const void * (*namespace)(struct kobject___315 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___314 {
	int (* const filter)(struct kset___314 *, struct kobject___315 *);
	const char * (* const name)(struct kset___314 *, struct kobject___315 *);
	int (* const uevent)(struct kset___314 *, struct kobject___315 *, struct kobj_uevent_env *);
};

struct kobj_attribute___306 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___315 *, struct kobj_attribute___306 *, char *);
	ssize_t (*store)(struct kobject___315 *, struct kobj_attribute___306 *, const char *, size_t);
};

struct dev_pm_ops___294 {
	int (*prepare)(struct device___294 *);
	void (*complete)(struct device___294 *);
	int (*suspend)(struct device___294 *);
	int (*resume)(struct device___294 *);
	int (*freeze)(struct device___294 *);
	int (*thaw)(struct device___294 *);
	int (*poweroff)(struct device___294 *);
	int (*restore)(struct device___294 *);
	int (*suspend_late)(struct device___294 *);
	int (*resume_early)(struct device___294 *);
	int (*freeze_late)(struct device___294 *);
	int (*thaw_early)(struct device___294 *);
	int (*poweroff_late)(struct device___294 *);
	int (*restore_early)(struct device___294 *);
	int (*suspend_noirq)(struct device___294 *);
	int (*resume_noirq)(struct device___294 *);
	int (*freeze_noirq)(struct device___294 *);
	int (*thaw_noirq)(struct device___294 *);
	int (*poweroff_noirq)(struct device___294 *);
	int (*restore_noirq)(struct device___294 *);
	int (*runtime_suspend)(struct device___294 *);
	int (*runtime_resume)(struct device___294 *);
	int (*runtime_idle)(struct device___294 *);
};

struct dev_pm_domain___294 {
	struct dev_pm_ops___294 ops;
	void (*detach)(struct device___294 *, bool);
	int (*activate)(struct device___294 *);
	void (*sync)(struct device___294 *);
	void (*dismiss)(struct device___294 *);
};

struct bus_type___294 {
	const char *name;
	const char *dev_name;
	struct device___294 *dev_root;
	const struct attribute_group___292 **bus_groups;
	const struct attribute_group___292 **dev_groups;
	const struct attribute_group___292 **drv_groups;
	int (*match)(struct device___294 *, struct device_driver___294 *);
	int (*uevent)(struct device___294 *, struct kobj_uevent_env *);
	int (*probe)(struct device___294 *);
	int (*remove)(struct device___294 *);
	void (*shutdown)(struct device___294 *);
	int (*online)(struct device___294 *);
	int (*offline)(struct device___294 *);
	int (*suspend)(struct device___294 *, pm_message_t);
	int (*resume)(struct device___294 *);
	int (*num_vf)(struct device___294 *);
	int (*dma_configure)(struct device___294 *);
	const struct dev_pm_ops___294 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___294 {
	const char *name;
	struct bus_type___294 *bus;
	struct module___267 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___294 *);
	int (*remove)(struct device___294 *);
	void (*shutdown)(struct device___294 *);
	int (*suspend)(struct device___294 *, pm_message_t);
	int (*resume)(struct device___294 *);
	const struct attribute_group___292 **groups;
	const struct dev_pm_ops___294 *pm;
	void (*coredump)(struct device___294 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct fwnode_operations___223;

struct fwnode_handle___223 {
	struct fwnode_handle___223 *secondary;
	const struct fwnode_operations___223 *ops;
};

struct disk_part_tbl___82 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___82 *last_lookup;
	struct hd_struct___82 *part[0];
};

struct block_device_operations___81 {
	int (*open)(struct block_device___327 *, fmode_t);
	void (*release)(struct gendisk___82 *, fmode_t);
	int (*rw_page)(struct block_device___327 *, sector_t, struct page___329 *, unsigned int);
	int (*ioctl)(struct block_device___327 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___327 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___82 *, unsigned int);
	int (*media_changed)(struct gendisk___82 *);
	void (*unlock_native_capacity)(struct gendisk___82 *);
	int (*revalidate_disk)(struct gendisk___82 *);
	int (*getgeo)(struct block_device___327 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___327 *, long unsigned int);
	int (*report_zones)(struct gendisk___82 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___267 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___316(struct page___329 *);

struct bdi_writeback_congested___156 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___156 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct cgroup_subsys___216;

struct cgroup_subsys_state___216 {
	struct cgroup___216 *cgroup;
	struct cgroup_subsys___216 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___216 *parent;
};

struct bsg_ops___80 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___80 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___80 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___80 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___80(struct request___80 *, blk_status_t);

struct request___80 {
	struct request_queue___80 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___156 *bio;
	struct bio___156 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___157 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___84 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___80 *saved_end_io;
		} flush;
	};
	struct gendisk___82 *rq_disk;
	struct hd_struct___82 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___80 *end_io;
	void *end_io_data;
	struct request___80 *next_rq;
};

struct fwnode_reference_args___223;

struct fwnode_endpoint___223;

struct fwnode_operations___223 {
	struct fwnode_handle___223 * (*get)(struct fwnode_handle___223 *);
	void (*put)(struct fwnode_handle___223 *);
	bool (*device_is_available)(const struct fwnode_handle___223 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___223 *, const struct device___294 *);
	bool (*property_present)(const struct fwnode_handle___223 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___223 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___223 *, const char *, const char **, size_t);
	struct fwnode_handle___223 * (*get_parent)(const struct fwnode_handle___223 *);
	struct fwnode_handle___223 * (*get_next_child_node)(const struct fwnode_handle___223 *, struct fwnode_handle___223 *);
	struct fwnode_handle___223 * (*get_named_child_node)(const struct fwnode_handle___223 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___223 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___223 *);
	struct fwnode_handle___223 * (*graph_get_next_endpoint)(const struct fwnode_handle___223 *, struct fwnode_handle___223 *);
	struct fwnode_handle___223 * (*graph_get_remote_endpoint)(const struct fwnode_handle___223 *);
	struct fwnode_handle___223 * (*graph_get_port_parent)(struct fwnode_handle___223 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___223 *, struct fwnode_endpoint___223 *);
};

struct fwnode_endpoint___223 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___223 *local_fwnode;
};

struct fwnode_reference_args___223 {
	struct fwnode_handle___223 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct elevator_type___80;

struct elevator_mq_ops___80 {
	int (*init_sched)(struct request_queue___80 *, struct elevator_type___80 *);
	void (*exit_sched)(struct elevator_queue___80 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	bool (*allow_merge)(struct request_queue___80 *, struct request___80 *, struct bio___156 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx *, struct bio___156 *);
	int (*request_merge)(struct request_queue___80 *, struct request___80 **, struct bio___156 *);
	void (*request_merged)(struct request_queue___80 *, struct request___80 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___80 *, struct request___80 *, struct request___80 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___80 *, struct bio___156 *);
	void (*finish_request)(struct request___80 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___80 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___80 *, u64);
	void (*started_request)(struct request___80 *);
	void (*requeue_request)(struct request___80 *);
	struct request___80 * (*former_request)(struct request_queue___80 *, struct request___80 *);
	struct request___80 * (*next_request)(struct request_queue___80 *, struct request___80 *);
	void (*init_icq)(struct io_cq___84 *);
	void (*exit_icq)(struct io_cq___84 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx___19 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___80;

struct elevator_type___80 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___80 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___80 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___267 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___80 {
	struct elevator_type___80 *type;
	void *elevator_data;
	struct kobject___315 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___80 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___80 *, char *);
	ssize_t (*store)(struct elevator_queue___80 *, const char *, size_t);
};

typedef int (*key_restrict_link_func_t___306)(struct key___305 *, const struct key_type *, const union key_payload *, struct key___305 *);

struct key_restriction___305;

struct key___305 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___329 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___305 *restrict_link;
};

struct key_restriction___305 {
	key_restrict_link_func_t___306 check;
	struct key___305 *key;
	struct key_type *keytype;
};

struct seq_operations___278 {
	void * (*start)(struct seq_file___279 *, loff_t *);
	void (*stop)(struct seq_file___279 *, void *);
	void * (*next)(struct seq_file___279 *, void *, loff_t *);
	int (*show)(struct seq_file___279 *, void *);
};

struct cgroup_namespace___216 {
	refcount_t count;
	struct ns_common___9 ns;
	struct user_namespace___231 *user_ns;
	struct ucounts___231 *ucounts;
	struct css_set___216 *root_cset;
};

struct ucounts___231 {
	struct hlist_node node;
	struct user_namespace___231 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___217;

struct bpf_map_ops___216 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___217 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___217 *, struct file___328 *);
	void (*map_free)(struct bpf_map___217 *);
	int (*map_get_next_key)(struct bpf_map___217 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___217 *);
	void * (*map_lookup_elem)(struct bpf_map___217 *, void *);
	int (*map_update_elem)(struct bpf_map___217 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___217 *, void *);
	int (*map_push_elem)(struct bpf_map___217 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___217 *, void *);
	int (*map_peek_elem)(struct bpf_map___217 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___217 *, struct file___328 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___217 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___217 *, void *, struct seq_file___279 *);
	int (*map_check_btf)(const struct bpf_map___217 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___217 {
	const struct bpf_map_ops___216 *ops;
	struct bpf_map___217 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___305 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___216;

typedef void (*kthread_work_func_t___216)(struct kthread_work___216 *);

struct kthread_worker___216;

struct kthread_work___216 {
	struct list_head node;
	kthread_work_func_t___216 func;
	struct kthread_worker___216 *worker;
	int canceling;
};

struct kthread_worker___216 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___329 *task;
	struct kthread_work___216 *current_work;
};

struct kthread_delayed_work___216 {
	struct kthread_work___216 work;
	struct timer_list timer;
};

struct psi_group___216 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___216 *poll_kworker;
	struct kthread_delayed_work___216 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___216 {
	struct kernfs_node___322 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_root___216;

struct cgroup_rstat_cpu___216;

struct cgroup___216 {
	struct cgroup_subsys_state___216 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___322 *kn;
	struct cgroup_file___216 procs_file;
	struct cgroup_file___216 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___216 *subsys[13];
	struct cgroup_root___216 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___216 *dom_cgrp;
	struct cgroup_rstat_cpu___216 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___35 bpf;
	atomic_t congestion_count;
	struct cgroup___216 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___216 psi;
	int ancestor_ids[0];
};

struct cftype___216;

struct cgroup_subsys___216 {
	struct cgroup_subsys_state___216 * (*css_alloc)(struct cgroup_subsys_state___216 *);
	int (*css_online)(struct cgroup_subsys_state___216 *);
	void (*css_offline)(struct cgroup_subsys_state___216 *);
	void (*css_released)(struct cgroup_subsys_state___216 *);
	void (*css_free)(struct cgroup_subsys_state___216 *);
	void (*css_reset)(struct cgroup_subsys_state___216 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___216 *, int);
	int (*css_extra_stat_show)(struct seq_file___279 *, struct cgroup_subsys_state___216 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___329 *);
	void (*cancel_fork)(struct task_struct___329 *);
	void (*fork)(struct task_struct___329 *);
	void (*exit)(struct task_struct___329 *);
	void (*free)(struct task_struct___329 *);
	void (*bind)(struct cgroup_subsys_state___216 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___216 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___216 *dfl_cftypes;
	struct cftype___216 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___216 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___216 *updated_children;
	struct cgroup___216 *updated_next;
};

struct cgroup_root___216 {
	struct kernfs_root___321 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___216 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___216 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___216 *ss;
	struct list_head node;
	struct kernfs_ops___321 *kf_ops;
	int (*open)(struct kernfs_open_file___321 *);
	void (*release)(struct kernfs_open_file___321 *);
	u64 (*read_u64)(struct cgroup_subsys_state___216 *, struct cftype___216 *);
	s64 (*read_s64)(struct cgroup_subsys_state___216 *, struct cftype___216 *);
	int (*seq_show)(struct seq_file___279 *, void *);
	void * (*seq_start)(struct seq_file___279 *, loff_t *);
	void * (*seq_next)(struct seq_file___279 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___279 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___216 *, struct cftype___216 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___216 *, struct cftype___216 *, s64);
	ssize_t (*write)(struct kernfs_open_file___321 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___321 *, struct poll_table_struct___6 *);
};

struct blkcg_policy_data___56;

struct blkcg___56 {
	struct cgroup_subsys_state___216 css;
	spinlock_t lock;
	struct xarray blkg_tree;
	struct blkcg_gq___56 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___56 *cpd[5];
	struct list_head all_blkcgs_node;
	struct list_head cgwb_list;
	refcount_t cgwb_refcnt;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct blkcg_policy_data___56 {
	struct blkcg___56 *blkcg;
	int plid;
};

struct blkg_policy_data___56 {
	struct blkcg_gq___56 *blkg;
	int plid;
};

struct kernel_param_ops___264 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___264 *);
	int (*get)(char *, const struct kernel_param___264 *);
	void (*free)(void *);
};

struct kparam_array___264;

struct kernel_param___264 {
	const char *name;
	struct module___267 *mod;
	const struct kernel_param_ops___264 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___264 *arr;
	};
};

struct kparam_array___264 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___264 *ops;
	void *elem;
};

struct module_attribute___264 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___264 *, struct module_kobject___264 *, char *);
	ssize_t (*store)(struct module_attribute___264 *, struct module_kobject___264 *, const char *, size_t);
	void (*setup)(struct module___267 *, const char *);
	int (*test)(struct module___267 *);
	void (*free)(struct module___267 *);
};

struct raw_config_request {
	int raw_minor;
	__u64 block_major;
	__u64 block_minor;
};

struct raw_device_data {
	struct block_device___327 *binding;
	int inuse;
};

struct device_attribute___27 {
	struct attribute attr;
	ssize_t (*show)(struct device___71 *, struct device_attribute___27 *, char *);
	ssize_t (*store)(struct device___71 *, struct device_attribute___27 *, const char *, size_t);
};

typedef void (*dr_release_t___16)(struct device___71 *, void *);

struct hwrng {
	const char *name;
	int (*init)(struct hwrng *);
	void (*cleanup)(struct hwrng *);
	int (*data_present)(struct hwrng *, int);
	int (*data_read)(struct hwrng *, u32 *);
	int (*read)(struct hwrng *, void *, size_t, bool);
	long unsigned int priv;
	short unsigned int quality;
	struct list_head list;
	struct kref ref;
	struct completion cleanup_done;
};

struct miscdevice___6 {
	int minor;
	const char *name;
	const struct file_operations___76 *fops;
	struct list_head list;
	struct device___71 *parent;
	struct device___71 *this_device;
	const struct attribute_group___70 **groups;
	const char *nodename;
	umode_t mode;
};

struct virtrng_info {
	struct hwrng hwrng;
	struct virtqueue___3 *vq;
	struct completion have_data;
	char name[25];
	unsigned int data_avail;
	int index;
	bool busy;
	bool hwrng_register_done;
	bool hwrng_removed;
};

struct hisi_rng {
	void *base;
	struct hwrng rng;
};

struct tpm_bank_info {
	u16 alg_id;
	u16 digest_size;
	u16 crypto_id;
};

struct tpm_chip;

struct tpm_class_ops {
	unsigned int flags;
	const u8 req_complete_mask;
	const u8 req_complete_val;
	bool (*req_canceled)(struct tpm_chip *, u8);
	int (*recv)(struct tpm_chip *, u8 *, size_t);
	int (*send)(struct tpm_chip *, u8 *, size_t);
	void (*cancel)(struct tpm_chip *);
	u8 (*status)(struct tpm_chip *);
	void (*update_timeouts)(struct tpm_chip *, long unsigned int *);
	int (*go_idle)(struct tpm_chip *);
	int (*cmd_ready)(struct tpm_chip *);
	int (*request_locality)(struct tpm_chip *, int);
	int (*relinquish_locality)(struct tpm_chip *, int);
	void (*clk_enable)(struct tpm_chip *, bool);
};

struct tpm_bios_log {
	void *bios_event_log;
	void *bios_event_log_end;
};

struct tpm_chip_seqops {
	struct tpm_chip *chip;
	const struct seq_operations___262 *seqops;
};

struct tpm_space {
	u32 context_tbl[3];
	u8 *context_buf;
	u32 session_tbl[3];
	u8 *session_buf;
};

struct tpm_chip {
	struct device___276 dev;
	struct device___276 devs;
	struct cdev___61 cdev;
	struct cdev___61 cdevs;
	struct rw_semaphore___312 ops_sem;
	const struct tpm_class_ops *ops;
	struct tpm_bios_log log;
	struct tpm_chip_seqops bin_log_seqops;
	struct tpm_chip_seqops ascii_log_seqops;
	unsigned int flags;
	int dev_num;
	long unsigned int is_open;
	char hwrng_name[64];
	struct hwrng hwrng;
	struct mutex tpm_mutex;
	long unsigned int timeout_a;
	long unsigned int timeout_b;
	long unsigned int timeout_c;
	long unsigned int timeout_d;
	bool timeout_adjusted;
	long unsigned int duration[4];
	bool duration_adjusted;
	struct dentry___310 *bios_dir[3];
	const struct attribute_group___275 *groups[3];
	unsigned int groups_cnt;
	u32 nr_allocated_banks;
	struct tpm_bank_info *allocated_banks;
	acpi_handle acpi_dev_handle;
	char ppi_version[4];
	struct tpm_space work_space;
	u32 last_cc;
	u32 nr_commands;
	u32 *cc_attrs_tbl;
	int locality;
};

enum tpm_duration {
	TPM_SHORT = 0,
	TPM_MEDIUM = 1,
	TPM_LONG = 2,
	TPM_LONG_LONG = 3,
	TPM_UNDEFINED = 4,
	TPM_NUM_DURATIONS = 4,
};

enum tpm2_startup_types {
	TPM2_SU_CLEAR = 0,
	TPM2_SU_STATE = 1,
};

enum tpm_chip_flags {
	TPM_CHIP_FLAG_TPM2 = 2,
	TPM_CHIP_FLAG_IRQ = 4,
	TPM_CHIP_FLAG_VIRTUAL = 8,
	TPM_CHIP_FLAG_HAVE_TIMEOUTS = 16,
	TPM_CHIP_FLAG_ALWAYS_POWERED = 32,
};

typedef struct poll_table_struct___188 poll_table___28;

enum tpm2_structures {
	TPM2_ST_NO_SESSIONS = 32769,
	TPM2_ST_SESSIONS = 32770,
};

enum tpm2_return_codes {
	TPM2_RC_SUCCESS = 0,
	TPM2_RC_HASH = 131,
	TPM2_RC_HANDLE = 139,
	TPM2_RC_INITIALIZE = 256,
	TPM2_RC_FAILURE = 257,
	TPM2_RC_DISABLED = 288,
	TPM2_RC_COMMAND_CODE = 323,
	TPM2_RC_TESTING = 2314,
	TPM2_RC_REFERENCE_H0 = 2320,
	TPM2_RC_RETRY = 2338,
};

struct tpm_header {
	__be16 tag;
	__be32 length;
	union {
		__be32 ordinal;
		__be32 return_code;
	};
} __attribute__((packed));

struct file_priv {
	struct tpm_chip *chip;
	struct tpm_space *space;
	struct mutex buffer_mutex;
	struct timer_list user_read_timer;
	struct work_struct timeout_work;
	struct work_struct async_work;
	wait_queue_head_t async_wait;
	size_t response_length;
	bool response_read;
	bool command_enqueued;
	u8 data_buffer[4096];
};

struct module_version_attribute___4 {
	struct module_attribute___248 mattr;
	const char *module_name;
	const char *version;
};

struct tpm_digest {
	u16 alg_id;
	u8 digest[64];
};

enum TPM_OPS_FLAGS {
	TPM_OPS_AUTO_STARTUP = 1,
};

enum tpm_timeout {
	TPM_TIMEOUT = 5,
	TPM_TIMEOUT_RETRY = 100,
	TPM_TIMEOUT_RANGE_US = 300,
	TPM_TIMEOUT_POLL = 1,
	TPM_TIMEOUT_USECS_MIN = 100,
	TPM_TIMEOUT_USECS_MAX = 500,
};

enum tpm2_timeouts {
	TPM2_TIMEOUT_A = 750,
	TPM2_TIMEOUT_B = 2000,
	TPM2_TIMEOUT_C = 200,
	TPM2_TIMEOUT_D = 30,
	TPM2_DURATION_SHORT = 20,
	TPM2_DURATION_MEDIUM = 750,
	TPM2_DURATION_LONG = 2000,
	TPM2_DURATION_LONG_LONG = 300000,
	TPM2_DURATION_DEFAULT = 120000,
};

enum tpm2_command_codes {
	TPM2_CC_FIRST = 287,
	TPM2_CC_HIERARCHY_CONTROL = 289,
	TPM2_CC_HIERARCHY_CHANGE_AUTH = 297,
	TPM2_CC_CREATE_PRIMARY = 305,
	TPM2_CC_SEQUENCE_COMPLETE = 318,
	TPM2_CC_SELF_TEST = 323,
	TPM2_CC_STARTUP = 324,
	TPM2_CC_SHUTDOWN = 325,
	TPM2_CC_NV_READ = 334,
	TPM2_CC_CREATE = 339,
	TPM2_CC_LOAD = 343,
	TPM2_CC_SEQUENCE_UPDATE = 348,
	TPM2_CC_UNSEAL = 350,
	TPM2_CC_CONTEXT_LOAD = 353,
	TPM2_CC_CONTEXT_SAVE = 354,
	TPM2_CC_FLUSH_CONTEXT = 357,
	TPM2_CC_VERIFY_SIGNATURE = 375,
	TPM2_CC_GET_CAPABILITY = 378,
	TPM2_CC_GET_RANDOM = 379,
	TPM2_CC_PCR_READ = 382,
	TPM2_CC_PCR_EXTEND = 386,
	TPM2_CC_EVENT_SEQUENCE_COMPLETE = 389,
	TPM2_CC_HASH_SEQUENCE_START = 390,
	TPM2_CC_CREATE_LOADED = 401,
	TPM2_CC_LAST = 403,
};

struct tpm_buf {
	struct page___312 *data_page;
	unsigned int flags;
	u8 *data;
};

struct trusted_key_payload;

struct trusted_key_options;

enum tpm_algorithms {
	TPM_ALG_ERROR = 0,
	TPM_ALG_SHA1 = 4,
	TPM_ALG_KEYEDHASH = 8,
	TPM_ALG_SHA256 = 11,
	TPM_ALG_SHA384 = 12,
	TPM_ALG_SHA512 = 13,
	TPM_ALG_NULL = 16,
	TPM_ALG_SM3_256 = 18,
};

struct stclear_flags_t {
	__be16 tag;
	u8 deactivated;
	u8 disableForceClear;
	u8 physicalPresence;
	u8 physicalPresenceLock;
	u8 bGlobalLock;
} __attribute__((packed));

struct tpm_version_t {
	u8 Major;
	u8 Minor;
	u8 revMajor;
	u8 revMinor;
};

struct tpm_version_1_2_t {
	__be16 tag;
	u8 Major;
	u8 Minor;
	u8 revMajor;
	u8 revMinor;
};

struct timeout_t {
	__be32 a;
	__be32 b;
	__be32 c;
	__be32 d;
};

struct duration_t {
	__be32 tpm_short;
	__be32 tpm_medium;
	__be32 tpm_long;
};

struct permanent_flags_t {
	__be16 tag;
	u8 disable;
	u8 ownership;
	u8 deactivated;
	u8 readPubek;
	u8 disableOwnerClear;
	u8 allowMaintenance;
	u8 physicalPresenceLifetimeLock;
	u8 physicalPresenceHWEnable;
	u8 physicalPresenceCMDEnable;
	u8 CEKPUsed;
	u8 TPMpost;
	u8 TPMpostLock;
	u8 FIPS;
	u8 operator;
	u8 enableRevokeEK;
	u8 nvLocked;
	u8 readSRKPub;
	u8 tpmEstablished;
	u8 maintenanceDone;
	u8 disableFullDALogicInfo;
};

typedef union {
	struct permanent_flags_t perm_flags;
	struct stclear_flags_t stclear_flags;
	__u8 owned;
	__be32 num_pcrs;
	struct tpm_version_t tpm_version;
	struct tpm_version_1_2_t tpm_version_1_2;
	__be32 manufacturer_id;
	struct timeout_t timeout;
	struct duration_t duration;
} cap_t;

enum tpm_capabilities {
	TPM_CAP_FLAG = 4,
	TPM_CAP_PROP = 5,
	TPM_CAP_VERSION_1_1 = 6,
	TPM_CAP_VERSION_1_2 = 26,
};

enum tpm_sub_capabilities {
	TPM_CAP_PROP_PCR = 257,
	TPM_CAP_PROP_MANUFACTURER = 259,
	TPM_CAP_FLAG_PERM = 264,
	TPM_CAP_FLAG_VOL = 265,
	TPM_CAP_PROP_OWNER = 273,
	TPM_CAP_PROP_TIS_TIMEOUT = 277,
	TPM_CAP_PROP_TIS_DURATION = 288,
};

enum tpm_buf_flags {
	TPM_BUF_OVERFLOW = 1,
};

struct tpm1_get_random_out {
	__be32 rng_data_len;
	u8 rng_data[128];
};

struct tpm_chip___2;

struct tpm_class_ops___2 {
	unsigned int flags;
	const u8 req_complete_mask;
	const u8 req_complete_val;
	bool (*req_canceled)(struct tpm_chip___2 *, u8);
	int (*recv)(struct tpm_chip___2 *, u8 *, size_t);
	int (*send)(struct tpm_chip___2 *, u8 *, size_t);
	void (*cancel)(struct tpm_chip___2 *);
	u8 (*status)(struct tpm_chip___2 *);
	void (*update_timeouts)(struct tpm_chip___2 *, long unsigned int *);
	int (*go_idle)(struct tpm_chip___2 *);
	int (*cmd_ready)(struct tpm_chip___2 *);
	int (*request_locality)(struct tpm_chip___2 *, int);
	int (*relinquish_locality)(struct tpm_chip___2 *, int);
	void (*clk_enable)(struct tpm_chip___2 *, bool);
};

struct tpm_chip_seqops___2 {
	struct tpm_chip___2 *chip;
	const struct seq_operations___275 *seqops;
};

struct tpm_chip___2 {
	struct device___291 dev;
	struct device___291 devs;
	struct cdev___73 cdev;
	struct cdev___73 cdevs;
	struct rw_semaphore___326 ops_sem;
	const struct tpm_class_ops___2 *ops;
	struct tpm_bios_log log;
	struct tpm_chip_seqops___2 bin_log_seqops;
	struct tpm_chip_seqops___2 ascii_log_seqops;
	unsigned int flags;
	int dev_num;
	long unsigned int is_open;
	char hwrng_name[64];
	struct hwrng hwrng;
	struct mutex tpm_mutex;
	long unsigned int timeout_a;
	long unsigned int timeout_b;
	long unsigned int timeout_c;
	long unsigned int timeout_d;
	bool timeout_adjusted;
	long unsigned int duration[4];
	bool duration_adjusted;
	struct dentry___324 *bios_dir[3];
	const struct attribute_group___289 *groups[3];
	unsigned int groups_cnt;
	u32 nr_allocated_banks;
	struct tpm_bank_info *allocated_banks;
	acpi_handle acpi_dev_handle;
	char ppi_version[4];
	struct tpm_space work_space;
	u32 last_cc;
	u32 nr_commands;
	u32 *cc_attrs_tbl;
	int locality;
};

enum tpm2_const {
	TPM2_PLATFORM_PCR = 24,
	TPM2_PCR_SELECT_MIN = 3,
};

enum tpm2_permanent_handles {
	TPM2_RS_PW = 1073741833,
};

enum tpm2_capabilities {
	TPM2_CAP_HANDLES = 1,
	TPM2_CAP_COMMANDS = 2,
	TPM2_CAP_PCRS = 5,
	TPM2_CAP_TPM_PROPERTIES = 6,
};

enum tpm2_properties {
	TPM_PT_TOTAL_COMMANDS = 297,
};

enum tpm2_cc_attrs {
	TPM2_CC_ATTR_CHANDLES = 25,
	TPM2_CC_ATTR_RHANDLE = 28,
};

struct tpm_buf___2 {
	struct page___326 *data_page;
	unsigned int flags;
	u8 *data;
};

struct trusted_key_payload___2 {
	struct callback_head rcu;
	unsigned int key_len;
	unsigned int blob_len;
	unsigned char migratable;
	unsigned char key[129];
	unsigned char blob[512];
};

struct trusted_key_options___2 {
	uint16_t keytype;
	uint32_t keyhandle;
	unsigned char keyauth[20];
	unsigned char blobauth[20];
	uint32_t pcrinfo_len;
	unsigned char pcrinfo[64];
	int pcrlock;
	uint32_t hash;
	uint32_t policydigest_len;
	unsigned char policydigest[64];
	uint32_t policyhandle;
};

enum tpm2_object_attributes {
	TPM2_OA_USER_WITH_AUTH = 64,
};

enum tpm2_session_attributes {
	TPM2_SA_CONTINUE_SESSION = 1,
};

struct tpm2_hash {
	unsigned int crypto_id;
	unsigned int tpm_id;
};

struct tpm2_pcr_read_out {
	__be32 update_cnt;
	__be32 pcr_selects_cnt;
	__be16 hash_alg;
	u8 pcr_select_size;
	u8 pcr_select[3];
	__be32 digests_cnt;
	__be16 digest_size;
	u8 digest[0];
} __attribute__((packed));

struct tpm2_null_auth_area {
	__be32 handle;
	__be16 nonce_size;
	u8 attributes;
	__be16 auth_size;
} __attribute__((packed));

struct tpm2_get_random_out {
	__be16 size;
	u8 buffer[128];
};

struct tpm2_get_cap_out {
	u8 more_data;
	__be32 subcap_id;
	__be32 property_cnt;
	__be32 property_id;
	__be32 value;
} __attribute__((packed));

struct tpm2_pcr_selection {
	__be16 hash_alg;
	u8 size_of_select;
	u8 pcr_select[3];
};

struct tpmrm_priv {
	struct file_priv priv;
	struct tpm_space space;
};

enum tpm2_handle_types {
	TPM2_HT_HMAC_SESSION = 33554432,
	TPM2_HT_POLICY_SESSION = 50331648,
	TPM2_HT_TRANSIENT = 2147483648,
};

struct tpm2_context {
	__be64 sequence;
	__be32 saved_handle;
	__be32 hierarchy;
	__be16 blob_size;
} __attribute__((packed));

struct tpm2_cap_handles {
	u8 more_data;
	__be32 capability;
	__be32 count;
	__be32 handles[0];
} __attribute__((packed));

struct tpm_chip___3;

struct tpm_class_ops___3 {
	unsigned int flags;
	const u8 req_complete_mask;
	const u8 req_complete_val;
	bool (*req_canceled)(struct tpm_chip___3 *, u8);
	int (*recv)(struct tpm_chip___3 *, u8 *, size_t);
	int (*send)(struct tpm_chip___3 *, u8 *, size_t);
	void (*cancel)(struct tpm_chip___3 *);
	u8 (*status)(struct tpm_chip___3 *);
	void (*update_timeouts)(struct tpm_chip___3 *, long unsigned int *);
	int (*go_idle)(struct tpm_chip___3 *);
	int (*cmd_ready)(struct tpm_chip___3 *);
	int (*request_locality)(struct tpm_chip___3 *, int);
	int (*relinquish_locality)(struct tpm_chip___3 *, int);
	void (*clk_enable)(struct tpm_chip___3 *, bool);
};

struct tpm_chip_seqops___3 {
	struct tpm_chip___3 *chip;
	const struct seq_operations___265 *seqops;
};

struct tpm_chip___3 {
	struct device___279 dev;
	struct device___279 devs;
	struct cdev___64 cdev;
	struct cdev___64 cdevs;
	struct rw_semaphore___315 ops_sem;
	const struct tpm_class_ops___3 *ops;
	struct tpm_bios_log log;
	struct tpm_chip_seqops___3 bin_log_seqops;
	struct tpm_chip_seqops___3 ascii_log_seqops;
	unsigned int flags;
	int dev_num;
	long unsigned int is_open;
	char hwrng_name[64];
	struct hwrng hwrng;
	struct mutex tpm_mutex;
	long unsigned int timeout_a;
	long unsigned int timeout_b;
	long unsigned int timeout_c;
	long unsigned int timeout_d;
	bool timeout_adjusted;
	long unsigned int duration[4];
	bool duration_adjusted;
	struct dentry___313 *bios_dir[3];
	const struct attribute_group___278 *groups[3];
	unsigned int groups_cnt;
	u32 nr_allocated_banks;
	struct tpm_bank_info *allocated_banks;
	acpi_handle acpi_dev_handle;
	char ppi_version[4];
	struct tpm_space work_space;
	u32 last_cc;
	u32 nr_commands;
	u32 *cc_attrs_tbl;
	int locality;
};

struct tpm_buf___3 {
	struct page___315 *data_page;
	unsigned int flags;
	u8 *data;
};

struct tpm_readpubek_out {
	u8 algorithm[4];
	u8 encscheme[2];
	u8 sigscheme[2];
	__be32 paramsize;
	u8 parameters[12];
	__be32 keysize;
	u8 modulus[256];
	u8 checksum[20];
};

struct tpm_chip___4;

struct tpm_class_ops___4 {
	unsigned int flags;
	const u8 req_complete_mask;
	const u8 req_complete_val;
	bool (*req_canceled)(struct tpm_chip___4 *, u8);
	int (*recv)(struct tpm_chip___4 *, u8 *, size_t);
	int (*send)(struct tpm_chip___4 *, u8 *, size_t);
	void (*cancel)(struct tpm_chip___4 *);
	u8 (*status)(struct tpm_chip___4 *);
	void (*update_timeouts)(struct tpm_chip___4 *, long unsigned int *);
	int (*go_idle)(struct tpm_chip___4 *);
	int (*cmd_ready)(struct tpm_chip___4 *);
	int (*request_locality)(struct tpm_chip___4 *, int);
	int (*relinquish_locality)(struct tpm_chip___4 *, int);
	void (*clk_enable)(struct tpm_chip___4 *, bool);
};

struct tpm_chip_seqops___4 {
	struct tpm_chip___4 *chip;
	const struct seq_operations___16 *seqops;
};

struct tpm_chip___4 {
	struct device___17 dev;
	struct device___17 devs;
	struct cdev___7 cdev;
	struct cdev___7 cdevs;
	struct rw_semaphore___21 ops_sem;
	const struct tpm_class_ops___4 *ops;
	struct tpm_bios_log log;
	struct tpm_chip_seqops___4 bin_log_seqops;
	struct tpm_chip_seqops___4 ascii_log_seqops;
	unsigned int flags;
	int dev_num;
	long unsigned int is_open;
	char hwrng_name[64];
	struct hwrng hwrng;
	struct mutex tpm_mutex;
	long unsigned int timeout_a;
	long unsigned int timeout_b;
	long unsigned int timeout_c;
	long unsigned int timeout_d;
	bool timeout_adjusted;
	long unsigned int duration[4];
	bool duration_adjusted;
	struct dentry___22 *bios_dir[3];
	const struct attribute_group___17 *groups[3];
	unsigned int groups_cnt;
	u32 nr_allocated_banks;
	struct tpm_bank_info *allocated_banks;
	acpi_handle acpi_dev_handle;
	char ppi_version[4];
	struct tpm_space work_space;
	u32 last_cc;
	u32 nr_commands;
	u32 *cc_attrs_tbl;
	int locality;
};

struct module___268;

struct file___329;

struct kiocb___329;

struct poll_table_struct___200;

struct vm_area_struct___330;

struct inode___329;

struct file_lock___329;

struct page___330;

struct seq_file___280;

struct file_operations___329 {
	struct module___268 *owner;
	loff_t (*llseek)(struct file___329 *, loff_t, int);
	ssize_t (*read)(struct file___329 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___329 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___329 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___329 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___329 *, bool);
	int (*iterate)(struct file___329 *, struct dir_context *);
	int (*iterate_shared)(struct file___329 *, struct dir_context *);
	__poll_t (*poll)(struct file___329 *, struct poll_table_struct___200 *);
	long int (*unlocked_ioctl)(struct file___329 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___329 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___329 *, struct vm_area_struct___330 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___329 *, struct file___329 *);
	int (*flush)(struct file___329 *, fl_owner_t);
	int (*release)(struct inode___329 *, struct file___329 *);
	int (*fsync)(struct file___329 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___329 *, int);
	int (*lock)(struct file___329 *, int, struct file_lock___329 *);
	ssize_t (*sendpage)(struct file___329 *, struct page___330 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___329 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___329 *, int, struct file_lock___329 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___329 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___329 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___329 *, long int, struct file_lock___329 **, void **);
	long int (*fallocate)(struct file___329 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___280 *, struct file___329 *);
	ssize_t (*copy_file_range)(struct file___329 *, loff_t, struct file___329 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___329 *, loff_t, struct file___329 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___329 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___329 {
	u64 seqnum;
	struct vm_area_struct___330 *vmas[4];
};

struct page_frag___329 {
	struct page___330 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___329;

struct cred___306;

struct vm_struct___240;

struct task_struct___330 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___330 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___329 *mm;
	struct mm_struct___329 *active_mm;
	struct vmacache___329 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___330 *real_parent;
	struct task_struct___330 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___330 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___209 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___209 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___209 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___306 *ptracer_cred;
	const struct cred___306 *real_cred;
	const struct cred___306 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___330 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___84 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___329 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___330 *oom_reaper_list;
	struct vm_struct___240 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___134 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___328;

struct super_block___328;

struct dentry___328 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___328 *d_parent;
	struct qstr d_name;
	struct inode___329 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___328 *d_op;
	struct super_block___328 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct rw_semaphore___330 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___330 *owner;
};

struct address_space_operations___328;

struct address_space___328 {
	struct inode___329 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___330 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___328 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___328;

struct block_device___328;

struct cdev___76;

struct inode___329 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___328 *i_op;
	struct super_block___328 *i_sb;
	struct address_space___328 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___330 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___329 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___328 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___328 *i_bdev;
		struct cdev___76 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___329;

struct dentry_operations___328 {
	int (*d_revalidate)(struct dentry___328 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___328 *, unsigned int);
	int (*d_hash)(const struct dentry___328 *, struct qstr *);
	int (*d_compare)(const struct dentry___328 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___328 *);
	int (*d_init)(struct dentry___328 *);
	void (*d_release)(struct dentry___328 *);
	void (*d_prune)(struct dentry___328 *);
	void (*d_iput)(struct dentry___328 *, struct inode___329 *);
	char * (*d_dname)(struct dentry___328 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___329 *);
	int (*d_manage)(const struct path___329 *, bool);
	struct dentry___328 * (*d_real)(struct dentry___328 *, const struct inode___329 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___328;

struct mem_dqinfo___328 {
	struct quota_format_type___328 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___328;

struct quota_info___328 {
	unsigned int flags;
	struct rw_semaphore___330 dqio_sem;
	struct inode___329 *files[3];
	struct mem_dqinfo___328 info[3];
	const struct quota_format_ops___328 *ops[3];
};

struct rcuwait___328 {
	struct task_struct___330 *task;
};

struct percpu_rw_semaphore___328 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___330 rw_sem;
	struct rcuwait___328 writer;
	int readers_block;
};

struct sb_writers___328 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___328 rw_sem[3];
};

struct file_system_type___328;

struct super_operations___328;

struct dquot_operations___328;

struct quotactl_ops___328;

struct super_block___328 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___328 *s_type;
	const struct super_operations___328 *s_op;
	const struct dquot_operations___328 *dq_op;
	const struct quotactl_ops___328 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___328 *s_root;
	struct rw_semaphore___330 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___328 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___328 s_dquot;
	struct sb_writers___328 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___328 *s_d_op;
	int cleancache_poolid;
	struct shrinker___122 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct path___329 {
	struct vfsmount *mnt;
	struct dentry___328 *dentry;
};

typedef struct page___330 *pgtable_t___329;

struct dev_pagemap___317;

struct page___330 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___328 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___330 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___329 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___329 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___317 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___329;

struct lruvec___329 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___329 *pgdat;
};

struct zone___329 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___329 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___329 {
	struct zone___329 *zone;
	int zone_idx;
};

struct zonelist___329 {
	struct zoneref___329 _zonerefs[25];
};

struct pglist_data___329 {
	struct zone___329 node_zones[3];
	struct zonelist___329 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___330 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___330 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___329 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___330 {
	void *stack;
	struct task_struct___330 *task;
	long int status;
};

struct blocking_notifier_head___329 {
	struct rw_semaphore___330 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___317;

struct vm_area_struct___330 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___330 *vm_next;
	struct vm_area_struct___330 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___329 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___317 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___329 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___329;

struct mm_struct___329 {
	struct {
		struct vm_area_struct___330 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___329 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___330 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___329 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___330 *owner;
		struct user_namespace___3 *user_ns;
		struct file___329 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___329 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___317)(struct vm_area_struct___330 *, long unsigned int, const struct page___330 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___317)(struct page___330 *, void *);

struct device___295;

struct dev_pagemap___317 {
	dev_page_fault_t___317 page_fault;
	dev_page_free_t___317 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___295 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct file___329 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___329 f_path;
	struct inode___329 *f_inode;
	const struct file_operations___329 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___209 f_owner;
	const struct cred___306 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___328 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___317;

struct vm_operations_struct___317 {
	void (*open)(struct vm_area_struct___330 *);
	void (*close)(struct vm_area_struct___330 *);
	int (*split)(struct vm_area_struct___330 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___330 *);
	vm_fault_t (*fault)(struct vm_fault___317 *);
	vm_fault_t (*huge_fault)(struct vm_fault___317 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___317 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___330 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___317 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___317 *);
	int (*access)(struct vm_area_struct___330 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___330 *);
	int (*set_policy)(struct vm_area_struct___330 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___330 *, long unsigned int);
	struct page___330 * (*find_special_page)(struct vm_area_struct___330 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___329 {
	struct task_struct___330 *task;
	struct core_thread___329 *next;
};

struct core_state___329 {
	atomic_t nr_threads;
	struct core_thread___329 dumper;
	struct completion startup;
};

struct vm_fault___317 {
	struct vm_area_struct___330 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___330 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___330 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___329 prealloc_pte;
};

struct key___306;

struct user_struct___306 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___306 *uid_keyring;
	struct key___306 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___306 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___306 *session_keyring;
	struct key___306 *process_keyring;
	struct key___306 *thread_keyring;
	struct key___306 *request_key_auth;
	void *security;
	struct user_struct___306 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct vm_struct___240 {
	struct vm_struct___240 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___330 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct kiocb___329 {
	struct file___329 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___329 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___328 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___329 *ia_file;
};

struct dquot___328 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___328 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___328 {
	int qf_fmt_id;
	const struct quota_format_ops___328 *qf_ops;
	struct module___268 *qf_owner;
	struct quota_format_type___328 *qf_next;
};

struct quota_format_ops___328 {
	int (*check_quota_file)(struct super_block___328 *, int);
	int (*read_file_info)(struct super_block___328 *, int);
	int (*write_file_info)(struct super_block___328 *, int);
	int (*free_file_info)(struct super_block___328 *, int);
	int (*read_dqblk)(struct dquot___328 *);
	int (*commit_dqblk)(struct dquot___328 *);
	int (*release_dqblk)(struct dquot___328 *);
	int (*get_next_id)(struct super_block___328 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___328 {
	int (*write_dquot)(struct dquot___328 *);
	struct dquot___328 * (*alloc_dquot)(struct super_block___328 *, int);
	void (*destroy_dquot)(struct dquot___328 *);
	int (*acquire_dquot)(struct dquot___328 *);
	int (*release_dquot)(struct dquot___328 *);
	int (*mark_dirty)(struct dquot___328 *);
	int (*write_info)(struct super_block___328 *, int);
	qsize_t * (*get_reserved_space)(struct inode___329 *);
	int (*get_projid)(struct inode___329 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___329 *, qsize_t *);
	int (*get_next_id)(struct super_block___328 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___328 {
	int (*quota_on)(struct super_block___328 *, int, int, const struct path___329 *);
	int (*quota_off)(struct super_block___328 *, int);
	int (*quota_enable)(struct super_block___328 *, unsigned int);
	int (*quota_disable)(struct super_block___328 *, unsigned int);
	int (*quota_sync)(struct super_block___328 *, int);
	int (*set_info)(struct super_block___328 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___328 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___328 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___328 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___328 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___328 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___315;

struct kobj_type___315;

struct kernfs_node___323;

struct kobject___316 {
	const char *name;
	struct list_head entry;
	struct kobject___316 *parent;
	struct kset___315 *kset;
	struct kobj_type___315 *ktype;
	struct kernfs_node___323 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___265 {
	struct kobject___316 kobj;
	struct module___268 *mod;
	struct kobject___316 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___265 {
	struct module___268 *mod;
	struct latch_tree_node node;
};

struct module_layout___265 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___265 mtn;
};

struct module_attribute___265;

struct kernel_param___265;

struct module___268 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___265 mkobj;
	struct module_attribute___265 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___316 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___265 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___265 core_layout;
	struct module_layout___265 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___328 {
	int (*writepage)(struct page___330 *, struct writeback_control___3 *);
	int (*readpage)(struct file___329 *, struct page___330 *);
	int (*writepages)(struct address_space___328 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___330 *);
	int (*readpages)(struct file___329 *, struct address_space___328 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___329 *, struct address_space___328 *, loff_t, unsigned int, unsigned int, struct page___330 **, void **);
	int (*write_end)(struct file___329 *, struct address_space___328 *, loff_t, unsigned int, unsigned int, struct page___330 *, void *);
	sector_t (*bmap)(struct address_space___328 *, sector_t);
	void (*invalidatepage)(struct page___330 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___330 *, gfp_t);
	void (*freepage)(struct page___330 *);
	ssize_t (*direct_IO)(struct kiocb___329 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___328 *, struct page___330 *, struct page___330 *, enum migrate_mode);
	bool (*isolate_page)(struct page___330 *, isolate_mode_t);
	void (*putback_page)(struct page___330 *);
	int (*launder_page)(struct page___330 *);
	int (*is_partially_uptodate)(struct page___330 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___330 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___328 *, struct page___330 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___329 *, sector_t *);
	void (*swap_deactivate)(struct file___329 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___328 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___329 *bd_inode;
	struct super_block___328 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___328 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___76 {
	struct kobject___316 kobj;
	struct module___268 *owner;
	const struct file_operations___329 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___328 {
	struct dentry___328 * (*lookup)(struct inode___329 *, struct dentry___328 *, unsigned int);
	const char * (*get_link)(struct dentry___328 *, struct inode___329 *, struct delayed_call *);
	int (*permission)(struct inode___329 *, int);
	struct posix_acl * (*get_acl)(struct inode___329 *, int);
	int (*readlink)(struct dentry___328 *, char *, int);
	int (*create)(struct inode___329 *, struct dentry___328 *, umode_t, bool);
	int (*link)(struct dentry___328 *, struct inode___329 *, struct dentry___328 *);
	int (*unlink)(struct inode___329 *, struct dentry___328 *);
	int (*symlink)(struct inode___329 *, struct dentry___328 *, const char *);
	int (*mkdir)(struct inode___329 *, struct dentry___328 *, umode_t);
	int (*rmdir)(struct inode___329 *, struct dentry___328 *);
	int (*mknod)(struct inode___329 *, struct dentry___328 *, umode_t, dev_t);
	int (*rename)(struct inode___329 *, struct dentry___328 *, struct inode___329 *, struct dentry___328 *, unsigned int);
	int (*setattr)(struct dentry___328 *, struct iattr___328 *);
	int (*getattr)(const struct path___329 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___328 *, char *, size_t);
	int (*fiemap)(struct inode___329 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___329 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___329 *, struct dentry___328 *, struct file___329 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___329 *, struct dentry___328 *, umode_t);
	int (*set_acl)(struct inode___329 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___328 {
	void (*fl_copy_lock)(struct file_lock___329 *, struct file_lock___329 *);
	void (*fl_release_private)(struct file_lock___329 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___328;

struct lock_manager_operations___328;

struct file_lock___329 {
	struct file_lock___329 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___329 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___328 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___328 *fl_ops;
	const struct lock_manager_operations___328 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___328 {
	int (*lm_compare_owner)(struct file_lock___329 *, struct file_lock___329 *);
	long unsigned int (*lm_owner_key)(struct file_lock___329 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___329 *);
	int (*lm_grant)(struct file_lock___329 *, int);
	bool (*lm_break)(struct file_lock___329 *);
	int (*lm_change)(struct file_lock___329 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___329 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___328 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___328 *fa_next;
	struct file___329 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___328 {
	const char *name;
	int fs_flags;
	struct dentry___328 * (*mount)(struct file_system_type___328 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___328 *);
	struct module___268 *owner;
	struct file_system_type___328 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___328 {
	struct inode___329 * (*alloc_inode)(struct super_block___328 *);
	void (*destroy_inode)(struct inode___329 *);
	void (*dirty_inode)(struct inode___329 *, int);
	int (*write_inode)(struct inode___329 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___329 *);
	void (*evict_inode)(struct inode___329 *);
	void (*put_super)(struct super_block___328 *);
	int (*sync_fs)(struct super_block___328 *, int);
	int (*freeze_super)(struct super_block___328 *);
	int (*freeze_fs)(struct super_block___328 *);
	int (*thaw_super)(struct super_block___328 *);
	int (*unfreeze_fs)(struct super_block___328 *);
	int (*statfs)(struct dentry___328 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___328 *, int *, char *);
	void (*umount_begin)(struct super_block___328 *);
	int (*show_options)(struct seq_file___280 *, struct dentry___328 *);
	int (*show_devname)(struct seq_file___280 *, struct dentry___328 *);
	int (*show_path)(struct seq_file___280 *, struct dentry___328 *);
	int (*show_stats)(struct seq_file___280 *, struct dentry___328 *);
	ssize_t (*quota_read)(struct super_block___328 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___328 *, int, const char *, size_t, loff_t);
	struct dquot___328 ** (*get_dquots)(struct inode___329 *);
	int (*bdev_try_to_free_page)(struct super_block___328 *, struct page___330 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___328 *, struct shrink_control___122 *);
	long int (*free_cached_objects)(struct super_block___328 *, struct shrink_control___122 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___205)(struct file___329 *, wait_queue_head_t *, struct poll_table_struct___200 *);

struct poll_table_struct___200 {
	poll_queue_proc___205 _qproc;
	__poll_t _key;
};

struct seq_operations___279;

struct seq_file___280 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___279 *op;
	int poll_event;
	const struct file___329 *file;
	void *private;
};

typedef int (*key_restrict_link_func_t___307)(struct key___306 *, const struct key_type *, const union key_payload *, struct key___306 *);

struct key_restriction___306;

struct key___306 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___330 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___306 *restrict_link;
};

struct key_restriction___306 {
	key_restrict_link_func_t___307 check;
	struct key___306 *key;
	struct key_type *keytype;
};

struct seq_operations___279 {
	void * (*start)(struct seq_file___280 *, loff_t *);
	void (*stop)(struct seq_file___280 *, void *);
	void * (*next)(struct seq_file___280 *, void *, loff_t *);
	int (*show)(struct seq_file___280 *, void *);
};

struct dev_pm_info___295 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___3 *subsys_data;
	void (*set_latency_tolerance)(struct device___295 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___295;

struct bus_type___295;

struct device_driver___295;

struct dev_pm_domain___295;

struct fwnode_handle___224;

struct class___295;

struct attribute_group___293;

struct device___295 {
	struct device___295 *parent;
	struct device_private *p;
	struct kobject___316 kobj;
	const char *init_name;
	const struct device_type___295 *type;
	struct mutex mutex;
	struct bus_type___295 *bus;
	struct device_driver___295 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___295 power;
	struct dev_pm_domain___295 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___224 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___295 *class;
	const struct attribute_group___293 **groups;
	void (*release)(struct device___295 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct kernfs_root___322;

struct kernfs_elem_dir___322 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___322 *root;
};

struct kernfs_syscall_ops___322;

struct kernfs_root___322 {
	struct kernfs_node___323 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___322 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___322 {
	struct kernfs_node___323 *target_kn;
};

struct kernfs_ops___322;

struct kernfs_elem_attr___322 {
	const struct kernfs_ops___322 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___323 *notify_next;
};

struct kernfs_node___323 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___323 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___322 dir;
		struct kernfs_elem_symlink___322 symlink;
		struct kernfs_elem_attr___322 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___322;

struct kernfs_ops___322 {
	int (*open)(struct kernfs_open_file___322 *);
	void (*release)(struct kernfs_open_file___322 *);
	int (*seq_show)(struct seq_file___280 *, void *);
	void * (*seq_start)(struct seq_file___280 *, loff_t *);
	void * (*seq_next)(struct seq_file___280 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___280 *, void *);
	ssize_t (*read)(struct kernfs_open_file___322 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___322 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___322 *, struct vm_area_struct___330 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___322 *, struct poll_table_struct___200 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___322 {
	int (*remount_fs)(struct kernfs_root___322 *, int *, char *);
	int (*show_options)(struct seq_file___280 *, struct kernfs_root___322 *);
	int (*mkdir)(struct kernfs_node___323 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___323 *);
	int (*rename)(struct kernfs_node___323 *, struct kernfs_node___323 *, const char *);
	int (*show_path)(struct seq_file___280 *, struct kernfs_node___323 *, struct kernfs_root___322 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___322 {
	struct kernfs_node___323 *kn;
	struct file___329 *file;
	struct seq_file___280 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___317 *vm_ops;
};

struct bin_attribute___292;

struct attribute_group___293 {
	const char *name;
	umode_t (*is_visible)(struct kobject___316 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___316 *, struct bin_attribute___292 *, int);
	struct attribute **attrs;
	struct bin_attribute___292 **bin_attrs;
};

struct bin_attribute___292 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___329 *, struct kobject___316 *, struct bin_attribute___292 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___329 *, struct kobject___316 *, struct bin_attribute___292 *, char *, loff_t, size_t);
	int (*mmap)(struct file___329 *, struct kobject___316 *, struct bin_attribute___292 *, struct vm_area_struct___330 *);
};

struct sysfs_ops___315 {
	ssize_t (*show)(struct kobject___316 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___316 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___315;

struct kset___315 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___316 kobj;
	const struct kset_uevent_ops___315 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___315 {
	void (*release)(struct kobject___316 *);
	const struct sysfs_ops___315 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___25 * (*child_ns_type)(struct kobject___316 *);
	const void * (*namespace)(struct kobject___316 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___315 {
	int (* const filter)(struct kset___315 *, struct kobject___316 *);
	const char * (* const name)(struct kset___315 *, struct kobject___316 *);
	int (* const uevent)(struct kset___315 *, struct kobject___316 *, struct kobj_uevent_env *);
};

struct kobj_attribute___307 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___316 *, struct kobj_attribute___307 *, char *);
	ssize_t (*store)(struct kobject___316 *, struct kobj_attribute___307 *, const char *, size_t);
};

struct dev_pm_ops___295 {
	int (*prepare)(struct device___295 *);
	void (*complete)(struct device___295 *);
	int (*suspend)(struct device___295 *);
	int (*resume)(struct device___295 *);
	int (*freeze)(struct device___295 *);
	int (*thaw)(struct device___295 *);
	int (*poweroff)(struct device___295 *);
	int (*restore)(struct device___295 *);
	int (*suspend_late)(struct device___295 *);
	int (*resume_early)(struct device___295 *);
	int (*freeze_late)(struct device___295 *);
	int (*thaw_early)(struct device___295 *);
	int (*poweroff_late)(struct device___295 *);
	int (*restore_early)(struct device___295 *);
	int (*suspend_noirq)(struct device___295 *);
	int (*resume_noirq)(struct device___295 *);
	int (*freeze_noirq)(struct device___295 *);
	int (*thaw_noirq)(struct device___295 *);
	int (*poweroff_noirq)(struct device___295 *);
	int (*restore_noirq)(struct device___295 *);
	int (*runtime_suspend)(struct device___295 *);
	int (*runtime_resume)(struct device___295 *);
	int (*runtime_idle)(struct device___295 *);
};

struct dev_pm_domain___295 {
	struct dev_pm_ops___295 ops;
	void (*detach)(struct device___295 *, bool);
	int (*activate)(struct device___295 *);
	void (*sync)(struct device___295 *);
	void (*dismiss)(struct device___295 *);
};

struct bus_type___295 {
	const char *name;
	const char *dev_name;
	struct device___295 *dev_root;
	const struct attribute_group___293 **bus_groups;
	const struct attribute_group___293 **dev_groups;
	const struct attribute_group___293 **drv_groups;
	int (*match)(struct device___295 *, struct device_driver___295 *);
	int (*uevent)(struct device___295 *, struct kobj_uevent_env *);
	int (*probe)(struct device___295 *);
	int (*remove)(struct device___295 *);
	void (*shutdown)(struct device___295 *);
	int (*online)(struct device___295 *);
	int (*offline)(struct device___295 *);
	int (*suspend)(struct device___295 *, pm_message_t);
	int (*resume)(struct device___295 *);
	int (*num_vf)(struct device___295 *);
	int (*dma_configure)(struct device___295 *);
	const struct dev_pm_ops___295 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___295 {
	const char *name;
	struct bus_type___295 *bus;
	struct module___268 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___295 *);
	int (*remove)(struct device___295 *);
	void (*shutdown)(struct device___295 *);
	int (*suspend)(struct device___295 *, pm_message_t);
	int (*resume)(struct device___295 *);
	const struct attribute_group___293 **groups;
	const struct dev_pm_ops___295 *pm;
	void (*coredump)(struct device___295 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___295 {
	const char *name;
	const struct attribute_group___293 **groups;
	int (*uevent)(struct device___295 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___295 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___295 *);
	const struct dev_pm_ops___295 *pm;
};

struct class___295 {
	const char *name;
	struct module___268 *owner;
	const struct attribute_group___293 **class_groups;
	const struct attribute_group___293 **dev_groups;
	struct kobject___316 *dev_kobj;
	int (*dev_uevent)(struct device___295 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___295 *, umode_t *);
	void (*class_release)(struct class___295 *);
	void (*dev_release)(struct device___295 *);
	int (*shutdown_pre)(struct device___295 *);
	const struct kobj_ns_type_operations___25 *ns_type;
	const void * (*namespace)(struct device___295 *);
	const struct dev_pm_ops___295 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct fwnode_operations___224;

struct fwnode_handle___224 {
	struct fwnode_handle___224 *secondary;
	const struct fwnode_operations___224 *ops;
};

typedef void compound_page_dtor___317(struct page___330 *);

struct kernel_param_ops___265 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___265 *);
	int (*get)(char *, const struct kernel_param___265 *);
	void (*free)(void *);
};

struct kparam_array___265;

struct kernel_param___265 {
	const char *name;
	struct module___268 *mod;
	const struct kernel_param_ops___265 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___265 *arr;
	};
};

struct kparam_array___265 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___265 *ops;
	void *elem;
};

struct module_attribute___265 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___265 *, struct module_kobject___265 *, char *);
	ssize_t (*store)(struct module_attribute___265 *, struct module_kobject___265 *, const char *, size_t);
	void (*setup)(struct module___268 *, const char *);
	int (*test)(struct module___268 *);
	void (*free)(struct module___268 *);
};

struct fwnode_reference_args___224;

struct fwnode_endpoint___224;

struct fwnode_operations___224 {
	struct fwnode_handle___224 * (*get)(struct fwnode_handle___224 *);
	void (*put)(struct fwnode_handle___224 *);
	bool (*device_is_available)(const struct fwnode_handle___224 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___224 *, const struct device___295 *);
	bool (*property_present)(const struct fwnode_handle___224 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___224 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___224 *, const char *, const char **, size_t);
	struct fwnode_handle___224 * (*get_parent)(const struct fwnode_handle___224 *);
	struct fwnode_handle___224 * (*get_next_child_node)(const struct fwnode_handle___224 *, struct fwnode_handle___224 *);
	struct fwnode_handle___224 * (*get_named_child_node)(const struct fwnode_handle___224 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___224 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___224 *);
	struct fwnode_handle___224 * (*graph_get_next_endpoint)(const struct fwnode_handle___224 *, struct fwnode_handle___224 *);
	struct fwnode_handle___224 * (*graph_get_remote_endpoint)(const struct fwnode_handle___224 *);
	struct fwnode_handle___224 * (*graph_get_port_parent)(struct fwnode_handle___224 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___224 *, struct fwnode_endpoint___224 *);
};

struct fwnode_endpoint___224 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___224 *local_fwnode;
};

struct fwnode_reference_args___224 {
	struct fwnode_handle___224 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct tpm_chip___5;

struct tpm_class_ops___5 {
	unsigned int flags;
	const u8 req_complete_mask;
	const u8 req_complete_val;
	bool (*req_canceled)(struct tpm_chip___5 *, u8);
	int (*recv)(struct tpm_chip___5 *, u8 *, size_t);
	int (*send)(struct tpm_chip___5 *, u8 *, size_t);
	void (*cancel)(struct tpm_chip___5 *);
	u8 (*status)(struct tpm_chip___5 *);
	void (*update_timeouts)(struct tpm_chip___5 *, long unsigned int *);
	int (*go_idle)(struct tpm_chip___5 *);
	int (*cmd_ready)(struct tpm_chip___5 *);
	int (*request_locality)(struct tpm_chip___5 *, int);
	int (*relinquish_locality)(struct tpm_chip___5 *, int);
	void (*clk_enable)(struct tpm_chip___5 *, bool);
};

struct tpm_chip_seqops___5 {
	struct tpm_chip___5 *chip;
	const struct seq_operations___279 *seqops;
};

struct tpm_chip___5 {
	struct device___295 dev;
	struct device___295 devs;
	struct cdev___76 cdev;
	struct cdev___76 cdevs;
	struct rw_semaphore___330 ops_sem;
	const struct tpm_class_ops___5 *ops;
	struct tpm_bios_log log;
	struct tpm_chip_seqops___5 bin_log_seqops;
	struct tpm_chip_seqops___5 ascii_log_seqops;
	unsigned int flags;
	int dev_num;
	long unsigned int is_open;
	char hwrng_name[64];
	struct hwrng hwrng;
	struct mutex tpm_mutex;
	long unsigned int timeout_a;
	long unsigned int timeout_b;
	long unsigned int timeout_c;
	long unsigned int timeout_d;
	bool timeout_adjusted;
	long unsigned int duration[4];
	bool duration_adjusted;
	struct dentry___328 *bios_dir[3];
	const struct attribute_group___293 *groups[3];
	unsigned int groups_cnt;
	u32 nr_allocated_banks;
	struct tpm_bank_info *allocated_banks;
	acpi_handle acpi_dev_handle;
	char ppi_version[4];
	struct tpm_space work_space;
	u32 last_cc;
	u32 nr_commands;
	u32 *cc_attrs_tbl;
	int locality;
};

enum tcpa_event_types {
	PREBOOT = 0,
	POST_CODE = 1,
	UNUSED = 2,
	NO_ACTION = 3,
	SEPARATOR = 4,
	ACTION = 5,
	EVENT_TAG = 6,
	SCRTM_CONTENTS = 7,
	SCRTM_VERSION = 8,
	CPU_MICROCODE = 9,
	PLATFORM_CONFIG_FLAGS = 10,
	TABLE_OF_DEVICES = 11,
	COMPACT_HASH = 12,
	IPL = 13,
	IPL_PARTITION_DATA = 14,
	NONHOST_CODE = 15,
	NONHOST_CONFIG = 16,
	NONHOST_INFO = 17,
};

struct tcpa_pc_event {
	u32 event_id;
	u32 event_size;
	u8 event_data[0];
};

enum tcpa_pc_event_ids {
	SMBIOS = 1,
	BIS_CERT = 2,
	POST_BIOS_ROM = 3,
	ESCD = 4,
	CMOS = 5,
	NVRAM = 6,
	OPTION_ROM_EXEC = 7,
	OPTION_ROM_CONFIG = 8,
	OPTION_ROM_MICROCODE = 10,
	S_CRTM_VERSION = 11,
	S_CRTM_CONTENTS = 12,
	POST_CONTENTS = 13,
	HOST_TABLE_OF_DEVICES = 14,
};

struct tcg_efi_specid_event_algs {
	u16 alg_id;
	u16 digest_size;
};

struct tcg_efi_specid_event_head {
	u8 signature[16];
	u32 platform_class;
	u8 spec_version_minor;
	u8 spec_version_major;
	u8 spec_errata;
	u8 uintnsize;
	u32 num_algs;
	struct tcg_efi_specid_event_algs digest_sizes[0];
};

struct tcg_pcr_event {
	u32 pcr_idx;
	u32 event_type;
	u8 digest[20];
	u32 event_size;
	u8 event[0];
};

struct tcg_event_field {
	u32 event_size;
	u8 event[0];
};

struct tcg_pcr_event2_head {
	u32 pcr_idx;
	u32 event_type;
	u32 count;
	struct tpm_digest digests[0];
};

enum bios_platform_class {
	BIOS_CLIENT = 0,
	BIOS_SERVER = 1,
};

struct client_hdr {
	u32 log_max_len;
	u64 log_start_addr;
} __attribute__((packed));

struct server_hdr {
	u16 reserved;
	u64 log_max_len;
	u64 log_start_addr;
} __attribute__((packed));

struct acpi_tcpa {
	struct acpi_table_header hdr;
	u16 platform_class;
	union {
		struct client_hdr client;
		struct server_hdr server;
	};
} __attribute__((packed));

typedef void (*poll_queue_proc___206)(struct file___314 *, wait_queue_head_t *, struct poll_table_struct___6 *);

struct module_version_attribute___5 {
	struct module_attribute___262 mattr;
	const char *module_name;
	const char *version;
};

struct pnp_protocol___5;

struct pnp_card___5 {
	struct device___291 dev;
	unsigned char number;
	struct list_head global_list;
	struct list_head protocol_list;
	struct list_head devices;
	struct pnp_protocol___5 *protocol;
	struct pnp_id *id;
	char name[50];
	unsigned char pnpver;
	unsigned char productver;
	unsigned int serial;
	unsigned char checksum;
	struct proc_dir_entry *procdir;
};

struct pnp_dev___5;

struct pnp_protocol___5 {
	struct list_head protocol_list;
	char *name;
	int (*get)(struct pnp_dev___5 *);
	int (*set)(struct pnp_dev___5 *);
	int (*disable)(struct pnp_dev___5 *);
	bool (*can_wakeup)(struct pnp_dev___5 *);
	int (*suspend)(struct pnp_dev___5 *, pm_message_t);
	int (*resume)(struct pnp_dev___5 *);
	unsigned char number;
	struct device___291 dev;
	struct list_head cards;
	struct list_head devices;
};

struct pnp_card_driver___5;

struct pnp_card_link___5 {
	struct pnp_card___5 *card;
	struct pnp_card_driver___5 *driver;
	void *driver_data;
	pm_message_t pm_state;
};

struct pnp_driver___5 {
	char *name;
	const struct pnp_device_id *id_table;
	unsigned int flags;
	int (*probe)(struct pnp_dev___5 *, const struct pnp_device_id *);
	void (*remove)(struct pnp_dev___5 *);
	void (*shutdown)(struct pnp_dev___5 *);
	int (*suspend)(struct pnp_dev___5 *, pm_message_t);
	int (*resume)(struct pnp_dev___5 *);
	struct device_driver___291 driver;
};

struct pnp_card_driver___5 {
	struct list_head global_list;
	char *name;
	const struct pnp_card_device_id *id_table;
	unsigned int flags;
	int (*probe)(struct pnp_card_link___5 *, const struct pnp_card_device_id *);
	void (*remove)(struct pnp_card_link___5 *);
	int (*suspend)(struct pnp_card_link___5 *, pm_message_t);
	int (*resume)(struct pnp_card_link___5 *);
	struct pnp_driver___5 link;
};

struct pnp_dev___5 {
	struct device___291 dev;
	u64 dma_mask;
	unsigned int number;
	int status;
	struct list_head global_list;
	struct list_head protocol_list;
	struct list_head card_list;
	struct list_head rdev_list;
	struct pnp_protocol___5 *protocol;
	struct pnp_card___5 *card;
	struct pnp_driver___5 *driver;
	struct pnp_card_link___5 *card_link;
	struct pnp_id *id;
	int active;
	int capabilities;
	unsigned int num_dependent_sets;
	struct list_head resources;
	struct list_head options;
	char name[50];
	int flags;
	struct proc_dir_entry *procent;
	void *data;
};

enum tis_access {
	TPM_ACCESS_VALID = 128,
	TPM_ACCESS_ACTIVE_LOCALITY = 32,
	TPM_ACCESS_REQUEST_PENDING = 4,
	TPM_ACCESS_REQUEST_USE = 2,
};

enum tis_status {
	TPM_STS_VALID = 128,
	TPM_STS_COMMAND_READY = 64,
	TPM_STS_GO = 32,
	TPM_STS_DATA_AVAIL = 16,
	TPM_STS_DATA_EXPECT = 8,
};

enum tis_int_flags {
	TPM_GLOBAL_INT_ENABLE = 2147483648,
	TPM_INTF_BURST_COUNT_STATIC = 256,
	TPM_INTF_CMD_READY_INT = 128,
	TPM_INTF_INT_EDGE_FALLING = 64,
	TPM_INTF_INT_EDGE_RISING = 32,
	TPM_INTF_INT_LEVEL_LOW = 16,
	TPM_INTF_INT_LEVEL_HIGH = 8,
	TPM_INTF_LOCALITY_CHANGE_INT = 4,
	TPM_INTF_STS_VALID_INT = 2,
	TPM_INTF_DATA_AVAIL_INT = 1,
};

enum tis_defaults {
	TIS_MEM_LEN = 20480,
	TIS_SHORT_TIMEOUT = 750,
	TIS_LONG_TIMEOUT = 2000,
};

enum tpm_tis_flags {
	TPM_TIS_ITPM_WORKAROUND = 1,
};

struct tpm_tis_phy_ops;

struct tpm_tis_data {
	u16 manufacturer_id;
	int locality;
	int irq;
	bool irq_tested;
	unsigned int flags;
	void *ilb_base_addr;
	u16 clkrun_enabled;
	wait_queue_head_t int_queue;
	wait_queue_head_t read_queue;
	const struct tpm_tis_phy_ops *phy_ops;
	short unsigned int rng_quality;
};

struct tpm_tis_phy_ops {
	int (*read_bytes)(struct tpm_tis_data *, u32, u16, u8 *);
	int (*write_bytes)(struct tpm_tis_data *, u32, u16, const u8 *);
	int (*read16)(struct tpm_tis_data *, u32, u16 *);
	int (*read32)(struct tpm_tis_data *, u32, u32 *);
	int (*write32)(struct tpm_tis_data *, u32, u32);
};

struct tis_vendor_timeout_override {
	u32 did_vid;
	long unsigned int timeout_us[4];
};

struct acpi_table_tpm2 {
	struct acpi_table_header header;
	u16 platform_class;
	u16 reserved;
	u64 control_address;
	u32 start_method;
} __attribute__((packed));

struct platform_device_info___3 {
	struct device___291 *parent;
	struct fwnode_handle___220 *fwnode;
	const char *name;
	int id;
	const struct resource *res;
	unsigned int num_res;
	const void *data;
	size_t size_data;
	u64 dma_mask;
	struct property_entry___2 *properties;
};

struct tpm_info {
	struct resource res;
	int irq;
};

struct tpm_tis_tcg_phy {
	struct tpm_tis_data priv;
	void *iobase;
};

struct module_version_attribute___6 {
	struct module_attribute___251 mattr;
	const char *module_name;
	const char *version;
};

enum crb_defaults {
	CRB_ACPI_START_REVISION_ID = 1,
	CRB_ACPI_START_INDEX = 1,
};

enum crb_loc_ctrl {
	CRB_LOC_CTRL_REQUEST_ACCESS = 1,
	CRB_LOC_CTRL_RELINQUISH = 2,
};

enum crb_loc_state {
	CRB_LOC_STATE_LOC_ASSIGNED = 2,
	CRB_LOC_STATE_TPM_REG_VALID_STS = 128,
};

enum crb_ctrl_req {
	CRB_CTRL_REQ_CMD_READY = 1,
	CRB_CTRL_REQ_GO_IDLE = 2,
};

enum crb_ctrl_sts {
	CRB_CTRL_STS_ERROR = 1,
	CRB_CTRL_STS_TPM_IDLE = 2,
};

enum crb_start {
	CRB_START_INVOKE = 1,
};

enum crb_cancel {
	CRB_CANCEL_INVOKE = 1,
};

struct crb_regs_head {
	u32 loc_state;
	u32 reserved1;
	u32 loc_ctrl;
	u32 loc_sts;
	u8 reserved2[32];
	u64 intf_id;
	u64 ctrl_ext;
};

struct crb_regs_tail {
	u32 ctrl_req;
	u32 ctrl_sts;
	u32 ctrl_cancel;
	u32 ctrl_start;
	u32 ctrl_int_enable;
	u32 ctrl_int_sts;
	u32 ctrl_cmd_size;
	u32 ctrl_cmd_pa_low;
	u32 ctrl_cmd_pa_high;
	u32 ctrl_rsp_size;
	u64 ctrl_rsp_pa;
};

enum crb_status {
	CRB_DRV_STS_COMPLETE = 1,
};

struct crb_priv {
	u32 sm;
	const char *hid;
	void *iobase;
	struct crb_regs_head *regs_h;
	struct crb_regs_tail *regs_t;
	u8 *cmd;
	u8 *rsp;
	u32 cmd_size;
	u32 smc_func_id;
};

struct tpm2_crb_smc {
	u32 interrupt;
	u8 interrupt_flags;
	u8 op_flags;
	u16 reserved2;
	u32 smc_func_id;
};

struct iommu_group {
	struct kobject___294 kobj;
	struct kobject___294 *devices_kobj;
	struct list_head devices;
	struct mutex mutex;
	struct blocking_notifier_head___307 notifier;
	void *iommu_data;
	void (*iommu_data_release)(void *);
	char *name;
	int id;
	struct iommu_domain *default_domain;
	struct iommu_domain *domain;
};

struct iommu_device {
	struct list_head list;
	const struct iommu_ops *ops;
	struct fwnode_handle___12 *fwnode;
	struct device___272 *dev;
};

struct iommu_callback_data {
	const struct iommu_ops *ops;
};

struct group_device {
	struct list_head list;
	struct device___272 *dev;
	char *name;
};

struct iommu_group_attribute {
	struct attribute attr;
	ssize_t (*show)(struct iommu_group *, char *);
	ssize_t (*store)(struct iommu_group *, const char *, size_t);
};

struct group_for_pci_data {
	struct pci_dev___8 *pdev;
	struct iommu_group *group;
};

struct trace_event_raw_iommu_group_event {
	struct trace_entry ent;
	int gid;
	u32 __data_loc_device;
	char __data[0];
};

struct trace_event_raw_iommu_device_event {
	struct trace_entry ent;
	u32 __data_loc_device;
	char __data[0];
};

struct trace_event_raw_map {
	struct trace_entry ent;
	u64 iova;
	u64 paddr;
	size_t size;
	char __data[0];
};

struct trace_event_raw_unmap {
	struct trace_entry ent;
	u64 iova;
	size_t size;
	size_t unmapped_size;
	char __data[0];
};

struct trace_event_raw_iommu_error {
	struct trace_entry ent;
	u32 __data_loc_device;
	u32 __data_loc_driver;
	u64 iova;
	int flags;
	char __data[0];
};

struct trace_event_data_offsets_iommu_group_event {
	u32 device;
};

struct trace_event_data_offsets_iommu_device_event {
	u32 device;
};

struct trace_event_data_offsets_map {};

struct trace_event_data_offsets_unmap {};

struct trace_event_data_offsets_iommu_error {
	u32 device;
	u32 driver;
};

struct module___269;

struct file___330;

struct kiocb___330;

struct vm_area_struct___331;

struct inode___330;

struct file_lock___330;

struct page___331;

struct file_operations___330 {
	struct module___269 *owner;
	loff_t (*llseek)(struct file___330 *, loff_t, int);
	ssize_t (*read)(struct file___330 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___330 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___330 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___330 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___330 *, bool);
	int (*iterate)(struct file___330 *, struct dir_context *);
	int (*iterate_shared)(struct file___330 *, struct dir_context *);
	__poll_t (*poll)(struct file___330 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___330 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___330 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___330 *, struct vm_area_struct___331 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___330 *, struct file___330 *);
	int (*flush)(struct file___330 *, fl_owner_t);
	int (*release)(struct inode___330 *, struct file___330 *);
	int (*fsync)(struct file___330 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___330 *, int);
	int (*lock)(struct file___330 *, int, struct file_lock___330 *);
	ssize_t (*sendpage)(struct file___330 *, struct page___331 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___330 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___330 *, int, struct file_lock___330 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___330 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___330 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___330 *, long int, struct file_lock___330 **, void **);
	long int (*fallocate)(struct file___330 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___330 *);
	ssize_t (*copy_file_range)(struct file___330 *, loff_t, struct file___330 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___330 *, loff_t, struct file___330 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___330 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___330 {
	u64 seqnum;
	struct vm_area_struct___331 *vmas[4];
};

struct page_frag___330 {
	struct page___331 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___330;

struct vm_struct___241;

struct task_struct___331 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___331 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___330 *mm;
	struct mm_struct___330 *active_mm;
	struct vmacache___330 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___331 *real_parent;
	struct task_struct___331 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___331 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___209 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___209 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___209 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___2 *ptracer_cred;
	const struct cred___2 *real_cred;
	const struct cred___2 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___331 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___84 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___330 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___331 *oom_reaper_list;
	struct vm_struct___241 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___134 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___331 *pgtable_t___330;

struct address_space___329;

struct dev_pagemap___318;

struct page___331 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___329 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___331 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___330 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___330 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___318 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___330;

struct lruvec___330 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___330 *pgdat;
};

struct zone___330 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___330 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___330 {
	struct zone___330 *zone;
	int zone_idx;
};

struct zonelist___330 {
	struct zoneref___330 _zonerefs[25];
};

struct pglist_data___330 {
	struct zone___330 node_zones[3];
	struct zonelist___330 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___331 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___331 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___330 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___331 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___331 *owner;
};

struct secondary_data___331 {
	void *stack;
	struct task_struct___331 *task;
	long int status;
};

struct blocking_notifier_head___330 {
	struct rw_semaphore___331 rwsem;
	struct notifier_block *head;
};

struct kernfs_root___323;

struct kernfs_elem_dir___323 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___323 *root;
};

struct kernfs_node___324;

struct kernfs_syscall_ops___323;

struct kernfs_root___323 {
	struct kernfs_node___324 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___323 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___323 {
	struct kernfs_node___324 *target_kn;
};

struct kernfs_ops___323;

struct kernfs_elem_attr___323 {
	const struct kernfs_ops___323 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___324 *notify_next;
};

struct kernfs_node___324 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___324 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___323 dir;
		struct kernfs_elem_symlink___323 symlink;
		struct kernfs_elem_attr___323 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___323;

struct kernfs_ops___323 {
	int (*open)(struct kernfs_open_file___323 *);
	void (*release)(struct kernfs_open_file___323 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___323 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___323 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___323 *, struct vm_area_struct___331 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___323 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___323 {
	int (*remount_fs)(struct kernfs_root___323 *, int *, char *);
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___323 *);
	int (*mkdir)(struct kernfs_node___324 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___324 *);
	int (*rename)(struct kernfs_node___324 *, struct kernfs_node___324 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___324 *, struct kernfs_root___323 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_operations_struct___318;

struct kernfs_open_file___323 {
	struct kernfs_node___324 *kn;
	struct file___330 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___318 *vm_ops;
};

struct dentry___329;

struct path___330 {
	struct vfsmount *mnt;
	struct dentry___329 *dentry;
};

struct file___330 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___330 f_path;
	struct inode___330 *f_inode;
	const struct file_operations___330 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___209 f_owner;
	const struct cred___2 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___329 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___318;

struct vm_operations_struct___318 {
	void (*open)(struct vm_area_struct___331 *);
	void (*close)(struct vm_area_struct___331 *);
	int (*split)(struct vm_area_struct___331 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___331 *);
	vm_fault_t (*fault)(struct vm_fault___318 *);
	vm_fault_t (*huge_fault)(struct vm_fault___318 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___318 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___331 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___318 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___318 *);
	int (*access)(struct vm_area_struct___331 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___331 *);
	int (*set_policy)(struct vm_area_struct___331 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___331 *, long unsigned int);
	struct page___331 * (*find_special_page)(struct vm_area_struct___331 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_area_struct___331 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___331 *vm_next;
	struct vm_area_struct___331 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___330 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___318 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___330 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___317;

struct bin_attribute___293;

struct attribute_group___294 {
	const char *name;
	umode_t (*is_visible)(struct kobject___317 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___317 *, struct bin_attribute___293 *, int);
	struct attribute **attrs;
	struct bin_attribute___293 **bin_attrs;
};

struct kset___316;

struct kobj_type___316;

struct kobject___317 {
	const char *name;
	struct list_head entry;
	struct kobject___317 *parent;
	struct kset___316 *kset;
	struct kobj_type___316 *ktype;
	struct kernfs_node___324 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___293 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___330 *, struct kobject___317 *, struct bin_attribute___293 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___330 *, struct kobject___317 *, struct bin_attribute___293 *, char *, loff_t, size_t);
	int (*mmap)(struct file___330 *, struct kobject___317 *, struct bin_attribute___293 *, struct vm_area_struct___331 *);
};

struct sysfs_ops___316 {
	ssize_t (*show)(struct kobject___317 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___317 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___316;

struct kset___316 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___317 kobj;
	const struct kset_uevent_ops___316 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___316 {
	void (*release)(struct kobject___317 *);
	const struct sysfs_ops___316 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___25 * (*child_ns_type)(struct kobject___317 *);
	const void * (*namespace)(struct kobject___317 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___316 {
	int (* const filter)(struct kset___316 *, struct kobject___317 *);
	const char * (* const name)(struct kset___316 *, struct kobject___317 *);
	int (* const uevent)(struct kset___316 *, struct kobject___317 *, struct kobj_uevent_env *);
};

struct kobj_attribute___308 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___317 *, struct kobj_attribute___308 *, char *);
	ssize_t (*store)(struct kobject___317 *, struct kobj_attribute___308 *, const char *, size_t);
};

struct device___296;

struct dev_pm_ops___296 {
	int (*prepare)(struct device___296 *);
	void (*complete)(struct device___296 *);
	int (*suspend)(struct device___296 *);
	int (*resume)(struct device___296 *);
	int (*freeze)(struct device___296 *);
	int (*thaw)(struct device___296 *);
	int (*poweroff)(struct device___296 *);
	int (*restore)(struct device___296 *);
	int (*suspend_late)(struct device___296 *);
	int (*resume_early)(struct device___296 *);
	int (*freeze_late)(struct device___296 *);
	int (*thaw_early)(struct device___296 *);
	int (*poweroff_late)(struct device___296 *);
	int (*restore_early)(struct device___296 *);
	int (*suspend_noirq)(struct device___296 *);
	int (*resume_noirq)(struct device___296 *);
	int (*freeze_noirq)(struct device___296 *);
	int (*thaw_noirq)(struct device___296 *);
	int (*poweroff_noirq)(struct device___296 *);
	int (*restore_noirq)(struct device___296 *);
	int (*runtime_suspend)(struct device___296 *);
	int (*runtime_resume)(struct device___296 *);
	int (*runtime_idle)(struct device___296 *);
};

struct dev_pm_info___296 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___3 *subsys_data;
	void (*set_latency_tolerance)(struct device___296 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___296;

struct bus_type___296;

struct device_driver___296;

struct dev_pm_domain___296;

struct device_node___74;

struct fwnode_handle___225;

struct class___296;

struct iommu_fwspec___6;

struct device___296 {
	struct device___296 *parent;
	struct device_private *p;
	struct kobject___317 kobj;
	const char *init_name;
	const struct device_type___296 *type;
	struct mutex mutex;
	struct bus_type___296 *bus;
	struct device_driver___296 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___296 power;
	struct dev_pm_domain___296 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___74 *of_node;
	struct fwnode_handle___225 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___296 *class;
	const struct attribute_group___294 **groups;
	void (*release)(struct device___296 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec___6 *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___296 {
	struct dev_pm_ops___296 ops;
	void (*detach)(struct device___296 *, bool);
	int (*activate)(struct device___296 *);
	void (*sync)(struct device___296 *);
	void (*dismiss)(struct device___296 *);
};

struct core_state___330;

struct mm_struct___330 {
	struct {
		struct vm_area_struct___331 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___330 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___331 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___330 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___331 *owner;
		struct user_namespace___3 *user_ns;
		struct file___330 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___330 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct vm_struct___241 {
	struct vm_struct___241 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___331 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct iommu_ops___6;

struct bus_type___296 {
	const char *name;
	const char *dev_name;
	struct device___296 *dev_root;
	const struct attribute_group___294 **bus_groups;
	const struct attribute_group___294 **dev_groups;
	const struct attribute_group___294 **drv_groups;
	int (*match)(struct device___296 *, struct device_driver___296 *);
	int (*uevent)(struct device___296 *, struct kobj_uevent_env *);
	int (*probe)(struct device___296 *);
	int (*remove)(struct device___296 *);
	void (*shutdown)(struct device___296 *);
	int (*online)(struct device___296 *);
	int (*offline)(struct device___296 *);
	int (*suspend)(struct device___296 *, pm_message_t);
	int (*resume)(struct device___296 *);
	int (*num_vf)(struct device___296 *);
	int (*dma_configure)(struct device___296 *);
	const struct dev_pm_ops___296 *pm;
	const struct iommu_ops___6 *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___296 {
	const char *name;
	struct bus_type___296 *bus;
	struct module___269 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___296 *);
	int (*remove)(struct device___296 *);
	void (*shutdown)(struct device___296 *);
	int (*suspend)(struct device___296 *, pm_message_t);
	int (*resume)(struct device___296 *);
	const struct attribute_group___294 **groups;
	const struct dev_pm_ops___296 *pm;
	void (*coredump)(struct device___296 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct iommu_domain___6;

struct of_phandle_args___12;

struct iommu_ops___6 {
	bool (*capable)(enum iommu_cap);
	struct iommu_domain___6 * (*domain_alloc)(unsigned int);
	void (*domain_free)(struct iommu_domain___6 *);
	int (*attach_dev)(struct iommu_domain___6 *, struct device___296 *);
	void (*detach_dev)(struct iommu_domain___6 *, struct device___296 *);
	int (*map)(struct iommu_domain___6 *, long unsigned int, phys_addr_t, size_t, int);
	size_t (*unmap)(struct iommu_domain___6 *, long unsigned int, size_t);
	void (*flush_iotlb_all)(struct iommu_domain___6 *);
	void (*iotlb_range_add)(struct iommu_domain___6 *, long unsigned int, size_t);
	void (*iotlb_sync)(struct iommu_domain___6 *);
	phys_addr_t (*iova_to_phys)(struct iommu_domain___6 *, dma_addr_t);
	int (*add_device)(struct device___296 *);
	void (*remove_device)(struct device___296 *);
	struct iommu_group * (*device_group)(struct device___296 *);
	int (*domain_get_attr)(struct iommu_domain___6 *, enum iommu_attr, void *);
	int (*domain_set_attr)(struct iommu_domain___6 *, enum iommu_attr, void *);
	void (*get_resv_regions)(struct device___296 *, struct list_head *);
	void (*put_resv_regions)(struct device___296 *, struct list_head *);
	void (*apply_resv_region)(struct device___296 *, struct iommu_domain___6 *, struct iommu_resv_region *);
	int (*domain_window_enable)(struct iommu_domain___6 *, u32, phys_addr_t, u64, int);
	void (*domain_window_disable)(struct iommu_domain___6 *, u32);
	int (*domain_set_windows)(struct iommu_domain___6 *, u32);
	u32 (*domain_get_windows)(struct iommu_domain___6 *);
	int (*of_xlate)(struct device___296 *, struct of_phandle_args___12 *);
	bool (*is_attach_deferred)(struct iommu_domain___6 *, struct device___296 *);
	long unsigned int pgsize_bitmap;
};

struct device_type___296 {
	const char *name;
	const struct attribute_group___294 **groups;
	int (*uevent)(struct device___296 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___296 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___296 *);
	const struct dev_pm_ops___296 *pm;
};

struct module_kobject___266 {
	struct kobject___317 kobj;
	struct module___269 *mod;
	struct kobject___317 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___266 {
	struct module___269 *mod;
	struct latch_tree_node node;
};

struct module_layout___266 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___266 mtn;
};

struct module_attribute___266;

struct kernel_param___266;

struct module___269 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___266 mkobj;
	struct module_attribute___266 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___317 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___266 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___266 core_layout;
	struct module_layout___266 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct class___296 {
	const char *name;
	struct module___269 *owner;
	const struct attribute_group___294 **class_groups;
	const struct attribute_group___294 **dev_groups;
	struct kobject___317 *dev_kobj;
	int (*dev_uevent)(struct device___296 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___296 *, umode_t *);
	void (*class_release)(struct class___296 *);
	void (*dev_release)(struct device___296 *);
	int (*shutdown_pre)(struct device___296 *);
	const struct kobj_ns_type_operations___25 *ns_type;
	const void * (*namespace)(struct device___296 *);
	const struct dev_pm_ops___296 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct fwnode_operations___225;

struct fwnode_handle___225 {
	struct fwnode_handle___225 *secondary;
	const struct fwnode_operations___225 *ops;
};

struct property___70;

struct device_node___74 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___225 fwnode;
	struct property___70 *properties;
	struct property___70 *deadprops;
	struct device_node___74 *parent;
	struct device_node___74 *child;
	struct device_node___74 *sibling;
	struct kobject___317 kobj;
	long unsigned int _flags;
	void *data;
};

struct iommu_fwspec___6 {
	const struct iommu_ops___6 *ops;
	struct fwnode_handle___225 *iommu_fwnode;
	void *iommu_priv;
	unsigned int num_ids;
	u32 ids[1];
};

struct address_space_operations___329;

struct address_space___329 {
	struct inode___330 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___331 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___329 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___318)(struct vm_area_struct___331 *, long unsigned int, const struct page___331 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___318)(struct page___331 *, void *);

struct dev_pagemap___318 {
	dev_page_fault_t___318 page_fault;
	dev_page_free_t___318 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___296 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___330 {
	struct task_struct___331 *task;
	struct core_thread___330 *next;
};

struct core_state___330 {
	atomic_t nr_threads;
	struct core_thread___330 dumper;
	struct completion startup;
};

struct vm_fault___318 {
	struct vm_area_struct___331 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___331 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___331 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___330 prealloc_pte;
};

struct dentry_operations___329;

struct super_block___329;

struct dentry___329 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___329 *d_parent;
	struct qstr d_name;
	struct inode___330 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___329 *d_op;
	struct super_block___329 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___329;

struct block_device___329;

struct inode___330 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___329 *i_op;
	struct super_block___329 *i_sb;
	struct address_space___329 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___331 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___330 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___329 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___329 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___329 {
	int (*d_revalidate)(struct dentry___329 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___329 *, unsigned int);
	int (*d_hash)(const struct dentry___329 *, struct qstr *);
	int (*d_compare)(const struct dentry___329 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___329 *);
	int (*d_init)(struct dentry___329 *);
	void (*d_release)(struct dentry___329 *);
	void (*d_prune)(struct dentry___329 *);
	void (*d_iput)(struct dentry___329 *, struct inode___330 *);
	char * (*d_dname)(struct dentry___329 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___330 *);
	int (*d_manage)(const struct path___330 *, bool);
	struct dentry___329 * (*d_real)(struct dentry___329 *, const struct inode___330 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___329;

struct mem_dqinfo___329 {
	struct quota_format_type___329 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___329;

struct quota_info___329 {
	unsigned int flags;
	struct rw_semaphore___331 dqio_sem;
	struct inode___330 *files[3];
	struct mem_dqinfo___329 info[3];
	const struct quota_format_ops___329 *ops[3];
};

struct rcuwait___329 {
	struct task_struct___331 *task;
};

struct percpu_rw_semaphore___329 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___331 rw_sem;
	struct rcuwait___329 writer;
	int readers_block;
};

struct sb_writers___329 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___329 rw_sem[3];
};

struct file_system_type___329;

struct super_operations___329;

struct dquot_operations___329;

struct quotactl_ops___329;

struct super_block___329 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___329 *s_type;
	const struct super_operations___329 *s_op;
	const struct dquot_operations___329 *dq_op;
	const struct quotactl_ops___329 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___329 *s_root;
	struct rw_semaphore___331 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___329 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___329 s_dquot;
	struct sb_writers___329 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___329 *s_d_op;
	int cleancache_poolid;
	struct shrinker___122 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___330 {
	struct file___330 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___330 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___329 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___330 *ia_file;
};

struct dquot___329 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___329 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___329 {
	int qf_fmt_id;
	const struct quota_format_ops___329 *qf_ops;
	struct module___269 *qf_owner;
	struct quota_format_type___329 *qf_next;
};

struct quota_format_ops___329 {
	int (*check_quota_file)(struct super_block___329 *, int);
	int (*read_file_info)(struct super_block___329 *, int);
	int (*write_file_info)(struct super_block___329 *, int);
	int (*free_file_info)(struct super_block___329 *, int);
	int (*read_dqblk)(struct dquot___329 *);
	int (*commit_dqblk)(struct dquot___329 *);
	int (*release_dqblk)(struct dquot___329 *);
	int (*get_next_id)(struct super_block___329 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___329 {
	int (*write_dquot)(struct dquot___329 *);
	struct dquot___329 * (*alloc_dquot)(struct super_block___329 *, int);
	void (*destroy_dquot)(struct dquot___329 *);
	int (*acquire_dquot)(struct dquot___329 *);
	int (*release_dquot)(struct dquot___329 *);
	int (*mark_dirty)(struct dquot___329 *);
	int (*write_info)(struct super_block___329 *, int);
	qsize_t * (*get_reserved_space)(struct inode___330 *);
	int (*get_projid)(struct inode___330 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___330 *, qsize_t *);
	int (*get_next_id)(struct super_block___329 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___329 {
	int (*quota_on)(struct super_block___329 *, int, int, const struct path___330 *);
	int (*quota_off)(struct super_block___329 *, int);
	int (*quota_enable)(struct super_block___329 *, unsigned int);
	int (*quota_disable)(struct super_block___329 *, unsigned int);
	int (*quota_sync)(struct super_block___329 *, int);
	int (*set_info)(struct super_block___329 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___329 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___329 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___329 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___329 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___329 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___329 {
	int (*writepage)(struct page___331 *, struct writeback_control___3 *);
	int (*readpage)(struct file___330 *, struct page___331 *);
	int (*writepages)(struct address_space___329 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___331 *);
	int (*readpages)(struct file___330 *, struct address_space___329 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___330 *, struct address_space___329 *, loff_t, unsigned int, unsigned int, struct page___331 **, void **);
	int (*write_end)(struct file___330 *, struct address_space___329 *, loff_t, unsigned int, unsigned int, struct page___331 *, void *);
	sector_t (*bmap)(struct address_space___329 *, sector_t);
	void (*invalidatepage)(struct page___331 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___331 *, gfp_t);
	void (*freepage)(struct page___331 *);
	ssize_t (*direct_IO)(struct kiocb___330 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___329 *, struct page___331 *, struct page___331 *, enum migrate_mode);
	bool (*isolate_page)(struct page___331 *, isolate_mode_t);
	void (*putback_page)(struct page___331 *);
	int (*launder_page)(struct page___331 *);
	int (*is_partially_uptodate)(struct page___331 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___331 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___329 *, struct page___331 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___330 *, sector_t *);
	void (*swap_deactivate)(struct file___330 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___329 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___330 *bd_inode;
	struct super_block___329 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___329 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___329 {
	struct dentry___329 * (*lookup)(struct inode___330 *, struct dentry___329 *, unsigned int);
	const char * (*get_link)(struct dentry___329 *, struct inode___330 *, struct delayed_call *);
	int (*permission)(struct inode___330 *, int);
	struct posix_acl * (*get_acl)(struct inode___330 *, int);
	int (*readlink)(struct dentry___329 *, char *, int);
	int (*create)(struct inode___330 *, struct dentry___329 *, umode_t, bool);
	int (*link)(struct dentry___329 *, struct inode___330 *, struct dentry___329 *);
	int (*unlink)(struct inode___330 *, struct dentry___329 *);
	int (*symlink)(struct inode___330 *, struct dentry___329 *, const char *);
	int (*mkdir)(struct inode___330 *, struct dentry___329 *, umode_t);
	int (*rmdir)(struct inode___330 *, struct dentry___329 *);
	int (*mknod)(struct inode___330 *, struct dentry___329 *, umode_t, dev_t);
	int (*rename)(struct inode___330 *, struct dentry___329 *, struct inode___330 *, struct dentry___329 *, unsigned int);
	int (*setattr)(struct dentry___329 *, struct iattr___329 *);
	int (*getattr)(const struct path___330 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___329 *, char *, size_t);
	int (*fiemap)(struct inode___330 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___330 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___330 *, struct dentry___329 *, struct file___330 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___330 *, struct dentry___329 *, umode_t);
	int (*set_acl)(struct inode___330 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___329 {
	void (*fl_copy_lock)(struct file_lock___330 *, struct file_lock___330 *);
	void (*fl_release_private)(struct file_lock___330 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___329;

struct lock_manager_operations___329;

struct file_lock___330 {
	struct file_lock___330 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___330 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___329 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___329 *fl_ops;
	const struct lock_manager_operations___329 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___329 {
	int (*lm_compare_owner)(struct file_lock___330 *, struct file_lock___330 *);
	long unsigned int (*lm_owner_key)(struct file_lock___330 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___330 *);
	int (*lm_grant)(struct file_lock___330 *, int);
	bool (*lm_break)(struct file_lock___330 *);
	int (*lm_change)(struct file_lock___330 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___330 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___329 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___329 *fa_next;
	struct file___330 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___329 {
	const char *name;
	int fs_flags;
	struct dentry___329 * (*mount)(struct file_system_type___329 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___329 *);
	struct module___269 *owner;
	struct file_system_type___329 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___329 {
	struct inode___330 * (*alloc_inode)(struct super_block___329 *);
	void (*destroy_inode)(struct inode___330 *);
	void (*dirty_inode)(struct inode___330 *, int);
	int (*write_inode)(struct inode___330 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___330 *);
	void (*evict_inode)(struct inode___330 *);
	void (*put_super)(struct super_block___329 *);
	int (*sync_fs)(struct super_block___329 *, int);
	int (*freeze_super)(struct super_block___329 *);
	int (*freeze_fs)(struct super_block___329 *);
	int (*thaw_super)(struct super_block___329 *);
	int (*unfreeze_fs)(struct super_block___329 *);
	int (*statfs)(struct dentry___329 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___329 *, int *, char *);
	void (*umount_begin)(struct super_block___329 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___329 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___329 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___329 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___329 *);
	ssize_t (*quota_read)(struct super_block___329 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___329 *, int, const char *, size_t, loff_t);
	struct dquot___329 ** (*get_dquots)(struct inode___330 *);
	int (*bdev_try_to_free_page)(struct super_block___329 *, struct page___331 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___329 *, struct shrink_control___122 *);
	long int (*free_cached_objects)(struct super_block___329 *, struct shrink_control___122 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___318(struct page___331 *);

struct fwnode_reference_args___225;

struct fwnode_endpoint___225;

struct fwnode_operations___225 {
	struct fwnode_handle___225 * (*get)(struct fwnode_handle___225 *);
	void (*put)(struct fwnode_handle___225 *);
	bool (*device_is_available)(const struct fwnode_handle___225 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___225 *, const struct device___296 *);
	bool (*property_present)(const struct fwnode_handle___225 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___225 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___225 *, const char *, const char **, size_t);
	struct fwnode_handle___225 * (*get_parent)(const struct fwnode_handle___225 *);
	struct fwnode_handle___225 * (*get_next_child_node)(const struct fwnode_handle___225 *, struct fwnode_handle___225 *);
	struct fwnode_handle___225 * (*get_named_child_node)(const struct fwnode_handle___225 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___225 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___225 *);
	struct fwnode_handle___225 * (*graph_get_next_endpoint)(const struct fwnode_handle___225 *, struct fwnode_handle___225 *);
	struct fwnode_handle___225 * (*graph_get_remote_endpoint)(const struct fwnode_handle___225 *);
	struct fwnode_handle___225 * (*graph_get_port_parent)(struct fwnode_handle___225 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___225 *, struct fwnode_endpoint___225 *);
};

struct fwnode_endpoint___225 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___225 *local_fwnode;
};

struct fwnode_reference_args___225 {
	struct fwnode_handle___225 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct property___70 {
	char *name;
	int length;
	void *value;
	struct property___70 *next;
	long unsigned int _flags;
	struct bin_attribute___293 attr;
};

struct of_phandle_args___12 {
	struct device_node___74 *np;
	int args_count;
	uint32_t args[16];
};

typedef int (*iommu_fault_handler_t___7)(struct iommu_domain___6 *, struct device___296 *, long unsigned int, int, void *);

struct iommu_domain___6 {
	unsigned int type;
	const struct iommu_ops___6 *ops;
	long unsigned int pgsize_bitmap;
	iommu_fault_handler_t___7 handler;
	void *handler_token;
	struct iommu_domain_geometry geometry;
	void *iova_cookie;
};

struct iommu_device___2 {
	struct list_head list;
	const struct iommu_ops___6 *ops;
	struct fwnode_handle___225 *fwnode;
	struct device___296 *dev;
};

struct kernel_param_ops___266 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___266 *);
	int (*get)(char *, const struct kernel_param___266 *);
	void (*free)(void *);
};

struct kparam_array___266;

struct kernel_param___266 {
	const char *name;
	struct module___269 *mod;
	const struct kernel_param_ops___266 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___266 *arr;
	};
};

struct kparam_array___266 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___266 *ops;
	void *elem;
};

struct module_attribute___266 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___266 *, struct module_kobject___266 *, char *);
	ssize_t (*store)(struct module_attribute___266 *, struct module_kobject___266 *, const char *, size_t);
	void (*setup)(struct module___269 *, const char *);
	int (*test)(struct module___269 *);
	void (*free)(struct module___269 *);
};

struct sg_mapping_iter___3 {
	struct page___282 *page;
	void *addr;
	size_t length;
	size_t consumed;
	struct sg_page_iter piter;
	unsigned int __offset;
	unsigned int __remaining;
	unsigned int __flags;
};

struct iova {
	struct rb_node node;
	long unsigned int pfn_hi;
	long unsigned int pfn_lo;
};

struct iova_magazine;

struct iova_cpu_rcache;

struct iova_rcache {
	spinlock_t lock;
	long unsigned int depot_size;
	struct iova_magazine *depot[32];
	struct iova_cpu_rcache *cpu_rcaches;
};

struct iova_domain;

typedef void (*iova_flush_cb)(struct iova_domain *);

typedef void (*iova_entry_dtor)(long unsigned int);

struct iova_fq;

struct iova_domain {
	spinlock_t iova_rbtree_lock;
	struct rb_root rbroot;
	struct rb_node *cached_node;
	struct rb_node *cached32_node;
	long unsigned int granule;
	long unsigned int start_pfn;
	long unsigned int dma_32bit_pfn;
	long unsigned int max32_alloc_size;
	struct iova anchor;
	struct iova_rcache rcaches[6];
	iova_flush_cb flush_cb;
	iova_entry_dtor entry_dtor;
	struct iova_fq *fq;
	atomic64_t fq_flush_start_cnt;
	atomic64_t fq_flush_finish_cnt;
	struct timer_list fq_timer;
	atomic_t fq_timer_on;
};

struct iova_fq_entry {
	long unsigned int iova_pfn;
	long unsigned int pages;
	long unsigned int data;
	u64 counter;
};

struct iova_fq {
	struct iova_fq_entry entries[256];
	unsigned int head;
	unsigned int tail;
	spinlock_t lock;
};

struct iommu_dma_msi_page {
	struct list_head list;
	dma_addr_t iova;
	phys_addr_t phys;
};

enum iommu_dma_cookie_type {
	IOMMU_DMA_IOVA_COOKIE = 0,
	IOMMU_DMA_MSI_COOKIE = 1,
};

struct iommu_dma_cookie {
	enum iommu_dma_cookie_type type;
	union {
		struct iova_domain iovad;
		dma_addr_t msi_iova;
	};
	struct list_head msi_page_list;
	spinlock_t msi_lock;
	struct iommu_domain___3 *fq_domain;
};

enum io_pgtable_fmt {
	ARM_32_LPAE_S1 = 0,
	ARM_32_LPAE_S2 = 1,
	ARM_64_LPAE_S1 = 2,
	ARM_64_LPAE_S2 = 3,
	ARM_V7S = 4,
	IO_PGTABLE_NUM_FMTS = 5,
};

struct iommu_gather_ops {
	void (*tlb_flush_all)(void *);
	void (*tlb_add_flush)(long unsigned int, size_t, size_t, bool, void *);
	void (*tlb_sync)(void *);
};

struct io_pgtable_cfg {
	long unsigned int quirks;
	long unsigned int pgsize_bitmap;
	unsigned int ias;
	unsigned int oas;
	const struct iommu_gather_ops *tlb;
	struct device___6 *iommu_dev;
	union {
		struct {
			u64 ttbr[2];
			u64 tcr;
			u64 mair[2];
		} arm_lpae_s1_cfg;
		struct {
			u64 vttbr;
			u64 vtcr;
		} arm_lpae_s2_cfg;
		struct {
			u32 ttbr[2];
			u32 tcr;
			u32 nmrr;
			u32 prrr;
		} arm_v7s_cfg;
	};
};

struct io_pgtable_ops {
	int (*map)(struct io_pgtable_ops *, long unsigned int, phys_addr_t, size_t, int);
	size_t (*unmap)(struct io_pgtable_ops *, long unsigned int, size_t);
	phys_addr_t (*iova_to_phys)(struct io_pgtable_ops *, long unsigned int);
};

struct io_pgtable {
	enum io_pgtable_fmt fmt;
	void *cookie;
	struct io_pgtable_cfg cfg;
	struct io_pgtable_ops ops;
};

struct io_pgtable_init_fns {
	struct io_pgtable * (*alloc)(struct io_pgtable_cfg *, void *);
	void (*free)(struct io_pgtable *);
};

struct file___331;

struct kiocb___331;

struct vm_area_struct___332;

struct inode___331;

struct file_lock___331;

struct page___332;

struct file_operations___331 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___331 *, loff_t, int);
	ssize_t (*read)(struct file___331 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___331 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___331 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___331 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___331 *, bool);
	int (*iterate)(struct file___331 *, struct dir_context *);
	int (*iterate_shared)(struct file___331 *, struct dir_context *);
	__poll_t (*poll)(struct file___331 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___331 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___331 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___331 *, struct vm_area_struct___332 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___331 *, struct file___331 *);
	int (*flush)(struct file___331 *, fl_owner_t);
	int (*release)(struct inode___331 *, struct file___331 *);
	int (*fsync)(struct file___331 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___331 *, int);
	int (*lock)(struct file___331 *, int, struct file_lock___331 *);
	ssize_t (*sendpage)(struct file___331 *, struct page___332 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___331 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___331 *, int, struct file_lock___331 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___331 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___331 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___331 *, long int, struct file_lock___331 **, void **);
	long int (*fallocate)(struct file___331 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___331 *);
	ssize_t (*copy_file_range)(struct file___331 *, loff_t, struct file___331 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___331 *, loff_t, struct file___331 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___331 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___331 {
	u64 seqnum;
	struct vm_area_struct___332 *vmas[4];
};

struct page_frag___331 {
	struct page___332 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___331;

struct vm_struct___242;

struct task_struct___332 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___332 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___331 *mm;
	struct mm_struct___331 *active_mm;
	struct vmacache___331 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___332 *real_parent;
	struct task_struct___332 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___332 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___209 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___209 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___209 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___2 *ptracer_cred;
	const struct cred___2 *real_cred;
	const struct cred___2 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___332 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___84 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___331 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___332 *oom_reaper_list;
	struct vm_struct___242 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___134 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___332 *pgtable_t___331;

struct address_space___330;

struct dev_pagemap___319;

struct page___332 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___330 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___332 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___331 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___331 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___319 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___331;

struct lruvec___331 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___331 *pgdat;
};

struct zone___331 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___331 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___331 {
	struct zone___331 *zone;
	int zone_idx;
};

struct zonelist___331 {
	struct zoneref___331 _zonerefs[25];
};

struct pglist_data___331 {
	struct zone___331 node_zones[3];
	struct zonelist___331 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___332 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___332 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___331 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___332 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___332 *owner;
};

struct secondary_data___332 {
	void *stack;
	struct task_struct___332 *task;
	long int status;
};

struct blocking_notifier_head___331 {
	struct rw_semaphore___332 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___319;

struct vm_area_struct___332 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___332 *vm_next;
	struct vm_area_struct___332 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___331 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___319 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___331 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___331;

struct mm_struct___331 {
	struct {
		struct vm_area_struct___332 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___331 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___332 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___331 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___332 *owner;
		struct user_namespace___3 *user_ns;
		struct file___331 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___331 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___330;

struct address_space___330 {
	struct inode___331 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___332 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___330 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___319)(struct vm_area_struct___332 *, long unsigned int, const struct page___332 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___319)(struct page___332 *, void *);

struct device___297;

struct dev_pagemap___319 {
	dev_page_fault_t___319 page_fault;
	dev_page_free_t___319 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___297 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct dentry___330;

struct path___331 {
	struct vfsmount *mnt;
	struct dentry___330 *dentry;
};

struct file___331 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___331 f_path;
	struct inode___331 *f_inode;
	const struct file_operations___331 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___209 f_owner;
	const struct cred___2 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___330 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___319;

struct vm_operations_struct___319 {
	void (*open)(struct vm_area_struct___332 *);
	void (*close)(struct vm_area_struct___332 *);
	int (*split)(struct vm_area_struct___332 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___332 *);
	vm_fault_t (*fault)(struct vm_fault___319 *);
	vm_fault_t (*huge_fault)(struct vm_fault___319 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___319 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___332 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___319 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___319 *);
	int (*access)(struct vm_area_struct___332 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___332 *);
	int (*set_policy)(struct vm_area_struct___332 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___332 *, long unsigned int);
	struct page___332 * (*find_special_page)(struct vm_area_struct___332 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___331 {
	struct task_struct___332 *task;
	struct core_thread___331 *next;
};

struct core_state___331 {
	atomic_t nr_threads;
	struct core_thread___331 dumper;
	struct completion startup;
};

struct vm_fault___319 {
	struct vm_area_struct___332 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___332 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___332 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___331 prealloc_pte;
};

struct vm_struct___242 {
	struct vm_struct___242 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___332 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct kset___317;

struct kobj_type___317;

struct kernfs_node___325;

struct kobject___318 {
	const char *name;
	struct list_head entry;
	struct kobject___318 *parent;
	struct kset___317 *kset;
	struct kobj_type___317 *ktype;
	struct kernfs_node___325 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___297 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___3 *subsys_data;
	void (*set_latency_tolerance)(struct device___297 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___297;

struct bus_type___297;

struct device_driver___297;

struct dev_pm_domain___297;

struct dma_map_ops___96;

struct device_node___75;

struct fwnode_handle___226;

struct class___297;

struct attribute_group___295;

struct iommu_fwspec___7;

struct device___297 {
	struct device___297 *parent;
	struct device_private *p;
	struct kobject___318 kobj;
	const char *init_name;
	const struct device_type___297 *type;
	struct mutex mutex;
	struct bus_type___297 *bus;
	struct device_driver___297 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___297 power;
	struct dev_pm_domain___297 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___96 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___75 *of_node;
	struct fwnode_handle___226 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___297 *class;
	const struct attribute_group___295 **groups;
	void (*release)(struct device___297 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec___7 *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___330;

struct super_block___330;

struct dentry___330 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___330 *d_parent;
	struct qstr d_name;
	struct inode___331 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___330 *d_op;
	struct super_block___330 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___330;

struct block_device___330;

struct inode___331 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___330 *i_op;
	struct super_block___330 *i_sb;
	struct address_space___330 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___332 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___331 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___330 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___330 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___330 {
	int (*d_revalidate)(struct dentry___330 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___330 *, unsigned int);
	int (*d_hash)(const struct dentry___330 *, struct qstr *);
	int (*d_compare)(const struct dentry___330 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___330 *);
	int (*d_init)(struct dentry___330 *);
	void (*d_release)(struct dentry___330 *);
	void (*d_prune)(struct dentry___330 *);
	void (*d_iput)(struct dentry___330 *, struct inode___331 *);
	char * (*d_dname)(struct dentry___330 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___331 *);
	int (*d_manage)(const struct path___331 *, bool);
	struct dentry___330 * (*d_real)(struct dentry___330 *, const struct inode___331 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___330;

struct mem_dqinfo___330 {
	struct quota_format_type___330 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___330;

struct quota_info___330 {
	unsigned int flags;
	struct rw_semaphore___332 dqio_sem;
	struct inode___331 *files[3];
	struct mem_dqinfo___330 info[3];
	const struct quota_format_ops___330 *ops[3];
};

struct rcuwait___330 {
	struct task_struct___332 *task;
};

struct percpu_rw_semaphore___330 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___332 rw_sem;
	struct rcuwait___330 writer;
	int readers_block;
};

struct sb_writers___330 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___330 rw_sem[3];
};

struct file_system_type___330;

struct super_operations___330;

struct dquot_operations___330;

struct quotactl_ops___330;

struct super_block___330 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___330 *s_type;
	const struct super_operations___330 *s_op;
	const struct dquot_operations___330 *dq_op;
	const struct quotactl_ops___330 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___330 *s_root;
	struct rw_semaphore___332 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___330 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___330 s_dquot;
	struct sb_writers___330 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___330 *s_d_op;
	int cleancache_poolid;
	struct shrinker___122 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___331 {
	struct file___331 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___331 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___330 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___331 *ia_file;
};

struct dquot___330 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___330 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___330 {
	int qf_fmt_id;
	const struct quota_format_ops___330 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___330 *qf_next;
};

struct quota_format_ops___330 {
	int (*check_quota_file)(struct super_block___330 *, int);
	int (*read_file_info)(struct super_block___330 *, int);
	int (*write_file_info)(struct super_block___330 *, int);
	int (*free_file_info)(struct super_block___330 *, int);
	int (*read_dqblk)(struct dquot___330 *);
	int (*commit_dqblk)(struct dquot___330 *);
	int (*release_dqblk)(struct dquot___330 *);
	int (*get_next_id)(struct super_block___330 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___330 {
	int (*write_dquot)(struct dquot___330 *);
	struct dquot___330 * (*alloc_dquot)(struct super_block___330 *, int);
	void (*destroy_dquot)(struct dquot___330 *);
	int (*acquire_dquot)(struct dquot___330 *);
	int (*release_dquot)(struct dquot___330 *);
	int (*mark_dirty)(struct dquot___330 *);
	int (*write_info)(struct super_block___330 *, int);
	qsize_t * (*get_reserved_space)(struct inode___331 *);
	int (*get_projid)(struct inode___331 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___331 *, qsize_t *);
	int (*get_next_id)(struct super_block___330 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___330 {
	int (*quota_on)(struct super_block___330 *, int, int, const struct path___331 *);
	int (*quota_off)(struct super_block___330 *, int);
	int (*quota_enable)(struct super_block___330 *, unsigned int);
	int (*quota_disable)(struct super_block___330 *, unsigned int);
	int (*quota_sync)(struct super_block___330 *, int);
	int (*set_info)(struct super_block___330 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___330 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___330 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___330 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___330 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___330 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___330 {
	int (*writepage)(struct page___332 *, struct writeback_control___3 *);
	int (*readpage)(struct file___331 *, struct page___332 *);
	int (*writepages)(struct address_space___330 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___332 *);
	int (*readpages)(struct file___331 *, struct address_space___330 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___331 *, struct address_space___330 *, loff_t, unsigned int, unsigned int, struct page___332 **, void **);
	int (*write_end)(struct file___331 *, struct address_space___330 *, loff_t, unsigned int, unsigned int, struct page___332 *, void *);
	sector_t (*bmap)(struct address_space___330 *, sector_t);
	void (*invalidatepage)(struct page___332 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___332 *, gfp_t);
	void (*freepage)(struct page___332 *);
	ssize_t (*direct_IO)(struct kiocb___331 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___330 *, struct page___332 *, struct page___332 *, enum migrate_mode);
	bool (*isolate_page)(struct page___332 *, isolate_mode_t);
	void (*putback_page)(struct page___332 *);
	int (*launder_page)(struct page___332 *);
	int (*is_partially_uptodate)(struct page___332 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___332 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___330 *, struct page___332 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___331 *, sector_t *);
	void (*swap_deactivate)(struct file___331 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___330 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___331 *bd_inode;
	struct super_block___330 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___330 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___330 {
	struct dentry___330 * (*lookup)(struct inode___331 *, struct dentry___330 *, unsigned int);
	const char * (*get_link)(struct dentry___330 *, struct inode___331 *, struct delayed_call *);
	int (*permission)(struct inode___331 *, int);
	struct posix_acl * (*get_acl)(struct inode___331 *, int);
	int (*readlink)(struct dentry___330 *, char *, int);
	int (*create)(struct inode___331 *, struct dentry___330 *, umode_t, bool);
	int (*link)(struct dentry___330 *, struct inode___331 *, struct dentry___330 *);
	int (*unlink)(struct inode___331 *, struct dentry___330 *);
	int (*symlink)(struct inode___331 *, struct dentry___330 *, const char *);
	int (*mkdir)(struct inode___331 *, struct dentry___330 *, umode_t);
	int (*rmdir)(struct inode___331 *, struct dentry___330 *);
	int (*mknod)(struct inode___331 *, struct dentry___330 *, umode_t, dev_t);
	int (*rename)(struct inode___331 *, struct dentry___330 *, struct inode___331 *, struct dentry___330 *, unsigned int);
	int (*setattr)(struct dentry___330 *, struct iattr___330 *);
	int (*getattr)(const struct path___331 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___330 *, char *, size_t);
	int (*fiemap)(struct inode___331 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___331 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___331 *, struct dentry___330 *, struct file___331 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___331 *, struct dentry___330 *, umode_t);
	int (*set_acl)(struct inode___331 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___330 {
	void (*fl_copy_lock)(struct file_lock___331 *, struct file_lock___331 *);
	void (*fl_release_private)(struct file_lock___331 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___330;

struct lock_manager_operations___330;

struct file_lock___331 {
	struct file_lock___331 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___331 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___330 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___330 *fl_ops;
	const struct lock_manager_operations___330 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___330 {
	int (*lm_compare_owner)(struct file_lock___331 *, struct file_lock___331 *);
	long unsigned int (*lm_owner_key)(struct file_lock___331 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___331 *);
	int (*lm_grant)(struct file_lock___331 *, int);
	bool (*lm_break)(struct file_lock___331 *);
	int (*lm_change)(struct file_lock___331 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___331 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___330 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___330 *fa_next;
	struct file___331 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___330 {
	const char *name;
	int fs_flags;
	struct dentry___330 * (*mount)(struct file_system_type___330 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___330 *);
	struct module___11 *owner;
	struct file_system_type___330 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___330 {
	struct inode___331 * (*alloc_inode)(struct super_block___330 *);
	void (*destroy_inode)(struct inode___331 *);
	void (*dirty_inode)(struct inode___331 *, int);
	int (*write_inode)(struct inode___331 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___331 *);
	void (*evict_inode)(struct inode___331 *);
	void (*put_super)(struct super_block___330 *);
	int (*sync_fs)(struct super_block___330 *, int);
	int (*freeze_super)(struct super_block___330 *);
	int (*freeze_fs)(struct super_block___330 *);
	int (*thaw_super)(struct super_block___330 *);
	int (*unfreeze_fs)(struct super_block___330 *);
	int (*statfs)(struct dentry___330 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___330 *, int *, char *);
	void (*umount_begin)(struct super_block___330 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___330 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___330 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___330 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___330 *);
	ssize_t (*quota_read)(struct super_block___330 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___330 *, int, const char *, size_t, loff_t);
	struct dquot___330 ** (*get_dquots)(struct inode___331 *);
	int (*bdev_try_to_free_page)(struct super_block___330 *, struct page___332 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___330 *, struct shrink_control___122 *);
	long int (*free_cached_objects)(struct super_block___330 *, struct shrink_control___122 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_attribute___309 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___318 *, struct kobj_attribute___309 *, char *);
	ssize_t (*store)(struct kobject___318 *, struct kobj_attribute___309 *, const char *, size_t);
};

typedef void compound_page_dtor___319(struct page___332 *);

struct fwnode_operations___226;

struct fwnode_handle___226 {
	struct fwnode_handle___226 *secondary;
	const struct fwnode_operations___226 *ops;
};

struct fwnode_reference_args___226;

struct fwnode_endpoint___226;

struct fwnode_operations___226 {
	struct fwnode_handle___226 * (*get)(struct fwnode_handle___226 *);
	void (*put)(struct fwnode_handle___226 *);
	bool (*device_is_available)(const struct fwnode_handle___226 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___226 *, const struct device___297 *);
	bool (*property_present)(const struct fwnode_handle___226 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___226 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___226 *, const char *, const char **, size_t);
	struct fwnode_handle___226 * (*get_parent)(const struct fwnode_handle___226 *);
	struct fwnode_handle___226 * (*get_next_child_node)(const struct fwnode_handle___226 *, struct fwnode_handle___226 *);
	struct fwnode_handle___226 * (*get_named_child_node)(const struct fwnode_handle___226 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___226 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___226 *);
	struct fwnode_handle___226 * (*graph_get_next_endpoint)(const struct fwnode_handle___226 *, struct fwnode_handle___226 *);
	struct fwnode_handle___226 * (*graph_get_remote_endpoint)(const struct fwnode_handle___226 *);
	struct fwnode_handle___226 * (*graph_get_port_parent)(struct fwnode_handle___226 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___226 *, struct fwnode_endpoint___226 *);
};

struct fwnode_endpoint___226 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___226 *local_fwnode;
};

struct fwnode_reference_args___226 {
	struct fwnode_handle___226 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct kernfs_root___324;

struct kernfs_elem_dir___324 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___324 *root;
};

struct kernfs_syscall_ops___324;

struct kernfs_root___324 {
	struct kernfs_node___325 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___324 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___324 {
	struct kernfs_node___325 *target_kn;
};

struct kernfs_ops___324;

struct kernfs_elem_attr___324 {
	const struct kernfs_ops___324 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___325 *notify_next;
};

struct kernfs_node___325 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___325 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___324 dir;
		struct kernfs_elem_symlink___324 symlink;
		struct kernfs_elem_attr___324 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___324;

struct kernfs_ops___324 {
	int (*open)(struct kernfs_open_file___324 *);
	void (*release)(struct kernfs_open_file___324 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___324 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___324 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___324 *, struct vm_area_struct___332 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___324 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___324 {
	int (*remount_fs)(struct kernfs_root___324 *, int *, char *);
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___324 *);
	int (*mkdir)(struct kernfs_node___325 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___325 *);
	int (*rename)(struct kernfs_node___325 *, struct kernfs_node___325 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___325 *, struct kernfs_root___324 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___324 {
	struct kernfs_node___325 *kn;
	struct file___331 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___319 *vm_ops;
};

struct bin_attribute___294;

struct attribute_group___295 {
	const char *name;
	umode_t (*is_visible)(struct kobject___318 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___318 *, struct bin_attribute___294 *, int);
	struct attribute **attrs;
	struct bin_attribute___294 **bin_attrs;
};

struct bin_attribute___294 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___331 *, struct kobject___318 *, struct bin_attribute___294 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___331 *, struct kobject___318 *, struct bin_attribute___294 *, char *, loff_t, size_t);
	int (*mmap)(struct file___331 *, struct kobject___318 *, struct bin_attribute___294 *, struct vm_area_struct___332 *);
};

struct sysfs_ops___317 {
	ssize_t (*show)(struct kobject___318 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___318 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___317;

struct kset___317 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___318 kobj;
	const struct kset_uevent_ops___317 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___317 {
	void (*release)(struct kobject___318 *);
	const struct sysfs_ops___317 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___25 * (*child_ns_type)(struct kobject___318 *);
	const void * (*namespace)(struct kobject___318 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___317 {
	int (* const filter)(struct kset___317 *, struct kobject___318 *);
	const char * (* const name)(struct kset___317 *, struct kobject___318 *);
	int (* const uevent)(struct kset___317 *, struct kobject___318 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___297 {
	int (*prepare)(struct device___297 *);
	void (*complete)(struct device___297 *);
	int (*suspend)(struct device___297 *);
	int (*resume)(struct device___297 *);
	int (*freeze)(struct device___297 *);
	int (*thaw)(struct device___297 *);
	int (*poweroff)(struct device___297 *);
	int (*restore)(struct device___297 *);
	int (*suspend_late)(struct device___297 *);
	int (*resume_early)(struct device___297 *);
	int (*freeze_late)(struct device___297 *);
	int (*thaw_early)(struct device___297 *);
	int (*poweroff_late)(struct device___297 *);
	int (*restore_early)(struct device___297 *);
	int (*suspend_noirq)(struct device___297 *);
	int (*resume_noirq)(struct device___297 *);
	int (*freeze_noirq)(struct device___297 *);
	int (*thaw_noirq)(struct device___297 *);
	int (*poweroff_noirq)(struct device___297 *);
	int (*restore_noirq)(struct device___297 *);
	int (*runtime_suspend)(struct device___297 *);
	int (*runtime_resume)(struct device___297 *);
	int (*runtime_idle)(struct device___297 *);
};

struct dev_pm_domain___297 {
	struct dev_pm_ops___297 ops;
	void (*detach)(struct device___297 *, bool);
	int (*activate)(struct device___297 *);
	void (*sync)(struct device___297 *);
	void (*dismiss)(struct device___297 *);
};

struct iommu_ops___7;

struct bus_type___297 {
	const char *name;
	const char *dev_name;
	struct device___297 *dev_root;
	const struct attribute_group___295 **bus_groups;
	const struct attribute_group___295 **dev_groups;
	const struct attribute_group___295 **drv_groups;
	int (*match)(struct device___297 *, struct device_driver___297 *);
	int (*uevent)(struct device___297 *, struct kobj_uevent_env *);
	int (*probe)(struct device___297 *);
	int (*remove)(struct device___297 *);
	void (*shutdown)(struct device___297 *);
	int (*online)(struct device___297 *);
	int (*offline)(struct device___297 *);
	int (*suspend)(struct device___297 *, pm_message_t);
	int (*resume)(struct device___297 *);
	int (*num_vf)(struct device___297 *);
	int (*dma_configure)(struct device___297 *);
	const struct dev_pm_ops___297 *pm;
	const struct iommu_ops___7 *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___297 {
	const char *name;
	struct bus_type___297 *bus;
	struct module___11 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___297 *);
	int (*remove)(struct device___297 *);
	void (*shutdown)(struct device___297 *);
	int (*suspend)(struct device___297 *, pm_message_t);
	int (*resume)(struct device___297 *);
	const struct attribute_group___295 **groups;
	const struct dev_pm_ops___297 *pm;
	void (*coredump)(struct device___297 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct iommu_domain___7;

struct of_phandle_args___13;

struct iommu_ops___7 {
	bool (*capable)(enum iommu_cap);
	struct iommu_domain___7 * (*domain_alloc)(unsigned int);
	void (*domain_free)(struct iommu_domain___7 *);
	int (*attach_dev)(struct iommu_domain___7 *, struct device___297 *);
	void (*detach_dev)(struct iommu_domain___7 *, struct device___297 *);
	int (*map)(struct iommu_domain___7 *, long unsigned int, phys_addr_t, size_t, int);
	size_t (*unmap)(struct iommu_domain___7 *, long unsigned int, size_t);
	void (*flush_iotlb_all)(struct iommu_domain___7 *);
	void (*iotlb_range_add)(struct iommu_domain___7 *, long unsigned int, size_t);
	void (*iotlb_sync)(struct iommu_domain___7 *);
	phys_addr_t (*iova_to_phys)(struct iommu_domain___7 *, dma_addr_t);
	int (*add_device)(struct device___297 *);
	void (*remove_device)(struct device___297 *);
	struct iommu_group * (*device_group)(struct device___297 *);
	int (*domain_get_attr)(struct iommu_domain___7 *, enum iommu_attr, void *);
	int (*domain_set_attr)(struct iommu_domain___7 *, enum iommu_attr, void *);
	void (*get_resv_regions)(struct device___297 *, struct list_head *);
	void (*put_resv_regions)(struct device___297 *, struct list_head *);
	void (*apply_resv_region)(struct device___297 *, struct iommu_domain___7 *, struct iommu_resv_region *);
	int (*domain_window_enable)(struct iommu_domain___7 *, u32, phys_addr_t, u64, int);
	void (*domain_window_disable)(struct iommu_domain___7 *, u32);
	int (*domain_set_windows)(struct iommu_domain___7 *, u32);
	u32 (*domain_get_windows)(struct iommu_domain___7 *);
	int (*of_xlate)(struct device___297 *, struct of_phandle_args___13 *);
	bool (*is_attach_deferred)(struct iommu_domain___7 *, struct device___297 *);
	long unsigned int pgsize_bitmap;
};

struct device_type___297 {
	const char *name;
	const struct attribute_group___295 **groups;
	int (*uevent)(struct device___297 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___297 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___297 *);
	const struct dev_pm_ops___297 *pm;
};

struct class___297 {
	const char *name;
	struct module___11 *owner;
	const struct attribute_group___295 **class_groups;
	const struct attribute_group___295 **dev_groups;
	struct kobject___318 *dev_kobj;
	int (*dev_uevent)(struct device___297 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___297 *, umode_t *);
	void (*class_release)(struct class___297 *);
	void (*dev_release)(struct device___297 *);
	int (*shutdown_pre)(struct device___297 *);
	const struct kobj_ns_type_operations___25 *ns_type;
	const void * (*namespace)(struct device___297 *);
	const struct dev_pm_ops___297 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___96 {
	void * (*alloc)(struct device___297 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___297 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___297 *, struct vm_area_struct___332 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___297 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___297 *, struct page___332 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___297 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___297 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___297 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___297 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___297 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___297 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___297 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___297 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___297 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___297 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___297 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___297 *, u64);
	u64 (*get_required_mask)(struct device___297 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct property___71;

struct device_node___75 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___226 fwnode;
	struct property___71 *properties;
	struct property___71 *deadprops;
	struct device_node___75 *parent;
	struct device_node___75 *child;
	struct device_node___75 *sibling;
	struct kobject___318 kobj;
	long unsigned int _flags;
	void *data;
};

struct iommu_fwspec___7 {
	const struct iommu_ops___7 *ops;
	struct fwnode_handle___226 *iommu_fwnode;
	void *iommu_priv;
	unsigned int num_ids;
	u32 ids[1];
};

struct property___71 {
	char *name;
	int length;
	void *value;
	struct property___71 *next;
	long unsigned int _flags;
	struct bin_attribute___294 attr;
};

struct of_phandle_args___13 {
	struct device_node___75 *np;
	int args_count;
	uint32_t args[16];
};

typedef int (*iommu_fault_handler_t___8)(struct iommu_domain___7 *, struct device___297 *, long unsigned int, int, void *);

struct iommu_domain___7 {
	unsigned int type;
	const struct iommu_ops___7 *ops;
	long unsigned int pgsize_bitmap;
	iommu_fault_handler_t___8 handler;
	void *handler_token;
	struct iommu_domain_geometry geometry;
	void *iova_cookie;
};

struct io_pgtable_cfg___2 {
	long unsigned int quirks;
	long unsigned int pgsize_bitmap;
	unsigned int ias;
	unsigned int oas;
	const struct iommu_gather_ops *tlb;
	struct device___297 *iommu_dev;
	union {
		struct {
			u64 ttbr[2];
			u64 tcr;
			u64 mair[2];
		} arm_lpae_s1_cfg;
		struct {
			u64 vttbr;
			u64 vtcr;
		} arm_lpae_s2_cfg;
		struct {
			u32 ttbr[2];
			u32 tcr;
			u32 nmrr;
			u32 prrr;
		} arm_v7s_cfg;
	};
};

struct io_pgtable___2 {
	enum io_pgtable_fmt fmt;
	void *cookie;
	struct io_pgtable_cfg___2 cfg;
	struct io_pgtable_ops ops;
};

struct io_pgtable_init_fns___2 {
	struct io_pgtable___2 * (*alloc)(struct io_pgtable_cfg___2 *, void *);
	void (*free)(struct io_pgtable___2 *);
};

struct arm_lpae_io_pgtable {
	struct io_pgtable___2 iop;
	int levels;
	size_t pgd_size;
	long unsigned int pg_shift;
	long unsigned int bits_per_level;
	void *pgd;
};

typedef u64 arm_lpae_iopte;

struct iova_magazine {
	long unsigned int size;
	long unsigned int pfns[128];
};

struct iova_cpu_rcache {
	spinlock_t lock;
	struct iova_magazine *loaded;
	struct iova_magazine *prev;
};

struct pci_bus___28;

struct pci_slot___28 {
	struct pci_bus___28 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject___318 kobj;
};

struct pci_dev___28;

struct pci_ops___28;

struct msi_controller___12;

struct pci_bus___28 {
	struct list_head node;
	struct pci_bus___28 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___28 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___28 *ops;
	struct msi_controller___12 *msi;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	int domain_nr;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___297 *bridge;
	struct device___297 dev;
	struct bin_attribute___294 *legacy_io;
	struct bin_attribute___294 *legacy_mem;
	unsigned int is_added: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
};

struct pci_driver___28;

struct pci_dev___28 {
	struct list_head bus_list;
	struct pci_bus___28 *bus;
	struct pci_bus___28 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___28 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u16 aer_cap;
	struct aer_stats *aer_stats;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	long unsigned int *dma_alias_mask;
	struct pci_driver___28 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	unsigned int imm_ready: 1;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int bridge_d3: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int hotplug_user_indicators: 1;
	unsigned int clear_retrain_link: 1;
	unsigned int d3_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	unsigned int ltr_path: 1;
	unsigned int eetlp_prefix_path: 1;
	pci_channel_state_t error_state;
	struct device___297 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int multifunction: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int ats_enabled: 1;
	unsigned int pasid_enabled: 1;
	unsigned int pri_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int reset_fn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int shpc_managed: 1;
	unsigned int is_thunderbolt: 1;
	unsigned int __aer_firmware_first_valid: 1;
	unsigned int __aer_firmware_first: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int irq_managed: 1;
	unsigned int has_secondary_link: 1;
	unsigned int non_compliant_bars: 1;
	unsigned int is_probed: 1;
	unsigned int link_active_reporting: 1;
	unsigned int untrusted: 1;
	unsigned int no_vf_scan: 1;
	unsigned int io_window: 1;
	unsigned int pref_window: 1;
	unsigned int pref_64_window: 1;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	struct bin_attribute___294 *rom_attr;
	int rom_attr_enabled;
	struct bin_attribute___294 *res_attr[17];
	struct bin_attribute___294 *res_attr_wc[17];
	unsigned int broken_cmd_compl: 1;
	const struct attribute_group___295 **msi_irq_groups;
	struct pci_vpd *vpd;
	union {
		struct pci_sriov *sriov;
		struct pci_dev___28 *physfn;
	};
	u16 ats_cap;
	u8 ats_stu;
	atomic_t ats_ref_cnt;
	u32 pri_reqs_alloc;
	u16 pasid_features;
	struct pci_p2pdma *p2pdma;
	phys_addr_t rom;
	size_t romlen;
	char *driver_override;
	long unsigned int priv_flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t pci_dev_extended_size_rh;
	struct pci_dev_extended_rh pci_dev_extended_rh;
};

struct pci_error_handlers___28;

struct pci_driver___28 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___28 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___28 *);
	int (*suspend)(struct pci_dev___28 *, pm_message_t);
	int (*suspend_late)(struct pci_dev___28 *, pm_message_t);
	int (*resume_early)(struct pci_dev___28 *);
	int (*resume)(struct pci_dev___28 *);
	void (*shutdown)(struct pci_dev___28 *);
	int (*sriov_configure)(struct pci_dev___28 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	const struct pci_error_handlers___28 *err_handler;
	const struct attribute_group___295 **groups;
	struct device_driver___297 driver;
	struct pci_dynids dynids;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct pci_ops___28 {
	int (*add_bus)(struct pci_bus___28 *);
	void (*remove_bus)(struct pci_bus___28 *);
	void * (*map_bus)(struct pci_bus___28 *, unsigned int, int);
	int (*read)(struct pci_bus___28 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___28 *, unsigned int, int, int, u32);
};

struct msi_desc___15;

struct msi_controller___12 {
	struct module___11 *owner;
	struct device___297 *dev;
	struct device_node___75 *of_node;
	struct list_head list;
	int (*setup_irq)(struct msi_controller___12 *, struct pci_dev___28 *, struct msi_desc___15 *);
	int (*setup_irqs)(struct msi_controller___12 *, struct pci_dev___28 *, int, int);
	void (*teardown_irq)(struct msi_controller___12 *, unsigned int);
};

struct pci_error_handlers___28 {
	pci_ers_result_t (*error_detected)(struct pci_dev___28 *, enum pci_channel_state);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___28 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___28 *);
	void (*reset_prepare)(struct pci_dev___28 *);
	void (*reset_done)(struct pci_dev___28 *);
	void (*resume)(struct pci_dev___28 *);
};

struct msi_desc___15 {
	struct list_head list;
	unsigned int irq;
	unsigned int nvec_used;
	struct device___297 *dev;
	struct msi_msg msg;
	struct irq_affinity_desc *affinity;
	const void *iommu_cookie;
	union {
		struct {
			u32 masked;
			struct {
				u8 is_msix: 1;
				u8 multiple: 3;
				u8 multi_cap: 3;
				u8 maskbit: 1;
				u8 is_64: 1;
				u16 entry_nr;
				unsigned int default_irq;
			} msi_attrib;
			union {
				u8 mask_pos;
				void *mask_base;
			};
		};
		struct platform_msi_desc platform;
		struct fsl_mc_msi_desc fsl_mc;
	};
};

struct of_pci_iommu_alias_info {
	struct device___297 *dev;
	struct device_node___75 *np;
};

struct of_phandle_iterator {
	const char *cells_name;
	int cell_count;
	const struct device_node___5 *parent;
	const __be32 *list_end;
	const __be32 *phandle_end;
	const __be32 *cur;
	uint32_t cur_count;
	phandle phandle;
	struct device_node___5 *node;
};

typedef void (*of_init_fn_1___3)(struct device_node___5 *);

struct io_pgtable_cfg___3 {
	long unsigned int quirks;
	long unsigned int pgsize_bitmap;
	unsigned int ias;
	unsigned int oas;
	const struct iommu_gather_ops *tlb;
	struct device___272 *iommu_dev;
	union {
		struct {
			u64 ttbr[2];
			u64 tcr;
			u64 mair[2];
		} arm_lpae_s1_cfg;
		struct {
			u64 vttbr;
			u64 vtcr;
		} arm_lpae_s2_cfg;
		struct {
			u32 ttbr[2];
			u32 tcr;
			u32 nmrr;
			u32 prrr;
		} arm_v7s_cfg;
	};
};

struct io_pgtable___3 {
	enum io_pgtable_fmt fmt;
	void *cookie;
	struct io_pgtable_cfg___3 cfg;
	struct io_pgtable_ops ops;
};

struct io_pgtable_init_fns___3 {
	struct io_pgtable___3 * (*alloc)(struct io_pgtable_cfg___3 *, void *);
	void (*free)(struct io_pgtable___3 *);
};

enum arm_smmu_s2cr_type {
	S2CR_TYPE_TRANS = 0,
	S2CR_TYPE_BYPASS = 1,
	S2CR_TYPE_FAULT = 2,
};

enum arm_smmu_s2cr_privcfg {
	S2CR_PRIVCFG_DEFAULT = 0,
	S2CR_PRIVCFG_DIPAN = 1,
	S2CR_PRIVCFG_UNPRIV = 2,
	S2CR_PRIVCFG_PRIV = 3,
};

enum arm_smmu_arch_version {
	ARM_SMMU_V1 = 0,
	ARM_SMMU_V1_64K = 1,
	ARM_SMMU_V2 = 2,
};

enum arm_smmu_implementation {
	GENERIC_SMMU = 0,
	ARM_MMU500 = 1,
	CAVIUM_SMMUV2 = 2,
};

struct arm_smmu_s2cr {
	struct iommu_group *group;
	int count;
	enum arm_smmu_s2cr_type type;
	enum arm_smmu_s2cr_privcfg privcfg;
	u8 cbndx;
};

struct arm_smmu_smr {
	u16 mask;
	u16 id;
	bool valid;
};

struct arm_smmu_cfg;

struct arm_smmu_cb {
	u64 ttbr[2];
	u32 tcr[2];
	u32 mair[2];
	struct arm_smmu_cfg *cfg;
};

enum arm_smmu_context_fmt {
	ARM_SMMU_CTX_FMT_NONE = 0,
	ARM_SMMU_CTX_FMT_AARCH64 = 1,
	ARM_SMMU_CTX_FMT_AARCH32_L = 2,
	ARM_SMMU_CTX_FMT_AARCH32_S = 3,
};

struct arm_smmu_cfg {
	u8 cbndx;
	u8 irptndx;
	union {
		u16 asid;
		u16 vmid;
	};
	u32 cbar;
	enum arm_smmu_context_fmt fmt;
};

struct arm_smmu_device;

struct arm_smmu_master_cfg {
	struct arm_smmu_device *smmu;
	s16 smendx[0];
};

struct arm_smmu_device {
	struct device___272 *dev;
	void *base;
	void *cb_base;
	long unsigned int pgshift;
	u32 features;
	u32 options;
	enum arm_smmu_arch_version version;
	enum arm_smmu_implementation model;
	u32 num_context_banks;
	u32 num_s2_context_banks;
	long unsigned int context_map[2];
	struct arm_smmu_cb *cbs;
	atomic_t irptndx;
	u32 num_mapping_groups;
	u16 streamid_mask;
	u16 smr_mask_mask;
	struct arm_smmu_smr *smrs;
	struct arm_smmu_s2cr *s2crs;
	struct mutex stream_map_mutex;
	long unsigned int va_size;
	long unsigned int ipa_size;
	long unsigned int pa_size;
	long unsigned int pgsize_bitmap;
	u32 num_global_irqs;
	u32 num_context_irqs;
	unsigned int *irqs;
	u32 cavium_id_base;
	spinlock_t global_sync_lock;
	struct iommu_device iommu;
};

enum arm_smmu_domain_stage {
	ARM_SMMU_DOMAIN_S1 = 0,
	ARM_SMMU_DOMAIN_S2 = 1,
	ARM_SMMU_DOMAIN_NESTED = 2,
	ARM_SMMU_DOMAIN_BYPASS = 3,
};

struct arm_smmu_domain {
	struct arm_smmu_device *smmu;
	struct io_pgtable_ops *pgtbl_ops;
	const struct iommu_gather_ops *tlb_ops;
	struct arm_smmu_cfg cfg;
	enum arm_smmu_domain_stage stage;
	bool non_strict;
	struct mutex init_mutex;
	spinlock_t cb_lock;
	struct iommu_domain domain;
};

struct arm_smmu_option_prop {
	u32 opt;
	const char *prop;
};

struct arm_smmu_match_data {
	enum arm_smmu_arch_version version;
	enum arm_smmu_implementation model;
};

enum pri_resp {
	PRI_RESP_DENY = 0,
	PRI_RESP_FAIL = 1,
	PRI_RESP_SUCC = 2,
};

enum arm_smmu_msi_index {
	EVTQ_MSI_INDEX = 0,
	GERROR_MSI_INDEX = 1,
	PRIQ_MSI_INDEX = 2,
	ARM_SMMU_MAX_MSIS = 3,
};

struct arm_smmu_cmdq_ent {
	u8 opcode;
	bool substream_valid;
	union {
		struct {
			u32 sid;
			u8 size;
			u64 addr;
		} prefetch;
		struct {
			u32 sid;
			union {
				bool leaf;
				u8 span;
			};
		} cfgi;
		struct {
			u16 asid;
			u16 vmid;
			bool leaf;
			u64 addr;
		} tlbi;
		struct {
			u32 sid;
			u32 ssid;
			u16 grpid;
			enum pri_resp resp;
		} pri;
		struct {
			u32 msidata;
			u64 msiaddr;
		} sync;
	};
};

struct arm_smmu_queue {
	int irq;
	__le64 *base;
	dma_addr_t base_dma;
	u64 q_base;
	size_t ent_dwords;
	u32 max_n_shift;
	u32 prod;
	u32 cons;
	u32 *prod_reg;
	u32 *cons_reg;
};

struct arm_smmu_cmdq {
	struct arm_smmu_queue q;
	spinlock_t lock;
};

struct arm_smmu_evtq {
	struct arm_smmu_queue q;
	u32 max_stalls;
};

struct arm_smmu_priq {
	struct arm_smmu_queue q;
};

struct arm_smmu_strtab_l1_desc {
	u8 span;
	__le64 *l2ptr;
	dma_addr_t l2ptr_dma;
};

struct arm_smmu_ctx_desc {
	u16 asid;
	u64 ttbr;
	u64 tcr;
	u64 mair;
};

struct arm_smmu_s1_cfg {
	__le64 *cdptr;
	dma_addr_t cdptr_dma;
	struct arm_smmu_ctx_desc cd;
};

struct arm_smmu_s2_cfg {
	u16 vmid;
	u64 vttbr;
	u64 vtcr;
};

struct arm_smmu_strtab_ent {
	bool assigned;
	struct arm_smmu_s1_cfg *s1_cfg;
	struct arm_smmu_s2_cfg *s2_cfg;
};

struct arm_smmu_strtab_cfg {
	__le64 *strtab;
	dma_addr_t strtab_dma;
	struct arm_smmu_strtab_l1_desc *l1_desc;
	unsigned int num_l1_ents;
	u64 strtab_base;
	u32 strtab_base_cfg;
};

struct arm_smmu_device___2 {
	struct device___272 *dev;
	void *base;
	u32 features;
	u32 options;
	struct arm_smmu_cmdq cmdq;
	struct arm_smmu_evtq evtq;
	struct arm_smmu_priq priq;
	int gerr_irq;
	int combined_irq;
	u32 sync_nr;
	u8 prev_cmd_opcode;
	long unsigned int ias;
	long unsigned int oas;
	long unsigned int pgsize_bitmap;
	unsigned int asid_bits;
	long unsigned int asid_map[1024];
	unsigned int vmid_bits;
	long unsigned int vmid_map[1024];
	unsigned int ssid_bits;
	unsigned int sid_bits;
	struct arm_smmu_strtab_cfg strtab_cfg;
	u32 sync_count;
	struct iommu_device iommu;
};

struct arm_smmu_master_data {
	struct arm_smmu_device___2 *smmu;
	struct arm_smmu_strtab_ent ste;
};

struct arm_smmu_domain___2 {
	struct arm_smmu_device___2 *smmu;
	struct mutex init_mutex;
	struct io_pgtable_ops *pgtbl_ops;
	bool non_strict;
	enum arm_smmu_domain_stage stage;
	union {
		struct arm_smmu_s1_cfg s1_cfg;
		struct arm_smmu_s2_cfg s2_cfg;
	};
	struct iommu_domain domain;
};

struct drm_dmi_panel_orientation_data {
	int width;
	int height;
	const char * const *bios_dates;
	int orientation;
};

struct module___270;

struct file___332;

struct kiocb___332;

struct poll_table_struct___201;

struct vm_area_struct___333;

struct inode___332;

struct file_lock___332;

struct page___333;

struct file_operations___332 {
	struct module___270 *owner;
	loff_t (*llseek)(struct file___332 *, loff_t, int);
	ssize_t (*read)(struct file___332 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___332 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___332 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___332 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___332 *, bool);
	int (*iterate)(struct file___332 *, struct dir_context *);
	int (*iterate_shared)(struct file___332 *, struct dir_context *);
	__poll_t (*poll)(struct file___332 *, struct poll_table_struct___201 *);
	long int (*unlocked_ioctl)(struct file___332 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___332 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___332 *, struct vm_area_struct___333 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___332 *, struct file___332 *);
	int (*flush)(struct file___332 *, fl_owner_t);
	int (*release)(struct inode___332 *, struct file___332 *);
	int (*fsync)(struct file___332 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___332 *, int);
	int (*lock)(struct file___332 *, int, struct file_lock___332 *);
	ssize_t (*sendpage)(struct file___332 *, struct page___333 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___332 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___332 *, int, struct file_lock___332 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___332 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___332 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___332 *, long int, struct file_lock___332 **, void **);
	long int (*fallocate)(struct file___332 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___332 *);
	ssize_t (*copy_file_range)(struct file___332 *, loff_t, struct file___332 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___332 *, loff_t, struct file___332 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___332 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___332 {
	u64 seqnum;
	struct vm_area_struct___333 *vmas[4];
};

struct page_frag___332 {
	struct page___333 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___332;

struct cred___307;

struct signal_struct___242;

struct vm_struct___243;

struct task_struct___333 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___333 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___332 *mm;
	struct mm_struct___332 *active_mm;
	struct vmacache___332 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___333 *real_parent;
	struct task_struct___333 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___333 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___209 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___209 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___209 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___307 *ptracer_cred;
	const struct cred___307 *real_cred;
	const struct cred___307 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___242 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___333 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___84 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___332 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___333 *oom_reaper_list;
	struct vm_struct___243 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___134 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___333 *pgtable_t___332;

struct address_space___331;

struct dev_pagemap___320;

struct page___333 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___331 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___333 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___332 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___332 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___320 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___332;

struct lruvec___332 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___332 *pgdat;
};

struct zone___332 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___332 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___332 {
	struct zone___332 *zone;
	int zone_idx;
};

struct zonelist___332 {
	struct zoneref___332 _zonerefs[25];
};

struct pglist_data___332 {
	struct zone___332 node_zones[3];
	struct zonelist___332 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___333 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___333 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___332 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___333 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___333 *owner;
};

struct secondary_data___333 {
	void *stack;
	struct task_struct___333 *task;
	long int status;
};

struct blocking_notifier_head___332 {
	struct rw_semaphore___333 rwsem;
	struct notifier_block *head;
};

struct dentry___331;

struct path___332 {
	struct vfsmount *mnt;
	struct dentry___331 *dentry;
};

struct file___332 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___332 f_path;
	struct inode___332 *f_inode;
	const struct file_operations___332 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___209 f_owner;
	const struct cred___307 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___331 *f_mapping;
	errseq_t f_wb_err;
};

struct key___307;

struct user_struct___307;

struct cred___307 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___307 *session_keyring;
	struct key___307 *process_keyring;
	struct key___307 *thread_keyring;
	struct key___307 *request_key_auth;
	void *security;
	struct user_struct___307 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___325;

struct kernfs_elem_dir___325 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___325 *root;
};

struct kernfs_node___326;

struct kernfs_syscall_ops___325;

struct kernfs_root___325 {
	struct kernfs_node___326 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___325 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___325 {
	struct kernfs_node___326 *target_kn;
};

struct kernfs_ops___325;

struct kernfs_elem_attr___325 {
	const struct kernfs_ops___325 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___326 *notify_next;
};

struct kernfs_node___326 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___326 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___325 dir;
		struct kernfs_elem_symlink___325 symlink;
		struct kernfs_elem_attr___325 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___325;

struct kernfs_ops___325 {
	int (*open)(struct kernfs_open_file___325 *);
	void (*release)(struct kernfs_open_file___325 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___325 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___325 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___325 *, struct vm_area_struct___333 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___325 *, struct poll_table_struct___201 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___325 {
	int (*remount_fs)(struct kernfs_root___325 *, int *, char *);
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___325 *);
	int (*mkdir)(struct kernfs_node___326 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___326 *);
	int (*rename)(struct kernfs_node___326 *, struct kernfs_node___326 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___326 *, struct kernfs_root___325 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_operations_struct___320;

struct kernfs_open_file___325 {
	struct kernfs_node___326 *kn;
	struct file___332 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___320 *vm_ops;
};

struct vm_fault___320;

struct vm_operations_struct___320 {
	void (*open)(struct vm_area_struct___333 *);
	void (*close)(struct vm_area_struct___333 *);
	int (*split)(struct vm_area_struct___333 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___333 *);
	vm_fault_t (*fault)(struct vm_fault___320 *);
	vm_fault_t (*huge_fault)(struct vm_fault___320 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___320 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___333 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___320 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___320 *);
	int (*access)(struct vm_area_struct___333 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___333 *);
	int (*set_policy)(struct vm_area_struct___333 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___333 *, long unsigned int);
	struct page___333 * (*find_special_page)(struct vm_area_struct___333 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___207)(struct file___332 *, wait_queue_head_t *, struct poll_table_struct___201 *);

struct poll_table_struct___201 {
	poll_queue_proc___207 _qproc;
	__poll_t _key;
};

struct vm_area_struct___333 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___333 *vm_next;
	struct vm_area_struct___333 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___332 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___320 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___332 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___319;

struct bin_attribute___295;

struct attribute_group___296 {
	const char *name;
	umode_t (*is_visible)(struct kobject___319 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___319 *, struct bin_attribute___295 *, int);
	struct attribute **attrs;
	struct bin_attribute___295 **bin_attrs;
};

struct kset___318;

struct kobj_type___318;

struct kobject___319 {
	const char *name;
	struct list_head entry;
	struct kobject___319 *parent;
	struct kset___318 *kset;
	struct kobj_type___318 *ktype;
	struct kernfs_node___326 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___295 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___332 *, struct kobject___319 *, struct bin_attribute___295 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___332 *, struct kobject___319 *, struct bin_attribute___295 *, char *, loff_t, size_t);
	int (*mmap)(struct file___332 *, struct kobject___319 *, struct bin_attribute___295 *, struct vm_area_struct___333 *);
};

struct sysfs_ops___318 {
	ssize_t (*show)(struct kobject___319 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___319 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___318;

struct kset___318 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___319 kobj;
	const struct kset_uevent_ops___318 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___318 {
	void (*release)(struct kobject___319 *);
	const struct sysfs_ops___318 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___25 * (*child_ns_type)(struct kobject___319 *);
	const void * (*namespace)(struct kobject___319 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___318 {
	int (* const filter)(struct kset___318 *, struct kobject___319 *);
	const char * (* const name)(struct kset___318 *, struct kobject___319 *);
	int (* const uevent)(struct kset___318 *, struct kobject___319 *, struct kobj_uevent_env *);
};

struct kobj_attribute___310 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___319 *, struct kobj_attribute___310 *, char *);
	ssize_t (*store)(struct kobject___319 *, struct kobj_attribute___310 *, const char *, size_t);
};

struct kernel_param___267;

struct kernel_param_ops___267 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___267 *);
	int (*get)(char *, const struct kernel_param___267 *);
	void (*free)(void *);
};

struct kparam_array___267;

struct kernel_param___267 {
	const char *name;
	struct module___270 *mod;
	const struct kernel_param_ops___267 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___267 *arr;
	};
};

struct kparam_array___267 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___267 *ops;
	void *elem;
};

struct module_kobject___267 {
	struct kobject___319 kobj;
	struct module___270 *mod;
	struct kobject___319 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___267 {
	struct module___270 *mod;
	struct latch_tree_node node;
};

struct module_layout___267 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___267 mtn;
};

struct module_attribute___267;

struct module___270 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___267 mkobj;
	struct module_attribute___267 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___319 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___267 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___267 core_layout;
	struct module_layout___267 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___267 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___267 *, struct module_kobject___267 *, char *);
	ssize_t (*store)(struct module_attribute___267 *, struct module_kobject___267 *, const char *, size_t);
	void (*setup)(struct module___270 *, const char *);
	int (*test)(struct module___270 *);
	void (*free)(struct module___270 *);
};

struct device___298;

struct dev_pm_ops___298 {
	int (*prepare)(struct device___298 *);
	void (*complete)(struct device___298 *);
	int (*suspend)(struct device___298 *);
	int (*resume)(struct device___298 *);
	int (*freeze)(struct device___298 *);
	int (*thaw)(struct device___298 *);
	int (*poweroff)(struct device___298 *);
	int (*restore)(struct device___298 *);
	int (*suspend_late)(struct device___298 *);
	int (*resume_early)(struct device___298 *);
	int (*freeze_late)(struct device___298 *);
	int (*thaw_early)(struct device___298 *);
	int (*poweroff_late)(struct device___298 *);
	int (*restore_early)(struct device___298 *);
	int (*suspend_noirq)(struct device___298 *);
	int (*resume_noirq)(struct device___298 *);
	int (*freeze_noirq)(struct device___298 *);
	int (*thaw_noirq)(struct device___298 *);
	int (*poweroff_noirq)(struct device___298 *);
	int (*restore_noirq)(struct device___298 *);
	int (*runtime_suspend)(struct device___298 *);
	int (*runtime_resume)(struct device___298 *);
	int (*runtime_idle)(struct device___298 *);
};

struct dev_pm_info___298 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___3 *subsys_data;
	void (*set_latency_tolerance)(struct device___298 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___298;

struct bus_type___298;

struct device_driver___298;

struct dev_pm_domain___298;

struct dma_map_ops___97;

struct fwnode_handle___227;

struct class___298;

struct device___298 {
	struct device___298 *parent;
	struct device_private *p;
	struct kobject___319 kobj;
	const char *init_name;
	const struct device_type___298 *type;
	struct mutex mutex;
	struct bus_type___298 *bus;
	struct device_driver___298 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___298 power;
	struct dev_pm_domain___298 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___97 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___227 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___298 *class;
	const struct attribute_group___296 **groups;
	void (*release)(struct device___298 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___298 {
	struct dev_pm_ops___298 ops;
	void (*detach)(struct device___298 *, bool);
	int (*activate)(struct device___298 *);
	void (*sync)(struct device___298 *);
	void (*dismiss)(struct device___298 *);
};

struct user_struct___307 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___307 *uid_keyring;
	struct key___307 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___332;

struct mm_struct___332 {
	struct {
		struct vm_area_struct___333 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___332 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___333 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___332 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___333 *owner;
		struct user_namespace___3 *user_ns;
		struct file___332 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___332 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct signal_struct___242 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___333 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___333 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___209 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___209 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___332 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___209 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_struct___243 {
	struct vm_struct___243 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___333 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___254 {
	struct task_struct___333 task;
	long unsigned int stack[8192];
};

struct bus_type___298 {
	const char *name;
	const char *dev_name;
	struct device___298 *dev_root;
	const struct attribute_group___296 **bus_groups;
	const struct attribute_group___296 **dev_groups;
	const struct attribute_group___296 **drv_groups;
	int (*match)(struct device___298 *, struct device_driver___298 *);
	int (*uevent)(struct device___298 *, struct kobj_uevent_env *);
	int (*probe)(struct device___298 *);
	int (*remove)(struct device___298 *);
	void (*shutdown)(struct device___298 *);
	int (*online)(struct device___298 *);
	int (*offline)(struct device___298 *);
	int (*suspend)(struct device___298 *, pm_message_t);
	int (*resume)(struct device___298 *);
	int (*num_vf)(struct device___298 *);
	int (*dma_configure)(struct device___298 *);
	const struct dev_pm_ops___298 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___298 {
	const char *name;
	struct bus_type___298 *bus;
	struct module___270 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___298 *);
	int (*remove)(struct device___298 *);
	void (*shutdown)(struct device___298 *);
	int (*suspend)(struct device___298 *, pm_message_t);
	int (*resume)(struct device___298 *);
	const struct attribute_group___296 **groups;
	const struct dev_pm_ops___298 *pm;
	void (*coredump)(struct device___298 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___298 {
	const char *name;
	const struct attribute_group___296 **groups;
	int (*uevent)(struct device___298 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___298 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___298 *);
	const struct dev_pm_ops___298 *pm;
};

struct class___298 {
	const char *name;
	struct module___270 *owner;
	const struct attribute_group___296 **class_groups;
	const struct attribute_group___296 **dev_groups;
	struct kobject___319 *dev_kobj;
	int (*dev_uevent)(struct device___298 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___298 *, umode_t *);
	void (*class_release)(struct class___298 *);
	void (*dev_release)(struct device___298 *);
	int (*shutdown_pre)(struct device___298 *);
	const struct kobj_ns_type_operations___25 *ns_type;
	const void * (*namespace)(struct device___298 *);
	const struct dev_pm_ops___298 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___97 {
	void * (*alloc)(struct device___298 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___298 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___298 *, struct vm_area_struct___333 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___298 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___298 *, struct page___333 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___298 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___298 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___298 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___298 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___298 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___298 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___298 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___298 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___298 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___298 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___298 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___298 *, u64);
	u64 (*get_required_mask)(struct device___298 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___227;

struct fwnode_handle___227 {
	struct fwnode_handle___227 *secondary;
	const struct fwnode_operations___227 *ops;
};

struct address_space_operations___331;

struct address_space___331 {
	struct inode___332 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___333 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___331 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___320)(struct vm_area_struct___333 *, long unsigned int, const struct page___333 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___320)(struct page___333 *, void *);

struct dev_pagemap___320 {
	dev_page_fault_t___320 page_fault;
	dev_page_free_t___320 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___298 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___332 {
	struct task_struct___333 *task;
	struct core_thread___332 *next;
};

struct core_state___332 {
	atomic_t nr_threads;
	struct core_thread___332 dumper;
	struct completion startup;
};

struct vm_fault___320 {
	struct vm_area_struct___333 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___333 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___333 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___332 prealloc_pte;
};

struct fwnode_reference_args___227;

struct fwnode_endpoint___227;

struct fwnode_operations___227 {
	struct fwnode_handle___227 * (*get)(struct fwnode_handle___227 *);
	void (*put)(struct fwnode_handle___227 *);
	bool (*device_is_available)(const struct fwnode_handle___227 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___227 *, const struct device___298 *);
	bool (*property_present)(const struct fwnode_handle___227 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___227 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___227 *, const char *, const char **, size_t);
	struct fwnode_handle___227 * (*get_parent)(const struct fwnode_handle___227 *);
	struct fwnode_handle___227 * (*get_next_child_node)(const struct fwnode_handle___227 *, struct fwnode_handle___227 *);
	struct fwnode_handle___227 * (*get_named_child_node)(const struct fwnode_handle___227 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___227 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___227 *);
	struct fwnode_handle___227 * (*graph_get_next_endpoint)(const struct fwnode_handle___227 *, struct fwnode_handle___227 *);
	struct fwnode_handle___227 * (*graph_get_remote_endpoint)(const struct fwnode_handle___227 *);
	struct fwnode_handle___227 * (*graph_get_port_parent)(struct fwnode_handle___227 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___227 *, struct fwnode_endpoint___227 *);
};

struct fwnode_endpoint___227 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___227 *local_fwnode;
};

struct fwnode_reference_args___227 {
	struct fwnode_handle___227 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pci_bus___29;

struct pci_slot___29 {
	struct pci_bus___29 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject___319 kobj;
};

struct pci_dev___29;

struct pci_ops___29;

struct pci_bus___29 {
	struct list_head node;
	struct pci_bus___29 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___29 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___29 *ops;
	struct msi_controller___2 *msi;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	int domain_nr;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___298 *bridge;
	struct device___298 dev;
	struct bin_attribute___295 *legacy_io;
	struct bin_attribute___295 *legacy_mem;
	unsigned int is_added: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
};

struct pci_driver___29;

struct pci_dev___29 {
	struct list_head bus_list;
	struct pci_bus___29 *bus;
	struct pci_bus___29 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___29 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u16 aer_cap;
	struct aer_stats *aer_stats;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	long unsigned int *dma_alias_mask;
	struct pci_driver___29 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	unsigned int imm_ready: 1;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int bridge_d3: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int hotplug_user_indicators: 1;
	unsigned int clear_retrain_link: 1;
	unsigned int d3_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	unsigned int ltr_path: 1;
	unsigned int eetlp_prefix_path: 1;
	pci_channel_state_t error_state;
	struct device___298 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int multifunction: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int ats_enabled: 1;
	unsigned int pasid_enabled: 1;
	unsigned int pri_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int reset_fn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int shpc_managed: 1;
	unsigned int is_thunderbolt: 1;
	unsigned int __aer_firmware_first_valid: 1;
	unsigned int __aer_firmware_first: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int irq_managed: 1;
	unsigned int has_secondary_link: 1;
	unsigned int non_compliant_bars: 1;
	unsigned int is_probed: 1;
	unsigned int link_active_reporting: 1;
	unsigned int untrusted: 1;
	unsigned int no_vf_scan: 1;
	unsigned int io_window: 1;
	unsigned int pref_window: 1;
	unsigned int pref_64_window: 1;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	struct bin_attribute___295 *rom_attr;
	int rom_attr_enabled;
	struct bin_attribute___295 *res_attr[17];
	struct bin_attribute___295 *res_attr_wc[17];
	unsigned int broken_cmd_compl: 1;
	const struct attribute_group___296 **msi_irq_groups;
	struct pci_vpd *vpd;
	union {
		struct pci_sriov *sriov;
		struct pci_dev___29 *physfn;
	};
	u16 ats_cap;
	u8 ats_stu;
	atomic_t ats_ref_cnt;
	u32 pri_reqs_alloc;
	u16 pasid_features;
	struct pci_p2pdma *p2pdma;
	phys_addr_t rom;
	size_t romlen;
	char *driver_override;
	long unsigned int priv_flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t pci_dev_extended_size_rh;
	struct pci_dev_extended_rh pci_dev_extended_rh;
};

struct pci_error_handlers___29;

struct pci_driver___29 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___29 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___29 *);
	int (*suspend)(struct pci_dev___29 *, pm_message_t);
	int (*suspend_late)(struct pci_dev___29 *, pm_message_t);
	int (*resume_early)(struct pci_dev___29 *);
	int (*resume)(struct pci_dev___29 *);
	void (*shutdown)(struct pci_dev___29 *);
	int (*sriov_configure)(struct pci_dev___29 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	const struct pci_error_handlers___29 *err_handler;
	const struct attribute_group___296 **groups;
	struct device_driver___298 driver;
	struct pci_dynids dynids;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct pci_ops___29 {
	int (*add_bus)(struct pci_bus___29 *);
	void (*remove_bus)(struct pci_bus___29 *);
	void * (*map_bus)(struct pci_bus___29 *, unsigned int, int);
	int (*read)(struct pci_bus___29 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___29 *, unsigned int, int, int, u32);
};

struct pci_error_handlers___29 {
	pci_ers_result_t (*error_detected)(struct pci_dev___29 *, enum pci_channel_state);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___29 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___29 *);
	void (*reset_prepare)(struct pci_dev___29 *);
	void (*reset_done)(struct pci_dev___29 *);
	void (*resume)(struct pci_dev___29 *);
};

struct dentry_operations___331;

struct super_block___331;

struct dentry___331 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___331 *d_parent;
	struct qstr d_name;
	struct inode___332 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___331 *d_op;
	struct super_block___331 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___331;

struct block_device___331;

struct inode___332 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___331 *i_op;
	struct super_block___331 *i_sb;
	struct address_space___331 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___333 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___332 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___331 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___331 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___331 {
	int (*d_revalidate)(struct dentry___331 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___331 *, unsigned int);
	int (*d_hash)(const struct dentry___331 *, struct qstr *);
	int (*d_compare)(const struct dentry___331 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___331 *);
	int (*d_init)(struct dentry___331 *);
	void (*d_release)(struct dentry___331 *);
	void (*d_prune)(struct dentry___331 *);
	void (*d_iput)(struct dentry___331 *, struct inode___332 *);
	char * (*d_dname)(struct dentry___331 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___332 *);
	int (*d_manage)(const struct path___332 *, bool);
	struct dentry___331 * (*d_real)(struct dentry___331 *, const struct inode___332 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___331;

struct mem_dqinfo___331 {
	struct quota_format_type___331 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___331;

struct quota_info___331 {
	unsigned int flags;
	struct rw_semaphore___333 dqio_sem;
	struct inode___332 *files[3];
	struct mem_dqinfo___331 info[3];
	const struct quota_format_ops___331 *ops[3];
};

struct rcuwait___331 {
	struct task_struct___333 *task;
};

struct percpu_rw_semaphore___331 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___333 rw_sem;
	struct rcuwait___331 writer;
	int readers_block;
};

struct sb_writers___331 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___331 rw_sem[3];
};

struct file_system_type___331;

struct super_operations___331;

struct dquot_operations___331;

struct quotactl_ops___331;

struct super_block___331 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___331 *s_type;
	const struct super_operations___331 *s_op;
	const struct dquot_operations___331 *dq_op;
	const struct quotactl_ops___331 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___331 *s_root;
	struct rw_semaphore___333 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___331 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___331 s_dquot;
	struct sb_writers___331 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___331 *s_d_op;
	int cleancache_poolid;
	struct shrinker___122 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___332 {
	struct file___332 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___332 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___331 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___332 *ia_file;
};

struct dquot___331 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___331 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___331 {
	int qf_fmt_id;
	const struct quota_format_ops___331 *qf_ops;
	struct module___270 *qf_owner;
	struct quota_format_type___331 *qf_next;
};

struct quota_format_ops___331 {
	int (*check_quota_file)(struct super_block___331 *, int);
	int (*read_file_info)(struct super_block___331 *, int);
	int (*write_file_info)(struct super_block___331 *, int);
	int (*free_file_info)(struct super_block___331 *, int);
	int (*read_dqblk)(struct dquot___331 *);
	int (*commit_dqblk)(struct dquot___331 *);
	int (*release_dqblk)(struct dquot___331 *);
	int (*get_next_id)(struct super_block___331 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___331 {
	int (*write_dquot)(struct dquot___331 *);
	struct dquot___331 * (*alloc_dquot)(struct super_block___331 *, int);
	void (*destroy_dquot)(struct dquot___331 *);
	int (*acquire_dquot)(struct dquot___331 *);
	int (*release_dquot)(struct dquot___331 *);
	int (*mark_dirty)(struct dquot___331 *);
	int (*write_info)(struct super_block___331 *, int);
	qsize_t * (*get_reserved_space)(struct inode___332 *);
	int (*get_projid)(struct inode___332 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___332 *, qsize_t *);
	int (*get_next_id)(struct super_block___331 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___331 {
	int (*quota_on)(struct super_block___331 *, int, int, const struct path___332 *);
	int (*quota_off)(struct super_block___331 *, int);
	int (*quota_enable)(struct super_block___331 *, unsigned int);
	int (*quota_disable)(struct super_block___331 *, unsigned int);
	int (*quota_sync)(struct super_block___331 *, int);
	int (*set_info)(struct super_block___331 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___331 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___331 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___331 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___331 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___331 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___331 {
	int (*writepage)(struct page___333 *, struct writeback_control___3 *);
	int (*readpage)(struct file___332 *, struct page___333 *);
	int (*writepages)(struct address_space___331 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___333 *);
	int (*readpages)(struct file___332 *, struct address_space___331 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___332 *, struct address_space___331 *, loff_t, unsigned int, unsigned int, struct page___333 **, void **);
	int (*write_end)(struct file___332 *, struct address_space___331 *, loff_t, unsigned int, unsigned int, struct page___333 *, void *);
	sector_t (*bmap)(struct address_space___331 *, sector_t);
	void (*invalidatepage)(struct page___333 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___333 *, gfp_t);
	void (*freepage)(struct page___333 *);
	ssize_t (*direct_IO)(struct kiocb___332 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___331 *, struct page___333 *, struct page___333 *, enum migrate_mode);
	bool (*isolate_page)(struct page___333 *, isolate_mode_t);
	void (*putback_page)(struct page___333 *);
	int (*launder_page)(struct page___333 *);
	int (*is_partially_uptodate)(struct page___333 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___333 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___331 *, struct page___333 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___332 *, sector_t *);
	void (*swap_deactivate)(struct file___332 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___331 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___332 *bd_inode;
	struct super_block___331 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___331 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___331 {
	struct dentry___331 * (*lookup)(struct inode___332 *, struct dentry___331 *, unsigned int);
	const char * (*get_link)(struct dentry___331 *, struct inode___332 *, struct delayed_call *);
	int (*permission)(struct inode___332 *, int);
	struct posix_acl * (*get_acl)(struct inode___332 *, int);
	int (*readlink)(struct dentry___331 *, char *, int);
	int (*create)(struct inode___332 *, struct dentry___331 *, umode_t, bool);
	int (*link)(struct dentry___331 *, struct inode___332 *, struct dentry___331 *);
	int (*unlink)(struct inode___332 *, struct dentry___331 *);
	int (*symlink)(struct inode___332 *, struct dentry___331 *, const char *);
	int (*mkdir)(struct inode___332 *, struct dentry___331 *, umode_t);
	int (*rmdir)(struct inode___332 *, struct dentry___331 *);
	int (*mknod)(struct inode___332 *, struct dentry___331 *, umode_t, dev_t);
	int (*rename)(struct inode___332 *, struct dentry___331 *, struct inode___332 *, struct dentry___331 *, unsigned int);
	int (*setattr)(struct dentry___331 *, struct iattr___331 *);
	int (*getattr)(const struct path___332 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___331 *, char *, size_t);
	int (*fiemap)(struct inode___332 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___332 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___332 *, struct dentry___331 *, struct file___332 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___332 *, struct dentry___331 *, umode_t);
	int (*set_acl)(struct inode___332 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___331 {
	void (*fl_copy_lock)(struct file_lock___332 *, struct file_lock___332 *);
	void (*fl_release_private)(struct file_lock___332 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___331;

struct lock_manager_operations___331;

struct file_lock___332 {
	struct file_lock___332 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___332 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___331 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___331 *fl_ops;
	const struct lock_manager_operations___331 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___331 {
	int (*lm_compare_owner)(struct file_lock___332 *, struct file_lock___332 *);
	long unsigned int (*lm_owner_key)(struct file_lock___332 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___332 *);
	int (*lm_grant)(struct file_lock___332 *, int);
	bool (*lm_break)(struct file_lock___332 *);
	int (*lm_change)(struct file_lock___332 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___332 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___331 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___331 *fa_next;
	struct file___332 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___331 {
	const char *name;
	int fs_flags;
	struct dentry___331 * (*mount)(struct file_system_type___331 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___331 *);
	struct module___270 *owner;
	struct file_system_type___331 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___331 {
	struct inode___332 * (*alloc_inode)(struct super_block___331 *);
	void (*destroy_inode)(struct inode___332 *);
	void (*dirty_inode)(struct inode___332 *, int);
	int (*write_inode)(struct inode___332 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___332 *);
	void (*evict_inode)(struct inode___332 *);
	void (*put_super)(struct super_block___331 *);
	int (*sync_fs)(struct super_block___331 *, int);
	int (*freeze_super)(struct super_block___331 *);
	int (*freeze_fs)(struct super_block___331 *);
	int (*thaw_super)(struct super_block___331 *);
	int (*unfreeze_fs)(struct super_block___331 *);
	int (*statfs)(struct dentry___331 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___331 *, int *, char *);
	void (*umount_begin)(struct super_block___331 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___331 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___331 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___331 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___331 *);
	ssize_t (*quota_read)(struct super_block___331 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___331 *, int, const char *, size_t, loff_t);
	struct dquot___331 ** (*get_dquots)(struct inode___332 *);
	int (*bdev_try_to_free_page)(struct super_block___331 *, struct page___333 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___331 *, struct shrink_control___122 *);
	long int (*free_cached_objects)(struct super_block___331 *, struct shrink_control___122 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___320(struct page___333 *);

typedef int (*key_restrict_link_func_t___308)(struct key___307 *, const struct key_type *, const union key_payload *, struct key___307 *);

struct key_restriction___307;

struct key___307 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___333 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___307 *restrict_link;
};

struct key_restriction___307 {
	key_restrict_link_func_t___308 check;
	struct key___307 *key;
	struct key_type *keytype;
};

typedef struct poll_table_struct___201 poll_table___29;

struct miscdevice___7 {
	int minor;
	const char *name;
	const struct file_operations___332 *fops;
	struct list_head list;
	struct device___298 *parent;
	struct device___298 *this_device;
	const struct attribute_group___296 **groups;
	const char *nodename;
	umode_t mode;
};

struct consw___22 {
	struct module___270 *owner;
	const char * (*con_startup)();
	void (*con_init)(struct vc_data *, int);
	void (*con_deinit)(struct vc_data *);
	void (*con_clear)(struct vc_data *, int, int, int, int);
	void (*con_putc)(struct vc_data *, int, int, int);
	void (*con_putcs)(struct vc_data *, const short unsigned int *, int, int, int);
	void (*con_cursor)(struct vc_data *, int);
	bool (*con_scroll)(struct vc_data *, unsigned int, unsigned int, enum con_scroll, unsigned int);
	int (*con_switch)(struct vc_data *);
	int (*con_blank)(struct vc_data *, int, int);
	int (*con_font_set)(struct vc_data *, struct console_font *, unsigned int);
	int (*con_font_get)(struct vc_data *, struct console_font *);
	int (*con_font_default)(struct vc_data *, struct console_font *, char *);
	int (*con_font_copy)(struct vc_data *, int);
	int (*con_resize)(struct vc_data *, unsigned int, unsigned int, unsigned int);
	void (*con_set_palette)(struct vc_data *, const unsigned char *);
	void (*con_scrolldelta)(struct vc_data *, int);
	int (*con_set_origin)(struct vc_data *);
	void (*con_save_screen)(struct vc_data *);
	u8 (*con_build_attr)(struct vc_data *, u8, u8, u8, u8, u8, u8);
	void (*con_invert_region)(struct vc_data *, u16 *, int);
	u16 * (*con_screen_pos)(struct vc_data *, int);
	long unsigned int (*con_getxy)(struct vc_data *, long unsigned int, int *, int *);
	void (*con_flush_scrollback)(struct vc_data *);
	int (*con_debug_enter)(struct vc_data *);
	int (*con_debug_leave)(struct vc_data *);
};

struct vga_device {
	struct list_head list;
	struct pci_dev___29 *pdev;
	unsigned int decodes;
	unsigned int owns;
	unsigned int locks;
	unsigned int io_lock_cnt;
	unsigned int mem_lock_cnt;
	unsigned int io_norm_cnt;
	unsigned int mem_norm_cnt;
	bool bridge_has_one_vga;
	void *cookie;
	void (*irq_set_state)(void *, bool);
	unsigned int (*set_vga_decode)(void *, bool);
};

struct vga_arb_user_card {
	struct pci_dev___29 *pdev;
	unsigned int mem_cnt;
	unsigned int io_cnt;
};

struct vga_arb_private {
	struct list_head list;
	struct pci_dev___29 *target;
	struct vga_arb_user_card cards[64];
	spinlock_t lock;
};

struct module___271;

struct file___333;

struct kiocb___333;

struct iov_iter___144;

struct poll_table_struct___202;

struct vm_area_struct___334;

struct inode___333;

struct file_lock___333;

struct page___334;

struct pipe_inode_info___70;

struct seq_file___281;

struct file_operations___333 {
	struct module___271 *owner;
	loff_t (*llseek)(struct file___333 *, loff_t, int);
	ssize_t (*read)(struct file___333 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___333 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___333 *, struct iov_iter___144 *);
	ssize_t (*write_iter)(struct kiocb___333 *, struct iov_iter___144 *);
	int (*iopoll)(struct kiocb___333 *, bool);
	int (*iterate)(struct file___333 *, struct dir_context *);
	int (*iterate_shared)(struct file___333 *, struct dir_context *);
	__poll_t (*poll)(struct file___333 *, struct poll_table_struct___202 *);
	long int (*unlocked_ioctl)(struct file___333 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___333 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___333 *, struct vm_area_struct___334 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___333 *, struct file___333 *);
	int (*flush)(struct file___333 *, fl_owner_t);
	int (*release)(struct inode___333 *, struct file___333 *);
	int (*fsync)(struct file___333 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___333 *, int);
	int (*lock)(struct file___333 *, int, struct file_lock___333 *);
	ssize_t (*sendpage)(struct file___333 *, struct page___334 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___333 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___333 *, int, struct file_lock___333 *);
	ssize_t (*splice_write)(struct pipe_inode_info___70 *, struct file___333 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___333 *, loff_t *, struct pipe_inode_info___70 *, size_t, unsigned int);
	int (*setlease)(struct file___333 *, long int, struct file_lock___333 **, void **);
	long int (*fallocate)(struct file___333 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___281 *, struct file___333 *);
	ssize_t (*copy_file_range)(struct file___333 *, loff_t, struct file___333 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___333 *, loff_t, struct file___333 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___333 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___333 {
	u64 seqnum;
	struct vm_area_struct___334 *vmas[4];
};

struct page_frag___333 {
	struct page___334 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___333;

struct mem_cgroup___123;

struct cred___308;

struct nsproxy___261;

struct signal_struct___243;

struct bio_list___157;

struct backing_dev_info___157;

struct css_set___217;

struct vm_struct___244;

struct task_struct___334 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___334 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___333 *mm;
	struct mm_struct___333 *active_mm;
	struct vmacache___333 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___334 *real_parent;
	struct task_struct___334 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___334 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___123 *active_memcg;
	long int rh_reserved2;
	struct pid___209 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___209 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___209 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___308 *ptracer_cred;
	const struct cred___308 *real_cred;
	const struct cred___308 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___261 *nsproxy;
	struct signal_struct___243 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___334 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___157 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___157 *backing_dev_info;
	struct io_context___84 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___217 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___70 *splice_pipe;
	struct page_frag___333 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___123 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___334 *oom_reaper_list;
	struct vm_struct___244 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___134 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rw_semaphore___334 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___334 *owner;
};

struct key___308;

struct ucounts___232;

struct user_namespace___232 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___232 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___9 ns;
	long unsigned int flags;
	struct key___308 *persistent_keyring_register;
	struct rw_semaphore___334 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___232 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___334 *pgtable_t___333;

struct address_space___332;

struct dev_pagemap___321;

struct page___334 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___332 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___334 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___333 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___333 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___321 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___123 *mem_cgroup;
};

struct pglist_data___333;

struct lruvec___333 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___333 *pgdat;
};

struct zone___333 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___333 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___333 {
	struct zone___333 *zone;
	int zone_idx;
};

struct zonelist___333 {
	struct zoneref___333 _zonerefs[25];
};

struct pglist_data___333 {
	struct zone___333 node_zones[3];
	struct zonelist___333 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___334 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___334 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___333 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___334 {
	void *stack;
	struct task_struct___334 *task;
	long int status;
};

struct blocking_notifier_head___333 {
	struct rw_semaphore___334 rwsem;
	struct notifier_block *head;
};

struct dentry___332;

struct path___333 {
	struct vfsmount *mnt;
	struct dentry___332 *dentry;
};

struct file___333 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___333 f_path;
	struct inode___333 *f_inode;
	const struct file_operations___333 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___209 f_owner;
	const struct cred___308 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___332 *f_mapping;
	errseq_t f_wb_err;
};

struct user_struct___308;

struct cred___308 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___308 *session_keyring;
	struct key___308 *process_keyring;
	struct key___308 *thread_keyring;
	struct key___308 *request_key_auth;
	void *security;
	struct user_struct___308 *user;
	struct user_namespace___232 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___326;

struct kernfs_elem_dir___326 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___326 *root;
};

struct kernfs_node___327;

struct kernfs_syscall_ops___326;

struct kernfs_root___326 {
	struct kernfs_node___327 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___326 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___326 {
	struct kernfs_node___327 *target_kn;
};

struct kernfs_ops___326;

struct kernfs_elem_attr___326 {
	const struct kernfs_ops___326 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___327 *notify_next;
};

struct kernfs_node___327 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___327 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___326 dir;
		struct kernfs_elem_symlink___326 symlink;
		struct kernfs_elem_attr___326 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___326;

struct kernfs_ops___326 {
	int (*open)(struct kernfs_open_file___326 *);
	void (*release)(struct kernfs_open_file___326 *);
	int (*seq_show)(struct seq_file___281 *, void *);
	void * (*seq_start)(struct seq_file___281 *, loff_t *);
	void * (*seq_next)(struct seq_file___281 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___281 *, void *);
	ssize_t (*read)(struct kernfs_open_file___326 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___326 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___326 *, struct vm_area_struct___334 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___326 *, struct poll_table_struct___202 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___326 {
	int (*remount_fs)(struct kernfs_root___326 *, int *, char *);
	int (*show_options)(struct seq_file___281 *, struct kernfs_root___326 *);
	int (*mkdir)(struct kernfs_node___327 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___327 *);
	int (*rename)(struct kernfs_node___327 *, struct kernfs_node___327 *, const char *);
	int (*show_path)(struct seq_file___281 *, struct kernfs_node___327 *, struct kernfs_root___326 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___280;

struct seq_file___281 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___280 *op;
	int poll_event;
	const struct file___333 *file;
	void *private;
};

struct vm_operations_struct___321;

struct kernfs_open_file___326 {
	struct kernfs_node___327 *kn;
	struct file___333 *file;
	struct seq_file___281 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___321 *vm_ops;
};

struct vm_fault___321;

struct vm_operations_struct___321 {
	void (*open)(struct vm_area_struct___334 *);
	void (*close)(struct vm_area_struct___334 *);
	int (*split)(struct vm_area_struct___334 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___334 *);
	vm_fault_t (*fault)(struct vm_fault___321 *);
	vm_fault_t (*huge_fault)(struct vm_fault___321 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___321 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___334 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___321 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___321 *);
	int (*access)(struct vm_area_struct___334 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___334 *);
	int (*set_policy)(struct vm_area_struct___334 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___334 *, long unsigned int);
	struct page___334 * (*find_special_page)(struct vm_area_struct___334 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___208)(struct file___333 *, wait_queue_head_t *, struct poll_table_struct___202 *);

struct poll_table_struct___202 {
	poll_queue_proc___208 _qproc;
	__poll_t _key;
};

struct vm_area_struct___334 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___334 *vm_next;
	struct vm_area_struct___334 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___333 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___321 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___333 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sock___27;

struct kobj_ns_type_operations___26 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___27 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct net___48;

typedef struct {
	struct net___48 *net;
} possible_net_t___38;

struct proto___26;

struct sock_common___26 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___26 *skc_prot;
	possible_net_t___38 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___27 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___39;

struct sk_buff_head___37 {
	struct sk_buff___39 *next;
	struct sk_buff___39 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___26;

struct socket_wq___27;

struct dst_entry___26;

struct socket___28;

struct net_device___39;

struct sock___27 {
	struct sock_common___26 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___37 sk_error_queue;
	struct sk_buff_head___37 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___39 *head;
		struct sk_buff___39 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___26 *sk_filter;
	union {
		struct socket_wq___27 *sk_wq;
		struct socket_wq___27 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___26 *sk_rx_dst;
	struct dst_entry___26 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___39 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___37 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___333 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___26 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___209 *sk_peer_pid;
	const struct cred___308 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___28 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___123 *sk_memcg;
	void (*sk_state_change)(struct sock___27 *);
	void (*sk_data_ready)(struct sock___27 *);
	void (*sk_write_space)(struct sock___27 *);
	void (*sk_error_report)(struct sock___27 *);
	int (*sk_backlog_rcv)(struct sock___27 *, struct sk_buff___39 *);
	struct sk_buff___39 * (*sk_validate_xmit_skb)(struct sock___27 *, struct net_device___39 *, struct sk_buff___39 *);
	void (*sk_destruct)(struct sock___27 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kobject___320;

struct bin_attribute___296;

struct attribute_group___297 {
	const char *name;
	umode_t (*is_visible)(struct kobject___320 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___320 *, struct bin_attribute___296 *, int);
	struct attribute **attrs;
	struct bin_attribute___296 **bin_attrs;
};

struct kset___319;

struct kobj_type___319;

struct kobject___320 {
	const char *name;
	struct list_head entry;
	struct kobject___320 *parent;
	struct kset___319 *kset;
	struct kobj_type___319 *ktype;
	struct kernfs_node___327 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___296 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___333 *, struct kobject___320 *, struct bin_attribute___296 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___333 *, struct kobject___320 *, struct bin_attribute___296 *, char *, loff_t, size_t);
	int (*mmap)(struct file___333 *, struct kobject___320 *, struct bin_attribute___296 *, struct vm_area_struct___334 *);
};

struct sysfs_ops___319 {
	ssize_t (*show)(struct kobject___320 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___320 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___319;

struct kset___319 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___320 kobj;
	const struct kset_uevent_ops___319 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___319 {
	void (*release)(struct kobject___320 *);
	const struct sysfs_ops___319 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___26 * (*child_ns_type)(struct kobject___320 *);
	const void * (*namespace)(struct kobject___320 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___319 {
	int (* const filter)(struct kset___319 *, struct kobject___320 *);
	const char * (* const name)(struct kset___319 *, struct kobject___320 *);
	int (* const uevent)(struct kset___319 *, struct kobject___320 *, struct kobj_uevent_env *);
};

struct kobj_attribute___311 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___320 *, struct kobj_attribute___311 *, char *);
	ssize_t (*store)(struct kobject___320 *, struct kobj_attribute___311 *, const char *, size_t);
};

struct kernel_param___268;

struct kernel_param_ops___268 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___268 *);
	int (*get)(char *, const struct kernel_param___268 *);
	void (*free)(void *);
};

struct kparam_array___268;

struct kernel_param___268 {
	const char *name;
	struct module___271 *mod;
	const struct kernel_param_ops___268 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___268 *arr;
	};
};

struct kparam_array___268 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___268 *ops;
	void *elem;
};

struct module_kobject___268 {
	struct kobject___320 kobj;
	struct module___271 *mod;
	struct kobject___320 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___268 {
	struct module___271 *mod;
	struct latch_tree_node node;
};

struct module_layout___268 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___268 mtn;
};

struct module_attribute___268;

struct module___271 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___268 mkobj;
	struct module_attribute___268 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___320 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___268 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___268 core_layout;
	struct module_layout___268 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___268 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___268 *, struct module_kobject___268 *, char *);
	ssize_t (*store)(struct module_attribute___268 *, struct module_kobject___268 *, const char *, size_t);
	void (*setup)(struct module___271 *, const char *);
	int (*test)(struct module___271 *);
	void (*free)(struct module___271 *);
};

struct cgroup___217;

struct cgroup_subsys___217;

struct cgroup_subsys_state___217 {
	struct cgroup___217 *cgroup;
	struct cgroup_subsys___217 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___217 *parent;
};

struct mem_cgroup_id___26 {
	int id;
	union {
		refcount_t ref;
		struct {
			atomic_t ref;
		} __UNIQUE_ID_rh_kabi_hide38;
		union {		};
	};
};

struct cgroup_file___217 {
	struct kernfs_node___327 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___123;

struct mem_cgroup___123 {
	struct cgroup_subsys_state___217 css;
	struct mem_cgroup_id___26 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___217 events_file;
	struct cgroup_file___217 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___334 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___123 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct user_struct___308 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___308 *uid_keyring;
	struct key___308 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___333;

struct mm_struct___333 {
	struct {
		struct vm_area_struct___334 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___333 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___334 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___333 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___334 *owner;
		struct user_namespace___232 *user_ns;
		struct file___333 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___333 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___217;

struct nsproxy___261 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net___48 *net_ns;
	struct cgroup_namespace___217 *cgroup_ns;
};

struct signal_struct___243 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___334 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___334 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___209 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___209 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___333 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___209 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide43;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___157;

struct bio_list___157 {
	struct bio___157 *head;
	struct bio___157 *tail;
};

struct bdi_writeback_congested___157;

struct bdi_writeback___157 {
	struct backing_dev_info___157 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___157 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___217 *memcg_css;
	struct cgroup_subsys_state___217 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___299;

struct backing_dev_info___157 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___157 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___299 *dev;
	struct device___299 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___332 *debug_dir;
	struct dentry___332 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___217 {
	struct cgroup_subsys_state___217 *subsys[13];
	refcount_t refcount;
	struct css_set___217 *dom_cset;
	struct cgroup___217 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___217 *mg_src_cgrp;
	struct cgroup___217 *mg_dst_cgrp;
	struct css_set___217 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___332;

struct pipe_buffer___70;

struct pipe_inode_info___70 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___334 *tmp_page;
	struct fasync_struct___332 *fasync_readers;
	struct fasync_struct___332 *fasync_writers;
	struct pipe_buffer___70 *bufs;
	struct user_struct___308 *user;
};

struct vm_struct___244 {
	struct vm_struct___244 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___334 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___255 {
	struct task_struct___334 task;
	long unsigned int stack[8192];
};

struct address_space_operations___332;

struct address_space___332 {
	struct inode___333 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___334 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___332 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___321)(struct vm_area_struct___334 *, long unsigned int, const struct page___334 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___321)(struct page___334 *, void *);

struct dev_pagemap___321 {
	dev_page_fault_t___321 page_fault;
	dev_page_free_t___321 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___299 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___333 {
	struct task_struct___334 *task;
	struct core_thread___333 *next;
};

struct core_state___333 {
	atomic_t nr_threads;
	struct core_thread___333 dumper;
	struct completion startup;
};

struct vm_fault___321 {
	struct vm_area_struct___334 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___334 *cow_page;
	struct mem_cgroup___123 *memcg;
	struct page___334 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___333 prealloc_pte;
};

struct bio_vec___158 {
	struct page___334 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___144 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___158 *bvec;
		struct pipe_inode_info___70 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct msghdr___29 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___144 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___333 *msg_iocb;
};

struct kiocb___333 {
	struct file___333 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___333 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dentry_operations___332;

struct super_block___332;

struct dentry___332 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___332 *d_parent;
	struct qstr d_name;
	struct inode___333 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___332 *d_op;
	struct super_block___332 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___332;

struct block_device___332;

struct inode___333 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___332 *i_op;
	struct super_block___332 *i_sb;
	struct address_space___332 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___334 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___157 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___333 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___332 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___70 *i_pipe;
		struct block_device___332 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___332 {
	int (*d_revalidate)(struct dentry___332 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___332 *, unsigned int);
	int (*d_hash)(const struct dentry___332 *, struct qstr *);
	int (*d_compare)(const struct dentry___332 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___332 *);
	int (*d_init)(struct dentry___332 *);
	void (*d_release)(struct dentry___332 *);
	void (*d_prune)(struct dentry___332 *);
	void (*d_iput)(struct dentry___332 *, struct inode___333 *);
	char * (*d_dname)(struct dentry___332 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___333 *);
	int (*d_manage)(const struct path___333 *, bool);
	struct dentry___332 * (*d_real)(struct dentry___332 *, const struct inode___333 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___332;

struct mem_dqinfo___332 {
	struct quota_format_type___332 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___332;

struct quota_info___332 {
	unsigned int flags;
	struct rw_semaphore___334 dqio_sem;
	struct inode___333 *files[3];
	struct mem_dqinfo___332 info[3];
	const struct quota_format_ops___332 *ops[3];
};

struct rcuwait___332 {
	struct task_struct___334 *task;
};

struct percpu_rw_semaphore___332 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___334 rw_sem;
	struct rcuwait___332 writer;
	int readers_block;
};

struct sb_writers___332 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___332 rw_sem[3];
};

struct shrink_control___123;

struct shrinker___123 {
	long unsigned int (*count_objects)(struct shrinker___123 *, struct shrink_control___123 *);
	long unsigned int (*scan_objects)(struct shrinker___123 *, struct shrink_control___123 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___332;

struct super_operations___332;

struct dquot_operations___332;

struct quotactl_ops___332;

struct super_block___332 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___332 *s_type;
	const struct super_operations___332 *s_op;
	const struct dquot_operations___332 *dq_op;
	const struct quotactl_ops___332 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___332 *s_root;
	struct rw_semaphore___334 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___332 *s_bdev;
	struct backing_dev_info___157 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___332 s_dquot;
	struct sb_writers___332 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___332 *s_d_op;
	int cleancache_poolid;
	struct shrinker___123 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___232 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___123 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___123 *memcg;
};

struct iattr___332 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___333 *ia_file;
};

struct dquot___332 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___332 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___332 {
	int qf_fmt_id;
	const struct quota_format_ops___332 *qf_ops;
	struct module___271 *qf_owner;
	struct quota_format_type___332 *qf_next;
};

struct quota_format_ops___332 {
	int (*check_quota_file)(struct super_block___332 *, int);
	int (*read_file_info)(struct super_block___332 *, int);
	int (*write_file_info)(struct super_block___332 *, int);
	int (*free_file_info)(struct super_block___332 *, int);
	int (*read_dqblk)(struct dquot___332 *);
	int (*commit_dqblk)(struct dquot___332 *);
	int (*release_dqblk)(struct dquot___332 *);
	int (*get_next_id)(struct super_block___332 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___332 {
	int (*write_dquot)(struct dquot___332 *);
	struct dquot___332 * (*alloc_dquot)(struct super_block___332 *, int);
	void (*destroy_dquot)(struct dquot___332 *);
	int (*acquire_dquot)(struct dquot___332 *);
	int (*release_dquot)(struct dquot___332 *);
	int (*mark_dirty)(struct dquot___332 *);
	int (*write_info)(struct super_block___332 *, int);
	qsize_t * (*get_reserved_space)(struct inode___333 *);
	int (*get_projid)(struct inode___333 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___333 *, qsize_t *);
	int (*get_next_id)(struct super_block___332 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___332 {
	int (*quota_on)(struct super_block___332 *, int, int, const struct path___333 *);
	int (*quota_off)(struct super_block___332 *, int);
	int (*quota_enable)(struct super_block___332 *, unsigned int);
	int (*quota_disable)(struct super_block___332 *, unsigned int);
	int (*quota_sync)(struct super_block___332 *, int);
	int (*set_info)(struct super_block___332 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___332 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___332 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___332 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___332 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___332 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___140;

struct swap_info_struct___81;

struct address_space_operations___332 {
	int (*writepage)(struct page___334 *, struct writeback_control___140 *);
	int (*readpage)(struct file___333 *, struct page___334 *);
	int (*writepages)(struct address_space___332 *, struct writeback_control___140 *);
	int (*set_page_dirty)(struct page___334 *);
	int (*readpages)(struct file___333 *, struct address_space___332 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___333 *, struct address_space___332 *, loff_t, unsigned int, unsigned int, struct page___334 **, void **);
	int (*write_end)(struct file___333 *, struct address_space___332 *, loff_t, unsigned int, unsigned int, struct page___334 *, void *);
	sector_t (*bmap)(struct address_space___332 *, sector_t);
	void (*invalidatepage)(struct page___334 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___334 *, gfp_t);
	void (*freepage)(struct page___334 *);
	ssize_t (*direct_IO)(struct kiocb___333 *, struct iov_iter___144 *);
	int (*migratepage)(struct address_space___332 *, struct page___334 *, struct page___334 *, enum migrate_mode);
	bool (*isolate_page)(struct page___334 *, isolate_mode_t);
	void (*putback_page)(struct page___334 *);
	int (*launder_page)(struct page___334 *);
	int (*is_partially_uptodate)(struct page___334 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___334 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___332 *, struct page___334 *);
	int (*swap_activate)(struct swap_info_struct___81 *, struct file___333 *, sector_t *);
	void (*swap_deactivate)(struct file___333 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___140 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___157 *wb;
	struct inode___333 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct swap_info_struct___81 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___332 *bdev;
	struct file___333 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___332 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___333 *bd_inode;
	struct super_block___332 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___332 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___157 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___332 {
	struct dentry___332 * (*lookup)(struct inode___333 *, struct dentry___332 *, unsigned int);
	const char * (*get_link)(struct dentry___332 *, struct inode___333 *, struct delayed_call *);
	int (*permission)(struct inode___333 *, int);
	struct posix_acl * (*get_acl)(struct inode___333 *, int);
	int (*readlink)(struct dentry___332 *, char *, int);
	int (*create)(struct inode___333 *, struct dentry___332 *, umode_t, bool);
	int (*link)(struct dentry___332 *, struct inode___333 *, struct dentry___332 *);
	int (*unlink)(struct inode___333 *, struct dentry___332 *);
	int (*symlink)(struct inode___333 *, struct dentry___332 *, const char *);
	int (*mkdir)(struct inode___333 *, struct dentry___332 *, umode_t);
	int (*rmdir)(struct inode___333 *, struct dentry___332 *);
	int (*mknod)(struct inode___333 *, struct dentry___332 *, umode_t, dev_t);
	int (*rename)(struct inode___333 *, struct dentry___332 *, struct inode___333 *, struct dentry___332 *, unsigned int);
	int (*setattr)(struct dentry___332 *, struct iattr___332 *);
	int (*getattr)(const struct path___333 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___332 *, char *, size_t);
	int (*fiemap)(struct inode___333 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___333 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___333 *, struct dentry___332 *, struct file___333 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___333 *, struct dentry___332 *, umode_t);
	int (*set_acl)(struct inode___333 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___332 {
	void (*fl_copy_lock)(struct file_lock___333 *, struct file_lock___333 *);
	void (*fl_release_private)(struct file_lock___333 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___332;

struct file_lock___333 {
	struct file_lock___333 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___333 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___332 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___332 *fl_ops;
	const struct lock_manager_operations___332 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___332 {
	int (*lm_compare_owner)(struct file_lock___333 *, struct file_lock___333 *);
	long unsigned int (*lm_owner_key)(struct file_lock___333 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___333 *);
	int (*lm_grant)(struct file_lock___333 *, int);
	bool (*lm_break)(struct file_lock___333 *);
	int (*lm_change)(struct file_lock___333 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___333 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___332 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___332 *fa_next;
	struct file___333 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___332 {
	const char *name;
	int fs_flags;
	struct dentry___332 * (*mount)(struct file_system_type___332 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___332 *);
	struct module___271 *owner;
	struct file_system_type___332 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___332 {
	struct inode___333 * (*alloc_inode)(struct super_block___332 *);
	void (*destroy_inode)(struct inode___333 *);
	void (*dirty_inode)(struct inode___333 *, int);
	int (*write_inode)(struct inode___333 *, struct writeback_control___140 *);
	int (*drop_inode)(struct inode___333 *);
	void (*evict_inode)(struct inode___333 *);
	void (*put_super)(struct super_block___332 *);
	int (*sync_fs)(struct super_block___332 *, int);
	int (*freeze_super)(struct super_block___332 *);
	int (*freeze_fs)(struct super_block___332 *);
	int (*thaw_super)(struct super_block___332 *);
	int (*unfreeze_fs)(struct super_block___332 *);
	int (*statfs)(struct dentry___332 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___332 *, int *, char *);
	void (*umount_begin)(struct super_block___332 *);
	int (*show_options)(struct seq_file___281 *, struct dentry___332 *);
	int (*show_devname)(struct seq_file___281 *, struct dentry___332 *);
	int (*show_path)(struct seq_file___281 *, struct dentry___332 *);
	int (*show_stats)(struct seq_file___281 *, struct dentry___332 *);
	ssize_t (*quota_read)(struct super_block___332 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___332 *, int, const char *, size_t, loff_t);
	struct dquot___332 ** (*get_dquots)(struct inode___333 *);
	int (*bdev_try_to_free_page)(struct super_block___332 *, struct page___334 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___332 *, struct shrink_control___123 *);
	long int (*free_cached_objects)(struct super_block___332 *, struct shrink_control___123 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___157(struct bio___157 *);

struct bio_integrity_payload___157;

struct bio_set___157;

struct bio___157 {
	struct bio___157 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___157 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___157 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___158 *bi_io_vec;
	struct bio_set___157 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___158 bi_inline_vecs[0];
};

struct socket_wq___27 {
	wait_queue_head_t wait;
	struct fasync_struct___332 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___27;

struct socket___28 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___27 *wq;
	struct file___333 *file;
	struct sock___27 *sk;
	const struct proto_ops___27 *ops;
};

typedef int (*sk_read_actor_t___26)(read_descriptor_t *, struct sk_buff___39 *, unsigned int, size_t);

struct proto_ops___27 {
	int family;
	struct module___271 *owner;
	int (*release)(struct socket___28 *);
	int (*bind)(struct socket___28 *, struct sockaddr *, int);
	int (*connect)(struct socket___28 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___28 *, struct socket___28 *);
	int (*accept)(struct socket___28 *, struct socket___28 *, int, bool);
	int (*getname)(struct socket___28 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___333 *, struct socket___28 *, struct poll_table_struct___202 *);
	int (*ioctl)(struct socket___28 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___28 *, int);
	int (*shutdown)(struct socket___28 *, int);
	int (*setsockopt)(struct socket___28 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___28 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___28 *, struct msghdr___29 *, size_t);
	int (*recvmsg)(struct socket___28 *, struct msghdr___29 *, size_t, int);
	int (*mmap)(struct file___333 *, struct socket___28 *, struct vm_area_struct___334 *);
	ssize_t (*sendpage)(struct socket___28 *, struct page___334 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___28 *, loff_t *, struct pipe_inode_info___70 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___27 *, int);
	int (*peek_len)(struct socket___28 *);
	int (*read_sock)(struct sock___27 *, read_descriptor_t *, sk_read_actor_t___26);
	int (*sendpage_locked)(struct sock___27 *, struct page___334 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___27 *, struct msghdr___29 *, size_t);
	int (*set_rcvlowat)(struct sock___27 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct nf_bridge_info___37;

struct sk_buff___39 {
	union {
		struct {
			struct sk_buff___39 *next;
			struct sk_buff___39 *prev;
			union {
				struct net_device___39 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___27 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___39 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___37 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___37;

struct netns_frags___37 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___37 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_rules_ops___26;

struct fib_notifier_ops___26;

struct netns_ipv4___37 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___26 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___27 *fibnl;
	struct sock___27 **icmp_sk;
	struct sock___27 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___27 **tcp_sk;
	struct netns_frags___37 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___26 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___26 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___26 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___26;

struct dst_ops___47 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___47 *);
	struct dst_entry___26 * (*check)(struct dst_entry___26 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___26 *);
	unsigned int (*mtu)(const struct dst_entry___26 *);
	u32 * (*cow_metrics)(struct dst_entry___26 *, long unsigned int);
	void (*destroy)(struct dst_entry___26 *);
	void (*ifdown)(struct dst_entry___26 *, struct net_device___39 *, int);
	struct dst_entry___26 * (*negative_advice)(struct dst_entry___26 *);
	void (*link_failure)(struct sk_buff___39 *);
	void (*update_pmtu)(struct dst_entry___26 *, struct sock___27 *, struct sk_buff___39 *, u32);
	void (*redirect)(struct dst_entry___26 *, struct sock___27 *, struct sk_buff___39 *);
	int (*local_out)(struct net___48 *, struct sock___27 *, struct sk_buff___39 *);
	struct neighbour___26 * (*neigh_lookup)(const struct dst_entry___26 *, struct sk_buff___39 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___26 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___47 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___37 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___47 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___26 *fib6_rules_ops;
	struct sock___27 **icmp_sk;
	struct sock___27 *ndisc_sk;
	struct sock___27 *tcp_sk;
	struct sock___27 *igmp_sk;
	struct sock___27 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___26 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___26 *notifier_ops;
	struct fib_notifier_ops___26 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___27 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___27 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___37 {
	struct netns_frags___37 frags;
};

struct netns_xfrm___47 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___27 *nlsk;
	struct sock___27 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___47 xfrm4_dst_ops;
	struct dst_ops___47 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___36;

struct net___48 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___232 *user_ns;
	struct ucounts___232 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___9 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___27 *rtnl;
	struct sock___27 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___39 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___37 ipv4;
	struct netns_ipv6___47 ipv6;
	struct netns_sctp___27 sctp;
	struct netns_nf nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___37 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___27 *nfnl;
	struct sock___27 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___47 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___27 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___36 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___299 {
	int (*prepare)(struct device___299 *);
	void (*complete)(struct device___299 *);
	int (*suspend)(struct device___299 *);
	int (*resume)(struct device___299 *);
	int (*freeze)(struct device___299 *);
	int (*thaw)(struct device___299 *);
	int (*poweroff)(struct device___299 *);
	int (*restore)(struct device___299 *);
	int (*suspend_late)(struct device___299 *);
	int (*resume_early)(struct device___299 *);
	int (*freeze_late)(struct device___299 *);
	int (*thaw_early)(struct device___299 *);
	int (*poweroff_late)(struct device___299 *);
	int (*restore_early)(struct device___299 *);
	int (*suspend_noirq)(struct device___299 *);
	int (*resume_noirq)(struct device___299 *);
	int (*freeze_noirq)(struct device___299 *);
	int (*thaw_noirq)(struct device___299 *);
	int (*poweroff_noirq)(struct device___299 *);
	int (*restore_noirq)(struct device___299 *);
	int (*runtime_suspend)(struct device___299 *);
	int (*runtime_resume)(struct device___299 *);
	int (*runtime_idle)(struct device___299 *);
};

struct dev_pm_info___299 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___3 *subsys_data;
	void (*set_latency_tolerance)(struct device___299 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___299;

struct bus_type___299;

struct device_driver___299;

struct dev_pm_domain___299;

struct dma_map_ops___98;

struct fwnode_handle___228;

struct class___299;

struct device___299 {
	struct device___299 *parent;
	struct device_private *p;
	struct kobject___320 kobj;
	const char *init_name;
	const struct device_type___299 *type;
	struct mutex mutex;
	struct bus_type___299 *bus;
	struct device_driver___299 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___299 power;
	struct dev_pm_domain___299 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___98 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___228 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___299 *class;
	const struct attribute_group___297 **groups;
	void (*release)(struct device___299 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___299 {
	struct dev_pm_ops___299 ops;
	void (*detach)(struct device___299 *, bool);
	int (*activate)(struct device___299 *);
	void (*sync)(struct device___299 *);
	void (*dismiss)(struct device___299 *);
};

struct bus_type___299 {
	const char *name;
	const char *dev_name;
	struct device___299 *dev_root;
	const struct attribute_group___297 **bus_groups;
	const struct attribute_group___297 **dev_groups;
	const struct attribute_group___297 **drv_groups;
	int (*match)(struct device___299 *, struct device_driver___299 *);
	int (*uevent)(struct device___299 *, struct kobj_uevent_env *);
	int (*probe)(struct device___299 *);
	int (*remove)(struct device___299 *);
	void (*shutdown)(struct device___299 *);
	int (*online)(struct device___299 *);
	int (*offline)(struct device___299 *);
	int (*suspend)(struct device___299 *, pm_message_t);
	int (*resume)(struct device___299 *);
	int (*num_vf)(struct device___299 *);
	int (*dma_configure)(struct device___299 *);
	const struct dev_pm_ops___299 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___299 {
	const char *name;
	struct bus_type___299 *bus;
	struct module___271 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___299 *);
	int (*remove)(struct device___299 *);
	void (*shutdown)(struct device___299 *);
	int (*suspend)(struct device___299 *, pm_message_t);
	int (*resume)(struct device___299 *);
	const struct attribute_group___297 **groups;
	const struct dev_pm_ops___299 *pm;
	void (*coredump)(struct device___299 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___299 {
	const char *name;
	const struct attribute_group___297 **groups;
	int (*uevent)(struct device___299 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___299 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___299 *);
	const struct dev_pm_ops___299 *pm;
};

struct class___299 {
	const char *name;
	struct module___271 *owner;
	const struct attribute_group___297 **class_groups;
	const struct attribute_group___297 **dev_groups;
	struct kobject___320 *dev_kobj;
	int (*dev_uevent)(struct device___299 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___299 *, umode_t *);
	void (*class_release)(struct class___299 *);
	void (*dev_release)(struct device___299 *);
	int (*shutdown_pre)(struct device___299 *);
	const struct kobj_ns_type_operations___26 *ns_type;
	const void * (*namespace)(struct device___299 *);
	const struct dev_pm_ops___299 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___98 {
	void * (*alloc)(struct device___299 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___299 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___299 *, struct vm_area_struct___334 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___299 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___299 *, struct page___334 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___299 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___299 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___299 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___299 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___299 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___299 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___299 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___299 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___299 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___299 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___299 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___299 *, u64);
	u64 (*get_required_mask)(struct device___299 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___228;

struct fwnode_handle___228 {
	struct fwnode_handle___228 *secondary;
	const struct fwnode_operations___228 *ops;
};

typedef void compound_page_dtor___321(struct page___334 *);

struct fwnode_reference_args___228;

struct fwnode_endpoint___228;

struct fwnode_operations___228 {
	struct fwnode_handle___228 * (*get)(struct fwnode_handle___228 *);
	void (*put)(struct fwnode_handle___228 *);
	bool (*device_is_available)(const struct fwnode_handle___228 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___228 *, const struct device___299 *);
	bool (*property_present)(const struct fwnode_handle___228 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___228 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___228 *, const char *, const char **, size_t);
	struct fwnode_handle___228 * (*get_parent)(const struct fwnode_handle___228 *);
	struct fwnode_handle___228 * (*get_next_child_node)(const struct fwnode_handle___228 *, struct fwnode_handle___228 *);
	struct fwnode_handle___228 * (*get_named_child_node)(const struct fwnode_handle___228 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___228 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___228 *);
	struct fwnode_handle___228 * (*graph_get_next_endpoint)(const struct fwnode_handle___228 *, struct fwnode_handle___228 *);
	struct fwnode_handle___228 * (*graph_get_remote_endpoint)(const struct fwnode_handle___228 *);
	struct fwnode_handle___228 * (*graph_get_port_parent)(struct fwnode_handle___228 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___228 *, struct fwnode_endpoint___228 *);
};

struct fwnode_endpoint___228 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___228 *local_fwnode;
};

struct fwnode_reference_args___228 {
	struct fwnode_handle___228 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___70;

struct pipe_buffer___70 {
	struct page___334 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___70 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___70 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___70 *, struct pipe_buffer___70 *);
	void (*release)(struct pipe_inode_info___70 *, struct pipe_buffer___70 *);
	int (*steal)(struct pipe_inode_info___70 *, struct pipe_buffer___70 *);
	union {
		bool (*get)(struct pipe_inode_info___70 *, struct pipe_buffer___70 *);
		struct {
			void (*get)(struct pipe_inode_info___70 *, struct pipe_buffer___70 *);
		} __UNIQUE_ID_rh_kabi_hide21;
		union {		};
	};
};

struct nf_bridge_info___37 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___37 = 0,
		BRNF_PROTO_8021Q___37 = 1,
		BRNF_PROTO_PPPOE___37 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___39 *physindev;
	struct net_device___39 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___37(struct sk_buff___39 **);

struct net_device_ops___37;

struct ethtool_ops___37;

struct l3mdev_ops___26;

struct xfrmdev_ops___37;

struct tlsdev_ops___37;

struct header_ops___37;

struct netdev_rx_queue___37;

struct mini_Qdisc___36;

struct netdev_queue___37;

struct Qdisc___36;

struct rtnl_link_ops___36;

struct dcbnl_rtnl_ops___37;

struct net_device___39 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___37 *netdev_ops;
	const struct ethtool_ops___37 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___26 *l3mdev_ops;
	const struct ndisc_ops___2 *ndisc_ops;
	const struct xfrmdev_ops___37 *xfrmdev_ops;
	const struct tlsdev_ops___37 *tlsdev_ops;
	const struct header_ops___37 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___319 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___2 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___37 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___36 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___37 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___36 *miniq_ingress;
	struct netdev_queue___37 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___37 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___36 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___36 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___37 = 0,
		NETREG_REGISTERED___37 = 1,
		NETREG_UNREGISTERING___37 = 2,
		NETREG_UNREGISTERED___37 = 3,
		NETREG_RELEASED___37 = 4,
		NETREG_DUMMY___37 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___37 = 0,
		RTNL_LINK_INITIALIZING___37 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___39 *);
	struct netpoll_info *npinfo;
	possible_net_t___38 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___299 dev;
	const struct attribute_group___297 *sysfs_groups[4];
	const struct attribute_group___297 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___36 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___37 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide50;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

typedef int (*key_restrict_link_func_t___309)(struct key___308 *, const struct key_type *, const union key_payload *, struct key___308 *);

struct key_restriction___308;

struct key___308 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___334 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___308 *restrict_link;
};

struct key_restriction___308 {
	key_restrict_link_func_t___309 check;
	struct key___308 *key;
	struct key_type *keytype;
};

struct seq_operations___280 {
	void * (*start)(struct seq_file___281 *, loff_t *);
	void (*stop)(struct seq_file___281 *, void *);
	void * (*next)(struct seq_file___281 *, void *, loff_t *);
	int (*show)(struct seq_file___281 *, void *);
};

struct cgroup_namespace___217 {
	refcount_t count;
	struct ns_common___9 ns;
	struct user_namespace___232 *user_ns;
	struct ucounts___232 *ucounts;
	struct css_set___217 *root_cset;
};

struct ucounts___232 {
	struct hlist_node node;
	struct user_namespace___232 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___218;

struct bpf_map_ops___217 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___218 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___218 *, struct file___333 *);
	void (*map_free)(struct bpf_map___218 *);
	int (*map_get_next_key)(struct bpf_map___218 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___218 *);
	void * (*map_lookup_elem)(struct bpf_map___218 *, void *);
	int (*map_update_elem)(struct bpf_map___218 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___218 *, void *);
	int (*map_push_elem)(struct bpf_map___218 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___218 *, void *);
	int (*map_peek_elem)(struct bpf_map___218 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___218 *, struct file___333 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___218 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___218 *, void *, struct seq_file___281 *);
	int (*map_check_btf)(const struct bpf_map___218 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___218 {
	const struct bpf_map_ops___217 *ops;
	struct bpf_map___218 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___308 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___37;

struct bpf_map_dev_ops___37 {
	int (*map_get_next_key)(struct bpf_offloaded_map___37 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___37 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___37 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___37 *, void *);
};

struct bpf_offloaded_map___37 {
	struct bpf_map___218 map;
	struct net_device___39 *netdev;
	const struct bpf_map_dev_ops___37 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___36 {
	int (*test_run)(struct bpf_prog___36 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_aux___39;

struct bpf_prog___36 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___39 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

struct bpf_verifier_ops___36 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___36 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___36 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___36 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___36 *, u32 *);
};

struct bpf_prog_offload_ops___36 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___36 *);
	int (*translate)(struct bpf_prog___36 *);
	void (*destroy)(struct bpf_prog___36 *);
};

struct bpf_prog_offload___36 {
	struct bpf_prog___36 *prog;
	struct net_device___39 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___36 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___39 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___36 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___36 *ops;
	struct bpf_map___218 **used_maps;
	struct bpf_prog___36 *prog;
	struct user_struct___308 *user;
	u64 load_time;
	struct bpf_map___218 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___36 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___36 {
	struct bpf_prog___36 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___36 {
	struct callback_head rcu;
	struct bpf_prog_array_item___36 items[0];
};

struct cgroup_bpf___36 {
	struct bpf_prog_array___36 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___36 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___217;

typedef void (*kthread_work_func_t___217)(struct kthread_work___217 *);

struct kthread_worker___217;

struct kthread_work___217 {
	struct list_head node;
	kthread_work_func_t___217 func;
	struct kthread_worker___217 *worker;
	int canceling;
};

struct kthread_worker___217 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___334 *task;
	struct kthread_work___217 *current_work;
};

struct kthread_delayed_work___217 {
	struct kthread_work___217 work;
	struct timer_list timer;
};

struct psi_group___217 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___217 *poll_kworker;
	struct kthread_delayed_work___217 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___217;

struct cgroup_rstat_cpu___217;

struct cgroup___217 {
	struct cgroup_subsys_state___217 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___327 *kn;
	struct cgroup_file___217 procs_file;
	struct cgroup_file___217 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___217 *subsys[13];
	struct cgroup_root___217 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___217 *dom_cgrp;
	struct cgroup_rstat_cpu___217 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___36 bpf;
	atomic_t congestion_count;
	struct cgroup___217 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___217 psi;
	int ancestor_ids[0];
};

struct cftype___217;

struct cgroup_subsys___217 {
	struct cgroup_subsys_state___217 * (*css_alloc)(struct cgroup_subsys_state___217 *);
	int (*css_online)(struct cgroup_subsys_state___217 *);
	void (*css_offline)(struct cgroup_subsys_state___217 *);
	void (*css_released)(struct cgroup_subsys_state___217 *);
	void (*css_free)(struct cgroup_subsys_state___217 *);
	void (*css_reset)(struct cgroup_subsys_state___217 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___217 *, int);
	int (*css_extra_stat_show)(struct seq_file___281 *, struct cgroup_subsys_state___217 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___334 *);
	void (*cancel_fork)(struct task_struct___334 *);
	void (*fork)(struct task_struct___334 *);
	void (*exit)(struct task_struct___334 *);
	void (*free)(struct task_struct___334 *);
	void (*bind)(struct cgroup_subsys_state___217 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___217 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___217 *dfl_cftypes;
	struct cftype___217 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___217 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___217 *updated_children;
	struct cgroup___217 *updated_next;
};

struct cgroup_root___217 {
	struct kernfs_root___326 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___217 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___217 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___217 *ss;
	struct list_head node;
	struct kernfs_ops___326 *kf_ops;
	int (*open)(struct kernfs_open_file___326 *);
	void (*release)(struct kernfs_open_file___326 *);
	u64 (*read_u64)(struct cgroup_subsys_state___217 *, struct cftype___217 *);
	s64 (*read_s64)(struct cgroup_subsys_state___217 *, struct cftype___217 *);
	int (*seq_show)(struct seq_file___281 *, void *);
	void * (*seq_start)(struct seq_file___281 *, loff_t *);
	void * (*seq_next)(struct seq_file___281 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___281 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___217 *, struct cftype___217 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___217 *, struct cftype___217 *, s64);
	ssize_t (*write)(struct kernfs_open_file___326 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___326 *, struct poll_table_struct___202 *);
};

struct bdi_writeback_congested___157 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___157 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___157 {
	struct bio___157 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___158 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___158 bip_inline_vecs[0];
};

struct bio_set___157 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___157 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___123 {
	struct mem_cgroup___123 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___123 {
	struct lruvec___333 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___123 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___123 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct node___193 {
	struct device___299 dev;
};

struct ethtool_ops___37 {
	int (*get_settings)(struct net_device___39 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___39 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___39 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___39 *);
	void (*get_regs)(struct net_device___39 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___39 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___39 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___39 *);
	void (*set_msglevel)(struct net_device___39 *, u32);
	int (*nway_reset)(struct net_device___39 *);
	u32 (*get_link)(struct net_device___39 *);
	int (*get_eeprom_len)(struct net_device___39 *);
	int (*get_eeprom)(struct net_device___39 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___39 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___39 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___39 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___39 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___39 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___39 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___39 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___39 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___39 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___39 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___39 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___39 *);
	void (*complete)(struct net_device___39 *);
	u32 (*get_priv_flags)(struct net_device___39 *);
	int (*set_priv_flags)(struct net_device___39 *, u32);
	int (*get_sset_count)(struct net_device___39 *, int);
	int (*get_rxnfc)(struct net_device___39 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___39 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___39 *, struct ethtool_flash *);
	int (*reset)(struct net_device___39 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___39 *);
	u32 (*get_rxfh_indir_size)(struct net_device___39 *);
	int (*get_rxfh)(struct net_device___39 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___39 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___39 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___39 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___39 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___39 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___39 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___39 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___39 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___39 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___39 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___39 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___39 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___39 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___39 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___39 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___39 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___39 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___39 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___39 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide39;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___39 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___39 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide40;
		union {		};
	};
	int (*get_fecparam)(struct net_device___39 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___39 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___39 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___39 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide41;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___39 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide42;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___37;

struct inet_frags___37 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___37 *, const void *);
	void (*destructor)(struct inet_frag_queue___37 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___37 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___39 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___39 *fragments_tail;
	struct sk_buff___39 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___37 *net;
	struct callback_head rcu;
};

struct fib_rule___26;

struct fib_lookup_arg___26;

struct fib_rules_ops___26 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___26 *, struct flowi *, int, struct fib_lookup_arg___26 *);
	bool (*suppress)(struct fib_rule___26 *, struct fib_lookup_arg___26 *);
	int (*match)(struct fib_rule___26 *, struct flowi *, int);
	int (*configure)(struct fib_rule___26 *, struct sk_buff___39 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___26 *);
	int (*compare)(struct fib_rule___26 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___26 *, struct sk_buff___39 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___26 *);
	void (*flush_cache)(struct fib_rules_ops___26 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___271 *owner;
	struct net___48 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___26 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___48 *);
	int (*fib_dump)(struct net___48 *, struct notifier_block *);
	struct module___271 *owner;
	struct callback_head rcu;
};

struct dst_entry___26 {
	struct net_device___39 *dev;
	struct dst_ops___47 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___39 *);
	int (*output)(struct net___48 *, struct sock___27 *, struct sk_buff___39 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___26;

struct neigh_parms___26;

struct neigh_ops___26;

struct neighbour___26 {
	struct neighbour___26 *next;
	struct neigh_table___26 *tbl;
	struct neigh_parms___26 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___37 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___26 *, struct sk_buff___39 *);
	const struct neigh_ops___26 *ops;
	struct callback_head rcu;
	struct net_device___39 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct pernet_operations___38 {
	struct list_head list;
	int (*init)(struct net___48 *);
	void (*exit)(struct net___48 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___37 {
	int (*ieee_getets)(struct net_device___39 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___39 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___39 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___39 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___39 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___39 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___39 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___39 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___39 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___39 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___39 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___39 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___39 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___39 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___39 *);
	u8 (*setstate)(struct net_device___39 *, u8);
	void (*getpermhwaddr)(struct net_device___39 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___39 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___39 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___39 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___39 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___39 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___39 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___39 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___39 *, int, u8 *);
	void (*setpfccfg)(struct net_device___39 *, int, u8);
	void (*getpfccfg)(struct net_device___39 *, int, u8 *);
	u8 (*setall)(struct net_device___39 *);
	u8 (*getcap)(struct net_device___39 *, int, u8 *);
	int (*getnumtcs)(struct net_device___39 *, int, u8 *);
	int (*setnumtcs)(struct net_device___39 *, int, u8);
	u8 (*getpfcstate)(struct net_device___39 *);
	void (*setpfcstate)(struct net_device___39 *, u8);
	void (*getbcncfg)(struct net_device___39 *, int, u32 *);
	void (*setbcncfg)(struct net_device___39 *, int, u32);
	void (*getbcnrp)(struct net_device___39 *, int, u8 *);
	void (*setbcnrp)(struct net_device___39 *, int, u8);
	int (*setapp)(struct net_device___39 *, u8, u16, u8);
	int (*getapp)(struct net_device___39 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___39 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___39 *, int, u8);
	u8 (*getdcbx)(struct net_device___39 *);
	u8 (*setdcbx)(struct net_device___39 *, u8);
	int (*peer_getappinfo)(struct net_device___39 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___39 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___39 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___39 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___39 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___39 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct xdp_rxq_info___37 {
	struct net_device___39 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___37 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___39 *dev_rx;
};

struct netlink_skb_parms___3 {
	struct scm_creds creds;
	__u32 portid;
	__u32 dst_group;
	__u32 flags;
	struct sock___27 *sk;
	bool nsid_is_set;
	int nsid;
};

struct netlink_callback___38 {
	struct sk_buff___39 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___38 *);
	int (*dump)(struct sk_buff___39 *, struct netlink_callback___38 *);
	int (*done)(struct netlink_callback___38 *);
	void *data;
	struct module___271 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___37 {
	int (*create)(struct sk_buff___39 *, struct net_device___39 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___39 *, unsigned char *);
	int (*cache)(const struct neighbour___26 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___39 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___37 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___37 *, int);
	int poll_owner;
	struct net_device___39 *dev;
	struct sk_buff___39 *gro_list;
	struct sk_buff___39 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___37 {
	struct net_device___39 *dev;
	struct Qdisc___36 *qdisc;
	struct Qdisc___36 *qdisc_sleeping;
	struct kobject___320 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___39 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide44;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___36 {
	struct sk_buff___39 *head;
	struct sk_buff___39 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___36;

struct Qdisc___36 {
	int (*enqueue)(struct sk_buff___39 *, struct Qdisc___36 *, struct sk_buff___39 **);
	struct sk_buff___39 * (*dequeue)(struct Qdisc___36 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___36 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___37 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___37 gso_skb;
	struct qdisc_skb_head___36 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___36 *next_sched;
	struct sk_buff_head___37 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___37 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___320 kobj;
	struct net_device___39 *dev;
	long: 64;
	struct xdp_rxq_info___37 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide45;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___37)(struct net_device___39 *, struct sk_buff___39 *, struct net_device___39 *);

struct netdev_bpf___37 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___36 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___36 *prog;
			const struct bpf_prog_offload_ops___36 *ops;
		} verifier;
		struct {
			struct bpf_prog___36 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___37 *offmap;
		};
		struct {
			struct xdp_umem *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___37 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___39 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___37 {
	int (*tls_dev_add)(struct net_device___39 *, struct sock___27 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___39 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___39 *, struct sock___27 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide46;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___37 {
	int (*ndo_init)(struct net_device___39 *);
	void (*ndo_uninit)(struct net_device___39 *);
	int (*ndo_open)(struct net_device___39 *);
	int (*ndo_stop)(struct net_device___39 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___39 *, struct net_device___39 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___39 *, struct net_device___39 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___39 *, struct sk_buff___39 *, struct net_device___39 *, select_queue_fallback_t___37);
	void (*ndo_change_rx_flags)(struct net_device___39 *, int);
	void (*ndo_set_rx_mode)(struct net_device___39 *);
	int (*ndo_set_mac_address)(struct net_device___39 *, void *);
	int (*ndo_validate_addr)(struct net_device___39 *);
	int (*ndo_do_ioctl)(struct net_device___39 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___39 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___39 *, int);
	int (*ndo_neigh_setup)(struct net_device___39 *, struct neigh_parms___26 *);
	void (*ndo_tx_timeout)(struct net_device___39 *);
	void (*ndo_get_stats64)(struct net_device___39 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___39 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___39 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___39 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___39 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___39 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___39 *);
	int (*ndo_netpoll_setup)(struct net_device___39 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___39 *);
	int (*ndo_set_vf_mac)(struct net_device___39 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___39 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___39 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___39 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___39 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___39 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___39 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___39 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___39 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___39 *, int, struct sk_buff___39 *);
	int (*ndo_set_vf_guid)(struct net_device___39 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___39 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___39 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___39 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___39 *, const struct sk_buff___39 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___39 *, struct net_device___39 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___39 *, struct net_device___39 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___39 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___39 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___39 *, struct neighbour___26 *);
	void (*ndo_neigh_destroy)(struct net_device___39 *, struct neighbour___26 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___39 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___39 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide47;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___39 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___39 *, struct netlink_callback___38 *, struct net_device___39 *, struct net_device___39 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___39 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___39 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide48;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___39 *, u32, u32, struct net_device___39 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___39 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___39 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___39 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___39 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___39 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___39 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___39 *, struct net_device___39 *);
	void (*ndo_dfwd_del_station)(struct net_device___39 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___39 *);
	int (*ndo_set_tx_maxrate)(struct net_device___39 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___39 *);
	int (*ndo_change_proto_down)(struct net_device___39 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___39 *, struct sk_buff___39 *);
	void (*ndo_set_rx_headroom)(struct net_device___39 *, int);
	int (*ndo_bpf)(struct net_device___39 *, struct netdev_bpf___37 *);
	int (*ndo_xdp_xmit)(struct net_device___39 *, int, struct xdp_frame___37 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___39 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___39 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide49;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___26 {
	possible_net_t___38 net;
	struct net_device___39 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___26 *);
	void (*neigh_cleanup)(struct neighbour___26 *);
	struct neigh_table___26 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___26 {
	u32 (*l3mdev_fib_table)(const struct net_device___39 *);
	struct sk_buff___39 * (*l3mdev_l3_rcv)(struct net_device___39 *, struct sk_buff___39 *, u16);
	struct sk_buff___39 * (*l3mdev_l3_out)(struct net_device___39 *, struct sock___27 *, struct sk_buff___39 *, u16);
	struct dst_entry___26 * (*l3mdev_link_scope_lookup)(const struct net_device___39 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct tcf_proto___36;

struct mini_Qdisc___36 {
	struct tcf_proto___36 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___36 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___39 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___48 *, struct net_device___39 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___39 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___39 *, struct list_head *);
	size_t (*get_size)(const struct net_device___39 *);
	int (*fill_info)(struct sk_buff___39 *, const struct net_device___39 *);
	size_t (*get_xstats_size)(const struct net_device___39 *);
	int (*fill_xstats)(struct sk_buff___39 *, const struct net_device___39 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___39 *, struct net_device___39 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___39 *, const struct net_device___39 *);
	int (*fill_slave_info)(struct sk_buff___39 *, const struct net_device___39 *, const struct net_device___39 *);
	struct net___48 * (*get_link_net)(const struct net_device___39 *);
	size_t (*get_linkxstats_size)(const struct net_device___39 *, int);
	int (*fill_linkxstats)(struct sk_buff___39 *, const struct net_device___39 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___37 {
	struct list_head poll_list;
	struct sk_buff_head___37 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___37 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___36 *output_queue;
	struct Qdisc___36 **output_queue_tailp;
	struct sk_buff___39 *completion_queue;
	struct sk_buff_head___37 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___37 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___37 input_pkt_queue;
	struct napi_struct___37 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct gnet_dump___36 {
	spinlock_t *lock;
	struct sk_buff___39 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___36;

struct Qdisc_ops___36 {
	struct Qdisc_ops___36 *next;
	const struct Qdisc_class_ops___36 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___39 *, struct Qdisc___36 *, struct sk_buff___39 **);
	struct sk_buff___39 * (*dequeue)(struct Qdisc___36 *);
	struct sk_buff___39 * (*peek)(struct Qdisc___36 *);
	int (*init)(struct Qdisc___36 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___36 *);
	void (*destroy)(struct Qdisc___36 *);
	int (*change)(struct Qdisc___36 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___36 *);
	int (*change_tx_queue_len)(struct Qdisc___36 *, unsigned int);
	int (*dump)(struct Qdisc___36 *, struct sk_buff___39 *);
	int (*dump_stats)(struct Qdisc___36 *, struct gnet_dump___36 *);
	void (*ingress_block_set)(struct Qdisc___36 *, u32);
	void (*egress_block_set)(struct Qdisc___36 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___36 *);
	u32 (*egress_block_get)(struct Qdisc___36 *);
	struct module___271 *owner;
};

struct tcf_block___36;

struct Qdisc_class_ops___36 {
	unsigned int flags;
	struct netdev_queue___37 * (*select_queue)(struct Qdisc___36 *, struct tcmsg *);
	int (*graft)(struct Qdisc___36 *, long unsigned int, struct Qdisc___36 *, struct Qdisc___36 **, struct netlink_ext_ack *);
	struct Qdisc___36 * (*leaf)(struct Qdisc___36 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___36 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___36 *, u32);
	int (*change)(struct Qdisc___36 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___36 *, long unsigned int);
	void (*walk)(struct Qdisc___36 *, struct qdisc_walker *);
	struct tcf_block___36 * (*tcf_block)(struct Qdisc___36 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___36 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___36 *, long unsigned int);
	int (*dump)(struct Qdisc___36 *, long unsigned int, struct sk_buff___39 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___36 *, long unsigned int, struct gnet_dump___36 *);
};

struct tcf_chain___36;

struct tcf_block___36 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___48 *net;
	struct Qdisc___36 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___36 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___36;

struct tcf_proto_ops___36;

struct tcf_proto___36 {
	struct tcf_proto___36 *next;
	void *root;
	int (*classify)(struct sk_buff___39 *, const struct tcf_proto___36 *, struct tcf_result___36 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___36 *ops;
	struct tcf_chain___36 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___36 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___36 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___36 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___39 *, const struct tcf_proto___36 *, struct tcf_result___36 *);
	int (*init)(struct tcf_proto___36 *);
	void (*destroy)(struct tcf_proto___36 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___36 *, u32);
	void (*put)(struct tcf_proto___36 *, void *);
	int (*change)(struct net___48 *, struct sk_buff___39 *, struct tcf_proto___36 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___36 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___36 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___36 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___48 *, struct tcf_chain___36 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___48 *, struct tcf_proto___36 *, void *, struct sk_buff___39 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___39 *, struct net___48 *, void *);
	struct module___271 *owner;
	int flags;
};

struct tcf_chain___36 {
	struct mutex filter_chain_lock;
	struct tcf_proto___36 *filter_chain;
	struct list_head list;
	struct tcf_block___36 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___36 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___26 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___36 *prog;
};

struct bpf_redirect_info___36 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___218 *map;
	struct bpf_map___218 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___26;

struct neigh_hash_table___26;

struct neigh_table___26 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___39 *, __u32 *);
	bool (*key_eq)(const struct neighbour___26 *, const void *);
	int (*constructor)(struct neighbour___26 *);
	int (*pconstructor)(struct pneigh_entry___26 *);
	void (*pdestructor)(struct pneigh_entry___26 *);
	void (*proxy_redo)(struct sk_buff___39 *);
	char *id;
	struct neigh_parms___26 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___37 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___26 *nht;
	struct pneigh_entry___26 **phash_buckets;
};

struct neigh_ops___26 {
	int family;
	void (*solicit)(struct neighbour___26 *, struct sk_buff___39 *);
	void (*error_report)(struct neighbour___26 *, struct sk_buff___39 *);
	int (*output)(struct neighbour___26 *, struct sk_buff___39 *);
	int (*connected_output)(struct neighbour___26 *, struct sk_buff___39 *);
};

struct pneigh_entry___26 {
	struct pneigh_entry___26 *next;
	possible_net_t___38 net;
	struct net_device___39 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___26 {
	struct neighbour___26 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___26 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___26 *ctarget;
	struct net___48 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___26 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___26 *rule;
	u32 table;
	int flags;
};

struct proto___26 {
	void (*close)(struct sock___27 *, long int);
	int (*pre_connect)(struct sock___27 *, struct sockaddr *, int);
	int (*connect)(struct sock___27 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___27 *, int);
	struct sock___27 * (*accept)(struct sock___27 *, int, int *, bool);
	int (*ioctl)(struct sock___27 *, int, long unsigned int);
	int (*init)(struct sock___27 *);
	void (*destroy)(struct sock___27 *);
	void (*shutdown)(struct sock___27 *, int);
	int (*setsockopt)(struct sock___27 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___27 *, int, int, char *, int *);
	void (*keepalive)(struct sock___27 *, int);
	int (*sendmsg)(struct sock___27 *, struct msghdr___29 *, size_t);
	int (*recvmsg)(struct sock___27 *, struct msghdr___29 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___27 *, struct page___334 *, int, size_t, int);
	int (*bind)(struct sock___27 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___27 *, struct sk_buff___39 *);
	void (*release_cb)(struct sock___27 *);
	int (*hash)(struct sock___27 *);
	void (*unhash)(struct sock___27 *);
	void (*rehash)(struct sock___27 *);
	int (*get_port)(struct sock___27 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___27 *);
	bool (*stream_memory_read)(const struct sock___27 *);
	void (*enter_memory_pressure)(struct sock___27 *);
	void (*leave_memory_pressure)(struct sock___27 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___3 *rsk_prot;
	struct timewait_sock_ops___3 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___271 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___27 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct cb_id {
	__u32 idx;
	__u32 val;
};

struct cn_msg {
	struct cb_id id;
	__u32 seq;
	__u32 ack;
	__u16 len;
	__u16 flags;
	__u8 data[0];
};

struct cn_queue_dev {
	atomic_t refcnt;
	unsigned char name[32];
	struct list_head queue_list;
	spinlock_t queue_lock;
	struct sock___27 *nls;
};

struct cn_callback_id {
	unsigned char name[32];
	struct cb_id id;
};

struct cn_callback_entry {
	struct list_head callback_entry;
	refcount_t refcnt;
	struct cn_queue_dev *pdev;
	struct cn_callback_id id;
	void (*callback)(struct cn_msg *, struct netlink_skb_parms___3 *);
	u32 seq;
	u32 group;
};

struct module___272;

struct file___334;

struct kiocb___334;

struct iov_iter___145;

struct poll_table_struct___203;

struct vm_area_struct___335;

struct inode___334;

struct file_lock___334;

struct page___335;

struct pipe_inode_info___71;

struct seq_file___282;

struct file_operations___334 {
	struct module___272 *owner;
	loff_t (*llseek)(struct file___334 *, loff_t, int);
	ssize_t (*read)(struct file___334 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___334 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___334 *, struct iov_iter___145 *);
	ssize_t (*write_iter)(struct kiocb___334 *, struct iov_iter___145 *);
	int (*iopoll)(struct kiocb___334 *, bool);
	int (*iterate)(struct file___334 *, struct dir_context *);
	int (*iterate_shared)(struct file___334 *, struct dir_context *);
	__poll_t (*poll)(struct file___334 *, struct poll_table_struct___203 *);
	long int (*unlocked_ioctl)(struct file___334 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___334 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___334 *, struct vm_area_struct___335 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___334 *, struct file___334 *);
	int (*flush)(struct file___334 *, fl_owner_t);
	int (*release)(struct inode___334 *, struct file___334 *);
	int (*fsync)(struct file___334 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___334 *, int);
	int (*lock)(struct file___334 *, int, struct file_lock___334 *);
	ssize_t (*sendpage)(struct file___334 *, struct page___335 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___334 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___334 *, int, struct file_lock___334 *);
	ssize_t (*splice_write)(struct pipe_inode_info___71 *, struct file___334 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___334 *, loff_t *, struct pipe_inode_info___71 *, size_t, unsigned int);
	int (*setlease)(struct file___334 *, long int, struct file_lock___334 **, void **);
	long int (*fallocate)(struct file___334 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___282 *, struct file___334 *);
	ssize_t (*copy_file_range)(struct file___334 *, loff_t, struct file___334 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___334 *, loff_t, struct file___334 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___334 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___334 {
	u64 seqnum;
	struct vm_area_struct___335 *vmas[4];
};

struct page_frag___334 {
	struct page___335 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___334;

struct mem_cgroup___124;

struct cred___309;

struct nsproxy___262;

struct signal_struct___244;

struct bio_list___158;

struct backing_dev_info___158;

struct css_set___218;

struct vm_struct___245;

struct task_struct___335 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___335 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___334 *mm;
	struct mm_struct___334 *active_mm;
	struct vmacache___334 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___335 *real_parent;
	struct task_struct___335 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___335 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___124 *active_memcg;
	long int rh_reserved2;
	struct pid___209 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___209 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___209 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___309 *ptracer_cred;
	const struct cred___309 *real_cred;
	const struct cred___309 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___262 *nsproxy;
	struct signal_struct___244 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___335 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___158 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___158 *backing_dev_info;
	struct io_context___84 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___218 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___71 *splice_pipe;
	struct page_frag___334 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___124 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___335 *oom_reaper_list;
	struct vm_struct___245 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___134 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rw_semaphore___335 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___335 *owner;
};

struct key___309;

struct ucounts___233;

struct user_namespace___233 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___233 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___9 ns;
	long unsigned int flags;
	struct key___309 *persistent_keyring_register;
	struct rw_semaphore___335 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___233 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___335 *pgtable_t___334;

struct address_space___333;

struct dev_pagemap___322;

struct page___335 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___333 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___335 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___334 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___334 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___322 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___124 *mem_cgroup;
};

struct pglist_data___334;

struct lruvec___334 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___334 *pgdat;
};

struct zone___334 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___334 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___334 {
	struct zone___334 *zone;
	int zone_idx;
};

struct zonelist___334 {
	struct zoneref___334 _zonerefs[25];
};

struct pglist_data___334 {
	struct zone___334 node_zones[3];
	struct zonelist___334 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___335 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___335 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___334 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___335 {
	void *stack;
	struct task_struct___335 *task;
	long int status;
};

struct blocking_notifier_head___334 {
	struct rw_semaphore___335 rwsem;
	struct notifier_block *head;
};

struct dentry___333;

struct path___334 {
	struct vfsmount *mnt;
	struct dentry___333 *dentry;
};

struct file___334 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___334 f_path;
	struct inode___334 *f_inode;
	const struct file_operations___334 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___209 f_owner;
	const struct cred___309 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___333 *f_mapping;
	errseq_t f_wb_err;
};

struct user_struct___309;

struct cred___309 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___309 *session_keyring;
	struct key___309 *process_keyring;
	struct key___309 *thread_keyring;
	struct key___309 *request_key_auth;
	void *security;
	struct user_struct___309 *user;
	struct user_namespace___233 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___327;

struct kernfs_elem_dir___327 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___327 *root;
};

struct kernfs_node___328;

struct kernfs_syscall_ops___327;

struct kernfs_root___327 {
	struct kernfs_node___328 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___327 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___327 {
	struct kernfs_node___328 *target_kn;
};

struct kernfs_ops___327;

struct kernfs_elem_attr___327 {
	const struct kernfs_ops___327 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___328 *notify_next;
};

struct kernfs_node___328 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___328 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___327 dir;
		struct kernfs_elem_symlink___327 symlink;
		struct kernfs_elem_attr___327 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___327;

struct kernfs_ops___327 {
	int (*open)(struct kernfs_open_file___327 *);
	void (*release)(struct kernfs_open_file___327 *);
	int (*seq_show)(struct seq_file___282 *, void *);
	void * (*seq_start)(struct seq_file___282 *, loff_t *);
	void * (*seq_next)(struct seq_file___282 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___282 *, void *);
	ssize_t (*read)(struct kernfs_open_file___327 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___327 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___327 *, struct vm_area_struct___335 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___327 *, struct poll_table_struct___203 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___327 {
	int (*remount_fs)(struct kernfs_root___327 *, int *, char *);
	int (*show_options)(struct seq_file___282 *, struct kernfs_root___327 *);
	int (*mkdir)(struct kernfs_node___328 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___328 *);
	int (*rename)(struct kernfs_node___328 *, struct kernfs_node___328 *, const char *);
	int (*show_path)(struct seq_file___282 *, struct kernfs_node___328 *, struct kernfs_root___327 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___281;

struct seq_file___282 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___281 *op;
	int poll_event;
	const struct file___334 *file;
	void *private;
};

struct vm_operations_struct___322;

struct kernfs_open_file___327 {
	struct kernfs_node___328 *kn;
	struct file___334 *file;
	struct seq_file___282 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___322 *vm_ops;
};

struct vm_fault___322;

struct vm_operations_struct___322 {
	void (*open)(struct vm_area_struct___335 *);
	void (*close)(struct vm_area_struct___335 *);
	int (*split)(struct vm_area_struct___335 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___335 *);
	vm_fault_t (*fault)(struct vm_fault___322 *);
	vm_fault_t (*huge_fault)(struct vm_fault___322 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___322 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___335 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___322 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___322 *);
	int (*access)(struct vm_area_struct___335 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___335 *);
	int (*set_policy)(struct vm_area_struct___335 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___335 *, long unsigned int);
	struct page___335 * (*find_special_page)(struct vm_area_struct___335 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___209)(struct file___334 *, wait_queue_head_t *, struct poll_table_struct___203 *);

struct poll_table_struct___203 {
	poll_queue_proc___209 _qproc;
	__poll_t _key;
};

struct vm_area_struct___335 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___335 *vm_next;
	struct vm_area_struct___335 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___334 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___322 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___334 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sock___28;

struct kobj_ns_type_operations___27 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___28 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct net___49;

typedef struct {
	struct net___49 *net;
} possible_net_t___39;

struct proto___27;

struct sock_common___27 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___27 *skc_prot;
	possible_net_t___39 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___28 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___40;

struct sk_buff_head___38 {
	struct sk_buff___40 *next;
	struct sk_buff___40 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___27;

struct socket_wq___28;

struct dst_entry___27;

struct socket___29;

struct net_device___40;

struct sock___28 {
	struct sock_common___27 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___38 sk_error_queue;
	struct sk_buff_head___38 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___40 *head;
		struct sk_buff___40 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___27 *sk_filter;
	union {
		struct socket_wq___28 *sk_wq;
		struct socket_wq___28 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___27 *sk_rx_dst;
	struct dst_entry___27 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___40 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___38 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___334 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___27 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___209 *sk_peer_pid;
	const struct cred___309 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___29 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___124 *sk_memcg;
	void (*sk_state_change)(struct sock___28 *);
	void (*sk_data_ready)(struct sock___28 *);
	void (*sk_write_space)(struct sock___28 *);
	void (*sk_error_report)(struct sock___28 *);
	int (*sk_backlog_rcv)(struct sock___28 *, struct sk_buff___40 *);
	struct sk_buff___40 * (*sk_validate_xmit_skb)(struct sock___28 *, struct net_device___40 *, struct sk_buff___40 *);
	void (*sk_destruct)(struct sock___28 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kobject___321;

struct bin_attribute___297;

struct attribute_group___298 {
	const char *name;
	umode_t (*is_visible)(struct kobject___321 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___321 *, struct bin_attribute___297 *, int);
	struct attribute **attrs;
	struct bin_attribute___297 **bin_attrs;
};

struct kset___320;

struct kobj_type___320;

struct kobject___321 {
	const char *name;
	struct list_head entry;
	struct kobject___321 *parent;
	struct kset___320 *kset;
	struct kobj_type___320 *ktype;
	struct kernfs_node___328 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___297 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___334 *, struct kobject___321 *, struct bin_attribute___297 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___334 *, struct kobject___321 *, struct bin_attribute___297 *, char *, loff_t, size_t);
	int (*mmap)(struct file___334 *, struct kobject___321 *, struct bin_attribute___297 *, struct vm_area_struct___335 *);
};

struct sysfs_ops___320 {
	ssize_t (*show)(struct kobject___321 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___321 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___320;

struct kset___320 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___321 kobj;
	const struct kset_uevent_ops___320 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___320 {
	void (*release)(struct kobject___321 *);
	const struct sysfs_ops___320 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___27 * (*child_ns_type)(struct kobject___321 *);
	const void * (*namespace)(struct kobject___321 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___320 {
	int (* const filter)(struct kset___320 *, struct kobject___321 *);
	const char * (* const name)(struct kset___320 *, struct kobject___321 *);
	int (* const uevent)(struct kset___320 *, struct kobject___321 *, struct kobj_uevent_env *);
};

struct kobj_attribute___312 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___321 *, struct kobj_attribute___312 *, char *);
	ssize_t (*store)(struct kobject___321 *, struct kobj_attribute___312 *, const char *, size_t);
};

struct kernel_param___269;

struct kernel_param_ops___269 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___269 *);
	int (*get)(char *, const struct kernel_param___269 *);
	void (*free)(void *);
};

struct kparam_array___269;

struct kernel_param___269 {
	const char *name;
	struct module___272 *mod;
	const struct kernel_param_ops___269 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___269 *arr;
	};
};

struct kparam_array___269 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___269 *ops;
	void *elem;
};

struct module_kobject___269 {
	struct kobject___321 kobj;
	struct module___272 *mod;
	struct kobject___321 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___269 {
	struct module___272 *mod;
	struct latch_tree_node node;
};

struct module_layout___269 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___269 mtn;
};

struct module_attribute___269;

struct module___272 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___269 mkobj;
	struct module_attribute___269 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___321 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___269 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___269 core_layout;
	struct module_layout___269 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___269 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___269 *, struct module_kobject___269 *, char *);
	ssize_t (*store)(struct module_attribute___269 *, struct module_kobject___269 *, const char *, size_t);
	void (*setup)(struct module___272 *, const char *);
	int (*test)(struct module___272 *);
	void (*free)(struct module___272 *);
};

struct cgroup___218;

struct cgroup_subsys___218;

struct cgroup_subsys_state___218 {
	struct cgroup___218 *cgroup;
	struct cgroup_subsys___218 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___218 *parent;
};

struct cgroup_file___218 {
	struct kernfs_node___328 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___124;

struct mem_cgroup___124 {
	struct cgroup_subsys_state___218 css;
	struct mem_cgroup_id___13 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___218 events_file;
	struct cgroup_file___218 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___335 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___124 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct user_struct___309 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___309 *uid_keyring;
	struct key___309 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___334;

struct mm_struct___334 {
	struct {
		struct vm_area_struct___335 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___334 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___335 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___334 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___335 *owner;
		struct user_namespace___233 *user_ns;
		struct file___334 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___334 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___218;

struct nsproxy___262 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net___49 *net_ns;
	struct cgroup_namespace___218 *cgroup_ns;
};

struct signal_struct___244 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___335 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___335 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___209 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___209 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___334 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___209 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___158;

struct bio_list___158 {
	struct bio___158 *head;
	struct bio___158 *tail;
};

struct bdi_writeback_congested___158;

struct bdi_writeback___158 {
	struct backing_dev_info___158 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___158 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___218 *memcg_css;
	struct cgroup_subsys_state___218 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___300;

struct backing_dev_info___158 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___158 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___300 *dev;
	struct device___300 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___333 *debug_dir;
	struct dentry___333 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___218 {
	struct cgroup_subsys_state___218 *subsys[13];
	refcount_t refcount;
	struct css_set___218 *dom_cset;
	struct cgroup___218 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___218 *mg_src_cgrp;
	struct cgroup___218 *mg_dst_cgrp;
	struct css_set___218 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___333;

struct pipe_buffer___71;

struct pipe_inode_info___71 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___335 *tmp_page;
	struct fasync_struct___333 *fasync_readers;
	struct fasync_struct___333 *fasync_writers;
	struct pipe_buffer___71 *bufs;
	struct user_struct___309 *user;
};

struct vm_struct___245 {
	struct vm_struct___245 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___335 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___256 {
	struct task_struct___335 task;
	long unsigned int stack[8192];
};

struct address_space_operations___333;

struct address_space___333 {
	struct inode___334 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___335 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___333 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___322)(struct vm_area_struct___335 *, long unsigned int, const struct page___335 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___322)(struct page___335 *, void *);

struct dev_pagemap___322 {
	dev_page_fault_t___322 page_fault;
	dev_page_free_t___322 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___300 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___334 {
	struct task_struct___335 *task;
	struct core_thread___334 *next;
};

struct core_state___334 {
	atomic_t nr_threads;
	struct core_thread___334 dumper;
	struct completion startup;
};

struct vm_fault___322 {
	struct vm_area_struct___335 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___335 *cow_page;
	struct mem_cgroup___124 *memcg;
	struct page___335 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___334 prealloc_pte;
};

struct bio_vec___159 {
	struct page___335 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___145 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___159 *bvec;
		struct pipe_inode_info___71 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct msghdr___30 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___145 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___334 *msg_iocb;
};

struct kiocb___334 {
	struct file___334 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___334 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dentry_operations___333;

struct super_block___333;

struct dentry___333 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___333 *d_parent;
	struct qstr d_name;
	struct inode___334 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___333 *d_op;
	struct super_block___333 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___333;

struct block_device___333;

struct inode___334 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___333 *i_op;
	struct super_block___333 *i_sb;
	struct address_space___333 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___335 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___158 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___334 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___333 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___71 *i_pipe;
		struct block_device___333 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___333 {
	int (*d_revalidate)(struct dentry___333 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___333 *, unsigned int);
	int (*d_hash)(const struct dentry___333 *, struct qstr *);
	int (*d_compare)(const struct dentry___333 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___333 *);
	int (*d_init)(struct dentry___333 *);
	void (*d_release)(struct dentry___333 *);
	void (*d_prune)(struct dentry___333 *);
	void (*d_iput)(struct dentry___333 *, struct inode___334 *);
	char * (*d_dname)(struct dentry___333 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___334 *);
	int (*d_manage)(const struct path___334 *, bool);
	struct dentry___333 * (*d_real)(struct dentry___333 *, const struct inode___334 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___333;

struct mem_dqinfo___333 {
	struct quota_format_type___333 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___333;

struct quota_info___333 {
	unsigned int flags;
	struct rw_semaphore___335 dqio_sem;
	struct inode___334 *files[3];
	struct mem_dqinfo___333 info[3];
	const struct quota_format_ops___333 *ops[3];
};

struct rcuwait___333 {
	struct task_struct___335 *task;
};

struct percpu_rw_semaphore___333 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___335 rw_sem;
	struct rcuwait___333 writer;
	int readers_block;
};

struct sb_writers___333 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___333 rw_sem[3];
};

struct shrink_control___124;

struct shrinker___124 {
	long unsigned int (*count_objects)(struct shrinker___124 *, struct shrink_control___124 *);
	long unsigned int (*scan_objects)(struct shrinker___124 *, struct shrink_control___124 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___333;

struct super_operations___333;

struct dquot_operations___333;

struct quotactl_ops___333;

struct super_block___333 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___333 *s_type;
	const struct super_operations___333 *s_op;
	const struct dquot_operations___333 *dq_op;
	const struct quotactl_ops___333 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___333 *s_root;
	struct rw_semaphore___335 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___333 *s_bdev;
	struct backing_dev_info___158 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___333 s_dquot;
	struct sb_writers___333 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___333 *s_d_op;
	int cleancache_poolid;
	struct shrinker___124 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___233 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___124 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___124 *memcg;
};

struct iattr___333 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___334 *ia_file;
};

struct dquot___333 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___333 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___333 {
	int qf_fmt_id;
	const struct quota_format_ops___333 *qf_ops;
	struct module___272 *qf_owner;
	struct quota_format_type___333 *qf_next;
};

struct quota_format_ops___333 {
	int (*check_quota_file)(struct super_block___333 *, int);
	int (*read_file_info)(struct super_block___333 *, int);
	int (*write_file_info)(struct super_block___333 *, int);
	int (*free_file_info)(struct super_block___333 *, int);
	int (*read_dqblk)(struct dquot___333 *);
	int (*commit_dqblk)(struct dquot___333 *);
	int (*release_dqblk)(struct dquot___333 *);
	int (*get_next_id)(struct super_block___333 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___333 {
	int (*write_dquot)(struct dquot___333 *);
	struct dquot___333 * (*alloc_dquot)(struct super_block___333 *, int);
	void (*destroy_dquot)(struct dquot___333 *);
	int (*acquire_dquot)(struct dquot___333 *);
	int (*release_dquot)(struct dquot___333 *);
	int (*mark_dirty)(struct dquot___333 *);
	int (*write_info)(struct super_block___333 *, int);
	qsize_t * (*get_reserved_space)(struct inode___334 *);
	int (*get_projid)(struct inode___334 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___334 *, qsize_t *);
	int (*get_next_id)(struct super_block___333 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___333 {
	int (*quota_on)(struct super_block___333 *, int, int, const struct path___334 *);
	int (*quota_off)(struct super_block___333 *, int);
	int (*quota_enable)(struct super_block___333 *, unsigned int);
	int (*quota_disable)(struct super_block___333 *, unsigned int);
	int (*quota_sync)(struct super_block___333 *, int);
	int (*set_info)(struct super_block___333 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___333 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___333 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___333 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___333 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___333 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___141;

struct address_space_operations___333 {
	int (*writepage)(struct page___335 *, struct writeback_control___141 *);
	int (*readpage)(struct file___334 *, struct page___335 *);
	int (*writepages)(struct address_space___333 *, struct writeback_control___141 *);
	int (*set_page_dirty)(struct page___335 *);
	int (*readpages)(struct file___334 *, struct address_space___333 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___334 *, struct address_space___333 *, loff_t, unsigned int, unsigned int, struct page___335 **, void **);
	int (*write_end)(struct file___334 *, struct address_space___333 *, loff_t, unsigned int, unsigned int, struct page___335 *, void *);
	sector_t (*bmap)(struct address_space___333 *, sector_t);
	void (*invalidatepage)(struct page___335 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___335 *, gfp_t);
	void (*freepage)(struct page___335 *);
	ssize_t (*direct_IO)(struct kiocb___334 *, struct iov_iter___145 *);
	int (*migratepage)(struct address_space___333 *, struct page___335 *, struct page___335 *, enum migrate_mode);
	bool (*isolate_page)(struct page___335 *, isolate_mode_t);
	void (*putback_page)(struct page___335 *);
	int (*launder_page)(struct page___335 *);
	int (*is_partially_uptodate)(struct page___335 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___335 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___333 *, struct page___335 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___334 *, sector_t *);
	void (*swap_deactivate)(struct file___334 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___141 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___158 *wb;
	struct inode___334 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___333 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___334 *bd_inode;
	struct super_block___333 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___333 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___158 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___333 {
	struct dentry___333 * (*lookup)(struct inode___334 *, struct dentry___333 *, unsigned int);
	const char * (*get_link)(struct dentry___333 *, struct inode___334 *, struct delayed_call *);
	int (*permission)(struct inode___334 *, int);
	struct posix_acl * (*get_acl)(struct inode___334 *, int);
	int (*readlink)(struct dentry___333 *, char *, int);
	int (*create)(struct inode___334 *, struct dentry___333 *, umode_t, bool);
	int (*link)(struct dentry___333 *, struct inode___334 *, struct dentry___333 *);
	int (*unlink)(struct inode___334 *, struct dentry___333 *);
	int (*symlink)(struct inode___334 *, struct dentry___333 *, const char *);
	int (*mkdir)(struct inode___334 *, struct dentry___333 *, umode_t);
	int (*rmdir)(struct inode___334 *, struct dentry___333 *);
	int (*mknod)(struct inode___334 *, struct dentry___333 *, umode_t, dev_t);
	int (*rename)(struct inode___334 *, struct dentry___333 *, struct inode___334 *, struct dentry___333 *, unsigned int);
	int (*setattr)(struct dentry___333 *, struct iattr___333 *);
	int (*getattr)(const struct path___334 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___333 *, char *, size_t);
	int (*fiemap)(struct inode___334 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___334 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___334 *, struct dentry___333 *, struct file___334 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___334 *, struct dentry___333 *, umode_t);
	int (*set_acl)(struct inode___334 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___333 {
	void (*fl_copy_lock)(struct file_lock___334 *, struct file_lock___334 *);
	void (*fl_release_private)(struct file_lock___334 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___333;

struct file_lock___334 {
	struct file_lock___334 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___334 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___333 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___333 *fl_ops;
	const struct lock_manager_operations___333 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___333 {
	int (*lm_compare_owner)(struct file_lock___334 *, struct file_lock___334 *);
	long unsigned int (*lm_owner_key)(struct file_lock___334 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___334 *);
	int (*lm_grant)(struct file_lock___334 *, int);
	bool (*lm_break)(struct file_lock___334 *);
	int (*lm_change)(struct file_lock___334 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___334 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___333 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___333 *fa_next;
	struct file___334 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___333 {
	const char *name;
	int fs_flags;
	struct dentry___333 * (*mount)(struct file_system_type___333 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___333 *);
	struct module___272 *owner;
	struct file_system_type___333 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___333 {
	struct inode___334 * (*alloc_inode)(struct super_block___333 *);
	void (*destroy_inode)(struct inode___334 *);
	void (*dirty_inode)(struct inode___334 *, int);
	int (*write_inode)(struct inode___334 *, struct writeback_control___141 *);
	int (*drop_inode)(struct inode___334 *);
	void (*evict_inode)(struct inode___334 *);
	void (*put_super)(struct super_block___333 *);
	int (*sync_fs)(struct super_block___333 *, int);
	int (*freeze_super)(struct super_block___333 *);
	int (*freeze_fs)(struct super_block___333 *);
	int (*thaw_super)(struct super_block___333 *);
	int (*unfreeze_fs)(struct super_block___333 *);
	int (*statfs)(struct dentry___333 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___333 *, int *, char *);
	void (*umount_begin)(struct super_block___333 *);
	int (*show_options)(struct seq_file___282 *, struct dentry___333 *);
	int (*show_devname)(struct seq_file___282 *, struct dentry___333 *);
	int (*show_path)(struct seq_file___282 *, struct dentry___333 *);
	int (*show_stats)(struct seq_file___282 *, struct dentry___333 *);
	ssize_t (*quota_read)(struct super_block___333 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___333 *, int, const char *, size_t, loff_t);
	struct dquot___333 ** (*get_dquots)(struct inode___334 *);
	int (*bdev_try_to_free_page)(struct super_block___333 *, struct page___335 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___333 *, struct shrink_control___124 *);
	long int (*free_cached_objects)(struct super_block___333 *, struct shrink_control___124 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___158(struct bio___158 *);

struct bio_integrity_payload___158;

struct bio_set___158;

struct bio___158 {
	struct bio___158 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___158 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___158 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___159 *bi_io_vec;
	struct bio_set___158 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___159 bi_inline_vecs[0];
};

struct socket_wq___28 {
	wait_queue_head_t wait;
	struct fasync_struct___333 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___28;

struct socket___29 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___28 *wq;
	struct file___334 *file;
	struct sock___28 *sk;
	const struct proto_ops___28 *ops;
};

typedef int (*sk_read_actor_t___27)(read_descriptor_t *, struct sk_buff___40 *, unsigned int, size_t);

struct proto_ops___28 {
	int family;
	struct module___272 *owner;
	int (*release)(struct socket___29 *);
	int (*bind)(struct socket___29 *, struct sockaddr *, int);
	int (*connect)(struct socket___29 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___29 *, struct socket___29 *);
	int (*accept)(struct socket___29 *, struct socket___29 *, int, bool);
	int (*getname)(struct socket___29 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___334 *, struct socket___29 *, struct poll_table_struct___203 *);
	int (*ioctl)(struct socket___29 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___29 *, int);
	int (*shutdown)(struct socket___29 *, int);
	int (*setsockopt)(struct socket___29 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___29 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___29 *, struct msghdr___30 *, size_t);
	int (*recvmsg)(struct socket___29 *, struct msghdr___30 *, size_t, int);
	int (*mmap)(struct file___334 *, struct socket___29 *, struct vm_area_struct___335 *);
	ssize_t (*sendpage)(struct socket___29 *, struct page___335 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___29 *, loff_t *, struct pipe_inode_info___71 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___28 *, int);
	int (*peek_len)(struct socket___29 *);
	int (*read_sock)(struct sock___28 *, read_descriptor_t *, sk_read_actor_t___27);
	int (*sendpage_locked)(struct sock___28 *, struct page___335 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___28 *, struct msghdr___30 *, size_t);
	int (*set_rcvlowat)(struct sock___28 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct nf_bridge_info___38;

struct sk_buff___40 {
	union {
		struct {
			struct sk_buff___40 *next;
			struct sk_buff___40 *prev;
			union {
				struct net_device___40 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___28 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___40 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___38 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___38;

struct netns_frags___38 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___38 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_rules_ops___27;

struct fib_notifier_ops___27;

struct netns_ipv4___38 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___27 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___28 *fibnl;
	struct sock___28 **icmp_sk;
	struct sock___28 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___28 **tcp_sk;
	struct netns_frags___38 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___27 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___27 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___27 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___27;

struct dst_ops___48 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___48 *);
	struct dst_entry___27 * (*check)(struct dst_entry___27 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___27 *);
	unsigned int (*mtu)(const struct dst_entry___27 *);
	u32 * (*cow_metrics)(struct dst_entry___27 *, long unsigned int);
	void (*destroy)(struct dst_entry___27 *);
	void (*ifdown)(struct dst_entry___27 *, struct net_device___40 *, int);
	struct dst_entry___27 * (*negative_advice)(struct dst_entry___27 *);
	void (*link_failure)(struct sk_buff___40 *);
	void (*update_pmtu)(struct dst_entry___27 *, struct sock___28 *, struct sk_buff___40 *, u32);
	void (*redirect)(struct dst_entry___27 *, struct sock___28 *, struct sk_buff___40 *);
	int (*local_out)(struct net___49 *, struct sock___28 *, struct sk_buff___40 *);
	struct neighbour___27 * (*neigh_lookup)(const struct dst_entry___27 *, struct sk_buff___40 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___27 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___48 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___38 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___48 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___27 *fib6_rules_ops;
	struct sock___28 **icmp_sk;
	struct sock___28 *ndisc_sk;
	struct sock___28 *tcp_sk;
	struct sock___28 *igmp_sk;
	struct sock___28 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___27 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___27 *notifier_ops;
	struct fib_notifier_ops___27 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___28 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___28 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___38 {
	struct netns_frags___38 frags;
};

struct netns_xfrm___48 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___28 *nlsk;
	struct sock___28 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___48 xfrm4_dst_ops;
	struct dst_ops___48 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___37;

struct net___49 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___233 *user_ns;
	struct ucounts___233 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___9 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___28 *rtnl;
	struct sock___28 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___40 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___38 ipv4;
	struct netns_ipv6___48 ipv6;
	struct netns_sctp___28 sctp;
	struct netns_nf nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___38 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___28 *nfnl;
	struct sock___28 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___48 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___28 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___37 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___300 {
	int (*prepare)(struct device___300 *);
	void (*complete)(struct device___300 *);
	int (*suspend)(struct device___300 *);
	int (*resume)(struct device___300 *);
	int (*freeze)(struct device___300 *);
	int (*thaw)(struct device___300 *);
	int (*poweroff)(struct device___300 *);
	int (*restore)(struct device___300 *);
	int (*suspend_late)(struct device___300 *);
	int (*resume_early)(struct device___300 *);
	int (*freeze_late)(struct device___300 *);
	int (*thaw_early)(struct device___300 *);
	int (*poweroff_late)(struct device___300 *);
	int (*restore_early)(struct device___300 *);
	int (*suspend_noirq)(struct device___300 *);
	int (*resume_noirq)(struct device___300 *);
	int (*freeze_noirq)(struct device___300 *);
	int (*thaw_noirq)(struct device___300 *);
	int (*poweroff_noirq)(struct device___300 *);
	int (*restore_noirq)(struct device___300 *);
	int (*runtime_suspend)(struct device___300 *);
	int (*runtime_resume)(struct device___300 *);
	int (*runtime_idle)(struct device___300 *);
};

struct dev_pm_info___300 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___3 *subsys_data;
	void (*set_latency_tolerance)(struct device___300 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___300;

struct bus_type___300;

struct device_driver___300;

struct dev_pm_domain___300;

struct dma_map_ops___99;

struct fwnode_handle___229;

struct class___300;

struct device___300 {
	struct device___300 *parent;
	struct device_private *p;
	struct kobject___321 kobj;
	const char *init_name;
	const struct device_type___300 *type;
	struct mutex mutex;
	struct bus_type___300 *bus;
	struct device_driver___300 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___300 power;
	struct dev_pm_domain___300 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___99 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___229 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___300 *class;
	const struct attribute_group___298 **groups;
	void (*release)(struct device___300 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___300 {
	struct dev_pm_ops___300 ops;
	void (*detach)(struct device___300 *, bool);
	int (*activate)(struct device___300 *);
	void (*sync)(struct device___300 *);
	void (*dismiss)(struct device___300 *);
};

struct bus_type___300 {
	const char *name;
	const char *dev_name;
	struct device___300 *dev_root;
	const struct attribute_group___298 **bus_groups;
	const struct attribute_group___298 **dev_groups;
	const struct attribute_group___298 **drv_groups;
	int (*match)(struct device___300 *, struct device_driver___300 *);
	int (*uevent)(struct device___300 *, struct kobj_uevent_env *);
	int (*probe)(struct device___300 *);
	int (*remove)(struct device___300 *);
	void (*shutdown)(struct device___300 *);
	int (*online)(struct device___300 *);
	int (*offline)(struct device___300 *);
	int (*suspend)(struct device___300 *, pm_message_t);
	int (*resume)(struct device___300 *);
	int (*num_vf)(struct device___300 *);
	int (*dma_configure)(struct device___300 *);
	const struct dev_pm_ops___300 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___300 {
	const char *name;
	struct bus_type___300 *bus;
	struct module___272 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___300 *);
	int (*remove)(struct device___300 *);
	void (*shutdown)(struct device___300 *);
	int (*suspend)(struct device___300 *, pm_message_t);
	int (*resume)(struct device___300 *);
	const struct attribute_group___298 **groups;
	const struct dev_pm_ops___300 *pm;
	void (*coredump)(struct device___300 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___300 {
	const char *name;
	const struct attribute_group___298 **groups;
	int (*uevent)(struct device___300 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___300 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___300 *);
	const struct dev_pm_ops___300 *pm;
};

struct class___300 {
	const char *name;
	struct module___272 *owner;
	const struct attribute_group___298 **class_groups;
	const struct attribute_group___298 **dev_groups;
	struct kobject___321 *dev_kobj;
	int (*dev_uevent)(struct device___300 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___300 *, umode_t *);
	void (*class_release)(struct class___300 *);
	void (*dev_release)(struct device___300 *);
	int (*shutdown_pre)(struct device___300 *);
	const struct kobj_ns_type_operations___27 *ns_type;
	const void * (*namespace)(struct device___300 *);
	const struct dev_pm_ops___300 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___99 {
	void * (*alloc)(struct device___300 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___300 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___300 *, struct vm_area_struct___335 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___300 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___300 *, struct page___335 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___300 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___300 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___300 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___300 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___300 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___300 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___300 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___300 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___300 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___300 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___300 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___300 *, u64);
	u64 (*get_required_mask)(struct device___300 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___229;

struct fwnode_handle___229 {
	struct fwnode_handle___229 *secondary;
	const struct fwnode_operations___229 *ops;
};

typedef void compound_page_dtor___322(struct page___335 *);

struct fwnode_reference_args___229;

struct fwnode_endpoint___229;

struct fwnode_operations___229 {
	struct fwnode_handle___229 * (*get)(struct fwnode_handle___229 *);
	void (*put)(struct fwnode_handle___229 *);
	bool (*device_is_available)(const struct fwnode_handle___229 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___229 *, const struct device___300 *);
	bool (*property_present)(const struct fwnode_handle___229 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___229 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___229 *, const char *, const char **, size_t);
	struct fwnode_handle___229 * (*get_parent)(const struct fwnode_handle___229 *);
	struct fwnode_handle___229 * (*get_next_child_node)(const struct fwnode_handle___229 *, struct fwnode_handle___229 *);
	struct fwnode_handle___229 * (*get_named_child_node)(const struct fwnode_handle___229 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___229 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___229 *);
	struct fwnode_handle___229 * (*graph_get_next_endpoint)(const struct fwnode_handle___229 *, struct fwnode_handle___229 *);
	struct fwnode_handle___229 * (*graph_get_remote_endpoint)(const struct fwnode_handle___229 *);
	struct fwnode_handle___229 * (*graph_get_port_parent)(struct fwnode_handle___229 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___229 *, struct fwnode_endpoint___229 *);
};

struct fwnode_endpoint___229 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___229 *local_fwnode;
};

struct fwnode_reference_args___229 {
	struct fwnode_handle___229 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___71;

struct pipe_buffer___71 {
	struct page___335 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___71 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___71 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___71 *, struct pipe_buffer___71 *);
	void (*release)(struct pipe_inode_info___71 *, struct pipe_buffer___71 *);
	int (*steal)(struct pipe_inode_info___71 *, struct pipe_buffer___71 *);
	union {
		bool (*get)(struct pipe_inode_info___71 *, struct pipe_buffer___71 *);
		struct {
			void (*get)(struct pipe_inode_info___71 *, struct pipe_buffer___71 *);
		} __UNIQUE_ID_rh_kabi_hide21;
		union {		};
	};
};

struct nf_bridge_info___38 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___38 = 0,
		BRNF_PROTO_8021Q___38 = 1,
		BRNF_PROTO_PPPOE___38 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___40 *physindev;
	struct net_device___40 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___38(struct sk_buff___40 **);

struct net_device_ops___38;

struct ethtool_ops___38;

struct l3mdev_ops___27;

struct xfrmdev_ops___38;

struct tlsdev_ops___38;

struct header_ops___38;

struct netdev_rx_queue___38;

struct mini_Qdisc___37;

struct netdev_queue___38;

struct Qdisc___37;

struct rtnl_link_ops___37;

struct dcbnl_rtnl_ops___38;

struct net_device___40 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___38 *netdev_ops;
	const struct ethtool_ops___38 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___27 *l3mdev_ops;
	const struct ndisc_ops___2 *ndisc_ops;
	const struct xfrmdev_ops___38 *xfrmdev_ops;
	const struct tlsdev_ops___38 *tlsdev_ops;
	const struct header_ops___38 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___320 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___2 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___38 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___37 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___38 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___37 *miniq_ingress;
	struct netdev_queue___38 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___38 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___37 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___37 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___38 = 0,
		NETREG_REGISTERED___38 = 1,
		NETREG_UNREGISTERING___38 = 2,
		NETREG_UNREGISTERED___38 = 3,
		NETREG_RELEASED___38 = 4,
		NETREG_DUMMY___38 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___38 = 0,
		RTNL_LINK_INITIALIZING___38 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___40 *);
	struct netpoll_info *npinfo;
	possible_net_t___39 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___300 dev;
	const struct attribute_group___298 *sysfs_groups[4];
	const struct attribute_group___298 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___37 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___38 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide35;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

typedef int (*key_restrict_link_func_t___310)(struct key___309 *, const struct key_type *, const union key_payload *, struct key___309 *);

struct key_restriction___309;

struct key___309 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___335 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___309 *restrict_link;
};

struct key_restriction___309 {
	key_restrict_link_func_t___310 check;
	struct key___309 *key;
	struct key_type *keytype;
};

struct cgroup_namespace___218 {
	refcount_t count;
	struct ns_common___9 ns;
	struct user_namespace___233 *user_ns;
	struct ucounts___233 *ucounts;
	struct css_set___218 *root_cset;
};

struct netlink_skb_parms___4 {
	struct scm_creds creds;
	__u32 portid;
	__u32 dst_group;
	__u32 flags;
	struct sock___28 *sk;
	bool nsid_is_set;
	int nsid;
};

struct netlink_kernel_cfg___2 {
	unsigned int groups;
	unsigned int flags;
	void (*input)(struct sk_buff___40 *);
	struct mutex *cb_mutex;
	int (*bind)(struct net___49 *, int);
	void (*unbind)(struct net___49 *, int);
	bool (*compare)(struct net___49 *, struct sock___28 *);
};

struct netlink_callback___39 {
	struct sk_buff___40 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___39 *);
	int (*dump)(struct sk_buff___40 *, struct netlink_callback___39 *);
	int (*done)(struct netlink_callback___39 *);
	void *data;
	struct module___272 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct ethtool_ops___38 {
	int (*get_settings)(struct net_device___40 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___40 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___40 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___40 *);
	void (*get_regs)(struct net_device___40 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___40 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___40 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___40 *);
	void (*set_msglevel)(struct net_device___40 *, u32);
	int (*nway_reset)(struct net_device___40 *);
	u32 (*get_link)(struct net_device___40 *);
	int (*get_eeprom_len)(struct net_device___40 *);
	int (*get_eeprom)(struct net_device___40 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___40 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___40 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___40 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___40 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___40 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___40 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___40 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___40 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___40 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___40 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___40 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___40 *);
	void (*complete)(struct net_device___40 *);
	u32 (*get_priv_flags)(struct net_device___40 *);
	int (*set_priv_flags)(struct net_device___40 *, u32);
	int (*get_sset_count)(struct net_device___40 *, int);
	int (*get_rxnfc)(struct net_device___40 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___40 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___40 *, struct ethtool_flash *);
	int (*reset)(struct net_device___40 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___40 *);
	u32 (*get_rxfh_indir_size)(struct net_device___40 *);
	int (*get_rxfh)(struct net_device___40 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___40 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___40 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___40 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___40 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___40 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___40 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___40 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___40 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___40 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___40 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___40 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___40 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___40 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___40 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___40 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___40 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___40 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___40 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___40 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___40 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___40 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	int (*get_fecparam)(struct net_device___40 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___40 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___40 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___40 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___40 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___38;

struct inet_frags___38 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___38 *, const void *);
	void (*destructor)(struct inet_frag_queue___38 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___38 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___40 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___40 *fragments_tail;
	struct sk_buff___40 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___38 *net;
	struct callback_head rcu;
};

struct fib_rule___27;

struct fib_lookup_arg___27;

struct fib_rules_ops___27 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___27 *, struct flowi *, int, struct fib_lookup_arg___27 *);
	bool (*suppress)(struct fib_rule___27 *, struct fib_lookup_arg___27 *);
	int (*match)(struct fib_rule___27 *, struct flowi *, int);
	int (*configure)(struct fib_rule___27 *, struct sk_buff___40 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___27 *);
	int (*compare)(struct fib_rule___27 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___27 *, struct sk_buff___40 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___27 *);
	void (*flush_cache)(struct fib_rules_ops___27 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___272 *owner;
	struct net___49 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___27 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___49 *);
	int (*fib_dump)(struct net___49 *, struct notifier_block *);
	struct module___272 *owner;
	struct callback_head rcu;
};

struct dst_entry___27 {
	struct net_device___40 *dev;
	struct dst_ops___48 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___40 *);
	int (*output)(struct net___49 *, struct sock___28 *, struct sk_buff___40 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___27;

struct neigh_parms___27;

struct neigh_ops___27;

struct neighbour___27 {
	struct neighbour___27 *next;
	struct neigh_table___27 *tbl;
	struct neigh_parms___27 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___38 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___27 *, struct sk_buff___40 *);
	const struct neigh_ops___27 *ops;
	struct callback_head rcu;
	struct net_device___40 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct ucounts___233 {
	struct hlist_node node;
	struct user_namespace___233 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_prog_aux___40;

struct bpf_prog___37 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___40 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

struct seq_operations___281 {
	void * (*start)(struct seq_file___282 *, loff_t *);
	void (*stop)(struct seq_file___282 *, void *);
	void * (*next)(struct seq_file___282 *, void *, loff_t *);
	int (*show)(struct seq_file___282 *, void *);
};

struct pernet_operations___39 {
	struct list_head list;
	int (*init)(struct net___49 *);
	void (*exit)(struct net___49 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___38 {
	int (*ieee_getets)(struct net_device___40 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___40 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___40 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___40 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___40 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___40 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___40 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___40 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___40 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___40 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___40 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___40 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___40 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___40 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___40 *);
	u8 (*setstate)(struct net_device___40 *, u8);
	void (*getpermhwaddr)(struct net_device___40 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___40 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___40 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___40 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___40 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___40 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___40 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___40 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___40 *, int, u8 *);
	void (*setpfccfg)(struct net_device___40 *, int, u8);
	void (*getpfccfg)(struct net_device___40 *, int, u8 *);
	u8 (*setall)(struct net_device___40 *);
	u8 (*getcap)(struct net_device___40 *, int, u8 *);
	int (*getnumtcs)(struct net_device___40 *, int, u8 *);
	int (*setnumtcs)(struct net_device___40 *, int, u8);
	u8 (*getpfcstate)(struct net_device___40 *);
	void (*setpfcstate)(struct net_device___40 *, u8);
	void (*getbcncfg)(struct net_device___40 *, int, u32 *);
	void (*setbcncfg)(struct net_device___40 *, int, u32);
	void (*getbcnrp)(struct net_device___40 *, int, u8 *);
	void (*setbcnrp)(struct net_device___40 *, int, u8);
	int (*setapp)(struct net_device___40 *, u8, u16, u8);
	int (*getapp)(struct net_device___40 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___40 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___40 *, int, u8);
	u8 (*getdcbx)(struct net_device___40 *);
	u8 (*setdcbx)(struct net_device___40 *, u8);
	int (*peer_getappinfo)(struct net_device___40 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___40 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___40 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___40 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___40 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___40 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct bpf_map___219;

struct bpf_map_ops___218 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___219 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___219 *, struct file___334 *);
	void (*map_free)(struct bpf_map___219 *);
	int (*map_get_next_key)(struct bpf_map___219 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___219 *);
	void * (*map_lookup_elem)(struct bpf_map___219 *, void *);
	int (*map_update_elem)(struct bpf_map___219 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___219 *, void *);
	int (*map_push_elem)(struct bpf_map___219 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___219 *, void *);
	int (*map_peek_elem)(struct bpf_map___219 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___219 *, struct file___334 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___219 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___219 *, void *, struct seq_file___282 *);
	int (*map_check_btf)(const struct bpf_map___219 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___219 {
	const struct bpf_map_ops___218 *ops;
	struct bpf_map___219 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___309 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___38;

struct bpf_map_dev_ops___38 {
	int (*map_get_next_key)(struct bpf_offloaded_map___38 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___38 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___38 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___38 *, void *);
};

struct bpf_offloaded_map___38 {
	struct bpf_map___219 map;
	struct net_device___40 *netdev;
	const struct bpf_map_dev_ops___38 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___37 {
	int (*test_run)(struct bpf_prog___37 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___37 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___37 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___37 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___37 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___37 *, u32 *);
};

struct bpf_prog_offload_ops___37 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___37 *);
	int (*translate)(struct bpf_prog___37 *);
	void (*destroy)(struct bpf_prog___37 *);
};

struct bpf_prog_offload___37 {
	struct bpf_prog___37 *prog;
	struct net_device___40 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___37 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___40 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___37 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___37 *ops;
	struct bpf_map___219 **used_maps;
	struct bpf_prog___37 *prog;
	struct user_struct___309 *user;
	u64 load_time;
	struct bpf_map___219 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___37 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___37 {
	struct bpf_prog___37 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___37 {
	struct callback_head rcu;
	struct bpf_prog_array_item___37 items[0];
};

struct cgroup_bpf___37 {
	struct bpf_prog_array___37 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___37 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___218;

typedef void (*kthread_work_func_t___218)(struct kthread_work___218 *);

struct kthread_worker___218;

struct kthread_work___218 {
	struct list_head node;
	kthread_work_func_t___218 func;
	struct kthread_worker___218 *worker;
	int canceling;
};

struct kthread_worker___218 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___335 *task;
	struct kthread_work___218 *current_work;
};

struct kthread_delayed_work___218 {
	struct kthread_work___218 work;
	struct timer_list timer;
};

struct psi_group___218 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___218 *poll_kworker;
	struct kthread_delayed_work___218 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___218;

struct cgroup_rstat_cpu___218;

struct cgroup___218 {
	struct cgroup_subsys_state___218 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___328 *kn;
	struct cgroup_file___218 procs_file;
	struct cgroup_file___218 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___218 *subsys[13];
	struct cgroup_root___218 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___218 *dom_cgrp;
	struct cgroup_rstat_cpu___218 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___37 bpf;
	atomic_t congestion_count;
	struct cgroup___218 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___218 psi;
	int ancestor_ids[0];
};

struct cftype___218;

struct cgroup_subsys___218 {
	struct cgroup_subsys_state___218 * (*css_alloc)(struct cgroup_subsys_state___218 *);
	int (*css_online)(struct cgroup_subsys_state___218 *);
	void (*css_offline)(struct cgroup_subsys_state___218 *);
	void (*css_released)(struct cgroup_subsys_state___218 *);
	void (*css_free)(struct cgroup_subsys_state___218 *);
	void (*css_reset)(struct cgroup_subsys_state___218 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___218 *, int);
	int (*css_extra_stat_show)(struct seq_file___282 *, struct cgroup_subsys_state___218 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___335 *);
	void (*cancel_fork)(struct task_struct___335 *);
	void (*fork)(struct task_struct___335 *);
	void (*exit)(struct task_struct___335 *);
	void (*free)(struct task_struct___335 *);
	void (*bind)(struct cgroup_subsys_state___218 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___218 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___218 *dfl_cftypes;
	struct cftype___218 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___218 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___218 *updated_children;
	struct cgroup___218 *updated_next;
};

struct cgroup_root___218 {
	struct kernfs_root___327 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___218 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___218 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___218 *ss;
	struct list_head node;
	struct kernfs_ops___327 *kf_ops;
	int (*open)(struct kernfs_open_file___327 *);
	void (*release)(struct kernfs_open_file___327 *);
	u64 (*read_u64)(struct cgroup_subsys_state___218 *, struct cftype___218 *);
	s64 (*read_s64)(struct cgroup_subsys_state___218 *, struct cftype___218 *);
	int (*seq_show)(struct seq_file___282 *, void *);
	void * (*seq_start)(struct seq_file___282 *, loff_t *);
	void * (*seq_next)(struct seq_file___282 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___282 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___218 *, struct cftype___218 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___218 *, struct cftype___218 *, s64);
	ssize_t (*write)(struct kernfs_open_file___327 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___327 *, struct poll_table_struct___203 *);
};

struct xdp_rxq_info___38 {
	struct net_device___40 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___38 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___40 *dev_rx;
};

struct header_ops___38 {
	int (*create)(struct sk_buff___40 *, struct net_device___40 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___40 *, unsigned char *);
	int (*cache)(const struct neighbour___27 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___40 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___38 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___38 *, int);
	int poll_owner;
	struct net_device___40 *dev;
	struct sk_buff___40 *gro_list;
	struct sk_buff___40 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___38 {
	struct net_device___40 *dev;
	struct Qdisc___37 *qdisc;
	struct Qdisc___37 *qdisc_sleeping;
	struct kobject___321 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___40 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___37 {
	struct sk_buff___40 *head;
	struct sk_buff___40 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___37;

struct Qdisc___37 {
	int (*enqueue)(struct sk_buff___40 *, struct Qdisc___37 *, struct sk_buff___40 **);
	struct sk_buff___40 * (*dequeue)(struct Qdisc___37 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___37 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___38 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___38 gso_skb;
	struct qdisc_skb_head___37 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___37 *next_sched;
	struct sk_buff_head___38 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___38 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___321 kobj;
	struct net_device___40 *dev;
	long: 64;
	struct xdp_rxq_info___38 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___38)(struct net_device___40 *, struct sk_buff___40 *, struct net_device___40 *);

struct netdev_bpf___38 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___37 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___37 *prog;
			const struct bpf_prog_offload_ops___37 *ops;
		} verifier;
		struct {
			struct bpf_prog___37 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___38 *offmap;
		};
		struct {
			struct xdp_umem *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___38 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___40 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___38 {
	int (*tls_dev_add)(struct net_device___40 *, struct sock___28 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___40 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___40 *, struct sock___28 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___38 {
	int (*ndo_init)(struct net_device___40 *);
	void (*ndo_uninit)(struct net_device___40 *);
	int (*ndo_open)(struct net_device___40 *);
	int (*ndo_stop)(struct net_device___40 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___40 *, struct net_device___40 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___40 *, struct net_device___40 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___40 *, struct sk_buff___40 *, struct net_device___40 *, select_queue_fallback_t___38);
	void (*ndo_change_rx_flags)(struct net_device___40 *, int);
	void (*ndo_set_rx_mode)(struct net_device___40 *);
	int (*ndo_set_mac_address)(struct net_device___40 *, void *);
	int (*ndo_validate_addr)(struct net_device___40 *);
	int (*ndo_do_ioctl)(struct net_device___40 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___40 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___40 *, int);
	int (*ndo_neigh_setup)(struct net_device___40 *, struct neigh_parms___27 *);
	void (*ndo_tx_timeout)(struct net_device___40 *);
	void (*ndo_get_stats64)(struct net_device___40 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___40 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___40 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___40 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___40 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___40 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___40 *);
	int (*ndo_netpoll_setup)(struct net_device___40 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___40 *);
	int (*ndo_set_vf_mac)(struct net_device___40 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___40 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___40 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___40 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___40 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___40 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___40 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___40 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___40 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___40 *, int, struct sk_buff___40 *);
	int (*ndo_set_vf_guid)(struct net_device___40 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___40 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___40 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___40 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___40 *, const struct sk_buff___40 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___40 *, struct net_device___40 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___40 *, struct net_device___40 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___40 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___40 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___40 *, struct neighbour___27 *);
	void (*ndo_neigh_destroy)(struct net_device___40 *, struct neighbour___27 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___40 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___40 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___40 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___40 *, struct netlink_callback___39 *, struct net_device___40 *, struct net_device___40 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___40 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___40 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___40 *, u32, u32, struct net_device___40 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___40 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___40 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___40 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___40 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___40 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___40 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___40 *, struct net_device___40 *);
	void (*ndo_dfwd_del_station)(struct net_device___40 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___40 *);
	int (*ndo_set_tx_maxrate)(struct net_device___40 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___40 *);
	int (*ndo_change_proto_down)(struct net_device___40 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___40 *, struct sk_buff___40 *);
	void (*ndo_set_rx_headroom)(struct net_device___40 *, int);
	int (*ndo_bpf)(struct net_device___40 *, struct netdev_bpf___38 *);
	int (*ndo_xdp_xmit)(struct net_device___40 *, int, struct xdp_frame___38 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___40 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___40 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___27 {
	possible_net_t___39 net;
	struct net_device___40 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___27 *);
	void (*neigh_cleanup)(struct neighbour___27 *);
	struct neigh_table___27 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___27 {
	u32 (*l3mdev_fib_table)(const struct net_device___40 *);
	struct sk_buff___40 * (*l3mdev_l3_rcv)(struct net_device___40 *, struct sk_buff___40 *, u16);
	struct sk_buff___40 * (*l3mdev_l3_out)(struct net_device___40 *, struct sock___28 *, struct sk_buff___40 *, u16);
	struct dst_entry___27 * (*l3mdev_link_scope_lookup)(const struct net_device___40 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct tcf_proto___37;

struct mini_Qdisc___37 {
	struct tcf_proto___37 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___37 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___40 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___49 *, struct net_device___40 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___40 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___40 *, struct list_head *);
	size_t (*get_size)(const struct net_device___40 *);
	int (*fill_info)(struct sk_buff___40 *, const struct net_device___40 *);
	size_t (*get_xstats_size)(const struct net_device___40 *);
	int (*fill_xstats)(struct sk_buff___40 *, const struct net_device___40 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___40 *, struct net_device___40 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___40 *, const struct net_device___40 *);
	int (*fill_slave_info)(struct sk_buff___40 *, const struct net_device___40 *, const struct net_device___40 *);
	struct net___49 * (*get_link_net)(const struct net_device___40 *);
	size_t (*get_linkxstats_size)(const struct net_device___40 *, int);
	int (*fill_linkxstats)(struct sk_buff___40 *, const struct net_device___40 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___38 {
	struct list_head poll_list;
	struct sk_buff_head___38 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___38 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___37 *output_queue;
	struct Qdisc___37 **output_queue_tailp;
	struct sk_buff___40 *completion_queue;
	struct sk_buff_head___38 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___38 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___38 input_pkt_queue;
	struct napi_struct___38 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bdi_writeback_congested___158 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___158 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___158 {
	struct bio___158 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___159 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___159 bip_inline_vecs[0];
};

struct bio_set___158 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___158 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___124 {
	struct mem_cgroup___124 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___124 {
	struct lruvec___334 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___124 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___124 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct gnet_dump___37 {
	spinlock_t *lock;
	struct sk_buff___40 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___37;

struct Qdisc_ops___37 {
	struct Qdisc_ops___37 *next;
	const struct Qdisc_class_ops___37 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___40 *, struct Qdisc___37 *, struct sk_buff___40 **);
	struct sk_buff___40 * (*dequeue)(struct Qdisc___37 *);
	struct sk_buff___40 * (*peek)(struct Qdisc___37 *);
	int (*init)(struct Qdisc___37 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___37 *);
	void (*destroy)(struct Qdisc___37 *);
	int (*change)(struct Qdisc___37 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___37 *);
	int (*change_tx_queue_len)(struct Qdisc___37 *, unsigned int);
	int (*dump)(struct Qdisc___37 *, struct sk_buff___40 *);
	int (*dump_stats)(struct Qdisc___37 *, struct gnet_dump___37 *);
	void (*ingress_block_set)(struct Qdisc___37 *, u32);
	void (*egress_block_set)(struct Qdisc___37 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___37 *);
	u32 (*egress_block_get)(struct Qdisc___37 *);
	struct module___272 *owner;
};

struct tcf_block___37;

struct Qdisc_class_ops___37 {
	unsigned int flags;
	struct netdev_queue___38 * (*select_queue)(struct Qdisc___37 *, struct tcmsg *);
	int (*graft)(struct Qdisc___37 *, long unsigned int, struct Qdisc___37 *, struct Qdisc___37 **, struct netlink_ext_ack *);
	struct Qdisc___37 * (*leaf)(struct Qdisc___37 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___37 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___37 *, u32);
	int (*change)(struct Qdisc___37 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___37 *, long unsigned int);
	void (*walk)(struct Qdisc___37 *, struct qdisc_walker *);
	struct tcf_block___37 * (*tcf_block)(struct Qdisc___37 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___37 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___37 *, long unsigned int);
	int (*dump)(struct Qdisc___37 *, long unsigned int, struct sk_buff___40 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___37 *, long unsigned int, struct gnet_dump___37 *);
};

struct tcf_chain___37;

struct tcf_block___37 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___49 *net;
	struct Qdisc___37 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___37 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___37;

struct tcf_proto_ops___37;

struct tcf_proto___37 {
	struct tcf_proto___37 *next;
	void *root;
	int (*classify)(struct sk_buff___40 *, const struct tcf_proto___37 *, struct tcf_result___37 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___37 *ops;
	struct tcf_chain___37 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___37 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___37 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___37 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___40 *, const struct tcf_proto___37 *, struct tcf_result___37 *);
	int (*init)(struct tcf_proto___37 *);
	void (*destroy)(struct tcf_proto___37 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___37 *, u32);
	void (*put)(struct tcf_proto___37 *, void *);
	int (*change)(struct net___49 *, struct sk_buff___40 *, struct tcf_proto___37 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___37 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___37 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___37 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___49 *, struct tcf_chain___37 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___49 *, struct tcf_proto___37 *, void *, struct sk_buff___40 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___40 *, struct net___49 *, void *);
	struct module___272 *owner;
	int flags;
};

struct tcf_chain___37 {
	struct mutex filter_chain_lock;
	struct tcf_proto___37 *filter_chain;
	struct list_head list;
	struct tcf_block___37 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___37 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___27 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___37 *prog;
};

struct bpf_redirect_info___37 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___219 *map;
	struct bpf_map___219 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___27;

struct neigh_hash_table___27;

struct neigh_table___27 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___40 *, __u32 *);
	bool (*key_eq)(const struct neighbour___27 *, const void *);
	int (*constructor)(struct neighbour___27 *);
	int (*pconstructor)(struct pneigh_entry___27 *);
	void (*pdestructor)(struct pneigh_entry___27 *);
	void (*proxy_redo)(struct sk_buff___40 *);
	char *id;
	struct neigh_parms___27 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___38 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___27 *nht;
	struct pneigh_entry___27 **phash_buckets;
};

struct neigh_ops___27 {
	int family;
	void (*solicit)(struct neighbour___27 *, struct sk_buff___40 *);
	void (*error_report)(struct neighbour___27 *, struct sk_buff___40 *);
	int (*output)(struct neighbour___27 *, struct sk_buff___40 *);
	int (*connected_output)(struct neighbour___27 *, struct sk_buff___40 *);
};

struct pneigh_entry___27 {
	struct pneigh_entry___27 *next;
	possible_net_t___39 net;
	struct net_device___40 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___27 {
	struct neighbour___27 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___27 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___27 *ctarget;
	struct net___49 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___27 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___27 *rule;
	u32 table;
	int flags;
};

struct proto___27 {
	void (*close)(struct sock___28 *, long int);
	int (*pre_connect)(struct sock___28 *, struct sockaddr *, int);
	int (*connect)(struct sock___28 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___28 *, int);
	struct sock___28 * (*accept)(struct sock___28 *, int, int *, bool);
	int (*ioctl)(struct sock___28 *, int, long unsigned int);
	int (*init)(struct sock___28 *);
	void (*destroy)(struct sock___28 *);
	void (*shutdown)(struct sock___28 *, int);
	int (*setsockopt)(struct sock___28 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___28 *, int, int, char *, int *);
	void (*keepalive)(struct sock___28 *, int);
	int (*sendmsg)(struct sock___28 *, struct msghdr___30 *, size_t);
	int (*recvmsg)(struct sock___28 *, struct msghdr___30 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___28 *, struct page___335 *, int, size_t, int);
	int (*bind)(struct sock___28 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___28 *, struct sk_buff___40 *);
	void (*release_cb)(struct sock___28 *);
	int (*hash)(struct sock___28 *);
	void (*unhash)(struct sock___28 *);
	void (*rehash)(struct sock___28 *);
	int (*get_port)(struct sock___28 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___28 *);
	bool (*stream_memory_read)(const struct sock___28 *);
	void (*enter_memory_pressure)(struct sock___28 *);
	void (*leave_memory_pressure)(struct sock___28 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___3 *rsk_prot;
	struct timewait_sock_ops___3 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___272 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___28 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct cn_queue_dev___2 {
	atomic_t refcnt;
	unsigned char name[32];
	struct list_head queue_list;
	spinlock_t queue_lock;
	struct sock___28 *nls;
};

struct cn_callback_entry___2 {
	struct list_head callback_entry;
	refcount_t refcnt;
	struct cn_queue_dev___2 *pdev;
	struct cn_callback_id id;
	void (*callback)(struct cn_msg *, struct netlink_skb_parms___4 *);
	u32 seq;
	u32 group;
};

struct cn_dev {
	struct cb_id id;
	u32 seq;
	u32 groups;
	struct sock___28 *nls;
	void (*input)(struct sk_buff___40 *);
	struct cn_queue_dev___2 *cbdev;
};

struct netlink_skb_parms___5 {
	struct scm_creds creds;
	__u32 portid;
	__u32 dst_group;
	__u32 flags;
	struct sock___16 *sk;
	bool nsid_is_set;
	int nsid;
};

enum proc_cn_mcast_op {
	PROC_CN_MCAST_LISTEN = 1,
	PROC_CN_MCAST_IGNORE = 2,
};

struct fork_proc_event {
	__kernel_pid_t parent_pid;
	__kernel_pid_t parent_tgid;
	__kernel_pid_t child_pid;
	__kernel_pid_t child_tgid;
};

struct exec_proc_event {
	__kernel_pid_t process_pid;
	__kernel_pid_t process_tgid;
};

struct id_proc_event {
	__kernel_pid_t process_pid;
	__kernel_pid_t process_tgid;
	union {
		__u32 ruid;
		__u32 rgid;
	} r;
	union {
		__u32 euid;
		__u32 egid;
	} e;
};

struct sid_proc_event {
	__kernel_pid_t process_pid;
	__kernel_pid_t process_tgid;
};

struct ptrace_proc_event {
	__kernel_pid_t process_pid;
	__kernel_pid_t process_tgid;
	__kernel_pid_t tracer_pid;
	__kernel_pid_t tracer_tgid;
};

struct comm_proc_event {
	__kernel_pid_t process_pid;
	__kernel_pid_t process_tgid;
	char comm[16];
};

struct coredump_proc_event {
	__kernel_pid_t process_pid;
	__kernel_pid_t process_tgid;
	__kernel_pid_t parent_pid;
	__kernel_pid_t parent_tgid;
};

struct exit_proc_event {
	__kernel_pid_t process_pid;
	__kernel_pid_t process_tgid;
	__u32 exit_code;
	__u32 exit_signal;
	__kernel_pid_t parent_pid;
	__kernel_pid_t parent_tgid;
};

struct proc_event {
	enum what what;
	__u32 cpu;
	__u64 timestamp_ns;
	union {
		struct {
			__u32 err;
		} ack;
		struct fork_proc_event fork;
		struct exec_proc_event exec;
		struct id_proc_event id;
		struct sid_proc_event sid;
		struct ptrace_proc_event ptrace;
		struct comm_proc_event comm;
		struct coredump_proc_event coredump;
		struct exit_proc_event exit;
	} event_data;
};

struct component_ops {
	int (*bind)(struct device___279 *, struct device___279 *, void *);
	void (*unbind)(struct device___279 *, struct device___279 *, void *);
};

struct component_master_ops {
	int (*bind)(struct device___279 *);
	void (*unbind)(struct device___279 *);
};

struct component;

struct component_match_array {
	void *data;
	int (*compare)(struct device___279 *, void *);
	int (*compare_typed)(struct device___279 *, int, void *);
	void (*release)(struct device___279 *, void *);
	struct component *component;
	bool duplicate;
};

struct master;

struct component {
	struct list_head node;
	struct master *master;
	bool bound;
	const struct component_ops *ops;
	int subcomponent;
	struct device___279 *dev;
};

struct component_match {
	size_t alloc;
	size_t num;
	struct component_match_array *compare;
};

struct master {
	struct list_head node;
	bool bound;
	const struct component_master_ops *ops;
	struct device___279 *dev;
	struct component_match *match;
	struct dentry___313 *dentry;
};

struct module___273;

struct file___335;

struct kiocb___335;

struct iov_iter___146;

struct vm_area_struct___336;

struct inode___335;

struct file_lock___335;

struct page___336;

struct pipe_inode_info___72;

struct seq_file___283;

struct file_operations___335 {
	struct module___273 *owner;
	loff_t (*llseek)(struct file___335 *, loff_t, int);
	ssize_t (*read)(struct file___335 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___335 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___335 *, struct iov_iter___146 *);
	ssize_t (*write_iter)(struct kiocb___335 *, struct iov_iter___146 *);
	int (*iopoll)(struct kiocb___335 *, bool);
	int (*iterate)(struct file___335 *, struct dir_context *);
	int (*iterate_shared)(struct file___335 *, struct dir_context *);
	__poll_t (*poll)(struct file___335 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___335 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___335 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___335 *, struct vm_area_struct___336 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___335 *, struct file___335 *);
	int (*flush)(struct file___335 *, fl_owner_t);
	int (*release)(struct inode___335 *, struct file___335 *);
	int (*fsync)(struct file___335 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___335 *, int);
	int (*lock)(struct file___335 *, int, struct file_lock___335 *);
	ssize_t (*sendpage)(struct file___335 *, struct page___336 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___335 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___335 *, int, struct file_lock___335 *);
	ssize_t (*splice_write)(struct pipe_inode_info___72 *, struct file___335 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___335 *, loff_t *, struct pipe_inode_info___72 *, size_t, unsigned int);
	int (*setlease)(struct file___335 *, long int, struct file_lock___335 **, void **);
	long int (*fallocate)(struct file___335 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___283 *, struct file___335 *);
	ssize_t (*copy_file_range)(struct file___335 *, loff_t, struct file___335 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___335 *, loff_t, struct file___335 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___335 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___335 {
	u64 seqnum;
	struct vm_area_struct___336 *vmas[4];
};

struct page_frag___335 {
	struct page___336 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___335;

struct cred___310;

struct nsproxy___263;

struct signal_struct___245;

struct css_set___219;

struct vm_struct___246;

struct task_struct___336 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___336 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___335 *mm;
	struct mm_struct___335 *active_mm;
	struct vmacache___335 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___336 *real_parent;
	struct task_struct___336 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___336 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___209 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___209 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___209 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___310 *ptracer_cred;
	const struct cred___310 *real_cred;
	const struct cred___310 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___263 *nsproxy;
	struct signal_struct___245 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___336 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___84 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___219 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___72 *splice_pipe;
	struct page_frag___335 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___336 *oom_reaper_list;
	struct vm_struct___246 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___134 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___336 *pgtable_t___335;

struct address_space___334;

struct dev_pagemap___323;

struct page___336 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___334 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___336 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___335 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___335 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___323 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___335;

struct lruvec___335 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___335 *pgdat;
};

struct zone___335 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___335 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___335 {
	struct zone___335 *zone;
	int zone_idx;
};

struct zonelist___335 {
	struct zoneref___335 _zonerefs[25];
};

struct pglist_data___335 {
	struct zone___335 node_zones[3];
	struct zonelist___335 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___336 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___336 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___335 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___336 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___336 *owner;
};

struct secondary_data___336 {
	void *stack;
	struct task_struct___336 *task;
	long int status;
};

struct blocking_notifier_head___335 {
	struct rw_semaphore___336 rwsem;
	struct notifier_block *head;
};

struct key___310;

struct ucounts___234;

struct user_namespace___234 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___234 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___9 ns;
	long unsigned int flags;
	struct key___310 *persistent_keyring_register;
	struct rw_semaphore___336 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___234 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_root___328;

struct kernfs_elem_dir___328 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___328 *root;
};

struct kernfs_node___329;

struct kernfs_syscall_ops___328;

struct kernfs_root___328 {
	struct kernfs_node___329 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___328 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___328 {
	struct kernfs_node___329 *target_kn;
};

struct kernfs_ops___328;

struct kernfs_elem_attr___328 {
	const struct kernfs_ops___328 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___329 *notify_next;
};

struct kernfs_node___329 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___329 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___328 dir;
		struct kernfs_elem_symlink___328 symlink;
		struct kernfs_elem_attr___328 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___328;

struct kernfs_ops___328 {
	int (*open)(struct kernfs_open_file___328 *);
	void (*release)(struct kernfs_open_file___328 *);
	int (*seq_show)(struct seq_file___283 *, void *);
	void * (*seq_start)(struct seq_file___283 *, loff_t *);
	void * (*seq_next)(struct seq_file___283 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___283 *, void *);
	ssize_t (*read)(struct kernfs_open_file___328 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___328 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___328 *, struct vm_area_struct___336 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___328 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___328 {
	int (*remount_fs)(struct kernfs_root___328 *, int *, char *);
	int (*show_options)(struct seq_file___283 *, struct kernfs_root___328 *);
	int (*mkdir)(struct kernfs_node___329 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___329 *);
	int (*rename)(struct kernfs_node___329 *, struct kernfs_node___329 *, const char *);
	int (*show_path)(struct seq_file___283 *, struct kernfs_node___329 *, struct kernfs_root___328 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___282;

struct seq_file___283 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___282 *op;
	int poll_event;
	const struct file___335 *file;
	void *private;
};

struct vm_operations_struct___323;

struct kernfs_open_file___328 {
	struct kernfs_node___329 *kn;
	struct file___335 *file;
	struct seq_file___283 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___323 *vm_ops;
};

struct dentry___334;

struct path___335 {
	struct vfsmount *mnt;
	struct dentry___334 *dentry;
};

struct file___335 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___335 f_path;
	struct inode___335 *f_inode;
	const struct file_operations___335 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___209 f_owner;
	const struct cred___310 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___334 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___323;

struct vm_operations_struct___323 {
	void (*open)(struct vm_area_struct___336 *);
	void (*close)(struct vm_area_struct___336 *);
	int (*split)(struct vm_area_struct___336 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___336 *);
	vm_fault_t (*fault)(struct vm_fault___323 *);
	vm_fault_t (*huge_fault)(struct vm_fault___323 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___323 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___336 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___323 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___323 *);
	int (*access)(struct vm_area_struct___336 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___336 *);
	int (*set_policy)(struct vm_area_struct___336 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___336 *, long unsigned int);
	struct page___336 * (*find_special_page)(struct vm_area_struct___336 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_area_struct___336 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___336 *vm_next;
	struct vm_area_struct___336 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___335 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___323 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___335 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___322;

struct bin_attribute___298;

struct attribute_group___299 {
	const char *name;
	umode_t (*is_visible)(struct kobject___322 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___322 *, struct bin_attribute___298 *, int);
	struct attribute **attrs;
	struct bin_attribute___298 **bin_attrs;
};

struct kset___321;

struct kobj_type___321;

struct kobject___322 {
	const char *name;
	struct list_head entry;
	struct kobject___322 *parent;
	struct kset___321 *kset;
	struct kobj_type___321 *ktype;
	struct kernfs_node___329 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___298 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___335 *, struct kobject___322 *, struct bin_attribute___298 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___335 *, struct kobject___322 *, struct bin_attribute___298 *, char *, loff_t, size_t);
	int (*mmap)(struct file___335 *, struct kobject___322 *, struct bin_attribute___298 *, struct vm_area_struct___336 *);
};

struct sysfs_ops___321 {
	ssize_t (*show)(struct kobject___322 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___322 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___321;

struct kset___321 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___322 kobj;
	const struct kset_uevent_ops___321 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___321 {
	void (*release)(struct kobject___322 *);
	const struct sysfs_ops___321 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___27 * (*child_ns_type)(struct kobject___322 *);
	const void * (*namespace)(struct kobject___322 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___321 {
	int (* const filter)(struct kset___321 *, struct kobject___322 *);
	const char * (* const name)(struct kset___321 *, struct kobject___322 *);
	int (* const uevent)(struct kset___321 *, struct kobject___322 *, struct kobj_uevent_env *);
};

struct kobj_attribute___313 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___322 *, struct kobj_attribute___313 *, char *);
	ssize_t (*store)(struct kobject___322 *, struct kobj_attribute___313 *, const char *, size_t);
};

struct device___301;

struct dev_pm_ops___301 {
	int (*prepare)(struct device___301 *);
	void (*complete)(struct device___301 *);
	int (*suspend)(struct device___301 *);
	int (*resume)(struct device___301 *);
	int (*freeze)(struct device___301 *);
	int (*thaw)(struct device___301 *);
	int (*poweroff)(struct device___301 *);
	int (*restore)(struct device___301 *);
	int (*suspend_late)(struct device___301 *);
	int (*resume_early)(struct device___301 *);
	int (*freeze_late)(struct device___301 *);
	int (*thaw_early)(struct device___301 *);
	int (*poweroff_late)(struct device___301 *);
	int (*restore_early)(struct device___301 *);
	int (*suspend_noirq)(struct device___301 *);
	int (*resume_noirq)(struct device___301 *);
	int (*freeze_noirq)(struct device___301 *);
	int (*thaw_noirq)(struct device___301 *);
	int (*poweroff_noirq)(struct device___301 *);
	int (*restore_noirq)(struct device___301 *);
	int (*runtime_suspend)(struct device___301 *);
	int (*runtime_resume)(struct device___301 *);
	int (*runtime_idle)(struct device___301 *);
};

struct dev_pm_qos___12;

struct dev_pm_info___301 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___3 *subsys_data;
	void (*set_latency_tolerance)(struct device___301 *, s32);
	struct dev_pm_qos___12 *qos;
};

struct device_private___2;

struct device_type___301;

struct bus_type___301;

struct device_driver___301;

struct dev_pm_domain___301;

struct dma_map_ops___100;

struct device_node___76;

struct fwnode_handle___230;

struct class___301;

struct device___301 {
	struct device___301 *parent;
	struct device_private___2 *p;
	struct kobject___322 kobj;
	const char *init_name;
	const struct device_type___301 *type;
	struct mutex mutex;
	struct bus_type___301 *bus;
	struct device_driver___301 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___301 power;
	struct dev_pm_domain___301 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___100 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___76 *of_node;
	struct fwnode_handle___230 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___301 *class;
	const struct attribute_group___299 **groups;
	void (*release)(struct device___301 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct wake_irq {
	struct device___301 *dev;
	unsigned int status;
	int irq;
	const char *name;
};

struct pm_qos_constraints___12 {
	struct plist_head list;
	s32 target_value;
	s32 default_value;
	s32 no_constraint_value;
	enum pm_qos_type type;
	struct blocking_notifier_head___335 *notifiers;
};

struct dev_pm_qos_request___12;

struct dev_pm_qos___12 {
	struct pm_qos_constraints___12 resume_latency;
	struct pm_qos_constraints___12 latency_tolerance;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___12 *resume_latency_req;
	struct dev_pm_qos_request___12 *latency_tolerance_req;
	struct dev_pm_qos_request___12 *flags_req;
};

struct dev_pm_domain___301 {
	struct dev_pm_ops___301 ops;
	void (*detach)(struct device___301 *, bool);
	int (*activate)(struct device___301 *);
	void (*sync)(struct device___301 *);
	void (*dismiss)(struct device___301 *);
};

enum dpm_order {
	DPM_ORDER_NONE = 0,
	DPM_ORDER_DEV_AFTER_PARENT = 1,
	DPM_ORDER_PARENT_BEFORE_DEV = 2,
	DPM_ORDER_DEV_LAST = 3,
};

struct user_struct___310 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___310 *uid_keyring;
	struct key___310 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___335;

struct mm_struct___335 {
	struct {
		struct vm_area_struct___336 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___335 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___336 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___335 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___336 *owner;
		struct user_namespace___234 *user_ns;
		struct file___335 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___335 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___310 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___310 *session_keyring;
	struct key___310 *process_keyring;
	struct key___310 *thread_keyring;
	struct key___310 *request_key_auth;
	void *security;
	struct user_struct___310 *user;
	struct user_namespace___234 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___50;

struct cgroup_namespace___219;

struct nsproxy___263 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net___50 *net_ns;
	struct cgroup_namespace___219 *cgroup_ns;
};

struct signal_struct___245 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___336 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___336 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___209 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___209 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___335 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___209 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___219;

struct cgroup___219;

struct css_set___219 {
	struct cgroup_subsys_state___219 *subsys[13];
	refcount_t refcount;
	struct css_set___219 *dom_cset;
	struct cgroup___219 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___219 *mg_src_cgrp;
	struct cgroup___219 *mg_dst_cgrp;
	struct css_set___219 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___334;

struct pipe_buffer___72;

struct pipe_inode_info___72 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___336 *tmp_page;
	struct fasync_struct___334 *fasync_readers;
	struct fasync_struct___334 *fasync_writers;
	struct pipe_buffer___72 *bufs;
	struct user_struct___310 *user;
};

struct vm_struct___246 {
	struct vm_struct___246 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___336 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___257 {
	struct task_struct___336 task;
	long unsigned int stack[8192];
};

struct subsys_private___2;

struct bus_type___301 {
	const char *name;
	const char *dev_name;
	struct device___301 *dev_root;
	const struct attribute_group___299 **bus_groups;
	const struct attribute_group___299 **dev_groups;
	const struct attribute_group___299 **drv_groups;
	int (*match)(struct device___301 *, struct device_driver___301 *);
	int (*uevent)(struct device___301 *, struct kobj_uevent_env *);
	int (*probe)(struct device___301 *);
	int (*remove)(struct device___301 *);
	void (*shutdown)(struct device___301 *);
	int (*online)(struct device___301 *);
	int (*offline)(struct device___301 *);
	int (*suspend)(struct device___301 *, pm_message_t);
	int (*resume)(struct device___301 *);
	int (*num_vf)(struct device___301 *);
	int (*dma_configure)(struct device___301 *);
	const struct dev_pm_ops___301 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private___2 *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct driver_private___2;

struct device_driver___301 {
	const char *name;
	struct bus_type___301 *bus;
	struct module___273 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___301 *);
	int (*remove)(struct device___301 *);
	void (*shutdown)(struct device___301 *);
	int (*suspend)(struct device___301 *, pm_message_t);
	int (*resume)(struct device___301 *);
	const struct attribute_group___299 **groups;
	const struct dev_pm_ops___301 *pm;
	void (*coredump)(struct device___301 *);
	struct driver_private___2 *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct subsys_private___2 {
	struct kset___321 subsys;
	struct kset___321 *devices_kset;
	struct list_head interfaces;
	struct mutex mutex;
	struct kset___321 *drivers_kset;
	struct klist klist_devices;
	struct klist klist_drivers;
	struct blocking_notifier_head___335 bus_notifier;
	unsigned int drivers_autoprobe: 1;
	struct bus_type___301 *bus;
	struct kset___321 glue_dirs;
	struct class___301 *class;
};

struct device_type___301 {
	const char *name;
	const struct attribute_group___299 **groups;
	int (*uevent)(struct device___301 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___301 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___301 *);
	const struct dev_pm_ops___301 *pm;
};

struct module_kobject___270 {
	struct kobject___322 kobj;
	struct module___273 *mod;
	struct kobject___322 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___270 {
	struct module___273 *mod;
	struct latch_tree_node node;
};

struct module_layout___270 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___270 mtn;
};

struct module_attribute___270;

struct kernel_param___270;

struct module___273 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___270 mkobj;
	struct module_attribute___270 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___322 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___270 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___270 core_layout;
	struct module_layout___270 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct driver_private___2 {
	struct kobject___322 kobj;
	struct klist klist_devices;
	struct klist_node knode_bus;
	struct module_kobject___270 *mkobj;
	struct device_driver___301 *driver;
};

struct class___301 {
	const char *name;
	struct module___273 *owner;
	const struct attribute_group___299 **class_groups;
	const struct attribute_group___299 **dev_groups;
	struct kobject___322 *dev_kobj;
	int (*dev_uevent)(struct device___301 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___301 *, umode_t *);
	void (*class_release)(struct class___301 *);
	void (*dev_release)(struct device___301 *);
	int (*shutdown_pre)(struct device___301 *);
	const struct kobj_ns_type_operations___27 *ns_type;
	const void * (*namespace)(struct device___301 *);
	const struct dev_pm_ops___301 *pm;
	struct subsys_private___2 *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct class_interface___2 {
	struct list_head node;
	struct class___301 *class;
	int (*add_dev)(struct device___301 *, struct class_interface___2 *);
	void (*remove_dev)(struct device___301 *, struct class_interface___2 *);
};

struct device_attribute___28 {
	struct attribute attr;
	ssize_t (*show)(struct device___301 *, struct device_attribute___28 *, char *);
	ssize_t (*store)(struct device___301 *, struct device_attribute___28 *, const char *, size_t);
};

struct dev_ext_attribute {
	struct device_attribute___28 attr;
	void *var;
};

typedef void (*dr_release_t___17)(struct device___301 *, void *);

enum device_link_state {
	DL_STATE_NONE = 4294967295,
	DL_STATE_DORMANT = 0,
	DL_STATE_AVAILABLE = 1,
	DL_STATE_CONSUMER_PROBE = 2,
	DL_STATE_ACTIVE = 3,
	DL_STATE_SUPPLIER_UNBIND = 4,
};

struct device_link {
	struct device___301 *supplier;
	struct list_head s_node;
	struct device___301 *consumer;
	struct list_head c_node;
	enum device_link_state status;
	u32 flags;
	bool rpm_active;
	struct kref kref;
	struct callback_head callback_head;
};

struct device_private___2 {
	struct klist klist_children;
	struct klist_node knode_parent;
	struct klist_node knode_driver;
	struct klist_node knode_bus;
	struct list_head deferred_probe;
	struct device___301 *device;
};

struct dma_map_ops___100 {
	void * (*alloc)(struct device___301 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___301 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___301 *, struct vm_area_struct___336 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___301 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___301 *, struct page___336 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___301 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___301 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___301 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___301 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___301 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___301 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___301 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___301 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___301 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___301 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___301 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___301 *, u64);
	u64 (*get_required_mask)(struct device___301 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___230;

struct fwnode_handle___230 {
	struct fwnode_handle___230 *secondary;
	const struct fwnode_operations___230 *ops;
};

struct property___72;

struct device_node___76 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___230 fwnode;
	struct property___72 *properties;
	struct property___72 *deadprops;
	struct device_node___76 *parent;
	struct device_node___76 *child;
	struct device_node___76 *sibling;
	struct kobject___322 kobj;
	long unsigned int _flags;
	void *data;
};

struct fwnode_reference_args___230;

struct fwnode_endpoint___230;

struct fwnode_operations___230 {
	struct fwnode_handle___230 * (*get)(struct fwnode_handle___230 *);
	void (*put)(struct fwnode_handle___230 *);
	bool (*device_is_available)(const struct fwnode_handle___230 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___230 *, const struct device___301 *);
	bool (*property_present)(const struct fwnode_handle___230 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___230 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___230 *, const char *, const char **, size_t);
	struct fwnode_handle___230 * (*get_parent)(const struct fwnode_handle___230 *);
	struct fwnode_handle___230 * (*get_next_child_node)(const struct fwnode_handle___230 *, struct fwnode_handle___230 *);
	struct fwnode_handle___230 * (*get_named_child_node)(const struct fwnode_handle___230 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___230 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___230 *);
	struct fwnode_handle___230 * (*graph_get_next_endpoint)(const struct fwnode_handle___230 *, struct fwnode_handle___230 *);
	struct fwnode_handle___230 * (*graph_get_remote_endpoint)(const struct fwnode_handle___230 *);
	struct fwnode_handle___230 * (*graph_get_port_parent)(struct fwnode_handle___230 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___230 *, struct fwnode_endpoint___230 *);
};

struct fwnode_endpoint___230 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___230 *local_fwnode;
};

struct fwnode_reference_args___230 {
	struct fwnode_handle___230 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct kernel_param_ops___270 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___270 *);
	int (*get)(char *, const struct kernel_param___270 *);
	void (*free)(void *);
};

struct kparam_array___270;

struct kernel_param___270 {
	const char *name;
	struct module___273 *mod;
	const struct kernel_param_ops___270 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___270 *arr;
	};
};

struct kparam_array___270 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___270 *ops;
	void *elem;
};

struct module_attribute___270 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___270 *, struct module_kobject___270 *, char *);
	ssize_t (*store)(struct module_attribute___270 *, struct module_kobject___270 *, const char *, size_t);
	void (*setup)(struct module___273 *, const char *);
	int (*test)(struct module___273 *);
	void (*free)(struct module___273 *);
};

struct property___72 {
	char *name;
	int length;
	void *value;
	struct property___72 *next;
	long unsigned int _flags;
	struct bin_attribute___298 attr;
};

struct node___194 {
	struct device___301 dev;
};

struct bio_vec___160 {
	struct page___336 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct hd_struct___83 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___301 __dev;
	struct kobject___322 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___83;

struct gendisk___83 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___83 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___83 *part_tbl;
	struct hd_struct___83 part0;
	const struct block_device_operations___13 *fops;
	struct request_queue___3 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___336 lookup_sem;
	struct kobject___322 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___322 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dentry_operations___334;

struct super_block___334;

struct dentry___334 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___334 *d_parent;
	struct qstr d_name;
	struct inode___335 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___334 *d_op;
	struct super_block___334 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___334;

struct address_space___334 {
	struct inode___335 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___336 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___334 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___334;

struct block_device___334;

struct inode___335 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___334 *i_op;
	struct super_block___334 *i_sb;
	struct address_space___334 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___336 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___335 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___334 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___72 *i_pipe;
		struct block_device___334 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___334 {
	int (*d_revalidate)(struct dentry___334 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___334 *, unsigned int);
	int (*d_hash)(const struct dentry___334 *, struct qstr *);
	int (*d_compare)(const struct dentry___334 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___334 *);
	int (*d_init)(struct dentry___334 *);
	void (*d_release)(struct dentry___334 *);
	void (*d_prune)(struct dentry___334 *);
	void (*d_iput)(struct dentry___334 *, struct inode___335 *);
	char * (*d_dname)(struct dentry___334 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___335 *);
	int (*d_manage)(const struct path___335 *, bool);
	struct dentry___334 * (*d_real)(struct dentry___334 *, const struct inode___335 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___334;

struct mem_dqinfo___334 {
	struct quota_format_type___334 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___334;

struct quota_info___334 {
	unsigned int flags;
	struct rw_semaphore___336 dqio_sem;
	struct inode___335 *files[3];
	struct mem_dqinfo___334 info[3];
	const struct quota_format_ops___334 *ops[3];
};

struct rcuwait___334 {
	struct task_struct___336 *task;
};

struct percpu_rw_semaphore___334 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___336 rw_sem;
	struct rcuwait___334 writer;
	int readers_block;
};

struct sb_writers___334 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___334 rw_sem[3];
};

struct file_system_type___334;

struct super_operations___334;

struct dquot_operations___334;

struct quotactl_ops___334;

struct super_block___334 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___334 *s_type;
	const struct super_operations___334 *s_op;
	const struct dquot_operations___334 *dq_op;
	const struct quotactl_ops___334 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___334 *s_root;
	struct rw_semaphore___336 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___334 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___334 s_dquot;
	struct sb_writers___334 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___334 *s_d_op;
	int cleancache_poolid;
	struct shrinker___124 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___234 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

typedef int (*dev_page_fault_t___323)(struct vm_area_struct___336 *, long unsigned int, const struct page___336 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___323)(struct page___336 *, void *);

struct dev_pagemap___323 {
	dev_page_fault_t___323 page_fault;
	dev_page_free_t___323 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___301 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___335 {
	struct task_struct___336 *task;
	struct core_thread___335 *next;
};

struct core_state___335 {
	atomic_t nr_threads;
	struct core_thread___335 dumper;
	struct completion startup;
};

struct vm_fault___323 {
	struct vm_area_struct___336 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___336 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___336 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___335 prealloc_pte;
};

struct kiocb___335 {
	struct file___335 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___335 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___334 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___335 *ia_file;
};

struct dquot___334 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___334 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___334 {
	int qf_fmt_id;
	const struct quota_format_ops___334 *qf_ops;
	struct module___273 *qf_owner;
	struct quota_format_type___334 *qf_next;
};

struct quota_format_ops___334 {
	int (*check_quota_file)(struct super_block___334 *, int);
	int (*read_file_info)(struct super_block___334 *, int);
	int (*write_file_info)(struct super_block___334 *, int);
	int (*free_file_info)(struct super_block___334 *, int);
	int (*read_dqblk)(struct dquot___334 *);
	int (*commit_dqblk)(struct dquot___334 *);
	int (*release_dqblk)(struct dquot___334 *);
	int (*get_next_id)(struct super_block___334 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___334 {
	int (*write_dquot)(struct dquot___334 *);
	struct dquot___334 * (*alloc_dquot)(struct super_block___334 *, int);
	void (*destroy_dquot)(struct dquot___334 *);
	int (*acquire_dquot)(struct dquot___334 *);
	int (*release_dquot)(struct dquot___334 *);
	int (*mark_dirty)(struct dquot___334 *);
	int (*write_info)(struct super_block___334 *, int);
	qsize_t * (*get_reserved_space)(struct inode___335 *);
	int (*get_projid)(struct inode___335 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___335 *, qsize_t *);
	int (*get_next_id)(struct super_block___334 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___334 {
	int (*quota_on)(struct super_block___334 *, int, int, const struct path___335 *);
	int (*quota_off)(struct super_block___334 *, int);
	int (*quota_enable)(struct super_block___334 *, unsigned int);
	int (*quota_disable)(struct super_block___334 *, unsigned int);
	int (*quota_sync)(struct super_block___334 *, int);
	int (*set_info)(struct super_block___334 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___334 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___334 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___334 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___334 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___334 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___334 {
	int (*writepage)(struct page___336 *, struct writeback_control___3 *);
	int (*readpage)(struct file___335 *, struct page___336 *);
	int (*writepages)(struct address_space___334 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___336 *);
	int (*readpages)(struct file___335 *, struct address_space___334 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___335 *, struct address_space___334 *, loff_t, unsigned int, unsigned int, struct page___336 **, void **);
	int (*write_end)(struct file___335 *, struct address_space___334 *, loff_t, unsigned int, unsigned int, struct page___336 *, void *);
	sector_t (*bmap)(struct address_space___334 *, sector_t);
	void (*invalidatepage)(struct page___336 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___336 *, gfp_t);
	void (*freepage)(struct page___336 *);
	ssize_t (*direct_IO)(struct kiocb___335 *, struct iov_iter___146 *);
	int (*migratepage)(struct address_space___334 *, struct page___336 *, struct page___336 *, enum migrate_mode);
	bool (*isolate_page)(struct page___336 *, isolate_mode_t);
	void (*putback_page)(struct page___336 *);
	int (*launder_page)(struct page___336 *);
	int (*is_partially_uptodate)(struct page___336 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___336 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___334 *, struct page___336 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___335 *, sector_t *);
	void (*swap_deactivate)(struct file___335 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct iov_iter___146 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___160 *bvec;
		struct pipe_inode_info___72 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___334 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___335 *bd_inode;
	struct super_block___334 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___334 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___83 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___83 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___334 {
	struct dentry___334 * (*lookup)(struct inode___335 *, struct dentry___334 *, unsigned int);
	const char * (*get_link)(struct dentry___334 *, struct inode___335 *, struct delayed_call *);
	int (*permission)(struct inode___335 *, int);
	struct posix_acl * (*get_acl)(struct inode___335 *, int);
	int (*readlink)(struct dentry___334 *, char *, int);
	int (*create)(struct inode___335 *, struct dentry___334 *, umode_t, bool);
	int (*link)(struct dentry___334 *, struct inode___335 *, struct dentry___334 *);
	int (*unlink)(struct inode___335 *, struct dentry___334 *);
	int (*symlink)(struct inode___335 *, struct dentry___334 *, const char *);
	int (*mkdir)(struct inode___335 *, struct dentry___334 *, umode_t);
	int (*rmdir)(struct inode___335 *, struct dentry___334 *);
	int (*mknod)(struct inode___335 *, struct dentry___334 *, umode_t, dev_t);
	int (*rename)(struct inode___335 *, struct dentry___334 *, struct inode___335 *, struct dentry___334 *, unsigned int);
	int (*setattr)(struct dentry___334 *, struct iattr___334 *);
	int (*getattr)(const struct path___335 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___334 *, char *, size_t);
	int (*fiemap)(struct inode___335 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___335 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___335 *, struct dentry___334 *, struct file___335 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___335 *, struct dentry___334 *, umode_t);
	int (*set_acl)(struct inode___335 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___334 {
	void (*fl_copy_lock)(struct file_lock___335 *, struct file_lock___335 *);
	void (*fl_release_private)(struct file_lock___335 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___334;

struct file_lock___335 {
	struct file_lock___335 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___335 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___334 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___334 *fl_ops;
	const struct lock_manager_operations___334 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___334 {
	int (*lm_compare_owner)(struct file_lock___335 *, struct file_lock___335 *);
	long unsigned int (*lm_owner_key)(struct file_lock___335 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___335 *);
	int (*lm_grant)(struct file_lock___335 *, int);
	bool (*lm_break)(struct file_lock___335 *);
	int (*lm_change)(struct file_lock___335 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___335 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___334 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___334 *fa_next;
	struct file___335 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___334 {
	const char *name;
	int fs_flags;
	struct dentry___334 * (*mount)(struct file_system_type___334 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___334 *);
	struct module___273 *owner;
	struct file_system_type___334 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___334 {
	struct inode___335 * (*alloc_inode)(struct super_block___334 *);
	void (*destroy_inode)(struct inode___335 *);
	void (*dirty_inode)(struct inode___335 *, int);
	int (*write_inode)(struct inode___335 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___335 *);
	void (*evict_inode)(struct inode___335 *);
	void (*put_super)(struct super_block___334 *);
	int (*sync_fs)(struct super_block___334 *, int);
	int (*freeze_super)(struct super_block___334 *);
	int (*freeze_fs)(struct super_block___334 *);
	int (*thaw_super)(struct super_block___334 *);
	int (*unfreeze_fs)(struct super_block___334 *);
	int (*statfs)(struct dentry___334 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___334 *, int *, char *);
	void (*umount_begin)(struct super_block___334 *);
	int (*show_options)(struct seq_file___283 *, struct dentry___334 *);
	int (*show_devname)(struct seq_file___283 *, struct dentry___334 *);
	int (*show_path)(struct seq_file___283 *, struct dentry___334 *);
	int (*show_stats)(struct seq_file___283 *, struct dentry___334 *);
	ssize_t (*quota_read)(struct super_block___334 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___334 *, int, const char *, size_t, loff_t);
	struct dquot___334 ** (*get_dquots)(struct inode___335 *);
	int (*bdev_try_to_free_page)(struct super_block___334 *, struct page___336 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___334 *, struct shrink_control___124 *);
	long int (*free_cached_objects)(struct super_block___334 *, struct shrink_control___124 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___83 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___83 *last_lookup;
	struct hd_struct___83 *part[0];
};

struct net_device___41;

struct nf_bridge_info___39;

struct sk_buff___41 {
	union {
		struct {
			struct sk_buff___41 *next;
			struct sk_buff___41 *prev;
			union {
				struct net_device___41 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___28 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___41 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___39 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___39;

struct netns_frags___39 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___39 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv4___39 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct sock *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock **tcp_sk;
	struct netns_frags___39 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct dst_ops___49 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___49 *);
	struct dst_entry___2 * (*check)(struct dst_entry___2 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___2 *);
	unsigned int (*mtu)(const struct dst_entry___2 *);
	u32 * (*cow_metrics)(struct dst_entry___2 *, long unsigned int);
	void (*destroy)(struct dst_entry___2 *);
	void (*ifdown)(struct dst_entry___2 *, struct net_device___41 *, int);
	struct dst_entry___2 * (*negative_advice)(struct dst_entry___2 *);
	void (*link_failure)(struct sk_buff___41 *);
	void (*update_pmtu)(struct dst_entry___2 *, struct sock *, struct sk_buff___41 *, u32);
	void (*redirect)(struct dst_entry___2 *, struct sock *, struct sk_buff___41 *);
	int (*local_out)(struct net___50 *, struct sock *, struct sk_buff___41 *);
	struct neighbour___2 * (*neigh_lookup)(const struct dst_entry___2 *, struct sk_buff___41 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___2 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___49 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___39 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___49 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct sock *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops *notifier_ops;
	struct fib_notifier_ops *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_nf_frag___39 {
	struct netns_frags___39 frags;
};

struct netns_xfrm___49 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___49 xfrm4_dst_ops;
	struct dst_ops___49 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct net___50 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___234 *user_ns;
	struct ucounts___234 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___9 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___41 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___39 ipv4;
	struct netns_ipv6___49 ipv6;
	struct netns_sctp___28 sctp;
	struct netns_nf nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___39 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock *nfnl;
	struct sock *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___49 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef void compound_page_dtor___323(struct page___336 *);

struct pipe_buf_operations___72;

struct pipe_buffer___72 {
	struct page___336 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___72 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___72 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___72 *, struct pipe_buffer___72 *);
	void (*release)(struct pipe_inode_info___72 *, struct pipe_buffer___72 *);
	int (*steal)(struct pipe_inode_info___72 *, struct pipe_buffer___72 *);
	union {
		bool (*get)(struct pipe_inode_info___72 *, struct pipe_buffer___72 *);
		struct {
			void (*get)(struct pipe_inode_info___72 *, struct pipe_buffer___72 *);
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
};

struct nf_bridge_info___39 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___39 = 0,
		BRNF_PROTO_8021Q___39 = 1,
		BRNF_PROTO_PPPOE___39 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___41 *physindev;
	struct net_device___41 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___39(struct sk_buff___41 **);

typedef struct {
	struct net___50 *net;
} possible_net_t___40;

struct net_device_ops___39;

struct ethtool_ops___39;

struct xfrmdev_ops___39;

struct tlsdev_ops___39;

struct header_ops___39;

struct netdev_rx_queue___39;

struct netdev_queue___39;

struct dcbnl_rtnl_ops___39;

struct net_device___41 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___39 *netdev_ops;
	const struct ethtool_ops___39 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___2 *l3mdev_ops;
	const struct ndisc_ops___2 *ndisc_ops;
	const struct xfrmdev_ops___39 *xfrmdev_ops;
	const struct tlsdev_ops___39 *tlsdev_ops;
	const struct header_ops___39 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___321 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___2 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___39 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___39 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___2 *miniq_ingress;
	struct netdev_queue___39 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___39 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___2 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___2 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___39 = 0,
		NETREG_REGISTERED___39 = 1,
		NETREG_UNREGISTERING___39 = 2,
		NETREG_UNREGISTERED___39 = 3,
		NETREG_RELEASED___39 = 4,
		NETREG_DUMMY___39 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___39 = 0,
		RTNL_LINK_INITIALIZING___39 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___41 *);
	struct netpoll_info *npinfo;
	possible_net_t___40 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___301 dev;
	const struct attribute_group___299 *sysfs_groups[4];
	const struct attribute_group___299 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___2 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___39 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide39;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct sk_buff_head___39 {
	struct sk_buff___41 *next;
	struct sk_buff___41 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct ethtool_ops___39 {
	int (*get_settings)(struct net_device___41 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___41 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___41 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___41 *);
	void (*get_regs)(struct net_device___41 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___41 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___41 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___41 *);
	void (*set_msglevel)(struct net_device___41 *, u32);
	int (*nway_reset)(struct net_device___41 *);
	u32 (*get_link)(struct net_device___41 *);
	int (*get_eeprom_len)(struct net_device___41 *);
	int (*get_eeprom)(struct net_device___41 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___41 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___41 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___41 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___41 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___41 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___41 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___41 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___41 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___41 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___41 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___41 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___41 *);
	void (*complete)(struct net_device___41 *);
	u32 (*get_priv_flags)(struct net_device___41 *);
	int (*set_priv_flags)(struct net_device___41 *, u32);
	int (*get_sset_count)(struct net_device___41 *, int);
	int (*get_rxnfc)(struct net_device___41 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___41 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___41 *, struct ethtool_flash *);
	int (*reset)(struct net_device___41 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___41 *);
	u32 (*get_rxfh_indir_size)(struct net_device___41 *);
	int (*get_rxfh)(struct net_device___41 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___41 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___41 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___41 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___41 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___41 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___41 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___41 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___41 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___41 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___41 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___41 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___41 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___41 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___41 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___41 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___41 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___41 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___41 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___41 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___41 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___41 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	int (*get_fecparam)(struct net_device___41 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___41 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___41 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___41 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___41 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___39;

struct inet_frags___39 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___39 *, const void *);
	void (*destructor)(struct inet_frag_queue___39 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___39 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___41 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___41 *fragments_tail;
	struct sk_buff___41 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___39 *net;
	struct callback_head rcu;
};

struct ucounts___234 {
	struct hlist_node node;
	struct user_namespace___234 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

typedef int (*key_restrict_link_func_t___311)(struct key___310 *, const struct key_type *, const union key_payload *, struct key___310 *);

struct key_restriction___310;

struct key___310 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___336 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___310 *restrict_link;
};

struct key_restriction___310 {
	key_restrict_link_func_t___311 check;
	struct key___310 *key;
	struct key_type *keytype;
};

struct seq_operations___282 {
	void * (*start)(struct seq_file___283 *, loff_t *);
	void (*stop)(struct seq_file___283 *, void *);
	void * (*next)(struct seq_file___283 *, void *, loff_t *);
	int (*show)(struct seq_file___283 *, void *);
};

struct pernet_operations___40 {
	struct list_head list;
	int (*init)(struct net___50 *);
	void (*exit)(struct net___50 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___39 {
	int (*ieee_getets)(struct net_device___41 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___41 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___41 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___41 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___41 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___41 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___41 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___41 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___41 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___41 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___41 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___41 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___41 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___41 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___41 *);
	u8 (*setstate)(struct net_device___41 *, u8);
	void (*getpermhwaddr)(struct net_device___41 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___41 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___41 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___41 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___41 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___41 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___41 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___41 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___41 *, int, u8 *);
	void (*setpfccfg)(struct net_device___41 *, int, u8);
	void (*getpfccfg)(struct net_device___41 *, int, u8 *);
	u8 (*setall)(struct net_device___41 *);
	u8 (*getcap)(struct net_device___41 *, int, u8 *);
	int (*getnumtcs)(struct net_device___41 *, int, u8 *);
	int (*setnumtcs)(struct net_device___41 *, int, u8);
	u8 (*getpfcstate)(struct net_device___41 *);
	void (*setpfcstate)(struct net_device___41 *, u8);
	void (*getbcncfg)(struct net_device___41 *, int, u32 *);
	void (*setbcncfg)(struct net_device___41 *, int, u32);
	void (*getbcnrp)(struct net_device___41 *, int, u8 *);
	void (*setbcnrp)(struct net_device___41 *, int, u8);
	int (*setapp)(struct net_device___41 *, u8, u16, u8);
	int (*getapp)(struct net_device___41 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___41 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___41 *, int, u8);
	u8 (*getdcbx)(struct net_device___41 *);
	u8 (*setdcbx)(struct net_device___41 *, u8);
	int (*peer_getappinfo)(struct net_device___41 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___41 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___41 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___41 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___41 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___41 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___219 {
	refcount_t count;
	struct ns_common___9 ns;
	struct user_namespace___234 *user_ns;
	struct ucounts___234 *ucounts;
	struct css_set___219 *root_cset;
};

struct bpf_map___220;

struct bpf_map_ops___219 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___220 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___220 *, struct file___335 *);
	void (*map_free)(struct bpf_map___220 *);
	int (*map_get_next_key)(struct bpf_map___220 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___220 *);
	void * (*map_lookup_elem)(struct bpf_map___220 *, void *);
	int (*map_update_elem)(struct bpf_map___220 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___220 *, void *);
	int (*map_push_elem)(struct bpf_map___220 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___220 *, void *);
	int (*map_peek_elem)(struct bpf_map___220 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___220 *, struct file___335 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___220 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___220 *, void *, struct seq_file___283 *);
	int (*map_check_btf)(const struct bpf_map___220 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___220 {
	const struct bpf_map_ops___219 *ops;
	struct bpf_map___220 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___310 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___39;

struct bpf_map_dev_ops___39 {
	int (*map_get_next_key)(struct bpf_offloaded_map___39 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___39 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___39 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___39 *, void *);
};

struct bpf_offloaded_map___39 {
	struct bpf_map___220 map;
	struct net_device___41 *netdev;
	const struct bpf_map_dev_ops___39 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___219;

typedef void (*kthread_work_func_t___219)(struct kthread_work___219 *);

struct kthread_worker___219;

struct kthread_work___219 {
	struct list_head node;
	kthread_work_func_t___219 func;
	struct kthread_worker___219 *worker;
	int canceling;
};

struct kthread_worker___219 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___336 *task;
	struct kthread_work___219 *current_work;
};

struct kthread_delayed_work___219 {
	struct kthread_work___219 work;
	struct timer_list timer;
};

struct psi_group___219 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___219 *poll_kworker;
	struct kthread_delayed_work___219 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___219 {
	struct kernfs_node___329 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___219;

struct cgroup_subsys_state___219 {
	struct cgroup___219 *cgroup;
	struct cgroup_subsys___219 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___219 *parent;
};

struct cgroup_root___219;

struct cgroup_rstat_cpu___219;

struct cgroup___219 {
	struct cgroup_subsys_state___219 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___329 *kn;
	struct cgroup_file___219 procs_file;
	struct cgroup_file___219 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___219 *subsys[13];
	struct cgroup_root___219 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___219 *dom_cgrp;
	struct cgroup_rstat_cpu___219 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___37 bpf;
	atomic_t congestion_count;
	struct cgroup___219 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___219 psi;
	int ancestor_ids[0];
};

struct cftype___219;

struct cgroup_subsys___219 {
	struct cgroup_subsys_state___219 * (*css_alloc)(struct cgroup_subsys_state___219 *);
	int (*css_online)(struct cgroup_subsys_state___219 *);
	void (*css_offline)(struct cgroup_subsys_state___219 *);
	void (*css_released)(struct cgroup_subsys_state___219 *);
	void (*css_free)(struct cgroup_subsys_state___219 *);
	void (*css_reset)(struct cgroup_subsys_state___219 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___219 *, int);
	int (*css_extra_stat_show)(struct seq_file___283 *, struct cgroup_subsys_state___219 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___336 *);
	void (*cancel_fork)(struct task_struct___336 *);
	void (*fork)(struct task_struct___336 *);
	void (*exit)(struct task_struct___336 *);
	void (*free)(struct task_struct___336 *);
	void (*bind)(struct cgroup_subsys_state___219 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___219 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___219 *dfl_cftypes;
	struct cftype___219 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___219 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___219 *updated_children;
	struct cgroup___219 *updated_next;
};

struct cgroup_root___219 {
	struct kernfs_root___328 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___219 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___219 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___219 *ss;
	struct list_head node;
	struct kernfs_ops___328 *kf_ops;
	int (*open)(struct kernfs_open_file___328 *);
	void (*release)(struct kernfs_open_file___328 *);
	u64 (*read_u64)(struct cgroup_subsys_state___219 *, struct cftype___219 *);
	s64 (*read_s64)(struct cgroup_subsys_state___219 *, struct cftype___219 *);
	int (*seq_show)(struct seq_file___283 *, void *);
	void * (*seq_start)(struct seq_file___283 *, loff_t *);
	void * (*seq_next)(struct seq_file___283 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___283 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___219 *, struct cftype___219 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___219 *, struct cftype___219 *, s64);
	ssize_t (*write)(struct kernfs_open_file___328 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___328 *, struct poll_table_struct___6 *);
};

struct xdp_rxq_info___39 {
	struct net_device___41 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___39 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___41 *dev_rx;
};

struct netlink_callback___40 {
	struct sk_buff___41 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___40 *);
	int (*dump)(struct sk_buff___41 *, struct netlink_callback___40 *);
	int (*done)(struct netlink_callback___40 *);
	void *data;
	struct module___273 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___39 {
	int (*create)(struct sk_buff___41 *, struct net_device___41 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___41 *, unsigned char *);
	int (*cache)(const struct neighbour___2 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___41 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___39 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___39 *, int);
	int poll_owner;
	struct net_device___41 *dev;
	struct sk_buff___41 *gro_list;
	struct sk_buff___41 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___39 {
	struct net_device___41 *dev;
	struct Qdisc___2 *qdisc;
	struct Qdisc___2 *qdisc_sleeping;
	struct kobject___322 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___41 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct netdev_rx_queue___39 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___322 kobj;
	struct net_device___41 *dev;
	long: 64;
	struct xdp_rxq_info___39 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___39)(struct net_device___41 *, struct sk_buff___41 *, struct net_device___41 *);

struct netdev_bpf___39 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___37 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___37 *prog;
			const struct bpf_prog_offload_ops___37 *ops;
		} verifier;
		struct {
			struct bpf_prog___37 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___39 *offmap;
		};
		struct {
			struct xdp_umem *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___39 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___41 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___39 {
	int (*tls_dev_add)(struct net_device___41 *, struct sock *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___41 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___41 *, struct sock *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide35;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___39 {
	int (*ndo_init)(struct net_device___41 *);
	void (*ndo_uninit)(struct net_device___41 *);
	int (*ndo_open)(struct net_device___41 *);
	int (*ndo_stop)(struct net_device___41 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___41 *, struct net_device___41 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___41 *, struct net_device___41 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___41 *, struct sk_buff___41 *, struct net_device___41 *, select_queue_fallback_t___39);
	void (*ndo_change_rx_flags)(struct net_device___41 *, int);
	void (*ndo_set_rx_mode)(struct net_device___41 *);
	int (*ndo_set_mac_address)(struct net_device___41 *, void *);
	int (*ndo_validate_addr)(struct net_device___41 *);
	int (*ndo_do_ioctl)(struct net_device___41 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___41 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___41 *, int);
	int (*ndo_neigh_setup)(struct net_device___41 *, struct neigh_parms___3 *);
	void (*ndo_tx_timeout)(struct net_device___41 *);
	void (*ndo_get_stats64)(struct net_device___41 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___41 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___41 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___41 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___41 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___41 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___41 *);
	int (*ndo_netpoll_setup)(struct net_device___41 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___41 *);
	int (*ndo_set_vf_mac)(struct net_device___41 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___41 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___41 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___41 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___41 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___41 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___41 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___41 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___41 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___41 *, int, struct sk_buff___41 *);
	int (*ndo_set_vf_guid)(struct net_device___41 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___41 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___41 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___41 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___41 *, const struct sk_buff___41 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___41 *, struct net_device___41 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___41 *, struct net_device___41 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___41 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___41 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___41 *, struct neighbour___2 *);
	void (*ndo_neigh_destroy)(struct net_device___41 *, struct neighbour___2 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___41 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___41 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide36;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___41 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___41 *, struct netlink_callback___40 *, struct net_device___41 *, struct net_device___41 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___41 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___41 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide37;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___41 *, u32, u32, struct net_device___41 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___41 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___41 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___41 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___41 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___41 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___41 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___41 *, struct net_device___41 *);
	void (*ndo_dfwd_del_station)(struct net_device___41 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___41 *);
	int (*ndo_set_tx_maxrate)(struct net_device___41 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___41 *);
	int (*ndo_change_proto_down)(struct net_device___41 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___41 *, struct sk_buff___41 *);
	void (*ndo_set_rx_headroom)(struct net_device___41 *, int);
	int (*ndo_bpf)(struct net_device___41 *, struct netdev_bpf___39 *);
	int (*ndo_xdp_xmit)(struct net_device___41 *, int, struct xdp_frame___39 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___41 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___41 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide38;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct softnet_data___39 {
	struct list_head poll_list;
	struct sk_buff_head___39 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___39 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___2 *output_queue;
	struct Qdisc___2 **output_queue_tailp;
	struct sk_buff___41 *completion_queue;
	struct sk_buff_head___39 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___39 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___39 input_pkt_queue;
	struct napi_struct___39 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_qos_request___12 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___301 *dev;
};

union device_attr_group_devres {
	const struct attribute_group___299 *group;
	const struct attribute_group___299 **groups;
};

struct class_dir {
	struct kobject___322 kobj;
	struct class___301 *class;
};

struct root_device {
	struct device___301 dev;
	struct module___273 *owner;
};

struct bus_attribute___3 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___301 *, char *);
	ssize_t (*store)(struct bus_type___301 *, const char *, size_t);
};

struct subsys_dev_iter {
	struct klist_iter ki;
	const struct device_type___301 *type;
};

struct driver_attribute___2 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___301 *, char *);
	ssize_t (*store)(struct device_driver___301 *, const char *, size_t);
};

struct subsys_interface {
	const char *name;
	struct bus_type___301 *subsys;
	struct list_head node;
	int (*add_dev)(struct device___301 *, struct subsys_interface *);
	void (*remove_dev)(struct device___301 *, struct subsys_interface *);
};

struct module___274;

struct file___336;

struct kiocb___336;

struct vm_area_struct___337;

struct inode___336;

struct file_lock___336;

struct page___337;

struct seq_file___284;

struct file_operations___336 {
	struct module___274 *owner;
	loff_t (*llseek)(struct file___336 *, loff_t, int);
	ssize_t (*read)(struct file___336 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___336 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___336 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___336 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___336 *, bool);
	int (*iterate)(struct file___336 *, struct dir_context *);
	int (*iterate_shared)(struct file___336 *, struct dir_context *);
	__poll_t (*poll)(struct file___336 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___336 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___336 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___336 *, struct vm_area_struct___337 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___336 *, struct file___336 *);
	int (*flush)(struct file___336 *, fl_owner_t);
	int (*release)(struct inode___336 *, struct file___336 *);
	int (*fsync)(struct file___336 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___336 *, int);
	int (*lock)(struct file___336 *, int, struct file_lock___336 *);
	ssize_t (*sendpage)(struct file___336 *, struct page___337 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___336 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___336 *, int, struct file_lock___336 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___336 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___336 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___336 *, long int, struct file_lock___336 **, void **);
	long int (*fallocate)(struct file___336 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___284 *, struct file___336 *);
	ssize_t (*copy_file_range)(struct file___336 *, loff_t, struct file___336 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___336 *, loff_t, struct file___336 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___336 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___336 {
	u64 seqnum;
	struct vm_area_struct___337 *vmas[4];
};

struct page_frag___336 {
	struct page___337 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___336;

struct cred___311;

struct vm_struct___247;

struct task_struct___337 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___337 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___336 *mm;
	struct mm_struct___336 *active_mm;
	struct vmacache___336 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___337 *real_parent;
	struct task_struct___337 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___337 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___209 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___209 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___209 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___311 *ptracer_cred;
	const struct cred___311 *real_cred;
	const struct cred___311 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___337 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___84 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___336 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___337 *oom_reaper_list;
	struct vm_struct___247 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___134 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___337 *pgtable_t___336;

struct address_space___335;

struct dev_pagemap___324;

struct page___337 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___335 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___337 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___336 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___336 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___324 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___336;

struct lruvec___336 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___336 *pgdat;
};

struct zone___336 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___336 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___336 {
	struct zone___336 *zone;
	int zone_idx;
};

struct zonelist___336 {
	struct zoneref___336 _zonerefs[25];
};

struct pglist_data___336 {
	struct zone___336 node_zones[3];
	struct zonelist___336 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___337 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___337 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___336 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___337 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___337 *owner;
};

struct secondary_data___337 {
	void *stack;
	struct task_struct___337 *task;
	long int status;
};

struct blocking_notifier_head___336 {
	struct rw_semaphore___337 rwsem;
	struct notifier_block *head;
};

struct kernfs_root___329;

struct kernfs_elem_dir___329 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___329 *root;
};

struct kernfs_node___330;

struct kernfs_syscall_ops___329;

struct kernfs_root___329 {
	struct kernfs_node___330 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___329 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___329 {
	struct kernfs_node___330 *target_kn;
};

struct kernfs_ops___329;

struct kernfs_elem_attr___329 {
	const struct kernfs_ops___329 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___330 *notify_next;
};

struct kernfs_node___330 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___330 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___329 dir;
		struct kernfs_elem_symlink___329 symlink;
		struct kernfs_elem_attr___329 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___329;

struct kernfs_ops___329 {
	int (*open)(struct kernfs_open_file___329 *);
	void (*release)(struct kernfs_open_file___329 *);
	int (*seq_show)(struct seq_file___284 *, void *);
	void * (*seq_start)(struct seq_file___284 *, loff_t *);
	void * (*seq_next)(struct seq_file___284 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___284 *, void *);
	ssize_t (*read)(struct kernfs_open_file___329 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___329 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___329 *, struct vm_area_struct___337 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___329 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___329 {
	int (*remount_fs)(struct kernfs_root___329 *, int *, char *);
	int (*show_options)(struct seq_file___284 *, struct kernfs_root___329 *);
	int (*mkdir)(struct kernfs_node___330 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___330 *);
	int (*rename)(struct kernfs_node___330 *, struct kernfs_node___330 *, const char *);
	int (*show_path)(struct seq_file___284 *, struct kernfs_node___330 *, struct kernfs_root___329 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___283;

struct seq_file___284 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___283 *op;
	int poll_event;
	const struct file___336 *file;
	void *private;
};

struct vm_operations_struct___324;

struct kernfs_open_file___329 {
	struct kernfs_node___330 *kn;
	struct file___336 *file;
	struct seq_file___284 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___324 *vm_ops;
};

struct dentry___335;

struct path___336 {
	struct vfsmount *mnt;
	struct dentry___335 *dentry;
};

struct file___336 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___336 f_path;
	struct inode___336 *f_inode;
	const struct file_operations___336 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___209 f_owner;
	const struct cred___311 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___335 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___324;

struct vm_operations_struct___324 {
	void (*open)(struct vm_area_struct___337 *);
	void (*close)(struct vm_area_struct___337 *);
	int (*split)(struct vm_area_struct___337 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___337 *);
	vm_fault_t (*fault)(struct vm_fault___324 *);
	vm_fault_t (*huge_fault)(struct vm_fault___324 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___324 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___337 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___324 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___324 *);
	int (*access)(struct vm_area_struct___337 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___337 *);
	int (*set_policy)(struct vm_area_struct___337 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___337 *, long unsigned int);
	struct page___337 * (*find_special_page)(struct vm_area_struct___337 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_area_struct___337 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___337 *vm_next;
	struct vm_area_struct___337 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___336 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___324 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___336 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___323;

struct bin_attribute___299;

struct attribute_group___300 {
	const char *name;
	umode_t (*is_visible)(struct kobject___323 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___323 *, struct bin_attribute___299 *, int);
	struct attribute **attrs;
	struct bin_attribute___299 **bin_attrs;
};

struct kset___322;

struct kobj_type___322;

struct kobject___323 {
	const char *name;
	struct list_head entry;
	struct kobject___323 *parent;
	struct kset___322 *kset;
	struct kobj_type___322 *ktype;
	struct kernfs_node___330 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___299 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___336 *, struct kobject___323 *, struct bin_attribute___299 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___336 *, struct kobject___323 *, struct bin_attribute___299 *, char *, loff_t, size_t);
	int (*mmap)(struct file___336 *, struct kobject___323 *, struct bin_attribute___299 *, struct vm_area_struct___337 *);
};

struct sysfs_ops___322 {
	ssize_t (*show)(struct kobject___323 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___323 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___322;

struct kset___322 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___323 kobj;
	const struct kset_uevent_ops___322 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___322 {
	void (*release)(struct kobject___323 *);
	const struct sysfs_ops___322 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___27 * (*child_ns_type)(struct kobject___323 *);
	const void * (*namespace)(struct kobject___323 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___322 {
	int (* const filter)(struct kset___322 *, struct kobject___323 *);
	const char * (* const name)(struct kset___322 *, struct kobject___323 *);
	int (* const uevent)(struct kset___322 *, struct kobject___323 *, struct kobj_uevent_env *);
};

struct kobj_attribute___314 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___323 *, struct kobj_attribute___314 *, char *);
	ssize_t (*store)(struct kobject___323 *, struct kobj_attribute___314 *, const char *, size_t);
};

struct device___302;

struct dev_pm_ops___302 {
	int (*prepare)(struct device___302 *);
	void (*complete)(struct device___302 *);
	int (*suspend)(struct device___302 *);
	int (*resume)(struct device___302 *);
	int (*freeze)(struct device___302 *);
	int (*thaw)(struct device___302 *);
	int (*poweroff)(struct device___302 *);
	int (*restore)(struct device___302 *);
	int (*suspend_late)(struct device___302 *);
	int (*resume_early)(struct device___302 *);
	int (*freeze_late)(struct device___302 *);
	int (*thaw_early)(struct device___302 *);
	int (*poweroff_late)(struct device___302 *);
	int (*restore_early)(struct device___302 *);
	int (*suspend_noirq)(struct device___302 *);
	int (*resume_noirq)(struct device___302 *);
	int (*freeze_noirq)(struct device___302 *);
	int (*thaw_noirq)(struct device___302 *);
	int (*poweroff_noirq)(struct device___302 *);
	int (*restore_noirq)(struct device___302 *);
	int (*runtime_suspend)(struct device___302 *);
	int (*runtime_resume)(struct device___302 *);
	int (*runtime_idle)(struct device___302 *);
};

struct wakeup_source___2;

struct wake_irq___2;

struct dev_pm_qos___13;

struct dev_pm_info___302 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___2 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq___2 *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___3 *subsys_data;
	void (*set_latency_tolerance)(struct device___302 *, s32);
	struct dev_pm_qos___13 *qos;
};

struct device_private___3;

struct device_type___302;

struct bus_type___302;

struct device_driver___302;

struct dev_pm_domain___302;

struct dma_map_ops___101;

struct fwnode_handle___231;

struct class___302;

struct device___302 {
	struct device___302 *parent;
	struct device_private___3 *p;
	struct kobject___323 kobj;
	const char *init_name;
	const struct device_type___302 *type;
	struct mutex mutex;
	struct bus_type___302 *bus;
	struct device_driver___302 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___302 power;
	struct dev_pm_domain___302 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info___4 *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___101 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___231 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___302 *class;
	const struct attribute_group___300 **groups;
	void (*release)(struct device___302 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct wakeup_source___2 {
	const char *name;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq___2 *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	bool active: 1;
	bool autosleep_enabled: 1;
};

struct wake_irq___2 {
	struct device___302 *dev;
	unsigned int status;
	int irq;
	const char *name;
};

struct pm_qos_constraints___13 {
	struct plist_head list;
	s32 target_value;
	s32 default_value;
	s32 no_constraint_value;
	enum pm_qos_type type;
	struct blocking_notifier_head___336 *notifiers;
};

struct dev_pm_qos_request___13;

struct dev_pm_qos___13 {
	struct pm_qos_constraints___13 resume_latency;
	struct pm_qos_constraints___13 latency_tolerance;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___13 *resume_latency_req;
	struct dev_pm_qos_request___13 *latency_tolerance_req;
	struct dev_pm_qos_request___13 *flags_req;
};

struct dev_pm_domain___302 {
	struct dev_pm_ops___302 ops;
	void (*detach)(struct device___302 *, bool);
	int (*activate)(struct device___302 *);
	void (*sync)(struct device___302 *);
	void (*dismiss)(struct device___302 *);
};

struct key___311;

struct user_struct___311 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___311 *uid_keyring;
	struct key___311 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___336;

struct mm_struct___336 {
	struct {
		struct vm_area_struct___337 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___336 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___337 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___336 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___337 *owner;
		struct user_namespace___3 *user_ns;
		struct file___336 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___336 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___311 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___311 *session_keyring;
	struct key___311 *process_keyring;
	struct key___311 *thread_keyring;
	struct key___311 *request_key_auth;
	void *security;
	struct user_struct___311 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct vm_struct___247 {
	struct vm_struct___247 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___337 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct subsys_private___3;

struct bus_type___302 {
	const char *name;
	const char *dev_name;
	struct device___302 *dev_root;
	const struct attribute_group___300 **bus_groups;
	const struct attribute_group___300 **dev_groups;
	const struct attribute_group___300 **drv_groups;
	int (*match)(struct device___302 *, struct device_driver___302 *);
	int (*uevent)(struct device___302 *, struct kobj_uevent_env *);
	int (*probe)(struct device___302 *);
	int (*remove)(struct device___302 *);
	void (*shutdown)(struct device___302 *);
	int (*online)(struct device___302 *);
	int (*offline)(struct device___302 *);
	int (*suspend)(struct device___302 *, pm_message_t);
	int (*resume)(struct device___302 *);
	int (*num_vf)(struct device___302 *);
	int (*dma_configure)(struct device___302 *);
	const struct dev_pm_ops___302 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private___3 *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct driver_private___3;

struct device_driver___302 {
	const char *name;
	struct bus_type___302 *bus;
	struct module___274 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___302 *);
	int (*remove)(struct device___302 *);
	void (*shutdown)(struct device___302 *);
	int (*suspend)(struct device___302 *, pm_message_t);
	int (*resume)(struct device___302 *);
	const struct attribute_group___300 **groups;
	const struct dev_pm_ops___302 *pm;
	void (*coredump)(struct device___302 *);
	struct driver_private___3 *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct subsys_private___3 {
	struct kset___322 subsys;
	struct kset___322 *devices_kset;
	struct list_head interfaces;
	struct mutex mutex;
	struct kset___322 *drivers_kset;
	struct klist klist_devices;
	struct klist klist_drivers;
	struct blocking_notifier_head___336 bus_notifier;
	unsigned int drivers_autoprobe: 1;
	struct bus_type___302 *bus;
	struct kset___322 glue_dirs;
	struct class___302 *class;
};

struct device_type___302 {
	const char *name;
	const struct attribute_group___300 **groups;
	int (*uevent)(struct device___302 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___302 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___302 *);
	const struct dev_pm_ops___302 *pm;
};

struct module_kobject___271 {
	struct kobject___323 kobj;
	struct module___274 *mod;
	struct kobject___323 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___271 {
	struct module___274 *mod;
	struct latch_tree_node node;
};

struct module_layout___271 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___271 mtn;
};

struct module_attribute___271;

struct kernel_param___271;

struct module___274 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___271 mkobj;
	struct module_attribute___271 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___323 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___271 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___271 core_layout;
	struct module_layout___271 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct driver_private___3 {
	struct kobject___323 kobj;
	struct klist klist_devices;
	struct klist_node knode_bus;
	struct module_kobject___271 *mkobj;
	struct device_driver___302 *driver;
};

struct class___302 {
	const char *name;
	struct module___274 *owner;
	const struct attribute_group___300 **class_groups;
	const struct attribute_group___300 **dev_groups;
	struct kobject___323 *dev_kobj;
	int (*dev_uevent)(struct device___302 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___302 *, umode_t *);
	void (*class_release)(struct class___302 *);
	void (*dev_release)(struct device___302 *);
	int (*shutdown_pre)(struct device___302 *);
	const struct kobj_ns_type_operations___27 *ns_type;
	const void * (*namespace)(struct device___302 *);
	const struct dev_pm_ops___302 *pm;
	struct subsys_private___3 *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct device_attribute___29 {
	struct attribute attr;
	ssize_t (*show)(struct device___302 *, struct device_attribute___29 *, char *);
	ssize_t (*store)(struct device___302 *, struct device_attribute___29 *, const char *, size_t);
};

struct device_private___3 {
	struct klist klist_children;
	struct klist_node knode_parent;
	struct klist_node knode_driver;
	struct klist_node knode_bus;
	struct list_head deferred_probe;
	struct device___302 *device;
};

struct dma_map_ops___101 {
	void * (*alloc)(struct device___302 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___302 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___302 *, struct vm_area_struct___337 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___302 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___302 *, struct page___337 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___302 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___302 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___302 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___302 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___302 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___302 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___302 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___302 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___302 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___302 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___302 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___302 *, u64);
	u64 (*get_required_mask)(struct device___302 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___231;

struct fwnode_handle___231 {
	struct fwnode_handle___231 *secondary;
	const struct fwnode_operations___231 *ops;
};

struct address_space_operations___335;

struct address_space___335 {
	struct inode___336 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___337 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___335 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___324)(struct vm_area_struct___337 *, long unsigned int, const struct page___337 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___324)(struct page___337 *, void *);

struct dev_pagemap___324 {
	dev_page_fault_t___324 page_fault;
	dev_page_free_t___324 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___302 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___336 {
	struct task_struct___337 *task;
	struct core_thread___336 *next;
};

struct core_state___336 {
	atomic_t nr_threads;
	struct core_thread___336 dumper;
	struct completion startup;
};

struct vm_fault___324 {
	struct vm_area_struct___337 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___337 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___337 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___336 prealloc_pte;
};

struct dentry_operations___335;

struct super_block___335;

struct dentry___335 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___335 *d_parent;
	struct qstr d_name;
	struct inode___336 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___335 *d_op;
	struct super_block___335 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___335;

struct block_device___335;

struct inode___336 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___335 *i_op;
	struct super_block___335 *i_sb;
	struct address_space___335 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___337 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___336 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___335 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___335 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___335 {
	int (*d_revalidate)(struct dentry___335 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___335 *, unsigned int);
	int (*d_hash)(const struct dentry___335 *, struct qstr *);
	int (*d_compare)(const struct dentry___335 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___335 *);
	int (*d_init)(struct dentry___335 *);
	void (*d_release)(struct dentry___335 *);
	void (*d_prune)(struct dentry___335 *);
	void (*d_iput)(struct dentry___335 *, struct inode___336 *);
	char * (*d_dname)(struct dentry___335 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___336 *);
	int (*d_manage)(const struct path___336 *, bool);
	struct dentry___335 * (*d_real)(struct dentry___335 *, const struct inode___336 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___335;

struct mem_dqinfo___335 {
	struct quota_format_type___335 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___335;

struct quota_info___335 {
	unsigned int flags;
	struct rw_semaphore___337 dqio_sem;
	struct inode___336 *files[3];
	struct mem_dqinfo___335 info[3];
	const struct quota_format_ops___335 *ops[3];
};

struct rcuwait___335 {
	struct task_struct___337 *task;
};

struct percpu_rw_semaphore___335 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___337 rw_sem;
	struct rcuwait___335 writer;
	int readers_block;
};

struct sb_writers___335 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___335 rw_sem[3];
};

struct file_system_type___335;

struct super_operations___335;

struct dquot_operations___335;

struct quotactl_ops___335;

struct super_block___335 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___335 *s_type;
	const struct super_operations___335 *s_op;
	const struct dquot_operations___335 *dq_op;
	const struct quotactl_ops___335 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___335 *s_root;
	struct rw_semaphore___337 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___335 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___335 s_dquot;
	struct sb_writers___335 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___335 *s_d_op;
	int cleancache_poolid;
	struct shrinker___124 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___336 {
	struct file___336 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___336 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___335 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___336 *ia_file;
};

struct dquot___335 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___335 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___335 {
	int qf_fmt_id;
	const struct quota_format_ops___335 *qf_ops;
	struct module___274 *qf_owner;
	struct quota_format_type___335 *qf_next;
};

struct quota_format_ops___335 {
	int (*check_quota_file)(struct super_block___335 *, int);
	int (*read_file_info)(struct super_block___335 *, int);
	int (*write_file_info)(struct super_block___335 *, int);
	int (*free_file_info)(struct super_block___335 *, int);
	int (*read_dqblk)(struct dquot___335 *);
	int (*commit_dqblk)(struct dquot___335 *);
	int (*release_dqblk)(struct dquot___335 *);
	int (*get_next_id)(struct super_block___335 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___335 {
	int (*write_dquot)(struct dquot___335 *);
	struct dquot___335 * (*alloc_dquot)(struct super_block___335 *, int);
	void (*destroy_dquot)(struct dquot___335 *);
	int (*acquire_dquot)(struct dquot___335 *);
	int (*release_dquot)(struct dquot___335 *);
	int (*mark_dirty)(struct dquot___335 *);
	int (*write_info)(struct super_block___335 *, int);
	qsize_t * (*get_reserved_space)(struct inode___336 *);
	int (*get_projid)(struct inode___336 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___336 *, qsize_t *);
	int (*get_next_id)(struct super_block___335 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___335 {
	int (*quota_on)(struct super_block___335 *, int, int, const struct path___336 *);
	int (*quota_off)(struct super_block___335 *, int);
	int (*quota_enable)(struct super_block___335 *, unsigned int);
	int (*quota_disable)(struct super_block___335 *, unsigned int);
	int (*quota_sync)(struct super_block___335 *, int);
	int (*set_info)(struct super_block___335 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___335 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___335 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___335 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___335 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___335 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___335 {
	int (*writepage)(struct page___337 *, struct writeback_control___3 *);
	int (*readpage)(struct file___336 *, struct page___337 *);
	int (*writepages)(struct address_space___335 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___337 *);
	int (*readpages)(struct file___336 *, struct address_space___335 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___336 *, struct address_space___335 *, loff_t, unsigned int, unsigned int, struct page___337 **, void **);
	int (*write_end)(struct file___336 *, struct address_space___335 *, loff_t, unsigned int, unsigned int, struct page___337 *, void *);
	sector_t (*bmap)(struct address_space___335 *, sector_t);
	void (*invalidatepage)(struct page___337 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___337 *, gfp_t);
	void (*freepage)(struct page___337 *);
	ssize_t (*direct_IO)(struct kiocb___336 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___335 *, struct page___337 *, struct page___337 *, enum migrate_mode);
	bool (*isolate_page)(struct page___337 *, isolate_mode_t);
	void (*putback_page)(struct page___337 *);
	int (*launder_page)(struct page___337 *);
	int (*is_partially_uptodate)(struct page___337 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___337 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___335 *, struct page___337 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___336 *, sector_t *);
	void (*swap_deactivate)(struct file___336 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___335 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___336 *bd_inode;
	struct super_block___335 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___335 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___335 {
	struct dentry___335 * (*lookup)(struct inode___336 *, struct dentry___335 *, unsigned int);
	const char * (*get_link)(struct dentry___335 *, struct inode___336 *, struct delayed_call *);
	int (*permission)(struct inode___336 *, int);
	struct posix_acl * (*get_acl)(struct inode___336 *, int);
	int (*readlink)(struct dentry___335 *, char *, int);
	int (*create)(struct inode___336 *, struct dentry___335 *, umode_t, bool);
	int (*link)(struct dentry___335 *, struct inode___336 *, struct dentry___335 *);
	int (*unlink)(struct inode___336 *, struct dentry___335 *);
	int (*symlink)(struct inode___336 *, struct dentry___335 *, const char *);
	int (*mkdir)(struct inode___336 *, struct dentry___335 *, umode_t);
	int (*rmdir)(struct inode___336 *, struct dentry___335 *);
	int (*mknod)(struct inode___336 *, struct dentry___335 *, umode_t, dev_t);
	int (*rename)(struct inode___336 *, struct dentry___335 *, struct inode___336 *, struct dentry___335 *, unsigned int);
	int (*setattr)(struct dentry___335 *, struct iattr___335 *);
	int (*getattr)(const struct path___336 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___335 *, char *, size_t);
	int (*fiemap)(struct inode___336 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___336 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___336 *, struct dentry___335 *, struct file___336 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___336 *, struct dentry___335 *, umode_t);
	int (*set_acl)(struct inode___336 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___335 {
	void (*fl_copy_lock)(struct file_lock___336 *, struct file_lock___336 *);
	void (*fl_release_private)(struct file_lock___336 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___335;

struct lock_manager_operations___335;

struct file_lock___336 {
	struct file_lock___336 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___336 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___335 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___335 *fl_ops;
	const struct lock_manager_operations___335 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___335 {
	int (*lm_compare_owner)(struct file_lock___336 *, struct file_lock___336 *);
	long unsigned int (*lm_owner_key)(struct file_lock___336 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___336 *);
	int (*lm_grant)(struct file_lock___336 *, int);
	bool (*lm_break)(struct file_lock___336 *);
	int (*lm_change)(struct file_lock___336 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___336 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___335 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___335 *fa_next;
	struct file___336 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___335 {
	const char *name;
	int fs_flags;
	struct dentry___335 * (*mount)(struct file_system_type___335 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___335 *);
	struct module___274 *owner;
	struct file_system_type___335 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___335 {
	struct inode___336 * (*alloc_inode)(struct super_block___335 *);
	void (*destroy_inode)(struct inode___336 *);
	void (*dirty_inode)(struct inode___336 *, int);
	int (*write_inode)(struct inode___336 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___336 *);
	void (*evict_inode)(struct inode___336 *);
	void (*put_super)(struct super_block___335 *);
	int (*sync_fs)(struct super_block___335 *, int);
	int (*freeze_super)(struct super_block___335 *);
	int (*freeze_fs)(struct super_block___335 *);
	int (*thaw_super)(struct super_block___335 *);
	int (*unfreeze_fs)(struct super_block___335 *);
	int (*statfs)(struct dentry___335 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___335 *, int *, char *);
	void (*umount_begin)(struct super_block___335 *);
	int (*show_options)(struct seq_file___284 *, struct dentry___335 *);
	int (*show_devname)(struct seq_file___284 *, struct dentry___335 *);
	int (*show_path)(struct seq_file___284 *, struct dentry___335 *);
	int (*show_stats)(struct seq_file___284 *, struct dentry___335 *);
	ssize_t (*quota_read)(struct super_block___335 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___335 *, int, const char *, size_t, loff_t);
	struct dquot___335 ** (*get_dquots)(struct inode___336 *);
	int (*bdev_try_to_free_page)(struct super_block___335 *, struct page___337 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___335 *, struct shrink_control___124 *);
	long int (*free_cached_objects)(struct super_block___335 *, struct shrink_control___124 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___324(struct page___337 *);

struct fwnode_reference_args___231;

struct fwnode_endpoint___231;

struct fwnode_operations___231 {
	struct fwnode_handle___231 * (*get)(struct fwnode_handle___231 *);
	void (*put)(struct fwnode_handle___231 *);
	bool (*device_is_available)(const struct fwnode_handle___231 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___231 *, const struct device___302 *);
	bool (*property_present)(const struct fwnode_handle___231 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___231 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___231 *, const char *, const char **, size_t);
	struct fwnode_handle___231 * (*get_parent)(const struct fwnode_handle___231 *);
	struct fwnode_handle___231 * (*get_next_child_node)(const struct fwnode_handle___231 *, struct fwnode_handle___231 *);
	struct fwnode_handle___231 * (*get_named_child_node)(const struct fwnode_handle___231 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___231 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___231 *);
	struct fwnode_handle___231 * (*graph_get_next_endpoint)(const struct fwnode_handle___231 *, struct fwnode_handle___231 *);
	struct fwnode_handle___231 * (*graph_get_remote_endpoint)(const struct fwnode_handle___231 *);
	struct fwnode_handle___231 * (*graph_get_port_parent)(struct fwnode_handle___231 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___231 *, struct fwnode_endpoint___231 *);
};

struct fwnode_endpoint___231 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___231 *local_fwnode;
};

struct fwnode_reference_args___231 {
	struct fwnode_handle___231 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct kernel_param_ops___271 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___271 *);
	int (*get)(char *, const struct kernel_param___271 *);
	void (*free)(void *);
};

struct kparam_array___271;

struct kernel_param___271 {
	const char *name;
	struct module___274 *mod;
	const struct kernel_param_ops___271 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___271 *arr;
	};
};

struct kparam_array___271 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___271 *ops;
	void *elem;
};

struct module_attribute___271 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___271 *, struct module_kobject___271 *, char *);
	ssize_t (*store)(struct module_attribute___271 *, struct module_kobject___271 *, const char *, size_t);
	void (*setup)(struct module___274 *, const char *);
	int (*test)(struct module___274 *);
	void (*free)(struct module___274 *);
};

typedef int (*key_restrict_link_func_t___312)(struct key___311 *, const struct key_type *, const union key_payload *, struct key___311 *);

struct key_restriction___311;

struct key___311 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___337 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___311 *restrict_link;
};

struct key_restriction___311 {
	key_restrict_link_func_t___312 check;
	struct key___311 *key;
	struct key_type *keytype;
};

struct seq_operations___283 {
	void * (*start)(struct seq_file___284 *, loff_t *);
	void (*stop)(struct seq_file___284 *, void *);
	void * (*next)(struct seq_file___284 *, void *, loff_t *);
	int (*show)(struct seq_file___284 *, void *);
};

struct dev_pm_qos_request___13 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___302 *dev;
};

struct device_attach_data {
	struct device___302 *dev;
	bool check_async;
	bool want_async;
	bool have_async;
};

struct module___275;

struct file___337;

struct kiocb___337;

struct iov_iter___147;

struct poll_table_struct___204;

struct vm_area_struct___338;

struct inode___337;

struct file_lock___337;

struct page___338;

struct seq_file___285;

struct file_operations___337 {
	struct module___275 *owner;
	loff_t (*llseek)(struct file___337 *, loff_t, int);
	ssize_t (*read)(struct file___337 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___337 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___337 *, struct iov_iter___147 *);
	ssize_t (*write_iter)(struct kiocb___337 *, struct iov_iter___147 *);
	int (*iopoll)(struct kiocb___337 *, bool);
	int (*iterate)(struct file___337 *, struct dir_context *);
	int (*iterate_shared)(struct file___337 *, struct dir_context *);
	__poll_t (*poll)(struct file___337 *, struct poll_table_struct___204 *);
	long int (*unlocked_ioctl)(struct file___337 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___337 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___337 *, struct vm_area_struct___338 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___337 *, struct file___337 *);
	int (*flush)(struct file___337 *, fl_owner_t);
	int (*release)(struct inode___337 *, struct file___337 *);
	int (*fsync)(struct file___337 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___337 *, int);
	int (*lock)(struct file___337 *, int, struct file_lock___337 *);
	ssize_t (*sendpage)(struct file___337 *, struct page___338 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___337 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___337 *, int, struct file_lock___337 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___337 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___337 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___337 *, long int, struct file_lock___337 **, void **);
	long int (*fallocate)(struct file___337 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___285 *, struct file___337 *);
	ssize_t (*copy_file_range)(struct file___337 *, loff_t, struct file___337 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___337 *, loff_t, struct file___337 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___337 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct perf_event___135;

struct debug_info___135 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___135 *hbp_break[16];
	struct perf_event___135 *hbp_watch[16];
};

struct task_struct___338;

struct hw_perf_event___135 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___338 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___135)(struct perf_event___135 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___135;

struct perf_event_context___135;

struct fasync_struct___336;

struct pid_namespace___210;

struct trace_event_call___128;

struct perf_cgroup___135;

struct perf_event___135 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___135 *group_leader;
	struct pmu___135 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___135 hw;
	struct perf_event_context___135 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___135 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___338 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___336 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___135 *);
	struct callback_head callback_head;
	struct pid_namespace___210 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___135 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___135 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___128 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___135 *cgrp;
	struct list_head sb_list;
};

struct thread_struct___135 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___135 debug;
	long: 64;
};

struct vmacache___337 {
	u64 seqnum;
	struct vm_area_struct___338 *vmas[4];
};

struct page_frag___337 {
	struct page___338 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___337;

struct mem_cgroup___125;

struct pid___210;

struct cred___312;

struct nsproxy___264;

struct signal_struct___246;

struct bio_list___159;

struct backing_dev_info___159;

struct css_set___220;

struct task_struct___338 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___338 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___337 *mm;
	struct mm_struct___337 *active_mm;
	struct vmacache___337 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___338 *real_parent;
	struct task_struct___338 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___338 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___125 *active_memcg;
	long int rh_reserved2;
	struct pid___210 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___210 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___210 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___312 *ptracer_cred;
	const struct cred___312 *real_cred;
	const struct cred___312 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___264 *nsproxy;
	struct signal_struct___246 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___338 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___159 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___159 *backing_dev_info;
	struct io_context___84 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___220 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___135 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___337 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___125 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___338 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___135 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rw_semaphore___338 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___338 *owner;
};

struct key___312;

struct ucounts___235;

struct user_namespace___235 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___235 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___9 ns;
	long unsigned int flags;
	struct key___312 *persistent_keyring_register;
	struct rw_semaphore___338 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___235 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___338 *pgtable_t___337;

struct address_space___336;

struct dev_pagemap___325;

struct page___338 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___336 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___338 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___337 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___337 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___325 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___125 *mem_cgroup;
};

struct pglist_data___337;

struct lruvec___337 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___337 *pgdat;
};

struct zone___337 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___337 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___337 {
	struct zone___337 *zone;
	int zone_idx;
};

struct zonelist___337 {
	struct zoneref___337 _zonerefs[25];
};

struct pglist_data___337 {
	struct zone___337 node_zones[3];
	struct zonelist___337 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___338 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___338 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___337 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___338 {
	void *stack;
	struct task_struct___338 *task;
	long int status;
};

struct blocking_notifier_head___337 {
	struct rw_semaphore___338 rwsem;
	struct notifier_block *head;
};

struct dentry___336;

struct path___337 {
	struct vfsmount *mnt;
	struct dentry___336 *dentry;
};

struct fown_struct___210 {
	rwlock_t lock;
	struct pid___210 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___337 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___337 f_path;
	struct inode___337 *f_inode;
	const struct file_operations___337 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___210 f_owner;
	const struct cred___312 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___336 *f_mapping;
	errseq_t f_wb_err;
};

struct user_struct___312;

struct cred___312 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___312 *session_keyring;
	struct key___312 *process_keyring;
	struct key___312 *thread_keyring;
	struct key___312 *request_key_auth;
	void *security;
	struct user_struct___312 *user;
	struct user_namespace___235 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___330;

struct kernfs_elem_dir___330 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___330 *root;
};

struct kernfs_node___331;

struct kernfs_syscall_ops___330;

struct kernfs_root___330 {
	struct kernfs_node___331 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___330 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___330 {
	struct kernfs_node___331 *target_kn;
};

struct kernfs_ops___330;

struct kernfs_elem_attr___330 {
	const struct kernfs_ops___330 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___331 *notify_next;
};

struct kernfs_node___331 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___331 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___330 dir;
		struct kernfs_elem_symlink___330 symlink;
		struct kernfs_elem_attr___330 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___330;

struct kernfs_ops___330 {
	int (*open)(struct kernfs_open_file___330 *);
	void (*release)(struct kernfs_open_file___330 *);
	int (*seq_show)(struct seq_file___285 *, void *);
	void * (*seq_start)(struct seq_file___285 *, loff_t *);
	void * (*seq_next)(struct seq_file___285 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___285 *, void *);
	ssize_t (*read)(struct kernfs_open_file___330 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___330 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___330 *, struct vm_area_struct___338 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___330 *, struct poll_table_struct___204 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___330 {
	int (*remount_fs)(struct kernfs_root___330 *, int *, char *);
	int (*show_options)(struct seq_file___285 *, struct kernfs_root___330 *);
	int (*mkdir)(struct kernfs_node___331 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___331 *);
	int (*rename)(struct kernfs_node___331 *, struct kernfs_node___331 *, const char *);
	int (*show_path)(struct seq_file___285 *, struct kernfs_node___331 *, struct kernfs_root___330 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___284;

struct seq_file___285 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___284 *op;
	int poll_event;
	const struct file___337 *file;
	void *private;
};

struct vm_operations_struct___325;

struct kernfs_open_file___330 {
	struct kernfs_node___331 *kn;
	struct file___337 *file;
	struct seq_file___285 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___325 *vm_ops;
};

struct vm_fault___325;

struct vm_operations_struct___325 {
	void (*open)(struct vm_area_struct___338 *);
	void (*close)(struct vm_area_struct___338 *);
	int (*split)(struct vm_area_struct___338 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___338 *);
	vm_fault_t (*fault)(struct vm_fault___325 *);
	vm_fault_t (*huge_fault)(struct vm_fault___325 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___325 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___338 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___325 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___325 *);
	int (*access)(struct vm_area_struct___338 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___338 *);
	int (*set_policy)(struct vm_area_struct___338 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___338 *, long unsigned int);
	struct page___338 * (*find_special_page)(struct vm_area_struct___338 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___210)(struct file___337 *, wait_queue_head_t *, struct poll_table_struct___204 *);

struct poll_table_struct___204 {
	poll_queue_proc___210 _qproc;
	__poll_t _key;
};

struct vm_area_struct___338 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___338 *vm_next;
	struct vm_area_struct___338 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___337 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___325 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___337 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___324;

struct bin_attribute___300;

struct attribute_group___301 {
	const char *name;
	umode_t (*is_visible)(struct kobject___324 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___324 *, struct bin_attribute___300 *, int);
	struct attribute **attrs;
	struct bin_attribute___300 **bin_attrs;
};

struct kset___323;

struct kobj_type___323;

struct kobject___324 {
	const char *name;
	struct list_head entry;
	struct kobject___324 *parent;
	struct kset___323 *kset;
	struct kobj_type___323 *ktype;
	struct kernfs_node___331 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___300 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___337 *, struct kobject___324 *, struct bin_attribute___300 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___337 *, struct kobject___324 *, struct bin_attribute___300 *, char *, loff_t, size_t);
	int (*mmap)(struct file___337 *, struct kobject___324 *, struct bin_attribute___300 *, struct vm_area_struct___338 *);
};

struct sysfs_ops___323 {
	ssize_t (*show)(struct kobject___324 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___324 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___323;

struct kset___323 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___324 kobj;
	const struct kset_uevent_ops___323 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___323 {
	void (*release)(struct kobject___324 *);
	const struct sysfs_ops___323 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___27 * (*child_ns_type)(struct kobject___324 *);
	const void * (*namespace)(struct kobject___324 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___323 {
	int (* const filter)(struct kset___323 *, struct kobject___324 *);
	const char * (* const name)(struct kset___323 *, struct kobject___324 *);
	int (* const uevent)(struct kset___323 *, struct kobject___324 *, struct kobj_uevent_env *);
};

struct kobj_attribute___315 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___324 *, struct kobj_attribute___315 *, char *);
	ssize_t (*store)(struct kobject___324 *, struct kobj_attribute___315 *, const char *, size_t);
};

struct kernel_param___272;

struct kernel_param_ops___272 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___272 *);
	int (*get)(char *, const struct kernel_param___272 *);
	void (*free)(void *);
};

struct kparam_array___272;

struct kernel_param___272 {
	const char *name;
	struct module___275 *mod;
	const struct kernel_param_ops___272 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___272 *arr;
	};
};

struct kparam_array___272 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___272 *ops;
	void *elem;
};

struct module_kobject___272 {
	struct kobject___324 kobj;
	struct module___275 *mod;
	struct kobject___324 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___272 {
	struct module___275 *mod;
	struct latch_tree_node node;
};

struct module_layout___272 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___272 mtn;
};

struct module_attribute___272;

struct module___275 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___272 mkobj;
	struct module_attribute___272 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___324 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___272 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___272 core_layout;
	struct module_layout___272 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___128 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___272 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___272 *, struct module_kobject___272 *, char *);
	ssize_t (*store)(struct module_attribute___272 *, struct module_kobject___272 *, const char *, size_t);
	void (*setup)(struct module___275 *, const char *);
	int (*test)(struct module___275 *);
	void (*free)(struct module___275 *);
};

struct trace_event_class___128;

struct trace_event_call___128 {
	struct list_head list;
	struct trace_event_class___128 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___13 event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___37 *prog_array;
	int (*perf_perm)(struct trace_event_call___128 *, struct perf_event___135 *);
};

struct upid___210 {
	int nr;
	struct pid_namespace___210 *ns;
};

struct pid_namespace___210 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___338 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___210 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___336 *proc_self;
	struct dentry___336 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___235 *user_ns;
	struct ucounts___235 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___9 ns;
};

struct pid___210 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___210 numbers[1];
};

struct user_struct___312 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___312 *uid_keyring;
	struct key___312 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___337;

struct mm_struct___337 {
	struct {
		struct vm_area_struct___338 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___337 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___338 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___337 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___338 *owner;
		struct user_namespace___235 *user_ns;
		struct file___337 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___337 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup___220;

struct cgroup_subsys___220;

struct cgroup_subsys_state___220 {
	struct cgroup___220 *cgroup;
	struct cgroup_subsys___220 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___220 *parent;
};

struct cgroup_file___220 {
	struct kernfs_node___331 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___125;

struct mem_cgroup___125 {
	struct cgroup_subsys_state___220 css;
	struct mem_cgroup_id___2 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___220 events_file;
	struct cgroup_file___220 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___338 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___125 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cgroup_namespace___220;

struct nsproxy___264 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___210 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___220 *cgroup_ns;
};

struct signal_struct___246 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___338 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___338 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___210 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___210 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___337 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___210 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___159;

struct bio_list___159 {
	struct bio___159 *head;
	struct bio___159 *tail;
};

struct bdi_writeback_congested___159;

struct bdi_writeback___159 {
	struct backing_dev_info___159 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___159 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___220 *memcg_css;
	struct cgroup_subsys_state___220 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___303;

struct backing_dev_info___159 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___159 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___303 *dev;
	struct device___303 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___336 *debug_dir;
	struct dentry___336 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___220 {
	struct cgroup_subsys_state___220 *subsys[13];
	refcount_t refcount;
	struct css_set___220 *dom_cset;
	struct cgroup___220 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___220 *mg_src_cgrp;
	struct cgroup___220 *mg_dst_cgrp;
	struct css_set___220 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___135 {
	struct pmu___135 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___338 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___135 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

union thread_union___258 {
	struct task_struct___338 task;
	long unsigned int stack[8192];
};

struct dentry_operations___336;

struct super_block___336;

struct dentry___336 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___336 *d_parent;
	struct qstr d_name;
	struct inode___337 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___336 *d_op;
	struct super_block___336 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___336;

struct address_space___336 {
	struct inode___337 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___338 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___336 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___336;

struct block_device___336;

struct inode___337 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___336 *i_op;
	struct super_block___336 *i_sb;
	struct address_space___336 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___338 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___159 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___337 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___336 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___336 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___336 {
	int (*d_revalidate)(struct dentry___336 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___336 *, unsigned int);
	int (*d_hash)(const struct dentry___336 *, struct qstr *);
	int (*d_compare)(const struct dentry___336 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___336 *);
	int (*d_init)(struct dentry___336 *);
	void (*d_release)(struct dentry___336 *);
	void (*d_prune)(struct dentry___336 *);
	void (*d_iput)(struct dentry___336 *, struct inode___337 *);
	char * (*d_dname)(struct dentry___336 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___337 *);
	int (*d_manage)(const struct path___337 *, bool);
	struct dentry___336 * (*d_real)(struct dentry___336 *, const struct inode___337 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___336;

struct mem_dqinfo___336 {
	struct quota_format_type___336 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___336;

struct quota_info___336 {
	unsigned int flags;
	struct rw_semaphore___338 dqio_sem;
	struct inode___337 *files[3];
	struct mem_dqinfo___336 info[3];
	const struct quota_format_ops___336 *ops[3];
};

struct rcuwait___336 {
	struct task_struct___338 *task;
};

struct percpu_rw_semaphore___336 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___338 rw_sem;
	struct rcuwait___336 writer;
	int readers_block;
};

struct sb_writers___336 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___336 rw_sem[3];
};

struct shrink_control___125;

struct shrinker___125 {
	long unsigned int (*count_objects)(struct shrinker___125 *, struct shrink_control___125 *);
	long unsigned int (*scan_objects)(struct shrinker___125 *, struct shrink_control___125 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___336;

struct super_operations___336;

struct dquot_operations___336;

struct quotactl_ops___336;

struct super_block___336 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___336 *s_type;
	const struct super_operations___336 *s_op;
	const struct dquot_operations___336 *dq_op;
	const struct quotactl_ops___336 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___336 *s_root;
	struct rw_semaphore___338 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___336 *s_bdev;
	struct backing_dev_info___159 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___336 s_dquot;
	struct sb_writers___336 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___336 *s_d_op;
	int cleancache_poolid;
	struct shrinker___125 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___235 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___125 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___125 *memcg;
};

typedef int (*dev_page_fault_t___325)(struct vm_area_struct___338 *, long unsigned int, const struct page___338 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___325)(struct page___338 *, void *);

struct dev_pagemap___325 {
	dev_page_fault_t___325 page_fault;
	dev_page_free_t___325 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___303 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___337 {
	struct task_struct___338 *task;
	struct core_thread___337 *next;
};

struct core_state___337 {
	atomic_t nr_threads;
	struct core_thread___337 dumper;
	struct completion startup;
};

struct vm_fault___325 {
	struct vm_area_struct___338 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___338 *cow_page;
	struct mem_cgroup___125 *memcg;
	struct page___338 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___337 prealloc_pte;
};

struct kiocb___337 {
	struct file___337 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___337 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___336 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___337 *ia_file;
};

struct dquot___336 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___336 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___336 {
	int qf_fmt_id;
	const struct quota_format_ops___336 *qf_ops;
	struct module___275 *qf_owner;
	struct quota_format_type___336 *qf_next;
};

struct quota_format_ops___336 {
	int (*check_quota_file)(struct super_block___336 *, int);
	int (*read_file_info)(struct super_block___336 *, int);
	int (*write_file_info)(struct super_block___336 *, int);
	int (*free_file_info)(struct super_block___336 *, int);
	int (*read_dqblk)(struct dquot___336 *);
	int (*commit_dqblk)(struct dquot___336 *);
	int (*release_dqblk)(struct dquot___336 *);
	int (*get_next_id)(struct super_block___336 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___336 {
	int (*write_dquot)(struct dquot___336 *);
	struct dquot___336 * (*alloc_dquot)(struct super_block___336 *, int);
	void (*destroy_dquot)(struct dquot___336 *);
	int (*acquire_dquot)(struct dquot___336 *);
	int (*release_dquot)(struct dquot___336 *);
	int (*mark_dirty)(struct dquot___336 *);
	int (*write_info)(struct super_block___336 *, int);
	qsize_t * (*get_reserved_space)(struct inode___337 *);
	int (*get_projid)(struct inode___337 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___337 *, qsize_t *);
	int (*get_next_id)(struct super_block___336 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___336 {
	int (*quota_on)(struct super_block___336 *, int, int, const struct path___337 *);
	int (*quota_off)(struct super_block___336 *, int);
	int (*quota_enable)(struct super_block___336 *, unsigned int);
	int (*quota_disable)(struct super_block___336 *, unsigned int);
	int (*quota_sync)(struct super_block___336 *, int);
	int (*set_info)(struct super_block___336 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___336 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___336 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___336 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___336 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___336 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___142;

struct swap_info_struct___82;

struct address_space_operations___336 {
	int (*writepage)(struct page___338 *, struct writeback_control___142 *);
	int (*readpage)(struct file___337 *, struct page___338 *);
	int (*writepages)(struct address_space___336 *, struct writeback_control___142 *);
	int (*set_page_dirty)(struct page___338 *);
	int (*readpages)(struct file___337 *, struct address_space___336 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___337 *, struct address_space___336 *, loff_t, unsigned int, unsigned int, struct page___338 **, void **);
	int (*write_end)(struct file___337 *, struct address_space___336 *, loff_t, unsigned int, unsigned int, struct page___338 *, void *);
	sector_t (*bmap)(struct address_space___336 *, sector_t);
	void (*invalidatepage)(struct page___338 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___338 *, gfp_t);
	void (*freepage)(struct page___338 *);
	ssize_t (*direct_IO)(struct kiocb___337 *, struct iov_iter___147 *);
	int (*migratepage)(struct address_space___336 *, struct page___338 *, struct page___338 *, enum migrate_mode);
	bool (*isolate_page)(struct page___338 *, isolate_mode_t);
	void (*putback_page)(struct page___338 *);
	int (*launder_page)(struct page___338 *);
	int (*is_partially_uptodate)(struct page___338 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___338 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___336 *, struct page___338 *);
	int (*swap_activate)(struct swap_info_struct___82 *, struct file___337 *, sector_t *);
	void (*swap_deactivate)(struct file___337 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___142 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___159 *wb;
	struct inode___337 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___161;

struct iov_iter___147 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___161 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct swap_info_struct___82 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___336 *bdev;
	struct file___337 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___336 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___337 *bd_inode;
	struct super_block___336 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___336 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___159 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___336 {
	struct dentry___336 * (*lookup)(struct inode___337 *, struct dentry___336 *, unsigned int);
	const char * (*get_link)(struct dentry___336 *, struct inode___337 *, struct delayed_call *);
	int (*permission)(struct inode___337 *, int);
	struct posix_acl * (*get_acl)(struct inode___337 *, int);
	int (*readlink)(struct dentry___336 *, char *, int);
	int (*create)(struct inode___337 *, struct dentry___336 *, umode_t, bool);
	int (*link)(struct dentry___336 *, struct inode___337 *, struct dentry___336 *);
	int (*unlink)(struct inode___337 *, struct dentry___336 *);
	int (*symlink)(struct inode___337 *, struct dentry___336 *, const char *);
	int (*mkdir)(struct inode___337 *, struct dentry___336 *, umode_t);
	int (*rmdir)(struct inode___337 *, struct dentry___336 *);
	int (*mknod)(struct inode___337 *, struct dentry___336 *, umode_t, dev_t);
	int (*rename)(struct inode___337 *, struct dentry___336 *, struct inode___337 *, struct dentry___336 *, unsigned int);
	int (*setattr)(struct dentry___336 *, struct iattr___336 *);
	int (*getattr)(const struct path___337 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___336 *, char *, size_t);
	int (*fiemap)(struct inode___337 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___337 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___337 *, struct dentry___336 *, struct file___337 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___337 *, struct dentry___336 *, umode_t);
	int (*set_acl)(struct inode___337 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___336 {
	void (*fl_copy_lock)(struct file_lock___337 *, struct file_lock___337 *);
	void (*fl_release_private)(struct file_lock___337 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___336;

struct file_lock___337 {
	struct file_lock___337 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___337 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___336 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___336 *fl_ops;
	const struct lock_manager_operations___336 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___336 {
	int (*lm_compare_owner)(struct file_lock___337 *, struct file_lock___337 *);
	long unsigned int (*lm_owner_key)(struct file_lock___337 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___337 *);
	int (*lm_grant)(struct file_lock___337 *, int);
	bool (*lm_break)(struct file_lock___337 *);
	int (*lm_change)(struct file_lock___337 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___337 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___336 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___336 *fa_next;
	struct file___337 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___336 {
	const char *name;
	int fs_flags;
	struct dentry___336 * (*mount)(struct file_system_type___336 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___336 *);
	struct module___275 *owner;
	struct file_system_type___336 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___336 {
	struct inode___337 * (*alloc_inode)(struct super_block___336 *);
	void (*destroy_inode)(struct inode___337 *);
	void (*dirty_inode)(struct inode___337 *, int);
	int (*write_inode)(struct inode___337 *, struct writeback_control___142 *);
	int (*drop_inode)(struct inode___337 *);
	void (*evict_inode)(struct inode___337 *);
	void (*put_super)(struct super_block___336 *);
	int (*sync_fs)(struct super_block___336 *, int);
	int (*freeze_super)(struct super_block___336 *);
	int (*freeze_fs)(struct super_block___336 *);
	int (*thaw_super)(struct super_block___336 *);
	int (*unfreeze_fs)(struct super_block___336 *);
	int (*statfs)(struct dentry___336 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___336 *, int *, char *);
	void (*umount_begin)(struct super_block___336 *);
	int (*show_options)(struct seq_file___285 *, struct dentry___336 *);
	int (*show_devname)(struct seq_file___285 *, struct dentry___336 *);
	int (*show_path)(struct seq_file___285 *, struct dentry___336 *);
	int (*show_stats)(struct seq_file___285 *, struct dentry___336 *);
	ssize_t (*quota_read)(struct super_block___336 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___336 *, int, const char *, size_t, loff_t);
	struct dquot___336 ** (*get_dquots)(struct inode___337 *);
	int (*bdev_try_to_free_page)(struct super_block___336 *, struct page___338 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___336 *, struct shrink_control___125 *);
	long int (*free_cached_objects)(struct super_block___336 *, struct shrink_control___125 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___159(struct bio___159 *);

struct bio_vec___161 {
	struct page___338 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___159;

struct bio_set___159;

struct bio___159 {
	struct bio___159 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___159 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___159 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___161 *bi_io_vec;
	struct bio_set___159 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___161 bi_inline_vecs[0];
};

typedef int (*key_restrict_link_func_t___313)(struct key___312 *, const struct key_type *, const union key_payload *, struct key___312 *);

struct key_restriction___312;

struct key___312 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___338 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___312 *restrict_link;
};

struct key_restriction___312 {
	key_restrict_link_func_t___313 check;
	struct key___312 *key;
	struct key_type *keytype;
};

struct seq_operations___284 {
	void * (*start)(struct seq_file___285 *, loff_t *);
	void (*stop)(struct seq_file___285 *, void *);
	void * (*next)(struct seq_file___285 *, void *, loff_t *);
	int (*show)(struct seq_file___285 *, void *);
};

struct cgroup_namespace___220 {
	refcount_t count;
	struct ns_common___9 ns;
	struct user_namespace___235 *user_ns;
	struct ucounts___235 *ucounts;
	struct css_set___220 *root_cset;
};

struct ucounts___235 {
	struct hlist_node node;
	struct user_namespace___235 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___221;

struct bpf_map_ops___220 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___221 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___221 *, struct file___337 *);
	void (*map_free)(struct bpf_map___221 *);
	int (*map_get_next_key)(struct bpf_map___221 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___221 *);
	void * (*map_lookup_elem)(struct bpf_map___221 *, void *);
	int (*map_update_elem)(struct bpf_map___221 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___221 *, void *);
	int (*map_push_elem)(struct bpf_map___221 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___221 *, void *);
	int (*map_peek_elem)(struct bpf_map___221 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___221 *, struct file___337 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___221 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___221 *, void *, struct seq_file___285 *);
	int (*map_check_btf)(const struct bpf_map___221 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___221 {
	const struct bpf_map_ops___220 *ops;
	struct bpf_map___221 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___312 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___220;

typedef void (*kthread_work_func_t___220)(struct kthread_work___220 *);

struct kthread_worker___220;

struct kthread_work___220 {
	struct list_head node;
	kthread_work_func_t___220 func;
	struct kthread_worker___220 *worker;
	int canceling;
};

struct kthread_worker___220 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___338 *task;
	struct kthread_work___220 *current_work;
};

struct kthread_delayed_work___220 {
	struct kthread_work___220 work;
	struct timer_list timer;
};

struct psi_group___220 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___220 *poll_kworker;
	struct kthread_delayed_work___220 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___220;

struct cgroup_rstat_cpu___220;

struct cgroup___220 {
	struct cgroup_subsys_state___220 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___331 *kn;
	struct cgroup_file___220 procs_file;
	struct cgroup_file___220 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___220 *subsys[13];
	struct cgroup_root___220 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___220 *dom_cgrp;
	struct cgroup_rstat_cpu___220 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___37 bpf;
	atomic_t congestion_count;
	struct cgroup___220 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___220 psi;
	int ancestor_ids[0];
};

struct cftype___220;

struct cgroup_subsys___220 {
	struct cgroup_subsys_state___220 * (*css_alloc)(struct cgroup_subsys_state___220 *);
	int (*css_online)(struct cgroup_subsys_state___220 *);
	void (*css_offline)(struct cgroup_subsys_state___220 *);
	void (*css_released)(struct cgroup_subsys_state___220 *);
	void (*css_free)(struct cgroup_subsys_state___220 *);
	void (*css_reset)(struct cgroup_subsys_state___220 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___220 *, int);
	int (*css_extra_stat_show)(struct seq_file___285 *, struct cgroup_subsys_state___220 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___338 *);
	void (*cancel_fork)(struct task_struct___338 *);
	void (*fork)(struct task_struct___338 *);
	void (*exit)(struct task_struct___338 *);
	void (*free)(struct task_struct___338 *);
	void (*bind)(struct cgroup_subsys_state___220 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___220 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___220 *dfl_cftypes;
	struct cftype___220 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___220 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___220 *updated_children;
	struct cgroup___220 *updated_next;
};

struct cgroup_root___220 {
	struct kernfs_root___330 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___220 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___220 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___220 *ss;
	struct list_head node;
	struct kernfs_ops___330 *kf_ops;
	int (*open)(struct kernfs_open_file___330 *);
	void (*release)(struct kernfs_open_file___330 *);
	u64 (*read_u64)(struct cgroup_subsys_state___220 *, struct cftype___220 *);
	s64 (*read_s64)(struct cgroup_subsys_state___220 *, struct cftype___220 *);
	int (*seq_show)(struct seq_file___285 *, void *);
	void * (*seq_start)(struct seq_file___285 *, loff_t *);
	void * (*seq_next)(struct seq_file___285 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___285 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___220 *, struct cftype___220 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___220 *, struct cftype___220 *, s64);
	ssize_t (*write)(struct kernfs_open_file___330 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___330 *, struct poll_table_struct___204 *);
};

struct dev_pm_qos___14;

struct dev_pm_info___303 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___2 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___3 *subsys_data;
	void (*set_latency_tolerance)(struct device___303 *, s32);
	struct dev_pm_qos___14 *qos;
};

struct device_type___303;

struct bus_type___303;

struct device_driver___303;

struct dev_pm_domain___303;

struct class___303;

struct device___303 {
	struct device___303 *parent;
	struct device_private *p;
	struct kobject___324 kobj;
	const char *init_name;
	const struct device_type___303 *type;
	struct mutex mutex;
	struct bus_type___303 *bus;
	struct device_driver___303 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___303 power;
	struct dev_pm_domain___303 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___303 *class;
	const struct attribute_group___301 **groups;
	void (*release)(struct device___303 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

typedef void compound_page_dtor___325(struct page___338 *);

struct bdi_writeback_congested___159 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___159 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___159 {
	struct bio___159 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___161 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___161 bip_inline_vecs[0];
};

struct bio_set___159 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___159 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___125 {
	struct mem_cgroup___125 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___125 {
	struct lruvec___337 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___125 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___125 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct dev_pm_ops___303 {
	int (*prepare)(struct device___303 *);
	void (*complete)(struct device___303 *);
	int (*suspend)(struct device___303 *);
	int (*resume)(struct device___303 *);
	int (*freeze)(struct device___303 *);
	int (*thaw)(struct device___303 *);
	int (*poweroff)(struct device___303 *);
	int (*restore)(struct device___303 *);
	int (*suspend_late)(struct device___303 *);
	int (*resume_early)(struct device___303 *);
	int (*freeze_late)(struct device___303 *);
	int (*thaw_early)(struct device___303 *);
	int (*poweroff_late)(struct device___303 *);
	int (*restore_early)(struct device___303 *);
	int (*suspend_noirq)(struct device___303 *);
	int (*resume_noirq)(struct device___303 *);
	int (*freeze_noirq)(struct device___303 *);
	int (*thaw_noirq)(struct device___303 *);
	int (*poweroff_noirq)(struct device___303 *);
	int (*restore_noirq)(struct device___303 *);
	int (*runtime_suspend)(struct device___303 *);
	int (*runtime_resume)(struct device___303 *);
	int (*runtime_idle)(struct device___303 *);
};

struct pm_qos_constraints___14 {
	struct plist_head list;
	s32 target_value;
	s32 default_value;
	s32 no_constraint_value;
	enum pm_qos_type type;
	struct blocking_notifier_head___337 *notifiers;
};

struct dev_pm_qos_request___14;

struct dev_pm_qos___14 {
	struct pm_qos_constraints___14 resume_latency;
	struct pm_qos_constraints___14 latency_tolerance;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___14 *resume_latency_req;
	struct dev_pm_qos_request___14 *latency_tolerance_req;
	struct dev_pm_qos_request___14 *flags_req;
};

struct dev_pm_domain___303 {
	struct dev_pm_ops___303 ops;
	void (*detach)(struct device___303 *, bool);
	int (*activate)(struct device___303 *);
	void (*sync)(struct device___303 *);
	void (*dismiss)(struct device___303 *);
};

struct bus_type___303 {
	const char *name;
	const char *dev_name;
	struct device___303 *dev_root;
	const struct attribute_group___301 **bus_groups;
	const struct attribute_group___301 **dev_groups;
	const struct attribute_group___301 **drv_groups;
	int (*match)(struct device___303 *, struct device_driver___303 *);
	int (*uevent)(struct device___303 *, struct kobj_uevent_env *);
	int (*probe)(struct device___303 *);
	int (*remove)(struct device___303 *);
	void (*shutdown)(struct device___303 *);
	int (*online)(struct device___303 *);
	int (*offline)(struct device___303 *);
	int (*suspend)(struct device___303 *, pm_message_t);
	int (*resume)(struct device___303 *);
	int (*num_vf)(struct device___303 *);
	int (*dma_configure)(struct device___303 *);
	const struct dev_pm_ops___303 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___303 {
	const char *name;
	struct bus_type___303 *bus;
	struct module___275 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___303 *);
	int (*remove)(struct device___303 *);
	void (*shutdown)(struct device___303 *);
	int (*suspend)(struct device___303 *, pm_message_t);
	int (*resume)(struct device___303 *);
	const struct attribute_group___301 **groups;
	const struct dev_pm_ops___303 *pm;
	void (*coredump)(struct device___303 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___303 {
	const char *name;
	const struct attribute_group___301 **groups;
	int (*uevent)(struct device___303 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___303 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___303 *);
	const struct dev_pm_ops___303 *pm;
};

struct class___303 {
	const char *name;
	struct module___275 *owner;
	const struct attribute_group___301 **class_groups;
	const struct attribute_group___301 **dev_groups;
	struct kobject___324 *dev_kobj;
	int (*dev_uevent)(struct device___303 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___303 *, umode_t *);
	void (*class_release)(struct class___303 *);
	void (*dev_release)(struct device___303 *);
	int (*shutdown_pre)(struct device___303 *);
	const struct kobj_ns_type_operations___27 *ns_type;
	const void * (*namespace)(struct device___303 *);
	const struct dev_pm_ops___303 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct node___195 {
	struct device___303 dev;
};

struct dev_pm_qos_request___14 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___303 *dev;
};

struct perf_cpu_context___135;

struct pmu___135 {
	struct list_head entry;
	struct module___275 *module;
	struct device___303 *dev;
	const struct attribute_group___301 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___135 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___135 *);
	void (*pmu_disable)(struct pmu___135 *);
	int (*event_init)(struct perf_event___135 *);
	void (*event_mapped)(struct perf_event___135 *, struct mm_struct___337 *);
	void (*event_unmapped)(struct perf_event___135 *, struct mm_struct___337 *);
	int (*add)(struct perf_event___135 *, int);
	void (*del)(struct perf_event___135 *, int);
	void (*start)(struct perf_event___135 *, int);
	void (*stop)(struct perf_event___135 *, int);
	void (*read)(struct perf_event___135 *);
	void (*start_txn)(struct pmu___135 *, unsigned int);
	int (*commit_txn)(struct pmu___135 *);
	void (*cancel_txn)(struct pmu___135 *);
	int (*event_idx)(struct perf_event___135 *);
	void (*sched_task)(struct perf_event_context___135 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___135 *);
	int (*filter_match)(struct perf_event___135 *);
	int (*check_period)(struct perf_event___135 *, u64);
};

struct perf_cpu_context___135 {
	struct perf_event_context___135 ctx;
	struct perf_event_context___135 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___135 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___135 {
	struct cgroup_subsys_state___220 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___128 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___128 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___128 *);
	struct list_head * (*get_fields)(struct trace_event_call___128 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___128 *);
};

struct class_dev_iter___3 {
	struct klist_iter ki;
	const struct device_type___301 *type;
};

struct class_attribute___2 {
	struct attribute attr;
	ssize_t (*show)(struct class___301 *, struct class_attribute___2 *, char *);
	ssize_t (*store)(struct class___301 *, struct class_attribute___2 *, const char *, size_t);
};

struct class_attribute_string {
	struct class_attribute___2 attr;
	char *str;
};

struct class_compat {
	struct kobject___322 *kobj;
};

struct module___276;

struct file___338;

struct kiocb___338;

struct poll_table_struct___205;

struct vm_area_struct___339;

struct inode___338;

struct file_lock___338;

struct page___339;

struct seq_file___286;

struct file_operations___338 {
	struct module___276 *owner;
	loff_t (*llseek)(struct file___338 *, loff_t, int);
	ssize_t (*read)(struct file___338 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___338 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___338 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___338 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___338 *, bool);
	int (*iterate)(struct file___338 *, struct dir_context *);
	int (*iterate_shared)(struct file___338 *, struct dir_context *);
	__poll_t (*poll)(struct file___338 *, struct poll_table_struct___205 *);
	long int (*unlocked_ioctl)(struct file___338 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___338 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___338 *, struct vm_area_struct___339 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___338 *, struct file___338 *);
	int (*flush)(struct file___338 *, fl_owner_t);
	int (*release)(struct inode___338 *, struct file___338 *);
	int (*fsync)(struct file___338 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___338 *, int);
	int (*lock)(struct file___338 *, int, struct file_lock___338 *);
	ssize_t (*sendpage)(struct file___338 *, struct page___339 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___338 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___338 *, int, struct file_lock___338 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___338 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___338 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___338 *, long int, struct file_lock___338 **, void **);
	long int (*fallocate)(struct file___338 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___286 *, struct file___338 *);
	ssize_t (*copy_file_range)(struct file___338 *, loff_t, struct file___338 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___338 *, loff_t, struct file___338 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___338 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___338 {
	u64 seqnum;
	struct vm_area_struct___339 *vmas[4];
};

struct page_frag___338 {
	struct page___339 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___338;

struct cred___313;

struct vm_struct___248;

struct task_struct___339 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___339 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___338 *mm;
	struct mm_struct___338 *active_mm;
	struct vmacache___338 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___339 *real_parent;
	struct task_struct___339 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___339 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___210 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___210 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___210 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___313 *ptracer_cred;
	const struct cred___313 *real_cred;
	const struct cred___313 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___339 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___84 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___338 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___339 *oom_reaper_list;
	struct vm_struct___248 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___135 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___339 *pgtable_t___338;

struct address_space___337;

struct dev_pagemap___326;

struct page___339 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___337 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___339 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___338 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___338 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___326 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___338;

struct lruvec___338 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___338 *pgdat;
};

struct zone___338 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___338 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___338 {
	struct zone___338 *zone;
	int zone_idx;
};

struct zonelist___338 {
	struct zoneref___338 _zonerefs[25];
};

struct pglist_data___338 {
	struct zone___338 node_zones[3];
	struct zonelist___338 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___339 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___339 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___338 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___339 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___339 *owner;
};

struct secondary_data___339 {
	void *stack;
	struct task_struct___339 *task;
	long int status;
};

struct blocking_notifier_head___338 {
	struct rw_semaphore___339 rwsem;
	struct notifier_block *head;
};

struct kernfs_root___331;

struct kernfs_elem_dir___331 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___331 *root;
};

struct kernfs_node___332;

struct kernfs_syscall_ops___331;

struct kernfs_root___331 {
	struct kernfs_node___332 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___331 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___331 {
	struct kernfs_node___332 *target_kn;
};

struct kernfs_ops___331;

struct kernfs_elem_attr___331 {
	const struct kernfs_ops___331 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___332 *notify_next;
};

struct kernfs_node___332 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___332 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___331 dir;
		struct kernfs_elem_symlink___331 symlink;
		struct kernfs_elem_attr___331 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___331;

struct kernfs_ops___331 {
	int (*open)(struct kernfs_open_file___331 *);
	void (*release)(struct kernfs_open_file___331 *);
	int (*seq_show)(struct seq_file___286 *, void *);
	void * (*seq_start)(struct seq_file___286 *, loff_t *);
	void * (*seq_next)(struct seq_file___286 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___286 *, void *);
	ssize_t (*read)(struct kernfs_open_file___331 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___331 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___331 *, struct vm_area_struct___339 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___331 *, struct poll_table_struct___205 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___331 {
	int (*remount_fs)(struct kernfs_root___331 *, int *, char *);
	int (*show_options)(struct seq_file___286 *, struct kernfs_root___331 *);
	int (*mkdir)(struct kernfs_node___332 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___332 *);
	int (*rename)(struct kernfs_node___332 *, struct kernfs_node___332 *, const char *);
	int (*show_path)(struct seq_file___286 *, struct kernfs_node___332 *, struct kernfs_root___331 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___285;

struct seq_file___286 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___285 *op;
	int poll_event;
	const struct file___338 *file;
	void *private;
};

struct vm_operations_struct___326;

struct kernfs_open_file___331 {
	struct kernfs_node___332 *kn;
	struct file___338 *file;
	struct seq_file___286 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___326 *vm_ops;
};

struct dentry___337;

struct path___338 {
	struct vfsmount *mnt;
	struct dentry___337 *dentry;
};

struct file___338 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___338 f_path;
	struct inode___338 *f_inode;
	const struct file_operations___338 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___210 f_owner;
	const struct cred___313 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___337 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___326;

struct vm_operations_struct___326 {
	void (*open)(struct vm_area_struct___339 *);
	void (*close)(struct vm_area_struct___339 *);
	int (*split)(struct vm_area_struct___339 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___339 *);
	vm_fault_t (*fault)(struct vm_fault___326 *);
	vm_fault_t (*huge_fault)(struct vm_fault___326 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___326 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___339 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___326 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___326 *);
	int (*access)(struct vm_area_struct___339 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___339 *);
	int (*set_policy)(struct vm_area_struct___339 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___339 *, long unsigned int);
	struct page___339 * (*find_special_page)(struct vm_area_struct___339 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___211)(struct file___338 *, wait_queue_head_t *, struct poll_table_struct___205 *);

struct poll_table_struct___205 {
	poll_queue_proc___211 _qproc;
	__poll_t _key;
};

struct vm_area_struct___339 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___339 *vm_next;
	struct vm_area_struct___339 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___338 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___326 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___338 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___325;

struct bin_attribute___301;

struct attribute_group___302 {
	const char *name;
	umode_t (*is_visible)(struct kobject___325 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___325 *, struct bin_attribute___301 *, int);
	struct attribute **attrs;
	struct bin_attribute___301 **bin_attrs;
};

struct kset___324;

struct kobj_type___324;

struct kobject___325 {
	const char *name;
	struct list_head entry;
	struct kobject___325 *parent;
	struct kset___324 *kset;
	struct kobj_type___324 *ktype;
	struct kernfs_node___332 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___301 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___338 *, struct kobject___325 *, struct bin_attribute___301 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___338 *, struct kobject___325 *, struct bin_attribute___301 *, char *, loff_t, size_t);
	int (*mmap)(struct file___338 *, struct kobject___325 *, struct bin_attribute___301 *, struct vm_area_struct___339 *);
};

struct sysfs_ops___324 {
	ssize_t (*show)(struct kobject___325 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___325 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___324;

struct kset___324 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___325 kobj;
	const struct kset_uevent_ops___324 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___324 {
	void (*release)(struct kobject___325 *);
	const struct sysfs_ops___324 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___27 * (*child_ns_type)(struct kobject___325 *);
	const void * (*namespace)(struct kobject___325 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___324 {
	int (* const filter)(struct kset___324 *, struct kobject___325 *);
	const char * (* const name)(struct kset___324 *, struct kobject___325 *);
	int (* const uevent)(struct kset___324 *, struct kobject___325 *, struct kobj_uevent_env *);
};

struct kobj_attribute___316 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___325 *, struct kobj_attribute___316 *, char *);
	ssize_t (*store)(struct kobject___325 *, struct kobj_attribute___316 *, const char *, size_t);
};

struct device___304;

struct dev_pm_ops___304 {
	int (*prepare)(struct device___304 *);
	void (*complete)(struct device___304 *);
	int (*suspend)(struct device___304 *);
	int (*resume)(struct device___304 *);
	int (*freeze)(struct device___304 *);
	int (*thaw)(struct device___304 *);
	int (*poweroff)(struct device___304 *);
	int (*restore)(struct device___304 *);
	int (*suspend_late)(struct device___304 *);
	int (*resume_early)(struct device___304 *);
	int (*freeze_late)(struct device___304 *);
	int (*thaw_early)(struct device___304 *);
	int (*poweroff_late)(struct device___304 *);
	int (*restore_early)(struct device___304 *);
	int (*suspend_noirq)(struct device___304 *);
	int (*resume_noirq)(struct device___304 *);
	int (*freeze_noirq)(struct device___304 *);
	int (*thaw_noirq)(struct device___304 *);
	int (*poweroff_noirq)(struct device___304 *);
	int (*restore_noirq)(struct device___304 *);
	int (*runtime_suspend)(struct device___304 *);
	int (*runtime_resume)(struct device___304 *);
	int (*runtime_idle)(struct device___304 *);
};

struct wakeup_source___3;

struct wake_irq___3;

struct pm_subsys_data___4;

struct dev_pm_qos___15;

struct dev_pm_info___304 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___3 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq___3 *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___4 *subsys_data;
	void (*set_latency_tolerance)(struct device___304 *, s32);
	struct dev_pm_qos___15 *qos;
};

struct device_type___304;

struct bus_type___304;

struct device_driver___304;

struct dev_pm_domain___304;

struct irq_domain___25;

struct dma_map_ops___102;

struct device_node___77;

struct fwnode_handle___232;

struct class___304;

struct device___304 {
	struct device___304 *parent;
	struct device_private *p;
	struct kobject___325 kobj;
	const char *init_name;
	const struct device_type___304 *type;
	struct mutex mutex;
	struct bus_type___304 *bus;
	struct device_driver___304 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___304 power;
	struct dev_pm_domain___304 *pm_domain;
	struct irq_domain___25 *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___102 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___77 *of_node;
	struct fwnode_handle___232 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___304 *class;
	const struct attribute_group___302 **groups;
	void (*release)(struct device___304 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct pm_domain_data___4;

struct pm_subsys_data___4 {
	spinlock_t lock;
	unsigned int refcount;
	struct list_head clock_list;
	struct pm_domain_data___4 *domain_data;
};

struct pm_domain_data___4 {
	struct list_head list_node;
	struct device___304 *dev;
};

struct wakeup_source___3 {
	const char *name;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq___3 *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	bool active: 1;
	bool autosleep_enabled: 1;
};

struct wake_irq___3 {
	struct device___304 *dev;
	unsigned int status;
	int irq;
	const char *name;
};

struct pm_qos_constraints___15 {
	struct plist_head list;
	s32 target_value;
	s32 default_value;
	s32 no_constraint_value;
	enum pm_qos_type type;
	struct blocking_notifier_head___338 *notifiers;
};

struct dev_pm_qos_request___15;

struct dev_pm_qos___15 {
	struct pm_qos_constraints___15 resume_latency;
	struct pm_qos_constraints___15 latency_tolerance;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___15 *resume_latency_req;
	struct dev_pm_qos_request___15 *latency_tolerance_req;
	struct dev_pm_qos_request___15 *flags_req;
};

struct dev_pm_domain___304 {
	struct dev_pm_ops___304 ops;
	void (*detach)(struct device___304 *, bool);
	int (*activate)(struct device___304 *);
	void (*sync)(struct device___304 *);
	void (*dismiss)(struct device___304 *);
};

struct key___313;

struct user_struct___313 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___313 *uid_keyring;
	struct key___313 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___338;

struct mm_struct___338 {
	struct {
		struct vm_area_struct___339 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___338 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___339 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___338 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___339 *owner;
		struct user_namespace___3 *user_ns;
		struct file___338 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___338 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___313 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___313 *session_keyring;
	struct key___313 *process_keyring;
	struct key___313 *thread_keyring;
	struct key___313 *request_key_auth;
	void *security;
	struct user_struct___313 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct vm_struct___248 {
	struct vm_struct___248 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___339 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bus_type___304 {
	const char *name;
	const char *dev_name;
	struct device___304 *dev_root;
	const struct attribute_group___302 **bus_groups;
	const struct attribute_group___302 **dev_groups;
	const struct attribute_group___302 **drv_groups;
	int (*match)(struct device___304 *, struct device_driver___304 *);
	int (*uevent)(struct device___304 *, struct kobj_uevent_env *);
	int (*probe)(struct device___304 *);
	int (*remove)(struct device___304 *);
	void (*shutdown)(struct device___304 *);
	int (*online)(struct device___304 *);
	int (*offline)(struct device___304 *);
	int (*suspend)(struct device___304 *, pm_message_t);
	int (*resume)(struct device___304 *);
	int (*num_vf)(struct device___304 *);
	int (*dma_configure)(struct device___304 *);
	const struct dev_pm_ops___304 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___304 {
	const char *name;
	struct bus_type___304 *bus;
	struct module___276 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___304 *);
	int (*remove)(struct device___304 *);
	void (*shutdown)(struct device___304 *);
	int (*suspend)(struct device___304 *, pm_message_t);
	int (*resume)(struct device___304 *);
	const struct attribute_group___302 **groups;
	const struct dev_pm_ops___304 *pm;
	void (*coredump)(struct device___304 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct subsys_private {
	struct kset___324 subsys;
	struct kset___324 *devices_kset;
	struct list_head interfaces;
	struct mutex mutex;
	struct kset___324 *drivers_kset;
	struct klist klist_devices;
	struct klist klist_drivers;
	struct blocking_notifier_head___338 bus_notifier;
	unsigned int drivers_autoprobe: 1;
	struct bus_type___304 *bus;
	struct kset___324 glue_dirs;
	struct class___304 *class;
};

struct device_type___304 {
	const char *name;
	const struct attribute_group___302 **groups;
	int (*uevent)(struct device___304 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___304 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___304 *);
	const struct dev_pm_ops___304 *pm;
};

struct module_kobject___273 {
	struct kobject___325 kobj;
	struct module___276 *mod;
	struct kobject___325 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___273 {
	struct module___276 *mod;
	struct latch_tree_node node;
};

struct module_layout___273 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___273 mtn;
};

struct module_attribute___273;

struct kernel_param___273;

struct module___276 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___273 mkobj;
	struct module_attribute___273 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___325 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___273 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___273 core_layout;
	struct module_layout___273 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct driver_private {
	struct kobject___325 kobj;
	struct klist klist_devices;
	struct klist_node knode_bus;
	struct module_kobject___273 *mkobj;
	struct device_driver___304 *driver;
};

struct class___304 {
	const char *name;
	struct module___276 *owner;
	const struct attribute_group___302 **class_groups;
	const struct attribute_group___302 **dev_groups;
	struct kobject___325 *dev_kobj;
	int (*dev_uevent)(struct device___304 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___304 *, umode_t *);
	void (*class_release)(struct class___304 *);
	void (*dev_release)(struct device___304 *);
	int (*shutdown_pre)(struct device___304 *);
	const struct kobj_ns_type_operations___27 *ns_type;
	const void * (*namespace)(struct device___304 *);
	const struct dev_pm_ops___304 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct device_attribute___30 {
	struct attribute attr;
	ssize_t (*show)(struct device___304 *, struct device_attribute___30 *, char *);
	ssize_t (*store)(struct device___304 *, struct device_attribute___30 *, const char *, size_t);
};

struct device_private {
	struct klist klist_children;
	struct klist_node knode_parent;
	struct klist_node knode_driver;
	struct klist_node knode_bus;
	struct list_head deferred_probe;
	struct device___304 *device;
};

struct irq_domain_ops___25;

struct irq_domain_chip_generic___13;

struct irq_domain___25 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___25 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___232 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___13 *gc;
	struct irq_domain___25 *parent;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_direct_max_irq;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_tree_mutex;
	unsigned int linear_revmap[0];
};

struct dma_map_ops___102 {
	void * (*alloc)(struct device___304 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___304 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___304 *, struct vm_area_struct___339 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___304 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___304 *, struct page___339 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___304 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___304 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___304 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___304 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___304 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___304 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___304 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___304 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___304 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___304 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___304 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___304 *, u64);
	u64 (*get_required_mask)(struct device___304 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___232;

struct fwnode_handle___232 {
	struct fwnode_handle___232 *secondary;
	const struct fwnode_operations___232 *ops;
};

struct property___73;

struct device_node___77 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___232 fwnode;
	struct property___73 *properties;
	struct property___73 *deadprops;
	struct device_node___77 *parent;
	struct device_node___77 *child;
	struct device_node___77 *sibling;
	struct kobject___325 kobj;
	long unsigned int _flags;
	void *data;
};

struct platform_device___18 {
	const char *name;
	int id;
	bool id_auto;
	struct device___304 dev;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct platform_device_info___4 {
	struct device___304 *parent;
	struct fwnode_handle___232 *fwnode;
	const char *name;
	int id;
	const struct resource *res;
	unsigned int num_res;
	const void *data;
	size_t size_data;
	u64 dma_mask;
	struct property_entry___2 *properties;
};

struct platform_driver___16 {
	int (*probe)(struct platform_device___18 *);
	int (*remove)(struct platform_device___18 *);
	void (*shutdown)(struct platform_device___18 *);
	int (*suspend)(struct platform_device___18 *, pm_message_t);
	int (*resume)(struct platform_device___18 *);
	struct device_driver___304 driver;
	const struct platform_device_id *id_table;
	bool prevent_deferred_probe;
};

struct early_platform_driver {
	const char *class_str;
	struct platform_driver___16 *pdrv;
	struct list_head list;
	int requested_id;
	char *buffer;
	int bufsize;
};

struct node___196 {
	struct device___304 dev;
};

struct fwnode_reference_args___232;

struct fwnode_endpoint___232;

struct fwnode_operations___232 {
	struct fwnode_handle___232 * (*get)(struct fwnode_handle___232 *);
	void (*put)(struct fwnode_handle___232 *);
	bool (*device_is_available)(const struct fwnode_handle___232 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___232 *, const struct device___304 *);
	bool (*property_present)(const struct fwnode_handle___232 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___232 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___232 *, const char *, const char **, size_t);
	struct fwnode_handle___232 * (*get_parent)(const struct fwnode_handle___232 *);
	struct fwnode_handle___232 * (*get_next_child_node)(const struct fwnode_handle___232 *, struct fwnode_handle___232 *);
	struct fwnode_handle___232 * (*get_named_child_node)(const struct fwnode_handle___232 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___232 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___232 *);
	struct fwnode_handle___232 * (*graph_get_next_endpoint)(const struct fwnode_handle___232 *, struct fwnode_handle___232 *);
	struct fwnode_handle___232 * (*graph_get_remote_endpoint)(const struct fwnode_handle___232 *);
	struct fwnode_handle___232 * (*graph_get_port_parent)(struct fwnode_handle___232 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___232 *, struct fwnode_endpoint___232 *);
};

struct fwnode_endpoint___232 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___232 *local_fwnode;
};

struct fwnode_reference_args___232 {
	struct fwnode_handle___232 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct property___73 {
	char *name;
	int length;
	void *value;
	struct property___73 *next;
	long unsigned int _flags;
	struct bin_attribute___301 attr;
};

struct irq_desc___18;

typedef void (*irq_flow_handler_t___18)(struct irq_desc___18 *);

struct irq_chip___25;

struct irq_data___25 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___11 *common;
	struct irq_chip___25 *chip;
	struct irq_domain___25 *domain;
	struct irq_data___25 *parent_data;
	void *chip_data;
};

struct irqaction___15;

struct irq_desc___18 {
	struct irq_common_data___11 irq_common_data;
	struct irq_data___25 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___18 handle_irq;
	struct irqaction___15 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int irq_count;
	unsigned int tot_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___325 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___276 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___337;

struct address_space___337 {
	struct inode___338 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___339 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___337 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___326)(struct vm_area_struct___339 *, long unsigned int, const struct page___339 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___326)(struct page___339 *, void *);

struct dev_pagemap___326 {
	dev_page_fault_t___326 page_fault;
	dev_page_free_t___326 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___304 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___338 {
	struct task_struct___339 *task;
	struct core_thread___338 *next;
};

struct core_state___338 {
	atomic_t nr_threads;
	struct core_thread___338 dumper;
	struct completion startup;
};

struct vm_fault___326 {
	struct vm_area_struct___339 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___339 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___339 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___338 prealloc_pte;
};

struct irq_chip___25 {
	struct device___304 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___25 *);
	void (*irq_shutdown)(struct irq_data___25 *);
	void (*irq_enable)(struct irq_data___25 *);
	void (*irq_disable)(struct irq_data___25 *);
	void (*irq_ack)(struct irq_data___25 *);
	void (*irq_mask)(struct irq_data___25 *);
	void (*irq_mask_ack)(struct irq_data___25 *);
	void (*irq_unmask)(struct irq_data___25 *);
	void (*irq_eoi)(struct irq_data___25 *);
	int (*irq_set_affinity)(struct irq_data___25 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___25 *);
	int (*irq_set_type)(struct irq_data___25 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___25 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___25 *);
	void (*irq_bus_sync_unlock)(struct irq_data___25 *);
	void (*irq_cpu_online)(struct irq_data___25 *);
	void (*irq_cpu_offline)(struct irq_data___25 *);
	void (*irq_suspend)(struct irq_data___25 *);
	void (*irq_resume)(struct irq_data___25 *);
	void (*irq_pm_shutdown)(struct irq_data___25 *);
	void (*irq_calc_mask)(struct irq_data___25 *);
	void (*irq_print_chip)(struct irq_data___25 *, struct seq_file___286 *);
	int (*irq_request_resources)(struct irq_data___25 *);
	void (*irq_release_resources)(struct irq_data___25 *);
	void (*irq_compose_msi_msg)(struct irq_data___25 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___25 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___25 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___25 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___25 *, void *);
	void (*ipi_send_single)(struct irq_data___25 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___25 *, const struct cpumask *);
	long unsigned int flags;
};

struct irqaction___15 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___15 *next;
	irq_handler_t thread_fn;
	struct task_struct___339 *thread;
	struct irqaction___15 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip_type___14 {
	struct irq_chip___25 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___18 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___14 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___14 *);
	void (*resume)(struct irq_chip_generic___14 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___25 *domain;
	struct list_head list;
	struct irq_chip_type___14 chip_types[0];
};

struct irq_domain_chip_generic___13 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___14 *gc[0];
};

struct irq_fwspec___25 {
	struct fwnode_handle___232 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___25 {
	int (*match)(struct irq_domain___25 *, struct device_node___77 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___25 *, struct irq_fwspec___25 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___25 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___25 *, unsigned int);
	int (*xlate)(struct irq_domain___25 *, struct device_node___77 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___25 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___25 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___25 *, struct irq_data___25 *, bool);
	void (*deactivate)(struct irq_domain___25 *, struct irq_data___25 *);
	int (*translate)(struct irq_domain___25 *, struct irq_fwspec___25 *, long unsigned int *, unsigned int *);
};

struct kernel_param_ops___273 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___273 *);
	int (*get)(char *, const struct kernel_param___273 *);
	void (*free)(void *);
};

struct kparam_array___273;

struct kernel_param___273 {
	const char *name;
	struct module___276 *mod;
	const struct kernel_param_ops___273 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___273 *arr;
	};
};

struct kparam_array___273 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___273 *ops;
	void *elem;
};

struct module_attribute___273 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___273 *, struct module_kobject___273 *, char *);
	ssize_t (*store)(struct module_attribute___273 *, struct module_kobject___273 *, const char *, size_t);
	void (*setup)(struct module___276 *, const char *);
	int (*test)(struct module___276 *);
	void (*free)(struct module___276 *);
};

struct dentry_operations___337;

struct super_block___337;

struct dentry___337 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___337 *d_parent;
	struct qstr d_name;
	struct inode___338 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___337 *d_op;
	struct super_block___337 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___337;

struct block_device___337;

struct cdev___77;

struct inode___338 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___337 *i_op;
	struct super_block___337 *i_sb;
	struct address_space___337 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___339 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___338 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___337 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___337 *i_bdev;
		struct cdev___77 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___337 {
	int (*d_revalidate)(struct dentry___337 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___337 *, unsigned int);
	int (*d_hash)(const struct dentry___337 *, struct qstr *);
	int (*d_compare)(const struct dentry___337 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___337 *);
	int (*d_init)(struct dentry___337 *);
	void (*d_release)(struct dentry___337 *);
	void (*d_prune)(struct dentry___337 *);
	void (*d_iput)(struct dentry___337 *, struct inode___338 *);
	char * (*d_dname)(struct dentry___337 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___338 *);
	int (*d_manage)(const struct path___338 *, bool);
	struct dentry___337 * (*d_real)(struct dentry___337 *, const struct inode___338 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___337;

struct mem_dqinfo___337 {
	struct quota_format_type___337 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___337;

struct quota_info___337 {
	unsigned int flags;
	struct rw_semaphore___339 dqio_sem;
	struct inode___338 *files[3];
	struct mem_dqinfo___337 info[3];
	const struct quota_format_ops___337 *ops[3];
};

struct rcuwait___337 {
	struct task_struct___339 *task;
};

struct percpu_rw_semaphore___337 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___339 rw_sem;
	struct rcuwait___337 writer;
	int readers_block;
};

struct sb_writers___337 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___337 rw_sem[3];
};

struct file_system_type___337;

struct super_operations___337;

struct dquot_operations___337;

struct quotactl_ops___337;

struct super_block___337 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___337 *s_type;
	const struct super_operations___337 *s_op;
	const struct dquot_operations___337 *dq_op;
	const struct quotactl_ops___337 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___337 *s_root;
	struct rw_semaphore___339 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___337 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___337 s_dquot;
	struct sb_writers___337 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___337 *s_d_op;
	int cleancache_poolid;
	struct shrinker___125 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___338 {
	struct file___338 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___338 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___337 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___338 *ia_file;
};

struct dquot___337 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___337 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___337 {
	int qf_fmt_id;
	const struct quota_format_ops___337 *qf_ops;
	struct module___276 *qf_owner;
	struct quota_format_type___337 *qf_next;
};

struct quota_format_ops___337 {
	int (*check_quota_file)(struct super_block___337 *, int);
	int (*read_file_info)(struct super_block___337 *, int);
	int (*write_file_info)(struct super_block___337 *, int);
	int (*free_file_info)(struct super_block___337 *, int);
	int (*read_dqblk)(struct dquot___337 *);
	int (*commit_dqblk)(struct dquot___337 *);
	int (*release_dqblk)(struct dquot___337 *);
	int (*get_next_id)(struct super_block___337 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___337 {
	int (*write_dquot)(struct dquot___337 *);
	struct dquot___337 * (*alloc_dquot)(struct super_block___337 *, int);
	void (*destroy_dquot)(struct dquot___337 *);
	int (*acquire_dquot)(struct dquot___337 *);
	int (*release_dquot)(struct dquot___337 *);
	int (*mark_dirty)(struct dquot___337 *);
	int (*write_info)(struct super_block___337 *, int);
	qsize_t * (*get_reserved_space)(struct inode___338 *);
	int (*get_projid)(struct inode___338 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___338 *, qsize_t *);
	int (*get_next_id)(struct super_block___337 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___337 {
	int (*quota_on)(struct super_block___337 *, int, int, const struct path___338 *);
	int (*quota_off)(struct super_block___337 *, int);
	int (*quota_enable)(struct super_block___337 *, unsigned int);
	int (*quota_disable)(struct super_block___337 *, unsigned int);
	int (*quota_sync)(struct super_block___337 *, int);
	int (*set_info)(struct super_block___337 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___337 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___337 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___337 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___337 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___337 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___337 {
	int (*writepage)(struct page___339 *, struct writeback_control___3 *);
	int (*readpage)(struct file___338 *, struct page___339 *);
	int (*writepages)(struct address_space___337 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___339 *);
	int (*readpages)(struct file___338 *, struct address_space___337 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___338 *, struct address_space___337 *, loff_t, unsigned int, unsigned int, struct page___339 **, void **);
	int (*write_end)(struct file___338 *, struct address_space___337 *, loff_t, unsigned int, unsigned int, struct page___339 *, void *);
	sector_t (*bmap)(struct address_space___337 *, sector_t);
	void (*invalidatepage)(struct page___339 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___339 *, gfp_t);
	void (*freepage)(struct page___339 *);
	ssize_t (*direct_IO)(struct kiocb___338 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___337 *, struct page___339 *, struct page___339 *, enum migrate_mode);
	bool (*isolate_page)(struct page___339 *, isolate_mode_t);
	void (*putback_page)(struct page___339 *);
	int (*launder_page)(struct page___339 *);
	int (*is_partially_uptodate)(struct page___339 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___339 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___337 *, struct page___339 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___338 *, sector_t *);
	void (*swap_deactivate)(struct file___338 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___337 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___338 *bd_inode;
	struct super_block___337 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___337 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___77 {
	struct kobject___325 kobj;
	struct module___276 *owner;
	const struct file_operations___338 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___337 {
	struct dentry___337 * (*lookup)(struct inode___338 *, struct dentry___337 *, unsigned int);
	const char * (*get_link)(struct dentry___337 *, struct inode___338 *, struct delayed_call *);
	int (*permission)(struct inode___338 *, int);
	struct posix_acl * (*get_acl)(struct inode___338 *, int);
	int (*readlink)(struct dentry___337 *, char *, int);
	int (*create)(struct inode___338 *, struct dentry___337 *, umode_t, bool);
	int (*link)(struct dentry___337 *, struct inode___338 *, struct dentry___337 *);
	int (*unlink)(struct inode___338 *, struct dentry___337 *);
	int (*symlink)(struct inode___338 *, struct dentry___337 *, const char *);
	int (*mkdir)(struct inode___338 *, struct dentry___337 *, umode_t);
	int (*rmdir)(struct inode___338 *, struct dentry___337 *);
	int (*mknod)(struct inode___338 *, struct dentry___337 *, umode_t, dev_t);
	int (*rename)(struct inode___338 *, struct dentry___337 *, struct inode___338 *, struct dentry___337 *, unsigned int);
	int (*setattr)(struct dentry___337 *, struct iattr___337 *);
	int (*getattr)(const struct path___338 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___337 *, char *, size_t);
	int (*fiemap)(struct inode___338 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___338 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___338 *, struct dentry___337 *, struct file___338 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___338 *, struct dentry___337 *, umode_t);
	int (*set_acl)(struct inode___338 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___337 {
	void (*fl_copy_lock)(struct file_lock___338 *, struct file_lock___338 *);
	void (*fl_release_private)(struct file_lock___338 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___337;

struct lock_manager_operations___337;

struct file_lock___338 {
	struct file_lock___338 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___338 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___337 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___337 *fl_ops;
	const struct lock_manager_operations___337 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___337 {
	int (*lm_compare_owner)(struct file_lock___338 *, struct file_lock___338 *);
	long unsigned int (*lm_owner_key)(struct file_lock___338 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___338 *);
	int (*lm_grant)(struct file_lock___338 *, int);
	bool (*lm_break)(struct file_lock___338 *);
	int (*lm_change)(struct file_lock___338 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___338 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___337 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___337 *fa_next;
	struct file___338 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___337 {
	const char *name;
	int fs_flags;
	struct dentry___337 * (*mount)(struct file_system_type___337 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___337 *);
	struct module___276 *owner;
	struct file_system_type___337 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___337 {
	struct inode___338 * (*alloc_inode)(struct super_block___337 *);
	void (*destroy_inode)(struct inode___338 *);
	void (*dirty_inode)(struct inode___338 *, int);
	int (*write_inode)(struct inode___338 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___338 *);
	void (*evict_inode)(struct inode___338 *);
	void (*put_super)(struct super_block___337 *);
	int (*sync_fs)(struct super_block___337 *, int);
	int (*freeze_super)(struct super_block___337 *);
	int (*freeze_fs)(struct super_block___337 *);
	int (*thaw_super)(struct super_block___337 *);
	int (*unfreeze_fs)(struct super_block___337 *);
	int (*statfs)(struct dentry___337 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___337 *, int *, char *);
	void (*umount_begin)(struct super_block___337 *);
	int (*show_options)(struct seq_file___286 *, struct dentry___337 *);
	int (*show_devname)(struct seq_file___286 *, struct dentry___337 *);
	int (*show_path)(struct seq_file___286 *, struct dentry___337 *);
	int (*show_stats)(struct seq_file___286 *, struct dentry___337 *);
	ssize_t (*quota_read)(struct super_block___337 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___337 *, int, const char *, size_t, loff_t);
	struct dquot___337 ** (*get_dquots)(struct inode___338 *);
	int (*bdev_try_to_free_page)(struct super_block___337 *, struct page___339 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___337 *, struct shrink_control___125 *);
	long int (*free_cached_objects)(struct super_block___337 *, struct shrink_control___125 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___326(struct page___339 *);

struct dev_power_governor___4 {
	bool (*power_down_ok)(struct dev_pm_domain___304 *);
	bool (*suspend_ok)(struct device___304 *);
};

struct acpi_device___14;

struct acpi_hotplug_profile___14 {
	struct kobject___325 kobj;
	int (*scan_dependent)(struct acpi_device___14 *);
	void (*notify_online)(struct acpi_device___14 *);
	bool enabled: 1;
	bool demand_offline: 1;
};

struct acpi_device_wakeup_context___14 {
	void (*func)(struct acpi_device_wakeup_context___14 *);
	struct device___304 *dev;
};

struct acpi_device_wakeup___14 {
	acpi_handle gpe_device;
	u64 gpe_number;
	u64 sleep_state;
	struct list_head resources;
	struct acpi_device_wakeup_flags flags;
	struct acpi_device_wakeup_context___14 context;
	struct wakeup_source___3 *ws;
	int prepare_count;
	int enable_count;
};

struct acpi_scan_handler___14;

struct acpi_hotplug_context___14;

struct acpi_driver___14;

struct acpi_device___14 {
	int device_type;
	acpi_handle handle;
	struct fwnode_handle___232 fwnode;
	struct acpi_device___14 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup___14 wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_device_data data;
	struct acpi_scan_handler___14 *handler;
	struct acpi_hotplug_context___14 *hp;
	struct acpi_driver___14 *driver;
	const struct acpi_gpio_mapping *driver_gpios;
	void *driver_data;
	struct device___304 dev;
	unsigned int physical_node_count;
	unsigned int dep_unmet;
	struct list_head physical_node_list;
	struct mutex physical_node_lock;
	void (*remove)(struct acpi_device___14 *);
};

struct acpi_scan_handler___14 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	bool (*match)(const char *, const struct acpi_device_id **);
	int (*attach)(struct acpi_device___14 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___14 *);
	void (*bind)(struct device___304 *);
	void (*unbind)(struct device___304 *);
	struct acpi_hotplug_profile___14 hotplug;
};

struct acpi_hotplug_context___14 {
	struct acpi_device___14 *self;
	int (*notify)(struct acpi_device___14 *, u32);
	void (*uevent)(struct acpi_device___14 *, u32);
	void (*fixup)(struct acpi_device___14 *);
};

typedef int (*acpi_op_add___14)(struct acpi_device___14 *);

typedef int (*acpi_op_remove___14)(struct acpi_device___14 *);

typedef void (*acpi_op_notify___14)(struct acpi_device___14 *, u32);

struct acpi_device_ops___14 {
	acpi_op_add___14 add;
	acpi_op_remove___14 remove;
	acpi_op_notify___14 notify;
};

struct acpi_driver___14 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___14 ops;
	struct device_driver___304 drv;
	struct module___276 *owner;
};

typedef int (*key_restrict_link_func_t___314)(struct key___313 *, const struct key_type *, const union key_payload *, struct key___313 *);

struct key_restriction___313;

struct key___313 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___339 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___313 *restrict_link;
};

struct key_restriction___313 {
	key_restrict_link_func_t___314 check;
	struct key___313 *key;
	struct key_type *keytype;
};

struct seq_operations___285 {
	void * (*start)(struct seq_file___286 *, loff_t *);
	void (*stop)(struct seq_file___286 *, void *);
	void * (*next)(struct seq_file___286 *, void *, loff_t *);
	int (*show)(struct seq_file___286 *, void *);
};

struct dev_pm_qos_request___15 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___304 *dev;
};

struct platform_object {
	struct platform_device___18 pdev;
	char name[0];
};

struct module___277;

struct file___339;

struct kiocb___339;

struct poll_table_struct___206;

struct vm_area_struct___340;

struct inode___339;

struct file_lock___339;

struct page___340;

struct seq_file___287;

struct file_operations___339 {
	struct module___277 *owner;
	loff_t (*llseek)(struct file___339 *, loff_t, int);
	ssize_t (*read)(struct file___339 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___339 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___339 *, struct iov_iter___147 *);
	ssize_t (*write_iter)(struct kiocb___339 *, struct iov_iter___147 *);
	int (*iopoll)(struct kiocb___339 *, bool);
	int (*iterate)(struct file___339 *, struct dir_context *);
	int (*iterate_shared)(struct file___339 *, struct dir_context *);
	__poll_t (*poll)(struct file___339 *, struct poll_table_struct___206 *);
	long int (*unlocked_ioctl)(struct file___339 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___339 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___339 *, struct vm_area_struct___340 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___339 *, struct file___339 *);
	int (*flush)(struct file___339 *, fl_owner_t);
	int (*release)(struct inode___339 *, struct file___339 *);
	int (*fsync)(struct file___339 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___339 *, int);
	int (*lock)(struct file___339 *, int, struct file_lock___339 *);
	ssize_t (*sendpage)(struct file___339 *, struct page___340 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___339 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___339 *, int, struct file_lock___339 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___339 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___339 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___339 *, long int, struct file_lock___339 **, void **);
	long int (*fallocate)(struct file___339 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___287 *, struct file___339 *);
	ssize_t (*copy_file_range)(struct file___339 *, loff_t, struct file___339 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___339 *, loff_t, struct file___339 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___339 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___339 {
	u64 seqnum;
	struct vm_area_struct___340 *vmas[4];
};

struct page_frag___339 {
	struct page___340 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___339;

struct pid___211;

struct cred___314;

struct nsproxy___265;

struct signal_struct___247;

struct vm_struct___249;

struct task_struct___340 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___340 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___339 *mm;
	struct mm_struct___339 *active_mm;
	struct vmacache___339 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___340 *real_parent;
	struct task_struct___340 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___340 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___211 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___211 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___211 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___314 *ptracer_cred;
	const struct cred___314 *real_cred;
	const struct cred___314 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___265 *nsproxy;
	struct signal_struct___247 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___340 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___84 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___339 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___340 *oom_reaper_list;
	struct vm_struct___249 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___135 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___340 *pgtable_t___339;

struct address_space___338;

struct dev_pagemap___327;

struct page___340 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___338 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___340 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___339 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___339 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___327 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___339;

struct lruvec___339 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___339 *pgdat;
};

struct zone___339 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___339 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___339 {
	struct zone___339 *zone;
	int zone_idx;
};

struct zonelist___339 {
	struct zoneref___339 _zonerefs[25];
};

struct pglist_data___339 {
	struct zone___339 node_zones[3];
	struct zonelist___339 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___340 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___340 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___339 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___340 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___340 *owner;
};

struct secondary_data___340 {
	void *stack;
	struct task_struct___340 *task;
	long int status;
};

struct clock_event_device___17;

struct arch_timer_erratum_workaround___17 {
	enum arch_timer_erratum_match_type match_type;
	const void *id;
	const char *desc;
	u32 (*read_cntp_tval_el0)();
	u32 (*read_cntv_tval_el0)();
	u64 (*read_cntpct_el0)();
	u64 (*read_cntvct_el0)();
	int (*set_next_event_phys)(long unsigned int, struct clock_event_device___17 *);
	int (*set_next_event_virt)(long unsigned int, struct clock_event_device___17 *);
};

struct clock_event_device___17 {
	void (*event_handler)(struct clock_event_device___17 *);
	int (*set_next_event)(long unsigned int, struct clock_event_device___17 *);
	int (*set_next_ktime)(ktime_t, struct clock_event_device___17 *);
	ktime_t next_event;
	u64 max_delta_ns;
	u64 min_delta_ns;
	u32 mult;
	u32 shift;
	enum clock_event_state state_use_accessors;
	unsigned int features;
	long unsigned int retries;
	int (*set_state_periodic)(struct clock_event_device___17 *);
	int (*set_state_oneshot)(struct clock_event_device___17 *);
	int (*set_state_oneshot_stopped)(struct clock_event_device___17 *);
	int (*set_state_shutdown)(struct clock_event_device___17 *);
	int (*tick_resume)(struct clock_event_device___17 *);
	void (*broadcast)(const struct cpumask *);
	void (*suspend)(struct clock_event_device___17 *);
	void (*resume)(struct clock_event_device___17 *);
	long unsigned int min_delta_ticks;
	long unsigned int max_delta_ticks;
	const char *name;
	int rating;
	int irq;
	int bound_on;
	const struct cpumask *cpumask;
	struct list_head list;
	struct module___277 *owner;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct blocking_notifier_head___339 {
	struct rw_semaphore___340 rwsem;
	struct notifier_block *head;
};

struct dentry___338;

struct path___339 {
	struct vfsmount *mnt;
	struct dentry___338 *dentry;
};

struct fown_struct___211 {
	rwlock_t lock;
	struct pid___211 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___339 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___339 f_path;
	struct inode___339 *f_inode;
	const struct file_operations___339 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___211 f_owner;
	const struct cred___314 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___338 *f_mapping;
	errseq_t f_wb_err;
};

struct key___314;

struct user_struct___314;

struct cred___314 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___314 *session_keyring;
	struct key___314 *process_keyring;
	struct key___314 *thread_keyring;
	struct key___314 *request_key_auth;
	void *security;
	struct user_struct___314 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___332;

struct kernfs_elem_dir___332 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___332 *root;
};

struct kernfs_node___333;

struct kernfs_syscall_ops___332;

struct kernfs_root___332 {
	struct kernfs_node___333 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___332 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___332 {
	struct kernfs_node___333 *target_kn;
};

struct kernfs_ops___332;

struct kernfs_elem_attr___332 {
	const struct kernfs_ops___332 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___333 *notify_next;
};

struct kernfs_node___333 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___333 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___332 dir;
		struct kernfs_elem_symlink___332 symlink;
		struct kernfs_elem_attr___332 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___332;

struct kernfs_ops___332 {
	int (*open)(struct kernfs_open_file___332 *);
	void (*release)(struct kernfs_open_file___332 *);
	int (*seq_show)(struct seq_file___287 *, void *);
	void * (*seq_start)(struct seq_file___287 *, loff_t *);
	void * (*seq_next)(struct seq_file___287 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___287 *, void *);
	ssize_t (*read)(struct kernfs_open_file___332 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___332 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___332 *, struct vm_area_struct___340 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___332 *, struct poll_table_struct___206 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___332 {
	int (*remount_fs)(struct kernfs_root___332 *, int *, char *);
	int (*show_options)(struct seq_file___287 *, struct kernfs_root___332 *);
	int (*mkdir)(struct kernfs_node___333 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___333 *);
	int (*rename)(struct kernfs_node___333 *, struct kernfs_node___333 *, const char *);
	int (*show_path)(struct seq_file___287 *, struct kernfs_node___333 *, struct kernfs_root___332 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___286;

struct seq_file___287 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___286 *op;
	int poll_event;
	const struct file___339 *file;
	void *private;
};

struct vm_operations_struct___327;

struct kernfs_open_file___332 {
	struct kernfs_node___333 *kn;
	struct file___339 *file;
	struct seq_file___287 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___327 *vm_ops;
};

struct vm_fault___327;

struct vm_operations_struct___327 {
	void (*open)(struct vm_area_struct___340 *);
	void (*close)(struct vm_area_struct___340 *);
	int (*split)(struct vm_area_struct___340 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___340 *);
	vm_fault_t (*fault)(struct vm_fault___327 *);
	vm_fault_t (*huge_fault)(struct vm_fault___327 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___327 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___340 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___327 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___327 *);
	int (*access)(struct vm_area_struct___340 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___340 *);
	int (*set_policy)(struct vm_area_struct___340 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___340 *, long unsigned int);
	struct page___340 * (*find_special_page)(struct vm_area_struct___340 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___212)(struct file___339 *, wait_queue_head_t *, struct poll_table_struct___206 *);

struct poll_table_struct___206 {
	poll_queue_proc___212 _qproc;
	__poll_t _key;
};

struct vm_area_struct___340 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___340 *vm_next;
	struct vm_area_struct___340 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___339 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___327 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___339 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___326;

struct bin_attribute___302;

struct attribute_group___303 {
	const char *name;
	umode_t (*is_visible)(struct kobject___326 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___326 *, struct bin_attribute___302 *, int);
	struct attribute **attrs;
	struct bin_attribute___302 **bin_attrs;
};

struct kset___325;

struct kobj_type___325;

struct kobject___326 {
	const char *name;
	struct list_head entry;
	struct kobject___326 *parent;
	struct kset___325 *kset;
	struct kobj_type___325 *ktype;
	struct kernfs_node___333 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___302 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___339 *, struct kobject___326 *, struct bin_attribute___302 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___339 *, struct kobject___326 *, struct bin_attribute___302 *, char *, loff_t, size_t);
	int (*mmap)(struct file___339 *, struct kobject___326 *, struct bin_attribute___302 *, struct vm_area_struct___340 *);
};

struct sysfs_ops___325 {
	ssize_t (*show)(struct kobject___326 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___326 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___325;

struct kset___325 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___326 kobj;
	const struct kset_uevent_ops___325 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___325 {
	void (*release)(struct kobject___326 *);
	const struct sysfs_ops___325 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___27 * (*child_ns_type)(struct kobject___326 *);
	const void * (*namespace)(struct kobject___326 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___325 {
	int (* const filter)(struct kset___325 *, struct kobject___326 *);
	const char * (* const name)(struct kset___325 *, struct kobject___326 *);
	int (* const uevent)(struct kset___325 *, struct kobject___326 *, struct kobj_uevent_env *);
};

struct kobj_attribute___317 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___326 *, struct kobj_attribute___317 *, char *);
	ssize_t (*store)(struct kobject___326 *, struct kobj_attribute___317 *, const char *, size_t);
};

struct kernel_param___274;

struct kernel_param_ops___274 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___274 *);
	int (*get)(char *, const struct kernel_param___274 *);
	void (*free)(void *);
};

struct kparam_array___274;

struct kernel_param___274 {
	const char *name;
	struct module___277 *mod;
	const struct kernel_param_ops___274 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___274 *arr;
	};
};

struct kparam_array___274 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___274 *ops;
	void *elem;
};

struct module_kobject___274 {
	struct kobject___326 kobj;
	struct module___277 *mod;
	struct kobject___326 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___274 {
	struct module___277 *mod;
	struct latch_tree_node node;
};

struct module_layout___274 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___274 mtn;
};

struct module_attribute___274;

struct module___277 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___274 mkobj;
	struct module_attribute___274 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___326 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___274 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___274 core_layout;
	struct module_layout___274 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___274 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___274 *, struct module_kobject___274 *, char *);
	ssize_t (*store)(struct module_attribute___274 *, struct module_kobject___274 *, const char *, size_t);
	void (*setup)(struct module___277 *, const char *);
	int (*test)(struct module___277 *);
	void (*free)(struct module___277 *);
};

struct pid_namespace___211;

struct upid___211 {
	int nr;
	struct pid_namespace___211 *ns;
};

struct pid_namespace___211 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___340 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___211 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___338 *proc_self;
	struct dentry___338 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___3 *user_ns;
	struct ucounts___2 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___9 ns;
};

struct pid___211 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___211 numbers[1];
};

struct user_struct___314 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___314 *uid_keyring;
	struct key___314 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___339;

struct mm_struct___339 {
	struct {
		struct vm_area_struct___340 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___339 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___340 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___339 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___340 *owner;
		struct user_namespace___3 *user_ns;
		struct file___339 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___339 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct nsproxy___265 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___211 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct signal_struct___247 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___340 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___340 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___211 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___211 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___339 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___211 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_struct___249 {
	struct vm_struct___249 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___340 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___259 {
	struct task_struct___340 task;
	long unsigned int stack[8192];
};

struct device___305;

struct dev_pm_ops___305 {
	int (*prepare)(struct device___305 *);
	void (*complete)(struct device___305 *);
	int (*suspend)(struct device___305 *);
	int (*resume)(struct device___305 *);
	int (*freeze)(struct device___305 *);
	int (*thaw)(struct device___305 *);
	int (*poweroff)(struct device___305 *);
	int (*restore)(struct device___305 *);
	int (*suspend_late)(struct device___305 *);
	int (*resume_early)(struct device___305 *);
	int (*freeze_late)(struct device___305 *);
	int (*thaw_early)(struct device___305 *);
	int (*poweroff_late)(struct device___305 *);
	int (*restore_early)(struct device___305 *);
	int (*suspend_noirq)(struct device___305 *);
	int (*resume_noirq)(struct device___305 *);
	int (*freeze_noirq)(struct device___305 *);
	int (*thaw_noirq)(struct device___305 *);
	int (*poweroff_noirq)(struct device___305 *);
	int (*restore_noirq)(struct device___305 *);
	int (*runtime_suspend)(struct device___305 *);
	int (*runtime_resume)(struct device___305 *);
	int (*runtime_idle)(struct device___305 *);
};

struct dev_pm_qos___16;

struct dev_pm_info___305 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___3 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___4 *subsys_data;
	void (*set_latency_tolerance)(struct device___305 *, s32);
	struct dev_pm_qos___16 *qos;
};

struct device_private___4;

struct device_type___305;

struct bus_type___305;

struct device_driver___305;

struct dev_pm_domain___305;

struct device_node___78;

struct fwnode_handle___233;

struct class___305;

struct device___305 {
	struct device___305 *parent;
	struct device_private___4 *p;
	struct kobject___326 kobj;
	const char *init_name;
	const struct device_type___305 *type;
	struct mutex mutex;
	struct bus_type___305 *bus;
	struct device_driver___305 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___305 power;
	struct dev_pm_domain___305 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___78 *of_node;
	struct fwnode_handle___233 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___305 *class;
	const struct attribute_group___303 **groups;
	void (*release)(struct device___305 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct pm_qos_constraints___16 {
	struct plist_head list;
	s32 target_value;
	s32 default_value;
	s32 no_constraint_value;
	enum pm_qos_type type;
	struct blocking_notifier_head___339 *notifiers;
};

struct dev_pm_qos_request___16;

struct dev_pm_qos___16 {
	struct pm_qos_constraints___16 resume_latency;
	struct pm_qos_constraints___16 latency_tolerance;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___16 *resume_latency_req;
	struct dev_pm_qos_request___16 *latency_tolerance_req;
	struct dev_pm_qos_request___16 *flags_req;
};

struct dev_pm_domain___305 {
	struct dev_pm_ops___305 ops;
	void (*detach)(struct device___305 *, bool);
	int (*activate)(struct device___305 *);
	void (*sync)(struct device___305 *);
	void (*dismiss)(struct device___305 *);
};

struct subsys_private___4;

struct bus_type___305 {
	const char *name;
	const char *dev_name;
	struct device___305 *dev_root;
	const struct attribute_group___303 **bus_groups;
	const struct attribute_group___303 **dev_groups;
	const struct attribute_group___303 **drv_groups;
	int (*match)(struct device___305 *, struct device_driver___305 *);
	int (*uevent)(struct device___305 *, struct kobj_uevent_env *);
	int (*probe)(struct device___305 *);
	int (*remove)(struct device___305 *);
	void (*shutdown)(struct device___305 *);
	int (*online)(struct device___305 *);
	int (*offline)(struct device___305 *);
	int (*suspend)(struct device___305 *, pm_message_t);
	int (*resume)(struct device___305 *);
	int (*num_vf)(struct device___305 *);
	int (*dma_configure)(struct device___305 *);
	const struct dev_pm_ops___305 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private___4 *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct driver_private___4;

struct device_driver___305 {
	const char *name;
	struct bus_type___305 *bus;
	struct module___277 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___305 *);
	int (*remove)(struct device___305 *);
	void (*shutdown)(struct device___305 *);
	int (*suspend)(struct device___305 *, pm_message_t);
	int (*resume)(struct device___305 *);
	const struct attribute_group___303 **groups;
	const struct dev_pm_ops___305 *pm;
	void (*coredump)(struct device___305 *);
	struct driver_private___4 *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct subsys_private___4 {
	struct kset___325 subsys;
	struct kset___325 *devices_kset;
	struct list_head interfaces;
	struct mutex mutex;
	struct kset___325 *drivers_kset;
	struct klist klist_devices;
	struct klist klist_drivers;
	struct blocking_notifier_head___339 bus_notifier;
	unsigned int drivers_autoprobe: 1;
	struct bus_type___305 *bus;
	struct kset___325 glue_dirs;
	struct class___305 *class;
};

struct device_type___305 {
	const char *name;
	const struct attribute_group___303 **groups;
	int (*uevent)(struct device___305 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___305 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___305 *);
	const struct dev_pm_ops___305 *pm;
};

struct driver_private___4 {
	struct kobject___326 kobj;
	struct klist klist_devices;
	struct klist_node knode_bus;
	struct module_kobject___274 *mkobj;
	struct device_driver___305 *driver;
};

struct class___305 {
	const char *name;
	struct module___277 *owner;
	const struct attribute_group___303 **class_groups;
	const struct attribute_group___303 **dev_groups;
	struct kobject___326 *dev_kobj;
	int (*dev_uevent)(struct device___305 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___305 *, umode_t *);
	void (*class_release)(struct class___305 *);
	void (*dev_release)(struct device___305 *);
	int (*shutdown_pre)(struct device___305 *);
	const struct kobj_ns_type_operations___27 *ns_type;
	const void * (*namespace)(struct device___305 *);
	const struct dev_pm_ops___305 *pm;
	struct subsys_private___4 *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct device_attribute___31 {
	struct attribute attr;
	ssize_t (*show)(struct device___305 *, struct device_attribute___31 *, char *);
	ssize_t (*store)(struct device___305 *, struct device_attribute___31 *, const char *, size_t);
};

struct device_private___4 {
	struct klist klist_children;
	struct klist_node knode_parent;
	struct klist_node knode_driver;
	struct klist_node knode_bus;
	struct list_head deferred_probe;
	struct device___305 *device;
};

struct fwnode_operations___233;

struct fwnode_handle___233 {
	struct fwnode_handle___233 *secondary;
	const struct fwnode_operations___233 *ops;
};

struct property___74;

struct device_node___78 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___233 fwnode;
	struct property___74 *properties;
	struct property___74 *deadprops;
	struct device_node___78 *parent;
	struct device_node___78 *child;
	struct device_node___78 *sibling;
	struct kobject___326 kobj;
	long unsigned int _flags;
	void *data;
};

struct node___197 {
	struct device___305 dev;
};

struct cpu___4 {
	int node_id;
	int hotpluggable;
	struct device___305 dev;
};

struct fwnode_reference_args___233;

struct fwnode_endpoint___233;

struct fwnode_operations___233 {
	struct fwnode_handle___233 * (*get)(struct fwnode_handle___233 *);
	void (*put)(struct fwnode_handle___233 *);
	bool (*device_is_available)(const struct fwnode_handle___233 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___233 *, const struct device___305 *);
	bool (*property_present)(const struct fwnode_handle___233 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___233 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___233 *, const char *, const char **, size_t);
	struct fwnode_handle___233 * (*get_parent)(const struct fwnode_handle___233 *);
	struct fwnode_handle___233 * (*get_next_child_node)(const struct fwnode_handle___233 *, struct fwnode_handle___233 *);
	struct fwnode_handle___233 * (*get_named_child_node)(const struct fwnode_handle___233 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___233 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___233 *);
	struct fwnode_handle___233 * (*graph_get_next_endpoint)(const struct fwnode_handle___233 *, struct fwnode_handle___233 *);
	struct fwnode_handle___233 * (*graph_get_remote_endpoint)(const struct fwnode_handle___233 *);
	struct fwnode_handle___233 * (*graph_get_port_parent)(struct fwnode_handle___233 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___233 *, struct fwnode_endpoint___233 *);
};

struct fwnode_endpoint___233 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___233 *local_fwnode;
};

struct fwnode_reference_args___233 {
	struct fwnode_handle___233 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct dentry_operations___338;

struct super_block___338;

struct dentry___338 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___338 *d_parent;
	struct qstr d_name;
	struct inode___339 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___338 *d_op;
	struct super_block___338 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___338;

struct address_space___338 {
	struct inode___339 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___340 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___338 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___338;

struct block_device___338;

struct cdev___78;

struct inode___339 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___338 *i_op;
	struct super_block___338 *i_sb;
	struct address_space___338 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___340 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___339 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___338 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___338 *i_bdev;
		struct cdev___78 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___338 {
	int (*d_revalidate)(struct dentry___338 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___338 *, unsigned int);
	int (*d_hash)(const struct dentry___338 *, struct qstr *);
	int (*d_compare)(const struct dentry___338 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___338 *);
	int (*d_init)(struct dentry___338 *);
	void (*d_release)(struct dentry___338 *);
	void (*d_prune)(struct dentry___338 *);
	void (*d_iput)(struct dentry___338 *, struct inode___339 *);
	char * (*d_dname)(struct dentry___338 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___339 *);
	int (*d_manage)(const struct path___339 *, bool);
	struct dentry___338 * (*d_real)(struct dentry___338 *, const struct inode___339 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___338;

struct mem_dqinfo___338 {
	struct quota_format_type___338 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___338;

struct quota_info___338 {
	unsigned int flags;
	struct rw_semaphore___340 dqio_sem;
	struct inode___339 *files[3];
	struct mem_dqinfo___338 info[3];
	const struct quota_format_ops___338 *ops[3];
};

struct rcuwait___338 {
	struct task_struct___340 *task;
};

struct percpu_rw_semaphore___338 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___340 rw_sem;
	struct rcuwait___338 writer;
	int readers_block;
};

struct sb_writers___338 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___338 rw_sem[3];
};

struct file_system_type___338;

struct super_operations___338;

struct dquot_operations___338;

struct quotactl_ops___338;

struct super_block___338 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___338 *s_type;
	const struct super_operations___338 *s_op;
	const struct dquot_operations___338 *dq_op;
	const struct quotactl_ops___338 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___338 *s_root;
	struct rw_semaphore___340 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___338 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___338 s_dquot;
	struct sb_writers___338 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___338 *s_d_op;
	int cleancache_poolid;
	struct shrinker___125 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

typedef int (*dev_page_fault_t___327)(struct vm_area_struct___340 *, long unsigned int, const struct page___340 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___327)(struct page___340 *, void *);

struct dev_pagemap___327 {
	dev_page_fault_t___327 page_fault;
	dev_page_free_t___327 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___305 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___339 {
	struct task_struct___340 *task;
	struct core_thread___339 *next;
};

struct core_state___339 {
	atomic_t nr_threads;
	struct core_thread___339 dumper;
	struct completion startup;
};

struct vm_fault___327 {
	struct vm_area_struct___340 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___340 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___340 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___339 prealloc_pte;
};

struct kiocb___339 {
	struct file___339 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___339 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___338 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___339 *ia_file;
};

struct dquot___338 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___338 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___338 {
	int qf_fmt_id;
	const struct quota_format_ops___338 *qf_ops;
	struct module___277 *qf_owner;
	struct quota_format_type___338 *qf_next;
};

struct quota_format_ops___338 {
	int (*check_quota_file)(struct super_block___338 *, int);
	int (*read_file_info)(struct super_block___338 *, int);
	int (*write_file_info)(struct super_block___338 *, int);
	int (*free_file_info)(struct super_block___338 *, int);
	int (*read_dqblk)(struct dquot___338 *);
	int (*commit_dqblk)(struct dquot___338 *);
	int (*release_dqblk)(struct dquot___338 *);
	int (*get_next_id)(struct super_block___338 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___338 {
	int (*write_dquot)(struct dquot___338 *);
	struct dquot___338 * (*alloc_dquot)(struct super_block___338 *, int);
	void (*destroy_dquot)(struct dquot___338 *);
	int (*acquire_dquot)(struct dquot___338 *);
	int (*release_dquot)(struct dquot___338 *);
	int (*mark_dirty)(struct dquot___338 *);
	int (*write_info)(struct super_block___338 *, int);
	qsize_t * (*get_reserved_space)(struct inode___339 *);
	int (*get_projid)(struct inode___339 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___339 *, qsize_t *);
	int (*get_next_id)(struct super_block___338 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___338 {
	int (*quota_on)(struct super_block___338 *, int, int, const struct path___339 *);
	int (*quota_off)(struct super_block___338 *, int);
	int (*quota_enable)(struct super_block___338 *, unsigned int);
	int (*quota_disable)(struct super_block___338 *, unsigned int);
	int (*quota_sync)(struct super_block___338 *, int);
	int (*set_info)(struct super_block___338 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___338 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___338 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___338 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___338 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___338 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___338 {
	int (*writepage)(struct page___340 *, struct writeback_control___3 *);
	int (*readpage)(struct file___339 *, struct page___340 *);
	int (*writepages)(struct address_space___338 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___340 *);
	int (*readpages)(struct file___339 *, struct address_space___338 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___339 *, struct address_space___338 *, loff_t, unsigned int, unsigned int, struct page___340 **, void **);
	int (*write_end)(struct file___339 *, struct address_space___338 *, loff_t, unsigned int, unsigned int, struct page___340 *, void *);
	sector_t (*bmap)(struct address_space___338 *, sector_t);
	void (*invalidatepage)(struct page___340 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___340 *, gfp_t);
	void (*freepage)(struct page___340 *);
	ssize_t (*direct_IO)(struct kiocb___339 *, struct iov_iter___147 *);
	int (*migratepage)(struct address_space___338 *, struct page___340 *, struct page___340 *, enum migrate_mode);
	bool (*isolate_page)(struct page___340 *, isolate_mode_t);
	void (*putback_page)(struct page___340 *);
	int (*launder_page)(struct page___340 *);
	int (*is_partially_uptodate)(struct page___340 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___340 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___338 *, struct page___340 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___339 *, sector_t *);
	void (*swap_deactivate)(struct file___339 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___338 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___339 *bd_inode;
	struct super_block___338 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___338 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___78 {
	struct kobject___326 kobj;
	struct module___277 *owner;
	const struct file_operations___339 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___338 {
	struct dentry___338 * (*lookup)(struct inode___339 *, struct dentry___338 *, unsigned int);
	const char * (*get_link)(struct dentry___338 *, struct inode___339 *, struct delayed_call *);
	int (*permission)(struct inode___339 *, int);
	struct posix_acl * (*get_acl)(struct inode___339 *, int);
	int (*readlink)(struct dentry___338 *, char *, int);
	int (*create)(struct inode___339 *, struct dentry___338 *, umode_t, bool);
	int (*link)(struct dentry___338 *, struct inode___339 *, struct dentry___338 *);
	int (*unlink)(struct inode___339 *, struct dentry___338 *);
	int (*symlink)(struct inode___339 *, struct dentry___338 *, const char *);
	int (*mkdir)(struct inode___339 *, struct dentry___338 *, umode_t);
	int (*rmdir)(struct inode___339 *, struct dentry___338 *);
	int (*mknod)(struct inode___339 *, struct dentry___338 *, umode_t, dev_t);
	int (*rename)(struct inode___339 *, struct dentry___338 *, struct inode___339 *, struct dentry___338 *, unsigned int);
	int (*setattr)(struct dentry___338 *, struct iattr___338 *);
	int (*getattr)(const struct path___339 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___338 *, char *, size_t);
	int (*fiemap)(struct inode___339 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___339 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___339 *, struct dentry___338 *, struct file___339 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___339 *, struct dentry___338 *, umode_t);
	int (*set_acl)(struct inode___339 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___338 {
	void (*fl_copy_lock)(struct file_lock___339 *, struct file_lock___339 *);
	void (*fl_release_private)(struct file_lock___339 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___338;

struct lock_manager_operations___338;

struct file_lock___339 {
	struct file_lock___339 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___339 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___338 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___338 *fl_ops;
	const struct lock_manager_operations___338 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___338 {
	int (*lm_compare_owner)(struct file_lock___339 *, struct file_lock___339 *);
	long unsigned int (*lm_owner_key)(struct file_lock___339 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___339 *);
	int (*lm_grant)(struct file_lock___339 *, int);
	bool (*lm_break)(struct file_lock___339 *);
	int (*lm_change)(struct file_lock___339 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___339 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___338 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___338 *fa_next;
	struct file___339 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___338 {
	const char *name;
	int fs_flags;
	struct dentry___338 * (*mount)(struct file_system_type___338 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___338 *);
	struct module___277 *owner;
	struct file_system_type___338 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___338 {
	struct inode___339 * (*alloc_inode)(struct super_block___338 *);
	void (*destroy_inode)(struct inode___339 *);
	void (*dirty_inode)(struct inode___339 *, int);
	int (*write_inode)(struct inode___339 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___339 *);
	void (*evict_inode)(struct inode___339 *);
	void (*put_super)(struct super_block___338 *);
	int (*sync_fs)(struct super_block___338 *, int);
	int (*freeze_super)(struct super_block___338 *);
	int (*freeze_fs)(struct super_block___338 *);
	int (*thaw_super)(struct super_block___338 *);
	int (*unfreeze_fs)(struct super_block___338 *);
	int (*statfs)(struct dentry___338 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___338 *, int *, char *);
	void (*umount_begin)(struct super_block___338 *);
	int (*show_options)(struct seq_file___287 *, struct dentry___338 *);
	int (*show_devname)(struct seq_file___287 *, struct dentry___338 *);
	int (*show_path)(struct seq_file___287 *, struct dentry___338 *);
	int (*show_stats)(struct seq_file___287 *, struct dentry___338 *);
	ssize_t (*quota_read)(struct super_block___338 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___338 *, int, const char *, size_t, loff_t);
	struct dquot___338 ** (*get_dquots)(struct inode___339 *);
	int (*bdev_try_to_free_page)(struct super_block___338 *, struct page___340 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___338 *, struct shrink_control___125 *);
	long int (*free_cached_objects)(struct super_block___338 *, struct shrink_control___125 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*key_restrict_link_func_t___315)(struct key___314 *, const struct key_type *, const union key_payload *, struct key___314 *);

struct key_restriction___314;

struct key___314 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___340 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___314 *restrict_link;
};

struct key_restriction___314 {
	key_restrict_link_func_t___315 check;
	struct key___314 *key;
	struct key_type *keytype;
};

struct seq_operations___286 {
	void * (*start)(struct seq_file___287 *, loff_t *);
	void (*stop)(struct seq_file___287 *, void *);
	void * (*next)(struct seq_file___287 *, void *, loff_t *);
	int (*show)(struct seq_file___287 *, void *);
};

typedef void compound_page_dtor___327(struct page___340 *);

struct property___74 {
	char *name;
	int length;
	void *value;
	struct property___74 *next;
	long unsigned int _flags;
	struct bin_attribute___302 attr;
};

struct dev_pm_qos_request___16 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___305 *dev;
};

struct kimage___22;

typedef void *kexec_load_t___22(struct kimage___22 *, char *, long unsigned int, char *, long unsigned int, char *, long unsigned int);

struct kexec_file_ops___23 {
	kexec_probe_t *probe;
	kexec_load_t___22 *load;
	kexec_cleanup_t *cleanup;
};

struct kimage___22 {
	kimage_entry_t head;
	kimage_entry_t *entry;
	kimage_entry_t *last_entry;
	long unsigned int start;
	struct page___340 *control_code_page;
	struct page___340 *swap_page;
	void *vmcoreinfo_data_copy;
	long unsigned int nr_segments;
	struct kexec_segment segment[16];
	struct list_head control_pages;
	struct list_head dest_pages;
	struct list_head unusable_pages;
	long unsigned int control_page;
	unsigned int type: 1;
	unsigned int preserve_context: 1;
	unsigned int file_mode: 1;
	struct kimage_arch arch;
	void *kernel_buf;
	long unsigned int kernel_buf_len;
	void *initrd_buf;
	long unsigned int initrd_buf_len;
	char *cmdline_buf;
	long unsigned int cmdline_buf_len;
	const struct kexec_file_ops___23 *fops;
	void *image_loader_data;
	struct purgatory_info purgatory_info;
};

struct cpu_attr {
	struct device_attribute___31 attr;
	const struct cpumask * const map;
};

typedef struct kobject___326 *kobj_probe_t(dev_t, int *, void *);

struct probe {
	struct probe *next;
	dev_t dev;
	long unsigned int range;
	struct module___277 *owner;
	kobj_probe_t *get;
	int (*lock)(dev_t, void *);
	void *data;
};

struct kobj_map___2 {
	struct probe *probes[255];
	struct mutex *lock;
};

typedef void (*dr_release_t___18)(struct device___304 *, void *);

typedef int (*dr_match_t)(struct device___304 *, void *, void *);

struct devres_node {
	struct list_head entry;
	dr_release_t___18 release;
};

struct devres {
	struct devres_node node;
	long long unsigned int data[0];
};

struct devres_group {
	struct devres_node node[2];
	void *id;
	int color;
};

struct action_devres {
	void *data;
	void (*action)(void *);
};

struct pages_devres {
	long unsigned int addr;
	unsigned int order;
};

struct attribute_container {
	struct list_head node;
	struct klist containers;
	struct class___304 *class;
	const struct attribute_group___302 *grp;
	struct device_attribute___30 **attrs;
	int (*match)(struct attribute_container *, struct device___304 *);
	long unsigned int flags;
};

struct internal_container {
	struct klist_node node;
	struct attribute_container *cont;
	struct device___304 classdev;
};

struct transport_container;

struct transport_class {
	struct class___304 class;
	int (*setup)(struct transport_container *, struct device___304 *, struct device___304 *);
	int (*configure)(struct transport_container *, struct device___304 *, struct device___304 *);
	int (*remove)(struct transport_container *, struct device___304 *, struct device___304 *);
};

struct transport_container {
	struct attribute_container ac;
	const struct attribute_group___302 *statistics;
};

struct anon_transport_class {
	struct transport_class tclass;
	struct attribute_container container;
};

struct device_attribute___32 {
	struct attribute attr;
	ssize_t (*show)(struct device___115 *, struct device_attribute___32 *, char *);
	ssize_t (*store)(struct device___115 *, struct device_attribute___32 *, const char *, size_t);
};

struct module___278;

struct file___340;

struct kiocb___340;

struct iov_iter___148;

struct poll_table_struct___207;

struct vm_area_struct___341;

struct inode___340;

struct file_lock___340;

struct page___341;

struct pipe_inode_info___73;

struct seq_file___288;

struct file_operations___340 {
	struct module___278 *owner;
	loff_t (*llseek)(struct file___340 *, loff_t, int);
	ssize_t (*read)(struct file___340 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___340 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___340 *, struct iov_iter___148 *);
	ssize_t (*write_iter)(struct kiocb___340 *, struct iov_iter___148 *);
	int (*iopoll)(struct kiocb___340 *, bool);
	int (*iterate)(struct file___340 *, struct dir_context *);
	int (*iterate_shared)(struct file___340 *, struct dir_context *);
	__poll_t (*poll)(struct file___340 *, struct poll_table_struct___207 *);
	long int (*unlocked_ioctl)(struct file___340 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___340 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___340 *, struct vm_area_struct___341 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___340 *, struct file___340 *);
	int (*flush)(struct file___340 *, fl_owner_t);
	int (*release)(struct inode___340 *, struct file___340 *);
	int (*fsync)(struct file___340 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___340 *, int);
	int (*lock)(struct file___340 *, int, struct file_lock___340 *);
	ssize_t (*sendpage)(struct file___340 *, struct page___341 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___340 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___340 *, int, struct file_lock___340 *);
	ssize_t (*splice_write)(struct pipe_inode_info___73 *, struct file___340 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___340 *, loff_t *, struct pipe_inode_info___73 *, size_t, unsigned int);
	int (*setlease)(struct file___340 *, long int, struct file_lock___340 **, void **);
	long int (*fallocate)(struct file___340 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___288 *, struct file___340 *);
	ssize_t (*copy_file_range)(struct file___340 *, loff_t, struct file___340 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___340 *, loff_t, struct file___340 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___340 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___340 {
	u64 seqnum;
	struct vm_area_struct___341 *vmas[4];
};

struct page_frag___340 {
	struct page___341 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___340;

struct cred___315;

struct nsproxy___266;

struct signal_struct___248;

struct css_set___221;

struct vm_struct___250;

struct task_struct___341 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___341 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___340 *mm;
	struct mm_struct___340 *active_mm;
	struct vmacache___340 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___341 *real_parent;
	struct task_struct___341 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___341 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___211 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___211 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___211 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___315 *ptracer_cred;
	const struct cred___315 *real_cred;
	const struct cred___315 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___266 *nsproxy;
	struct signal_struct___248 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___341 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___84 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___221 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___73 *splice_pipe;
	struct page_frag___340 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___341 *oom_reaper_list;
	struct vm_struct___250 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___135 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___341 *pgtable_t___340;

struct address_space___339;

struct dev_pagemap___328;

struct page___341 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___339 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___341 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___340 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___340 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___328 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___340;

struct lruvec___340 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___340 *pgdat;
};

struct zone___340 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___340 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___340 {
	struct zone___340 *zone;
	int zone_idx;
};

struct zonelist___340 {
	struct zoneref___340 _zonerefs[25];
};

struct pglist_data___340 {
	struct zone___340 node_zones[3];
	struct zonelist___340 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___341 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___341 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___340 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___341 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___341 *owner;
};

struct secondary_data___341 {
	void *stack;
	struct task_struct___341 *task;
	long int status;
};

struct blocking_notifier_head___340 {
	struct rw_semaphore___341 rwsem;
	struct notifier_block *head;
};

struct key___315;

struct ucounts___236;

struct user_namespace___236 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___236 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___9 ns;
	long unsigned int flags;
	struct key___315 *persistent_keyring_register;
	struct rw_semaphore___341 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___236 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_root___333;

struct kernfs_elem_dir___333 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___333 *root;
};

struct kernfs_node___334;

struct kernfs_syscall_ops___333;

struct kernfs_root___333 {
	struct kernfs_node___334 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___333 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___333 {
	struct kernfs_node___334 *target_kn;
};

struct kernfs_ops___333;

struct kernfs_elem_attr___333 {
	const struct kernfs_ops___333 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___334 *notify_next;
};

struct kernfs_node___334 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___334 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___333 dir;
		struct kernfs_elem_symlink___333 symlink;
		struct kernfs_elem_attr___333 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___333;

struct kernfs_ops___333 {
	int (*open)(struct kernfs_open_file___333 *);
	void (*release)(struct kernfs_open_file___333 *);
	int (*seq_show)(struct seq_file___288 *, void *);
	void * (*seq_start)(struct seq_file___288 *, loff_t *);
	void * (*seq_next)(struct seq_file___288 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___288 *, void *);
	ssize_t (*read)(struct kernfs_open_file___333 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___333 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___333 *, struct vm_area_struct___341 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___333 *, struct poll_table_struct___207 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___333 {
	int (*remount_fs)(struct kernfs_root___333 *, int *, char *);
	int (*show_options)(struct seq_file___288 *, struct kernfs_root___333 *);
	int (*mkdir)(struct kernfs_node___334 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___334 *);
	int (*rename)(struct kernfs_node___334 *, struct kernfs_node___334 *, const char *);
	int (*show_path)(struct seq_file___288 *, struct kernfs_node___334 *, struct kernfs_root___333 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___287;

struct seq_file___288 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___287 *op;
	int poll_event;
	const struct file___340 *file;
	void *private;
};

struct vm_operations_struct___328;

struct kernfs_open_file___333 {
	struct kernfs_node___334 *kn;
	struct file___340 *file;
	struct seq_file___288 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___328 *vm_ops;
};

struct dentry___339;

struct path___340 {
	struct vfsmount *mnt;
	struct dentry___339 *dentry;
};

struct file___340 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___340 f_path;
	struct inode___340 *f_inode;
	const struct file_operations___340 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___211 f_owner;
	const struct cred___315 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___339 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___328;

struct vm_operations_struct___328 {
	void (*open)(struct vm_area_struct___341 *);
	void (*close)(struct vm_area_struct___341 *);
	int (*split)(struct vm_area_struct___341 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___341 *);
	vm_fault_t (*fault)(struct vm_fault___328 *);
	vm_fault_t (*huge_fault)(struct vm_fault___328 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___328 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___341 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___328 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___328 *);
	int (*access)(struct vm_area_struct___341 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___341 *);
	int (*set_policy)(struct vm_area_struct___341 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___341 *, long unsigned int);
	struct page___341 * (*find_special_page)(struct vm_area_struct___341 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___213)(struct file___340 *, wait_queue_head_t *, struct poll_table_struct___207 *);

struct poll_table_struct___207 {
	poll_queue_proc___213 _qproc;
	__poll_t _key;
};

struct vm_area_struct___341 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___341 *vm_next;
	struct vm_area_struct___341 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___340 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___328 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___340 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___327;

struct bin_attribute___303;

struct attribute_group___304 {
	const char *name;
	umode_t (*is_visible)(struct kobject___327 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___327 *, struct bin_attribute___303 *, int);
	struct attribute **attrs;
	struct bin_attribute___303 **bin_attrs;
};

struct kset___326;

struct kobj_type___326;

struct kobject___327 {
	const char *name;
	struct list_head entry;
	struct kobject___327 *parent;
	struct kset___326 *kset;
	struct kobj_type___326 *ktype;
	struct kernfs_node___334 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___303 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___340 *, struct kobject___327 *, struct bin_attribute___303 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___340 *, struct kobject___327 *, struct bin_attribute___303 *, char *, loff_t, size_t);
	int (*mmap)(struct file___340 *, struct kobject___327 *, struct bin_attribute___303 *, struct vm_area_struct___341 *);
};

struct sysfs_ops___326 {
	ssize_t (*show)(struct kobject___327 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___327 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___326;

struct kset___326 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___327 kobj;
	const struct kset_uevent_ops___326 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___326 {
	void (*release)(struct kobject___327 *);
	const struct sysfs_ops___326 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___27 * (*child_ns_type)(struct kobject___327 *);
	const void * (*namespace)(struct kobject___327 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___326 {
	int (* const filter)(struct kset___326 *, struct kobject___327 *);
	const char * (* const name)(struct kset___326 *, struct kobject___327 *);
	int (* const uevent)(struct kset___326 *, struct kobject___327 *, struct kobj_uevent_env *);
};

struct kobj_attribute___318 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___327 *, struct kobj_attribute___318 *, char *);
	ssize_t (*store)(struct kobject___327 *, struct kobj_attribute___318 *, const char *, size_t);
};

struct device___306;

struct dev_pm_ops___306 {
	int (*prepare)(struct device___306 *);
	void (*complete)(struct device___306 *);
	int (*suspend)(struct device___306 *);
	int (*resume)(struct device___306 *);
	int (*freeze)(struct device___306 *);
	int (*thaw)(struct device___306 *);
	int (*poweroff)(struct device___306 *);
	int (*restore)(struct device___306 *);
	int (*suspend_late)(struct device___306 *);
	int (*resume_early)(struct device___306 *);
	int (*freeze_late)(struct device___306 *);
	int (*thaw_early)(struct device___306 *);
	int (*poweroff_late)(struct device___306 *);
	int (*restore_early)(struct device___306 *);
	int (*suspend_noirq)(struct device___306 *);
	int (*resume_noirq)(struct device___306 *);
	int (*freeze_noirq)(struct device___306 *);
	int (*thaw_noirq)(struct device___306 *);
	int (*poweroff_noirq)(struct device___306 *);
	int (*restore_noirq)(struct device___306 *);
	int (*runtime_suspend)(struct device___306 *);
	int (*runtime_resume)(struct device___306 *);
	int (*runtime_idle)(struct device___306 *);
};

struct dev_pm_info___306 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___3 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___4 *subsys_data;
	void (*set_latency_tolerance)(struct device___306 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___306;

struct bus_type___306;

struct device_driver___306;

struct dev_pm_domain___306;

struct irq_domain___26;

struct dma_map_ops___103;

struct device_node___79;

struct fwnode_handle___234;

struct class___306;

struct device___306 {
	struct device___306 *parent;
	struct device_private *p;
	struct kobject___327 kobj;
	const char *init_name;
	const struct device_type___306 *type;
	struct mutex mutex;
	struct bus_type___306 *bus;
	struct device_driver___306 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___306 power;
	struct dev_pm_domain___306 *pm_domain;
	struct irq_domain___26 *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___103 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___79 *of_node;
	struct fwnode_handle___234 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___306 *class;
	const struct attribute_group___304 **groups;
	void (*release)(struct device___306 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___306 {
	struct dev_pm_ops___306 ops;
	void (*detach)(struct device___306 *, bool);
	int (*activate)(struct device___306 *);
	void (*sync)(struct device___306 *);
	void (*dismiss)(struct device___306 *);
};

struct user_struct___315 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___315 *uid_keyring;
	struct key___315 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___340;

struct mm_struct___340 {
	struct {
		struct vm_area_struct___341 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___340 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___341 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___340 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___341 *owner;
		struct user_namespace___236 *user_ns;
		struct file___340 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___340 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___315 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___315 *session_keyring;
	struct key___315 *process_keyring;
	struct key___315 *thread_keyring;
	struct key___315 *request_key_auth;
	void *security;
	struct user_struct___315 *user;
	struct user_namespace___236 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___51;

struct cgroup_namespace___221;

struct nsproxy___266 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net___51 *net_ns;
	struct cgroup_namespace___221 *cgroup_ns;
};

struct signal_struct___248 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___341 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___341 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___211 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___211 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___340 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___211 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___221;

struct cgroup___221;

struct css_set___221 {
	struct cgroup_subsys_state___221 *subsys[13];
	refcount_t refcount;
	struct css_set___221 *dom_cset;
	struct cgroup___221 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___221 *mg_src_cgrp;
	struct cgroup___221 *mg_dst_cgrp;
	struct css_set___221 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___339;

struct pipe_buffer___73;

struct pipe_inode_info___73 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___341 *tmp_page;
	struct fasync_struct___339 *fasync_readers;
	struct fasync_struct___339 *fasync_writers;
	struct pipe_buffer___73 *bufs;
	struct user_struct___315 *user;
};

struct vm_struct___250 {
	struct vm_struct___250 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___341 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___260 {
	struct task_struct___341 task;
	long unsigned int stack[8192];
};

struct bus_type___306 {
	const char *name;
	const char *dev_name;
	struct device___306 *dev_root;
	const struct attribute_group___304 **bus_groups;
	const struct attribute_group___304 **dev_groups;
	const struct attribute_group___304 **drv_groups;
	int (*match)(struct device___306 *, struct device_driver___306 *);
	int (*uevent)(struct device___306 *, struct kobj_uevent_env *);
	int (*probe)(struct device___306 *);
	int (*remove)(struct device___306 *);
	void (*shutdown)(struct device___306 *);
	int (*online)(struct device___306 *);
	int (*offline)(struct device___306 *);
	int (*suspend)(struct device___306 *, pm_message_t);
	int (*resume)(struct device___306 *);
	int (*num_vf)(struct device___306 *);
	int (*dma_configure)(struct device___306 *);
	const struct dev_pm_ops___306 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___306 {
	const char *name;
	struct bus_type___306 *bus;
	struct module___278 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___306 *);
	int (*remove)(struct device___306 *);
	void (*shutdown)(struct device___306 *);
	int (*suspend)(struct device___306 *, pm_message_t);
	int (*resume)(struct device___306 *);
	const struct attribute_group___304 **groups;
	const struct dev_pm_ops___306 *pm;
	void (*coredump)(struct device___306 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___306 {
	const char *name;
	const struct attribute_group___304 **groups;
	int (*uevent)(struct device___306 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___306 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___306 *);
	const struct dev_pm_ops___306 *pm;
};

struct module_kobject___275 {
	struct kobject___327 kobj;
	struct module___278 *mod;
	struct kobject___327 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___275 {
	struct module___278 *mod;
	struct latch_tree_node node;
};

struct module_layout___275 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___275 mtn;
};

struct module_attribute___275;

struct kernel_param___275;

struct module___278 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___275 mkobj;
	struct module_attribute___275 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___327 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___275 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___275 core_layout;
	struct module_layout___275 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct class___306 {
	const char *name;
	struct module___278 *owner;
	const struct attribute_group___304 **class_groups;
	const struct attribute_group___304 **dev_groups;
	struct kobject___327 *dev_kobj;
	int (*dev_uevent)(struct device___306 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___306 *, umode_t *);
	void (*class_release)(struct class___306 *);
	void (*dev_release)(struct device___306 *);
	int (*shutdown_pre)(struct device___306 *);
	const struct kobj_ns_type_operations___27 *ns_type;
	const void * (*namespace)(struct device___306 *);
	const struct dev_pm_ops___306 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct irq_domain_ops___26;

struct irq_domain_chip_generic___14;

struct irq_domain___26 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___26 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___234 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___14 *gc;
	struct irq_domain___26 *parent;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_direct_max_irq;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_tree_mutex;
	unsigned int linear_revmap[0];
};

struct dma_map_ops___103 {
	void * (*alloc)(struct device___306 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___306 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___306 *, struct vm_area_struct___341 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___306 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___306 *, struct page___341 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___306 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___306 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___306 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___306 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___306 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___306 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___306 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___306 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___306 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___306 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___306 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___306 *, u64);
	u64 (*get_required_mask)(struct device___306 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___234;

struct fwnode_handle___234 {
	struct fwnode_handle___234 *secondary;
	const struct fwnode_operations___234 *ops;
};

struct property___75;

struct device_node___79 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___234 fwnode;
	struct property___75 *properties;
	struct property___75 *deadprops;
	struct device_node___79 *parent;
	struct device_node___79 *child;
	struct device_node___79 *sibling;
	struct kobject___327 kobj;
	long unsigned int _flags;
	void *data;
};

struct fwnode_reference_args___234;

struct fwnode_endpoint___234;

struct fwnode_operations___234 {
	struct fwnode_handle___234 * (*get)(struct fwnode_handle___234 *);
	void (*put)(struct fwnode_handle___234 *);
	bool (*device_is_available)(const struct fwnode_handle___234 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___234 *, const struct device___306 *);
	bool (*property_present)(const struct fwnode_handle___234 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___234 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___234 *, const char *, const char **, size_t);
	struct fwnode_handle___234 * (*get_parent)(const struct fwnode_handle___234 *);
	struct fwnode_handle___234 * (*get_next_child_node)(const struct fwnode_handle___234 *, struct fwnode_handle___234 *);
	struct fwnode_handle___234 * (*get_named_child_node)(const struct fwnode_handle___234 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___234 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___234 *);
	struct fwnode_handle___234 * (*graph_get_next_endpoint)(const struct fwnode_handle___234 *, struct fwnode_handle___234 *);
	struct fwnode_handle___234 * (*graph_get_remote_endpoint)(const struct fwnode_handle___234 *);
	struct fwnode_handle___234 * (*graph_get_port_parent)(struct fwnode_handle___234 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___234 *, struct fwnode_endpoint___234 *);
};

struct fwnode_endpoint___234 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___234 *local_fwnode;
};

struct fwnode_reference_args___234 {
	struct fwnode_handle___234 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct kernel_param_ops___275 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___275 *);
	int (*get)(char *, const struct kernel_param___275 *);
	void (*free)(void *);
};

struct kparam_array___275;

struct kernel_param___275 {
	const char *name;
	struct module___278 *mod;
	const struct kernel_param_ops___275 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___275 *arr;
	};
};

struct kparam_array___275 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___275 *ops;
	void *elem;
};

struct module_attribute___275 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___275 *, struct module_kobject___275 *, char *);
	ssize_t (*store)(struct module_attribute___275 *, struct module_kobject___275 *, const char *, size_t);
	void (*setup)(struct module___278 *, const char *);
	int (*test)(struct module___278 *);
	void (*free)(struct module___278 *);
};

struct dentry_operations___339;

struct super_block___339;

struct dentry___339 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___339 *d_parent;
	struct qstr d_name;
	struct inode___340 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___339 *d_op;
	struct super_block___339 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___339;

struct address_space___339 {
	struct inode___340 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___341 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___339 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___339;

struct block_device___339;

struct cdev___79;

struct inode___340 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___339 *i_op;
	struct super_block___339 *i_sb;
	struct address_space___339 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___341 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___340 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___339 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___73 *i_pipe;
		struct block_device___339 *i_bdev;
		struct cdev___79 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___339 {
	int (*d_revalidate)(struct dentry___339 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___339 *, unsigned int);
	int (*d_hash)(const struct dentry___339 *, struct qstr *);
	int (*d_compare)(const struct dentry___339 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___339 *);
	int (*d_init)(struct dentry___339 *);
	void (*d_release)(struct dentry___339 *);
	void (*d_prune)(struct dentry___339 *);
	void (*d_iput)(struct dentry___339 *, struct inode___340 *);
	char * (*d_dname)(struct dentry___339 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___340 *);
	int (*d_manage)(const struct path___340 *, bool);
	struct dentry___339 * (*d_real)(struct dentry___339 *, const struct inode___340 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___339;

struct mem_dqinfo___339 {
	struct quota_format_type___339 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___339;

struct quota_info___339 {
	unsigned int flags;
	struct rw_semaphore___341 dqio_sem;
	struct inode___340 *files[3];
	struct mem_dqinfo___339 info[3];
	const struct quota_format_ops___339 *ops[3];
};

struct rcuwait___339 {
	struct task_struct___341 *task;
};

struct percpu_rw_semaphore___339 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___341 rw_sem;
	struct rcuwait___339 writer;
	int readers_block;
};

struct sb_writers___339 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___339 rw_sem[3];
};

struct file_system_type___339;

struct super_operations___339;

struct dquot_operations___339;

struct quotactl_ops___339;

struct super_block___339 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___339 *s_type;
	const struct super_operations___339 *s_op;
	const struct dquot_operations___339 *dq_op;
	const struct quotactl_ops___339 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___339 *s_root;
	struct rw_semaphore___341 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___339 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___339 s_dquot;
	struct sb_writers___339 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___339 *s_d_op;
	int cleancache_poolid;
	struct shrinker___125 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___236 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

typedef int (*dev_page_fault_t___328)(struct vm_area_struct___341 *, long unsigned int, const struct page___341 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___328)(struct page___341 *, void *);

struct dev_pagemap___328 {
	dev_page_fault_t___328 page_fault;
	dev_page_free_t___328 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___306 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___340 {
	struct task_struct___341 *task;
	struct core_thread___340 *next;
};

struct core_state___340 {
	atomic_t nr_threads;
	struct core_thread___340 dumper;
	struct completion startup;
};

struct vm_fault___328 {
	struct vm_area_struct___341 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___341 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___341 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___340 prealloc_pte;
};

struct kiocb___340 {
	struct file___340 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___340 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___339 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___340 *ia_file;
};

struct dquot___339 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___339 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___339 {
	int qf_fmt_id;
	const struct quota_format_ops___339 *qf_ops;
	struct module___278 *qf_owner;
	struct quota_format_type___339 *qf_next;
};

struct quota_format_ops___339 {
	int (*check_quota_file)(struct super_block___339 *, int);
	int (*read_file_info)(struct super_block___339 *, int);
	int (*write_file_info)(struct super_block___339 *, int);
	int (*free_file_info)(struct super_block___339 *, int);
	int (*read_dqblk)(struct dquot___339 *);
	int (*commit_dqblk)(struct dquot___339 *);
	int (*release_dqblk)(struct dquot___339 *);
	int (*get_next_id)(struct super_block___339 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___339 {
	int (*write_dquot)(struct dquot___339 *);
	struct dquot___339 * (*alloc_dquot)(struct super_block___339 *, int);
	void (*destroy_dquot)(struct dquot___339 *);
	int (*acquire_dquot)(struct dquot___339 *);
	int (*release_dquot)(struct dquot___339 *);
	int (*mark_dirty)(struct dquot___339 *);
	int (*write_info)(struct super_block___339 *, int);
	qsize_t * (*get_reserved_space)(struct inode___340 *);
	int (*get_projid)(struct inode___340 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___340 *, qsize_t *);
	int (*get_next_id)(struct super_block___339 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___339 {
	int (*quota_on)(struct super_block___339 *, int, int, const struct path___340 *);
	int (*quota_off)(struct super_block___339 *, int);
	int (*quota_enable)(struct super_block___339 *, unsigned int);
	int (*quota_disable)(struct super_block___339 *, unsigned int);
	int (*quota_sync)(struct super_block___339 *, int);
	int (*set_info)(struct super_block___339 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___339 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___339 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___339 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___339 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___339 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___339 {
	int (*writepage)(struct page___341 *, struct writeback_control___3 *);
	int (*readpage)(struct file___340 *, struct page___341 *);
	int (*writepages)(struct address_space___339 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___341 *);
	int (*readpages)(struct file___340 *, struct address_space___339 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___340 *, struct address_space___339 *, loff_t, unsigned int, unsigned int, struct page___341 **, void **);
	int (*write_end)(struct file___340 *, struct address_space___339 *, loff_t, unsigned int, unsigned int, struct page___341 *, void *);
	sector_t (*bmap)(struct address_space___339 *, sector_t);
	void (*invalidatepage)(struct page___341 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___341 *, gfp_t);
	void (*freepage)(struct page___341 *);
	ssize_t (*direct_IO)(struct kiocb___340 *, struct iov_iter___148 *);
	int (*migratepage)(struct address_space___339 *, struct page___341 *, struct page___341 *, enum migrate_mode);
	bool (*isolate_page)(struct page___341 *, isolate_mode_t);
	void (*putback_page)(struct page___341 *);
	int (*launder_page)(struct page___341 *);
	int (*is_partially_uptodate)(struct page___341 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___341 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___339 *, struct page___341 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___340 *, sector_t *);
	void (*swap_deactivate)(struct file___340 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct iov_iter___148 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___3 *bvec;
		struct pipe_inode_info___73 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___339 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___340 *bd_inode;
	struct super_block___339 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___339 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___79 {
	struct kobject___327 kobj;
	struct module___278 *owner;
	const struct file_operations___340 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___339 {
	struct dentry___339 * (*lookup)(struct inode___340 *, struct dentry___339 *, unsigned int);
	const char * (*get_link)(struct dentry___339 *, struct inode___340 *, struct delayed_call *);
	int (*permission)(struct inode___340 *, int);
	struct posix_acl * (*get_acl)(struct inode___340 *, int);
	int (*readlink)(struct dentry___339 *, char *, int);
	int (*create)(struct inode___340 *, struct dentry___339 *, umode_t, bool);
	int (*link)(struct dentry___339 *, struct inode___340 *, struct dentry___339 *);
	int (*unlink)(struct inode___340 *, struct dentry___339 *);
	int (*symlink)(struct inode___340 *, struct dentry___339 *, const char *);
	int (*mkdir)(struct inode___340 *, struct dentry___339 *, umode_t);
	int (*rmdir)(struct inode___340 *, struct dentry___339 *);
	int (*mknod)(struct inode___340 *, struct dentry___339 *, umode_t, dev_t);
	int (*rename)(struct inode___340 *, struct dentry___339 *, struct inode___340 *, struct dentry___339 *, unsigned int);
	int (*setattr)(struct dentry___339 *, struct iattr___339 *);
	int (*getattr)(const struct path___340 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___339 *, char *, size_t);
	int (*fiemap)(struct inode___340 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___340 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___340 *, struct dentry___339 *, struct file___340 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___340 *, struct dentry___339 *, umode_t);
	int (*set_acl)(struct inode___340 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___339 {
	void (*fl_copy_lock)(struct file_lock___340 *, struct file_lock___340 *);
	void (*fl_release_private)(struct file_lock___340 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___339;

struct file_lock___340 {
	struct file_lock___340 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___340 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___339 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___339 *fl_ops;
	const struct lock_manager_operations___339 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___339 {
	int (*lm_compare_owner)(struct file_lock___340 *, struct file_lock___340 *);
	long unsigned int (*lm_owner_key)(struct file_lock___340 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___340 *);
	int (*lm_grant)(struct file_lock___340 *, int);
	bool (*lm_break)(struct file_lock___340 *);
	int (*lm_change)(struct file_lock___340 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___340 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___339 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___339 *fa_next;
	struct file___340 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___339 {
	const char *name;
	int fs_flags;
	struct dentry___339 * (*mount)(struct file_system_type___339 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___339 *);
	struct module___278 *owner;
	struct file_system_type___339 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___339 {
	struct inode___340 * (*alloc_inode)(struct super_block___339 *);
	void (*destroy_inode)(struct inode___340 *);
	void (*dirty_inode)(struct inode___340 *, int);
	int (*write_inode)(struct inode___340 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___340 *);
	void (*evict_inode)(struct inode___340 *);
	void (*put_super)(struct super_block___339 *);
	int (*sync_fs)(struct super_block___339 *, int);
	int (*freeze_super)(struct super_block___339 *);
	int (*freeze_fs)(struct super_block___339 *);
	int (*thaw_super)(struct super_block___339 *);
	int (*unfreeze_fs)(struct super_block___339 *);
	int (*statfs)(struct dentry___339 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___339 *, int *, char *);
	void (*umount_begin)(struct super_block___339 *);
	int (*show_options)(struct seq_file___288 *, struct dentry___339 *);
	int (*show_devname)(struct seq_file___288 *, struct dentry___339 *);
	int (*show_path)(struct seq_file___288 *, struct dentry___339 *);
	int (*show_stats)(struct seq_file___288 *, struct dentry___339 *);
	ssize_t (*quota_read)(struct super_block___339 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___339 *, int, const char *, size_t, loff_t);
	struct dquot___339 ** (*get_dquots)(struct inode___340 *);
	int (*bdev_try_to_free_page)(struct super_block___339 *, struct page___341 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___339 *, struct shrink_control___125 *);
	long int (*free_cached_objects)(struct super_block___339 *, struct shrink_control___125 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct acpi_device___15;

struct acpi_hotplug_profile___15 {
	struct kobject___327 kobj;
	int (*scan_dependent)(struct acpi_device___15 *);
	void (*notify_online)(struct acpi_device___15 *);
	bool enabled: 1;
	bool demand_offline: 1;
};

struct acpi_device_wakeup_context___15 {
	void (*func)(struct acpi_device_wakeup_context___15 *);
	struct device___306 *dev;
};

struct acpi_device_wakeup___15 {
	acpi_handle gpe_device;
	u64 gpe_number;
	u64 sleep_state;
	struct list_head resources;
	struct acpi_device_wakeup_flags flags;
	struct acpi_device_wakeup_context___15 context;
	struct wakeup_source___3 *ws;
	int prepare_count;
	int enable_count;
};

struct acpi_scan_handler___15;

struct acpi_hotplug_context___15;

struct acpi_driver___15;

struct acpi_device___15 {
	int device_type;
	acpi_handle handle;
	struct fwnode_handle___234 fwnode;
	struct acpi_device___15 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup___15 wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_device_data data;
	struct acpi_scan_handler___15 *handler;
	struct acpi_hotplug_context___15 *hp;
	struct acpi_driver___15 *driver;
	const struct acpi_gpio_mapping *driver_gpios;
	void *driver_data;
	struct device___306 dev;
	unsigned int physical_node_count;
	unsigned int dep_unmet;
	struct list_head physical_node_list;
	struct mutex physical_node_lock;
	void (*remove)(struct acpi_device___15 *);
};

struct acpi_scan_handler___15 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	bool (*match)(const char *, const struct acpi_device_id **);
	int (*attach)(struct acpi_device___15 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___15 *);
	void (*bind)(struct device___306 *);
	void (*unbind)(struct device___306 *);
	struct acpi_hotplug_profile___15 hotplug;
};

struct acpi_hotplug_context___15 {
	struct acpi_device___15 *self;
	int (*notify)(struct acpi_device___15 *, u32);
	void (*uevent)(struct acpi_device___15 *, u32);
	void (*fixup)(struct acpi_device___15 *);
};

typedef int (*acpi_op_add___15)(struct acpi_device___15 *);

typedef int (*acpi_op_remove___15)(struct acpi_device___15 *);

typedef void (*acpi_op_notify___15)(struct acpi_device___15 *, u32);

struct acpi_device_ops___15 {
	acpi_op_add___15 add;
	acpi_op_remove___15 remove;
	acpi_op_notify___15 notify;
};

struct acpi_driver___15 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___15 ops;
	struct device_driver___306 drv;
	struct module___278 *owner;
};

struct irqaction___16 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___16 *next;
	irq_handler_t thread_fn;
	struct task_struct___341 *thread;
	struct irqaction___16 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef int (*key_restrict_link_func_t___316)(struct key___315 *, const struct key_type *, const union key_payload *, struct key___315 *);

struct key_restriction___315;

struct key___315 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___341 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___315 *restrict_link;
};

struct key_restriction___315 {
	key_restrict_link_func_t___316 check;
	struct key___315 *key;
	struct key_type *keytype;
};

struct seq_operations___287 {
	void * (*start)(struct seq_file___288 *, loff_t *);
	void (*stop)(struct seq_file___288 *, void *);
	void * (*next)(struct seq_file___288 *, void *, loff_t *);
	int (*show)(struct seq_file___288 *, void *);
};

typedef void compound_page_dtor___328(struct page___341 *);

struct property___75 {
	char *name;
	int length;
	void *value;
	struct property___75 *next;
	long unsigned int _flags;
	struct bin_attribute___303 attr;
};

struct irq_desc___19;

typedef void (*irq_flow_handler_t___19)(struct irq_desc___19 *);

struct irq_chip___26;

struct irq_data___26 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___11 *common;
	struct irq_chip___26 *chip;
	struct irq_domain___26 *domain;
	struct irq_data___26 *parent_data;
	void *chip_data;
};

struct irq_desc___19 {
	struct irq_common_data___11 irq_common_data;
	struct irq_data___26 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___19 handle_irq;
	struct irqaction___16 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int irq_count;
	unsigned int tot_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___327 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___278 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip___26 {
	struct device___306 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___26 *);
	void (*irq_shutdown)(struct irq_data___26 *);
	void (*irq_enable)(struct irq_data___26 *);
	void (*irq_disable)(struct irq_data___26 *);
	void (*irq_ack)(struct irq_data___26 *);
	void (*irq_mask)(struct irq_data___26 *);
	void (*irq_mask_ack)(struct irq_data___26 *);
	void (*irq_unmask)(struct irq_data___26 *);
	void (*irq_eoi)(struct irq_data___26 *);
	int (*irq_set_affinity)(struct irq_data___26 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___26 *);
	int (*irq_set_type)(struct irq_data___26 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___26 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___26 *);
	void (*irq_bus_sync_unlock)(struct irq_data___26 *);
	void (*irq_cpu_online)(struct irq_data___26 *);
	void (*irq_cpu_offline)(struct irq_data___26 *);
	void (*irq_suspend)(struct irq_data___26 *);
	void (*irq_resume)(struct irq_data___26 *);
	void (*irq_pm_shutdown)(struct irq_data___26 *);
	void (*irq_calc_mask)(struct irq_data___26 *);
	void (*irq_print_chip)(struct irq_data___26 *, struct seq_file___288 *);
	int (*irq_request_resources)(struct irq_data___26 *);
	void (*irq_release_resources)(struct irq_data___26 *);
	void (*irq_compose_msi_msg)(struct irq_data___26 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___26 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___26 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___26 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___26 *, void *);
	void (*ipi_send_single)(struct irq_data___26 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___26 *, const struct cpumask *);
	long unsigned int flags;
};

struct irq_chip_type___15 {
	struct irq_chip___26 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___19 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___15 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___15 *);
	void (*resume)(struct irq_chip_generic___15 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___26 *domain;
	struct list_head list;
	struct irq_chip_type___15 chip_types[0];
};

struct irq_domain_chip_generic___14 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___15 *gc[0];
};

struct irq_fwspec___26 {
	struct fwnode_handle___234 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___26 {
	int (*match)(struct irq_domain___26 *, struct device_node___79 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___26 *, struct irq_fwspec___26 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___26 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___26 *, unsigned int);
	int (*xlate)(struct irq_domain___26 *, struct device_node___79 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___26 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___26 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___26 *, struct irq_data___26 *, bool);
	void (*deactivate)(struct irq_domain___26 *, struct irq_data___26 *);
	int (*translate)(struct irq_domain___26 *, struct irq_fwspec___26 *, long unsigned int *, unsigned int *);
};

struct net_device___42;

struct nf_bridge_info___40;

struct sk_buff___42 {
	union {
		struct {
			struct sk_buff___42 *next;
			struct sk_buff___42 *prev;
			union {
				struct net_device___42 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___28 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___42 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___40 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___40;

struct netns_frags___40 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___40 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv4___40 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct sock *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock **tcp_sk;
	struct netns_frags___40 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct dst_ops___50 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___50 *);
	struct dst_entry___2 * (*check)(struct dst_entry___2 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___2 *);
	unsigned int (*mtu)(const struct dst_entry___2 *);
	u32 * (*cow_metrics)(struct dst_entry___2 *, long unsigned int);
	void (*destroy)(struct dst_entry___2 *);
	void (*ifdown)(struct dst_entry___2 *, struct net_device___42 *, int);
	struct dst_entry___2 * (*negative_advice)(struct dst_entry___2 *);
	void (*link_failure)(struct sk_buff___42 *);
	void (*update_pmtu)(struct dst_entry___2 *, struct sock *, struct sk_buff___42 *, u32);
	void (*redirect)(struct dst_entry___2 *, struct sock *, struct sk_buff___42 *);
	int (*local_out)(struct net___51 *, struct sock *, struct sk_buff___42 *);
	struct neighbour___2 * (*neigh_lookup)(const struct dst_entry___2 *, struct sk_buff___42 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___2 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___50 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___40 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___50 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct sock *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops *notifier_ops;
	struct fib_notifier_ops *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_nf_frag___40 {
	struct netns_frags___40 frags;
};

struct netns_xfrm___50 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___50 xfrm4_dst_ops;
	struct dst_ops___50 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct net___51 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___236 *user_ns;
	struct ucounts___236 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___9 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___42 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___40 ipv4;
	struct netns_ipv6___50 ipv6;
	struct netns_sctp___28 sctp;
	struct netns_nf nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___40 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock *nfnl;
	struct sock *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___50 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pipe_buf_operations___73;

struct pipe_buffer___73 {
	struct page___341 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___73 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___73 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___73 *, struct pipe_buffer___73 *);
	void (*release)(struct pipe_inode_info___73 *, struct pipe_buffer___73 *);
	int (*steal)(struct pipe_inode_info___73 *, struct pipe_buffer___73 *);
	union {
		bool (*get)(struct pipe_inode_info___73 *, struct pipe_buffer___73 *);
		struct {
			void (*get)(struct pipe_inode_info___73 *, struct pipe_buffer___73 *);
		} __UNIQUE_ID_rh_kabi_hide21;
		union {		};
	};
};

struct nf_bridge_info___40 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___40 = 0,
		BRNF_PROTO_8021Q___40 = 1,
		BRNF_PROTO_PPPOE___40 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___42 *physindev;
	struct net_device___42 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___40(struct sk_buff___42 **);

typedef struct {
	struct net___51 *net;
} possible_net_t___41;

struct net_device_ops___40;

struct ethtool_ops___40;

struct xfrmdev_ops___40;

struct tlsdev_ops___40;

struct header_ops___40;

struct netdev_rx_queue___40;

struct netdev_queue___40;

struct dcbnl_rtnl_ops___40;

struct phy_device___2;

struct net_device___42 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___40 *netdev_ops;
	const struct ethtool_ops___40 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___2 *l3mdev_ops;
	const struct ndisc_ops___2 *ndisc_ops;
	const struct xfrmdev_ops___40 *xfrmdev_ops;
	const struct tlsdev_ops___40 *tlsdev_ops;
	const struct header_ops___40 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___326 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___2 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___40 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___40 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___2 *miniq_ingress;
	struct netdev_queue___40 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___40 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___2 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___2 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___40 = 0,
		NETREG_REGISTERED___40 = 1,
		NETREG_UNREGISTERING___40 = 2,
		NETREG_UNREGISTERED___40 = 3,
		NETREG_RELEASED___40 = 4,
		NETREG_DUMMY___40 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___40 = 0,
		RTNL_LINK_INITIALIZING___40 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___42 *);
	struct netpoll_info *npinfo;
	possible_net_t___41 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___306 dev;
	const struct attribute_group___304 *sysfs_groups[4];
	const struct attribute_group___304 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___2 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___40 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device___2 *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide35;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct sk_buff_head___40 {
	struct sk_buff___42 *next;
	struct sk_buff___42 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct ethtool_ops___40 {
	int (*get_settings)(struct net_device___42 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___42 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___42 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___42 *);
	void (*get_regs)(struct net_device___42 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___42 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___42 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___42 *);
	void (*set_msglevel)(struct net_device___42 *, u32);
	int (*nway_reset)(struct net_device___42 *);
	u32 (*get_link)(struct net_device___42 *);
	int (*get_eeprom_len)(struct net_device___42 *);
	int (*get_eeprom)(struct net_device___42 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___42 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___42 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___42 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___42 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___42 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___42 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___42 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___42 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___42 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___42 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___42 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___42 *);
	void (*complete)(struct net_device___42 *);
	u32 (*get_priv_flags)(struct net_device___42 *);
	int (*set_priv_flags)(struct net_device___42 *, u32);
	int (*get_sset_count)(struct net_device___42 *, int);
	int (*get_rxnfc)(struct net_device___42 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___42 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___42 *, struct ethtool_flash *);
	int (*reset)(struct net_device___42 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___42 *);
	u32 (*get_rxfh_indir_size)(struct net_device___42 *);
	int (*get_rxfh)(struct net_device___42 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___42 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___42 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___42 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___42 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___42 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___42 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___42 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___42 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___42 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___42 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___42 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___42 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___42 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___42 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___42 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___42 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___42 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___42 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___42 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___42 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___42 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	int (*get_fecparam)(struct net_device___42 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___42 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___42 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___42 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___42 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___40;

struct inet_frags___40 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___40 *, const void *);
	void (*destructor)(struct inet_frag_queue___40 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___40 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___42 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___42 *fragments_tail;
	struct sk_buff___42 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___40 *net;
	struct callback_head rcu;
};

struct ucounts___236 {
	struct hlist_node node;
	struct user_namespace___236 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct pernet_operations___41 {
	struct list_head list;
	int (*init)(struct net___51 *);
	void (*exit)(struct net___51 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___40 {
	int (*ieee_getets)(struct net_device___42 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___42 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___42 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___42 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___42 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___42 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___42 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___42 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___42 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___42 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___42 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___42 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___42 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___42 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___42 *);
	u8 (*setstate)(struct net_device___42 *, u8);
	void (*getpermhwaddr)(struct net_device___42 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___42 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___42 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___42 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___42 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___42 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___42 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___42 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___42 *, int, u8 *);
	void (*setpfccfg)(struct net_device___42 *, int, u8);
	void (*getpfccfg)(struct net_device___42 *, int, u8 *);
	u8 (*setall)(struct net_device___42 *);
	u8 (*getcap)(struct net_device___42 *, int, u8 *);
	int (*getnumtcs)(struct net_device___42 *, int, u8 *);
	int (*setnumtcs)(struct net_device___42 *, int, u8);
	u8 (*getpfcstate)(struct net_device___42 *);
	void (*setpfcstate)(struct net_device___42 *, u8);
	void (*getbcncfg)(struct net_device___42 *, int, u32 *);
	void (*setbcncfg)(struct net_device___42 *, int, u32);
	void (*getbcnrp)(struct net_device___42 *, int, u8 *);
	void (*setbcnrp)(struct net_device___42 *, int, u8);
	int (*setapp)(struct net_device___42 *, u8, u16, u8);
	int (*getapp)(struct net_device___42 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___42 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___42 *, int, u8);
	u8 (*getdcbx)(struct net_device___42 *);
	u8 (*setdcbx)(struct net_device___42 *, u8);
	int (*peer_getappinfo)(struct net_device___42 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___42 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___42 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___42 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___42 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___42 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___221 {
	refcount_t count;
	struct ns_common___9 ns;
	struct user_namespace___236 *user_ns;
	struct ucounts___236 *ucounts;
	struct css_set___221 *root_cset;
};

struct bpf_map___222;

struct bpf_map_ops___221 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___222 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___222 *, struct file___340 *);
	void (*map_free)(struct bpf_map___222 *);
	int (*map_get_next_key)(struct bpf_map___222 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___222 *);
	void * (*map_lookup_elem)(struct bpf_map___222 *, void *);
	int (*map_update_elem)(struct bpf_map___222 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___222 *, void *);
	int (*map_push_elem)(struct bpf_map___222 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___222 *, void *);
	int (*map_peek_elem)(struct bpf_map___222 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___222 *, struct file___340 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___222 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___222 *, void *, struct seq_file___288 *);
	int (*map_check_btf)(const struct bpf_map___222 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___222 {
	const struct bpf_map_ops___221 *ops;
	struct bpf_map___222 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___315 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___40;

struct bpf_map_dev_ops___40 {
	int (*map_get_next_key)(struct bpf_offloaded_map___40 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___40 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___40 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___40 *, void *);
};

struct bpf_offloaded_map___40 {
	struct bpf_map___222 map;
	struct net_device___42 *netdev;
	const struct bpf_map_dev_ops___40 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___221;

typedef void (*kthread_work_func_t___221)(struct kthread_work___221 *);

struct kthread_worker___221;

struct kthread_work___221 {
	struct list_head node;
	kthread_work_func_t___221 func;
	struct kthread_worker___221 *worker;
	int canceling;
};

struct kthread_worker___221 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___341 *task;
	struct kthread_work___221 *current_work;
};

struct kthread_delayed_work___221 {
	struct kthread_work___221 work;
	struct timer_list timer;
};

struct psi_group___221 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___221 *poll_kworker;
	struct kthread_delayed_work___221 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___221 {
	struct kernfs_node___334 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___221;

struct cgroup_subsys_state___221 {
	struct cgroup___221 *cgroup;
	struct cgroup_subsys___221 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___221 *parent;
};

struct cgroup_root___221;

struct cgroup_rstat_cpu___221;

struct cgroup___221 {
	struct cgroup_subsys_state___221 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___334 *kn;
	struct cgroup_file___221 procs_file;
	struct cgroup_file___221 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___221 *subsys[13];
	struct cgroup_root___221 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___221 *dom_cgrp;
	struct cgroup_rstat_cpu___221 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___37 bpf;
	atomic_t congestion_count;
	struct cgroup___221 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___221 psi;
	int ancestor_ids[0];
};

struct cftype___221;

struct cgroup_subsys___221 {
	struct cgroup_subsys_state___221 * (*css_alloc)(struct cgroup_subsys_state___221 *);
	int (*css_online)(struct cgroup_subsys_state___221 *);
	void (*css_offline)(struct cgroup_subsys_state___221 *);
	void (*css_released)(struct cgroup_subsys_state___221 *);
	void (*css_free)(struct cgroup_subsys_state___221 *);
	void (*css_reset)(struct cgroup_subsys_state___221 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___221 *, int);
	int (*css_extra_stat_show)(struct seq_file___288 *, struct cgroup_subsys_state___221 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___341 *);
	void (*cancel_fork)(struct task_struct___341 *);
	void (*fork)(struct task_struct___341 *);
	void (*exit)(struct task_struct___341 *);
	void (*free)(struct task_struct___341 *);
	void (*bind)(struct cgroup_subsys_state___221 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___221 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___221 *dfl_cftypes;
	struct cftype___221 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___221 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___221 *updated_children;
	struct cgroup___221 *updated_next;
};

struct cgroup_root___221 {
	struct kernfs_root___333 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___221 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___221 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___221 *ss;
	struct list_head node;
	struct kernfs_ops___333 *kf_ops;
	int (*open)(struct kernfs_open_file___333 *);
	void (*release)(struct kernfs_open_file___333 *);
	u64 (*read_u64)(struct cgroup_subsys_state___221 *, struct cftype___221 *);
	s64 (*read_s64)(struct cgroup_subsys_state___221 *, struct cftype___221 *);
	int (*seq_show)(struct seq_file___288 *, void *);
	void * (*seq_start)(struct seq_file___288 *, loff_t *);
	void * (*seq_next)(struct seq_file___288 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___288 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___221 *, struct cftype___221 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___221 *, struct cftype___221 *, s64);
	ssize_t (*write)(struct kernfs_open_file___333 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___333 *, struct poll_table_struct___207 *);
};

struct xdp_rxq_info___40 {
	struct net_device___42 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___40 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___42 *dev_rx;
};

struct netlink_callback___41 {
	struct sk_buff___42 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___41 *);
	int (*dump)(struct sk_buff___42 *, struct netlink_callback___41 *);
	int (*done)(struct netlink_callback___41 *);
	void *data;
	struct module___278 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___40 {
	int (*create)(struct sk_buff___42 *, struct net_device___42 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___42 *, unsigned char *);
	int (*cache)(const struct neighbour___2 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___42 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___40 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___40 *, int);
	int poll_owner;
	struct net_device___42 *dev;
	struct sk_buff___42 *gro_list;
	struct sk_buff___42 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___40 {
	struct net_device___42 *dev;
	struct Qdisc___2 *qdisc;
	struct Qdisc___2 *qdisc_sleeping;
	struct kobject___327 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___42 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct netdev_rx_queue___40 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___327 kobj;
	struct net_device___42 *dev;
	long: 64;
	struct xdp_rxq_info___40 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___40)(struct net_device___42 *, struct sk_buff___42 *, struct net_device___42 *);

struct netdev_bpf___40 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___37 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___37 *prog;
			const struct bpf_prog_offload_ops___37 *ops;
		} verifier;
		struct {
			struct bpf_prog___37 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___40 *offmap;
		};
		struct {
			struct xdp_umem *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___40 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___42 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___40 {
	int (*tls_dev_add)(struct net_device___42 *, struct sock *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___42 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___42 *, struct sock *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___40 {
	int (*ndo_init)(struct net_device___42 *);
	void (*ndo_uninit)(struct net_device___42 *);
	int (*ndo_open)(struct net_device___42 *);
	int (*ndo_stop)(struct net_device___42 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___42 *, struct net_device___42 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___42 *, struct net_device___42 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___42 *, struct sk_buff___42 *, struct net_device___42 *, select_queue_fallback_t___40);
	void (*ndo_change_rx_flags)(struct net_device___42 *, int);
	void (*ndo_set_rx_mode)(struct net_device___42 *);
	int (*ndo_set_mac_address)(struct net_device___42 *, void *);
	int (*ndo_validate_addr)(struct net_device___42 *);
	int (*ndo_do_ioctl)(struct net_device___42 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___42 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___42 *, int);
	int (*ndo_neigh_setup)(struct net_device___42 *, struct neigh_parms___3 *);
	void (*ndo_tx_timeout)(struct net_device___42 *);
	void (*ndo_get_stats64)(struct net_device___42 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___42 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___42 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___42 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___42 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___42 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___42 *);
	int (*ndo_netpoll_setup)(struct net_device___42 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___42 *);
	int (*ndo_set_vf_mac)(struct net_device___42 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___42 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___42 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___42 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___42 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___42 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___42 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___42 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___42 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___42 *, int, struct sk_buff___42 *);
	int (*ndo_set_vf_guid)(struct net_device___42 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___42 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___42 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___42 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___42 *, const struct sk_buff___42 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___42 *, struct net_device___42 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___42 *, struct net_device___42 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___42 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___42 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___42 *, struct neighbour___2 *);
	void (*ndo_neigh_destroy)(struct net_device___42 *, struct neighbour___2 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___42 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___42 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___42 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___42 *, struct netlink_callback___41 *, struct net_device___42 *, struct net_device___42 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___42 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___42 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___42 *, u32, u32, struct net_device___42 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___42 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___42 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___42 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___42 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___42 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___42 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___42 *, struct net_device___42 *);
	void (*ndo_dfwd_del_station)(struct net_device___42 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___42 *);
	int (*ndo_set_tx_maxrate)(struct net_device___42 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___42 *);
	int (*ndo_change_proto_down)(struct net_device___42 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___42 *, struct sk_buff___42 *);
	void (*ndo_set_rx_headroom)(struct net_device___42 *, int);
	int (*ndo_bpf)(struct net_device___42 *, struct netdev_bpf___40 *);
	int (*ndo_xdp_xmit)(struct net_device___42 *, int, struct xdp_frame___40 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___42 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___42 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct mii_bus;

struct mdio_device {
	struct device___306 dev;
	struct mii_bus *bus;
	char modalias[32];
	int (*bus_match)(struct device___306 *, struct device_driver___306 *);
	void (*device_free)(struct mdio_device *);
	void (*device_remove)(struct mdio_device *);
	int addr;
	int flags;
	struct gpio_desc *reset;
	unsigned int reset_assert_delay;
	unsigned int reset_deassert_delay;
};

struct phy_c45_device_ids {
	u32 devices_in_package;
	u32 device_ids[8];
};

enum phy_state {
	PHY_DOWN = 0,
	PHY_STARTING = 1,
	PHY_READY = 2,
	PHY_PENDING = 3,
	PHY_UP = 4,
	PHY_AN = 5,
	PHY_RUNNING = 6,
	PHY_NOLINK = 7,
	PHY_FORCING = 8,
	PHY_CHANGELINK = 9,
	PHY_HALTED = 10,
	PHY_RESUMING = 11,
};

typedef enum {
	PHY_INTERFACE_MODE_NA = 0,
	PHY_INTERFACE_MODE_INTERNAL = 1,
	PHY_INTERFACE_MODE_MII = 2,
	PHY_INTERFACE_MODE_GMII = 3,
	PHY_INTERFACE_MODE_SGMII = 4,
	PHY_INTERFACE_MODE_TBI = 5,
	PHY_INTERFACE_MODE_REVMII = 6,
	PHY_INTERFACE_MODE_RMII = 7,
	PHY_INTERFACE_MODE_RGMII = 8,
	PHY_INTERFACE_MODE_RGMII_ID = 9,
	PHY_INTERFACE_MODE_RGMII_RXID = 10,
	PHY_INTERFACE_MODE_RGMII_TXID = 11,
	PHY_INTERFACE_MODE_RTBI = 12,
	PHY_INTERFACE_MODE_SMII = 13,
	PHY_INTERFACE_MODE_XGMII = 14,
	PHY_INTERFACE_MODE_MOCA = 15,
	PHY_INTERFACE_MODE_QSGMII = 16,
	PHY_INTERFACE_MODE_TRGMII = 17,
	PHY_INTERFACE_MODE_1000BASEX = 18,
	PHY_INTERFACE_MODE_2500BASEX = 19,
	PHY_INTERFACE_MODE_RXAUI = 20,
	PHY_INTERFACE_MODE_XAUI = 21,
	PHY_INTERFACE_MODE_10GKR = 22,
	PHY_INTERFACE_MODE_MAX = 23,
} phy_interface_t;

struct phylink;

struct phy_driver;

struct phy_led_trigger;

struct phy_device___2 {
	struct mdio_device mdio;
	struct phy_driver *drv;
	u32 phy_id;
	struct phy_c45_device_ids c45_ids;
	unsigned int is_c45: 1;
	unsigned int is_internal: 1;
	unsigned int is_pseudo_fixed_link: 1;
	unsigned int has_fixups: 1;
	unsigned int suspended: 1;
	unsigned int sysfs_links: 1;
	unsigned int loopback_enabled: 1;
	unsigned int autoneg: 1;
	unsigned int link: 1;
	enum phy_state state;
	u32 dev_flags;
	phy_interface_t interface;
	int speed;
	int duplex;
	int pause;
	int asym_pause;
	u32 interrupts;
	u32 rh_reserved_supported;
	u32 rh_reserved_advertising;
	u32 rh_reserved_lp_advertising;
	u32 eee_broken_modes;
	int link_timeout;
	struct phy_led_trigger *phy_led_triggers;
	unsigned int phy_num_led_triggers;
	struct phy_led_trigger *last_triggered;
	struct phy_led_trigger *led_link_trigger;
	int irq;
	void *priv;
	struct work_struct phy_queue;
	struct delayed_work state_queue;
	struct mutex lock;
	struct phylink *phylink;
	struct net_device___42 *attached_dev;
	u8 mdix;
	u8 mdix_ctrl;
	long unsigned int supported[2];
	long unsigned int advertising[2];
	long unsigned int lp_advertising[2];
	void (*phy_link_change)(struct phy_device___2 *, bool, bool);
	void (*adjust_link)(struct net_device___42 *);
};

struct softnet_data___40 {
	struct list_head poll_list;
	struct sk_buff_head___40 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___40 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___2 *output_queue;
	struct Qdisc___2 **output_queue_tailp;
	struct sk_buff___42 *completion_queue;
	struct sk_buff_head___40 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___40 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___40 input_pkt_queue;
	struct napi_struct___40 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct mii_bus {
	struct module___278 *owner;
	const char *name;
	char id[61];
	void *priv;
	int (*read)(struct mii_bus *, int, int);
	int (*write)(struct mii_bus *, int, int, u16);
	int (*reset)(struct mii_bus *);
	struct mutex mdio_lock;
	struct device___306 *parent;
	enum {
		MDIOBUS_ALLOCATED = 1,
		MDIOBUS_REGISTERED = 2,
		MDIOBUS_UNREGISTERED = 3,
		MDIOBUS_RELEASED = 4,
	} state;
	struct device___306 dev;
	struct mdio_device *mdio_map[32];
	u32 phy_mask;
	u32 phy_ignore_ta_mask;
	int irq[32];
	int reset_delay_us;
	struct gpio_desc *reset_gpiod;
};

struct mdio_driver_common {
	struct device_driver___306 driver;
	int flags;
};

struct phy_driver {
	struct mdio_driver_common mdiodrv;
	u32 phy_id;
	char *name;
	u32 phy_id_mask;
	u32 rh_reserved_features;
	u32 flags;
	const void *driver_data;
	const long unsigned int * const features;
	int (*soft_reset)(struct phy_device___2 *);
	int (*config_init)(struct phy_device___2 *);
	int (*probe)(struct phy_device___2 *);
	int (*suspend)(struct phy_device___2 *);
	int (*resume)(struct phy_device___2 *);
	int (*config_aneg)(struct phy_device___2 *);
	int (*aneg_done)(struct phy_device___2 *);
	int (*read_status)(struct phy_device___2 *);
	int (*ack_interrupt)(struct phy_device___2 *);
	int (*config_intr)(struct phy_device___2 *);
	int (*did_interrupt)(struct phy_device___2 *);
	void (*remove)(struct phy_device___2 *);
	int (*match_phy_device)(struct phy_device___2 *);
	int (*ts_info)(struct phy_device___2 *, struct ethtool_ts_info *);
	int (*hwtstamp)(struct phy_device___2 *, struct ifreq *);
	bool (*rxtstamp)(struct phy_device___2 *, struct sk_buff___42 *, int);
	void (*txtstamp)(struct phy_device___2 *, struct sk_buff___42 *, int);
	int (*set_wol)(struct phy_device___2 *, struct ethtool_wolinfo *);
	void (*get_wol)(struct phy_device___2 *, struct ethtool_wolinfo *);
	void (*link_change_notify)(struct phy_device___2 *);
	int (*read_mmd)(struct phy_device___2 *, int, u16);
	int (*write_mmd)(struct phy_device___2 *, int, u16, u16);
	int (*read_page)(struct phy_device___2 *);
	int (*write_page)(struct phy_device___2 *, int);
	int (*module_info)(struct phy_device___2 *, struct ethtool_modinfo *);
	int (*module_eeprom)(struct phy_device___2 *, struct ethtool_eeprom *, u8 *);
	int (*get_sset_count)(struct phy_device___2 *);
	void (*get_strings)(struct phy_device___2 *, u8 *);
	void (*get_stats)(struct phy_device___2 *, struct ethtool_stats *, u64 *);
	int (*get_tunable)(struct phy_device___2 *, struct ethtool_tunable *, void *);
	int (*set_tunable)(struct phy_device___2 *, struct ethtool_tunable *, const void *);
	int (*set_loopback)(struct phy_device___2 *, bool);
};

struct property_set {
	struct device___306 *dev;
	struct fwnode_handle___234 fwnode;
	const struct property_entry___2 *properties;
};

struct cache_type_info {
	const char *size_prop;
	const char *line_size_props[2];
	const char *nr_sets_prop;
};

struct device_connection {
	const char *endpoint[2];
	const char *id;
	struct list_head list;
};

struct module___279;

struct file___341;

struct kiocb___341;

struct iov_iter___149;

struct poll_table_struct___208;

struct vm_area_struct___342;

struct inode___341;

struct file_lock___341;

struct page___342;

struct seq_file___289;

struct file_operations___341 {
	struct module___279 *owner;
	loff_t (*llseek)(struct file___341 *, loff_t, int);
	ssize_t (*read)(struct file___341 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___341 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___341 *, struct iov_iter___149 *);
	ssize_t (*write_iter)(struct kiocb___341 *, struct iov_iter___149 *);
	int (*iopoll)(struct kiocb___341 *, bool);
	int (*iterate)(struct file___341 *, struct dir_context *);
	int (*iterate_shared)(struct file___341 *, struct dir_context *);
	__poll_t (*poll)(struct file___341 *, struct poll_table_struct___208 *);
	long int (*unlocked_ioctl)(struct file___341 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___341 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___341 *, struct vm_area_struct___342 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___341 *, struct file___341 *);
	int (*flush)(struct file___341 *, fl_owner_t);
	int (*release)(struct inode___341 *, struct file___341 *);
	int (*fsync)(struct file___341 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___341 *, int);
	int (*lock)(struct file___341 *, int, struct file_lock___341 *);
	ssize_t (*sendpage)(struct file___341 *, struct page___342 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___341 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___341 *, int, struct file_lock___341 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___341 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___341 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___341 *, long int, struct file_lock___341 **, void **);
	long int (*fallocate)(struct file___341 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___289 *, struct file___341 *);
	ssize_t (*copy_file_range)(struct file___341 *, loff_t, struct file___341 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___341 *, loff_t, struct file___341 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___341 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___341 {
	u64 seqnum;
	struct vm_area_struct___342 *vmas[4];
};

struct page_frag___341 {
	struct page___342 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___136;

struct debug_info___136 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___136 *hbp_break[16];
	struct perf_event___136 *hbp_watch[16];
};

struct thread_struct___136 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___136 debug;
	long: 64;
};

struct mm_struct___341;

struct mem_cgroup___126;

struct pid___212;

struct cred___316;

struct nsproxy___267;

struct signal_struct___249;

struct bio_list___160;

struct backing_dev_info___160;

struct css_set___222;

struct perf_event_context___136;

struct task_struct___342 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___342 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___341 *mm;
	struct mm_struct___341 *active_mm;
	struct vmacache___341 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___342 *real_parent;
	struct task_struct___342 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___342 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___126 *active_memcg;
	long int rh_reserved2;
	struct pid___212 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___212 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___212 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___316 *ptracer_cred;
	const struct cred___316 *real_cred;
	const struct cred___316 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___267 *nsproxy;
	struct signal_struct___249 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___342 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___160 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___160 *backing_dev_info;
	struct io_context___84 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___222 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___136 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___341 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___126 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___342 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___136 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___136 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___342 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___136)(struct perf_event___136 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___136;

struct fasync_struct___340;

struct pid_namespace___212;

struct trace_event_call___129;

struct perf_cgroup___136;

struct perf_event___136 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___136 *group_leader;
	struct pmu___136 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___136 hw;
	struct perf_event_context___136 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___136 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___342 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___340 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___136 *);
	struct callback_head callback_head;
	struct pid_namespace___212 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___136 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___136 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___129 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___136 *cgrp;
	struct list_head sb_list;
};

struct dentry_operations___340;

struct super_block___340;

struct dentry___340 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___340 *d_parent;
	struct qstr d_name;
	struct inode___341 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___340 *d_op;
	struct super_block___340 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct rw_semaphore___342 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___342 *owner;
};

struct address_space_operations___340;

struct address_space___340 {
	struct inode___341 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___342 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___340 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___340;

struct bdi_writeback___160;

struct block_device___340;

struct inode___341 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___340 *i_op;
	struct super_block___340 *i_sb;
	struct address_space___340 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___342 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___160 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___341 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___340 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___340 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vfsmount___68;

struct path___341;

struct dentry_operations___340 {
	int (*d_revalidate)(struct dentry___340 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___340 *, unsigned int);
	int (*d_hash)(const struct dentry___340 *, struct qstr *);
	int (*d_compare)(const struct dentry___340 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___340 *);
	int (*d_init)(struct dentry___340 *);
	void (*d_release)(struct dentry___340 *);
	void (*d_prune)(struct dentry___340 *);
	void (*d_iput)(struct dentry___340 *, struct inode___341 *);
	char * (*d_dname)(struct dentry___340 *, char *, int);
	struct vfsmount___68 * (*d_automount)(struct path___341 *);
	int (*d_manage)(const struct path___341 *, bool);
	struct dentry___340 * (*d_real)(struct dentry___340 *, const struct inode___341 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___340;

struct mem_dqinfo___340 {
	struct quota_format_type___340 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___340;

struct quota_info___340 {
	unsigned int flags;
	struct rw_semaphore___342 dqio_sem;
	struct inode___341 *files[3];
	struct mem_dqinfo___340 info[3];
	const struct quota_format_ops___340 *ops[3];
};

struct rcuwait___340 {
	struct task_struct___342 *task;
};

struct percpu_rw_semaphore___340 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___342 rw_sem;
	struct rcuwait___340 writer;
	int readers_block;
};

struct sb_writers___340 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___340 rw_sem[3];
};

struct shrink_control___126;

struct shrinker___126 {
	long unsigned int (*count_objects)(struct shrinker___126 *, struct shrink_control___126 *);
	long unsigned int (*scan_objects)(struct shrinker___126 *, struct shrink_control___126 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___340;

struct super_operations___340;

struct dquot_operations___340;

struct quotactl_ops___340;

struct xattr_handler___26;

struct user_namespace___237;

struct super_block___340 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___340 *s_type;
	const struct super_operations___340 *s_op;
	const struct dquot_operations___340 *dq_op;
	const struct quotactl_ops___340 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___340 *s_root;
	struct rw_semaphore___342 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___26 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___340 *s_bdev;
	struct backing_dev_info___160 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___340 s_dquot;
	struct sb_writers___340 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___340 *s_d_op;
	int cleancache_poolid;
	struct shrinker___126 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___237 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___68 {
	struct dentry___340 *mnt_root;
	struct super_block___340 *mnt_sb;
	int mnt_flags;
};

struct path___341 {
	struct vfsmount___68 *mnt;
	struct dentry___340 *dentry;
};

struct key___316;

struct ucounts___237;

struct user_namespace___237 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___237 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___9 ns;
	long unsigned int flags;
	struct key___316 *persistent_keyring_register;
	struct rw_semaphore___342 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___237 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct shrink_control___126 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___126 *memcg;
};

struct cgroup___222;

struct cgroup_subsys___222;

struct cgroup_subsys_state___222 {
	struct cgroup___222 *cgroup;
	struct cgroup_subsys___222 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___222 *parent;
};

struct kernfs_node___335;

struct cgroup_file___222 {
	struct kernfs_node___335 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___126;

struct mem_cgroup___126 {
	struct cgroup_subsys_state___222 css;
	struct mem_cgroup_id___20 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___222 events_file;
	struct cgroup_file___222 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___342 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___126 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___342 *pgtable_t___341;

struct dev_pagemap___329;

struct page___342 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___340 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___342 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___341 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___341 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___329 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___126 *mem_cgroup;
};

struct pglist_data___341;

struct lruvec___341 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___341 *pgdat;
};

struct zone___341 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___341 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___341 {
	struct zone___341 *zone;
	int zone_idx;
};

struct zonelist___341 {
	struct zoneref___341 _zonerefs[25];
};

struct pglist_data___341 {
	struct zone___341 node_zones[3];
	struct zonelist___341 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___342 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___342 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___341 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___342 {
	void *stack;
	struct task_struct___342 *task;
	long int status;
};

struct blocking_notifier_head___341 {
	struct rw_semaphore___342 rwsem;
	struct notifier_block *head;
};

struct upid___212 {
	int nr;
	struct pid_namespace___212 *ns;
};

struct pid_namespace___212 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___342 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___212 *parent;
	struct vfsmount___68 *proc_mnt;
	struct dentry___340 *proc_self;
	struct dentry___340 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___237 *user_ns;
	struct ucounts___237 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___9 ns;
};

struct pid___212 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___212 numbers[1];
};

struct vm_operations_struct___329;

struct vm_area_struct___342 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___342 *vm_next;
	struct vm_area_struct___342 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___341 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___329 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___341 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___341;

struct mm_struct___341 {
	struct {
		struct vm_area_struct___342 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___341 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___342 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___341 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___342 *owner;
		struct user_namespace___237 *user_ns;
		struct file___341 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___341 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___329)(struct vm_area_struct___342 *, long unsigned int, const struct page___342 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___329)(struct page___342 *, void *);

struct device___307;

struct dev_pagemap___329 {
	dev_page_fault_t___329 page_fault;
	dev_page_free_t___329 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___307 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct fown_struct___212 {
	rwlock_t lock;
	struct pid___212 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___341 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___341 f_path;
	struct inode___341 *f_inode;
	const struct file_operations___341 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___212 f_owner;
	const struct cred___316 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___340 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___329;

struct vm_operations_struct___329 {
	void (*open)(struct vm_area_struct___342 *);
	void (*close)(struct vm_area_struct___342 *);
	int (*split)(struct vm_area_struct___342 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___342 *);
	vm_fault_t (*fault)(struct vm_fault___329 *);
	vm_fault_t (*huge_fault)(struct vm_fault___329 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___329 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___342 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___329 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___329 *);
	int (*access)(struct vm_area_struct___342 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___342 *);
	int (*set_policy)(struct vm_area_struct___342 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___342 *, long unsigned int);
	struct page___342 * (*find_special_page)(struct vm_area_struct___342 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___341 {
	struct task_struct___342 *task;
	struct core_thread___341 *next;
};

struct core_state___341 {
	atomic_t nr_threads;
	struct core_thread___341 dumper;
	struct completion startup;
};

struct vm_fault___329 {
	struct vm_area_struct___342 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___342 *cow_page;
	struct mem_cgroup___126 *memcg;
	struct page___342 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___341 prealloc_pte;
};

struct user_struct___316 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___316 *uid_keyring;
	struct key___316 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___316 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___316 *session_keyring;
	struct key___316 *process_keyring;
	struct key___316 *thread_keyring;
	struct key___316 *request_key_auth;
	void *security;
	struct user_struct___316 *user;
	struct user_namespace___237 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___222;

struct nsproxy___267 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___212 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___222 *cgroup_ns;
};

struct signal_struct___249 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___342 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___342 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___212 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___212 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___341 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___212 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___160;

struct bio_list___160 {
	struct bio___160 *head;
	struct bio___160 *tail;
};

struct bdi_writeback_congested___160;

struct bdi_writeback___160 {
	struct backing_dev_info___160 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___160 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___222 *memcg_css;
	struct cgroup_subsys_state___222 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___160 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___160 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___307 *dev;
	struct device___307 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___340 *debug_dir;
	struct dentry___340 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___222 {
	struct cgroup_subsys_state___222 *subsys[13];
	refcount_t refcount;
	struct css_set___222 *dom_cset;
	struct cgroup___222 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___222 *mg_src_cgrp;
	struct cgroup___222 *mg_dst_cgrp;
	struct css_set___222 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___136 {
	struct pmu___136 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___342 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___136 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

union thread_union___261 {
	struct task_struct___342 task;
	long unsigned int stack[8192];
};

struct kiocb___341 {
	struct file___341 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___341 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___340 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___341 *ia_file;
};

struct dquot___340 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___340 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___340 {
	int qf_fmt_id;
	const struct quota_format_ops___340 *qf_ops;
	struct module___279 *qf_owner;
	struct quota_format_type___340 *qf_next;
};

struct quota_format_ops___340 {
	int (*check_quota_file)(struct super_block___340 *, int);
	int (*read_file_info)(struct super_block___340 *, int);
	int (*write_file_info)(struct super_block___340 *, int);
	int (*free_file_info)(struct super_block___340 *, int);
	int (*read_dqblk)(struct dquot___340 *);
	int (*commit_dqblk)(struct dquot___340 *);
	int (*release_dqblk)(struct dquot___340 *);
	int (*get_next_id)(struct super_block___340 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___340 {
	int (*write_dquot)(struct dquot___340 *);
	struct dquot___340 * (*alloc_dquot)(struct super_block___340 *, int);
	void (*destroy_dquot)(struct dquot___340 *);
	int (*acquire_dquot)(struct dquot___340 *);
	int (*release_dquot)(struct dquot___340 *);
	int (*mark_dirty)(struct dquot___340 *);
	int (*write_info)(struct super_block___340 *, int);
	qsize_t * (*get_reserved_space)(struct inode___341 *);
	int (*get_projid)(struct inode___341 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___341 *, qsize_t *);
	int (*get_next_id)(struct super_block___340 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___340 {
	int (*quota_on)(struct super_block___340 *, int, int, const struct path___341 *);
	int (*quota_off)(struct super_block___340 *, int);
	int (*quota_enable)(struct super_block___340 *, unsigned int);
	int (*quota_disable)(struct super_block___340 *, unsigned int);
	int (*quota_sync)(struct super_block___340 *, int);
	int (*set_info)(struct super_block___340 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___340 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___340 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___340 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___340 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___340 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___327;

struct kobj_type___327;

struct kobject___328 {
	const char *name;
	struct list_head entry;
	struct kobject___328 *parent;
	struct kset___327 *kset;
	struct kobj_type___327 *ktype;
	struct kernfs_node___335 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___276 {
	struct kobject___328 kobj;
	struct module___279 *mod;
	struct kobject___328 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___276 {
	struct module___279 *mod;
	struct latch_tree_node node;
};

struct module_layout___276 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___276 mtn;
};

struct module_attribute___276;

struct kernel_param___276;

struct module___279 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___276 mkobj;
	struct module_attribute___276 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___328 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___276 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___276 core_layout;
	struct module_layout___276 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___129 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___143;

struct swap_info_struct___83;

struct address_space_operations___340 {
	int (*writepage)(struct page___342 *, struct writeback_control___143 *);
	int (*readpage)(struct file___341 *, struct page___342 *);
	int (*writepages)(struct address_space___340 *, struct writeback_control___143 *);
	int (*set_page_dirty)(struct page___342 *);
	int (*readpages)(struct file___341 *, struct address_space___340 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___341 *, struct address_space___340 *, loff_t, unsigned int, unsigned int, struct page___342 **, void **);
	int (*write_end)(struct file___341 *, struct address_space___340 *, loff_t, unsigned int, unsigned int, struct page___342 *, void *);
	sector_t (*bmap)(struct address_space___340 *, sector_t);
	void (*invalidatepage)(struct page___342 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___342 *, gfp_t);
	void (*freepage)(struct page___342 *);
	ssize_t (*direct_IO)(struct kiocb___341 *, struct iov_iter___149 *);
	int (*migratepage)(struct address_space___340 *, struct page___342 *, struct page___342 *, enum migrate_mode);
	bool (*isolate_page)(struct page___342 *, isolate_mode_t);
	void (*putback_page)(struct page___342 *);
	int (*launder_page)(struct page___342 *);
	int (*is_partially_uptodate)(struct page___342 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___342 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___340 *, struct page___342 *);
	int (*swap_activate)(struct swap_info_struct___83 *, struct file___341 *, sector_t *);
	void (*swap_deactivate)(struct file___341 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___143 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___160 *wb;
	struct inode___341 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___162;

struct iov_iter___149 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___162 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct swap_info_struct___83 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___340 *bdev;
	struct file___341 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct hd_struct___84;

struct gendisk___84;

struct block_device___340 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___341 *bd_inode;
	struct super_block___340 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___340 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___84 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___84 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___160 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___307 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___3 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___4 *subsys_data;
	void (*set_latency_tolerance)(struct device___307 *, s32);
	struct dev_pm_qos *qos;
};

struct device_private___5;

struct device_type___307;

struct bus_type___307;

struct device_driver___307;

struct dev_pm_domain___307;

struct class___307;

struct attribute_group___305;

struct device___307 {
	struct device___307 *parent;
	struct device_private___5 *p;
	struct kobject___328 kobj;
	const char *init_name;
	const struct device_type___307 *type;
	struct mutex mutex;
	struct bus_type___307 *bus;
	struct device_driver___307 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___307 power;
	struct dev_pm_domain___307 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___307 *class;
	const struct attribute_group___305 **groups;
	void (*release)(struct device___307 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___84 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___307 __dev;
	struct kobject___328 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___84;

struct gendisk___84 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___84 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___84 *part_tbl;
	struct hd_struct___84 part0;
	const struct block_device_operations___13 *fops;
	struct request_queue___3 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___342 lookup_sem;
	struct kobject___328 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___328 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___340 {
	struct dentry___340 * (*lookup)(struct inode___341 *, struct dentry___340 *, unsigned int);
	const char * (*get_link)(struct dentry___340 *, struct inode___341 *, struct delayed_call *);
	int (*permission)(struct inode___341 *, int);
	struct posix_acl * (*get_acl)(struct inode___341 *, int);
	int (*readlink)(struct dentry___340 *, char *, int);
	int (*create)(struct inode___341 *, struct dentry___340 *, umode_t, bool);
	int (*link)(struct dentry___340 *, struct inode___341 *, struct dentry___340 *);
	int (*unlink)(struct inode___341 *, struct dentry___340 *);
	int (*symlink)(struct inode___341 *, struct dentry___340 *, const char *);
	int (*mkdir)(struct inode___341 *, struct dentry___340 *, umode_t);
	int (*rmdir)(struct inode___341 *, struct dentry___340 *);
	int (*mknod)(struct inode___341 *, struct dentry___340 *, umode_t, dev_t);
	int (*rename)(struct inode___341 *, struct dentry___340 *, struct inode___341 *, struct dentry___340 *, unsigned int);
	int (*setattr)(struct dentry___340 *, struct iattr___340 *);
	int (*getattr)(const struct path___341 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___340 *, char *, size_t);
	int (*fiemap)(struct inode___341 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___341 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___341 *, struct dentry___340 *, struct file___341 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___341 *, struct dentry___340 *, umode_t);
	int (*set_acl)(struct inode___341 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___340 {
	void (*fl_copy_lock)(struct file_lock___341 *, struct file_lock___341 *);
	void (*fl_release_private)(struct file_lock___341 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___340;

struct file_lock___341 {
	struct file_lock___341 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___341 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___340 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___340 *fl_ops;
	const struct lock_manager_operations___340 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___340 {
	int (*lm_compare_owner)(struct file_lock___341 *, struct file_lock___341 *);
	long unsigned int (*lm_owner_key)(struct file_lock___341 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___341 *);
	int (*lm_grant)(struct file_lock___341 *, int);
	bool (*lm_break)(struct file_lock___341 *);
	int (*lm_change)(struct file_lock___341 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___341 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___340 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___340 *fa_next;
	struct file___341 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___340 {
	const char *name;
	int fs_flags;
	struct dentry___340 * (*mount)(struct file_system_type___340 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___340 *);
	struct module___279 *owner;
	struct file_system_type___340 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___340 {
	struct inode___341 * (*alloc_inode)(struct super_block___340 *);
	void (*destroy_inode)(struct inode___341 *);
	void (*dirty_inode)(struct inode___341 *, int);
	int (*write_inode)(struct inode___341 *, struct writeback_control___143 *);
	int (*drop_inode)(struct inode___341 *);
	void (*evict_inode)(struct inode___341 *);
	void (*put_super)(struct super_block___340 *);
	int (*sync_fs)(struct super_block___340 *, int);
	int (*freeze_super)(struct super_block___340 *);
	int (*freeze_fs)(struct super_block___340 *);
	int (*thaw_super)(struct super_block___340 *);
	int (*unfreeze_fs)(struct super_block___340 *);
	int (*statfs)(struct dentry___340 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___340 *, int *, char *);
	void (*umount_begin)(struct super_block___340 *);
	int (*show_options)(struct seq_file___289 *, struct dentry___340 *);
	int (*show_devname)(struct seq_file___289 *, struct dentry___340 *);
	int (*show_path)(struct seq_file___289 *, struct dentry___340 *);
	int (*show_stats)(struct seq_file___289 *, struct dentry___340 *);
	ssize_t (*quota_read)(struct super_block___340 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___340 *, int, const char *, size_t, loff_t);
	struct dquot___340 ** (*get_dquots)(struct inode___341 *);
	int (*bdev_try_to_free_page)(struct super_block___340 *, struct page___342 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___340 *, struct shrink_control___126 *);
	long int (*free_cached_objects)(struct super_block___340 *, struct shrink_control___126 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct xattr_handler___26 {
	const char *name;
	const char *prefix;
	int flags;
	bool (*list)(struct dentry___340 *);
	int (*get)(const struct xattr_handler___26 *, struct dentry___340 *, struct inode___341 *, const char *, void *, size_t);
	int (*set)(const struct xattr_handler___26 *, struct dentry___340 *, struct inode___341 *, const char *, const void *, size_t, int);
};

typedef void (*poll_queue_proc___214)(struct file___341 *, wait_queue_head_t *, struct poll_table_struct___208 *);

struct poll_table_struct___208 {
	poll_queue_proc___214 _qproc;
	__poll_t _key;
};

struct seq_operations___288;

struct seq_file___289 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___288 *op;
	int poll_event;
	const struct file___341 *file;
	void *private;
};

typedef void bio_end_io_t___160(struct bio___160 *);

struct bio_vec___162 {
	struct page___342 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___160;

struct bio_set___160;

struct bio___160 {
	struct bio___160 *bi_next;
	struct gendisk___84 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___160 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___160 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___162 *bi_io_vec;
	struct bio_set___160 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___162 bi_inline_vecs[0];
};

typedef int (*key_restrict_link_func_t___317)(struct key___316 *, const struct key_type *, const union key_payload *, struct key___316 *);

struct key_restriction___316;

struct key___316 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___342 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___316 *restrict_link;
};

struct key_restriction___316 {
	key_restrict_link_func_t___317 check;
	struct key___316 *key;
	struct key_type *keytype;
};

struct kobj_attribute___319 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___328 *, struct kobj_attribute___319 *, char *);
	ssize_t (*store)(struct kobject___328 *, struct kobj_attribute___319 *, const char *, size_t);
};

typedef void compound_page_dtor___329(struct page___342 *);

struct seq_operations___288 {
	void * (*start)(struct seq_file___289 *, loff_t *);
	void (*stop)(struct seq_file___289 *, void *);
	void * (*next)(struct seq_file___289 *, void *, loff_t *);
	int (*show)(struct seq_file___289 *, void *);
};

struct cgroup_namespace___222 {
	refcount_t count;
	struct ns_common___9 ns;
	struct user_namespace___237 *user_ns;
	struct ucounts___237 *ucounts;
	struct css_set___222 *root_cset;
};

struct ucounts___237 {
	struct hlist_node node;
	struct user_namespace___237 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct kernfs_root___334;

struct kernfs_elem_dir___334 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___334 *root;
};

struct kernfs_syscall_ops___334;

struct kernfs_root___334 {
	struct kernfs_node___335 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___334 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___334 {
	struct kernfs_node___335 *target_kn;
};

struct kernfs_ops___334;

struct kernfs_elem_attr___334 {
	const struct kernfs_ops___334 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___335 *notify_next;
};

struct kernfs_node___335 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___335 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___334 dir;
		struct kernfs_elem_symlink___334 symlink;
		struct kernfs_elem_attr___334 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___334;

struct kernfs_ops___334 {
	int (*open)(struct kernfs_open_file___334 *);
	void (*release)(struct kernfs_open_file___334 *);
	int (*seq_show)(struct seq_file___289 *, void *);
	void * (*seq_start)(struct seq_file___289 *, loff_t *);
	void * (*seq_next)(struct seq_file___289 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___289 *, void *);
	ssize_t (*read)(struct kernfs_open_file___334 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___334 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___334 *, struct vm_area_struct___342 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___334 *, struct poll_table_struct___208 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___334 {
	int (*remount_fs)(struct kernfs_root___334 *, int *, char *);
	int (*show_options)(struct seq_file___289 *, struct kernfs_root___334 *);
	int (*mkdir)(struct kernfs_node___335 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___335 *);
	int (*rename)(struct kernfs_node___335 *, struct kernfs_node___335 *, const char *);
	int (*show_path)(struct seq_file___289 *, struct kernfs_node___335 *, struct kernfs_root___334 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___334 {
	struct kernfs_node___335 *kn;
	struct file___341 *file;
	struct seq_file___289 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___329 *vm_ops;
};

struct bin_attribute___304;

struct attribute_group___305 {
	const char *name;
	umode_t (*is_visible)(struct kobject___328 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___328 *, struct bin_attribute___304 *, int);
	struct attribute **attrs;
	struct bin_attribute___304 **bin_attrs;
};

struct bin_attribute___304 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___341 *, struct kobject___328 *, struct bin_attribute___304 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___341 *, struct kobject___328 *, struct bin_attribute___304 *, char *, loff_t, size_t);
	int (*mmap)(struct file___341 *, struct kobject___328 *, struct bin_attribute___304 *, struct vm_area_struct___342 *);
};

struct sysfs_ops___327 {
	ssize_t (*show)(struct kobject___328 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___328 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___327;

struct kset___327 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___328 kobj;
	const struct kset_uevent_ops___327 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___327 {
	void (*release)(struct kobject___328 *);
	const struct sysfs_ops___327 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___27 * (*child_ns_type)(struct kobject___328 *);
	const void * (*namespace)(struct kobject___328 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___327 {
	int (* const filter)(struct kset___327 *, struct kobject___328 *);
	const char * (* const name)(struct kset___327 *, struct kobject___328 *);
	int (* const uevent)(struct kset___327 *, struct kobject___328 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___276 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___276 *);
	int (*get)(char *, const struct kernel_param___276 *);
	void (*free)(void *);
};

struct kparam_array___276;

struct kernel_param___276 {
	const char *name;
	struct module___279 *mod;
	const struct kernel_param_ops___276 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___276 *arr;
	};
};

struct kparam_array___276 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___276 *ops;
	void *elem;
};

struct module_attribute___276 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___276 *, struct module_kobject___276 *, char *);
	ssize_t (*store)(struct module_attribute___276 *, struct module_kobject___276 *, const char *, size_t);
	void (*setup)(struct module___279 *, const char *);
	int (*test)(struct module___279 *);
	void (*free)(struct module___279 *);
};

struct trace_event_class___129;

struct trace_event_call___129 {
	struct list_head list;
	struct trace_event_class___129 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___13 event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___37 *prog_array;
	int (*perf_perm)(struct trace_event_call___129 *, struct perf_event___136 *);
};

struct dev_pm_ops___307 {
	int (*prepare)(struct device___307 *);
	void (*complete)(struct device___307 *);
	int (*suspend)(struct device___307 *);
	int (*resume)(struct device___307 *);
	int (*freeze)(struct device___307 *);
	int (*thaw)(struct device___307 *);
	int (*poweroff)(struct device___307 *);
	int (*restore)(struct device___307 *);
	int (*suspend_late)(struct device___307 *);
	int (*resume_early)(struct device___307 *);
	int (*freeze_late)(struct device___307 *);
	int (*thaw_early)(struct device___307 *);
	int (*poweroff_late)(struct device___307 *);
	int (*restore_early)(struct device___307 *);
	int (*suspend_noirq)(struct device___307 *);
	int (*resume_noirq)(struct device___307 *);
	int (*freeze_noirq)(struct device___307 *);
	int (*thaw_noirq)(struct device___307 *);
	int (*poweroff_noirq)(struct device___307 *);
	int (*restore_noirq)(struct device___307 *);
	int (*runtime_suspend)(struct device___307 *);
	int (*runtime_resume)(struct device___307 *);
	int (*runtime_idle)(struct device___307 *);
};

struct dev_pm_domain___307 {
	struct dev_pm_ops___307 ops;
	void (*detach)(struct device___307 *, bool);
	int (*activate)(struct device___307 *);
	void (*sync)(struct device___307 *);
	void (*dismiss)(struct device___307 *);
};

struct subsys_private___5;

struct bus_type___307 {
	const char *name;
	const char *dev_name;
	struct device___307 *dev_root;
	const struct attribute_group___305 **bus_groups;
	const struct attribute_group___305 **dev_groups;
	const struct attribute_group___305 **drv_groups;
	int (*match)(struct device___307 *, struct device_driver___307 *);
	int (*uevent)(struct device___307 *, struct kobj_uevent_env *);
	int (*probe)(struct device___307 *);
	int (*remove)(struct device___307 *);
	void (*shutdown)(struct device___307 *);
	int (*online)(struct device___307 *);
	int (*offline)(struct device___307 *);
	int (*suspend)(struct device___307 *, pm_message_t);
	int (*resume)(struct device___307 *);
	int (*num_vf)(struct device___307 *);
	int (*dma_configure)(struct device___307 *);
	const struct dev_pm_ops___307 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private___5 *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct driver_private___5;

struct device_driver___307 {
	const char *name;
	struct bus_type___307 *bus;
	struct module___279 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___307 *);
	int (*remove)(struct device___307 *);
	void (*shutdown)(struct device___307 *);
	int (*suspend)(struct device___307 *, pm_message_t);
	int (*resume)(struct device___307 *);
	const struct attribute_group___305 **groups;
	const struct dev_pm_ops___307 *pm;
	void (*coredump)(struct device___307 *);
	struct driver_private___5 *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct subsys_private___5 {
	struct kset___327 subsys;
	struct kset___327 *devices_kset;
	struct list_head interfaces;
	struct mutex mutex;
	struct kset___327 *drivers_kset;
	struct klist klist_devices;
	struct klist klist_drivers;
	struct blocking_notifier_head___341 bus_notifier;
	unsigned int drivers_autoprobe: 1;
	struct bus_type___307 *bus;
	struct kset___327 glue_dirs;
	struct class___307 *class;
};

struct device_type___307 {
	const char *name;
	const struct attribute_group___305 **groups;
	int (*uevent)(struct device___307 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___307 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___307 *);
	const struct dev_pm_ops___307 *pm;
};

struct driver_private___5 {
	struct kobject___328 kobj;
	struct klist klist_devices;
	struct klist_node knode_bus;
	struct module_kobject___276 *mkobj;
	struct device_driver___307 *driver;
};

struct class___307 {
	const char *name;
	struct module___279 *owner;
	const struct attribute_group___305 **class_groups;
	const struct attribute_group___305 **dev_groups;
	struct kobject___328 *dev_kobj;
	int (*dev_uevent)(struct device___307 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___307 *, umode_t *);
	void (*class_release)(struct class___307 *);
	void (*dev_release)(struct device___307 *);
	int (*shutdown_pre)(struct device___307 *);
	const struct kobj_ns_type_operations___27 *ns_type;
	const void * (*namespace)(struct device___307 *);
	const struct dev_pm_ops___307 *pm;
	struct subsys_private___5 *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct device_private___5 {
	struct klist klist_children;
	struct klist_node knode_parent;
	struct klist_node knode_driver;
	struct klist_node knode_bus;
	struct list_head deferred_probe;
	struct device___307 *device;
};

struct node___198 {
	struct device___307 dev;
};

struct bpf_map___223;

struct bpf_map_ops___222 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___223 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___223 *, struct file___341 *);
	void (*map_free)(struct bpf_map___223 *);
	int (*map_get_next_key)(struct bpf_map___223 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___223 *);
	void * (*map_lookup_elem)(struct bpf_map___223 *, void *);
	int (*map_update_elem)(struct bpf_map___223 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___223 *, void *);
	int (*map_push_elem)(struct bpf_map___223 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___223 *, void *);
	int (*map_peek_elem)(struct bpf_map___223 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___223 *, struct file___341 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___223 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___223 *, void *, struct seq_file___289 *);
	int (*map_check_btf)(const struct bpf_map___223 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___223 {
	const struct bpf_map_ops___222 *ops;
	struct bpf_map___223 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___316 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___222;

typedef void (*kthread_work_func_t___222)(struct kthread_work___222 *);

struct kthread_worker___222;

struct kthread_work___222 {
	struct list_head node;
	kthread_work_func_t___222 func;
	struct kthread_worker___222 *worker;
	int canceling;
};

struct kthread_worker___222 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___342 *task;
	struct kthread_work___222 *current_work;
};

struct kthread_delayed_work___222 {
	struct kthread_work___222 work;
	struct timer_list timer;
};

struct psi_group___222 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___222 *poll_kworker;
	struct kthread_delayed_work___222 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___222;

struct cgroup_rstat_cpu___222;

struct cgroup___222 {
	struct cgroup_subsys_state___222 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___335 *kn;
	struct cgroup_file___222 procs_file;
	struct cgroup_file___222 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___222 *subsys[13];
	struct cgroup_root___222 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___222 *dom_cgrp;
	struct cgroup_rstat_cpu___222 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___37 bpf;
	atomic_t congestion_count;
	struct cgroup___222 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___222 psi;
	int ancestor_ids[0];
};

struct cftype___222;

struct cgroup_subsys___222 {
	struct cgroup_subsys_state___222 * (*css_alloc)(struct cgroup_subsys_state___222 *);
	int (*css_online)(struct cgroup_subsys_state___222 *);
	void (*css_offline)(struct cgroup_subsys_state___222 *);
	void (*css_released)(struct cgroup_subsys_state___222 *);
	void (*css_free)(struct cgroup_subsys_state___222 *);
	void (*css_reset)(struct cgroup_subsys_state___222 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___222 *, int);
	int (*css_extra_stat_show)(struct seq_file___289 *, struct cgroup_subsys_state___222 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___342 *);
	void (*cancel_fork)(struct task_struct___342 *);
	void (*fork)(struct task_struct___342 *);
	void (*exit)(struct task_struct___342 *);
	void (*free)(struct task_struct___342 *);
	void (*bind)(struct cgroup_subsys_state___222 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___222 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___222 *dfl_cftypes;
	struct cftype___222 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___222 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___222 *updated_children;
	struct cgroup___222 *updated_next;
};

struct cgroup_root___222 {
	struct kernfs_root___334 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___222 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___222 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___222 *ss;
	struct list_head node;
	struct kernfs_ops___334 *kf_ops;
	int (*open)(struct kernfs_open_file___334 *);
	void (*release)(struct kernfs_open_file___334 *);
	u64 (*read_u64)(struct cgroup_subsys_state___222 *, struct cftype___222 *);
	s64 (*read_s64)(struct cgroup_subsys_state___222 *, struct cftype___222 *);
	int (*seq_show)(struct seq_file___289 *, void *);
	void * (*seq_start)(struct seq_file___289 *, loff_t *);
	void * (*seq_next)(struct seq_file___289 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___289 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___222 *, struct cftype___222 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___222 *, struct cftype___222 *, s64);
	ssize_t (*write)(struct kernfs_open_file___334 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___334 *, struct poll_table_struct___208 *);
};

struct perf_cpu_context___136;

struct pmu___136 {
	struct list_head entry;
	struct module___279 *module;
	struct device___307 *dev;
	const struct attribute_group___305 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___136 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___136 *);
	void (*pmu_disable)(struct pmu___136 *);
	int (*event_init)(struct perf_event___136 *);
	void (*event_mapped)(struct perf_event___136 *, struct mm_struct___341 *);
	void (*event_unmapped)(struct perf_event___136 *, struct mm_struct___341 *);
	int (*add)(struct perf_event___136 *, int);
	void (*del)(struct perf_event___136 *, int);
	void (*start)(struct perf_event___136 *, int);
	void (*stop)(struct perf_event___136 *, int);
	void (*read)(struct perf_event___136 *);
	void (*start_txn)(struct pmu___136 *, unsigned int);
	int (*commit_txn)(struct pmu___136 *);
	void (*cancel_txn)(struct pmu___136 *);
	int (*event_idx)(struct perf_event___136 *);
	void (*sched_task)(struct perf_event_context___136 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___136 *);
	int (*filter_match)(struct perf_event___136 *);
	int (*check_period)(struct perf_event___136 *, u64);
};

struct perf_cpu_context___136 {
	struct perf_event_context___136 ctx;
	struct perf_event_context___136 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___136 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___136 {
	struct cgroup_subsys_state___222 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___129 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___129 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___129 *);
	struct list_head * (*get_fields)(struct trace_event_call___129 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___129 *);
};

struct bio_integrity_payload___160 {
	struct bio___160 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___162 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___162 bip_inline_vecs[0];
};

struct bio_set___160 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___160 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___84 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___84 *last_lookup;
	struct hd_struct___84 *part[0];
};

struct bdi_writeback_congested___160 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___160 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct mem_cgroup_reclaim_iter___126 {
	struct mem_cgroup___126 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___126 {
	struct lruvec___341 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___126 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___126 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct req {
	struct req *next;
	struct completion done;
	int err;
	const char *name;
	umode_t mode;
	kuid_t uid;
	kgid_t gid;
	struct device___307 *dev;
};

struct module___280;

struct file___342;

struct kiocb___342;

struct poll_table_struct___209;

struct vm_area_struct___343;

struct inode___342;

struct file_lock___342;

struct page___343;

struct seq_file___290;

struct file_operations___342 {
	struct module___280 *owner;
	loff_t (*llseek)(struct file___342 *, loff_t, int);
	ssize_t (*read)(struct file___342 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___342 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___342 *, struct iov_iter___149 *);
	ssize_t (*write_iter)(struct kiocb___342 *, struct iov_iter___149 *);
	int (*iopoll)(struct kiocb___342 *, bool);
	int (*iterate)(struct file___342 *, struct dir_context *);
	int (*iterate_shared)(struct file___342 *, struct dir_context *);
	__poll_t (*poll)(struct file___342 *, struct poll_table_struct___209 *);
	long int (*unlocked_ioctl)(struct file___342 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___342 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___342 *, struct vm_area_struct___343 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___342 *, struct file___342 *);
	int (*flush)(struct file___342 *, fl_owner_t);
	int (*release)(struct inode___342 *, struct file___342 *);
	int (*fsync)(struct file___342 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___342 *, int);
	int (*lock)(struct file___342 *, int, struct file_lock___342 *);
	ssize_t (*sendpage)(struct file___342 *, struct page___343 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___342 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___342 *, int, struct file_lock___342 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___342 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___342 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___342 *, long int, struct file_lock___342 **, void **);
	long int (*fallocate)(struct file___342 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___290 *, struct file___342 *);
	ssize_t (*copy_file_range)(struct file___342 *, loff_t, struct file___342 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___342 *, loff_t, struct file___342 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___342 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct perf_event___137;

struct debug_info___137 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___137 *hbp_break[16];
	struct perf_event___137 *hbp_watch[16];
};

struct task_struct___343;

struct hw_perf_event___137 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___343 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___137)(struct perf_event___137 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___137;

struct perf_event_context___137;

struct fasync_struct___341;

struct pid_namespace___213;

struct trace_event_call___130;

struct perf_cgroup___137;

struct perf_event___137 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___137 *group_leader;
	struct pmu___137 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___137 hw;
	struct perf_event_context___137 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___137 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___343 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___341 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___137 *);
	struct callback_head callback_head;
	struct pid_namespace___213 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___137 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___137 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___130 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___137 *cgrp;
	struct list_head sb_list;
};

struct thread_struct___137 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___137 debug;
	long: 64;
};

struct vmacache___342 {
	u64 seqnum;
	struct vm_area_struct___343 *vmas[4];
};

struct page_frag___342 {
	struct page___343 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___342;

struct pid___213;

struct cred___317;

struct nsproxy___268;

struct signal_struct___250;

struct css_set___223;

struct task_struct___343 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___343 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___342 *mm;
	struct mm_struct___342 *active_mm;
	struct vmacache___342 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___343 *real_parent;
	struct task_struct___343 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___343 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___213 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___213 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___213 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___317 *ptracer_cred;
	const struct cred___317 *real_cred;
	const struct cred___317 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___268 *nsproxy;
	struct signal_struct___250 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___343 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___84 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___223 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___137 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___342 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___343 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___137 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rw_semaphore___343 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___343 *owner;
};

struct secondary_data___343 {
	void *stack;
	struct task_struct___343 *task;
	long int status;
};

struct blocking_notifier_head___342 {
	struct rw_semaphore___343 rwsem;
	struct notifier_block *head;
};

typedef struct page___343 *pgtable_t___342;

struct address_space___341;

struct dev_pagemap___330;

struct page___343 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___341 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___343 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___342 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___342 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___330 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___342;

struct lruvec___342 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___342 *pgdat;
};

struct zone___342 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___342 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___342 {
	struct zone___342 *zone;
	int zone_idx;
};

struct zonelist___342 {
	struct zoneref___342 _zonerefs[25];
};

struct pglist_data___342 {
	struct zone___342 node_zones[3];
	struct zonelist___342 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___343 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___343 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___342 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct key___317;

struct ucounts___238;

struct user_namespace___238 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___238 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___9 ns;
	long unsigned int flags;
	struct key___317 *persistent_keyring_register;
	struct rw_semaphore___343 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___238 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_root___335;

struct kernfs_elem_dir___335 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___335 *root;
};

struct kernfs_node___336;

struct kernfs_syscall_ops___335;

struct kernfs_root___335 {
	struct kernfs_node___336 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___335 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___335 {
	struct kernfs_node___336 *target_kn;
};

struct kernfs_ops___335;

struct kernfs_elem_attr___335 {
	const struct kernfs_ops___335 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___336 *notify_next;
};

struct kernfs_node___336 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___336 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___335 dir;
		struct kernfs_elem_symlink___335 symlink;
		struct kernfs_elem_attr___335 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___335;

struct kernfs_ops___335 {
	int (*open)(struct kernfs_open_file___335 *);
	void (*release)(struct kernfs_open_file___335 *);
	int (*seq_show)(struct seq_file___290 *, void *);
	void * (*seq_start)(struct seq_file___290 *, loff_t *);
	void * (*seq_next)(struct seq_file___290 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___290 *, void *);
	ssize_t (*read)(struct kernfs_open_file___335 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___335 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___335 *, struct vm_area_struct___343 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___335 *, struct poll_table_struct___209 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___335 {
	int (*remount_fs)(struct kernfs_root___335 *, int *, char *);
	int (*show_options)(struct seq_file___290 *, struct kernfs_root___335 *);
	int (*mkdir)(struct kernfs_node___336 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___336 *);
	int (*rename)(struct kernfs_node___336 *, struct kernfs_node___336 *, const char *);
	int (*show_path)(struct seq_file___290 *, struct kernfs_node___336 *, struct kernfs_root___335 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___289;

struct seq_file___290 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___289 *op;
	int poll_event;
	const struct file___342 *file;
	void *private;
};

struct vm_operations_struct___330;

struct kernfs_open_file___335 {
	struct kernfs_node___336 *kn;
	struct file___342 *file;
	struct seq_file___290 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___330 *vm_ops;
};

struct dentry___341;

struct path___342 {
	struct vfsmount *mnt;
	struct dentry___341 *dentry;
};

struct fown_struct___213 {
	rwlock_t lock;
	struct pid___213 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___342 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___342 f_path;
	struct inode___342 *f_inode;
	const struct file_operations___342 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___213 f_owner;
	const struct cred___317 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___341 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___330;

struct vm_operations_struct___330 {
	void (*open)(struct vm_area_struct___343 *);
	void (*close)(struct vm_area_struct___343 *);
	int (*split)(struct vm_area_struct___343 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___343 *);
	vm_fault_t (*fault)(struct vm_fault___330 *);
	vm_fault_t (*huge_fault)(struct vm_fault___330 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___330 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___343 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___330 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___330 *);
	int (*access)(struct vm_area_struct___343 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___343 *);
	int (*set_policy)(struct vm_area_struct___343 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___343 *, long unsigned int);
	struct page___343 * (*find_special_page)(struct vm_area_struct___343 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___215)(struct file___342 *, wait_queue_head_t *, struct poll_table_struct___209 *);

struct poll_table_struct___209 {
	poll_queue_proc___215 _qproc;
	__poll_t _key;
};

struct vm_area_struct___343 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___343 *vm_next;
	struct vm_area_struct___343 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___342 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___330 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___342 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___329;

struct bin_attribute___305;

struct attribute_group___306 {
	const char *name;
	umode_t (*is_visible)(struct kobject___329 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___329 *, struct bin_attribute___305 *, int);
	struct attribute **attrs;
	struct bin_attribute___305 **bin_attrs;
};

struct kset___328;

struct kobj_type___328;

struct kobject___329 {
	const char *name;
	struct list_head entry;
	struct kobject___329 *parent;
	struct kset___328 *kset;
	struct kobj_type___328 *ktype;
	struct kernfs_node___336 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___305 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___342 *, struct kobject___329 *, struct bin_attribute___305 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___342 *, struct kobject___329 *, struct bin_attribute___305 *, char *, loff_t, size_t);
	int (*mmap)(struct file___342 *, struct kobject___329 *, struct bin_attribute___305 *, struct vm_area_struct___343 *);
};

struct sysfs_ops___328 {
	ssize_t (*show)(struct kobject___329 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___329 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___328;

struct kset___328 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___329 kobj;
	const struct kset_uevent_ops___328 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___328 {
	void (*release)(struct kobject___329 *);
	const struct sysfs_ops___328 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___27 * (*child_ns_type)(struct kobject___329 *);
	const void * (*namespace)(struct kobject___329 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___328 {
	int (* const filter)(struct kset___328 *, struct kobject___329 *);
	const char * (* const name)(struct kset___328 *, struct kobject___329 *);
	int (* const uevent)(struct kset___328 *, struct kobject___329 *, struct kobj_uevent_env *);
};

struct kobj_attribute___320 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___329 *, struct kobj_attribute___320 *, char *);
	ssize_t (*store)(struct kobject___329 *, struct kobj_attribute___320 *, const char *, size_t);
};

struct device___308;

struct dev_pm_ops___308 {
	int (*prepare)(struct device___308 *);
	void (*complete)(struct device___308 *);
	int (*suspend)(struct device___308 *);
	int (*resume)(struct device___308 *);
	int (*freeze)(struct device___308 *);
	int (*thaw)(struct device___308 *);
	int (*poweroff)(struct device___308 *);
	int (*restore)(struct device___308 *);
	int (*suspend_late)(struct device___308 *);
	int (*resume_early)(struct device___308 *);
	int (*freeze_late)(struct device___308 *);
	int (*thaw_early)(struct device___308 *);
	int (*poweroff_late)(struct device___308 *);
	int (*restore_early)(struct device___308 *);
	int (*suspend_noirq)(struct device___308 *);
	int (*resume_noirq)(struct device___308 *);
	int (*freeze_noirq)(struct device___308 *);
	int (*thaw_noirq)(struct device___308 *);
	int (*poweroff_noirq)(struct device___308 *);
	int (*restore_noirq)(struct device___308 *);
	int (*runtime_suspend)(struct device___308 *);
	int (*runtime_resume)(struct device___308 *);
	int (*runtime_idle)(struct device___308 *);
};

struct wakeup_source___4;

struct wake_irq___4;

struct dev_pm_qos___17;

struct dev_pm_info___308 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___4 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq___4 *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___4 *subsys_data;
	void (*set_latency_tolerance)(struct device___308 *, s32);
	struct dev_pm_qos___17 *qos;
};

struct device_type___308;

struct bus_type___308;

struct device_driver___308;

struct dev_pm_domain___308;

struct class___308;

struct device___308 {
	struct device___308 *parent;
	struct device_private *p;
	struct kobject___329 kobj;
	const char *init_name;
	const struct device_type___308 *type;
	struct mutex mutex;
	struct bus_type___308 *bus;
	struct device_driver___308 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___308 power;
	struct dev_pm_domain___308 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___308 *class;
	const struct attribute_group___306 **groups;
	void (*release)(struct device___308 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct wakeup_source___4 {
	const char *name;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq___4 *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	bool active: 1;
	bool autosleep_enabled: 1;
};

struct wake_irq___4 {
	struct device___308 *dev;
	unsigned int status;
	int irq;
	const char *name;
};

struct pm_qos_constraints___17 {
	struct plist_head list;
	s32 target_value;
	s32 default_value;
	s32 no_constraint_value;
	enum pm_qos_type type;
	struct blocking_notifier_head___342 *notifiers;
};

struct dev_pm_qos_request___17;

struct dev_pm_qos___17 {
	struct pm_qos_constraints___17 resume_latency;
	struct pm_qos_constraints___17 latency_tolerance;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___17 *resume_latency_req;
	struct dev_pm_qos_request___17 *latency_tolerance_req;
	struct dev_pm_qos_request___17 *flags_req;
};

struct dev_pm_domain___308 {
	struct dev_pm_ops___308 ops;
	void (*detach)(struct device___308 *, bool);
	int (*activate)(struct device___308 *);
	void (*sync)(struct device___308 *);
	void (*dismiss)(struct device___308 *);
};

struct upid___213 {
	int nr;
	struct pid_namespace___213 *ns;
};

struct pid_namespace___213 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___343 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___213 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___341 *proc_self;
	struct dentry___341 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___238 *user_ns;
	struct ucounts___238 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___9 ns;
};

struct pid___213 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___213 numbers[1];
};

struct user_struct___317 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___317 *uid_keyring;
	struct key___317 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___342;

struct mm_struct___342 {
	struct {
		struct vm_area_struct___343 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___342 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___343 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___342 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___343 *owner;
		struct user_namespace___238 *user_ns;
		struct file___342 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___342 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___317 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___317 *session_keyring;
	struct key___317 *process_keyring;
	struct key___317 *thread_keyring;
	struct key___317 *request_key_auth;
	void *security;
	struct user_struct___317 *user;
	struct user_namespace___238 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___223;

struct nsproxy___268 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___213 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___223 *cgroup_ns;
};

struct signal_struct___250 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___343 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___343 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___213 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___213 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___342 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___213 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___223;

struct cgroup___223;

struct css_set___223 {
	struct cgroup_subsys_state___223 *subsys[13];
	refcount_t refcount;
	struct css_set___223 *dom_cset;
	struct cgroup___223 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___223 *mg_src_cgrp;
	struct cgroup___223 *mg_dst_cgrp;
	struct css_set___223 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___137 {
	struct pmu___137 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___343 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___137 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

union thread_union___262 {
	struct task_struct___343 task;
	long unsigned int stack[8192];
};

struct bus_type___308 {
	const char *name;
	const char *dev_name;
	struct device___308 *dev_root;
	const struct attribute_group___306 **bus_groups;
	const struct attribute_group___306 **dev_groups;
	const struct attribute_group___306 **drv_groups;
	int (*match)(struct device___308 *, struct device_driver___308 *);
	int (*uevent)(struct device___308 *, struct kobj_uevent_env *);
	int (*probe)(struct device___308 *);
	int (*remove)(struct device___308 *);
	void (*shutdown)(struct device___308 *);
	int (*online)(struct device___308 *);
	int (*offline)(struct device___308 *);
	int (*suspend)(struct device___308 *, pm_message_t);
	int (*resume)(struct device___308 *);
	int (*num_vf)(struct device___308 *);
	int (*dma_configure)(struct device___308 *);
	const struct dev_pm_ops___308 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___308 {
	const char *name;
	struct bus_type___308 *bus;
	struct module___280 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___308 *);
	int (*remove)(struct device___308 *);
	void (*shutdown)(struct device___308 *);
	int (*suspend)(struct device___308 *, pm_message_t);
	int (*resume)(struct device___308 *);
	const struct attribute_group___306 **groups;
	const struct dev_pm_ops___308 *pm;
	void (*coredump)(struct device___308 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___308 {
	const char *name;
	const struct attribute_group___306 **groups;
	int (*uevent)(struct device___308 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___308 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___308 *);
	const struct dev_pm_ops___308 *pm;
};

struct module_kobject___277 {
	struct kobject___329 kobj;
	struct module___280 *mod;
	struct kobject___329 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___277 {
	struct module___280 *mod;
	struct latch_tree_node node;
};

struct module_layout___277 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___277 mtn;
};

struct module_attribute___277;

struct kernel_param___277;

struct module___280 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___277 mkobj;
	struct module_attribute___277 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___329 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___277 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___277 core_layout;
	struct module_layout___277 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___130 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct class___308 {
	const char *name;
	struct module___280 *owner;
	const struct attribute_group___306 **class_groups;
	const struct attribute_group___306 **dev_groups;
	struct kobject___329 *dev_kobj;
	int (*dev_uevent)(struct device___308 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___308 *, umode_t *);
	void (*class_release)(struct class___308 *);
	void (*dev_release)(struct device___308 *);
	int (*shutdown_pre)(struct device___308 *);
	const struct kobj_ns_type_operations___27 *ns_type;
	const void * (*namespace)(struct device___308 *);
	const struct dev_pm_ops___308 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dev_pm_qos_request___17 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___308 *dev;
};

struct address_space_operations___341;

struct address_space___341 {
	struct inode___342 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___343 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___341 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___330)(struct vm_area_struct___343 *, long unsigned int, const struct page___343 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___330)(struct page___343 *, void *);

struct dev_pagemap___330 {
	dev_page_fault_t___330 page_fault;
	dev_page_free_t___330 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___308 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___342 {
	struct task_struct___343 *task;
	struct core_thread___342 *next;
};

struct core_state___342 {
	atomic_t nr_threads;
	struct core_thread___342 dumper;
	struct completion startup;
};

struct vm_fault___330 {
	struct vm_area_struct___343 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___343 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___343 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___342 prealloc_pte;
};

struct dentry_operations___341;

struct super_block___341;

struct dentry___341 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___341 *d_parent;
	struct qstr d_name;
	struct inode___342 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___341 *d_op;
	struct super_block___341 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___341;

struct block_device___341;

struct inode___342 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___341 *i_op;
	struct super_block___341 *i_sb;
	struct address_space___341 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___343 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___342 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___341 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___341 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___341 {
	int (*d_revalidate)(struct dentry___341 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___341 *, unsigned int);
	int (*d_hash)(const struct dentry___341 *, struct qstr *);
	int (*d_compare)(const struct dentry___341 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___341 *);
	int (*d_init)(struct dentry___341 *);
	void (*d_release)(struct dentry___341 *);
	void (*d_prune)(struct dentry___341 *);
	void (*d_iput)(struct dentry___341 *, struct inode___342 *);
	char * (*d_dname)(struct dentry___341 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___342 *);
	int (*d_manage)(const struct path___342 *, bool);
	struct dentry___341 * (*d_real)(struct dentry___341 *, const struct inode___342 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___341;

struct mem_dqinfo___341 {
	struct quota_format_type___341 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___341;

struct quota_info___341 {
	unsigned int flags;
	struct rw_semaphore___343 dqio_sem;
	struct inode___342 *files[3];
	struct mem_dqinfo___341 info[3];
	const struct quota_format_ops___341 *ops[3];
};

struct rcuwait___341 {
	struct task_struct___343 *task;
};

struct percpu_rw_semaphore___341 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___343 rw_sem;
	struct rcuwait___341 writer;
	int readers_block;
};

struct sb_writers___341 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___341 rw_sem[3];
};

struct file_system_type___341;

struct super_operations___341;

struct dquot_operations___341;

struct quotactl_ops___341;

struct super_block___341 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___341 *s_type;
	const struct super_operations___341 *s_op;
	const struct dquot_operations___341 *dq_op;
	const struct quotactl_ops___341 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___341 *s_root;
	struct rw_semaphore___343 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___341 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___341 s_dquot;
	struct sb_writers___341 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___341 *s_d_op;
	int cleancache_poolid;
	struct shrinker___126 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___238 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___342 {
	struct file___342 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___342 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___341 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___342 *ia_file;
};

struct dquot___341 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___341 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___341 {
	int qf_fmt_id;
	const struct quota_format_ops___341 *qf_ops;
	struct module___280 *qf_owner;
	struct quota_format_type___341 *qf_next;
};

struct quota_format_ops___341 {
	int (*check_quota_file)(struct super_block___341 *, int);
	int (*read_file_info)(struct super_block___341 *, int);
	int (*write_file_info)(struct super_block___341 *, int);
	int (*free_file_info)(struct super_block___341 *, int);
	int (*read_dqblk)(struct dquot___341 *);
	int (*commit_dqblk)(struct dquot___341 *);
	int (*release_dqblk)(struct dquot___341 *);
	int (*get_next_id)(struct super_block___341 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___341 {
	int (*write_dquot)(struct dquot___341 *);
	struct dquot___341 * (*alloc_dquot)(struct super_block___341 *, int);
	void (*destroy_dquot)(struct dquot___341 *);
	int (*acquire_dquot)(struct dquot___341 *);
	int (*release_dquot)(struct dquot___341 *);
	int (*mark_dirty)(struct dquot___341 *);
	int (*write_info)(struct super_block___341 *, int);
	qsize_t * (*get_reserved_space)(struct inode___342 *);
	int (*get_projid)(struct inode___342 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___342 *, qsize_t *);
	int (*get_next_id)(struct super_block___341 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___341 {
	int (*quota_on)(struct super_block___341 *, int, int, const struct path___342 *);
	int (*quota_off)(struct super_block___341 *, int);
	int (*quota_enable)(struct super_block___341 *, unsigned int);
	int (*quota_disable)(struct super_block___341 *, unsigned int);
	int (*quota_sync)(struct super_block___341 *, int);
	int (*set_info)(struct super_block___341 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___341 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___341 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___341 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___341 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___341 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___341 {
	int (*writepage)(struct page___343 *, struct writeback_control___3 *);
	int (*readpage)(struct file___342 *, struct page___343 *);
	int (*writepages)(struct address_space___341 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___343 *);
	int (*readpages)(struct file___342 *, struct address_space___341 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___342 *, struct address_space___341 *, loff_t, unsigned int, unsigned int, struct page___343 **, void **);
	int (*write_end)(struct file___342 *, struct address_space___341 *, loff_t, unsigned int, unsigned int, struct page___343 *, void *);
	sector_t (*bmap)(struct address_space___341 *, sector_t);
	void (*invalidatepage)(struct page___343 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___343 *, gfp_t);
	void (*freepage)(struct page___343 *);
	ssize_t (*direct_IO)(struct kiocb___342 *, struct iov_iter___149 *);
	int (*migratepage)(struct address_space___341 *, struct page___343 *, struct page___343 *, enum migrate_mode);
	bool (*isolate_page)(struct page___343 *, isolate_mode_t);
	void (*putback_page)(struct page___343 *);
	int (*launder_page)(struct page___343 *);
	int (*is_partially_uptodate)(struct page___343 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___343 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___341 *, struct page___343 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___342 *, sector_t *);
	void (*swap_deactivate)(struct file___342 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___341 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___342 *bd_inode;
	struct super_block___341 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___341 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___341 {
	struct dentry___341 * (*lookup)(struct inode___342 *, struct dentry___341 *, unsigned int);
	const char * (*get_link)(struct dentry___341 *, struct inode___342 *, struct delayed_call *);
	int (*permission)(struct inode___342 *, int);
	struct posix_acl * (*get_acl)(struct inode___342 *, int);
	int (*readlink)(struct dentry___341 *, char *, int);
	int (*create)(struct inode___342 *, struct dentry___341 *, umode_t, bool);
	int (*link)(struct dentry___341 *, struct inode___342 *, struct dentry___341 *);
	int (*unlink)(struct inode___342 *, struct dentry___341 *);
	int (*symlink)(struct inode___342 *, struct dentry___341 *, const char *);
	int (*mkdir)(struct inode___342 *, struct dentry___341 *, umode_t);
	int (*rmdir)(struct inode___342 *, struct dentry___341 *);
	int (*mknod)(struct inode___342 *, struct dentry___341 *, umode_t, dev_t);
	int (*rename)(struct inode___342 *, struct dentry___341 *, struct inode___342 *, struct dentry___341 *, unsigned int);
	int (*setattr)(struct dentry___341 *, struct iattr___341 *);
	int (*getattr)(const struct path___342 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___341 *, char *, size_t);
	int (*fiemap)(struct inode___342 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___342 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___342 *, struct dentry___341 *, struct file___342 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___342 *, struct dentry___341 *, umode_t);
	int (*set_acl)(struct inode___342 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___341 {
	void (*fl_copy_lock)(struct file_lock___342 *, struct file_lock___342 *);
	void (*fl_release_private)(struct file_lock___342 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___341;

struct file_lock___342 {
	struct file_lock___342 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___342 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___341 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___341 *fl_ops;
	const struct lock_manager_operations___341 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___341 {
	int (*lm_compare_owner)(struct file_lock___342 *, struct file_lock___342 *);
	long unsigned int (*lm_owner_key)(struct file_lock___342 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___342 *);
	int (*lm_grant)(struct file_lock___342 *, int);
	bool (*lm_break)(struct file_lock___342 *);
	int (*lm_change)(struct file_lock___342 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___342 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___341 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___341 *fa_next;
	struct file___342 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___341 {
	const char *name;
	int fs_flags;
	struct dentry___341 * (*mount)(struct file_system_type___341 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___341 *);
	struct module___280 *owner;
	struct file_system_type___341 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___341 {
	struct inode___342 * (*alloc_inode)(struct super_block___341 *);
	void (*destroy_inode)(struct inode___342 *);
	void (*dirty_inode)(struct inode___342 *, int);
	int (*write_inode)(struct inode___342 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___342 *);
	void (*evict_inode)(struct inode___342 *);
	void (*put_super)(struct super_block___341 *);
	int (*sync_fs)(struct super_block___341 *, int);
	int (*freeze_super)(struct super_block___341 *);
	int (*freeze_fs)(struct super_block___341 *);
	int (*thaw_super)(struct super_block___341 *);
	int (*unfreeze_fs)(struct super_block___341 *);
	int (*statfs)(struct dentry___341 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___341 *, int *, char *);
	void (*umount_begin)(struct super_block___341 *);
	int (*show_options)(struct seq_file___290 *, struct dentry___341 *);
	int (*show_devname)(struct seq_file___290 *, struct dentry___341 *);
	int (*show_path)(struct seq_file___290 *, struct dentry___341 *);
	int (*show_stats)(struct seq_file___290 *, struct dentry___341 *);
	ssize_t (*quota_read)(struct super_block___341 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___341 *, int, const char *, size_t, loff_t);
	struct dquot___341 ** (*get_dquots)(struct inode___342 *);
	int (*bdev_try_to_free_page)(struct super_block___341 *, struct page___343 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___341 *, struct shrink_control___126 *);
	long int (*free_cached_objects)(struct super_block___341 *, struct shrink_control___126 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___330(struct page___343 *);

typedef int (*key_restrict_link_func_t___318)(struct key___317 *, const struct key_type *, const union key_payload *, struct key___317 *);

struct key_restriction___317;

struct key___317 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___343 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___317 *restrict_link;
};

struct key_restriction___317 {
	key_restrict_link_func_t___318 check;
	struct key___317 *key;
	struct key_type *keytype;
};

struct seq_operations___289 {
	void * (*start)(struct seq_file___290 *, loff_t *);
	void (*stop)(struct seq_file___290 *, void *);
	void * (*next)(struct seq_file___290 *, void *, loff_t *);
	int (*show)(struct seq_file___290 *, void *);
};

struct cgroup_namespace___223 {
	refcount_t count;
	struct ns_common___9 ns;
	struct user_namespace___238 *user_ns;
	struct ucounts___238 *ucounts;
	struct css_set___223 *root_cset;
};

struct ucounts___238 {
	struct hlist_node node;
	struct user_namespace___238 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct kernel_param_ops___277 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___277 *);
	int (*get)(char *, const struct kernel_param___277 *);
	void (*free)(void *);
};

struct kparam_array___277;

struct kernel_param___277 {
	const char *name;
	struct module___280 *mod;
	const struct kernel_param_ops___277 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___277 *arr;
	};
};

struct kparam_array___277 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___277 *ops;
	void *elem;
};

struct module_attribute___277 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___277 *, struct module_kobject___277 *, char *);
	ssize_t (*store)(struct module_attribute___277 *, struct module_kobject___277 *, const char *, size_t);
	void (*setup)(struct module___280 *, const char *);
	int (*test)(struct module___280 *);
	void (*free)(struct module___280 *);
};

struct trace_event_class___130;

struct trace_event_call___130 {
	struct list_head list;
	struct trace_event_class___130 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___13 event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___37 *prog_array;
	int (*perf_perm)(struct trace_event_call___130 *, struct perf_event___137 *);
};

struct node___199 {
	struct device___308 dev;
};

struct bpf_map___224;

struct bpf_map_ops___223 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___224 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___224 *, struct file___342 *);
	void (*map_free)(struct bpf_map___224 *);
	int (*map_get_next_key)(struct bpf_map___224 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___224 *);
	void * (*map_lookup_elem)(struct bpf_map___224 *, void *);
	int (*map_update_elem)(struct bpf_map___224 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___224 *, void *);
	int (*map_push_elem)(struct bpf_map___224 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___224 *, void *);
	int (*map_peek_elem)(struct bpf_map___224 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___224 *, struct file___342 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___224 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___224 *, void *, struct seq_file___290 *);
	int (*map_check_btf)(const struct bpf_map___224 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___224 {
	const struct bpf_map_ops___223 *ops;
	struct bpf_map___224 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___317 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___223;

typedef void (*kthread_work_func_t___223)(struct kthread_work___223 *);

struct kthread_worker___223;

struct kthread_work___223 {
	struct list_head node;
	kthread_work_func_t___223 func;
	struct kthread_worker___223 *worker;
	int canceling;
};

struct kthread_worker___223 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___343 *task;
	struct kthread_work___223 *current_work;
};

struct kthread_delayed_work___223 {
	struct kthread_work___223 work;
	struct timer_list timer;
};

struct psi_group___223 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___223 *poll_kworker;
	struct kthread_delayed_work___223 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___223 {
	struct kernfs_node___336 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___223;

struct cgroup_subsys_state___223 {
	struct cgroup___223 *cgroup;
	struct cgroup_subsys___223 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___223 *parent;
};

struct cgroup_root___223;

struct cgroup_rstat_cpu___223;

struct cgroup___223 {
	struct cgroup_subsys_state___223 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___336 *kn;
	struct cgroup_file___223 procs_file;
	struct cgroup_file___223 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___223 *subsys[13];
	struct cgroup_root___223 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___223 *dom_cgrp;
	struct cgroup_rstat_cpu___223 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___37 bpf;
	atomic_t congestion_count;
	struct cgroup___223 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___223 psi;
	int ancestor_ids[0];
};

struct cftype___223;

struct cgroup_subsys___223 {
	struct cgroup_subsys_state___223 * (*css_alloc)(struct cgroup_subsys_state___223 *);
	int (*css_online)(struct cgroup_subsys_state___223 *);
	void (*css_offline)(struct cgroup_subsys_state___223 *);
	void (*css_released)(struct cgroup_subsys_state___223 *);
	void (*css_free)(struct cgroup_subsys_state___223 *);
	void (*css_reset)(struct cgroup_subsys_state___223 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___223 *, int);
	int (*css_extra_stat_show)(struct seq_file___290 *, struct cgroup_subsys_state___223 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___343 *);
	void (*cancel_fork)(struct task_struct___343 *);
	void (*fork)(struct task_struct___343 *);
	void (*exit)(struct task_struct___343 *);
	void (*free)(struct task_struct___343 *);
	void (*bind)(struct cgroup_subsys_state___223 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___223 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___223 *dfl_cftypes;
	struct cftype___223 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___223 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___223 *updated_children;
	struct cgroup___223 *updated_next;
};

struct cgroup_root___223 {
	struct kernfs_root___335 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___223 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___223 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___223 *ss;
	struct list_head node;
	struct kernfs_ops___335 *kf_ops;
	int (*open)(struct kernfs_open_file___335 *);
	void (*release)(struct kernfs_open_file___335 *);
	u64 (*read_u64)(struct cgroup_subsys_state___223 *, struct cftype___223 *);
	s64 (*read_s64)(struct cgroup_subsys_state___223 *, struct cftype___223 *);
	int (*seq_show)(struct seq_file___290 *, void *);
	void * (*seq_start)(struct seq_file___290 *, loff_t *);
	void * (*seq_next)(struct seq_file___290 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___290 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___223 *, struct cftype___223 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___223 *, struct cftype___223 *, s64);
	ssize_t (*write)(struct kernfs_open_file___335 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___335 *, struct poll_table_struct___209 *);
};

struct perf_cpu_context___137;

struct pmu___137 {
	struct list_head entry;
	struct module___280 *module;
	struct device___308 *dev;
	const struct attribute_group___306 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___137 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___137 *);
	void (*pmu_disable)(struct pmu___137 *);
	int (*event_init)(struct perf_event___137 *);
	void (*event_mapped)(struct perf_event___137 *, struct mm_struct___342 *);
	void (*event_unmapped)(struct perf_event___137 *, struct mm_struct___342 *);
	int (*add)(struct perf_event___137 *, int);
	void (*del)(struct perf_event___137 *, int);
	void (*start)(struct perf_event___137 *, int);
	void (*stop)(struct perf_event___137 *, int);
	void (*read)(struct perf_event___137 *);
	void (*start_txn)(struct pmu___137 *, unsigned int);
	int (*commit_txn)(struct pmu___137 *);
	void (*cancel_txn)(struct pmu___137 *);
	int (*event_idx)(struct perf_event___137 *);
	void (*sched_task)(struct perf_event_context___137 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___137 *);
	int (*filter_match)(struct perf_event___137 *);
	int (*check_period)(struct perf_event___137 *, u64);
};

struct perf_cpu_context___137 {
	struct perf_event_context___137 ctx;
	struct perf_event_context___137 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___137 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___137 {
	struct cgroup_subsys_state___223 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___130 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___130 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___130 *);
	struct list_head * (*get_fields)(struct trace_event_call___130 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___130 *);
};

struct device___309;

struct dev_pm_ops___309 {
	int (*prepare)(struct device___309 *);
	void (*complete)(struct device___309 *);
	int (*suspend)(struct device___309 *);
	int (*resume)(struct device___309 *);
	int (*freeze)(struct device___309 *);
	int (*thaw)(struct device___309 *);
	int (*poweroff)(struct device___309 *);
	int (*restore)(struct device___309 *);
	int (*suspend_late)(struct device___309 *);
	int (*resume_early)(struct device___309 *);
	int (*freeze_late)(struct device___309 *);
	int (*thaw_early)(struct device___309 *);
	int (*poweroff_late)(struct device___309 *);
	int (*restore_early)(struct device___309 *);
	int (*suspend_noirq)(struct device___309 *);
	int (*resume_noirq)(struct device___309 *);
	int (*freeze_noirq)(struct device___309 *);
	int (*thaw_noirq)(struct device___309 *);
	int (*poweroff_noirq)(struct device___309 *);
	int (*restore_noirq)(struct device___309 *);
	int (*runtime_suspend)(struct device___309 *);
	int (*runtime_resume)(struct device___309 *);
	int (*runtime_idle)(struct device___309 *);
};

struct wakeup_source___5;

struct wake_irq___5;

struct dev_pm_qos___18;

struct dev_pm_info___309 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___5 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq___5 *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___4 *subsys_data;
	void (*set_latency_tolerance)(struct device___309 *, s32);
	struct dev_pm_qos___18 *qos;
};

struct device_private___6;

struct device_type___309;

struct bus_type___309;

struct device_driver___309;

struct dev_pm_domain___309;

struct class___309;

struct device___309 {
	struct device___309 *parent;
	struct device_private___6 *p;
	struct kobject___316 kobj;
	const char *init_name;
	const struct device_type___309 *type;
	struct mutex mutex;
	struct bus_type___309 *bus;
	struct device_driver___309 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___309 power;
	struct dev_pm_domain___309 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___309 *class;
	const struct attribute_group___293 **groups;
	void (*release)(struct device___309 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct wakeup_source___5 {
	const char *name;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq___5 *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	bool active: 1;
	bool autosleep_enabled: 1;
};

struct wake_irq___5 {
	struct device___309 *dev;
	unsigned int status;
	int irq;
	const char *name;
};

struct dev_pm_qos_request___18;

struct dev_pm_qos___18 {
	struct pm_qos_constraints___9 resume_latency;
	struct pm_qos_constraints___9 latency_tolerance;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___18 *resume_latency_req;
	struct dev_pm_qos_request___18 *latency_tolerance_req;
	struct dev_pm_qos_request___18 *flags_req;
};

struct dev_pm_domain___309 {
	struct dev_pm_ops___309 ops;
	void (*detach)(struct device___309 *, bool);
	int (*activate)(struct device___309 *);
	void (*sync)(struct device___309 *);
	void (*dismiss)(struct device___309 *);
};

struct subsys_private___6;

struct bus_type___309 {
	const char *name;
	const char *dev_name;
	struct device___309 *dev_root;
	const struct attribute_group___293 **bus_groups;
	const struct attribute_group___293 **dev_groups;
	const struct attribute_group___293 **drv_groups;
	int (*match)(struct device___309 *, struct device_driver___309 *);
	int (*uevent)(struct device___309 *, struct kobj_uevent_env *);
	int (*probe)(struct device___309 *);
	int (*remove)(struct device___309 *);
	void (*shutdown)(struct device___309 *);
	int (*online)(struct device___309 *);
	int (*offline)(struct device___309 *);
	int (*suspend)(struct device___309 *, pm_message_t);
	int (*resume)(struct device___309 *);
	int (*num_vf)(struct device___309 *);
	int (*dma_configure)(struct device___309 *);
	const struct dev_pm_ops___309 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private___6 *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct driver_private___6;

struct device_driver___309 {
	const char *name;
	struct bus_type___309 *bus;
	struct module___11 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___309 *);
	int (*remove)(struct device___309 *);
	void (*shutdown)(struct device___309 *);
	int (*suspend)(struct device___309 *, pm_message_t);
	int (*resume)(struct device___309 *);
	const struct attribute_group___293 **groups;
	const struct dev_pm_ops___309 *pm;
	void (*coredump)(struct device___309 *);
	struct driver_private___6 *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct subsys_private___6 {
	struct kset___315 subsys;
	struct kset___315 *devices_kset;
	struct list_head interfaces;
	struct mutex mutex;
	struct kset___315 *drivers_kset;
	struct klist klist_devices;
	struct klist klist_drivers;
	struct blocking_notifier_head___341 bus_notifier;
	unsigned int drivers_autoprobe: 1;
	struct bus_type___309 *bus;
	struct kset___315 glue_dirs;
	struct class___309 *class;
};

struct device_type___309 {
	const char *name;
	const struct attribute_group___293 **groups;
	int (*uevent)(struct device___309 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___309 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___309 *);
	const struct dev_pm_ops___309 *pm;
};

struct driver_private___6 {
	struct kobject___316 kobj;
	struct klist klist_devices;
	struct klist_node knode_bus;
	struct module_kobject___273 *mkobj;
	struct device_driver___309 *driver;
};

struct class___309 {
	const char *name;
	struct module___11 *owner;
	const struct attribute_group___293 **class_groups;
	const struct attribute_group___293 **dev_groups;
	struct kobject___316 *dev_kobj;
	int (*dev_uevent)(struct device___309 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___309 *, umode_t *);
	void (*class_release)(struct class___309 *);
	void (*dev_release)(struct device___309 *);
	int (*shutdown_pre)(struct device___309 *);
	const struct kobj_ns_type_operations___27 *ns_type;
	const void * (*namespace)(struct device___309 *);
	const struct dev_pm_ops___309 *pm;
	struct subsys_private___6 *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct device_link___2 {
	struct device___309 *supplier;
	struct list_head s_node;
	struct device___309 *consumer;
	struct list_head c_node;
	enum device_link_state status;
	u32 flags;
	bool rpm_active;
	struct kref kref;
	struct callback_head callback_head;
};

struct device_private___6 {
	struct klist klist_children;
	struct klist_node knode_parent;
	struct klist_node knode_driver;
	struct klist_node knode_bus;
	struct list_head deferred_probe;
	struct device___309 *device;
};

struct dev_pm_qos_request___18 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___309 *dev;
};

typedef int (*pm_callback_t)(struct device___309 *);

struct module___281;

struct file___343;

struct kiocb___343;

struct iov_iter___150;

struct poll_table_struct___210;

struct vm_area_struct___344;

struct inode___343;

struct file_lock___343;

struct page___344;

struct seq_file___291;

struct file_operations___343 {
	struct module___281 *owner;
	loff_t (*llseek)(struct file___343 *, loff_t, int);
	ssize_t (*read)(struct file___343 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___343 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___343 *, struct iov_iter___150 *);
	ssize_t (*write_iter)(struct kiocb___343 *, struct iov_iter___150 *);
	int (*iopoll)(struct kiocb___343 *, bool);
	int (*iterate)(struct file___343 *, struct dir_context *);
	int (*iterate_shared)(struct file___343 *, struct dir_context *);
	__poll_t (*poll)(struct file___343 *, struct poll_table_struct___210 *);
	long int (*unlocked_ioctl)(struct file___343 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___343 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___343 *, struct vm_area_struct___344 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___343 *, struct file___343 *);
	int (*flush)(struct file___343 *, fl_owner_t);
	int (*release)(struct inode___343 *, struct file___343 *);
	int (*fsync)(struct file___343 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___343 *, int);
	int (*lock)(struct file___343 *, int, struct file_lock___343 *);
	ssize_t (*sendpage)(struct file___343 *, struct page___344 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___343 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___343 *, int, struct file_lock___343 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___343 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___343 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___343 *, long int, struct file_lock___343 **, void **);
	long int (*fallocate)(struct file___343 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___291 *, struct file___343 *);
	ssize_t (*copy_file_range)(struct file___343 *, loff_t, struct file___343 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___343 *, loff_t, struct file___343 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___343 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct perf_event___138;

struct debug_info___138 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___138 *hbp_break[16];
	struct perf_event___138 *hbp_watch[16];
};

struct task_struct___344;

struct hw_perf_event___138 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___344 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___138)(struct perf_event___138 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___138;

struct perf_event_context___138;

struct fasync_struct___342;

struct pid_namespace___214;

struct trace_event_call___131;

struct perf_cgroup___138;

struct perf_event___138 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___138 *group_leader;
	struct pmu___138 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___138 hw;
	struct perf_event_context___138 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___138 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___344 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___342 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___138 *);
	struct callback_head callback_head;
	struct pid_namespace___214 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___138 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___138 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___131 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___138 *cgrp;
	struct list_head sb_list;
};

struct thread_struct___138 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___138 debug;
	long: 64;
};

struct vmacache___343 {
	u64 seqnum;
	struct vm_area_struct___344 *vmas[4];
};

struct page_frag___343 {
	struct page___344 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___343;

struct mem_cgroup___127;

struct pid___214;

struct cred___318;

struct nsproxy___269;

struct signal_struct___251;

struct bio_list___161;

struct backing_dev_info___161;

struct css_set___224;

struct task_struct___344 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___344 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___343 *mm;
	struct mm_struct___343 *active_mm;
	struct vmacache___343 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___344 *real_parent;
	struct task_struct___344 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___344 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___127 *active_memcg;
	long int rh_reserved2;
	struct pid___214 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___214 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___214 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___318 *ptracer_cred;
	const struct cred___318 *real_cred;
	const struct cred___318 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___269 *nsproxy;
	struct signal_struct___251 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___344 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___161 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___161 *backing_dev_info;
	struct io_context___84 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___224 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___138 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___343 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___127 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___344 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___138 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___344 *pgtable_t___343;

struct address_space___342;

struct dev_pagemap___331;

struct page___344 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___342 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___344 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___343 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___343 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___331 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___127 *mem_cgroup;
};

struct pglist_data___343;

struct lruvec___343 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___343 *pgdat;
};

struct zone___343 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___343 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___343 {
	struct zone___343 *zone;
	int zone_idx;
};

struct zonelist___343 {
	struct zoneref___343 _zonerefs[25];
};

struct pglist_data___343 {
	struct zone___343 node_zones[3];
	struct zonelist___343 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___344 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___344 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___343 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___344 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___344 *owner;
};

struct secondary_data___344 {
	void *stack;
	struct task_struct___344 *task;
	long int status;
};

struct blocking_notifier_head___343 {
	struct rw_semaphore___344 rwsem;
	struct notifier_block *head;
};

struct key___318;

struct ucounts___239;

struct user_namespace___239 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___239 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___9 ns;
	long unsigned int flags;
	struct key___318 *persistent_keyring_register;
	struct rw_semaphore___344 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___239 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_root___336;

struct kernfs_elem_dir___336 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___336 *root;
};

struct kernfs_node___337;

struct kernfs_syscall_ops___336;

struct kernfs_root___336 {
	struct kernfs_node___337 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___336 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___336 {
	struct kernfs_node___337 *target_kn;
};

struct kernfs_ops___336;

struct kernfs_elem_attr___336 {
	const struct kernfs_ops___336 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___337 *notify_next;
};

struct kernfs_node___337 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___337 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___336 dir;
		struct kernfs_elem_symlink___336 symlink;
		struct kernfs_elem_attr___336 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___336;

struct kernfs_ops___336 {
	int (*open)(struct kernfs_open_file___336 *);
	void (*release)(struct kernfs_open_file___336 *);
	int (*seq_show)(struct seq_file___291 *, void *);
	void * (*seq_start)(struct seq_file___291 *, loff_t *);
	void * (*seq_next)(struct seq_file___291 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___291 *, void *);
	ssize_t (*read)(struct kernfs_open_file___336 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___336 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___336 *, struct vm_area_struct___344 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___336 *, struct poll_table_struct___210 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___336 {
	int (*remount_fs)(struct kernfs_root___336 *, int *, char *);
	int (*show_options)(struct seq_file___291 *, struct kernfs_root___336 *);
	int (*mkdir)(struct kernfs_node___337 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___337 *);
	int (*rename)(struct kernfs_node___337 *, struct kernfs_node___337 *, const char *);
	int (*show_path)(struct seq_file___291 *, struct kernfs_node___337 *, struct kernfs_root___336 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___290;

struct seq_file___291 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___290 *op;
	int poll_event;
	const struct file___343 *file;
	void *private;
};

struct vm_operations_struct___331;

struct kernfs_open_file___336 {
	struct kernfs_node___337 *kn;
	struct file___343 *file;
	struct seq_file___291 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___331 *vm_ops;
};

struct dentry___342;

struct path___343 {
	struct vfsmount *mnt;
	struct dentry___342 *dentry;
};

struct fown_struct___214 {
	rwlock_t lock;
	struct pid___214 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___343 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___343 f_path;
	struct inode___343 *f_inode;
	const struct file_operations___343 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___214 f_owner;
	const struct cred___318 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___342 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___331;

struct vm_operations_struct___331 {
	void (*open)(struct vm_area_struct___344 *);
	void (*close)(struct vm_area_struct___344 *);
	int (*split)(struct vm_area_struct___344 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___344 *);
	vm_fault_t (*fault)(struct vm_fault___331 *);
	vm_fault_t (*huge_fault)(struct vm_fault___331 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___331 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___344 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___331 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___331 *);
	int (*access)(struct vm_area_struct___344 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___344 *);
	int (*set_policy)(struct vm_area_struct___344 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___344 *, long unsigned int);
	struct page___344 * (*find_special_page)(struct vm_area_struct___344 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___216)(struct file___343 *, wait_queue_head_t *, struct poll_table_struct___210 *);

struct poll_table_struct___210 {
	poll_queue_proc___216 _qproc;
	__poll_t _key;
};

struct vm_area_struct___344 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___344 *vm_next;
	struct vm_area_struct___344 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___343 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___331 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___343 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___330;

struct bin_attribute___306;

struct attribute_group___307 {
	const char *name;
	umode_t (*is_visible)(struct kobject___330 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___330 *, struct bin_attribute___306 *, int);
	struct attribute **attrs;
	struct bin_attribute___306 **bin_attrs;
};

struct kset___329;

struct kobj_type___329;

struct kobject___330 {
	const char *name;
	struct list_head entry;
	struct kobject___330 *parent;
	struct kset___329 *kset;
	struct kobj_type___329 *ktype;
	struct kernfs_node___337 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___306 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___343 *, struct kobject___330 *, struct bin_attribute___306 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___343 *, struct kobject___330 *, struct bin_attribute___306 *, char *, loff_t, size_t);
	int (*mmap)(struct file___343 *, struct kobject___330 *, struct bin_attribute___306 *, struct vm_area_struct___344 *);
};

struct sysfs_ops___329 {
	ssize_t (*show)(struct kobject___330 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___330 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___329;

struct kset___329 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___330 kobj;
	const struct kset_uevent_ops___329 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___329 {
	void (*release)(struct kobject___330 *);
	const struct sysfs_ops___329 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___27 * (*child_ns_type)(struct kobject___330 *);
	const void * (*namespace)(struct kobject___330 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___329 {
	int (* const filter)(struct kset___329 *, struct kobject___330 *);
	const char * (* const name)(struct kset___329 *, struct kobject___330 *);
	int (* const uevent)(struct kset___329 *, struct kobject___330 *, struct kobj_uevent_env *);
};

struct kobj_attribute___321 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___330 *, struct kobj_attribute___321 *, char *);
	ssize_t (*store)(struct kobject___330 *, struct kobj_attribute___321 *, const char *, size_t);
};

struct device___310;

struct dev_pm_ops___310 {
	int (*prepare)(struct device___310 *);
	void (*complete)(struct device___310 *);
	int (*suspend)(struct device___310 *);
	int (*resume)(struct device___310 *);
	int (*freeze)(struct device___310 *);
	int (*thaw)(struct device___310 *);
	int (*poweroff)(struct device___310 *);
	int (*restore)(struct device___310 *);
	int (*suspend_late)(struct device___310 *);
	int (*resume_early)(struct device___310 *);
	int (*freeze_late)(struct device___310 *);
	int (*thaw_early)(struct device___310 *);
	int (*poweroff_late)(struct device___310 *);
	int (*restore_early)(struct device___310 *);
	int (*suspend_noirq)(struct device___310 *);
	int (*resume_noirq)(struct device___310 *);
	int (*freeze_noirq)(struct device___310 *);
	int (*thaw_noirq)(struct device___310 *);
	int (*poweroff_noirq)(struct device___310 *);
	int (*restore_noirq)(struct device___310 *);
	int (*runtime_suspend)(struct device___310 *);
	int (*runtime_resume)(struct device___310 *);
	int (*runtime_idle)(struct device___310 *);
};

struct wakeup_source___6;

struct wake_irq___6;

struct dev_pm_qos___19;

struct dev_pm_info___310 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___6 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq___6 *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___4 *subsys_data;
	void (*set_latency_tolerance)(struct device___310 *, s32);
	struct dev_pm_qos___19 *qos;
};

struct device_private___7;

struct device_type___310;

struct bus_type___310;

struct device_driver___310;

struct dev_pm_domain___310;

struct class___310;

struct device___310 {
	struct device___310 *parent;
	struct device_private___7 *p;
	struct kobject___330 kobj;
	const char *init_name;
	const struct device_type___310 *type;
	struct mutex mutex;
	struct bus_type___310 *bus;
	struct device_driver___310 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___310 power;
	struct dev_pm_domain___310 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___310 *class;
	const struct attribute_group___307 **groups;
	void (*release)(struct device___310 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct wakeup_source___6 {
	const char *name;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq___6 *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	bool active: 1;
	bool autosleep_enabled: 1;
};

struct wake_irq___6 {
	struct device___310 *dev;
	unsigned int status;
	int irq;
	const char *name;
};

struct pm_qos_constraints___18 {
	struct plist_head list;
	s32 target_value;
	s32 default_value;
	s32 no_constraint_value;
	enum pm_qos_type type;
	struct blocking_notifier_head___343 *notifiers;
};

struct dev_pm_qos_request___19;

struct dev_pm_qos___19 {
	struct pm_qos_constraints___18 resume_latency;
	struct pm_qos_constraints___18 latency_tolerance;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___19 *resume_latency_req;
	struct dev_pm_qos_request___19 *latency_tolerance_req;
	struct dev_pm_qos_request___19 *flags_req;
};

struct dev_pm_domain___310 {
	struct dev_pm_ops___310 ops;
	void (*detach)(struct device___310 *, bool);
	int (*activate)(struct device___310 *);
	void (*sync)(struct device___310 *);
	void (*dismiss)(struct device___310 *);
};

struct upid___214 {
	int nr;
	struct pid_namespace___214 *ns;
};

struct pid_namespace___214 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___344 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___214 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___342 *proc_self;
	struct dentry___342 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___239 *user_ns;
	struct ucounts___239 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___9 ns;
};

struct pid___214 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___214 numbers[1];
};

struct user_struct___318 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___318 *uid_keyring;
	struct key___318 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___343;

struct mm_struct___343 {
	struct {
		struct vm_area_struct___344 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___343 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___344 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___343 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___344 *owner;
		struct user_namespace___239 *user_ns;
		struct file___343 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___343 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup___224;

struct cgroup_subsys___224;

struct cgroup_subsys_state___224 {
	struct cgroup___224 *cgroup;
	struct cgroup_subsys___224 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___224 *parent;
};

struct cgroup_file___224 {
	struct kernfs_node___337 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___127;

struct mem_cgroup___127 {
	struct cgroup_subsys_state___224 css;
	struct mem_cgroup_id___6 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___224 events_file;
	struct cgroup_file___224 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___344 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___127 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cred___318 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___318 *session_keyring;
	struct key___318 *process_keyring;
	struct key___318 *thread_keyring;
	struct key___318 *request_key_auth;
	void *security;
	struct user_struct___318 *user;
	struct user_namespace___239 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___224;

struct nsproxy___269 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___214 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___224 *cgroup_ns;
};

struct signal_struct___251 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___344 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___344 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___214 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___214 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___343 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___214 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___161;

struct bio_list___161 {
	struct bio___161 *head;
	struct bio___161 *tail;
};

struct bdi_writeback_congested___161;

struct bdi_writeback___161 {
	struct backing_dev_info___161 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___161 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___224 *memcg_css;
	struct cgroup_subsys_state___224 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___161 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___161 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___310 *dev;
	struct device___310 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___342 *debug_dir;
	struct dentry___342 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___224 {
	struct cgroup_subsys_state___224 *subsys[13];
	refcount_t refcount;
	struct css_set___224 *dom_cset;
	struct cgroup___224 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___224 *mg_src_cgrp;
	struct cgroup___224 *mg_dst_cgrp;
	struct css_set___224 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___138 {
	struct pmu___138 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___344 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___138 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

union thread_union___263 {
	struct task_struct___344 task;
	long unsigned int stack[8192];
};

struct subsys_private___7;

struct bus_type___310 {
	const char *name;
	const char *dev_name;
	struct device___310 *dev_root;
	const struct attribute_group___307 **bus_groups;
	const struct attribute_group___307 **dev_groups;
	const struct attribute_group___307 **drv_groups;
	int (*match)(struct device___310 *, struct device_driver___310 *);
	int (*uevent)(struct device___310 *, struct kobj_uevent_env *);
	int (*probe)(struct device___310 *);
	int (*remove)(struct device___310 *);
	void (*shutdown)(struct device___310 *);
	int (*online)(struct device___310 *);
	int (*offline)(struct device___310 *);
	int (*suspend)(struct device___310 *, pm_message_t);
	int (*resume)(struct device___310 *);
	int (*num_vf)(struct device___310 *);
	int (*dma_configure)(struct device___310 *);
	const struct dev_pm_ops___310 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private___7 *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct driver_private___7;

struct device_driver___310 {
	const char *name;
	struct bus_type___310 *bus;
	struct module___281 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___310 *);
	int (*remove)(struct device___310 *);
	void (*shutdown)(struct device___310 *);
	int (*suspend)(struct device___310 *, pm_message_t);
	int (*resume)(struct device___310 *);
	const struct attribute_group___307 **groups;
	const struct dev_pm_ops___310 *pm;
	void (*coredump)(struct device___310 *);
	struct driver_private___7 *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct subsys_private___7 {
	struct kset___329 subsys;
	struct kset___329 *devices_kset;
	struct list_head interfaces;
	struct mutex mutex;
	struct kset___329 *drivers_kset;
	struct klist klist_devices;
	struct klist klist_drivers;
	struct blocking_notifier_head___343 bus_notifier;
	unsigned int drivers_autoprobe: 1;
	struct bus_type___310 *bus;
	struct kset___329 glue_dirs;
	struct class___310 *class;
};

struct device_type___310 {
	const char *name;
	const struct attribute_group___307 **groups;
	int (*uevent)(struct device___310 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___310 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___310 *);
	const struct dev_pm_ops___310 *pm;
};

struct module_kobject___278 {
	struct kobject___330 kobj;
	struct module___281 *mod;
	struct kobject___330 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___278 {
	struct module___281 *mod;
	struct latch_tree_node node;
};

struct module_layout___278 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___278 mtn;
};

struct module_attribute___278;

struct kernel_param___278;

struct module___281 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___278 mkobj;
	struct module_attribute___278 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___330 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___278 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___278 core_layout;
	struct module_layout___278 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___131 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct driver_private___7 {
	struct kobject___330 kobj;
	struct klist klist_devices;
	struct klist_node knode_bus;
	struct module_kobject___278 *mkobj;
	struct device_driver___310 *driver;
};

struct class___310 {
	const char *name;
	struct module___281 *owner;
	const struct attribute_group___307 **class_groups;
	const struct attribute_group___307 **dev_groups;
	struct kobject___330 *dev_kobj;
	int (*dev_uevent)(struct device___310 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___310 *, umode_t *);
	void (*class_release)(struct class___310 *);
	void (*dev_release)(struct device___310 *);
	int (*shutdown_pre)(struct device___310 *);
	const struct kobj_ns_type_operations___27 *ns_type;
	const void * (*namespace)(struct device___310 *);
	const struct dev_pm_ops___310 *pm;
	struct subsys_private___7 *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct device_link___3 {
	struct device___310 *supplier;
	struct list_head s_node;
	struct device___310 *consumer;
	struct list_head c_node;
	enum device_link_state status;
	u32 flags;
	bool rpm_active;
	struct kref kref;
	struct callback_head callback_head;
};

struct device_private___7 {
	struct klist klist_children;
	struct klist_node knode_parent;
	struct klist_node knode_driver;
	struct klist_node knode_bus;
	struct list_head deferred_probe;
	struct device___310 *device;
};

struct dentry_operations___342;

struct super_block___342;

struct dentry___342 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___342 *d_parent;
	struct qstr d_name;
	struct inode___343 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___342 *d_op;
	struct super_block___342 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___342;

struct address_space___342 {
	struct inode___343 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___344 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___342 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___342;

struct block_device___342;

struct inode___343 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___342 *i_op;
	struct super_block___342 *i_sb;
	struct address_space___342 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___344 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___161 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___343 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___342 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___342 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___342 {
	int (*d_revalidate)(struct dentry___342 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___342 *, unsigned int);
	int (*d_hash)(const struct dentry___342 *, struct qstr *);
	int (*d_compare)(const struct dentry___342 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___342 *);
	int (*d_init)(struct dentry___342 *);
	void (*d_release)(struct dentry___342 *);
	void (*d_prune)(struct dentry___342 *);
	void (*d_iput)(struct dentry___342 *, struct inode___343 *);
	char * (*d_dname)(struct dentry___342 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___343 *);
	int (*d_manage)(const struct path___343 *, bool);
	struct dentry___342 * (*d_real)(struct dentry___342 *, const struct inode___343 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___342;

struct mem_dqinfo___342 {
	struct quota_format_type___342 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___342;

struct quota_info___342 {
	unsigned int flags;
	struct rw_semaphore___344 dqio_sem;
	struct inode___343 *files[3];
	struct mem_dqinfo___342 info[3];
	const struct quota_format_ops___342 *ops[3];
};

struct rcuwait___342 {
	struct task_struct___344 *task;
};

struct percpu_rw_semaphore___342 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___344 rw_sem;
	struct rcuwait___342 writer;
	int readers_block;
};

struct sb_writers___342 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___342 rw_sem[3];
};

struct shrink_control___127;

struct shrinker___127 {
	long unsigned int (*count_objects)(struct shrinker___127 *, struct shrink_control___127 *);
	long unsigned int (*scan_objects)(struct shrinker___127 *, struct shrink_control___127 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___342;

struct super_operations___342;

struct dquot_operations___342;

struct quotactl_ops___342;

struct super_block___342 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___342 *s_type;
	const struct super_operations___342 *s_op;
	const struct dquot_operations___342 *dq_op;
	const struct quotactl_ops___342 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___342 *s_root;
	struct rw_semaphore___344 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___342 *s_bdev;
	struct backing_dev_info___161 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___342 s_dquot;
	struct sb_writers___342 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___342 *s_d_op;
	int cleancache_poolid;
	struct shrinker___127 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___239 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___127 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___127 *memcg;
};

typedef int (*dev_page_fault_t___331)(struct vm_area_struct___344 *, long unsigned int, const struct page___344 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___331)(struct page___344 *, void *);

struct dev_pagemap___331 {
	dev_page_fault_t___331 page_fault;
	dev_page_free_t___331 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___310 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___343 {
	struct task_struct___344 *task;
	struct core_thread___343 *next;
};

struct core_state___343 {
	atomic_t nr_threads;
	struct core_thread___343 dumper;
	struct completion startup;
};

struct vm_fault___331 {
	struct vm_area_struct___344 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___344 *cow_page;
	struct mem_cgroup___127 *memcg;
	struct page___344 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___343 prealloc_pte;
};

struct kiocb___343 {
	struct file___343 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___343 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___342 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___343 *ia_file;
};

struct dquot___342 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___342 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___342 {
	int qf_fmt_id;
	const struct quota_format_ops___342 *qf_ops;
	struct module___281 *qf_owner;
	struct quota_format_type___342 *qf_next;
};

struct quota_format_ops___342 {
	int (*check_quota_file)(struct super_block___342 *, int);
	int (*read_file_info)(struct super_block___342 *, int);
	int (*write_file_info)(struct super_block___342 *, int);
	int (*free_file_info)(struct super_block___342 *, int);
	int (*read_dqblk)(struct dquot___342 *);
	int (*commit_dqblk)(struct dquot___342 *);
	int (*release_dqblk)(struct dquot___342 *);
	int (*get_next_id)(struct super_block___342 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___342 {
	int (*write_dquot)(struct dquot___342 *);
	struct dquot___342 * (*alloc_dquot)(struct super_block___342 *, int);
	void (*destroy_dquot)(struct dquot___342 *);
	int (*acquire_dquot)(struct dquot___342 *);
	int (*release_dquot)(struct dquot___342 *);
	int (*mark_dirty)(struct dquot___342 *);
	int (*write_info)(struct super_block___342 *, int);
	qsize_t * (*get_reserved_space)(struct inode___343 *);
	int (*get_projid)(struct inode___343 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___343 *, qsize_t *);
	int (*get_next_id)(struct super_block___342 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___342 {
	int (*quota_on)(struct super_block___342 *, int, int, const struct path___343 *);
	int (*quota_off)(struct super_block___342 *, int);
	int (*quota_enable)(struct super_block___342 *, unsigned int);
	int (*quota_disable)(struct super_block___342 *, unsigned int);
	int (*quota_sync)(struct super_block___342 *, int);
	int (*set_info)(struct super_block___342 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___342 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___342 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___342 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___342 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___342 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___144;

struct swap_info_struct___84;

struct address_space_operations___342 {
	int (*writepage)(struct page___344 *, struct writeback_control___144 *);
	int (*readpage)(struct file___343 *, struct page___344 *);
	int (*writepages)(struct address_space___342 *, struct writeback_control___144 *);
	int (*set_page_dirty)(struct page___344 *);
	int (*readpages)(struct file___343 *, struct address_space___342 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___343 *, struct address_space___342 *, loff_t, unsigned int, unsigned int, struct page___344 **, void **);
	int (*write_end)(struct file___343 *, struct address_space___342 *, loff_t, unsigned int, unsigned int, struct page___344 *, void *);
	sector_t (*bmap)(struct address_space___342 *, sector_t);
	void (*invalidatepage)(struct page___344 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___344 *, gfp_t);
	void (*freepage)(struct page___344 *);
	ssize_t (*direct_IO)(struct kiocb___343 *, struct iov_iter___150 *);
	int (*migratepage)(struct address_space___342 *, struct page___344 *, struct page___344 *, enum migrate_mode);
	bool (*isolate_page)(struct page___344 *, isolate_mode_t);
	void (*putback_page)(struct page___344 *);
	int (*launder_page)(struct page___344 *);
	int (*is_partially_uptodate)(struct page___344 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___344 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___342 *, struct page___344 *);
	int (*swap_activate)(struct swap_info_struct___84 *, struct file___343 *, sector_t *);
	void (*swap_deactivate)(struct file___343 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___144 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___161 *wb;
	struct inode___343 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___163;

struct iov_iter___150 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___163 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct swap_info_struct___84 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___342 *bdev;
	struct file___343 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___342 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___343 *bd_inode;
	struct super_block___342 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___342 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___161 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___342 {
	struct dentry___342 * (*lookup)(struct inode___343 *, struct dentry___342 *, unsigned int);
	const char * (*get_link)(struct dentry___342 *, struct inode___343 *, struct delayed_call *);
	int (*permission)(struct inode___343 *, int);
	struct posix_acl * (*get_acl)(struct inode___343 *, int);
	int (*readlink)(struct dentry___342 *, char *, int);
	int (*create)(struct inode___343 *, struct dentry___342 *, umode_t, bool);
	int (*link)(struct dentry___342 *, struct inode___343 *, struct dentry___342 *);
	int (*unlink)(struct inode___343 *, struct dentry___342 *);
	int (*symlink)(struct inode___343 *, struct dentry___342 *, const char *);
	int (*mkdir)(struct inode___343 *, struct dentry___342 *, umode_t);
	int (*rmdir)(struct inode___343 *, struct dentry___342 *);
	int (*mknod)(struct inode___343 *, struct dentry___342 *, umode_t, dev_t);
	int (*rename)(struct inode___343 *, struct dentry___342 *, struct inode___343 *, struct dentry___342 *, unsigned int);
	int (*setattr)(struct dentry___342 *, struct iattr___342 *);
	int (*getattr)(const struct path___343 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___342 *, char *, size_t);
	int (*fiemap)(struct inode___343 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___343 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___343 *, struct dentry___342 *, struct file___343 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___343 *, struct dentry___342 *, umode_t);
	int (*set_acl)(struct inode___343 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___342 {
	void (*fl_copy_lock)(struct file_lock___343 *, struct file_lock___343 *);
	void (*fl_release_private)(struct file_lock___343 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___342;

struct file_lock___343 {
	struct file_lock___343 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___343 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___342 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___342 *fl_ops;
	const struct lock_manager_operations___342 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___342 {
	int (*lm_compare_owner)(struct file_lock___343 *, struct file_lock___343 *);
	long unsigned int (*lm_owner_key)(struct file_lock___343 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___343 *);
	int (*lm_grant)(struct file_lock___343 *, int);
	bool (*lm_break)(struct file_lock___343 *);
	int (*lm_change)(struct file_lock___343 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___343 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___342 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___342 *fa_next;
	struct file___343 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___342 {
	const char *name;
	int fs_flags;
	struct dentry___342 * (*mount)(struct file_system_type___342 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___342 *);
	struct module___281 *owner;
	struct file_system_type___342 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___342 {
	struct inode___343 * (*alloc_inode)(struct super_block___342 *);
	void (*destroy_inode)(struct inode___343 *);
	void (*dirty_inode)(struct inode___343 *, int);
	int (*write_inode)(struct inode___343 *, struct writeback_control___144 *);
	int (*drop_inode)(struct inode___343 *);
	void (*evict_inode)(struct inode___343 *);
	void (*put_super)(struct super_block___342 *);
	int (*sync_fs)(struct super_block___342 *, int);
	int (*freeze_super)(struct super_block___342 *);
	int (*freeze_fs)(struct super_block___342 *);
	int (*thaw_super)(struct super_block___342 *);
	int (*unfreeze_fs)(struct super_block___342 *);
	int (*statfs)(struct dentry___342 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___342 *, int *, char *);
	void (*umount_begin)(struct super_block___342 *);
	int (*show_options)(struct seq_file___291 *, struct dentry___342 *);
	int (*show_devname)(struct seq_file___291 *, struct dentry___342 *);
	int (*show_path)(struct seq_file___291 *, struct dentry___342 *);
	int (*show_stats)(struct seq_file___291 *, struct dentry___342 *);
	ssize_t (*quota_read)(struct super_block___342 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___342 *, int, const char *, size_t, loff_t);
	struct dquot___342 ** (*get_dquots)(struct inode___343 *);
	int (*bdev_try_to_free_page)(struct super_block___342 *, struct page___344 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___342 *, struct shrink_control___127 *);
	long int (*free_cached_objects)(struct super_block___342 *, struct shrink_control___127 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___161(struct bio___161 *);

struct bio_vec___163 {
	struct page___344 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___161;

struct bio_set___161;

struct bio___161 {
	struct bio___161 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___161 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___161 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___163 *bi_io_vec;
	struct bio_set___161 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___163 bi_inline_vecs[0];
};

typedef int (*key_restrict_link_func_t___319)(struct key___318 *, const struct key_type *, const union key_payload *, struct key___318 *);

struct key_restriction___318;

struct key___318 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___344 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___318 *restrict_link;
};

struct key_restriction___318 {
	key_restrict_link_func_t___319 check;
	struct key___318 *key;
	struct key_type *keytype;
};

struct seq_operations___290 {
	void * (*start)(struct seq_file___291 *, loff_t *);
	void (*stop)(struct seq_file___291 *, void *);
	void * (*next)(struct seq_file___291 *, void *, loff_t *);
	int (*show)(struct seq_file___291 *, void *);
};

struct cgroup_namespace___224 {
	refcount_t count;
	struct ns_common___9 ns;
	struct user_namespace___239 *user_ns;
	struct ucounts___239 *ucounts;
	struct css_set___224 *root_cset;
};

struct ucounts___239 {
	struct hlist_node node;
	struct user_namespace___239 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___225;

struct bpf_map_ops___224 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___225 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___225 *, struct file___343 *);
	void (*map_free)(struct bpf_map___225 *);
	int (*map_get_next_key)(struct bpf_map___225 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___225 *);
	void * (*map_lookup_elem)(struct bpf_map___225 *, void *);
	int (*map_update_elem)(struct bpf_map___225 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___225 *, void *);
	int (*map_push_elem)(struct bpf_map___225 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___225 *, void *);
	int (*map_peek_elem)(struct bpf_map___225 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___225 *, struct file___343 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___225 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___225 *, void *, struct seq_file___291 *);
	int (*map_check_btf)(const struct bpf_map___225 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___225 {
	const struct bpf_map_ops___224 *ops;
	struct bpf_map___225 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___318 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___224;

typedef void (*kthread_work_func_t___224)(struct kthread_work___224 *);

struct kthread_worker___224;

struct kthread_work___224 {
	struct list_head node;
	kthread_work_func_t___224 func;
	struct kthread_worker___224 *worker;
	int canceling;
};

struct kthread_worker___224 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___344 *task;
	struct kthread_work___224 *current_work;
};

struct kthread_delayed_work___224 {
	struct kthread_work___224 work;
	struct timer_list timer;
};

struct psi_group___224 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___224 *poll_kworker;
	struct kthread_delayed_work___224 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___224;

struct cgroup_rstat_cpu___224;

struct cgroup___224 {
	struct cgroup_subsys_state___224 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___337 *kn;
	struct cgroup_file___224 procs_file;
	struct cgroup_file___224 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___224 *subsys[13];
	struct cgroup_root___224 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___224 *dom_cgrp;
	struct cgroup_rstat_cpu___224 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___37 bpf;
	atomic_t congestion_count;
	struct cgroup___224 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___224 psi;
	int ancestor_ids[0];
};

struct cftype___224;

struct cgroup_subsys___224 {
	struct cgroup_subsys_state___224 * (*css_alloc)(struct cgroup_subsys_state___224 *);
	int (*css_online)(struct cgroup_subsys_state___224 *);
	void (*css_offline)(struct cgroup_subsys_state___224 *);
	void (*css_released)(struct cgroup_subsys_state___224 *);
	void (*css_free)(struct cgroup_subsys_state___224 *);
	void (*css_reset)(struct cgroup_subsys_state___224 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___224 *, int);
	int (*css_extra_stat_show)(struct seq_file___291 *, struct cgroup_subsys_state___224 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___344 *);
	void (*cancel_fork)(struct task_struct___344 *);
	void (*fork)(struct task_struct___344 *);
	void (*exit)(struct task_struct___344 *);
	void (*free)(struct task_struct___344 *);
	void (*bind)(struct cgroup_subsys_state___224 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___224 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___224 *dfl_cftypes;
	struct cftype___224 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___224 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___224 *updated_children;
	struct cgroup___224 *updated_next;
};

struct cgroup_root___224 {
	struct kernfs_root___336 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___224 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___224 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___224 *ss;
	struct list_head node;
	struct kernfs_ops___336 *kf_ops;
	int (*open)(struct kernfs_open_file___336 *);
	void (*release)(struct kernfs_open_file___336 *);
	u64 (*read_u64)(struct cgroup_subsys_state___224 *, struct cftype___224 *);
	s64 (*read_s64)(struct cgroup_subsys_state___224 *, struct cftype___224 *);
	int (*seq_show)(struct seq_file___291 *, void *);
	void * (*seq_start)(struct seq_file___291 *, loff_t *);
	void * (*seq_next)(struct seq_file___291 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___291 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___224 *, struct cftype___224 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___224 *, struct cftype___224 *, s64);
	ssize_t (*write)(struct kernfs_open_file___336 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___336 *, struct poll_table_struct___210 *);
};

typedef void compound_page_dtor___331(struct page___344 *);

struct bdi_writeback_congested___161 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___161 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___161 {
	struct bio___161 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___163 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___163 bip_inline_vecs[0];
};

struct bio_set___161 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___161 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___127 {
	struct mem_cgroup___127 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___127 {
	struct lruvec___343 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___127 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___127 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct node___200 {
	struct device___310 dev;
};

struct dev_pm_qos_request___19 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___310 *dev;
};

struct kernel_param_ops___278 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___278 *);
	int (*get)(char *, const struct kernel_param___278 *);
	void (*free)(void *);
};

struct kparam_array___278;

struct kernel_param___278 {
	const char *name;
	struct module___281 *mod;
	const struct kernel_param_ops___278 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___278 *arr;
	};
};

struct kparam_array___278 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___278 *ops;
	void *elem;
};

struct module_attribute___278 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___278 *, struct module_kobject___278 *, char *);
	ssize_t (*store)(struct module_attribute___278 *, struct module_kobject___278 *, const char *, size_t);
	void (*setup)(struct module___281 *, const char *);
	int (*test)(struct module___281 *);
	void (*free)(struct module___281 *);
};

struct trace_event_class___131;

struct trace_event_call___131 {
	struct list_head list;
	struct trace_event_class___131 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___13 event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___37 *prog_array;
	int (*perf_perm)(struct trace_event_call___131 *, struct perf_event___138 *);
};

struct perf_cpu_context___138;

struct pmu___138 {
	struct list_head entry;
	struct module___281 *module;
	struct device___310 *dev;
	const struct attribute_group___307 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___138 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___138 *);
	void (*pmu_disable)(struct pmu___138 *);
	int (*event_init)(struct perf_event___138 *);
	void (*event_mapped)(struct perf_event___138 *, struct mm_struct___343 *);
	void (*event_unmapped)(struct perf_event___138 *, struct mm_struct___343 *);
	int (*add)(struct perf_event___138 *, int);
	void (*del)(struct perf_event___138 *, int);
	void (*start)(struct perf_event___138 *, int);
	void (*stop)(struct perf_event___138 *, int);
	void (*read)(struct perf_event___138 *);
	void (*start_txn)(struct pmu___138 *, unsigned int);
	int (*commit_txn)(struct pmu___138 *);
	void (*cancel_txn)(struct pmu___138 *);
	int (*event_idx)(struct perf_event___138 *);
	void (*sched_task)(struct perf_event_context___138 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___138 *);
	int (*filter_match)(struct perf_event___138 *);
	int (*check_period)(struct perf_event___138 *, u64);
};

struct perf_cpu_context___138 {
	struct perf_event_context___138 ctx;
	struct perf_event_context___138 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___138 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___138 {
	struct cgroup_subsys_state___224 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___131 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___131 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___131 *);
	struct list_head * (*get_fields)(struct trace_event_call___131 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___131 *);
};

struct cpufreq_governor___6;

struct cpufreq_policy___6 {
	cpumask_var_t cpus;
	cpumask_var_t related_cpus;
	cpumask_var_t real_cpus;
	unsigned int shared_type;
	unsigned int cpu;
	struct clk *clk;
	struct cpufreq_cpuinfo cpuinfo;
	unsigned int min;
	unsigned int max;
	unsigned int cur;
	unsigned int restore_freq;
	unsigned int suspend_freq;
	unsigned int policy;
	unsigned int last_policy;
	struct cpufreq_governor___6 *governor;
	void *governor_data;
	char last_governor[16];
	struct work_struct update;
	struct cpufreq_user_policy user_policy;
	struct cpufreq_frequency_table *freq_table;
	enum cpufreq_table_sorting freq_table_sorted;
	struct list_head policy_list;
	struct kobject___330 kobj;
	struct completion kobj_unregister;
	struct rw_semaphore___344 rwsem;
	bool fast_switch_possible;
	bool fast_switch_enabled;
	unsigned int transition_delay_us;
	bool dvfs_possible_from_any_cpu;
	unsigned int cached_target_freq;
	int cached_resolved_idx;
	bool transition_ongoing;
	spinlock_t transition_lock;
	wait_queue_head_t transition_wait;
	struct task_struct___344 *transition_task;
	struct cpufreq_stats *stats;
	void *driver_data;
};

struct cpufreq_governor___6 {
	char name[16];
	int (*init)(struct cpufreq_policy___6 *);
	void (*exit)(struct cpufreq_policy___6 *);
	int (*start)(struct cpufreq_policy___6 *);
	void (*stop)(struct cpufreq_policy___6 *);
	void (*limits)(struct cpufreq_policy___6 *);
	ssize_t (*show_setspeed)(struct cpufreq_policy___6 *, char *);
	int (*store_setspeed)(struct cpufreq_policy___6 *, unsigned int);
	bool dynamic_switching;
	struct list_head governor_list;
	struct module___281 *owner;
};

struct freq_attr___6 {
	struct attribute attr;
	ssize_t (*show)(struct cpufreq_policy___6 *, char *);
	ssize_t (*store)(struct cpufreq_policy___6 *, const char *, size_t);
};

typedef int (*pm_callback_t___2)(struct device___310 *);

struct module___282;

struct file___344;

struct kiocb___344;

struct iov_iter___151;

struct poll_table_struct___211;

struct vm_area_struct___345;

struct inode___344;

struct file_lock___344;

struct page___345;

struct seq_file___292;

struct file_operations___344 {
	struct module___282 *owner;
	loff_t (*llseek)(struct file___344 *, loff_t, int);
	ssize_t (*read)(struct file___344 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___344 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___344 *, struct iov_iter___151 *);
	ssize_t (*write_iter)(struct kiocb___344 *, struct iov_iter___151 *);
	int (*iopoll)(struct kiocb___344 *, bool);
	int (*iterate)(struct file___344 *, struct dir_context *);
	int (*iterate_shared)(struct file___344 *, struct dir_context *);
	__poll_t (*poll)(struct file___344 *, struct poll_table_struct___211 *);
	long int (*unlocked_ioctl)(struct file___344 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___344 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___344 *, struct vm_area_struct___345 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___344 *, struct file___344 *);
	int (*flush)(struct file___344 *, fl_owner_t);
	int (*release)(struct inode___344 *, struct file___344 *);
	int (*fsync)(struct file___344 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___344 *, int);
	int (*lock)(struct file___344 *, int, struct file_lock___344 *);
	ssize_t (*sendpage)(struct file___344 *, struct page___345 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___344 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___344 *, int, struct file_lock___344 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___344 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___344 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___344 *, long int, struct file_lock___344 **, void **);
	long int (*fallocate)(struct file___344 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___292 *, struct file___344 *);
	ssize_t (*copy_file_range)(struct file___344 *, loff_t, struct file___344 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___344 *, loff_t, struct file___344 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___344 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct perf_event___139;

struct debug_info___139 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___139 *hbp_break[16];
	struct perf_event___139 *hbp_watch[16];
};

struct task_struct___345;

struct hw_perf_event___139 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___345 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___139)(struct perf_event___139 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___139;

struct perf_event_context___139;

struct fasync_struct___343;

struct pid_namespace___215;

struct trace_event_call___132;

struct perf_cgroup___139;

struct perf_event___139 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___139 *group_leader;
	struct pmu___139 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___139 hw;
	struct perf_event_context___139 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___139 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___345 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___343 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___139 *);
	struct callback_head callback_head;
	struct pid_namespace___215 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___139 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___139 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___132 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___139 *cgrp;
	struct list_head sb_list;
};

struct thread_struct___139 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___139 debug;
	long: 64;
};

struct vmacache___344 {
	u64 seqnum;
	struct vm_area_struct___345 *vmas[4];
};

struct page_frag___344 {
	struct page___345 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___344;

struct mem_cgroup___128;

struct pid___215;

struct cred___319;

struct nsproxy___270;

struct signal_struct___252;

struct bio_list___162;

struct backing_dev_info___162;

struct css_set___225;

struct task_struct___345 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___345 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___344 *mm;
	struct mm_struct___344 *active_mm;
	struct vmacache___344 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___345 *real_parent;
	struct task_struct___345 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___345 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___128 *active_memcg;
	long int rh_reserved2;
	struct pid___215 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___215 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___215 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___319 *ptracer_cred;
	const struct cred___319 *real_cred;
	const struct cred___319 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___270 *nsproxy;
	struct signal_struct___252 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___345 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___162 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___162 *backing_dev_info;
	struct io_context___84 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___225 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___139 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___344 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___128 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___345 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___139 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___345 *pgtable_t___344;

struct address_space___343;

struct dev_pagemap___332;

struct page___345 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___343 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___345 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___344 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___344 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___332 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___128 *mem_cgroup;
};

struct pglist_data___344;

struct lruvec___344 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___344 *pgdat;
};

struct zone___344 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___344 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___344 {
	struct zone___344 *zone;
	int zone_idx;
};

struct zonelist___344 {
	struct zoneref___344 _zonerefs[25];
};

struct pglist_data___344 {
	struct zone___344 node_zones[3];
	struct zonelist___344 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___345 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___345 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___344 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___345 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___345 *owner;
};

struct secondary_data___345 {
	void *stack;
	struct task_struct___345 *task;
	long int status;
};

struct blocking_notifier_head___344 {
	struct rw_semaphore___345 rwsem;
	struct notifier_block *head;
};

struct key___319;

struct ucounts___240;

struct user_namespace___240 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___240 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___9 ns;
	long unsigned int flags;
	struct key___319 *persistent_keyring_register;
	struct rw_semaphore___345 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___240 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_root___337;

struct kernfs_elem_dir___337 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___337 *root;
};

struct kernfs_node___338;

struct kernfs_syscall_ops___337;

struct kernfs_root___337 {
	struct kernfs_node___338 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___337 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___337 {
	struct kernfs_node___338 *target_kn;
};

struct kernfs_ops___337;

struct kernfs_elem_attr___337 {
	const struct kernfs_ops___337 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___338 *notify_next;
};

struct kernfs_node___338 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___338 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___337 dir;
		struct kernfs_elem_symlink___337 symlink;
		struct kernfs_elem_attr___337 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___337;

struct kernfs_ops___337 {
	int (*open)(struct kernfs_open_file___337 *);
	void (*release)(struct kernfs_open_file___337 *);
	int (*seq_show)(struct seq_file___292 *, void *);
	void * (*seq_start)(struct seq_file___292 *, loff_t *);
	void * (*seq_next)(struct seq_file___292 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___292 *, void *);
	ssize_t (*read)(struct kernfs_open_file___337 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___337 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___337 *, struct vm_area_struct___345 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___337 *, struct poll_table_struct___211 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___337 {
	int (*remount_fs)(struct kernfs_root___337 *, int *, char *);
	int (*show_options)(struct seq_file___292 *, struct kernfs_root___337 *);
	int (*mkdir)(struct kernfs_node___338 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___338 *);
	int (*rename)(struct kernfs_node___338 *, struct kernfs_node___338 *, const char *);
	int (*show_path)(struct seq_file___292 *, struct kernfs_node___338 *, struct kernfs_root___337 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___291;

struct seq_file___292 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___291 *op;
	int poll_event;
	const struct file___344 *file;
	void *private;
};

struct vm_operations_struct___332;

struct kernfs_open_file___337 {
	struct kernfs_node___338 *kn;
	struct file___344 *file;
	struct seq_file___292 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___332 *vm_ops;
};

struct dentry___343;

struct path___344 {
	struct vfsmount *mnt;
	struct dentry___343 *dentry;
};

struct fown_struct___215 {
	rwlock_t lock;
	struct pid___215 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___344 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___344 f_path;
	struct inode___344 *f_inode;
	const struct file_operations___344 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___215 f_owner;
	const struct cred___319 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___343 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___332;

struct vm_operations_struct___332 {
	void (*open)(struct vm_area_struct___345 *);
	void (*close)(struct vm_area_struct___345 *);
	int (*split)(struct vm_area_struct___345 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___345 *);
	vm_fault_t (*fault)(struct vm_fault___332 *);
	vm_fault_t (*huge_fault)(struct vm_fault___332 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___332 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___345 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___332 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___332 *);
	int (*access)(struct vm_area_struct___345 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___345 *);
	int (*set_policy)(struct vm_area_struct___345 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___345 *, long unsigned int);
	struct page___345 * (*find_special_page)(struct vm_area_struct___345 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___217)(struct file___344 *, wait_queue_head_t *, struct poll_table_struct___211 *);

struct poll_table_struct___211 {
	poll_queue_proc___217 _qproc;
	__poll_t _key;
};

struct vm_area_struct___345 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___345 *vm_next;
	struct vm_area_struct___345 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___344 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___332 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___344 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___331;

struct bin_attribute___307;

struct attribute_group___308 {
	const char *name;
	umode_t (*is_visible)(struct kobject___331 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___331 *, struct bin_attribute___307 *, int);
	struct attribute **attrs;
	struct bin_attribute___307 **bin_attrs;
};

struct kset___330;

struct kobj_type___330;

struct kobject___331 {
	const char *name;
	struct list_head entry;
	struct kobject___331 *parent;
	struct kset___330 *kset;
	struct kobj_type___330 *ktype;
	struct kernfs_node___338 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___307 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___344 *, struct kobject___331 *, struct bin_attribute___307 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___344 *, struct kobject___331 *, struct bin_attribute___307 *, char *, loff_t, size_t);
	int (*mmap)(struct file___344 *, struct kobject___331 *, struct bin_attribute___307 *, struct vm_area_struct___345 *);
};

struct sysfs_ops___330 {
	ssize_t (*show)(struct kobject___331 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___331 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___330;

struct kset___330 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___331 kobj;
	const struct kset_uevent_ops___330 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___330 {
	void (*release)(struct kobject___331 *);
	const struct sysfs_ops___330 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___27 * (*child_ns_type)(struct kobject___331 *);
	const void * (*namespace)(struct kobject___331 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___330 {
	int (* const filter)(struct kset___330 *, struct kobject___331 *);
	const char * (* const name)(struct kset___330 *, struct kobject___331 *);
	int (* const uevent)(struct kset___330 *, struct kobject___331 *, struct kobj_uevent_env *);
};

struct kobj_attribute___322 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___331 *, struct kobj_attribute___322 *, char *);
	ssize_t (*store)(struct kobject___331 *, struct kobj_attribute___322 *, const char *, size_t);
};

struct device___311;

struct dev_pm_ops___311 {
	int (*prepare)(struct device___311 *);
	void (*complete)(struct device___311 *);
	int (*suspend)(struct device___311 *);
	int (*resume)(struct device___311 *);
	int (*freeze)(struct device___311 *);
	int (*thaw)(struct device___311 *);
	int (*poweroff)(struct device___311 *);
	int (*restore)(struct device___311 *);
	int (*suspend_late)(struct device___311 *);
	int (*resume_early)(struct device___311 *);
	int (*freeze_late)(struct device___311 *);
	int (*thaw_early)(struct device___311 *);
	int (*poweroff_late)(struct device___311 *);
	int (*restore_early)(struct device___311 *);
	int (*suspend_noirq)(struct device___311 *);
	int (*resume_noirq)(struct device___311 *);
	int (*freeze_noirq)(struct device___311 *);
	int (*thaw_noirq)(struct device___311 *);
	int (*poweroff_noirq)(struct device___311 *);
	int (*restore_noirq)(struct device___311 *);
	int (*runtime_suspend)(struct device___311 *);
	int (*runtime_resume)(struct device___311 *);
	int (*runtime_idle)(struct device___311 *);
};

struct wakeup_source___7;

struct wake_irq___7;

struct dev_pm_qos___20;

struct dev_pm_info___311 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___7 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq___7 *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___4 *subsys_data;
	void (*set_latency_tolerance)(struct device___311 *, s32);
	struct dev_pm_qos___20 *qos;
};

struct device_type___311;

struct bus_type___311;

struct device_driver___311;

struct dev_pm_domain___311;

struct class___311;

struct device___311 {
	struct device___311 *parent;
	struct device_private *p;
	struct kobject___331 kobj;
	const char *init_name;
	const struct device_type___311 *type;
	struct mutex mutex;
	struct bus_type___311 *bus;
	struct device_driver___311 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___311 power;
	struct dev_pm_domain___311 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___311 *class;
	const struct attribute_group___308 **groups;
	void (*release)(struct device___311 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct wakeup_source___7 {
	const char *name;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq___7 *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	bool active: 1;
	bool autosleep_enabled: 1;
};

struct wake_irq___7 {
	struct device___311 *dev;
	unsigned int status;
	int irq;
	const char *name;
};

struct pm_qos_constraints___19 {
	struct plist_head list;
	s32 target_value;
	s32 default_value;
	s32 no_constraint_value;
	enum pm_qos_type type;
	struct blocking_notifier_head___344 *notifiers;
};

struct dev_pm_qos_request___20;

struct dev_pm_qos___20 {
	struct pm_qos_constraints___19 resume_latency;
	struct pm_qos_constraints___19 latency_tolerance;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___20 *resume_latency_req;
	struct dev_pm_qos_request___20 *latency_tolerance_req;
	struct dev_pm_qos_request___20 *flags_req;
};

struct dev_pm_domain___311 {
	struct dev_pm_ops___311 ops;
	void (*detach)(struct device___311 *, bool);
	int (*activate)(struct device___311 *);
	void (*sync)(struct device___311 *);
	void (*dismiss)(struct device___311 *);
};

struct upid___215 {
	int nr;
	struct pid_namespace___215 *ns;
};

struct pid_namespace___215 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___345 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___215 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___343 *proc_self;
	struct dentry___343 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___240 *user_ns;
	struct ucounts___240 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___9 ns;
};

struct pid___215 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___215 numbers[1];
};

struct user_struct___319 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___319 *uid_keyring;
	struct key___319 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___344;

struct mm_struct___344 {
	struct {
		struct vm_area_struct___345 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___344 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___345 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___344 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___345 *owner;
		struct user_namespace___240 *user_ns;
		struct file___344 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___344 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup___225;

struct cgroup_subsys___225;

struct cgroup_subsys_state___225 {
	struct cgroup___225 *cgroup;
	struct cgroup_subsys___225 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___225 *parent;
};

struct cgroup_file___225 {
	struct kernfs_node___338 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___128;

struct mem_cgroup___128 {
	struct cgroup_subsys_state___225 css;
	struct mem_cgroup_id___8 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___225 events_file;
	struct cgroup_file___225 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___345 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___128 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cred___319 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___319 *session_keyring;
	struct key___319 *process_keyring;
	struct key___319 *thread_keyring;
	struct key___319 *request_key_auth;
	void *security;
	struct user_struct___319 *user;
	struct user_namespace___240 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___225;

struct nsproxy___270 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___215 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___225 *cgroup_ns;
};

struct signal_struct___252 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___345 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___345 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___215 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___215 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___344 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___215 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___162;

struct bio_list___162 {
	struct bio___162 *head;
	struct bio___162 *tail;
};

struct bdi_writeback_congested___162;

struct bdi_writeback___162 {
	struct backing_dev_info___162 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___162 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___225 *memcg_css;
	struct cgroup_subsys_state___225 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___162 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___162 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___311 *dev;
	struct device___311 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___343 *debug_dir;
	struct dentry___343 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___225 {
	struct cgroup_subsys_state___225 *subsys[13];
	refcount_t refcount;
	struct css_set___225 *dom_cset;
	struct cgroup___225 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___225 *mg_src_cgrp;
	struct cgroup___225 *mg_dst_cgrp;
	struct css_set___225 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___139 {
	struct pmu___139 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___345 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___139 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

union thread_union___264 {
	struct task_struct___345 task;
	long unsigned int stack[8192];
};

struct bus_type___311 {
	const char *name;
	const char *dev_name;
	struct device___311 *dev_root;
	const struct attribute_group___308 **bus_groups;
	const struct attribute_group___308 **dev_groups;
	const struct attribute_group___308 **drv_groups;
	int (*match)(struct device___311 *, struct device_driver___311 *);
	int (*uevent)(struct device___311 *, struct kobj_uevent_env *);
	int (*probe)(struct device___311 *);
	int (*remove)(struct device___311 *);
	void (*shutdown)(struct device___311 *);
	int (*online)(struct device___311 *);
	int (*offline)(struct device___311 *);
	int (*suspend)(struct device___311 *, pm_message_t);
	int (*resume)(struct device___311 *);
	int (*num_vf)(struct device___311 *);
	int (*dma_configure)(struct device___311 *);
	const struct dev_pm_ops___311 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___311 {
	const char *name;
	struct bus_type___311 *bus;
	struct module___282 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___311 *);
	int (*remove)(struct device___311 *);
	void (*shutdown)(struct device___311 *);
	int (*suspend)(struct device___311 *, pm_message_t);
	int (*resume)(struct device___311 *);
	const struct attribute_group___308 **groups;
	const struct dev_pm_ops___311 *pm;
	void (*coredump)(struct device___311 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___311 {
	const char *name;
	const struct attribute_group___308 **groups;
	int (*uevent)(struct device___311 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___311 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___311 *);
	const struct dev_pm_ops___311 *pm;
};

struct module_kobject___279 {
	struct kobject___331 kobj;
	struct module___282 *mod;
	struct kobject___331 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___279 {
	struct module___282 *mod;
	struct latch_tree_node node;
};

struct module_layout___279 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___279 mtn;
};

struct module_attribute___279;

struct kernel_param___279;

struct module___282 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___279 mkobj;
	struct module_attribute___279 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___331 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___279 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___279 core_layout;
	struct module_layout___279 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___132 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct class___311 {
	const char *name;
	struct module___282 *owner;
	const struct attribute_group___308 **class_groups;
	const struct attribute_group___308 **dev_groups;
	struct kobject___331 *dev_kobj;
	int (*dev_uevent)(struct device___311 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___311 *, umode_t *);
	void (*class_release)(struct class___311 *);
	void (*dev_release)(struct device___311 *);
	int (*shutdown_pre)(struct device___311 *);
	const struct kobj_ns_type_operations___27 *ns_type;
	const void * (*namespace)(struct device___311 *);
	const struct dev_pm_ops___311 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

typedef int (*key_restrict_link_func_t___320)(struct key___319 *, const struct key_type *, const union key_payload *, struct key___319 *);

struct key_restriction___319;

struct key___319 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___345 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___319 *restrict_link;
};

struct key_restriction___319 {
	key_restrict_link_func_t___320 check;
	struct key___319 *key;
	struct key_type *keytype;
};

struct dentry_operations___343;

struct super_block___343;

struct dentry___343 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___343 *d_parent;
	struct qstr d_name;
	struct inode___344 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___343 *d_op;
	struct super_block___343 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___343;

struct address_space___343 {
	struct inode___344 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___345 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___343 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___343;

struct block_device___343;

struct inode___344 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___343 *i_op;
	struct super_block___343 *i_sb;
	struct address_space___343 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___345 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___162 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___344 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___343 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___343 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___343 {
	int (*d_revalidate)(struct dentry___343 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___343 *, unsigned int);
	int (*d_hash)(const struct dentry___343 *, struct qstr *);
	int (*d_compare)(const struct dentry___343 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___343 *);
	int (*d_init)(struct dentry___343 *);
	void (*d_release)(struct dentry___343 *);
	void (*d_prune)(struct dentry___343 *);
	void (*d_iput)(struct dentry___343 *, struct inode___344 *);
	char * (*d_dname)(struct dentry___343 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___344 *);
	int (*d_manage)(const struct path___344 *, bool);
	struct dentry___343 * (*d_real)(struct dentry___343 *, const struct inode___344 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___343;

struct mem_dqinfo___343 {
	struct quota_format_type___343 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___343;

struct quota_info___343 {
	unsigned int flags;
	struct rw_semaphore___345 dqio_sem;
	struct inode___344 *files[3];
	struct mem_dqinfo___343 info[3];
	const struct quota_format_ops___343 *ops[3];
};

struct rcuwait___343 {
	struct task_struct___345 *task;
};

struct percpu_rw_semaphore___343 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___345 rw_sem;
	struct rcuwait___343 writer;
	int readers_block;
};

struct sb_writers___343 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___343 rw_sem[3];
};

struct shrink_control___128;

struct shrinker___128 {
	long unsigned int (*count_objects)(struct shrinker___128 *, struct shrink_control___128 *);
	long unsigned int (*scan_objects)(struct shrinker___128 *, struct shrink_control___128 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___343;

struct super_operations___343;

struct dquot_operations___343;

struct quotactl_ops___343;

struct super_block___343 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___343 *s_type;
	const struct super_operations___343 *s_op;
	const struct dquot_operations___343 *dq_op;
	const struct quotactl_ops___343 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___343 *s_root;
	struct rw_semaphore___345 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___343 *s_bdev;
	struct backing_dev_info___162 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___343 s_dquot;
	struct sb_writers___343 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___343 *s_d_op;
	int cleancache_poolid;
	struct shrinker___128 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___240 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___128 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___128 *memcg;
};

typedef int (*dev_page_fault_t___332)(struct vm_area_struct___345 *, long unsigned int, const struct page___345 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___332)(struct page___345 *, void *);

struct dev_pagemap___332 {
	dev_page_fault_t___332 page_fault;
	dev_page_free_t___332 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___311 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___344 {
	struct task_struct___345 *task;
	struct core_thread___344 *next;
};

struct core_state___344 {
	atomic_t nr_threads;
	struct core_thread___344 dumper;
	struct completion startup;
};

struct vm_fault___332 {
	struct vm_area_struct___345 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___345 *cow_page;
	struct mem_cgroup___128 *memcg;
	struct page___345 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___344 prealloc_pte;
};

struct kiocb___344 {
	struct file___344 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___344 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___343 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___344 *ia_file;
};

struct dquot___343 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___343 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___343 {
	int qf_fmt_id;
	const struct quota_format_ops___343 *qf_ops;
	struct module___282 *qf_owner;
	struct quota_format_type___343 *qf_next;
};

struct quota_format_ops___343 {
	int (*check_quota_file)(struct super_block___343 *, int);
	int (*read_file_info)(struct super_block___343 *, int);
	int (*write_file_info)(struct super_block___343 *, int);
	int (*free_file_info)(struct super_block___343 *, int);
	int (*read_dqblk)(struct dquot___343 *);
	int (*commit_dqblk)(struct dquot___343 *);
	int (*release_dqblk)(struct dquot___343 *);
	int (*get_next_id)(struct super_block___343 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___343 {
	int (*write_dquot)(struct dquot___343 *);
	struct dquot___343 * (*alloc_dquot)(struct super_block___343 *, int);
	void (*destroy_dquot)(struct dquot___343 *);
	int (*acquire_dquot)(struct dquot___343 *);
	int (*release_dquot)(struct dquot___343 *);
	int (*mark_dirty)(struct dquot___343 *);
	int (*write_info)(struct super_block___343 *, int);
	qsize_t * (*get_reserved_space)(struct inode___344 *);
	int (*get_projid)(struct inode___344 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___344 *, qsize_t *);
	int (*get_next_id)(struct super_block___343 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___343 {
	int (*quota_on)(struct super_block___343 *, int, int, const struct path___344 *);
	int (*quota_off)(struct super_block___343 *, int);
	int (*quota_enable)(struct super_block___343 *, unsigned int);
	int (*quota_disable)(struct super_block___343 *, unsigned int);
	int (*quota_sync)(struct super_block___343 *, int);
	int (*set_info)(struct super_block___343 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___343 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___343 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___343 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___343 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___343 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___145;

struct swap_info_struct___85;

struct address_space_operations___343 {
	int (*writepage)(struct page___345 *, struct writeback_control___145 *);
	int (*readpage)(struct file___344 *, struct page___345 *);
	int (*writepages)(struct address_space___343 *, struct writeback_control___145 *);
	int (*set_page_dirty)(struct page___345 *);
	int (*readpages)(struct file___344 *, struct address_space___343 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___344 *, struct address_space___343 *, loff_t, unsigned int, unsigned int, struct page___345 **, void **);
	int (*write_end)(struct file___344 *, struct address_space___343 *, loff_t, unsigned int, unsigned int, struct page___345 *, void *);
	sector_t (*bmap)(struct address_space___343 *, sector_t);
	void (*invalidatepage)(struct page___345 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___345 *, gfp_t);
	void (*freepage)(struct page___345 *);
	ssize_t (*direct_IO)(struct kiocb___344 *, struct iov_iter___151 *);
	int (*migratepage)(struct address_space___343 *, struct page___345 *, struct page___345 *, enum migrate_mode);
	bool (*isolate_page)(struct page___345 *, isolate_mode_t);
	void (*putback_page)(struct page___345 *);
	int (*launder_page)(struct page___345 *);
	int (*is_partially_uptodate)(struct page___345 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___345 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___343 *, struct page___345 *);
	int (*swap_activate)(struct swap_info_struct___85 *, struct file___344 *, sector_t *);
	void (*swap_deactivate)(struct file___344 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___145 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___162 *wb;
	struct inode___344 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___164;

struct iov_iter___151 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___164 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct swap_info_struct___85 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___343 *bdev;
	struct file___344 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___343 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___344 *bd_inode;
	struct super_block___343 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___343 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___162 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___343 {
	struct dentry___343 * (*lookup)(struct inode___344 *, struct dentry___343 *, unsigned int);
	const char * (*get_link)(struct dentry___343 *, struct inode___344 *, struct delayed_call *);
	int (*permission)(struct inode___344 *, int);
	struct posix_acl * (*get_acl)(struct inode___344 *, int);
	int (*readlink)(struct dentry___343 *, char *, int);
	int (*create)(struct inode___344 *, struct dentry___343 *, umode_t, bool);
	int (*link)(struct dentry___343 *, struct inode___344 *, struct dentry___343 *);
	int (*unlink)(struct inode___344 *, struct dentry___343 *);
	int (*symlink)(struct inode___344 *, struct dentry___343 *, const char *);
	int (*mkdir)(struct inode___344 *, struct dentry___343 *, umode_t);
	int (*rmdir)(struct inode___344 *, struct dentry___343 *);
	int (*mknod)(struct inode___344 *, struct dentry___343 *, umode_t, dev_t);
	int (*rename)(struct inode___344 *, struct dentry___343 *, struct inode___344 *, struct dentry___343 *, unsigned int);
	int (*setattr)(struct dentry___343 *, struct iattr___343 *);
	int (*getattr)(const struct path___344 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___343 *, char *, size_t);
	int (*fiemap)(struct inode___344 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___344 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___344 *, struct dentry___343 *, struct file___344 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___344 *, struct dentry___343 *, umode_t);
	int (*set_acl)(struct inode___344 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___343 {
	void (*fl_copy_lock)(struct file_lock___344 *, struct file_lock___344 *);
	void (*fl_release_private)(struct file_lock___344 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___343;

struct file_lock___344 {
	struct file_lock___344 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___344 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___343 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___343 *fl_ops;
	const struct lock_manager_operations___343 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___343 {
	int (*lm_compare_owner)(struct file_lock___344 *, struct file_lock___344 *);
	long unsigned int (*lm_owner_key)(struct file_lock___344 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___344 *);
	int (*lm_grant)(struct file_lock___344 *, int);
	bool (*lm_break)(struct file_lock___344 *);
	int (*lm_change)(struct file_lock___344 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___344 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___343 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___343 *fa_next;
	struct file___344 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___343 {
	const char *name;
	int fs_flags;
	struct dentry___343 * (*mount)(struct file_system_type___343 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___343 *);
	struct module___282 *owner;
	struct file_system_type___343 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___343 {
	struct inode___344 * (*alloc_inode)(struct super_block___343 *);
	void (*destroy_inode)(struct inode___344 *);
	void (*dirty_inode)(struct inode___344 *, int);
	int (*write_inode)(struct inode___344 *, struct writeback_control___145 *);
	int (*drop_inode)(struct inode___344 *);
	void (*evict_inode)(struct inode___344 *);
	void (*put_super)(struct super_block___343 *);
	int (*sync_fs)(struct super_block___343 *, int);
	int (*freeze_super)(struct super_block___343 *);
	int (*freeze_fs)(struct super_block___343 *);
	int (*thaw_super)(struct super_block___343 *);
	int (*unfreeze_fs)(struct super_block___343 *);
	int (*statfs)(struct dentry___343 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___343 *, int *, char *);
	void (*umount_begin)(struct super_block___343 *);
	int (*show_options)(struct seq_file___292 *, struct dentry___343 *);
	int (*show_devname)(struct seq_file___292 *, struct dentry___343 *);
	int (*show_path)(struct seq_file___292 *, struct dentry___343 *);
	int (*show_stats)(struct seq_file___292 *, struct dentry___343 *);
	ssize_t (*quota_read)(struct super_block___343 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___343 *, int, const char *, size_t, loff_t);
	struct dquot___343 ** (*get_dquots)(struct inode___344 *);
	int (*bdev_try_to_free_page)(struct super_block___343 *, struct page___345 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___343 *, struct shrink_control___128 *);
	long int (*free_cached_objects)(struct super_block___343 *, struct shrink_control___128 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___162(struct bio___162 *);

struct bio_vec___164 {
	struct page___345 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___162;

struct bio_set___162;

struct bio___162 {
	struct bio___162 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___162 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___162 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___164 *bi_io_vec;
	struct bio_set___162 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___164 bi_inline_vecs[0];
};

struct seq_operations___291 {
	void * (*start)(struct seq_file___292 *, loff_t *);
	void (*stop)(struct seq_file___292 *, void *);
	void * (*next)(struct seq_file___292 *, void *, loff_t *);
	int (*show)(struct seq_file___292 *, void *);
};

struct cgroup_namespace___225 {
	refcount_t count;
	struct ns_common___9 ns;
	struct user_namespace___240 *user_ns;
	struct ucounts___240 *ucounts;
	struct css_set___225 *root_cset;
};

struct ucounts___240 {
	struct hlist_node node;
	struct user_namespace___240 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___226;

struct bpf_map_ops___225 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___226 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___226 *, struct file___344 *);
	void (*map_free)(struct bpf_map___226 *);
	int (*map_get_next_key)(struct bpf_map___226 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___226 *);
	void * (*map_lookup_elem)(struct bpf_map___226 *, void *);
	int (*map_update_elem)(struct bpf_map___226 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___226 *, void *);
	int (*map_push_elem)(struct bpf_map___226 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___226 *, void *);
	int (*map_peek_elem)(struct bpf_map___226 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___226 *, struct file___344 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___226 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___226 *, void *, struct seq_file___292 *);
	int (*map_check_btf)(const struct bpf_map___226 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___226 {
	const struct bpf_map_ops___225 *ops;
	struct bpf_map___226 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___319 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___225;

typedef void (*kthread_work_func_t___225)(struct kthread_work___225 *);

struct kthread_worker___225;

struct kthread_work___225 {
	struct list_head node;
	kthread_work_func_t___225 func;
	struct kthread_worker___225 *worker;
	int canceling;
};

struct kthread_worker___225 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___345 *task;
	struct kthread_work___225 *current_work;
};

struct kthread_delayed_work___225 {
	struct kthread_work___225 work;
	struct timer_list timer;
};

struct psi_group___225 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___225 *poll_kworker;
	struct kthread_delayed_work___225 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___225;

struct cgroup_rstat_cpu___225;

struct cgroup___225 {
	struct cgroup_subsys_state___225 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___338 *kn;
	struct cgroup_file___225 procs_file;
	struct cgroup_file___225 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___225 *subsys[13];
	struct cgroup_root___225 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___225 *dom_cgrp;
	struct cgroup_rstat_cpu___225 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___37 bpf;
	atomic_t congestion_count;
	struct cgroup___225 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___225 psi;
	int ancestor_ids[0];
};

struct cftype___225;

struct cgroup_subsys___225 {
	struct cgroup_subsys_state___225 * (*css_alloc)(struct cgroup_subsys_state___225 *);
	int (*css_online)(struct cgroup_subsys_state___225 *);
	void (*css_offline)(struct cgroup_subsys_state___225 *);
	void (*css_released)(struct cgroup_subsys_state___225 *);
	void (*css_free)(struct cgroup_subsys_state___225 *);
	void (*css_reset)(struct cgroup_subsys_state___225 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___225 *, int);
	int (*css_extra_stat_show)(struct seq_file___292 *, struct cgroup_subsys_state___225 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___345 *);
	void (*cancel_fork)(struct task_struct___345 *);
	void (*fork)(struct task_struct___345 *);
	void (*exit)(struct task_struct___345 *);
	void (*free)(struct task_struct___345 *);
	void (*bind)(struct cgroup_subsys_state___225 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___225 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___225 *dfl_cftypes;
	struct cftype___225 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___225 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___225 *updated_children;
	struct cgroup___225 *updated_next;
};

struct cgroup_root___225 {
	struct kernfs_root___337 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___225 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___225 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___225 *ss;
	struct list_head node;
	struct kernfs_ops___337 *kf_ops;
	int (*open)(struct kernfs_open_file___337 *);
	void (*release)(struct kernfs_open_file___337 *);
	u64 (*read_u64)(struct cgroup_subsys_state___225 *, struct cftype___225 *);
	s64 (*read_s64)(struct cgroup_subsys_state___225 *, struct cftype___225 *);
	int (*seq_show)(struct seq_file___292 *, void *);
	void * (*seq_start)(struct seq_file___292 *, loff_t *);
	void * (*seq_next)(struct seq_file___292 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___292 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___225 *, struct cftype___225 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___225 *, struct cftype___225 *, s64);
	ssize_t (*write)(struct kernfs_open_file___337 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___337 *, struct poll_table_struct___211 *);
};

typedef void compound_page_dtor___332(struct page___345 *);

struct bdi_writeback_congested___162 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___162 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___162 {
	struct bio___162 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___164 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___164 bip_inline_vecs[0];
};

struct bio_set___162 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___162 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___128 {
	struct mem_cgroup___128 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___128 {
	struct lruvec___344 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___128 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___128 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct node___201 {
	struct device___311 dev;
};

struct dev_pm_qos_request___20 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___311 *dev;
};

struct kernel_param_ops___279 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___279 *);
	int (*get)(char *, const struct kernel_param___279 *);
	void (*free)(void *);
};

struct kparam_array___279;

struct kernel_param___279 {
	const char *name;
	struct module___282 *mod;
	const struct kernel_param_ops___279 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___279 *arr;
	};
};

struct kparam_array___279 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___279 *ops;
	void *elem;
};

struct module_attribute___279 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___279 *, struct module_kobject___279 *, char *);
	ssize_t (*store)(struct module_attribute___279 *, struct module_kobject___279 *, const char *, size_t);
	void (*setup)(struct module___282 *, const char *);
	int (*test)(struct module___282 *);
	void (*free)(struct module___282 *);
};

struct trace_event_class___132;

struct trace_event_call___132 {
	struct list_head list;
	struct trace_event_class___132 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___13 event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___37 *prog_array;
	int (*perf_perm)(struct trace_event_call___132 *, struct perf_event___139 *);
};

struct perf_cpu_context___139;

struct pmu___139 {
	struct list_head entry;
	struct module___282 *module;
	struct device___311 *dev;
	const struct attribute_group___308 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___139 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___139 *);
	void (*pmu_disable)(struct pmu___139 *);
	int (*event_init)(struct perf_event___139 *);
	void (*event_mapped)(struct perf_event___139 *, struct mm_struct___344 *);
	void (*event_unmapped)(struct perf_event___139 *, struct mm_struct___344 *);
	int (*add)(struct perf_event___139 *, int);
	void (*del)(struct perf_event___139 *, int);
	void (*start)(struct perf_event___139 *, int);
	void (*stop)(struct perf_event___139 *, int);
	void (*read)(struct perf_event___139 *);
	void (*start_txn)(struct pmu___139 *, unsigned int);
	int (*commit_txn)(struct pmu___139 *);
	void (*cancel_txn)(struct pmu___139 *);
	int (*event_idx)(struct perf_event___139 *);
	void (*sched_task)(struct perf_event_context___139 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___139 *);
	int (*filter_match)(struct perf_event___139 *);
	int (*check_period)(struct perf_event___139 *, u64);
};

struct perf_cpu_context___139 {
	struct perf_event_context___139 ctx;
	struct perf_event_context___139 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___139 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___139 {
	struct cgroup_subsys_state___225 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___132 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___132 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___132 *);
	struct list_head * (*get_fields)(struct trace_event_call___132 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___132 *);
};

struct file___345;

struct kiocb___345;

struct vm_area_struct___346;

struct inode___345;

struct file_lock___345;

struct page___346;

struct seq_file___293;

struct file_operations___345 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___345 *, loff_t, int);
	ssize_t (*read)(struct file___345 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___345 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___345 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___345 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___345 *, bool);
	int (*iterate)(struct file___345 *, struct dir_context *);
	int (*iterate_shared)(struct file___345 *, struct dir_context *);
	__poll_t (*poll)(struct file___345 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___345 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___345 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___345 *, struct vm_area_struct___346 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___345 *, struct file___345 *);
	int (*flush)(struct file___345 *, fl_owner_t);
	int (*release)(struct inode___345 *, struct file___345 *);
	int (*fsync)(struct file___345 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___345 *, int);
	int (*lock)(struct file___345 *, int, struct file_lock___345 *);
	ssize_t (*sendpage)(struct file___345 *, struct page___346 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___345 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___345 *, int, struct file_lock___345 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___345 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___345 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___345 *, long int, struct file_lock___345 **, void **);
	long int (*fallocate)(struct file___345 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___293 *, struct file___345 *);
	ssize_t (*copy_file_range)(struct file___345 *, loff_t, struct file___345 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___345 *, loff_t, struct file___345 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___345 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___346 *pgtable_t___345;

struct address_space___344;

struct mm_struct___345;

struct dev_pagemap___333;

struct mem_cgroup___129;

struct page___346 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___344 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___346 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___345 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___345 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___333 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___129 *mem_cgroup;
};

struct vmacache___345 {
	u64 seqnum;
	struct vm_area_struct___346 *vmas[4];
};

struct vm_operations_struct___333;

struct vm_area_struct___346 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___346 *vm_next;
	struct vm_area_struct___346 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___345 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___333 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___345 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct page_frag___345 {
	struct page___346 *page;
	__u32 offset;
	__u32 size;
};

struct cred___320;

struct nsproxy___271;

struct bio_list___163;

struct backing_dev_info___163;

struct css_set___226;

struct vm_struct___251;

struct task_struct___346 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___346 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___345 *mm;
	struct mm_struct___345 *active_mm;
	struct vmacache___345 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___346 *real_parent;
	struct task_struct___346 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___346 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___129 *active_memcg;
	long int rh_reserved2;
	struct pid___215 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___215 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___215 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___320 *ptracer_cred;
	const struct cred___320 *real_cred;
	const struct cred___320 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___271 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___346 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___163 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___163 *backing_dev_info;
	struct io_context___84 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___226 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___345 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___129 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___346 *oom_reaper_list;
	struct vm_struct___251 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___139 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rw_semaphore___346 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___346 *owner;
};

struct core_state___345;

struct user_namespace___241;

struct mm_struct___345 {
	struct {
		struct vm_area_struct___346 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___345 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___346 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___345 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___346 *owner;
		struct user_namespace___241 *user_ns;
		struct file___345 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___345 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct secondary_data___346 {
	void *stack;
	struct task_struct___346 *task;
	long int status;
};

struct address_space_operations___344;

struct address_space___344 {
	struct inode___345 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___346 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___344 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___333)(struct vm_area_struct___346 *, long unsigned int, const struct page___346 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___333)(struct page___346 *, void *);

struct device___312;

struct dev_pagemap___333 {
	dev_page_fault_t___333 page_fault;
	dev_page_free_t___333 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___312 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct cgroup___226;

struct cgroup_subsys___226;

struct cgroup_subsys_state___226 {
	struct cgroup___226 *cgroup;
	struct cgroup_subsys___226 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___226 *parent;
};

struct kernfs_node___339;

struct cgroup_file___226 {
	struct kernfs_node___339 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___129;

struct mem_cgroup___129 {
	struct cgroup_subsys_state___226 css;
	struct mem_cgroup_id___6 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___226 events_file;
	struct cgroup_file___226 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___346 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___129 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry___344;

struct path___345 {
	struct vfsmount *mnt;
	struct dentry___344 *dentry;
};

struct file___345 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___345 f_path;
	struct inode___345 *f_inode;
	const struct file_operations___345 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___215 f_owner;
	const struct cred___320 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___344 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___333;

struct vm_operations_struct___333 {
	void (*open)(struct vm_area_struct___346 *);
	void (*close)(struct vm_area_struct___346 *);
	int (*split)(struct vm_area_struct___346 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___346 *);
	vm_fault_t (*fault)(struct vm_fault___333 *);
	vm_fault_t (*huge_fault)(struct vm_fault___333 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___333 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___346 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___333 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___333 *);
	int (*access)(struct vm_area_struct___346 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___346 *);
	int (*set_policy)(struct vm_area_struct___346 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___346 *, long unsigned int);
	struct page___346 * (*find_special_page)(struct vm_area_struct___346 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___345 {
	struct task_struct___346 *task;
	struct core_thread___345 *next;
};

struct core_state___345 {
	atomic_t nr_threads;
	struct core_thread___345 dumper;
	struct completion startup;
};

struct key___320;

struct ucounts___241;

struct user_namespace___241 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___241 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___9 ns;
	long unsigned int flags;
	struct key___320 *persistent_keyring_register;
	struct rw_semaphore___346 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___241 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___333 {
	struct vm_area_struct___346 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___346 *cow_page;
	struct mem_cgroup___129 *memcg;
	struct page___346 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___345 prealloc_pte;
};

struct user_struct___320 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___320 *uid_keyring;
	struct key___320 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___320 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___320 *session_keyring;
	struct key___320 *process_keyring;
	struct key___320 *thread_keyring;
	struct key___320 *request_key_auth;
	void *security;
	struct user_struct___320 *user;
	struct user_namespace___241 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___226;

struct nsproxy___271 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___226 *cgroup_ns;
};

struct bio___163;

struct bio_list___163 {
	struct bio___163 *head;
	struct bio___163 *tail;
};

struct bdi_writeback_congested___163;

struct bdi_writeback___163 {
	struct backing_dev_info___163 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___163 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___226 *memcg_css;
	struct cgroup_subsys_state___226 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___163 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___163 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___312 *dev;
	struct device___312 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___344 *debug_dir;
	struct dentry___344 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___226 {
	struct cgroup_subsys_state___226 *subsys[13];
	refcount_t refcount;
	struct css_set___226 *dom_cset;
	struct cgroup___226 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___226 *mg_src_cgrp;
	struct cgroup___226 *mg_dst_cgrp;
	struct css_set___226 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct vm_struct___251 {
	struct vm_struct___251 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___346 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct fwnode_operations___235;

struct fwnode_handle___235 {
	struct fwnode_handle___235 *secondary;
	const struct fwnode_operations___235 *ops;
};

struct fwnode_reference_args___235;

struct fwnode_endpoint___235;

struct fwnode_operations___235 {
	struct fwnode_handle___235 * (*get)(struct fwnode_handle___235 *);
	void (*put)(struct fwnode_handle___235 *);
	bool (*device_is_available)(const struct fwnode_handle___235 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___235 *, const struct device___312 *);
	bool (*property_present)(const struct fwnode_handle___235 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___235 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___235 *, const char *, const char **, size_t);
	struct fwnode_handle___235 * (*get_parent)(const struct fwnode_handle___235 *);
	struct fwnode_handle___235 * (*get_next_child_node)(const struct fwnode_handle___235 *, struct fwnode_handle___235 *);
	struct fwnode_handle___235 * (*get_named_child_node)(const struct fwnode_handle___235 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___235 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___235 *);
	struct fwnode_handle___235 * (*graph_get_next_endpoint)(const struct fwnode_handle___235 *, struct fwnode_handle___235 *);
	struct fwnode_handle___235 * (*graph_get_remote_endpoint)(const struct fwnode_handle___235 *);
	struct fwnode_handle___235 * (*graph_get_port_parent)(struct fwnode_handle___235 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___235 *, struct fwnode_endpoint___235 *);
};

struct fwnode_endpoint___235 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___235 *local_fwnode;
};

struct fwnode_reference_args___235 {
	struct fwnode_handle___235 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct kset___331;

struct kobj_type___331;

struct kobject___332 {
	const char *name;
	struct list_head entry;
	struct kobject___332 *parent;
	struct kset___331 *kset;
	struct kobj_type___331 *ktype;
	struct kernfs_node___339 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct wakeup_source___8;

struct wake_irq___8;

struct pm_subsys_data___5;

struct dev_pm_qos___21;

struct dev_pm_info___312 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq___8 *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___5 *subsys_data;
	void (*set_latency_tolerance)(struct device___312 *, s32);
	struct dev_pm_qos___21 *qos;
};

struct device_type___312;

struct bus_type___312;

struct device_driver___312;

struct dev_pm_domain___312;

struct device_node___80;

struct class___312;

struct attribute_group___309;

struct device___312 {
	struct device___312 *parent;
	struct device_private *p;
	struct kobject___332 kobj;
	const char *init_name;
	const struct device_type___312 *type;
	struct mutex mutex;
	struct bus_type___312 *bus;
	struct device_driver___312 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___312 power;
	struct dev_pm_domain___312 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___80 *of_node;
	struct fwnode_handle___235 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___312 *class;
	const struct attribute_group___309 **groups;
	void (*release)(struct device___312 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct pglist_data___345;

struct lruvec___345 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___345 *pgdat;
};

struct zone___345 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___345 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___345 {
	struct zone___345 *zone;
	int zone_idx;
};

struct zonelist___345 {
	struct zoneref___345 _zonerefs[25];
};

struct pglist_data___345 {
	struct zone___345 node_zones[3];
	struct zonelist___345 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___346 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___346 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___345 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___345 {
	struct rw_semaphore___346 rwsem;
	struct notifier_block *head;
};

struct kernfs_root___338;

struct kernfs_elem_dir___338 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___338 *root;
};

struct kernfs_syscall_ops___338;

struct kernfs_root___338 {
	struct kernfs_node___339 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___338 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___338 {
	struct kernfs_node___339 *target_kn;
};

struct kernfs_ops___338;

struct kernfs_elem_attr___338 {
	const struct kernfs_ops___338 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___339 *notify_next;
};

struct kernfs_node___339 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___339 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___338 dir;
		struct kernfs_elem_symlink___338 symlink;
		struct kernfs_elem_attr___338 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___338;

struct kernfs_ops___338 {
	int (*open)(struct kernfs_open_file___338 *);
	void (*release)(struct kernfs_open_file___338 *);
	int (*seq_show)(struct seq_file___293 *, void *);
	void * (*seq_start)(struct seq_file___293 *, loff_t *);
	void * (*seq_next)(struct seq_file___293 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___293 *, void *);
	ssize_t (*read)(struct kernfs_open_file___338 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___338 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___338 *, struct vm_area_struct___346 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___338 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___338 {
	int (*remount_fs)(struct kernfs_root___338 *, int *, char *);
	int (*show_options)(struct seq_file___293 *, struct kernfs_root___338 *);
	int (*mkdir)(struct kernfs_node___339 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___339 *);
	int (*rename)(struct kernfs_node___339 *, struct kernfs_node___339 *, const char *);
	int (*show_path)(struct seq_file___293 *, struct kernfs_node___339 *, struct kernfs_root___338 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___292;

struct seq_file___293 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___292 *op;
	int poll_event;
	const struct file___345 *file;
	void *private;
};

struct kernfs_open_file___338 {
	struct kernfs_node___339 *kn;
	struct file___345 *file;
	struct seq_file___293 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___333 *vm_ops;
};

struct bin_attribute___308;

struct attribute_group___309 {
	const char *name;
	umode_t (*is_visible)(struct kobject___332 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___332 *, struct bin_attribute___308 *, int);
	struct attribute **attrs;
	struct bin_attribute___308 **bin_attrs;
};

struct bin_attribute___308 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___345 *, struct kobject___332 *, struct bin_attribute___308 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___345 *, struct kobject___332 *, struct bin_attribute___308 *, char *, loff_t, size_t);
	int (*mmap)(struct file___345 *, struct kobject___332 *, struct bin_attribute___308 *, struct vm_area_struct___346 *);
};

struct sysfs_ops___331 {
	ssize_t (*show)(struct kobject___332 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___332 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___331;

struct kset___331 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___332 kobj;
	const struct kset_uevent_ops___331 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___331 {
	void (*release)(struct kobject___332 *);
	const struct sysfs_ops___331 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___27 * (*child_ns_type)(struct kobject___332 *);
	const void * (*namespace)(struct kobject___332 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___331 {
	int (* const filter)(struct kset___331 *, struct kobject___332 *);
	const char * (* const name)(struct kset___331 *, struct kobject___332 *);
	int (* const uevent)(struct kset___331 *, struct kobject___332 *, struct kobj_uevent_env *);
};

struct kobj_attribute___323 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___332 *, struct kobj_attribute___323 *, char *);
	ssize_t (*store)(struct kobject___332 *, struct kobj_attribute___323 *, const char *, size_t);
};

struct dev_pm_ops___312 {
	int (*prepare)(struct device___312 *);
	void (*complete)(struct device___312 *);
	int (*suspend)(struct device___312 *);
	int (*resume)(struct device___312 *);
	int (*freeze)(struct device___312 *);
	int (*thaw)(struct device___312 *);
	int (*poweroff)(struct device___312 *);
	int (*restore)(struct device___312 *);
	int (*suspend_late)(struct device___312 *);
	int (*resume_early)(struct device___312 *);
	int (*freeze_late)(struct device___312 *);
	int (*thaw_early)(struct device___312 *);
	int (*poweroff_late)(struct device___312 *);
	int (*restore_early)(struct device___312 *);
	int (*suspend_noirq)(struct device___312 *);
	int (*resume_noirq)(struct device___312 *);
	int (*freeze_noirq)(struct device___312 *);
	int (*thaw_noirq)(struct device___312 *);
	int (*poweroff_noirq)(struct device___312 *);
	int (*restore_noirq)(struct device___312 *);
	int (*runtime_suspend)(struct device___312 *);
	int (*runtime_resume)(struct device___312 *);
	int (*runtime_idle)(struct device___312 *);
};

struct pm_domain_data___5;

struct pm_subsys_data___5 {
	spinlock_t lock;
	unsigned int refcount;
	struct list_head clock_list;
	struct pm_domain_data___5 *domain_data;
};

struct pm_domain_data___5 {
	struct list_head list_node;
	struct device___312 *dev;
};

struct wakeup_source___8 {
	const char *name;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq___8 *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	bool active: 1;
	bool autosleep_enabled: 1;
};

struct wake_irq___8 {
	struct device___312 *dev;
	unsigned int status;
	int irq;
	const char *name;
};

struct pm_qos_constraints___20 {
	struct plist_head list;
	s32 target_value;
	s32 default_value;
	s32 no_constraint_value;
	enum pm_qos_type type;
	struct blocking_notifier_head___345 *notifiers;
};

struct dev_pm_qos_request___21;

struct dev_pm_qos___21 {
	struct pm_qos_constraints___20 resume_latency;
	struct pm_qos_constraints___20 latency_tolerance;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___21 *resume_latency_req;
	struct dev_pm_qos_request___21 *latency_tolerance_req;
	struct dev_pm_qos_request___21 *flags_req;
};

struct dev_pm_domain___312 {
	struct dev_pm_ops___312 ops;
	void (*detach)(struct device___312 *, bool);
	int (*activate)(struct device___312 *);
	void (*sync)(struct device___312 *);
	void (*dismiss)(struct device___312 *);
};

struct bus_type___312 {
	const char *name;
	const char *dev_name;
	struct device___312 *dev_root;
	const struct attribute_group___309 **bus_groups;
	const struct attribute_group___309 **dev_groups;
	const struct attribute_group___309 **drv_groups;
	int (*match)(struct device___312 *, struct device_driver___312 *);
	int (*uevent)(struct device___312 *, struct kobj_uevent_env *);
	int (*probe)(struct device___312 *);
	int (*remove)(struct device___312 *);
	void (*shutdown)(struct device___312 *);
	int (*online)(struct device___312 *);
	int (*offline)(struct device___312 *);
	int (*suspend)(struct device___312 *, pm_message_t);
	int (*resume)(struct device___312 *);
	int (*num_vf)(struct device___312 *);
	int (*dma_configure)(struct device___312 *);
	const struct dev_pm_ops___312 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___312 {
	const char *name;
	struct bus_type___312 *bus;
	struct module___11 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___312 *);
	int (*remove)(struct device___312 *);
	void (*shutdown)(struct device___312 *);
	int (*suspend)(struct device___312 *, pm_message_t);
	int (*resume)(struct device___312 *);
	const struct attribute_group___309 **groups;
	const struct dev_pm_ops___312 *pm;
	void (*coredump)(struct device___312 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___312 {
	const char *name;
	const struct attribute_group___309 **groups;
	int (*uevent)(struct device___312 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___312 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___312 *);
	const struct dev_pm_ops___312 *pm;
};

struct class___312 {
	const char *name;
	struct module___11 *owner;
	const struct attribute_group___309 **class_groups;
	const struct attribute_group___309 **dev_groups;
	struct kobject___332 *dev_kobj;
	int (*dev_uevent)(struct device___312 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___312 *, umode_t *);
	void (*class_release)(struct class___312 *);
	void (*dev_release)(struct device___312 *);
	int (*shutdown_pre)(struct device___312 *);
	const struct kobj_ns_type_operations___27 *ns_type;
	const void * (*namespace)(struct device___312 *);
	const struct dev_pm_ops___312 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct property___76;

struct device_node___80 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___235 fwnode;
	struct property___76 *properties;
	struct property___76 *deadprops;
	struct device_node___80 *parent;
	struct device_node___80 *child;
	struct device_node___80 *sibling;
	struct kobject___332 kobj;
	long unsigned int _flags;
	void *data;
};

struct property___76 {
	char *name;
	int length;
	void *value;
	struct property___76 *next;
	long unsigned int _flags;
	struct bin_attribute___308 attr;
};

struct of_phandle_args___14 {
	struct device_node___80 *np;
	int args_count;
	uint32_t args[16];
};

struct of_phandle_iterator___2 {
	const char *cells_name;
	int cell_count;
	const struct device_node___80 *parent;
	const __be32 *list_end;
	const __be32 *phandle_end;
	const __be32 *cur;
	uint32_t cur_count;
	phandle phandle;
	struct device_node___80 *node;
};

enum gpd_status {
	GPD_STATE_ACTIVE = 0,
	GPD_STATE_POWER_OFF = 1,
};

struct dev_power_governor___5 {
	bool (*power_down_ok)(struct dev_pm_domain___312 *);
	bool (*suspend_ok)(struct device___312 *);
};

struct gpd_dev_ops {
	int (*start)(struct device___312 *);
	int (*stop)(struct device___312 *);
};

struct genpd_power_state {
	s64 power_off_latency_ns;
	s64 power_on_latency_ns;
	s64 residency_ns;
	struct fwnode_handle___235 *fwnode;
	ktime_t idle_time;
};

struct dev_pm_opp;

struct genpd_lock_ops;

struct generic_pm_domain {
	struct device___312 dev;
	struct dev_pm_domain___312 domain;
	struct list_head gpd_list_node;
	struct list_head master_links;
	struct list_head slave_links;
	struct list_head dev_list;
	struct dev_power_governor___5 *gov;
	struct work_struct power_off_work;
	struct fwnode_handle___235 *provider;
	bool has_provider;
	const char *name;
	atomic_t sd_count;
	enum gpd_status status;
	unsigned int device_count;
	unsigned int suspended_count;
	unsigned int prepared_count;
	unsigned int performance_state;
	int (*power_off)(struct generic_pm_domain *);
	int (*power_on)(struct generic_pm_domain *);
	unsigned int (*opp_to_performance_state)(struct generic_pm_domain *, struct dev_pm_opp *);
	int (*set_performance_state)(struct generic_pm_domain *, unsigned int);
	struct gpd_dev_ops dev_ops;
	s64 max_off_time_ns;
	bool max_off_time_changed;
	bool cached_power_down_ok;
	int (*attach_dev)(struct generic_pm_domain *, struct device___312 *);
	void (*detach_dev)(struct generic_pm_domain *, struct device___312 *);
	unsigned int flags;
	struct genpd_power_state *states;
	unsigned int state_count;
	unsigned int state_idx;
	void *free;
	ktime_t on_time;
	ktime_t accounting_time;
	const struct genpd_lock_ops *lock_ops;
	union {
		struct mutex mlock;
		struct {
			spinlock_t slock;
			long unsigned int lock_flags;
		};
	};
};

struct genpd_lock_ops {
	void (*lock)(struct generic_pm_domain *);
	void (*lock_nested)(struct generic_pm_domain *, int);
	int (*lock_interruptible)(struct generic_pm_domain *);
	void (*unlock)(struct generic_pm_domain *);
};

struct gpd_link {
	struct generic_pm_domain *master;
	struct list_head master_node;
	struct generic_pm_domain *slave;
	struct list_head slave_node;
};

struct gpd_timing_data {
	s64 suspend_latency_ns;
	s64 resume_latency_ns;
	s64 effective_constraint_ns;
	bool constraint_changed;
	bool cached_suspend_ok;
};

struct generic_pm_domain_data {
	struct pm_domain_data___5 base;
	struct gpd_timing_data td;
	struct notifier_block nb;
	unsigned int performance_state;
	void *data;
};

typedef struct generic_pm_domain * (*genpd_xlate_t)(struct of_phandle_args___14 *, void *);

struct genpd_onecell_data {
	struct generic_pm_domain **domains;
	unsigned int num_domains;
	genpd_xlate_t xlate;
};

struct dev_pm_qos_request___21 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___312 *dev;
};

struct dentry_operations___344;

struct super_block___344;

struct dentry___344 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___344 *d_parent;
	struct qstr d_name;
	struct inode___345 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___344 *d_op;
	struct super_block___344 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___344;

struct block_device___344;

struct inode___345 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___344 *i_op;
	struct super_block___344 *i_sb;
	struct address_space___344 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___346 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___163 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___345 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___344 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___344 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___344 {
	int (*d_revalidate)(struct dentry___344 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___344 *, unsigned int);
	int (*d_hash)(const struct dentry___344 *, struct qstr *);
	int (*d_compare)(const struct dentry___344 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___344 *);
	int (*d_init)(struct dentry___344 *);
	void (*d_release)(struct dentry___344 *);
	void (*d_prune)(struct dentry___344 *);
	void (*d_iput)(struct dentry___344 *, struct inode___345 *);
	char * (*d_dname)(struct dentry___344 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___345 *);
	int (*d_manage)(const struct path___345 *, bool);
	struct dentry___344 * (*d_real)(struct dentry___344 *, const struct inode___345 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___344;

struct mem_dqinfo___344 {
	struct quota_format_type___344 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___344;

struct quota_info___344 {
	unsigned int flags;
	struct rw_semaphore___346 dqio_sem;
	struct inode___345 *files[3];
	struct mem_dqinfo___344 info[3];
	const struct quota_format_ops___344 *ops[3];
};

struct rcuwait___344 {
	struct task_struct___346 *task;
};

struct percpu_rw_semaphore___344 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___346 rw_sem;
	struct rcuwait___344 writer;
	int readers_block;
};

struct sb_writers___344 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___344 rw_sem[3];
};

struct shrink_control___129;

struct shrinker___129 {
	long unsigned int (*count_objects)(struct shrinker___129 *, struct shrink_control___129 *);
	long unsigned int (*scan_objects)(struct shrinker___129 *, struct shrink_control___129 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___344;

struct super_operations___344;

struct dquot_operations___344;

struct quotactl_ops___344;

struct super_block___344 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___344 *s_type;
	const struct super_operations___344 *s_op;
	const struct dquot_operations___344 *dq_op;
	const struct quotactl_ops___344 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___344 *s_root;
	struct rw_semaphore___346 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___344 *s_bdev;
	struct backing_dev_info___163 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___344 s_dquot;
	struct sb_writers___344 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___344 *s_d_op;
	int cleancache_poolid;
	struct shrinker___129 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___241 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___129 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___129 *memcg;
};

struct kiocb___345 {
	struct file___345 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___345 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___344 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___345 *ia_file;
};

struct dquot___344 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___344 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___344 {
	int qf_fmt_id;
	const struct quota_format_ops___344 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___344 *qf_next;
};

struct quota_format_ops___344 {
	int (*check_quota_file)(struct super_block___344 *, int);
	int (*read_file_info)(struct super_block___344 *, int);
	int (*write_file_info)(struct super_block___344 *, int);
	int (*free_file_info)(struct super_block___344 *, int);
	int (*read_dqblk)(struct dquot___344 *);
	int (*commit_dqblk)(struct dquot___344 *);
	int (*release_dqblk)(struct dquot___344 *);
	int (*get_next_id)(struct super_block___344 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___344 {
	int (*write_dquot)(struct dquot___344 *);
	struct dquot___344 * (*alloc_dquot)(struct super_block___344 *, int);
	void (*destroy_dquot)(struct dquot___344 *);
	int (*acquire_dquot)(struct dquot___344 *);
	int (*release_dquot)(struct dquot___344 *);
	int (*mark_dirty)(struct dquot___344 *);
	int (*write_info)(struct super_block___344 *, int);
	qsize_t * (*get_reserved_space)(struct inode___345 *);
	int (*get_projid)(struct inode___345 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___345 *, qsize_t *);
	int (*get_next_id)(struct super_block___344 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___344 {
	int (*quota_on)(struct super_block___344 *, int, int, const struct path___345 *);
	int (*quota_off)(struct super_block___344 *, int);
	int (*quota_enable)(struct super_block___344 *, unsigned int);
	int (*quota_disable)(struct super_block___344 *, unsigned int);
	int (*quota_sync)(struct super_block___344 *, int);
	int (*set_info)(struct super_block___344 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___344 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___344 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___344 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___344 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___344 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___146;

struct swap_info_struct___86;

struct address_space_operations___344 {
	int (*writepage)(struct page___346 *, struct writeback_control___146 *);
	int (*readpage)(struct file___345 *, struct page___346 *);
	int (*writepages)(struct address_space___344 *, struct writeback_control___146 *);
	int (*set_page_dirty)(struct page___346 *);
	int (*readpages)(struct file___345 *, struct address_space___344 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___345 *, struct address_space___344 *, loff_t, unsigned int, unsigned int, struct page___346 **, void **);
	int (*write_end)(struct file___345 *, struct address_space___344 *, loff_t, unsigned int, unsigned int, struct page___346 *, void *);
	sector_t (*bmap)(struct address_space___344 *, sector_t);
	void (*invalidatepage)(struct page___346 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___346 *, gfp_t);
	void (*freepage)(struct page___346 *);
	ssize_t (*direct_IO)(struct kiocb___345 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___344 *, struct page___346 *, struct page___346 *, enum migrate_mode);
	bool (*isolate_page)(struct page___346 *, isolate_mode_t);
	void (*putback_page)(struct page___346 *);
	int (*launder_page)(struct page___346 *);
	int (*is_partially_uptodate)(struct page___346 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___346 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___344 *, struct page___346 *);
	int (*swap_activate)(struct swap_info_struct___86 *, struct file___345 *, sector_t *);
	void (*swap_deactivate)(struct file___345 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___146 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___163 *wb;
	struct inode___345 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct swap_info_struct___86 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___344 *bdev;
	struct file___345 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___344 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___345 *bd_inode;
	struct super_block___344 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___344 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___163 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___344 {
	struct dentry___344 * (*lookup)(struct inode___345 *, struct dentry___344 *, unsigned int);
	const char * (*get_link)(struct dentry___344 *, struct inode___345 *, struct delayed_call *);
	int (*permission)(struct inode___345 *, int);
	struct posix_acl * (*get_acl)(struct inode___345 *, int);
	int (*readlink)(struct dentry___344 *, char *, int);
	int (*create)(struct inode___345 *, struct dentry___344 *, umode_t, bool);
	int (*link)(struct dentry___344 *, struct inode___345 *, struct dentry___344 *);
	int (*unlink)(struct inode___345 *, struct dentry___344 *);
	int (*symlink)(struct inode___345 *, struct dentry___344 *, const char *);
	int (*mkdir)(struct inode___345 *, struct dentry___344 *, umode_t);
	int (*rmdir)(struct inode___345 *, struct dentry___344 *);
	int (*mknod)(struct inode___345 *, struct dentry___344 *, umode_t, dev_t);
	int (*rename)(struct inode___345 *, struct dentry___344 *, struct inode___345 *, struct dentry___344 *, unsigned int);
	int (*setattr)(struct dentry___344 *, struct iattr___344 *);
	int (*getattr)(const struct path___345 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___344 *, char *, size_t);
	int (*fiemap)(struct inode___345 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___345 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___345 *, struct dentry___344 *, struct file___345 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___345 *, struct dentry___344 *, umode_t);
	int (*set_acl)(struct inode___345 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___344 {
	void (*fl_copy_lock)(struct file_lock___345 *, struct file_lock___345 *);
	void (*fl_release_private)(struct file_lock___345 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___344;

struct lock_manager_operations___344;

struct file_lock___345 {
	struct file_lock___345 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___345 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___344 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___344 *fl_ops;
	const struct lock_manager_operations___344 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___344 {
	int (*lm_compare_owner)(struct file_lock___345 *, struct file_lock___345 *);
	long unsigned int (*lm_owner_key)(struct file_lock___345 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___345 *);
	int (*lm_grant)(struct file_lock___345 *, int);
	bool (*lm_break)(struct file_lock___345 *);
	int (*lm_change)(struct file_lock___345 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___345 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___344 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___344 *fa_next;
	struct file___345 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___344 {
	const char *name;
	int fs_flags;
	struct dentry___344 * (*mount)(struct file_system_type___344 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___344 *);
	struct module___11 *owner;
	struct file_system_type___344 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___344 {
	struct inode___345 * (*alloc_inode)(struct super_block___344 *);
	void (*destroy_inode)(struct inode___345 *);
	void (*dirty_inode)(struct inode___345 *, int);
	int (*write_inode)(struct inode___345 *, struct writeback_control___146 *);
	int (*drop_inode)(struct inode___345 *);
	void (*evict_inode)(struct inode___345 *);
	void (*put_super)(struct super_block___344 *);
	int (*sync_fs)(struct super_block___344 *, int);
	int (*freeze_super)(struct super_block___344 *);
	int (*freeze_fs)(struct super_block___344 *);
	int (*thaw_super)(struct super_block___344 *);
	int (*unfreeze_fs)(struct super_block___344 *);
	int (*statfs)(struct dentry___344 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___344 *, int *, char *);
	void (*umount_begin)(struct super_block___344 *);
	int (*show_options)(struct seq_file___293 *, struct dentry___344 *);
	int (*show_devname)(struct seq_file___293 *, struct dentry___344 *);
	int (*show_path)(struct seq_file___293 *, struct dentry___344 *);
	int (*show_stats)(struct seq_file___293 *, struct dentry___344 *);
	ssize_t (*quota_read)(struct super_block___344 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___344 *, int, const char *, size_t, loff_t);
	struct dquot___344 ** (*get_dquots)(struct inode___345 *);
	int (*bdev_try_to_free_page)(struct super_block___344 *, struct page___346 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___344 *, struct shrink_control___129 *);
	long int (*free_cached_objects)(struct super_block___344 *, struct shrink_control___129 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___163(struct bio___163 *);

struct bio_vec___165 {
	struct page___346 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___163;

struct bio_set___163;

struct bio___163 {
	struct bio___163 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___163 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___163 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___165 *bi_io_vec;
	struct bio_set___163 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___165 bi_inline_vecs[0];
};

typedef int (*key_restrict_link_func_t___321)(struct key___320 *, const struct key_type *, const union key_payload *, struct key___320 *);

struct key_restriction___320;

struct key___320 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___346 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___320 *restrict_link;
};

struct key_restriction___320 {
	key_restrict_link_func_t___321 check;
	struct key___320 *key;
	struct key_type *keytype;
};

struct seq_operations___292 {
	void * (*start)(struct seq_file___293 *, loff_t *);
	void (*stop)(struct seq_file___293 *, void *);
	void * (*next)(struct seq_file___293 *, void *, loff_t *);
	int (*show)(struct seq_file___293 *, void *);
};

struct cgroup_namespace___226 {
	refcount_t count;
	struct ns_common___9 ns;
	struct user_namespace___241 *user_ns;
	struct ucounts___241 *ucounts;
	struct css_set___226 *root_cset;
};

struct ucounts___241 {
	struct hlist_node node;
	struct user_namespace___241 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___227;

struct bpf_map_ops___226 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___227 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___227 *, struct file___345 *);
	void (*map_free)(struct bpf_map___227 *);
	int (*map_get_next_key)(struct bpf_map___227 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___227 *);
	void * (*map_lookup_elem)(struct bpf_map___227 *, void *);
	int (*map_update_elem)(struct bpf_map___227 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___227 *, void *);
	int (*map_push_elem)(struct bpf_map___227 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___227 *, void *);
	int (*map_peek_elem)(struct bpf_map___227 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___227 *, struct file___345 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___227 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___227 *, void *, struct seq_file___293 *);
	int (*map_check_btf)(const struct bpf_map___227 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___227 {
	const struct bpf_map_ops___226 *ops;
	struct bpf_map___227 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___320 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___226;

typedef void (*kthread_work_func_t___226)(struct kthread_work___226 *);

struct kthread_worker___226;

struct kthread_work___226 {
	struct list_head node;
	kthread_work_func_t___226 func;
	struct kthread_worker___226 *worker;
	int canceling;
};

struct kthread_worker___226 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___346 *task;
	struct kthread_work___226 *current_work;
};

struct kthread_delayed_work___226 {
	struct kthread_work___226 work;
	struct timer_list timer;
};

struct psi_group___226 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___226 *poll_kworker;
	struct kthread_delayed_work___226 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___226;

struct cgroup_rstat_cpu___226;

struct cgroup___226 {
	struct cgroup_subsys_state___226 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___339 *kn;
	struct cgroup_file___226 procs_file;
	struct cgroup_file___226 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___226 *subsys[13];
	struct cgroup_root___226 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___226 *dom_cgrp;
	struct cgroup_rstat_cpu___226 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___37 bpf;
	atomic_t congestion_count;
	struct cgroup___226 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___226 psi;
	int ancestor_ids[0];
};

struct cftype___226;

struct cgroup_subsys___226 {
	struct cgroup_subsys_state___226 * (*css_alloc)(struct cgroup_subsys_state___226 *);
	int (*css_online)(struct cgroup_subsys_state___226 *);
	void (*css_offline)(struct cgroup_subsys_state___226 *);
	void (*css_released)(struct cgroup_subsys_state___226 *);
	void (*css_free)(struct cgroup_subsys_state___226 *);
	void (*css_reset)(struct cgroup_subsys_state___226 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___226 *, int);
	int (*css_extra_stat_show)(struct seq_file___293 *, struct cgroup_subsys_state___226 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___346 *);
	void (*cancel_fork)(struct task_struct___346 *);
	void (*fork)(struct task_struct___346 *);
	void (*exit)(struct task_struct___346 *);
	void (*free)(struct task_struct___346 *);
	void (*bind)(struct cgroup_subsys_state___226 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___226 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___226 *dfl_cftypes;
	struct cftype___226 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___226 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___226 *updated_children;
	struct cgroup___226 *updated_next;
};

struct cgroup_root___226 {
	struct kernfs_root___338 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___226 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___226 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___226 *ss;
	struct list_head node;
	struct kernfs_ops___338 *kf_ops;
	int (*open)(struct kernfs_open_file___338 *);
	void (*release)(struct kernfs_open_file___338 *);
	u64 (*read_u64)(struct cgroup_subsys_state___226 *, struct cftype___226 *);
	s64 (*read_s64)(struct cgroup_subsys_state___226 *, struct cftype___226 *);
	int (*seq_show)(struct seq_file___293 *, void *);
	void * (*seq_start)(struct seq_file___293 *, loff_t *);
	void * (*seq_next)(struct seq_file___293 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___293 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___226 *, struct cftype___226 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___226 *, struct cftype___226 *, s64);
	ssize_t (*write)(struct kernfs_open_file___338 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___338 *, struct poll_table_struct___6 *);
};

typedef void compound_page_dtor___333(struct page___346 *);

struct bdi_writeback_congested___163 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___163 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___163 {
	struct bio___163 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___165 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___165 bip_inline_vecs[0];
};

struct bio_set___163 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___163 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___129 {
	struct mem_cgroup___129 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___129 {
	struct lruvec___345 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___129 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___129 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct node___202 {
	struct device___312 dev;
};

struct of_genpd_provider {
	struct list_head link;
	struct device_node___80 *node;
	genpd_xlate_t xlate;
	void *data;
};

struct gpd_dev_ops___2 {
	int (*start)(struct device___304 *);
	int (*stop)(struct device___304 *);
};

struct genpd_power_state___2 {
	s64 power_off_latency_ns;
	s64 power_on_latency_ns;
	s64 residency_ns;
	struct fwnode_handle___232 *fwnode;
	ktime_t idle_time;
};

struct genpd_lock_ops___2;

struct generic_pm_domain___2 {
	struct device___304 dev;
	struct dev_pm_domain___304 domain;
	struct list_head gpd_list_node;
	struct list_head master_links;
	struct list_head slave_links;
	struct list_head dev_list;
	struct dev_power_governor___4 *gov;
	struct work_struct power_off_work;
	struct fwnode_handle___232 *provider;
	bool has_provider;
	const char *name;
	atomic_t sd_count;
	enum gpd_status status;
	unsigned int device_count;
	unsigned int suspended_count;
	unsigned int prepared_count;
	unsigned int performance_state;
	int (*power_off)(struct generic_pm_domain___2 *);
	int (*power_on)(struct generic_pm_domain___2 *);
	unsigned int (*opp_to_performance_state)(struct generic_pm_domain___2 *, struct dev_pm_opp *);
	int (*set_performance_state)(struct generic_pm_domain___2 *, unsigned int);
	struct gpd_dev_ops___2 dev_ops;
	s64 max_off_time_ns;
	bool max_off_time_changed;
	bool cached_power_down_ok;
	int (*attach_dev)(struct generic_pm_domain___2 *, struct device___304 *);
	void (*detach_dev)(struct generic_pm_domain___2 *, struct device___304 *);
	unsigned int flags;
	struct genpd_power_state___2 *states;
	unsigned int state_count;
	unsigned int state_idx;
	void *free;
	ktime_t on_time;
	ktime_t accounting_time;
	const struct genpd_lock_ops___2 *lock_ops;
	union {
		struct mutex mlock;
		struct {
			spinlock_t slock;
			long unsigned int lock_flags;
		};
	};
};

struct gpd_link___2 {
	struct generic_pm_domain___2 *master;
	struct list_head master_node;
	struct generic_pm_domain___2 *slave;
	struct list_head slave_node;
};

struct generic_pm_domain_data___2 {
	struct pm_domain_data___4 base;
	struct gpd_timing_data td;
	struct notifier_block nb;
	unsigned int performance_state;
	void *data;
};

struct pm_clk_notifier_block {
	struct notifier_block nb;
	struct dev_pm_domain___272 *pm_domain;
	char *con_ids[0];
};

enum pce_status {
	PCE_STATUS_NONE = 0,
	PCE_STATUS_ACQUIRED = 1,
	PCE_STATUS_ENABLED = 2,
	PCE_STATUS_ERROR = 3,
};

struct pm_clock_entry {
	struct list_head node;
	char *con_id;
	struct clk *clk;
	enum pce_status status;
};

struct firmware_fallback_config {
	unsigned int force_sysfs_fallback;
	unsigned int ignore_sysfs_fallback;
	int old_timeout;
	int loading_timeout;
};

struct module___283;

struct file___346;

struct kiocb___346;

struct vm_area_struct___347;

struct inode___346;

struct file_lock___346;

struct page___347;

struct seq_file___294;

struct file_operations___346 {
	struct module___283 *owner;
	loff_t (*llseek)(struct file___346 *, loff_t, int);
	ssize_t (*read)(struct file___346 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___346 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___346 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___346 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___346 *, bool);
	int (*iterate)(struct file___346 *, struct dir_context *);
	int (*iterate_shared)(struct file___346 *, struct dir_context *);
	__poll_t (*poll)(struct file___346 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___346 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___346 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___346 *, struct vm_area_struct___347 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___346 *, struct file___346 *);
	int (*flush)(struct file___346 *, fl_owner_t);
	int (*release)(struct inode___346 *, struct file___346 *);
	int (*fsync)(struct file___346 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___346 *, int);
	int (*lock)(struct file___346 *, int, struct file_lock___346 *);
	ssize_t (*sendpage)(struct file___346 *, struct page___347 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___346 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___346 *, int, struct file_lock___346 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___346 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___346 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___346 *, long int, struct file_lock___346 **, void **);
	long int (*fallocate)(struct file___346 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___294 *, struct file___346 *);
	ssize_t (*copy_file_range)(struct file___346 *, loff_t, struct file___346 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___346 *, loff_t, struct file___346 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___346 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___346 {
	u64 seqnum;
	struct vm_area_struct___347 *vmas[4];
};

struct page_frag___346 {
	struct page___347 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___346;

struct mem_cgroup___130;

struct cred___321;

struct nsproxy___272;

struct bio_list___164;

struct backing_dev_info___164;

struct css_set___227;

struct vm_struct___252;

struct task_struct___347 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___347 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___346 *mm;
	struct mm_struct___346 *active_mm;
	struct vmacache___346 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___347 *real_parent;
	struct task_struct___347 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___347 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___130 *active_memcg;
	long int rh_reserved2;
	struct pid___215 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___215 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___215 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___321 *ptracer_cred;
	const struct cred___321 *real_cred;
	const struct cred___321 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___272 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___347 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___164 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___164 *backing_dev_info;
	struct io_context___84 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___227 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___346 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___130 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___347 *oom_reaper_list;
	struct vm_struct___252 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___139 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___347 *pgtable_t___346;

struct address_space___345;

struct dev_pagemap___334;

struct page___347 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___345 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___347 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___346 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___346 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___334 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___130 *mem_cgroup;
};

struct pglist_data___346;

struct lruvec___346 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___346 *pgdat;
};

struct zone___346 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___346 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___346 {
	struct zone___346 *zone;
	int zone_idx;
};

struct zonelist___346 {
	struct zoneref___346 _zonerefs[25];
};

struct pglist_data___346 {
	struct zone___346 node_zones[3];
	struct zonelist___346 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___347 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___347 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___346 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___347 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___347 *owner;
};

struct secondary_data___347 {
	void *stack;
	struct task_struct___347 *task;
	long int status;
};

struct blocking_notifier_head___346 {
	struct rw_semaphore___347 rwsem;
	struct notifier_block *head;
};

struct key___321;

struct ucounts___242;

struct user_namespace___242 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___242 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___9 ns;
	long unsigned int flags;
	struct key___321 *persistent_keyring_register;
	struct rw_semaphore___347 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___242 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_root___339;

struct kernfs_elem_dir___339 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___339 *root;
};

struct kernfs_node___340;

struct kernfs_syscall_ops___339;

struct kernfs_root___339 {
	struct kernfs_node___340 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___339 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___339 {
	struct kernfs_node___340 *target_kn;
};

struct kernfs_ops___339;

struct kernfs_elem_attr___339 {
	const struct kernfs_ops___339 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___340 *notify_next;
};

struct kernfs_node___340 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___340 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___339 dir;
		struct kernfs_elem_symlink___339 symlink;
		struct kernfs_elem_attr___339 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___339;

struct kernfs_ops___339 {
	int (*open)(struct kernfs_open_file___339 *);
	void (*release)(struct kernfs_open_file___339 *);
	int (*seq_show)(struct seq_file___294 *, void *);
	void * (*seq_start)(struct seq_file___294 *, loff_t *);
	void * (*seq_next)(struct seq_file___294 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___294 *, void *);
	ssize_t (*read)(struct kernfs_open_file___339 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___339 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___339 *, struct vm_area_struct___347 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___339 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___339 {
	int (*remount_fs)(struct kernfs_root___339 *, int *, char *);
	int (*show_options)(struct seq_file___294 *, struct kernfs_root___339 *);
	int (*mkdir)(struct kernfs_node___340 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___340 *);
	int (*rename)(struct kernfs_node___340 *, struct kernfs_node___340 *, const char *);
	int (*show_path)(struct seq_file___294 *, struct kernfs_node___340 *, struct kernfs_root___339 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___293;

struct seq_file___294 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___293 *op;
	int poll_event;
	const struct file___346 *file;
	void *private;
};

struct vm_operations_struct___334;

struct kernfs_open_file___339 {
	struct kernfs_node___340 *kn;
	struct file___346 *file;
	struct seq_file___294 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___334 *vm_ops;
};

struct dentry___345;

struct path___346 {
	struct vfsmount *mnt;
	struct dentry___345 *dentry;
};

struct file___346 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___346 f_path;
	struct inode___346 *f_inode;
	const struct file_operations___346 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___215 f_owner;
	const struct cred___321 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___345 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___334;

struct vm_operations_struct___334 {
	void (*open)(struct vm_area_struct___347 *);
	void (*close)(struct vm_area_struct___347 *);
	int (*split)(struct vm_area_struct___347 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___347 *);
	vm_fault_t (*fault)(struct vm_fault___334 *);
	vm_fault_t (*huge_fault)(struct vm_fault___334 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___334 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___347 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___334 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___334 *);
	int (*access)(struct vm_area_struct___347 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___347 *);
	int (*set_policy)(struct vm_area_struct___347 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___347 *, long unsigned int);
	struct page___347 * (*find_special_page)(struct vm_area_struct___347 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_area_struct___347 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___347 *vm_next;
	struct vm_area_struct___347 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___346 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___334 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___346 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___333;

struct bin_attribute___309;

struct attribute_group___310 {
	const char *name;
	umode_t (*is_visible)(struct kobject___333 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___333 *, struct bin_attribute___309 *, int);
	struct attribute **attrs;
	struct bin_attribute___309 **bin_attrs;
};

struct kset___332;

struct kobj_type___332;

struct kobject___333 {
	const char *name;
	struct list_head entry;
	struct kobject___333 *parent;
	struct kset___332 *kset;
	struct kobj_type___332 *ktype;
	struct kernfs_node___340 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___309 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___346 *, struct kobject___333 *, struct bin_attribute___309 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___346 *, struct kobject___333 *, struct bin_attribute___309 *, char *, loff_t, size_t);
	int (*mmap)(struct file___346 *, struct kobject___333 *, struct bin_attribute___309 *, struct vm_area_struct___347 *);
};

struct sysfs_ops___332 {
	ssize_t (*show)(struct kobject___333 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___333 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___332;

struct kset___332 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___333 kobj;
	const struct kset_uevent_ops___332 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___332 {
	void (*release)(struct kobject___333 *);
	const struct sysfs_ops___332 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___27 * (*child_ns_type)(struct kobject___333 *);
	const void * (*namespace)(struct kobject___333 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___332 {
	int (* const filter)(struct kset___332 *, struct kobject___333 *);
	const char * (* const name)(struct kset___332 *, struct kobject___333 *);
	int (* const uevent)(struct kset___332 *, struct kobject___333 *, struct kobj_uevent_env *);
};

struct kobj_attribute___324 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___333 *, struct kobj_attribute___324 *, char *);
	ssize_t (*store)(struct kobject___333 *, struct kobj_attribute___324 *, const char *, size_t);
};

struct device___313;

struct dev_pm_ops___313 {
	int (*prepare)(struct device___313 *);
	void (*complete)(struct device___313 *);
	int (*suspend)(struct device___313 *);
	int (*resume)(struct device___313 *);
	int (*freeze)(struct device___313 *);
	int (*thaw)(struct device___313 *);
	int (*poweroff)(struct device___313 *);
	int (*restore)(struct device___313 *);
	int (*suspend_late)(struct device___313 *);
	int (*resume_early)(struct device___313 *);
	int (*freeze_late)(struct device___313 *);
	int (*thaw_early)(struct device___313 *);
	int (*poweroff_late)(struct device___313 *);
	int (*restore_early)(struct device___313 *);
	int (*suspend_noirq)(struct device___313 *);
	int (*resume_noirq)(struct device___313 *);
	int (*freeze_noirq)(struct device___313 *);
	int (*thaw_noirq)(struct device___313 *);
	int (*poweroff_noirq)(struct device___313 *);
	int (*restore_noirq)(struct device___313 *);
	int (*runtime_suspend)(struct device___313 *);
	int (*runtime_resume)(struct device___313 *);
	int (*runtime_idle)(struct device___313 *);
};

struct dev_pm_info___313 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___5 *subsys_data;
	void (*set_latency_tolerance)(struct device___313 *, s32);
	struct dev_pm_qos *qos;
};

struct device_private___8;

struct device_type___313;

struct bus_type___313;

struct device_driver___313;

struct dev_pm_domain___313;

struct class___313;

struct device___313 {
	struct device___313 *parent;
	struct device_private___8 *p;
	struct kobject___333 kobj;
	const char *init_name;
	const struct device_type___313 *type;
	struct mutex mutex;
	struct bus_type___313 *bus;
	struct device_driver___313 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___313 power;
	struct dev_pm_domain___313 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___313 *class;
	const struct attribute_group___310 **groups;
	void (*release)(struct device___313 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___313 {
	struct dev_pm_ops___313 ops;
	void (*detach)(struct device___313 *, bool);
	int (*activate)(struct device___313 *);
	void (*sync)(struct device___313 *);
	void (*dismiss)(struct device___313 *);
};

struct user_struct___321 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___321 *uid_keyring;
	struct key___321 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___346;

struct mm_struct___346 {
	struct {
		struct vm_area_struct___347 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___346 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___347 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___346 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___347 *owner;
		struct user_namespace___242 *user_ns;
		struct file___346 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___346 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup___227;

struct cgroup_subsys___227;

struct cgroup_subsys_state___227 {
	struct cgroup___227 *cgroup;
	struct cgroup_subsys___227 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___227 *parent;
};

struct cgroup_file___227 {
	struct kernfs_node___340 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___130;

struct mem_cgroup___130 {
	struct cgroup_subsys_state___227 css;
	struct mem_cgroup_id___2 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___227 events_file;
	struct cgroup_file___227 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___347 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___130 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cred___321 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___321 *session_keyring;
	struct key___321 *process_keyring;
	struct key___321 *thread_keyring;
	struct key___321 *request_key_auth;
	void *security;
	struct user_struct___321 *user;
	struct user_namespace___242 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___227;

struct nsproxy___272 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___227 *cgroup_ns;
};

struct bio___164;

struct bio_list___164 {
	struct bio___164 *head;
	struct bio___164 *tail;
};

struct bdi_writeback_congested___164;

struct bdi_writeback___164 {
	struct backing_dev_info___164 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___164 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___227 *memcg_css;
	struct cgroup_subsys_state___227 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___164 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___164 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___313 *dev;
	struct device___313 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___345 *debug_dir;
	struct dentry___345 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___227 {
	struct cgroup_subsys_state___227 *subsys[13];
	refcount_t refcount;
	struct css_set___227 *dom_cset;
	struct cgroup___227 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___227 *mg_src_cgrp;
	struct cgroup___227 *mg_dst_cgrp;
	struct css_set___227 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct vm_struct___252 {
	struct vm_struct___252 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___347 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct subsys_private___8;

struct bus_type___313 {
	const char *name;
	const char *dev_name;
	struct device___313 *dev_root;
	const struct attribute_group___310 **bus_groups;
	const struct attribute_group___310 **dev_groups;
	const struct attribute_group___310 **drv_groups;
	int (*match)(struct device___313 *, struct device_driver___313 *);
	int (*uevent)(struct device___313 *, struct kobj_uevent_env *);
	int (*probe)(struct device___313 *);
	int (*remove)(struct device___313 *);
	void (*shutdown)(struct device___313 *);
	int (*online)(struct device___313 *);
	int (*offline)(struct device___313 *);
	int (*suspend)(struct device___313 *, pm_message_t);
	int (*resume)(struct device___313 *);
	int (*num_vf)(struct device___313 *);
	int (*dma_configure)(struct device___313 *);
	const struct dev_pm_ops___313 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private___8 *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct driver_private___8;

struct device_driver___313 {
	const char *name;
	struct bus_type___313 *bus;
	struct module___283 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___313 *);
	int (*remove)(struct device___313 *);
	void (*shutdown)(struct device___313 *);
	int (*suspend)(struct device___313 *, pm_message_t);
	int (*resume)(struct device___313 *);
	const struct attribute_group___310 **groups;
	const struct dev_pm_ops___313 *pm;
	void (*coredump)(struct device___313 *);
	struct driver_private___8 *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct subsys_private___8 {
	struct kset___332 subsys;
	struct kset___332 *devices_kset;
	struct list_head interfaces;
	struct mutex mutex;
	struct kset___332 *drivers_kset;
	struct klist klist_devices;
	struct klist klist_drivers;
	struct blocking_notifier_head___346 bus_notifier;
	unsigned int drivers_autoprobe: 1;
	struct bus_type___313 *bus;
	struct kset___332 glue_dirs;
	struct class___313 *class;
};

struct device_type___313 {
	const char *name;
	const struct attribute_group___310 **groups;
	int (*uevent)(struct device___313 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___313 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___313 *);
	const struct dev_pm_ops___313 *pm;
};

struct module_kobject___280 {
	struct kobject___333 kobj;
	struct module___283 *mod;
	struct kobject___333 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___280 {
	struct module___283 *mod;
	struct latch_tree_node node;
};

struct module_layout___280 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___280 mtn;
};

struct module_attribute___280;

struct kernel_param___280;

struct module___283 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___280 mkobj;
	struct module_attribute___280 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___333 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___280 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___280 core_layout;
	struct module_layout___280 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct driver_private___8 {
	struct kobject___333 kobj;
	struct klist klist_devices;
	struct klist_node knode_bus;
	struct module_kobject___280 *mkobj;
	struct device_driver___313 *driver;
};

struct class___313 {
	const char *name;
	struct module___283 *owner;
	const struct attribute_group___310 **class_groups;
	const struct attribute_group___310 **dev_groups;
	struct kobject___333 *dev_kobj;
	int (*dev_uevent)(struct device___313 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___313 *, umode_t *);
	void (*class_release)(struct class___313 *);
	void (*dev_release)(struct device___313 *);
	int (*shutdown_pre)(struct device___313 *);
	const struct kobj_ns_type_operations___27 *ns_type;
	const void * (*namespace)(struct device___313 *);
	const struct dev_pm_ops___313 *pm;
	struct subsys_private___8 *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

typedef void (*dr_release_t___19)(struct device___313 *, void *);

struct device_private___8 {
	struct klist klist_children;
	struct klist_node knode_parent;
	struct klist_node knode_driver;
	struct klist_node knode_bus;
	struct list_head deferred_probe;
	struct device___313 *device;
};

struct kernel_param_ops___280 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___280 *);
	int (*get)(char *, const struct kernel_param___280 *);
	void (*free)(void *);
};

struct kparam_array___280;

struct kernel_param___280 {
	const char *name;
	struct module___283 *mod;
	const struct kernel_param_ops___280 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___280 *arr;
	};
};

struct kparam_array___280 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___280 *ops;
	void *elem;
};

struct module_attribute___280 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___280 *, struct module_kobject___280 *, char *);
	ssize_t (*store)(struct module_attribute___280 *, struct module_kobject___280 *, const char *, size_t);
	void (*setup)(struct module___283 *, const char *);
	int (*test)(struct module___283 *);
	void (*free)(struct module___283 *);
};

struct dentry_operations___345;

struct super_block___345;

struct dentry___345 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___345 *d_parent;
	struct qstr d_name;
	struct inode___346 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___345 *d_op;
	struct super_block___345 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___345;

struct address_space___345 {
	struct inode___346 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___347 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___345 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___345;

struct block_device___345;

struct inode___346 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___345 *i_op;
	struct super_block___345 *i_sb;
	struct address_space___345 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___347 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___164 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___346 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___345 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___345 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___345 {
	int (*d_revalidate)(struct dentry___345 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___345 *, unsigned int);
	int (*d_hash)(const struct dentry___345 *, struct qstr *);
	int (*d_compare)(const struct dentry___345 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___345 *);
	int (*d_init)(struct dentry___345 *);
	void (*d_release)(struct dentry___345 *);
	void (*d_prune)(struct dentry___345 *);
	void (*d_iput)(struct dentry___345 *, struct inode___346 *);
	char * (*d_dname)(struct dentry___345 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___346 *);
	int (*d_manage)(const struct path___346 *, bool);
	struct dentry___345 * (*d_real)(struct dentry___345 *, const struct inode___346 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___345;

struct mem_dqinfo___345 {
	struct quota_format_type___345 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___345;

struct quota_info___345 {
	unsigned int flags;
	struct rw_semaphore___347 dqio_sem;
	struct inode___346 *files[3];
	struct mem_dqinfo___345 info[3];
	const struct quota_format_ops___345 *ops[3];
};

struct rcuwait___345 {
	struct task_struct___347 *task;
};

struct percpu_rw_semaphore___345 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___347 rw_sem;
	struct rcuwait___345 writer;
	int readers_block;
};

struct sb_writers___345 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___345 rw_sem[3];
};

struct shrink_control___130;

struct shrinker___130 {
	long unsigned int (*count_objects)(struct shrinker___130 *, struct shrink_control___130 *);
	long unsigned int (*scan_objects)(struct shrinker___130 *, struct shrink_control___130 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___345;

struct super_operations___345;

struct dquot_operations___345;

struct quotactl_ops___345;

struct super_block___345 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___345 *s_type;
	const struct super_operations___345 *s_op;
	const struct dquot_operations___345 *dq_op;
	const struct quotactl_ops___345 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___345 *s_root;
	struct rw_semaphore___347 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___345 *s_bdev;
	struct backing_dev_info___164 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___345 s_dquot;
	struct sb_writers___345 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___345 *s_d_op;
	int cleancache_poolid;
	struct shrinker___130 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___242 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___130 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___130 *memcg;
};

typedef int (*dev_page_fault_t___334)(struct vm_area_struct___347 *, long unsigned int, const struct page___347 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___334)(struct page___347 *, void *);

struct dev_pagemap___334 {
	dev_page_fault_t___334 page_fault;
	dev_page_free_t___334 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___313 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___346 {
	struct task_struct___347 *task;
	struct core_thread___346 *next;
};

struct core_state___346 {
	atomic_t nr_threads;
	struct core_thread___346 dumper;
	struct completion startup;
};

struct vm_fault___334 {
	struct vm_area_struct___347 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___347 *cow_page;
	struct mem_cgroup___130 *memcg;
	struct page___347 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___346 prealloc_pte;
};

struct kiocb___346 {
	struct file___346 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___346 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___345 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___346 *ia_file;
};

struct dquot___345 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___345 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___345 {
	int qf_fmt_id;
	const struct quota_format_ops___345 *qf_ops;
	struct module___283 *qf_owner;
	struct quota_format_type___345 *qf_next;
};

struct quota_format_ops___345 {
	int (*check_quota_file)(struct super_block___345 *, int);
	int (*read_file_info)(struct super_block___345 *, int);
	int (*write_file_info)(struct super_block___345 *, int);
	int (*free_file_info)(struct super_block___345 *, int);
	int (*read_dqblk)(struct dquot___345 *);
	int (*commit_dqblk)(struct dquot___345 *);
	int (*release_dqblk)(struct dquot___345 *);
	int (*get_next_id)(struct super_block___345 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___345 {
	int (*write_dquot)(struct dquot___345 *);
	struct dquot___345 * (*alloc_dquot)(struct super_block___345 *, int);
	void (*destroy_dquot)(struct dquot___345 *);
	int (*acquire_dquot)(struct dquot___345 *);
	int (*release_dquot)(struct dquot___345 *);
	int (*mark_dirty)(struct dquot___345 *);
	int (*write_info)(struct super_block___345 *, int);
	qsize_t * (*get_reserved_space)(struct inode___346 *);
	int (*get_projid)(struct inode___346 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___346 *, qsize_t *);
	int (*get_next_id)(struct super_block___345 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___345 {
	int (*quota_on)(struct super_block___345 *, int, int, const struct path___346 *);
	int (*quota_off)(struct super_block___345 *, int);
	int (*quota_enable)(struct super_block___345 *, unsigned int);
	int (*quota_disable)(struct super_block___345 *, unsigned int);
	int (*quota_sync)(struct super_block___345 *, int);
	int (*set_info)(struct super_block___345 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___345 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___345 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___345 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___345 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___345 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___147;

struct swap_info_struct___87;

struct address_space_operations___345 {
	int (*writepage)(struct page___347 *, struct writeback_control___147 *);
	int (*readpage)(struct file___346 *, struct page___347 *);
	int (*writepages)(struct address_space___345 *, struct writeback_control___147 *);
	int (*set_page_dirty)(struct page___347 *);
	int (*readpages)(struct file___346 *, struct address_space___345 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___346 *, struct address_space___345 *, loff_t, unsigned int, unsigned int, struct page___347 **, void **);
	int (*write_end)(struct file___346 *, struct address_space___345 *, loff_t, unsigned int, unsigned int, struct page___347 *, void *);
	sector_t (*bmap)(struct address_space___345 *, sector_t);
	void (*invalidatepage)(struct page___347 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___347 *, gfp_t);
	void (*freepage)(struct page___347 *);
	ssize_t (*direct_IO)(struct kiocb___346 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___345 *, struct page___347 *, struct page___347 *, enum migrate_mode);
	bool (*isolate_page)(struct page___347 *, isolate_mode_t);
	void (*putback_page)(struct page___347 *);
	int (*launder_page)(struct page___347 *);
	int (*is_partially_uptodate)(struct page___347 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___347 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___345 *, struct page___347 *);
	int (*swap_activate)(struct swap_info_struct___87 *, struct file___346 *, sector_t *);
	void (*swap_deactivate)(struct file___346 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___147 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___164 *wb;
	struct inode___346 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct swap_info_struct___87 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___345 *bdev;
	struct file___346 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___345 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___346 *bd_inode;
	struct super_block___345 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___345 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___164 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___345 {
	struct dentry___345 * (*lookup)(struct inode___346 *, struct dentry___345 *, unsigned int);
	const char * (*get_link)(struct dentry___345 *, struct inode___346 *, struct delayed_call *);
	int (*permission)(struct inode___346 *, int);
	struct posix_acl * (*get_acl)(struct inode___346 *, int);
	int (*readlink)(struct dentry___345 *, char *, int);
	int (*create)(struct inode___346 *, struct dentry___345 *, umode_t, bool);
	int (*link)(struct dentry___345 *, struct inode___346 *, struct dentry___345 *);
	int (*unlink)(struct inode___346 *, struct dentry___345 *);
	int (*symlink)(struct inode___346 *, struct dentry___345 *, const char *);
	int (*mkdir)(struct inode___346 *, struct dentry___345 *, umode_t);
	int (*rmdir)(struct inode___346 *, struct dentry___345 *);
	int (*mknod)(struct inode___346 *, struct dentry___345 *, umode_t, dev_t);
	int (*rename)(struct inode___346 *, struct dentry___345 *, struct inode___346 *, struct dentry___345 *, unsigned int);
	int (*setattr)(struct dentry___345 *, struct iattr___345 *);
	int (*getattr)(const struct path___346 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___345 *, char *, size_t);
	int (*fiemap)(struct inode___346 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___346 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___346 *, struct dentry___345 *, struct file___346 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___346 *, struct dentry___345 *, umode_t);
	int (*set_acl)(struct inode___346 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___345 {
	void (*fl_copy_lock)(struct file_lock___346 *, struct file_lock___346 *);
	void (*fl_release_private)(struct file_lock___346 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___345;

struct lock_manager_operations___345;

struct file_lock___346 {
	struct file_lock___346 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___346 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___345 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___345 *fl_ops;
	const struct lock_manager_operations___345 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___345 {
	int (*lm_compare_owner)(struct file_lock___346 *, struct file_lock___346 *);
	long unsigned int (*lm_owner_key)(struct file_lock___346 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___346 *);
	int (*lm_grant)(struct file_lock___346 *, int);
	bool (*lm_break)(struct file_lock___346 *);
	int (*lm_change)(struct file_lock___346 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___346 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___345 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___345 *fa_next;
	struct file___346 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___345 {
	const char *name;
	int fs_flags;
	struct dentry___345 * (*mount)(struct file_system_type___345 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___345 *);
	struct module___283 *owner;
	struct file_system_type___345 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___345 {
	struct inode___346 * (*alloc_inode)(struct super_block___345 *);
	void (*destroy_inode)(struct inode___346 *);
	void (*dirty_inode)(struct inode___346 *, int);
	int (*write_inode)(struct inode___346 *, struct writeback_control___147 *);
	int (*drop_inode)(struct inode___346 *);
	void (*evict_inode)(struct inode___346 *);
	void (*put_super)(struct super_block___345 *);
	int (*sync_fs)(struct super_block___345 *, int);
	int (*freeze_super)(struct super_block___345 *);
	int (*freeze_fs)(struct super_block___345 *);
	int (*thaw_super)(struct super_block___345 *);
	int (*unfreeze_fs)(struct super_block___345 *);
	int (*statfs)(struct dentry___345 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___345 *, int *, char *);
	void (*umount_begin)(struct super_block___345 *);
	int (*show_options)(struct seq_file___294 *, struct dentry___345 *);
	int (*show_devname)(struct seq_file___294 *, struct dentry___345 *);
	int (*show_path)(struct seq_file___294 *, struct dentry___345 *);
	int (*show_stats)(struct seq_file___294 *, struct dentry___345 *);
	ssize_t (*quota_read)(struct super_block___345 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___345 *, int, const char *, size_t, loff_t);
	struct dquot___345 ** (*get_dquots)(struct inode___346 *);
	int (*bdev_try_to_free_page)(struct super_block___345 *, struct page___347 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___345 *, struct shrink_control___130 *);
	long int (*free_cached_objects)(struct super_block___345 *, struct shrink_control___130 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___164(struct bio___164 *);

struct bio_vec___166 {
	struct page___347 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___164;

struct bio_set___164;

struct bio___164 {
	struct bio___164 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___164 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___164 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___166 *bi_io_vec;
	struct bio_set___164 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___166 bi_inline_vecs[0];
};

typedef void compound_page_dtor___334(struct page___347 *);

struct firmware {
	size_t size;
	const u8 *data;
	struct page___347 **pages;
	void *priv;
};

struct builtin_fw {
	char *name;
	void *data;
	long unsigned int size;
};

typedef int (*key_restrict_link_func_t___322)(struct key___321 *, const struct key_type *, const union key_payload *, struct key___321 *);

struct key_restriction___321;

struct key___321 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___347 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___321 *restrict_link;
};

struct key_restriction___321 {
	key_restrict_link_func_t___322 check;
	struct key___321 *key;
	struct key_type *keytype;
};

struct seq_operations___293 {
	void * (*start)(struct seq_file___294 *, loff_t *);
	void (*stop)(struct seq_file___294 *, void *);
	void * (*next)(struct seq_file___294 *, void *, loff_t *);
	int (*show)(struct seq_file___294 *, void *);
};

struct cgroup_namespace___227 {
	refcount_t count;
	struct ns_common___9 ns;
	struct user_namespace___242 *user_ns;
	struct ucounts___242 *ucounts;
	struct css_set___227 *root_cset;
};

struct ucounts___242 {
	struct hlist_node node;
	struct user_namespace___242 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___228;

struct bpf_map_ops___227 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___228 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___228 *, struct file___346 *);
	void (*map_free)(struct bpf_map___228 *);
	int (*map_get_next_key)(struct bpf_map___228 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___228 *);
	void * (*map_lookup_elem)(struct bpf_map___228 *, void *);
	int (*map_update_elem)(struct bpf_map___228 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___228 *, void *);
	int (*map_push_elem)(struct bpf_map___228 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___228 *, void *);
	int (*map_peek_elem)(struct bpf_map___228 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___228 *, struct file___346 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___228 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___228 *, void *, struct seq_file___294 *);
	int (*map_check_btf)(const struct bpf_map___228 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___228 {
	const struct bpf_map_ops___227 *ops;
	struct bpf_map___228 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___321 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___227;

typedef void (*kthread_work_func_t___227)(struct kthread_work___227 *);

struct kthread_worker___227;

struct kthread_work___227 {
	struct list_head node;
	kthread_work_func_t___227 func;
	struct kthread_worker___227 *worker;
	int canceling;
};

struct kthread_worker___227 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___347 *task;
	struct kthread_work___227 *current_work;
};

struct kthread_delayed_work___227 {
	struct kthread_work___227 work;
	struct timer_list timer;
};

struct psi_group___227 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___227 *poll_kworker;
	struct kthread_delayed_work___227 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___227;

struct cgroup_rstat_cpu___227;

struct cgroup___227 {
	struct cgroup_subsys_state___227 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___340 *kn;
	struct cgroup_file___227 procs_file;
	struct cgroup_file___227 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___227 *subsys[13];
	struct cgroup_root___227 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___227 *dom_cgrp;
	struct cgroup_rstat_cpu___227 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___37 bpf;
	atomic_t congestion_count;
	struct cgroup___227 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___227 psi;
	int ancestor_ids[0];
};

struct cftype___227;

struct cgroup_subsys___227 {
	struct cgroup_subsys_state___227 * (*css_alloc)(struct cgroup_subsys_state___227 *);
	int (*css_online)(struct cgroup_subsys_state___227 *);
	void (*css_offline)(struct cgroup_subsys_state___227 *);
	void (*css_released)(struct cgroup_subsys_state___227 *);
	void (*css_free)(struct cgroup_subsys_state___227 *);
	void (*css_reset)(struct cgroup_subsys_state___227 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___227 *, int);
	int (*css_extra_stat_show)(struct seq_file___294 *, struct cgroup_subsys_state___227 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___347 *);
	void (*cancel_fork)(struct task_struct___347 *);
	void (*fork)(struct task_struct___347 *);
	void (*exit)(struct task_struct___347 *);
	void (*free)(struct task_struct___347 *);
	void (*bind)(struct cgroup_subsys_state___227 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___227 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___227 *dfl_cftypes;
	struct cftype___227 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___227 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___227 *updated_children;
	struct cgroup___227 *updated_next;
};

struct cgroup_root___227 {
	struct kernfs_root___339 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___227 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___227 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___227 *ss;
	struct list_head node;
	struct kernfs_ops___339 *kf_ops;
	int (*open)(struct kernfs_open_file___339 *);
	void (*release)(struct kernfs_open_file___339 *);
	u64 (*read_u64)(struct cgroup_subsys_state___227 *, struct cftype___227 *);
	s64 (*read_s64)(struct cgroup_subsys_state___227 *, struct cftype___227 *);
	int (*seq_show)(struct seq_file___294 *, void *);
	void * (*seq_start)(struct seq_file___294 *, loff_t *);
	void * (*seq_next)(struct seq_file___294 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___294 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___227 *, struct cftype___227 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___227 *, struct cftype___227 *, s64);
	ssize_t (*write)(struct kernfs_open_file___339 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___339 *, struct poll_table_struct___6 *);
};

struct bdi_writeback_congested___164 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___164 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___164 {
	struct bio___164 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___166 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___166 bip_inline_vecs[0];
};

struct bio_set___164 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___164 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___130 {
	struct mem_cgroup___130 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___130 {
	struct lruvec___346 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___130 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___130 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct node___203 {
	struct device___313 dev;
};

enum fw_opt {
	FW_OPT_UEVENT = 1,
	FW_OPT_NOWAIT = 2,
	FW_OPT_USERHELPER = 4,
	FW_OPT_NO_WARN = 8,
	FW_OPT_NOCACHE = 16,
	FW_OPT_NOFALLBACK = 32,
};

enum fw_status {
	FW_STATUS_UNKNOWN = 0,
	FW_STATUS_LOADING = 1,
	FW_STATUS_DONE = 2,
	FW_STATUS_ABORTED = 3,
};

struct fw_state {
	struct completion completion;
	enum fw_status status;
};

struct firmware_cache;

struct fw_priv {
	struct kref ref;
	struct list_head list;
	struct firmware_cache *fwc;
	struct fw_state fw_st;
	void *data;
	size_t size;
	size_t allocated_size;
	bool is_paged_buf;
	bool need_uevent;
	struct page___347 **pages;
	int nr_pages;
	int page_array_size;
	struct list_head pending_list;
	const char *fw_name;
};

struct firmware_cache {
	spinlock_t lock;
	struct list_head head;
	int state;
	spinlock_t name_lock;
	struct list_head fw_names;
	struct delayed_work work;
	struct notifier_block pm_notify;
};

struct fw_cache_entry {
	struct list_head list;
	const char *name;
};

struct fw_name_devm {
	long unsigned int magic;
	const char *name;
};

struct firmware_work {
	struct work_struct work;
	struct module___283 *module;
	const char *name;
	struct device___313 *device;
	void *context;
	void (*cont)(const struct firmware *, void *);
	enum fw_opt opt_flags;
};

struct firmware___2 {
	size_t size;
	const u8 *data;
	struct page___332 **pages;
	void *priv;
};

struct class_attribute___3 {
	struct attribute attr;
	ssize_t (*show)(struct class___297 *, struct class_attribute___3 *, char *);
	ssize_t (*store)(struct class___297 *, struct class_attribute___3 *, const char *, size_t);
};

struct firmware_cache___2;

struct fw_priv___2 {
	struct kref ref;
	struct list_head list;
	struct firmware_cache___2 *fwc;
	struct fw_state fw_st;
	void *data;
	size_t size;
	size_t allocated_size;
	bool is_paged_buf;
	bool need_uevent;
	struct page___332 **pages;
	int nr_pages;
	int page_array_size;
	struct list_head pending_list;
	const char *fw_name;
};

struct fw_sysfs {
	bool nowait;
	struct device___297 dev;
	struct fw_priv___2 *fw_priv;
	struct firmware___2 *fw;
};

struct device_attribute___33 {
	struct attribute attr;
	ssize_t (*show)(struct device___303 *, struct device_attribute___33 *, char *);
	ssize_t (*store)(struct device___303 *, struct device_attribute___33 *, const char *, size_t);
};

typedef void (*node_registration_func_t)(struct node___195 *);

struct node_attr {
	struct device_attribute___33 attr;
	enum node_states state;
};

typedef void (*dr_release_t___20)(struct device___62 *, void *);

enum regcache_type {
	REGCACHE_NONE = 0,
	REGCACHE_RBTREE = 1,
	REGCACHE_COMPRESSED = 2,
	REGCACHE_FLAT = 3,
};

struct reg_default {
	unsigned int reg;
	unsigned int def;
};

struct reg_sequence {
	unsigned int reg;
	unsigned int def;
	unsigned int delay_us;
};

enum regmap_endian {
	REGMAP_ENDIAN_DEFAULT = 0,
	REGMAP_ENDIAN_BIG = 1,
	REGMAP_ENDIAN_LITTLE = 2,
	REGMAP_ENDIAN_NATIVE = 3,
};

struct regmap_range {
	unsigned int range_min;
	unsigned int range_max;
};

struct regmap_access_table {
	const struct regmap_range *yes_ranges;
	unsigned int n_yes_ranges;
	const struct regmap_range *no_ranges;
	unsigned int n_no_ranges;
};

typedef void (*regmap_lock)(void *);

typedef void (*regmap_unlock)(void *);

struct regmap_range_cfg;

struct regmap_config {
	const char *name;
	int reg_bits;
	int reg_stride;
	int pad_bits;
	int val_bits;
	bool (*writeable_reg)(struct device___62 *, unsigned int);
	bool (*readable_reg)(struct device___62 *, unsigned int);
	bool (*volatile_reg)(struct device___62 *, unsigned int);
	bool (*precious_reg)(struct device___62 *, unsigned int);
	bool disable_locking;
	regmap_lock lock;
	regmap_unlock unlock;
	void *lock_arg;
	int (*reg_read)(void *, unsigned int, unsigned int *);
	int (*reg_write)(void *, unsigned int, unsigned int);
	bool fast_io;
	unsigned int max_register;
	const struct regmap_access_table *wr_table;
	const struct regmap_access_table *rd_table;
	const struct regmap_access_table *volatile_table;
	const struct regmap_access_table *precious_table;
	const struct reg_default *reg_defaults;
	unsigned int num_reg_defaults;
	enum regcache_type cache_type;
	const void *reg_defaults_raw;
	unsigned int num_reg_defaults_raw;
	long unsigned int read_flag_mask;
	long unsigned int write_flag_mask;
	bool zero_flag_mask;
	bool use_single_read;
	bool use_single_write;
	bool can_multi_write;
	enum regmap_endian reg_format_endian;
	enum regmap_endian val_format_endian;
	const struct regmap_range_cfg *ranges;
	unsigned int num_ranges;
	bool use_hwlock;
	unsigned int hwlock_id;
	unsigned int hwlock_mode;
};

struct regmap_range_cfg {
	const char *name;
	unsigned int range_min;
	unsigned int range_max;
	unsigned int selector_reg;
	unsigned int selector_mask;
	int selector_shift;
	unsigned int window_start;
	unsigned int window_len;
};

typedef int (*regmap_hw_write)(void *, const void *, size_t);

typedef int (*regmap_hw_gather_write)(void *, const void *, size_t, const void *, size_t);

struct regmap_async;

typedef int (*regmap_hw_async_write)(void *, const void *, size_t, const void *, size_t, struct regmap_async *);

struct regmap___2;

struct regmap_async {
	struct list_head list;
	struct regmap___2 *map;
	void *work_buf;
};

typedef int (*regmap_hw_read)(void *, const void *, size_t, void *, size_t);

typedef int (*regmap_hw_reg_read)(void *, unsigned int, unsigned int *);

typedef int (*regmap_hw_reg_write)(void *, unsigned int, unsigned int);

typedef int (*regmap_hw_reg_update_bits)(void *, unsigned int, unsigned int, unsigned int);

typedef struct regmap_async * (*regmap_hw_async_alloc)();

typedef void (*regmap_hw_free_context)(void *);

struct regmap_bus {
	bool fast_io;
	regmap_hw_write write;
	regmap_hw_gather_write gather_write;
	regmap_hw_async_write async_write;
	regmap_hw_reg_write reg_write;
	regmap_hw_reg_update_bits reg_update_bits;
	regmap_hw_read read;
	regmap_hw_reg_read reg_read;
	regmap_hw_free_context free_context;
	regmap_hw_async_alloc async_alloc;
	u8 read_flag_mask;
	enum regmap_endian reg_format_endian_default;
	enum regmap_endian val_format_endian_default;
	size_t max_raw_read;
	size_t max_raw_write;
};

struct reg_field {
	unsigned int reg;
	unsigned int lsb;
	unsigned int msb;
	unsigned int id_size;
	unsigned int id_offset;
};

struct regmap_format {
	size_t buf_size;
	size_t reg_bytes;
	size_t pad_bytes;
	size_t val_bytes;
	void (*format_write)(struct regmap___2 *, unsigned int, unsigned int);
	void (*format_reg)(void *, unsigned int, unsigned int);
	void (*format_val)(void *, unsigned int, unsigned int);
	unsigned int (*parse_val)(const void *);
	void (*parse_inplace)(void *);
};

struct hwspinlock;

struct regcache_ops;

struct regmap___2 {
	union {
		struct mutex mutex;
		struct {
			spinlock_t spinlock;
			long unsigned int spinlock_flags;
		};
	};
	regmap_lock lock;
	regmap_unlock unlock;
	void *lock_arg;
	gfp_t alloc_flags;
	struct device___62 *dev;
	void *work_buf;
	struct regmap_format format;
	const struct regmap_bus *bus;
	void *bus_context;
	const char *name;
	bool async;
	spinlock_t async_lock;
	wait_queue_head_t async_waitq;
	struct list_head async_list;
	struct list_head async_free;
	int async_ret;
	bool debugfs_disable;
	struct dentry___68 *debugfs;
	const char *debugfs_name;
	unsigned int debugfs_reg_len;
	unsigned int debugfs_val_len;
	unsigned int debugfs_tot_len;
	struct list_head debugfs_off_cache;
	struct mutex cache_lock;
	unsigned int max_register;
	bool (*writeable_reg)(struct device___62 *, unsigned int);
	bool (*readable_reg)(struct device___62 *, unsigned int);
	bool (*volatile_reg)(struct device___62 *, unsigned int);
	bool (*precious_reg)(struct device___62 *, unsigned int);
	const struct regmap_access_table *wr_table;
	const struct regmap_access_table *rd_table;
	const struct regmap_access_table *volatile_table;
	const struct regmap_access_table *precious_table;
	int (*reg_read)(void *, unsigned int, unsigned int *);
	int (*reg_write)(void *, unsigned int, unsigned int);
	int (*reg_update_bits)(void *, unsigned int, unsigned int, unsigned int);
	bool defer_caching;
	long unsigned int read_flag_mask;
	long unsigned int write_flag_mask;
	int reg_shift;
	int reg_stride;
	int reg_stride_order;
	const struct regcache_ops *cache_ops;
	enum regcache_type cache_type;
	unsigned int cache_size_raw;
	unsigned int cache_word_size;
	unsigned int num_reg_defaults;
	unsigned int num_reg_defaults_raw;
	bool cache_only;
	bool cache_bypass;
	bool cache_free;
	struct reg_default *reg_defaults;
	const void *reg_defaults_raw;
	void *cache;
	bool cache_dirty;
	bool no_sync_defaults;
	struct reg_sequence *patch;
	int patch_regs;
	bool use_single_read;
	bool use_single_write;
	bool can_multi_write;
	size_t max_raw_read;
	size_t max_raw_write;
	struct rb_root range_tree;
	void *selector_work_buf;
	struct hwspinlock *hwlock;
};

struct regcache_ops {
	const char *name;
	enum regcache_type type;
	int (*init)(struct regmap___2 *);
	int (*exit)(struct regmap___2 *);
	void (*debugfs_init)(struct regmap___2 *);
	int (*read)(struct regmap___2 *, unsigned int, unsigned int *);
	int (*write)(struct regmap___2 *, unsigned int, unsigned int);
	int (*sync)(struct regmap___2 *, unsigned int, unsigned int);
	int (*drop)(struct regmap___2 *, unsigned int, unsigned int);
};

struct regmap_range_node {
	struct rb_node node;
	const char *name;
	struct regmap___2 *map;
	unsigned int range_min;
	unsigned int range_max;
	unsigned int selector_reg;
	unsigned int selector_mask;
	int selector_shift;
	unsigned int window_start;
	unsigned int window_len;
};

struct regmap_field {
	struct regmap___2 *regmap;
	unsigned int mask;
	unsigned int shift;
	unsigned int reg;
	unsigned int id_size;
	unsigned int id_offset;
};

struct trace_event_file___51;

struct trace_event_buffer___43 {
	struct ring_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___51 *trace_file;
	void *entry;
	long unsigned int flags;
	int pc;
};

struct trace_event_file___51 {
	struct list_head list;
	struct trace_event_call___37 *event_call;
	struct event_filter *filter;
	struct dentry___68 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_regmap_reg {
	struct trace_entry ent;
	u32 __data_loc_name;
	unsigned int reg;
	unsigned int val;
	char __data[0];
};

struct trace_event_raw_regmap_block {
	struct trace_entry ent;
	u32 __data_loc_name;
	unsigned int reg;
	int count;
	char __data[0];
};

struct trace_event_raw_regcache_sync {
	struct trace_entry ent;
	u32 __data_loc_name;
	u32 __data_loc_status;
	u32 __data_loc_type;
	int type;
	char __data[0];
};

struct trace_event_raw_regmap_bool {
	struct trace_entry ent;
	u32 __data_loc_name;
	int flag;
	char __data[0];
};

struct trace_event_raw_regmap_async {
	struct trace_entry ent;
	u32 __data_loc_name;
	char __data[0];
};

struct trace_event_raw_regcache_drop_region {
	struct trace_entry ent;
	u32 __data_loc_name;
	unsigned int from;
	unsigned int to;
	char __data[0];
};

struct trace_event_data_offsets_regmap_reg {
	u32 name;
};

struct trace_event_data_offsets_regmap_block {
	u32 name;
};

struct trace_event_data_offsets_regcache_sync {
	u32 name;
	u32 status;
	u32 type;
};

struct trace_event_data_offsets_regmap_bool {
	u32 name;
};

struct trace_event_data_offsets_regmap_async {
	u32 name;
};

struct trace_event_data_offsets_regcache_drop_region {
	u32 name;
};

struct regmap_async___2;

typedef int (*regmap_hw_async_write___2)(void *, const void *, size_t, const void *, size_t, struct regmap_async___2 *);

struct regmap___3;

struct regmap_async___2 {
	struct list_head list;
	struct regmap___3 *map;
	void *work_buf;
};

typedef struct regmap_async___2 * (*regmap_hw_async_alloc___2)();

struct regmap_bus___2 {
	bool fast_io;
	regmap_hw_write write;
	regmap_hw_gather_write gather_write;
	regmap_hw_async_write___2 async_write;
	regmap_hw_reg_write reg_write;
	regmap_hw_reg_update_bits reg_update_bits;
	regmap_hw_read read;
	regmap_hw_reg_read reg_read;
	regmap_hw_free_context free_context;
	regmap_hw_async_alloc___2 async_alloc;
	u8 read_flag_mask;
	enum regmap_endian reg_format_endian_default;
	enum regmap_endian val_format_endian_default;
	size_t max_raw_read;
	size_t max_raw_write;
};

struct regmap_format___2 {
	size_t buf_size;
	size_t reg_bytes;
	size_t pad_bytes;
	size_t val_bytes;
	void (*format_write)(struct regmap___3 *, unsigned int, unsigned int);
	void (*format_reg)(void *, unsigned int, unsigned int);
	void (*format_val)(void *, unsigned int, unsigned int);
	unsigned int (*parse_val)(const void *);
	void (*parse_inplace)(void *);
};

struct regcache_ops___2;

struct regmap___3 {
	union {
		struct mutex mutex;
		struct {
			spinlock_t spinlock;
			long unsigned int spinlock_flags;
		};
	};
	regmap_lock lock;
	regmap_unlock unlock;
	void *lock_arg;
	gfp_t alloc_flags;
	struct device___312 *dev;
	void *work_buf;
	struct regmap_format___2 format;
	const struct regmap_bus___2 *bus;
	void *bus_context;
	const char *name;
	bool async;
	spinlock_t async_lock;
	wait_queue_head_t async_waitq;
	struct list_head async_list;
	struct list_head async_free;
	int async_ret;
	bool debugfs_disable;
	struct dentry___344 *debugfs;
	const char *debugfs_name;
	unsigned int debugfs_reg_len;
	unsigned int debugfs_val_len;
	unsigned int debugfs_tot_len;
	struct list_head debugfs_off_cache;
	struct mutex cache_lock;
	unsigned int max_register;
	bool (*writeable_reg)(struct device___312 *, unsigned int);
	bool (*readable_reg)(struct device___312 *, unsigned int);
	bool (*volatile_reg)(struct device___312 *, unsigned int);
	bool (*precious_reg)(struct device___312 *, unsigned int);
	const struct regmap_access_table *wr_table;
	const struct regmap_access_table *rd_table;
	const struct regmap_access_table *volatile_table;
	const struct regmap_access_table *precious_table;
	int (*reg_read)(void *, unsigned int, unsigned int *);
	int (*reg_write)(void *, unsigned int, unsigned int);
	int (*reg_update_bits)(void *, unsigned int, unsigned int, unsigned int);
	bool defer_caching;
	long unsigned int read_flag_mask;
	long unsigned int write_flag_mask;
	int reg_shift;
	int reg_stride;
	int reg_stride_order;
	const struct regcache_ops___2 *cache_ops;
	enum regcache_type cache_type;
	unsigned int cache_size_raw;
	unsigned int cache_word_size;
	unsigned int num_reg_defaults;
	unsigned int num_reg_defaults_raw;
	bool cache_only;
	bool cache_bypass;
	bool cache_free;
	struct reg_default *reg_defaults;
	const void *reg_defaults_raw;
	void *cache;
	bool cache_dirty;
	bool no_sync_defaults;
	struct reg_sequence *patch;
	int patch_regs;
	bool use_single_read;
	bool use_single_write;
	bool can_multi_write;
	size_t max_raw_read;
	size_t max_raw_write;
	struct rb_root range_tree;
	void *selector_work_buf;
	struct hwspinlock *hwlock;
};

struct regcache_ops___2 {
	const char *name;
	enum regcache_type type;
	int (*init)(struct regmap___3 *);
	int (*exit)(struct regmap___3 *);
	void (*debugfs_init)(struct regmap___3 *);
	int (*read)(struct regmap___3 *, unsigned int, unsigned int *);
	int (*write)(struct regmap___3 *, unsigned int, unsigned int);
	int (*sync)(struct regmap___3 *, unsigned int, unsigned int);
	int (*drop)(struct regmap___3 *, unsigned int, unsigned int);
};

struct regcache_rbtree_node {
	void *block;
	long int *cache_present;
	unsigned int base_reg;
	unsigned int blklen;
	struct rb_node node;
};

struct regcache_rbtree_ctx {
	struct rb_root root;
	struct regcache_rbtree_node *cached_rbnode;
};

struct regmap_debugfs_off_cache {
	struct list_head list;
	off_t min;
	off_t max;
	unsigned int base_reg;
	unsigned int max_reg;
};

struct regmap_range_node___2 {
	struct rb_node node;
	const char *name;
	struct regmap___3 *map;
	unsigned int range_min;
	unsigned int range_max;
	unsigned int selector_reg;
	unsigned int selector_mask;
	int selector_shift;
	unsigned int window_start;
	unsigned int window_len;
};

struct regmap_debugfs_node {
	struct regmap___3 *map;
	const char *name;
	struct list_head link;
};

struct regmap_config___2 {
	const char *name;
	int reg_bits;
	int reg_stride;
	int pad_bits;
	int val_bits;
	bool (*writeable_reg)(struct device___306 *, unsigned int);
	bool (*readable_reg)(struct device___306 *, unsigned int);
	bool (*volatile_reg)(struct device___306 *, unsigned int);
	bool (*precious_reg)(struct device___306 *, unsigned int);
	bool disable_locking;
	regmap_lock lock;
	regmap_unlock unlock;
	void *lock_arg;
	int (*reg_read)(void *, unsigned int, unsigned int *);
	int (*reg_write)(void *, unsigned int, unsigned int);
	bool fast_io;
	unsigned int max_register;
	const struct regmap_access_table *wr_table;
	const struct regmap_access_table *rd_table;
	const struct regmap_access_table *volatile_table;
	const struct regmap_access_table *precious_table;
	const struct reg_default *reg_defaults;
	unsigned int num_reg_defaults;
	enum regcache_type cache_type;
	const void *reg_defaults_raw;
	unsigned int num_reg_defaults_raw;
	long unsigned int read_flag_mask;
	long unsigned int write_flag_mask;
	bool zero_flag_mask;
	bool use_single_read;
	bool use_single_write;
	bool can_multi_write;
	enum regmap_endian reg_format_endian;
	enum regmap_endian val_format_endian;
	const struct regmap_range_cfg *ranges;
	unsigned int num_ranges;
	bool use_hwlock;
	unsigned int hwlock_id;
	unsigned int hwlock_mode;
};

struct regmap_async___3;

typedef int (*regmap_hw_async_write___3)(void *, const void *, size_t, const void *, size_t, struct regmap_async___3 *);

struct regmap___4;

struct regmap_async___3 {
	struct list_head list;
	struct regmap___4 *map;
	void *work_buf;
};

typedef struct regmap_async___3 * (*regmap_hw_async_alloc___3)();

struct regmap_bus___3 {
	bool fast_io;
	regmap_hw_write write;
	regmap_hw_gather_write gather_write;
	regmap_hw_async_write___3 async_write;
	regmap_hw_reg_write reg_write;
	regmap_hw_reg_update_bits reg_update_bits;
	regmap_hw_read read;
	regmap_hw_reg_read reg_read;
	regmap_hw_free_context free_context;
	regmap_hw_async_alloc___3 async_alloc;
	u8 read_flag_mask;
	enum regmap_endian reg_format_endian_default;
	enum regmap_endian val_format_endian_default;
	size_t max_raw_read;
	size_t max_raw_write;
};

struct rt_mutex___4 {
	raw_spinlock_t wait_lock;
	struct rb_root_cached waiters;
	struct task_struct___347 *owner;
};

struct i2c_msg {
	__u16 addr;
	__u16 flags;
	__u16 len;
	__u8 *buf;
};

union i2c_smbus_data {
	__u8 byte;
	__u16 word;
	__u8 block[34];
};

enum i2c_slave_event {
	I2C_SLAVE_READ_REQUESTED = 0,
	I2C_SLAVE_WRITE_REQUESTED = 1,
	I2C_SLAVE_READ_PROCESSED = 2,
	I2C_SLAVE_WRITE_RECEIVED = 3,
	I2C_SLAVE_STOP = 4,
};

struct i2c_client;

typedef int (*i2c_slave_cb_t)(struct i2c_client *, enum i2c_slave_event, u8 *);

struct i2c_adapter;

struct i2c_client {
	short unsigned int flags;
	short unsigned int addr;
	char name[20];
	struct i2c_adapter *adapter;
	struct device___306 dev;
	int irq;
	struct list_head detected;
	i2c_slave_cb_t slave_cb;
};

struct i2c_algorithm;

struct i2c_lock_operations;

struct i2c_bus_recovery_info;

struct i2c_adapter_quirks;

struct i2c_adapter {
	struct module___283 *owner;
	unsigned int class;
	const struct i2c_algorithm *algo;
	void *algo_data;
	const struct i2c_lock_operations *lock_ops;
	struct rt_mutex___4 bus_lock;
	struct rt_mutex___4 mux_lock;
	int timeout;
	int retries;
	struct device___306 dev;
	int nr;
	char name[48];
	struct completion dev_released;
	struct mutex userspace_clients_lock;
	struct list_head userspace_clients;
	struct i2c_bus_recovery_info *bus_recovery_info;
	const struct i2c_adapter_quirks *quirks;
	struct irq_domain___26 *host_notify_domain;
};

struct i2c_algorithm {
	int (*master_xfer)(struct i2c_adapter *, struct i2c_msg *, int);
	int (*smbus_xfer)(struct i2c_adapter *, u16, short unsigned int, char, u8, int, union i2c_smbus_data *);
	u32 (*functionality)(struct i2c_adapter *);
	int (*reg_slave)(struct i2c_client *);
	int (*unreg_slave)(struct i2c_client *);
};

struct i2c_lock_operations {
	void (*lock_bus)(struct i2c_adapter *, unsigned int);
	int (*trylock_bus)(struct i2c_adapter *, unsigned int);
	void (*unlock_bus)(struct i2c_adapter *, unsigned int);
};

struct i2c_bus_recovery_info {
	int (*recover_bus)(struct i2c_adapter *);
	int (*get_scl)(struct i2c_adapter *);
	void (*set_scl)(struct i2c_adapter *, int);
	int (*get_sda)(struct i2c_adapter *);
	void (*set_sda)(struct i2c_adapter *, int);
	void (*prepare_recovery)(struct i2c_adapter *);
	void (*unprepare_recovery)(struct i2c_adapter *);
	struct gpio_desc *scl_gpiod;
	struct gpio_desc *sda_gpiod;
};

struct i2c_adapter_quirks {
	u64 flags;
	int max_num_msgs;
	u16 max_write_len;
	u16 max_read_len;
	u16 max_comb_1st_msg_len;
	u16 max_comb_2nd_msg_len;
};

struct regmap_format___3 {
	size_t buf_size;
	size_t reg_bytes;
	size_t pad_bytes;
	size_t val_bytes;
	void (*format_write)(struct regmap___4 *, unsigned int, unsigned int);
	void (*format_reg)(void *, unsigned int, unsigned int);
	void (*format_val)(void *, unsigned int, unsigned int);
	unsigned int (*parse_val)(const void *);
	void (*parse_inplace)(void *);
};

struct regcache_ops___3;

struct regmap___4 {
	union {
		struct mutex mutex;
		struct {
			spinlock_t spinlock;
			long unsigned int spinlock_flags;
		};
	};
	regmap_lock lock;
	regmap_unlock unlock;
	void *lock_arg;
	gfp_t alloc_flags;
	struct device___306 *dev;
	void *work_buf;
	struct regmap_format___3 format;
	const struct regmap_bus___3 *bus;
	void *bus_context;
	const char *name;
	bool async;
	spinlock_t async_lock;
	wait_queue_head_t async_waitq;
	struct list_head async_list;
	struct list_head async_free;
	int async_ret;
	bool debugfs_disable;
	struct dentry___345 *debugfs;
	const char *debugfs_name;
	unsigned int debugfs_reg_len;
	unsigned int debugfs_val_len;
	unsigned int debugfs_tot_len;
	struct list_head debugfs_off_cache;
	struct mutex cache_lock;
	unsigned int max_register;
	bool (*writeable_reg)(struct device___306 *, unsigned int);
	bool (*readable_reg)(struct device___306 *, unsigned int);
	bool (*volatile_reg)(struct device___306 *, unsigned int);
	bool (*precious_reg)(struct device___306 *, unsigned int);
	const struct regmap_access_table *wr_table;
	const struct regmap_access_table *rd_table;
	const struct regmap_access_table *volatile_table;
	const struct regmap_access_table *precious_table;
	int (*reg_read)(void *, unsigned int, unsigned int *);
	int (*reg_write)(void *, unsigned int, unsigned int);
	int (*reg_update_bits)(void *, unsigned int, unsigned int, unsigned int);
	bool defer_caching;
	long unsigned int read_flag_mask;
	long unsigned int write_flag_mask;
	int reg_shift;
	int reg_stride;
	int reg_stride_order;
	const struct regcache_ops___3 *cache_ops;
	enum regcache_type cache_type;
	unsigned int cache_size_raw;
	unsigned int cache_word_size;
	unsigned int num_reg_defaults;
	unsigned int num_reg_defaults_raw;
	bool cache_only;
	bool cache_bypass;
	bool cache_free;
	struct reg_default *reg_defaults;
	const void *reg_defaults_raw;
	void *cache;
	bool cache_dirty;
	bool no_sync_defaults;
	struct reg_sequence *patch;
	int patch_regs;
	bool use_single_read;
	bool use_single_write;
	bool can_multi_write;
	size_t max_raw_read;
	size_t max_raw_write;
	struct rb_root range_tree;
	void *selector_work_buf;
	struct hwspinlock *hwlock;
};

struct regcache_ops___3 {
	const char *name;
	enum regcache_type type;
	int (*init)(struct regmap___4 *);
	int (*exit)(struct regmap___4 *);
	void (*debugfs_init)(struct regmap___4 *);
	int (*read)(struct regmap___4 *, unsigned int, unsigned int *);
	int (*write)(struct regmap___4 *, unsigned int, unsigned int);
	int (*sync)(struct regmap___4 *, unsigned int, unsigned int);
	int (*drop)(struct regmap___4 *, unsigned int, unsigned int);
};

struct spi_statistics {
	spinlock_t lock;
	long unsigned int messages;
	long unsigned int transfers;
	long unsigned int errors;
	long unsigned int timedout;
	long unsigned int spi_sync;
	long unsigned int spi_sync_immediate;
	long unsigned int spi_async;
	long long unsigned int bytes;
	long long unsigned int bytes_rx;
	long long unsigned int bytes_tx;
	long unsigned int transfer_bytes_histo[17];
	long unsigned int transfers_split_maxsize;
};

struct spi_controller;

struct spi_device {
	struct device___62 dev;
	struct spi_controller *controller;
	struct spi_controller *master;
	u32 max_speed_hz;
	u8 chip_select;
	u8 bits_per_word;
	u16 mode;
	int irq;
	void *controller_state;
	void *controller_data;
	char modalias[32];
	const char *driver_override;
	int cs_gpio;
	struct gpio_desc *cs_gpiod;
	uint8_t word_delay_usecs;
	struct spi_statistics statistics;
};

struct spi_controller_mem_ops;

struct dma_chan___7;

struct spi_message;

struct spi_transfer;

struct spi_controller {
	struct device___62 dev;
	struct list_head list;
	s16 bus_num;
	u16 num_chipselect;
	u16 dma_alignment;
	u16 mode_bits;
	u32 bits_per_word_mask;
	u32 min_speed_hz;
	u32 max_speed_hz;
	u16 flags;
	bool slave;
	size_t (*max_transfer_size)(struct spi_device *);
	size_t (*max_message_size)(struct spi_device *);
	struct mutex io_mutex;
	spinlock_t bus_lock_spinlock;
	struct mutex bus_lock_mutex;
	bool bus_lock_flag;
	int (*setup)(struct spi_device *);
	int (*transfer)(struct spi_device *, struct spi_message *);
	void (*cleanup)(struct spi_device *);
	bool (*can_dma)(struct spi_controller *, struct spi_device *, struct spi_transfer *);
	bool queued;
	struct kthread_worker___53 kworker;
	struct task_struct___68 *kworker_task;
	struct kthread_work___53 pump_messages;
	spinlock_t queue_lock;
	struct list_head queue;
	struct spi_message *cur_msg;
	bool idling;
	bool busy;
	bool running;
	bool rt;
	bool auto_runtime_pm;
	bool cur_msg_prepared;
	bool cur_msg_mapped;
	struct completion xfer_completion;
	size_t max_dma_len;
	int (*prepare_transfer_hardware)(struct spi_controller *);
	int (*transfer_one_message)(struct spi_controller *, struct spi_message *);
	int (*unprepare_transfer_hardware)(struct spi_controller *);
	int (*prepare_message)(struct spi_controller *, struct spi_message *);
	int (*unprepare_message)(struct spi_controller *, struct spi_message *);
	int (*slave_abort)(struct spi_controller *);
	void (*set_cs)(struct spi_device *, bool);
	int (*transfer_one)(struct spi_controller *, struct spi_device *, struct spi_transfer *);
	void (*handle_err)(struct spi_controller *, struct spi_message *);
	const struct spi_controller_mem_ops *mem_ops;
	int *cs_gpios;
	struct gpio_desc **cs_gpiods;
	bool use_gpio_descriptors;
	struct spi_statistics statistics;
	struct dma_chan___7 *dma_tx;
	struct dma_chan___7 *dma_rx;
	void *dummy_rx;
	void *dummy_tx;
	int (*fw_translate_cs)(struct spi_controller *, unsigned int);
};

struct spi_message {
	struct list_head transfers;
	struct spi_device *spi;
	unsigned int is_dma_mapped: 1;
	void (*complete)(void *);
	void *context;
	unsigned int frame_length;
	unsigned int actual_length;
	int status;
	struct list_head queue;
	void *state;
	struct list_head resources;
};

struct spi_transfer {
	const void *tx_buf;
	void *rx_buf;
	unsigned int len;
	dma_addr_t tx_dma;
	dma_addr_t rx_dma;
	struct sg_table tx_sg;
	struct sg_table rx_sg;
	unsigned int cs_change: 1;
	unsigned int tx_nbits: 3;
	unsigned int rx_nbits: 3;
	u8 bits_per_word;
	u8 word_delay_usecs;
	u16 delay_usecs;
	u32 speed_hz;
	u16 word_delay;
	struct list_head transfer_list;
};

struct regmap_async_spi {
	struct regmap_async core;
	struct spi_message m;
	struct spi_transfer t[2];
};

struct regmap_config___3 {
	const char *name;
	int reg_bits;
	int reg_stride;
	int pad_bits;
	int val_bits;
	bool (*writeable_reg)(struct device___293 *, unsigned int);
	bool (*readable_reg)(struct device___293 *, unsigned int);
	bool (*volatile_reg)(struct device___293 *, unsigned int);
	bool (*precious_reg)(struct device___293 *, unsigned int);
	bool disable_locking;
	regmap_lock lock;
	regmap_unlock unlock;
	void *lock_arg;
	int (*reg_read)(void *, unsigned int, unsigned int *);
	int (*reg_write)(void *, unsigned int, unsigned int);
	bool fast_io;
	unsigned int max_register;
	const struct regmap_access_table *wr_table;
	const struct regmap_access_table *rd_table;
	const struct regmap_access_table *volatile_table;
	const struct regmap_access_table *precious_table;
	const struct reg_default *reg_defaults;
	unsigned int num_reg_defaults;
	enum regcache_type cache_type;
	const void *reg_defaults_raw;
	unsigned int num_reg_defaults_raw;
	long unsigned int read_flag_mask;
	long unsigned int write_flag_mask;
	bool zero_flag_mask;
	bool use_single_read;
	bool use_single_write;
	bool can_multi_write;
	enum regmap_endian reg_format_endian;
	enum regmap_endian val_format_endian;
	const struct regmap_range_cfg *ranges;
	unsigned int num_ranges;
	bool use_hwlock;
	unsigned int hwlock_id;
	unsigned int hwlock_mode;
};

struct regmap_async___4;

typedef int (*regmap_hw_async_write___4)(void *, const void *, size_t, const void *, size_t, struct regmap_async___4 *);

struct regmap___5;

struct regmap_async___4 {
	struct list_head list;
	struct regmap___5 *map;
	void *work_buf;
};

typedef struct regmap_async___4 * (*regmap_hw_async_alloc___4)();

struct regmap_bus___4 {
	bool fast_io;
	regmap_hw_write write;
	regmap_hw_gather_write gather_write;
	regmap_hw_async_write___4 async_write;
	regmap_hw_reg_write reg_write;
	regmap_hw_reg_update_bits reg_update_bits;
	regmap_hw_read read;
	regmap_hw_reg_read reg_read;
	regmap_hw_free_context free_context;
	regmap_hw_async_alloc___4 async_alloc;
	u8 read_flag_mask;
	enum regmap_endian reg_format_endian_default;
	enum regmap_endian val_format_endian_default;
	size_t max_raw_read;
	size_t max_raw_write;
};

struct regmap_format___4 {
	size_t buf_size;
	size_t reg_bytes;
	size_t pad_bytes;
	size_t val_bytes;
	void (*format_write)(struct regmap___5 *, unsigned int, unsigned int);
	void (*format_reg)(void *, unsigned int, unsigned int);
	void (*format_val)(void *, unsigned int, unsigned int);
	unsigned int (*parse_val)(const void *);
	void (*parse_inplace)(void *);
};

struct regcache_ops___4;

struct regmap___5 {
	union {
		struct mutex mutex;
		struct {
			spinlock_t spinlock;
			long unsigned int spinlock_flags;
		};
	};
	regmap_lock lock;
	regmap_unlock unlock;
	void *lock_arg;
	gfp_t alloc_flags;
	struct device___293 *dev;
	void *work_buf;
	struct regmap_format___4 format;
	const struct regmap_bus___4 *bus;
	void *bus_context;
	const char *name;
	bool async;
	spinlock_t async_lock;
	wait_queue_head_t async_waitq;
	struct list_head async_list;
	struct list_head async_free;
	int async_ret;
	bool debugfs_disable;
	struct dentry___326 *debugfs;
	const char *debugfs_name;
	unsigned int debugfs_reg_len;
	unsigned int debugfs_val_len;
	unsigned int debugfs_tot_len;
	struct list_head debugfs_off_cache;
	struct mutex cache_lock;
	unsigned int max_register;
	bool (*writeable_reg)(struct device___293 *, unsigned int);
	bool (*readable_reg)(struct device___293 *, unsigned int);
	bool (*volatile_reg)(struct device___293 *, unsigned int);
	bool (*precious_reg)(struct device___293 *, unsigned int);
	const struct regmap_access_table *wr_table;
	const struct regmap_access_table *rd_table;
	const struct regmap_access_table *volatile_table;
	const struct regmap_access_table *precious_table;
	int (*reg_read)(void *, unsigned int, unsigned int *);
	int (*reg_write)(void *, unsigned int, unsigned int);
	int (*reg_update_bits)(void *, unsigned int, unsigned int, unsigned int);
	bool defer_caching;
	long unsigned int read_flag_mask;
	long unsigned int write_flag_mask;
	int reg_shift;
	int reg_stride;
	int reg_stride_order;
	const struct regcache_ops___4 *cache_ops;
	enum regcache_type cache_type;
	unsigned int cache_size_raw;
	unsigned int cache_word_size;
	unsigned int num_reg_defaults;
	unsigned int num_reg_defaults_raw;
	bool cache_only;
	bool cache_bypass;
	bool cache_free;
	struct reg_default *reg_defaults;
	const void *reg_defaults_raw;
	void *cache;
	bool cache_dirty;
	bool no_sync_defaults;
	struct reg_sequence *patch;
	int patch_regs;
	bool use_single_read;
	bool use_single_write;
	bool can_multi_write;
	size_t max_raw_read;
	size_t max_raw_write;
	struct rb_root range_tree;
	void *selector_work_buf;
	struct hwspinlock *hwlock;
};

struct regcache_ops___4 {
	const char *name;
	enum regcache_type type;
	int (*init)(struct regmap___5 *);
	int (*exit)(struct regmap___5 *);
	void (*debugfs_init)(struct regmap___5 *);
	int (*read)(struct regmap___5 *, unsigned int, unsigned int *);
	int (*write)(struct regmap___5 *, unsigned int, unsigned int);
	int (*sync)(struct regmap___5 *, unsigned int, unsigned int);
	int (*drop)(struct regmap___5 *, unsigned int, unsigned int);
};

struct regmap_mmio_context {
	void *regs;
	unsigned int val_bytes;
	bool attached_clk;
	struct clk *clk;
	void (*reg_write)(struct regmap_mmio_context *, unsigned int, unsigned int);
	unsigned int (*reg_read)(struct regmap_mmio_context *, unsigned int);
};

typedef void (*irq_write_msi_msg_t)(struct msi_desc___4 *, struct msi_msg *);

struct platform_msi_priv_data {
	struct device___270 *dev;
	void *host_data;
	msi_alloc_info_t___4 arg;
	irq_write_msi_msg_t write_msg;
	int devid;
};

struct cpufreq_governor___7;

struct cpufreq_policy___7 {
	cpumask_var_t cpus;
	cpumask_var_t related_cpus;
	cpumask_var_t real_cpus;
	unsigned int shared_type;
	unsigned int cpu;
	struct clk *clk;
	struct cpufreq_cpuinfo cpuinfo;
	unsigned int min;
	unsigned int max;
	unsigned int cur;
	unsigned int restore_freq;
	unsigned int suspend_freq;
	unsigned int policy;
	unsigned int last_policy;
	struct cpufreq_governor___7 *governor;
	void *governor_data;
	char last_governor[16];
	struct work_struct update;
	struct cpufreq_user_policy user_policy;
	struct cpufreq_frequency_table *freq_table;
	enum cpufreq_table_sorting freq_table_sorted;
	struct list_head policy_list;
	struct kobject___327 kobj;
	struct completion kobj_unregister;
	struct rw_semaphore___341 rwsem;
	bool fast_switch_possible;
	bool fast_switch_enabled;
	unsigned int transition_delay_us;
	bool dvfs_possible_from_any_cpu;
	unsigned int cached_target_freq;
	int cached_resolved_idx;
	bool transition_ongoing;
	spinlock_t transition_lock;
	wait_queue_head_t transition_wait;
	struct task_struct___341 *transition_task;
	struct cpufreq_stats *stats;
	void *driver_data;
};

struct cpufreq_governor___7 {
	char name[16];
	int (*init)(struct cpufreq_policy___7 *);
	void (*exit)(struct cpufreq_policy___7 *);
	int (*start)(struct cpufreq_policy___7 *);
	void (*stop)(struct cpufreq_policy___7 *);
	void (*limits)(struct cpufreq_policy___7 *);
	ssize_t (*show_setspeed)(struct cpufreq_policy___7 *, char *);
	int (*store_setspeed)(struct cpufreq_policy___7 *, unsigned int);
	bool dynamic_switching;
	struct list_head governor_list;
	struct module___278 *owner;
};

struct freq_attr___7 {
	struct attribute attr;
	ssize_t (*show)(struct cpufreq_policy___7 *, char *);
	ssize_t (*store)(struct cpufreq_policy___7 *, const char *, size_t);
};

struct test_struct {
	char *get;
	char *put;
	void (*get_handler)(char *);
	int (*put_handler)(char *, char *);
};

struct test_state {
	char *name;
	struct test_struct *tst;
	int idx;
	int (*run_test)(int, int);
	int (*validate_put)(char *);
};

struct regmap_config___4 {
	const char *name;
	int reg_bits;
	int reg_stride;
	int pad_bits;
	int val_bits;
	bool (*writeable_reg)(struct device___271 *, unsigned int);
	bool (*readable_reg)(struct device___271 *, unsigned int);
	bool (*volatile_reg)(struct device___271 *, unsigned int);
	bool (*precious_reg)(struct device___271 *, unsigned int);
	bool disable_locking;
	regmap_lock lock;
	regmap_unlock unlock;
	void *lock_arg;
	int (*reg_read)(void *, unsigned int, unsigned int *);
	int (*reg_write)(void *, unsigned int, unsigned int);
	bool fast_io;
	unsigned int max_register;
	const struct regmap_access_table *wr_table;
	const struct regmap_access_table *rd_table;
	const struct regmap_access_table *volatile_table;
	const struct regmap_access_table *precious_table;
	const struct reg_default *reg_defaults;
	unsigned int num_reg_defaults;
	enum regcache_type cache_type;
	const void *reg_defaults_raw;
	unsigned int num_reg_defaults_raw;
	long unsigned int read_flag_mask;
	long unsigned int write_flag_mask;
	bool zero_flag_mask;
	bool use_single_read;
	bool use_single_write;
	bool can_multi_write;
	enum regmap_endian reg_format_endian;
	enum regmap_endian val_format_endian;
	const struct regmap_range_cfg *ranges;
	unsigned int num_ranges;
	bool use_hwlock;
	unsigned int hwlock_id;
	unsigned int hwlock_mode;
};

struct vexpress_config_bridge_ops___2 {
	struct regmap * (*regmap_init)(struct device___271 *, void *);
	void (*regmap_exit)(struct regmap *, void *);
};

struct vexpress_syscfg {
	struct device___271 *dev;
	void *base;
	struct list_head funcs;
};

struct vexpress_syscfg_func {
	struct list_head list;
	struct vexpress_syscfg *syscfg;
	struct regmap *regmap;
	int num_templates;
	u32 template[0];
};

struct syscon_platform_data {
	const char *label;
};

struct regmap_config___5 {
	const char *name;
	int reg_bits;
	int reg_stride;
	int pad_bits;
	int val_bits;
	bool (*writeable_reg)(struct device___281 *, unsigned int);
	bool (*readable_reg)(struct device___281 *, unsigned int);
	bool (*volatile_reg)(struct device___281 *, unsigned int);
	bool (*precious_reg)(struct device___281 *, unsigned int);
	bool disable_locking;
	regmap_lock lock;
	regmap_unlock unlock;
	void *lock_arg;
	int (*reg_read)(void *, unsigned int, unsigned int *);
	int (*reg_write)(void *, unsigned int, unsigned int);
	bool fast_io;
	unsigned int max_register;
	const struct regmap_access_table *wr_table;
	const struct regmap_access_table *rd_table;
	const struct regmap_access_table *volatile_table;
	const struct regmap_access_table *precious_table;
	const struct reg_default *reg_defaults;
	unsigned int num_reg_defaults;
	enum regcache_type cache_type;
	const void *reg_defaults_raw;
	unsigned int num_reg_defaults_raw;
	long unsigned int read_flag_mask;
	long unsigned int write_flag_mask;
	bool zero_flag_mask;
	bool use_single_read;
	bool use_single_write;
	bool can_multi_write;
	enum regmap_endian reg_format_endian;
	enum regmap_endian val_format_endian;
	const struct regmap_range_cfg *ranges;
	unsigned int num_ranges;
	bool use_hwlock;
	unsigned int hwlock_id;
	unsigned int hwlock_mode;
};

struct syscon {
	struct device_node___71 *np;
	struct regmap *regmap;
	struct list_head list;
};

struct module___284;

struct file___347;

struct kiocb___347;

struct iov_iter___152;

struct vm_area_struct___348;

struct inode___347;

struct file_lock___347;

struct page___348;

struct file_operations___347 {
	struct module___284 *owner;
	loff_t (*llseek)(struct file___347 *, loff_t, int);
	ssize_t (*read)(struct file___347 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___347 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___347 *, struct iov_iter___152 *);
	ssize_t (*write_iter)(struct kiocb___347 *, struct iov_iter___152 *);
	int (*iopoll)(struct kiocb___347 *, bool);
	int (*iterate)(struct file___347 *, struct dir_context *);
	int (*iterate_shared)(struct file___347 *, struct dir_context *);
	__poll_t (*poll)(struct file___347 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___347 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___347 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___347 *, struct vm_area_struct___348 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___347 *, struct file___347 *);
	int (*flush)(struct file___347 *, fl_owner_t);
	int (*release)(struct inode___347 *, struct file___347 *);
	int (*fsync)(struct file___347 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___347 *, int);
	int (*lock)(struct file___347 *, int, struct file_lock___347 *);
	ssize_t (*sendpage)(struct file___347 *, struct page___348 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___347 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___347 *, int, struct file_lock___347 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___347 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___347 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___347 *, long int, struct file_lock___347 **, void **);
	long int (*fallocate)(struct file___347 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___347 *);
	ssize_t (*copy_file_range)(struct file___347 *, loff_t, struct file___347 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___347 *, loff_t, struct file___347 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___347 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___347 {
	u64 seqnum;
	struct vm_area_struct___348 *vmas[4];
};

struct page_frag___347 {
	struct page___348 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___347;

struct bio_list___165;

struct backing_dev_info___165;

struct io_context___85;

struct request_queue___81;

struct vm_struct___253;

struct task_struct___348 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___348 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___347 *mm;
	struct mm_struct___347 *active_mm;
	struct vmacache___347 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___348 *real_parent;
	struct task_struct___348 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___348 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___215 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___215 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___215 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___2 *ptracer_cred;
	const struct cred___2 *real_cred;
	const struct cred___2 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___348 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___165 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___165 *backing_dev_info;
	struct io_context___85 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___347 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___81 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___348 *oom_reaper_list;
	struct vm_struct___253 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___139 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___348 *pgtable_t___347;

struct address_space___346;

struct dev_pagemap___335;

struct page___348 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___346 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___348 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___347 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___347 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___335 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___347;

struct lruvec___347 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___347 *pgdat;
};

struct zone___347 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___347 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___347 {
	struct zone___347 *zone;
	int zone_idx;
};

struct zonelist___347 {
	struct zoneref___347 _zonerefs[25];
};

struct pglist_data___347 {
	struct zone___347 node_zones[3];
	struct zonelist___347 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___348 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___348 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___347 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___348 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___348 *owner;
};

struct secondary_data___348 {
	void *stack;
	struct task_struct___348 *task;
	long int status;
};

struct blocking_notifier_head___347 {
	struct rw_semaphore___348 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___335;

struct vm_area_struct___348 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___348 *vm_next;
	struct vm_area_struct___348 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___347 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___335 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___347 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___347;

struct mm_struct___347 {
	struct {
		struct vm_area_struct___348 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___347 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___348 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___347 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___348 *owner;
		struct user_namespace___3 *user_ns;
		struct file___347 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___347 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___346;

struct address_space___346 {
	struct inode___347 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___348 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___346 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___335)(struct vm_area_struct___348 *, long unsigned int, const struct page___348 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___335)(struct page___348 *, void *);

struct device___314;

struct dev_pagemap___335 {
	dev_page_fault_t___335 page_fault;
	dev_page_free_t___335 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___314 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct vfsmount___69;

struct dentry___346;

struct path___347 {
	struct vfsmount___69 *mnt;
	struct dentry___346 *dentry;
};

struct file___347 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___347 f_path;
	struct inode___347 *f_inode;
	const struct file_operations___347 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___215 f_owner;
	const struct cred___2 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___346 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___335;

struct vm_operations_struct___335 {
	void (*open)(struct vm_area_struct___348 *);
	void (*close)(struct vm_area_struct___348 *);
	int (*split)(struct vm_area_struct___348 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___348 *);
	vm_fault_t (*fault)(struct vm_fault___335 *);
	vm_fault_t (*huge_fault)(struct vm_fault___335 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___335 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___348 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___335 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___335 *);
	int (*access)(struct vm_area_struct___348 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___348 *);
	int (*set_policy)(struct vm_area_struct___348 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___348 *, long unsigned int);
	struct page___348 * (*find_special_page)(struct vm_area_struct___348 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___347 {
	struct task_struct___348 *task;
	struct core_thread___347 *next;
};

struct core_state___347 {
	atomic_t nr_threads;
	struct core_thread___347 dumper;
	struct completion startup;
};

struct vm_fault___335 {
	struct vm_area_struct___348 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___348 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___348 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___347 prealloc_pte;
};

struct bio___165;

struct bio_list___165 {
	struct bio___165 *head;
	struct bio___165 *tail;
};

struct bdi_writeback_congested___165;

struct bdi_writeback___165 {
	struct backing_dev_info___165 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___165 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___157 *memcg_css;
	struct cgroup_subsys_state___157 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___165 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___165 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___314 *dev;
	struct device___314 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___346 *debug_dir;
	struct dentry___346 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___85;

struct io_context___85 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___85 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

typedef blk_qc_t make_request_fn___81(struct request_queue___81 *, struct bio___165 *);

struct request___81;

typedef int dma_drain_needed_fn___81(struct request___81 *);

struct kset___333;

struct kobj_type___333;

struct kernfs_node___341;

struct kobject___334 {
	const char *name;
	struct list_head entry;
	struct kobject___334 *parent;
	struct kset___333 *kset;
	struct kobj_type___333 *ktype;
	struct kernfs_node___341 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___81;

struct bsg_class_device___81 {
	struct device___314 *class_dev;
	int minor;
	struct request_queue___81 *queue;
	const struct bsg_ops___81 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___165 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___165 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___81;

struct request_queue___81 {
	struct list_head queue_head;
	struct request___81 *last_merge;
	struct elevator_queue___81 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___81 *make_request_fn;
	dma_drain_needed_fn___81 *dma_drain_needed;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___165 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___334 kobj;
	struct kobject___334 *mq_kobj;
	struct blk_integrity integrity;
	struct device___314 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	struct bsg_class_device___81 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___165 bio_split;
	struct dentry___346 *debugfs_dir;
	struct dentry___346 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___253 {
	struct vm_struct___253 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___348 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dev_pm_info___314 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___5 *subsys_data;
	void (*set_latency_tolerance)(struct device___314 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___314;

struct bus_type___314;

struct device_driver___314;

struct dev_pm_domain___314;

struct fwnode_handle___236;

struct class___314;

struct attribute_group___311;

struct device___314 {
	struct device___314 *parent;
	struct device_private *p;
	struct kobject___334 kobj;
	const char *init_name;
	const struct device_type___314 *type;
	struct mutex mutex;
	struct bus_type___314 *bus;
	struct device_driver___314 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___314 power;
	struct dev_pm_domain___314 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___236 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___314 *class;
	const struct attribute_group___311 **groups;
	void (*release)(struct device___314 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___346;

struct super_block___346;

struct dentry___346 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___346 *d_parent;
	struct qstr d_name;
	struct inode___347 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___346 *d_op;
	struct super_block___346 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___346;

struct block_device___346;

struct cdev___80;

struct inode___347 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___346 *i_op;
	struct super_block___346 *i_sb;
	struct address_space___346 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___348 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___165 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___347 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___346 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___346 *i_bdev;
		struct cdev___80 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___346 {
	int (*d_revalidate)(struct dentry___346 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___346 *, unsigned int);
	int (*d_hash)(const struct dentry___346 *, struct qstr *);
	int (*d_compare)(const struct dentry___346 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___346 *);
	int (*d_init)(struct dentry___346 *);
	void (*d_release)(struct dentry___346 *);
	void (*d_prune)(struct dentry___346 *);
	void (*d_iput)(struct dentry___346 *, struct inode___347 *);
	char * (*d_dname)(struct dentry___346 *, char *, int);
	struct vfsmount___69 * (*d_automount)(struct path___347 *);
	int (*d_manage)(const struct path___347 *, bool);
	struct dentry___346 * (*d_real)(struct dentry___346 *, const struct inode___347 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___346;

struct mem_dqinfo___346 {
	struct quota_format_type___346 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___346;

struct quota_info___346 {
	unsigned int flags;
	struct rw_semaphore___348 dqio_sem;
	struct inode___347 *files[3];
	struct mem_dqinfo___346 info[3];
	const struct quota_format_ops___346 *ops[3];
};

struct rcuwait___346 {
	struct task_struct___348 *task;
};

struct percpu_rw_semaphore___346 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___348 rw_sem;
	struct rcuwait___346 writer;
	int readers_block;
};

struct sb_writers___346 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___346 rw_sem[3];
};

struct file_system_type___346;

struct super_operations___346;

struct dquot_operations___346;

struct quotactl_ops___346;

struct super_block___346 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___346 *s_type;
	const struct super_operations___346 *s_op;
	const struct dquot_operations___346 *dq_op;
	const struct quotactl_ops___346 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___346 *s_root;
	struct rw_semaphore___348 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___346 *s_bdev;
	struct backing_dev_info___165 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___346 s_dquot;
	struct sb_writers___346 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___346 *s_d_op;
	int cleancache_poolid;
	struct shrinker___130 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___69 {
	struct dentry___346 *mnt_root;
	struct super_block___346 *mnt_sb;
	int mnt_flags;
};

struct io_cq___85 {
	struct request_queue___81 *q;
	struct io_context___85 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___347 {
	struct file___347 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___347 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___346 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___347 *ia_file;
};

struct dquot___346 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___346 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___346 {
	int qf_fmt_id;
	const struct quota_format_ops___346 *qf_ops;
	struct module___284 *qf_owner;
	struct quota_format_type___346 *qf_next;
};

struct quota_format_ops___346 {
	int (*check_quota_file)(struct super_block___346 *, int);
	int (*read_file_info)(struct super_block___346 *, int);
	int (*write_file_info)(struct super_block___346 *, int);
	int (*free_file_info)(struct super_block___346 *, int);
	int (*read_dqblk)(struct dquot___346 *);
	int (*commit_dqblk)(struct dquot___346 *);
	int (*release_dqblk)(struct dquot___346 *);
	int (*get_next_id)(struct super_block___346 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___346 {
	int (*write_dquot)(struct dquot___346 *);
	struct dquot___346 * (*alloc_dquot)(struct super_block___346 *, int);
	void (*destroy_dquot)(struct dquot___346 *);
	int (*acquire_dquot)(struct dquot___346 *);
	int (*release_dquot)(struct dquot___346 *);
	int (*mark_dirty)(struct dquot___346 *);
	int (*write_info)(struct super_block___346 *, int);
	qsize_t * (*get_reserved_space)(struct inode___347 *);
	int (*get_projid)(struct inode___347 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___347 *, qsize_t *);
	int (*get_next_id)(struct super_block___346 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___346 {
	int (*quota_on)(struct super_block___346 *, int, int, const struct path___347 *);
	int (*quota_off)(struct super_block___346 *, int);
	int (*quota_enable)(struct super_block___346 *, unsigned int);
	int (*quota_disable)(struct super_block___346 *, unsigned int);
	int (*quota_sync)(struct super_block___346 *, int);
	int (*set_info)(struct super_block___346 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___346 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___346 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___346 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___346 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___346 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___281 {
	struct kobject___334 kobj;
	struct module___284 *mod;
	struct kobject___334 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___281 {
	struct module___284 *mod;
	struct latch_tree_node node;
};

struct module_layout___281 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___281 mtn;
};

struct module_attribute___281;

struct kernel_param___281;

struct module___284 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___281 mkobj;
	struct module_attribute___281 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___334 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___281 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___281 core_layout;
	struct module_layout___281 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___346 {
	int (*writepage)(struct page___348 *, struct writeback_control___3 *);
	int (*readpage)(struct file___347 *, struct page___348 *);
	int (*writepages)(struct address_space___346 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___348 *);
	int (*readpages)(struct file___347 *, struct address_space___346 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___347 *, struct address_space___346 *, loff_t, unsigned int, unsigned int, struct page___348 **, void **);
	int (*write_end)(struct file___347 *, struct address_space___346 *, loff_t, unsigned int, unsigned int, struct page___348 *, void *);
	sector_t (*bmap)(struct address_space___346 *, sector_t);
	void (*invalidatepage)(struct page___348 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___348 *, gfp_t);
	void (*freepage)(struct page___348 *);
	ssize_t (*direct_IO)(struct kiocb___347 *, struct iov_iter___152 *);
	int (*migratepage)(struct address_space___346 *, struct page___348 *, struct page___348 *, enum migrate_mode);
	bool (*isolate_page)(struct page___348 *, isolate_mode_t);
	void (*putback_page)(struct page___348 *);
	int (*launder_page)(struct page___348 *);
	int (*is_partially_uptodate)(struct page___348 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___348 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___346 *, struct page___348 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___347 *, sector_t *);
	void (*swap_deactivate)(struct file___347 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio_vec___167;

struct iov_iter___152 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___167 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct hd_struct___85;

struct gendisk___85;

struct block_device___346 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___347 *bd_inode;
	struct super_block___346 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___346 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___85 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___85 *bd_disk;
	struct request_queue___81 *bd_queue;
	struct backing_dev_info___165 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct hd_struct___85 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___314 __dev;
	struct kobject___334 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___85;

struct block_device_operations___82;

struct gendisk___85 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___85 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___85 *part_tbl;
	struct hd_struct___85 part0;
	const struct block_device_operations___82 *fops;
	struct request_queue___81 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___348 lookup_sem;
	struct kobject___334 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___334 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___80 {
	struct kobject___334 kobj;
	struct module___284 *owner;
	const struct file_operations___347 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___346 {
	struct dentry___346 * (*lookup)(struct inode___347 *, struct dentry___346 *, unsigned int);
	const char * (*get_link)(struct dentry___346 *, struct inode___347 *, struct delayed_call *);
	int (*permission)(struct inode___347 *, int);
	struct posix_acl * (*get_acl)(struct inode___347 *, int);
	int (*readlink)(struct dentry___346 *, char *, int);
	int (*create)(struct inode___347 *, struct dentry___346 *, umode_t, bool);
	int (*link)(struct dentry___346 *, struct inode___347 *, struct dentry___346 *);
	int (*unlink)(struct inode___347 *, struct dentry___346 *);
	int (*symlink)(struct inode___347 *, struct dentry___346 *, const char *);
	int (*mkdir)(struct inode___347 *, struct dentry___346 *, umode_t);
	int (*rmdir)(struct inode___347 *, struct dentry___346 *);
	int (*mknod)(struct inode___347 *, struct dentry___346 *, umode_t, dev_t);
	int (*rename)(struct inode___347 *, struct dentry___346 *, struct inode___347 *, struct dentry___346 *, unsigned int);
	int (*setattr)(struct dentry___346 *, struct iattr___346 *);
	int (*getattr)(const struct path___347 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___346 *, char *, size_t);
	int (*fiemap)(struct inode___347 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___347 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___347 *, struct dentry___346 *, struct file___347 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___347 *, struct dentry___346 *, umode_t);
	int (*set_acl)(struct inode___347 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___346 {
	void (*fl_copy_lock)(struct file_lock___347 *, struct file_lock___347 *);
	void (*fl_release_private)(struct file_lock___347 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___346;

struct lock_manager_operations___346;

struct file_lock___347 {
	struct file_lock___347 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___347 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___346 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___346 *fl_ops;
	const struct lock_manager_operations___346 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___346 {
	int (*lm_compare_owner)(struct file_lock___347 *, struct file_lock___347 *);
	long unsigned int (*lm_owner_key)(struct file_lock___347 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___347 *);
	int (*lm_grant)(struct file_lock___347 *, int);
	bool (*lm_break)(struct file_lock___347 *);
	int (*lm_change)(struct file_lock___347 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___347 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___346 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___346 *fa_next;
	struct file___347 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___346 {
	const char *name;
	int fs_flags;
	struct dentry___346 * (*mount)(struct file_system_type___346 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___346 *);
	struct module___284 *owner;
	struct file_system_type___346 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___346 {
	struct inode___347 * (*alloc_inode)(struct super_block___346 *);
	void (*destroy_inode)(struct inode___347 *);
	void (*dirty_inode)(struct inode___347 *, int);
	int (*write_inode)(struct inode___347 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___347 *);
	void (*evict_inode)(struct inode___347 *);
	void (*put_super)(struct super_block___346 *);
	int (*sync_fs)(struct super_block___346 *, int);
	int (*freeze_super)(struct super_block___346 *);
	int (*freeze_fs)(struct super_block___346 *);
	int (*thaw_super)(struct super_block___346 *);
	int (*unfreeze_fs)(struct super_block___346 *);
	int (*statfs)(struct dentry___346 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___346 *, int *, char *);
	void (*umount_begin)(struct super_block___346 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___346 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___346 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___346 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___346 *);
	ssize_t (*quota_read)(struct super_block___346 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___346 *, int, const char *, size_t, loff_t);
	struct dquot___346 ** (*get_dquots)(struct inode___347 *);
	int (*bdev_try_to_free_page)(struct super_block___346 *, struct page___348 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___346 *, struct shrink_control___130 *);
	long int (*free_cached_objects)(struct super_block___346 *, struct shrink_control___130 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___165(struct bio___165 *);

struct bio_vec___167 {
	struct page___348 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___165;

struct bio___165 {
	struct bio___165 *bi_next;
	struct gendisk___85 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___165 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___165 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___167 *bi_io_vec;
	struct bio_set___165 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___167 bi_inline_vecs[0];
};

struct kobj_attribute___325 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___334 *, struct kobj_attribute___325 *, char *);
	ssize_t (*store)(struct kobject___334 *, struct kobj_attribute___325 *, const char *, size_t);
};

typedef void compound_page_dtor___335(struct page___348 *);

struct kernfs_root___340;

struct kernfs_elem_dir___340 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___340 *root;
};

struct kernfs_syscall_ops___340;

struct kernfs_root___340 {
	struct kernfs_node___341 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___340 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___340 {
	struct kernfs_node___341 *target_kn;
};

struct kernfs_ops___340;

struct kernfs_elem_attr___340 {
	const struct kernfs_ops___340 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___341 *notify_next;
};

struct kernfs_node___341 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___341 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___340 dir;
		struct kernfs_elem_symlink___340 symlink;
		struct kernfs_elem_attr___340 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___340;

struct kernfs_ops___340 {
	int (*open)(struct kernfs_open_file___340 *);
	void (*release)(struct kernfs_open_file___340 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___340 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___340 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___340 *, struct vm_area_struct___348 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___340 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___340 {
	int (*remount_fs)(struct kernfs_root___340 *, int *, char *);
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___340 *);
	int (*mkdir)(struct kernfs_node___341 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___341 *);
	int (*rename)(struct kernfs_node___341 *, struct kernfs_node___341 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___341 *, struct kernfs_root___340 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___340 {
	struct kernfs_node___341 *kn;
	struct file___347 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___335 *vm_ops;
};

struct bin_attribute___310;

struct attribute_group___311 {
	const char *name;
	umode_t (*is_visible)(struct kobject___334 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___334 *, struct bin_attribute___310 *, int);
	struct attribute **attrs;
	struct bin_attribute___310 **bin_attrs;
};

struct bin_attribute___310 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___347 *, struct kobject___334 *, struct bin_attribute___310 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___347 *, struct kobject___334 *, struct bin_attribute___310 *, char *, loff_t, size_t);
	int (*mmap)(struct file___347 *, struct kobject___334 *, struct bin_attribute___310 *, struct vm_area_struct___348 *);
};

struct sysfs_ops___333 {
	ssize_t (*show)(struct kobject___334 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___334 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___333;

struct kset___333 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___334 kobj;
	const struct kset_uevent_ops___333 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___333 {
	void (*release)(struct kobject___334 *);
	const struct sysfs_ops___333 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___27 * (*child_ns_type)(struct kobject___334 *);
	const void * (*namespace)(struct kobject___334 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___333 {
	int (* const filter)(struct kset___333 *, struct kobject___334 *);
	const char * (* const name)(struct kset___333 *, struct kobject___334 *);
	int (* const uevent)(struct kset___333 *, struct kobject___334 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___281 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___281 *);
	int (*get)(char *, const struct kernel_param___281 *);
	void (*free)(void *);
};

struct kparam_array___281;

struct kernel_param___281 {
	const char *name;
	struct module___284 *mod;
	const struct kernel_param_ops___281 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___281 *arr;
	};
};

struct kparam_array___281 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___281 *ops;
	void *elem;
};

struct module_attribute___281 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___281 *, struct module_kobject___281 *, char *);
	ssize_t (*store)(struct module_attribute___281 *, struct module_kobject___281 *, const char *, size_t);
	void (*setup)(struct module___284 *, const char *);
	int (*test)(struct module___284 *);
	void (*free)(struct module___284 *);
};

struct bio_integrity_payload___165 {
	struct bio___165 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___167 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___167 bip_inline_vecs[0];
};

struct dev_pm_ops___314;

struct device_type___314 {
	const char *name;
	const struct attribute_group___311 **groups;
	int (*uevent)(struct device___314 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___314 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___314 *);
	const struct dev_pm_ops___314 *pm;
};

struct class___314 {
	const char *name;
	struct module___284 *owner;
	const struct attribute_group___311 **class_groups;
	const struct attribute_group___311 **dev_groups;
	struct kobject___334 *dev_kobj;
	int (*dev_uevent)(struct device___314 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___314 *, umode_t *);
	void (*class_release)(struct class___314 *);
	void (*dev_release)(struct device___314 *);
	int (*shutdown_pre)(struct device___314 *);
	const struct kobj_ns_type_operations___27 *ns_type;
	const void * (*namespace)(struct device___314 *);
	const struct dev_pm_ops___314 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dev_pm_ops___314 {
	int (*prepare)(struct device___314 *);
	void (*complete)(struct device___314 *);
	int (*suspend)(struct device___314 *);
	int (*resume)(struct device___314 *);
	int (*freeze)(struct device___314 *);
	int (*thaw)(struct device___314 *);
	int (*poweroff)(struct device___314 *);
	int (*restore)(struct device___314 *);
	int (*suspend_late)(struct device___314 *);
	int (*resume_early)(struct device___314 *);
	int (*freeze_late)(struct device___314 *);
	int (*thaw_early)(struct device___314 *);
	int (*poweroff_late)(struct device___314 *);
	int (*restore_early)(struct device___314 *);
	int (*suspend_noirq)(struct device___314 *);
	int (*resume_noirq)(struct device___314 *);
	int (*freeze_noirq)(struct device___314 *);
	int (*thaw_noirq)(struct device___314 *);
	int (*poweroff_noirq)(struct device___314 *);
	int (*restore_noirq)(struct device___314 *);
	int (*runtime_suspend)(struct device___314 *);
	int (*runtime_resume)(struct device___314 *);
	int (*runtime_idle)(struct device___314 *);
};

struct dev_pm_domain___314 {
	struct dev_pm_ops___314 ops;
	void (*detach)(struct device___314 *, bool);
	int (*activate)(struct device___314 *);
	void (*sync)(struct device___314 *);
	void (*dismiss)(struct device___314 *);
};

struct bus_type___314 {
	const char *name;
	const char *dev_name;
	struct device___314 *dev_root;
	const struct attribute_group___311 **bus_groups;
	const struct attribute_group___311 **dev_groups;
	const struct attribute_group___311 **drv_groups;
	int (*match)(struct device___314 *, struct device_driver___314 *);
	int (*uevent)(struct device___314 *, struct kobj_uevent_env *);
	int (*probe)(struct device___314 *);
	int (*remove)(struct device___314 *);
	void (*shutdown)(struct device___314 *);
	int (*online)(struct device___314 *);
	int (*offline)(struct device___314 *);
	int (*suspend)(struct device___314 *, pm_message_t);
	int (*resume)(struct device___314 *);
	int (*num_vf)(struct device___314 *);
	int (*dma_configure)(struct device___314 *);
	const struct dev_pm_ops___314 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___314 {
	const char *name;
	struct bus_type___314 *bus;
	struct module___284 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___314 *);
	int (*remove)(struct device___314 *);
	void (*shutdown)(struct device___314 *);
	int (*suspend)(struct device___314 *, pm_message_t);
	int (*resume)(struct device___314 *);
	const struct attribute_group___311 **groups;
	const struct dev_pm_ops___314 *pm;
	void (*coredump)(struct device___314 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_attribute___34 {
	struct attribute attr;
	ssize_t (*show)(struct device___314 *, struct device_attribute___34 *, char *);
	ssize_t (*store)(struct device___314 *, struct device_attribute___34 *, const char *, size_t);
};

struct fwnode_operations___236;

struct fwnode_handle___236 {
	struct fwnode_handle___236 *secondary;
	const struct fwnode_operations___236 *ops;
};

struct disk_part_tbl___85 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___85 *last_lookup;
	struct hd_struct___85 *part[0];
};

struct block_device_operations___82 {
	int (*open)(struct block_device___346 *, fmode_t);
	void (*release)(struct gendisk___85 *, fmode_t);
	int (*rw_page)(struct block_device___346 *, sector_t, struct page___348 *, unsigned int);
	int (*ioctl)(struct block_device___346 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___346 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___85 *, unsigned int);
	int (*media_changed)(struct gendisk___85 *);
	void (*unlock_native_capacity)(struct gendisk___85 *);
	int (*revalidate_disk)(struct gendisk___85 *);
	int (*getgeo)(struct block_device___346 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___346 *, long unsigned int);
	int (*report_zones)(struct gendisk___85 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___284 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dax_device___2;

struct dax_operations {
	long int (*direct_access)(struct dax_device___2 *, long unsigned int, long int, void **, pfn_t *);
	bool (*dax_supported)(struct dax_device___2 *, struct block_device___346 *, int, sector_t, sector_t);
	size_t (*copy_from_iter)(struct dax_device___2 *, long unsigned int, void *, size_t, struct iov_iter___152 *);
	size_t (*copy_to_iter)(struct dax_device___2 *, long unsigned int, void *, size_t, struct iov_iter___152 *);
};

struct dax_device___2 {
	struct hlist_node list;
	struct inode___347 inode;
	struct cdev___80 cdev;
	const char *host;
	void *private;
	long unsigned int flags;
	const struct dax_operations *ops;
};

struct bdi_writeback_congested___165 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___165 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bsg_ops___81 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___81 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___81 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___81 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___81(struct request___81 *, blk_status_t);

struct request___81 {
	struct request_queue___81 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___165 *bio;
	struct bio___165 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___167 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___85 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___81 *saved_end_io;
		} flush;
	};
	struct gendisk___85 *rq_disk;
	struct hd_struct___85 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___81 *end_io;
	void *end_io_data;
	struct request___81 *next_rq;
};

struct fwnode_reference_args___236;

struct fwnode_endpoint___236;

struct fwnode_operations___236 {
	struct fwnode_handle___236 * (*get)(struct fwnode_handle___236 *);
	void (*put)(struct fwnode_handle___236 *);
	bool (*device_is_available)(const struct fwnode_handle___236 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___236 *, const struct device___314 *);
	bool (*property_present)(const struct fwnode_handle___236 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___236 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___236 *, const char *, const char **, size_t);
	struct fwnode_handle___236 * (*get_parent)(const struct fwnode_handle___236 *);
	struct fwnode_handle___236 * (*get_next_child_node)(const struct fwnode_handle___236 *, struct fwnode_handle___236 *);
	struct fwnode_handle___236 * (*get_named_child_node)(const struct fwnode_handle___236 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___236 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___236 *);
	struct fwnode_handle___236 * (*graph_get_next_endpoint)(const struct fwnode_handle___236 *, struct fwnode_handle___236 *);
	struct fwnode_handle___236 * (*graph_get_remote_endpoint)(const struct fwnode_handle___236 *);
	struct fwnode_handle___236 * (*graph_get_port_parent)(struct fwnode_handle___236 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___236 *, struct fwnode_endpoint___236 *);
};

struct fwnode_endpoint___236 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___236 *local_fwnode;
};

struct fwnode_reference_args___236 {
	struct fwnode_handle___236 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct elevator_type___81;

struct elevator_mq_ops___81 {
	int (*init_sched)(struct request_queue___81 *, struct elevator_type___81 *);
	void (*exit_sched)(struct elevator_queue___81 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	bool (*allow_merge)(struct request_queue___81 *, struct request___81 *, struct bio___165 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx *, struct bio___165 *);
	int (*request_merge)(struct request_queue___81 *, struct request___81 **, struct bio___165 *);
	void (*request_merged)(struct request_queue___81 *, struct request___81 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___81 *, struct request___81 *, struct request___81 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___81 *, struct bio___165 *);
	void (*finish_request)(struct request___81 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___81 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___81 *, u64);
	void (*started_request)(struct request___81 *);
	void (*requeue_request)(struct request___81 *);
	struct request___81 * (*former_request)(struct request_queue___81 *, struct request___81 *);
	struct request___81 * (*next_request)(struct request_queue___81 *, struct request___81 *);
	void (*init_icq)(struct io_cq___85 *);
	void (*exit_icq)(struct io_cq___85 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___81;

struct elevator_type___81 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___81 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___81 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___284 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___81 {
	struct elevator_type___81 *type;
	void *elevator_data;
	struct kobject___334 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___81 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___81 *, char *);
	ssize_t (*store)(struct elevator_queue___81 *, const char *, size_t);
};

enum dax_device_flags {
	DAXDEV_ALIVE = 0,
	DAXDEV_WRITE_CACHE = 1,
};

struct module___285;

struct file___348;

struct kiocb___348;

struct poll_table_struct___212;

struct vm_area_struct___349;

struct inode___348;

struct file_lock___348;

struct page___349;

struct seq_file___295;

struct file_operations___348 {
	struct module___285 *owner;
	loff_t (*llseek)(struct file___348 *, loff_t, int);
	ssize_t (*read)(struct file___348 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___348 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___348 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___348 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___348 *, bool);
	int (*iterate)(struct file___348 *, struct dir_context *);
	int (*iterate_shared)(struct file___348 *, struct dir_context *);
	__poll_t (*poll)(struct file___348 *, struct poll_table_struct___212 *);
	long int (*unlocked_ioctl)(struct file___348 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___348 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___348 *, struct vm_area_struct___349 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___348 *, struct file___348 *);
	int (*flush)(struct file___348 *, fl_owner_t);
	int (*release)(struct inode___348 *, struct file___348 *);
	int (*fsync)(struct file___348 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___348 *, int);
	int (*lock)(struct file___348 *, int, struct file_lock___348 *);
	ssize_t (*sendpage)(struct file___348 *, struct page___349 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___348 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___348 *, int, struct file_lock___348 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___348 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___348 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___348 *, long int, struct file_lock___348 **, void **);
	long int (*fallocate)(struct file___348 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___295 *, struct file___348 *);
	ssize_t (*copy_file_range)(struct file___348 *, loff_t, struct file___348 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___348 *, loff_t, struct file___348 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___348 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___348 {
	u64 seqnum;
	struct vm_area_struct___349 *vmas[4];
};

struct page_frag___348 {
	struct page___349 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___348;

struct cred___322;

struct vm_struct___254;

struct task_struct___349 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___349 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___348 *mm;
	struct mm_struct___348 *active_mm;
	struct vmacache___348 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___349 *real_parent;
	struct task_struct___349 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___349 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___215 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___215 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___215 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___322 *ptracer_cred;
	const struct cred___322 *real_cred;
	const struct cred___322 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___349 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___85 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___348 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___349 *oom_reaper_list;
	struct vm_struct___254 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___139 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___347;

struct super_block___347;

struct dentry___347 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___347 *d_parent;
	struct qstr d_name;
	struct inode___348 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___347 *d_op;
	struct super_block___347 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct rw_semaphore___349 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___349 *owner;
};

struct address_space_operations___347;

struct address_space___347 {
	struct inode___348 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___349 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___347 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___347;

struct block_device___347;

struct inode___348 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___347 *i_op;
	struct super_block___347 *i_sb;
	struct address_space___347 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___349 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___348 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___347 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___347 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vfsmount___70;

struct path___348;

struct dentry_operations___347 {
	int (*d_revalidate)(struct dentry___347 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___347 *, unsigned int);
	int (*d_hash)(const struct dentry___347 *, struct qstr *);
	int (*d_compare)(const struct dentry___347 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___347 *);
	int (*d_init)(struct dentry___347 *);
	void (*d_release)(struct dentry___347 *);
	void (*d_prune)(struct dentry___347 *);
	void (*d_iput)(struct dentry___347 *, struct inode___348 *);
	char * (*d_dname)(struct dentry___347 *, char *, int);
	struct vfsmount___70 * (*d_automount)(struct path___348 *);
	int (*d_manage)(const struct path___348 *, bool);
	struct dentry___347 * (*d_real)(struct dentry___347 *, const struct inode___348 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___347;

struct mem_dqinfo___347 {
	struct quota_format_type___347 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___347;

struct quota_info___347 {
	unsigned int flags;
	struct rw_semaphore___349 dqio_sem;
	struct inode___348 *files[3];
	struct mem_dqinfo___347 info[3];
	const struct quota_format_ops___347 *ops[3];
};

struct rcuwait___347 {
	struct task_struct___349 *task;
};

struct percpu_rw_semaphore___347 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___349 rw_sem;
	struct rcuwait___347 writer;
	int readers_block;
};

struct sb_writers___347 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___347 rw_sem[3];
};

struct file_system_type___347;

struct super_operations___347;

struct dquot_operations___347;

struct quotactl_ops___347;

struct super_block___347 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___347 *s_type;
	const struct super_operations___347 *s_op;
	const struct dquot_operations___347 *dq_op;
	const struct quotactl_ops___347 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___347 *s_root;
	struct rw_semaphore___349 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___347 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___347 s_dquot;
	struct sb_writers___347 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___347 *s_d_op;
	int cleancache_poolid;
	struct shrinker___130 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___70 {
	struct dentry___347 *mnt_root;
	struct super_block___347 *mnt_sb;
	int mnt_flags;
};

struct path___348 {
	struct vfsmount___70 *mnt;
	struct dentry___347 *dentry;
};

typedef struct page___349 *pgtable_t___348;

struct dev_pagemap___336;

struct page___349 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___347 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___349 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___348 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___348 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___336 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___348;

struct lruvec___348 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___348 *pgdat;
};

struct zone___348 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___348 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___348 {
	struct zone___348 *zone;
	int zone_idx;
};

struct zonelist___348 {
	struct zoneref___348 _zonerefs[25];
};

struct pglist_data___348 {
	struct zone___348 node_zones[3];
	struct zonelist___348 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___349 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___349 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___348 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct ww_acquire_ctx___2 {
	struct task_struct___349 *task;
	long unsigned int stamp;
	unsigned int acquired;
	short unsigned int wounded;
	short unsigned int is_wait_die;
};

struct secondary_data___349 {
	void *stack;
	struct task_struct___349 *task;
	long int status;
};

struct blocking_notifier_head___348 {
	struct rw_semaphore___349 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___336;

struct vm_area_struct___349 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___349 *vm_next;
	struct vm_area_struct___349 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___348 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___336 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___348 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___348;

struct mm_struct___348 {
	struct {
		struct vm_area_struct___349 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___348 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___349 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___348 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___349 *owner;
		struct user_namespace___3 *user_ns;
		struct file___348 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___348 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___336)(struct vm_area_struct___349 *, long unsigned int, const struct page___349 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___336)(struct page___349 *, void *);

struct device___315;

struct dev_pagemap___336 {
	dev_page_fault_t___336 page_fault;
	dev_page_free_t___336 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___315 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct file___348 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___348 f_path;
	struct inode___348 *f_inode;
	const struct file_operations___348 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___215 f_owner;
	const struct cred___322 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___347 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___336;

struct vm_operations_struct___336 {
	void (*open)(struct vm_area_struct___349 *);
	void (*close)(struct vm_area_struct___349 *);
	int (*split)(struct vm_area_struct___349 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___349 *);
	vm_fault_t (*fault)(struct vm_fault___336 *);
	vm_fault_t (*huge_fault)(struct vm_fault___336 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___336 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___349 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___336 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___336 *);
	int (*access)(struct vm_area_struct___349 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___349 *);
	int (*set_policy)(struct vm_area_struct___349 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___349 *, long unsigned int);
	struct page___349 * (*find_special_page)(struct vm_area_struct___349 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___348 {
	struct task_struct___349 *task;
	struct core_thread___348 *next;
};

struct core_state___348 {
	atomic_t nr_threads;
	struct core_thread___348 dumper;
	struct completion startup;
};

struct vm_fault___336 {
	struct vm_area_struct___349 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___349 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___349 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___348 prealloc_pte;
};

struct key___322;

struct user_struct___322 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___322 *uid_keyring;
	struct key___322 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___322 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___322 *session_keyring;
	struct key___322 *process_keyring;
	struct key___322 *thread_keyring;
	struct key___322 *request_key_auth;
	void *security;
	struct user_struct___322 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct vm_struct___254 {
	struct vm_struct___254 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___349 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct kiocb___348 {
	struct file___348 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___348 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___347 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___348 *ia_file;
};

struct dquot___347 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___347 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___347 {
	int qf_fmt_id;
	const struct quota_format_ops___347 *qf_ops;
	struct module___285 *qf_owner;
	struct quota_format_type___347 *qf_next;
};

struct quota_format_ops___347 {
	int (*check_quota_file)(struct super_block___347 *, int);
	int (*read_file_info)(struct super_block___347 *, int);
	int (*write_file_info)(struct super_block___347 *, int);
	int (*free_file_info)(struct super_block___347 *, int);
	int (*read_dqblk)(struct dquot___347 *);
	int (*commit_dqblk)(struct dquot___347 *);
	int (*release_dqblk)(struct dquot___347 *);
	int (*get_next_id)(struct super_block___347 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___347 {
	int (*write_dquot)(struct dquot___347 *);
	struct dquot___347 * (*alloc_dquot)(struct super_block___347 *, int);
	void (*destroy_dquot)(struct dquot___347 *);
	int (*acquire_dquot)(struct dquot___347 *);
	int (*release_dquot)(struct dquot___347 *);
	int (*mark_dirty)(struct dquot___347 *);
	int (*write_info)(struct super_block___347 *, int);
	qsize_t * (*get_reserved_space)(struct inode___348 *);
	int (*get_projid)(struct inode___348 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___348 *, qsize_t *);
	int (*get_next_id)(struct super_block___347 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___347 {
	int (*quota_on)(struct super_block___347 *, int, int, const struct path___348 *);
	int (*quota_off)(struct super_block___347 *, int);
	int (*quota_enable)(struct super_block___347 *, unsigned int);
	int (*quota_disable)(struct super_block___347 *, unsigned int);
	int (*quota_sync)(struct super_block___347 *, int);
	int (*set_info)(struct super_block___347 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___347 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___347 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___347 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___347 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___347 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___334;

struct kobj_type___334;

struct kernfs_node___342;

struct kobject___335 {
	const char *name;
	struct list_head entry;
	struct kobject___335 *parent;
	struct kset___334 *kset;
	struct kobj_type___334 *ktype;
	struct kernfs_node___342 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___282 {
	struct kobject___335 kobj;
	struct module___285 *mod;
	struct kobject___335 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___282 {
	struct module___285 *mod;
	struct latch_tree_node node;
};

struct module_layout___282 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___282 mtn;
};

struct module_attribute___282;

struct kernel_param___282;

struct module___285 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___282 mkobj;
	struct module_attribute___282 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___335 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___282 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___282 core_layout;
	struct module_layout___282 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___347 {
	int (*writepage)(struct page___349 *, struct writeback_control___3 *);
	int (*readpage)(struct file___348 *, struct page___349 *);
	int (*writepages)(struct address_space___347 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___349 *);
	int (*readpages)(struct file___348 *, struct address_space___347 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___348 *, struct address_space___347 *, loff_t, unsigned int, unsigned int, struct page___349 **, void **);
	int (*write_end)(struct file___348 *, struct address_space___347 *, loff_t, unsigned int, unsigned int, struct page___349 *, void *);
	sector_t (*bmap)(struct address_space___347 *, sector_t);
	void (*invalidatepage)(struct page___349 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___349 *, gfp_t);
	void (*freepage)(struct page___349 *);
	ssize_t (*direct_IO)(struct kiocb___348 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___347 *, struct page___349 *, struct page___349 *, enum migrate_mode);
	bool (*isolate_page)(struct page___349 *, isolate_mode_t);
	void (*putback_page)(struct page___349 *);
	int (*launder_page)(struct page___349 *);
	int (*is_partially_uptodate)(struct page___349 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___349 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___347 *, struct page___349 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___348 *, sector_t *);
	void (*swap_deactivate)(struct file___348 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___347 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___348 *bd_inode;
	struct super_block___347 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___347 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___347 {
	struct dentry___347 * (*lookup)(struct inode___348 *, struct dentry___347 *, unsigned int);
	const char * (*get_link)(struct dentry___347 *, struct inode___348 *, struct delayed_call *);
	int (*permission)(struct inode___348 *, int);
	struct posix_acl * (*get_acl)(struct inode___348 *, int);
	int (*readlink)(struct dentry___347 *, char *, int);
	int (*create)(struct inode___348 *, struct dentry___347 *, umode_t, bool);
	int (*link)(struct dentry___347 *, struct inode___348 *, struct dentry___347 *);
	int (*unlink)(struct inode___348 *, struct dentry___347 *);
	int (*symlink)(struct inode___348 *, struct dentry___347 *, const char *);
	int (*mkdir)(struct inode___348 *, struct dentry___347 *, umode_t);
	int (*rmdir)(struct inode___348 *, struct dentry___347 *);
	int (*mknod)(struct inode___348 *, struct dentry___347 *, umode_t, dev_t);
	int (*rename)(struct inode___348 *, struct dentry___347 *, struct inode___348 *, struct dentry___347 *, unsigned int);
	int (*setattr)(struct dentry___347 *, struct iattr___347 *);
	int (*getattr)(const struct path___348 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___347 *, char *, size_t);
	int (*fiemap)(struct inode___348 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___348 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___348 *, struct dentry___347 *, struct file___348 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___348 *, struct dentry___347 *, umode_t);
	int (*set_acl)(struct inode___348 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___347 {
	void (*fl_copy_lock)(struct file_lock___348 *, struct file_lock___348 *);
	void (*fl_release_private)(struct file_lock___348 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___347;

struct lock_manager_operations___347;

struct file_lock___348 {
	struct file_lock___348 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___348 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___347 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___347 *fl_ops;
	const struct lock_manager_operations___347 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___347 {
	int (*lm_compare_owner)(struct file_lock___348 *, struct file_lock___348 *);
	long unsigned int (*lm_owner_key)(struct file_lock___348 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___348 *);
	int (*lm_grant)(struct file_lock___348 *, int);
	bool (*lm_break)(struct file_lock___348 *);
	int (*lm_change)(struct file_lock___348 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___348 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___347 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___347 *fa_next;
	struct file___348 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___347 {
	const char *name;
	int fs_flags;
	struct dentry___347 * (*mount)(struct file_system_type___347 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___347 *);
	struct module___285 *owner;
	struct file_system_type___347 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___347 {
	struct inode___348 * (*alloc_inode)(struct super_block___347 *);
	void (*destroy_inode)(struct inode___348 *);
	void (*dirty_inode)(struct inode___348 *, int);
	int (*write_inode)(struct inode___348 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___348 *);
	void (*evict_inode)(struct inode___348 *);
	void (*put_super)(struct super_block___347 *);
	int (*sync_fs)(struct super_block___347 *, int);
	int (*freeze_super)(struct super_block___347 *);
	int (*freeze_fs)(struct super_block___347 *);
	int (*thaw_super)(struct super_block___347 *);
	int (*unfreeze_fs)(struct super_block___347 *);
	int (*statfs)(struct dentry___347 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___347 *, int *, char *);
	void (*umount_begin)(struct super_block___347 *);
	int (*show_options)(struct seq_file___295 *, struct dentry___347 *);
	int (*show_devname)(struct seq_file___295 *, struct dentry___347 *);
	int (*show_path)(struct seq_file___295 *, struct dentry___347 *);
	int (*show_stats)(struct seq_file___295 *, struct dentry___347 *);
	ssize_t (*quota_read)(struct super_block___347 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___347 *, int, const char *, size_t, loff_t);
	struct dquot___347 ** (*get_dquots)(struct inode___348 *);
	int (*bdev_try_to_free_page)(struct super_block___347 *, struct page___349 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___347 *, struct shrink_control___130 *);
	long int (*free_cached_objects)(struct super_block___347 *, struct shrink_control___130 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___218)(struct file___348 *, wait_queue_head_t *, struct poll_table_struct___212 *);

struct poll_table_struct___212 {
	poll_queue_proc___218 _qproc;
	__poll_t _key;
};

struct seq_operations___294;

struct seq_file___295 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___294 *op;
	int poll_event;
	const struct file___348 *file;
	void *private;
};

struct dev_pm_info___315 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___5 *subsys_data;
	void (*set_latency_tolerance)(struct device___315 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___315;

struct bus_type___315;

struct device_driver___315;

struct dev_pm_domain___315;

struct dma_map_ops___104;

struct fwnode_handle___237;

struct class___315;

struct attribute_group___312;

struct device___315 {
	struct device___315 *parent;
	struct device_private *p;
	struct kobject___335 kobj;
	const char *init_name;
	const struct device_type___315 *type;
	struct mutex mutex;
	struct bus_type___315 *bus;
	struct device_driver___315 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___315 power;
	struct dev_pm_domain___315 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___104 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___237 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___315 *class;
	const struct attribute_group___312 **groups;
	void (*release)(struct device___315 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct kobj_attribute___326 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___335 *, struct kobj_attribute___326 *, char *);
	ssize_t (*store)(struct kobject___335 *, struct kobj_attribute___326 *, const char *, size_t);
};

typedef void compound_page_dtor___336(struct page___349 *);

struct fwnode_operations___237;

struct fwnode_handle___237 {
	struct fwnode_handle___237 *secondary;
	const struct fwnode_operations___237 *ops;
};

struct fwnode_reference_args___237;

struct fwnode_endpoint___237;

struct fwnode_operations___237 {
	struct fwnode_handle___237 * (*get)(struct fwnode_handle___237 *);
	void (*put)(struct fwnode_handle___237 *);
	bool (*device_is_available)(const struct fwnode_handle___237 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___237 *, const struct device___315 *);
	bool (*property_present)(const struct fwnode_handle___237 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___237 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___237 *, const char *, const char **, size_t);
	struct fwnode_handle___237 * (*get_parent)(const struct fwnode_handle___237 *);
	struct fwnode_handle___237 * (*get_next_child_node)(const struct fwnode_handle___237 *, struct fwnode_handle___237 *);
	struct fwnode_handle___237 * (*get_named_child_node)(const struct fwnode_handle___237 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___237 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___237 *);
	struct fwnode_handle___237 * (*graph_get_next_endpoint)(const struct fwnode_handle___237 *, struct fwnode_handle___237 *);
	struct fwnode_handle___237 * (*graph_get_remote_endpoint)(const struct fwnode_handle___237 *);
	struct fwnode_handle___237 * (*graph_get_port_parent)(struct fwnode_handle___237 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___237 *, struct fwnode_endpoint___237 *);
};

struct fwnode_endpoint___237 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___237 *local_fwnode;
};

struct fwnode_reference_args___237 {
	struct fwnode_handle___237 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct kernfs_root___341;

struct kernfs_elem_dir___341 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___341 *root;
};

struct kernfs_syscall_ops___341;

struct kernfs_root___341 {
	struct kernfs_node___342 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___341 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___341 {
	struct kernfs_node___342 *target_kn;
};

struct kernfs_ops___341;

struct kernfs_elem_attr___341 {
	const struct kernfs_ops___341 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___342 *notify_next;
};

struct kernfs_node___342 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___342 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___341 dir;
		struct kernfs_elem_symlink___341 symlink;
		struct kernfs_elem_attr___341 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___341;

struct kernfs_ops___341 {
	int (*open)(struct kernfs_open_file___341 *);
	void (*release)(struct kernfs_open_file___341 *);
	int (*seq_show)(struct seq_file___295 *, void *);
	void * (*seq_start)(struct seq_file___295 *, loff_t *);
	void * (*seq_next)(struct seq_file___295 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___295 *, void *);
	ssize_t (*read)(struct kernfs_open_file___341 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___341 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___341 *, struct vm_area_struct___349 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___341 *, struct poll_table_struct___212 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___341 {
	int (*remount_fs)(struct kernfs_root___341 *, int *, char *);
	int (*show_options)(struct seq_file___295 *, struct kernfs_root___341 *);
	int (*mkdir)(struct kernfs_node___342 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___342 *);
	int (*rename)(struct kernfs_node___342 *, struct kernfs_node___342 *, const char *);
	int (*show_path)(struct seq_file___295 *, struct kernfs_node___342 *, struct kernfs_root___341 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___341 {
	struct kernfs_node___342 *kn;
	struct file___348 *file;
	struct seq_file___295 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___336 *vm_ops;
};

struct bin_attribute___311;

struct attribute_group___312 {
	const char *name;
	umode_t (*is_visible)(struct kobject___335 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___335 *, struct bin_attribute___311 *, int);
	struct attribute **attrs;
	struct bin_attribute___311 **bin_attrs;
};

struct bin_attribute___311 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___348 *, struct kobject___335 *, struct bin_attribute___311 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___348 *, struct kobject___335 *, struct bin_attribute___311 *, char *, loff_t, size_t);
	int (*mmap)(struct file___348 *, struct kobject___335 *, struct bin_attribute___311 *, struct vm_area_struct___349 *);
};

struct sysfs_ops___334 {
	ssize_t (*show)(struct kobject___335 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___335 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___334;

struct kset___334 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___335 kobj;
	const struct kset_uevent_ops___334 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___334 {
	void (*release)(struct kobject___335 *);
	const struct sysfs_ops___334 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___27 * (*child_ns_type)(struct kobject___335 *);
	const void * (*namespace)(struct kobject___335 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___334 {
	int (* const filter)(struct kset___334 *, struct kobject___335 *);
	const char * (* const name)(struct kset___334 *, struct kobject___335 *);
	int (* const uevent)(struct kset___334 *, struct kobject___335 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___315 {
	int (*prepare)(struct device___315 *);
	void (*complete)(struct device___315 *);
	int (*suspend)(struct device___315 *);
	int (*resume)(struct device___315 *);
	int (*freeze)(struct device___315 *);
	int (*thaw)(struct device___315 *);
	int (*poweroff)(struct device___315 *);
	int (*restore)(struct device___315 *);
	int (*suspend_late)(struct device___315 *);
	int (*resume_early)(struct device___315 *);
	int (*freeze_late)(struct device___315 *);
	int (*thaw_early)(struct device___315 *);
	int (*poweroff_late)(struct device___315 *);
	int (*restore_early)(struct device___315 *);
	int (*suspend_noirq)(struct device___315 *);
	int (*resume_noirq)(struct device___315 *);
	int (*freeze_noirq)(struct device___315 *);
	int (*thaw_noirq)(struct device___315 *);
	int (*poweroff_noirq)(struct device___315 *);
	int (*restore_noirq)(struct device___315 *);
	int (*runtime_suspend)(struct device___315 *);
	int (*runtime_resume)(struct device___315 *);
	int (*runtime_idle)(struct device___315 *);
};

struct dev_pm_domain___315 {
	struct dev_pm_ops___315 ops;
	void (*detach)(struct device___315 *, bool);
	int (*activate)(struct device___315 *);
	void (*sync)(struct device___315 *);
	void (*dismiss)(struct device___315 *);
};

struct bus_type___315 {
	const char *name;
	const char *dev_name;
	struct device___315 *dev_root;
	const struct attribute_group___312 **bus_groups;
	const struct attribute_group___312 **dev_groups;
	const struct attribute_group___312 **drv_groups;
	int (*match)(struct device___315 *, struct device_driver___315 *);
	int (*uevent)(struct device___315 *, struct kobj_uevent_env *);
	int (*probe)(struct device___315 *);
	int (*remove)(struct device___315 *);
	void (*shutdown)(struct device___315 *);
	int (*online)(struct device___315 *);
	int (*offline)(struct device___315 *);
	int (*suspend)(struct device___315 *, pm_message_t);
	int (*resume)(struct device___315 *);
	int (*num_vf)(struct device___315 *);
	int (*dma_configure)(struct device___315 *);
	const struct dev_pm_ops___315 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___315 {
	const char *name;
	struct bus_type___315 *bus;
	struct module___285 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___315 *);
	int (*remove)(struct device___315 *);
	void (*shutdown)(struct device___315 *);
	int (*suspend)(struct device___315 *, pm_message_t);
	int (*resume)(struct device___315 *);
	const struct attribute_group___312 **groups;
	const struct dev_pm_ops___315 *pm;
	void (*coredump)(struct device___315 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___315 {
	const char *name;
	const struct attribute_group___312 **groups;
	int (*uevent)(struct device___315 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___315 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___315 *);
	const struct dev_pm_ops___315 *pm;
};

struct class___315 {
	const char *name;
	struct module___285 *owner;
	const struct attribute_group___312 **class_groups;
	const struct attribute_group___312 **dev_groups;
	struct kobject___335 *dev_kobj;
	int (*dev_uevent)(struct device___315 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___315 *, umode_t *);
	void (*class_release)(struct class___315 *);
	void (*dev_release)(struct device___315 *);
	int (*shutdown_pre)(struct device___315 *);
	const struct kobj_ns_type_operations___27 *ns_type;
	const void * (*namespace)(struct device___315 *);
	const struct dev_pm_ops___315 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___104 {
	void * (*alloc)(struct device___315 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___315 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___315 *, struct vm_area_struct___349 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___315 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___315 *, struct page___349 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___315 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___315 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___315 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___315 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___315 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___315 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___315 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___315 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___315 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___315 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___315 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___315 *, u64);
	u64 (*get_required_mask)(struct device___315 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct dma_fence_ops;

struct dma_fence {
	struct kref refcount;
	const struct dma_fence_ops *ops;
	struct callback_head rcu;
	struct list_head cb_list;
	spinlock_t *lock;
	u64 context;
	u64 seqno;
	long unsigned int flags;
	ktime_t timestamp;
	int error;
};

struct dma_fence_ops {
	const char * (*get_driver_name)(struct dma_fence *);
	const char * (*get_timeline_name)(struct dma_fence *);
	bool (*enable_signaling)(struct dma_fence *);
	bool (*signaled)(struct dma_fence *);
	long int (*wait)(struct dma_fence *, bool, long int);
	void (*release)(struct dma_fence *);
	void (*fence_value_str)(struct dma_fence *, char *, int);
	void (*timeline_value_str)(struct dma_fence *, char *, int);
};

enum dma_fence_flag_bits {
	DMA_FENCE_FLAG_SIGNALED_BIT = 0,
	DMA_FENCE_FLAG_TIMESTAMP_BIT = 1,
	DMA_FENCE_FLAG_ENABLE_SIGNAL_BIT = 2,
	DMA_FENCE_FLAG_USER_BITS = 3,
};

struct dma_fence_cb;

typedef void (*dma_fence_func_t)(struct dma_fence *, struct dma_fence_cb *);

struct dma_fence_cb {
	struct list_head node;
	dma_fence_func_t func;
};

struct dma_buf;

struct dma_buf_attachment;

struct dma_buf_ops {
	bool cache_sgt_mapping;
	int (*attach)(struct dma_buf *, struct dma_buf_attachment *);
	void (*detach)(struct dma_buf *, struct dma_buf_attachment *);
	struct sg_table * (*map_dma_buf)(struct dma_buf_attachment *, enum dma_data_direction);
	void (*unmap_dma_buf)(struct dma_buf_attachment *, struct sg_table *, enum dma_data_direction);
	void (*release)(struct dma_buf *);
	int (*begin_cpu_access)(struct dma_buf *, enum dma_data_direction);
	int (*end_cpu_access)(struct dma_buf *, enum dma_data_direction);
	int (*mmap)(struct dma_buf *, struct vm_area_struct___349 *);
	void * (*map)(struct dma_buf *, long unsigned int);
	void (*unmap)(struct dma_buf *, long unsigned int, void *);
	void * (*vmap)(struct dma_buf *);
	void (*vunmap)(struct dma_buf *, void *);
};

struct dma_buf_poll_cb_t {
	struct dma_fence_cb cb;
	wait_queue_head_t *poll;
	__poll_t active;
};

struct reservation_object;

struct dma_buf {
	size_t size;
	struct file___348 *file;
	struct list_head attachments;
	const struct dma_buf_ops *ops;
	struct mutex lock;
	unsigned int vmapping_counter;
	void *vmap_ptr;
	const char *exp_name;
	const char *name;
	struct module___285 *owner;
	struct list_head list_node;
	void *priv;
	struct reservation_object *resv;
	wait_queue_head_t poll;
	struct dma_buf_poll_cb_t cb_excl;
	struct dma_buf_poll_cb_t cb_shared;
};

struct dma_buf_attachment {
	struct dma_buf *dmabuf;
	struct device___315 *dev;
	struct list_head node;
	struct sg_table *sgt;
	enum dma_data_direction dir;
	void *priv;
};

struct ww_mutex___2 {
	struct mutex base;
	struct ww_acquire_ctx___2 *ctx;
};

struct reservation_object_list;

struct reservation_object {
	struct ww_mutex___2 lock;
	seqcount_t seq;
	struct dma_fence *fence_excl;
	struct reservation_object_list *fence;
};

struct dma_buf_export_info {
	const char *exp_name;
	struct module___285 *owner;
	const struct dma_buf_ops *ops;
	size_t size;
	int flags;
	struct reservation_object *resv;
	void *priv;
};

typedef int (*key_restrict_link_func_t___323)(struct key___322 *, const struct key_type *, const union key_payload *, struct key___322 *);

struct key_restriction___322;

struct key___322 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___349 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___322 *restrict_link;
};

struct key_restriction___322 {
	key_restrict_link_func_t___323 check;
	struct key___322 *key;
	struct key_type *keytype;
};

struct seq_operations___294 {
	void * (*start)(struct seq_file___295 *, loff_t *);
	void (*stop)(struct seq_file___295 *, void *);
	void * (*next)(struct seq_file___295 *, void *, loff_t *);
	int (*show)(struct seq_file___295 *, void *);
};

struct kernel_param_ops___282 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___282 *);
	int (*get)(char *, const struct kernel_param___282 *);
	void (*free)(void *);
};

struct kparam_array___282;

struct kernel_param___282 {
	const char *name;
	struct module___285 *mod;
	const struct kernel_param_ops___282 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___282 *arr;
	};
};

struct kparam_array___282 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___282 *ops;
	void *elem;
};

struct module_attribute___282 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___282 *, struct module_kobject___282 *, char *);
	ssize_t (*store)(struct module_attribute___282 *, struct module_kobject___282 *, const char *, size_t);
	void (*setup)(struct module___285 *, const char *);
	int (*test)(struct module___285 *);
	void (*free)(struct module___285 *);
};

typedef struct poll_table_struct___212 poll_table___30;

struct ww_class {
	atomic_long_t stamp;
	struct lock_class_key acquire_key;
	struct lock_class_key mutex_key;
	const char *acquire_name;
	const char *mutex_name;
	unsigned int is_wait_die;
};

struct reservation_object_list {
	struct callback_head rcu;
	u32 shared_count;
	u32 shared_max;
	struct dma_fence *shared[0];
};

struct dma_buf_sync {
	__u64 flags;
};

struct dma_buf_list {
	struct list_head head;
	struct mutex lock;
};

struct trace_event_raw_dma_fence {
	struct trace_entry ent;
	u32 __data_loc_driver;
	u32 __data_loc_timeline;
	unsigned int context;
	unsigned int seqno;
	char __data[0];
};

struct trace_event_data_offsets_dma_fence {
	u32 driver;
	u32 timeline;
};

struct default_wait_cb {
	struct dma_fence_cb base;
	struct task_struct___12 *task;
};

struct dma_fence_array;

struct dma_fence_array_cb {
	struct dma_fence_cb cb;
	struct dma_fence_array *array;
};

struct dma_fence_array {
	struct dma_fence base;
	spinlock_t lock;
	unsigned int num_fences;
	atomic_t num_pending;
	struct dma_fence **fences;
	struct irq_work work;
};

enum seqno_fence_condition {
	SEQNO_FENCE_WAIT_GEQUAL = 0,
	SEQNO_FENCE_WAIT_NONZERO = 1,
};

struct seqno_fence {
	struct dma_fence base;
	const struct dma_fence_ops *ops;
	struct dma_buf *sync_buf;
	uint32_t seqno_ofs;
	enum seqno_fence_condition condition;
};

struct sync_file {
	struct file___348 *file;
	char user_name[32];
	struct list_head sync_file_list;
	wait_queue_head_t wq;
	long unsigned int flags;
	struct dma_fence *fence;
	struct dma_fence_cb cb;
};

struct sync_merge_data {
	char name[32];
	__s32 fd2;
	__s32 fence;
	__u32 flags;
	__u32 pad;
};

struct sync_fence_info {
	char obj_name[32];
	char driver_name[32];
	__s32 status;
	__u32 flags;
	__u64 timestamp_ns;
};

struct sync_file_info {
	char name[32];
	__s32 status;
	__u32 flags;
	__u32 num_fences;
	__u32 pad;
	__u64 sync_fence_info;
};

struct module___286;

struct file___349;

struct kiocb___349;

struct iov_iter___153;

struct poll_table_struct___213;

struct vm_area_struct___350;

struct inode___349;

struct file_lock___349;

struct page___350;

struct seq_file___296;

struct file_operations___349 {
	struct module___286 *owner;
	loff_t (*llseek)(struct file___349 *, loff_t, int);
	ssize_t (*read)(struct file___349 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___349 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___349 *, struct iov_iter___153 *);
	ssize_t (*write_iter)(struct kiocb___349 *, struct iov_iter___153 *);
	int (*iopoll)(struct kiocb___349 *, bool);
	int (*iterate)(struct file___349 *, struct dir_context *);
	int (*iterate_shared)(struct file___349 *, struct dir_context *);
	__poll_t (*poll)(struct file___349 *, struct poll_table_struct___213 *);
	long int (*unlocked_ioctl)(struct file___349 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___349 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___349 *, struct vm_area_struct___350 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___349 *, struct file___349 *);
	int (*flush)(struct file___349 *, fl_owner_t);
	int (*release)(struct inode___349 *, struct file___349 *);
	int (*fsync)(struct file___349 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___349 *, int);
	int (*lock)(struct file___349 *, int, struct file_lock___349 *);
	ssize_t (*sendpage)(struct file___349 *, struct page___350 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___349 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___349 *, int, struct file_lock___349 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___349 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___349 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___349 *, long int, struct file_lock___349 **, void **);
	long int (*fallocate)(struct file___349 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___296 *, struct file___349 *);
	ssize_t (*copy_file_range)(struct file___349 *, loff_t, struct file___349 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___349 *, loff_t, struct file___349 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___349 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___349 {
	u64 seqnum;
	struct vm_area_struct___350 *vmas[4];
};

struct page_frag___349 {
	struct page___350 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___140;

struct debug_info___140 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___140 *hbp_break[16];
	struct perf_event___140 *hbp_watch[16];
};

struct thread_struct___140 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___140 debug;
	long: 64;
};

struct mm_struct___349;

struct pid___216;

struct cred___323;

struct nsproxy___273;

struct signal_struct___253;

struct bio_list___166;

struct backing_dev_info___166;

struct io_context___86;

struct css_set___228;

struct perf_event_context___140;

struct request_queue___82;

struct vm_struct___255;

struct task_struct___350 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___350 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___349 *mm;
	struct mm_struct___349 *active_mm;
	struct vmacache___349 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___350 *real_parent;
	struct task_struct___350 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___350 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___216 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___216 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___216 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___323 *ptracer_cred;
	const struct cred___323 *real_cred;
	const struct cred___323 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___273 *nsproxy;
	struct signal_struct___253 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___350 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___166 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___166 *backing_dev_info;
	struct io_context___86 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___228 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___140 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___349 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___82 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___350 *oom_reaper_list;
	struct vm_struct___255 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___140 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___140 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___350 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___140)(struct perf_event___140 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___140;

struct fasync_struct___348;

struct pid_namespace___216;

struct trace_event_call___133;

struct perf_cgroup___140;

struct perf_event___140 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___140 *group_leader;
	struct pmu___140 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___140 hw;
	struct perf_event_context___140 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___140 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___350 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___348 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___140 *);
	struct callback_head callback_head;
	struct pid_namespace___216 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___140 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___140 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___133 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___140 *cgrp;
	struct list_head sb_list;
};

struct rw_semaphore___350 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___350 *owner;
};

struct key___323;

struct ucounts___243;

struct user_namespace___243 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___243 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___9 ns;
	long unsigned int flags;
	struct key___323 *persistent_keyring_register;
	struct rw_semaphore___350 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___243 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___350 *pgtable_t___349;

struct address_space___348;

struct dev_pagemap___337;

struct page___350 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___348 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___350 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___349 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___349 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___337 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___349;

struct lruvec___349 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___349 *pgdat;
};

struct zone___349 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___349 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___349 {
	struct zone___349 *zone;
	int zone_idx;
};

struct zonelist___349 {
	struct zoneref___349 _zonerefs[25];
};

struct pglist_data___349 {
	struct zone___349 node_zones[3];
	struct zonelist___349 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___350 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___350 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___349 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___350 {
	void *stack;
	struct task_struct___350 *task;
	long int status;
};

struct blocking_notifier_head___349 {
	struct rw_semaphore___350 rwsem;
	struct notifier_block *head;
};

struct dentry___348;

struct path___349 {
	struct vfsmount *mnt;
	struct dentry___348 *dentry;
};

struct fown_struct___216 {
	rwlock_t lock;
	struct pid___216 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___349 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___349 f_path;
	struct inode___349 *f_inode;
	const struct file_operations___349 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___216 f_owner;
	const struct cred___323 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___348 *f_mapping;
	errseq_t f_wb_err;
};

struct user_struct___323;

struct cred___323 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___323 *session_keyring;
	struct key___323 *process_keyring;
	struct key___323 *thread_keyring;
	struct key___323 *request_key_auth;
	void *security;
	struct user_struct___323 *user;
	struct user_namespace___243 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___342;

struct kernfs_elem_dir___342 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___342 *root;
};

struct kernfs_node___343;

struct kernfs_syscall_ops___342;

struct kernfs_root___342 {
	struct kernfs_node___343 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___342 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___342 {
	struct kernfs_node___343 *target_kn;
};

struct kernfs_ops___342;

struct kernfs_elem_attr___342 {
	const struct kernfs_ops___342 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___343 *notify_next;
};

struct kernfs_node___343 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___343 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___342 dir;
		struct kernfs_elem_symlink___342 symlink;
		struct kernfs_elem_attr___342 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___342;

struct kernfs_ops___342 {
	int (*open)(struct kernfs_open_file___342 *);
	void (*release)(struct kernfs_open_file___342 *);
	int (*seq_show)(struct seq_file___296 *, void *);
	void * (*seq_start)(struct seq_file___296 *, loff_t *);
	void * (*seq_next)(struct seq_file___296 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___296 *, void *);
	ssize_t (*read)(struct kernfs_open_file___342 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___342 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___342 *, struct vm_area_struct___350 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___342 *, struct poll_table_struct___213 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___342 {
	int (*remount_fs)(struct kernfs_root___342 *, int *, char *);
	int (*show_options)(struct seq_file___296 *, struct kernfs_root___342 *);
	int (*mkdir)(struct kernfs_node___343 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___343 *);
	int (*rename)(struct kernfs_node___343 *, struct kernfs_node___343 *, const char *);
	int (*show_path)(struct seq_file___296 *, struct kernfs_node___343 *, struct kernfs_root___342 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___295;

struct seq_file___296 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___295 *op;
	int poll_event;
	const struct file___349 *file;
	void *private;
};

struct vm_operations_struct___337;

struct kernfs_open_file___342 {
	struct kernfs_node___343 *kn;
	struct file___349 *file;
	struct seq_file___296 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___337 *vm_ops;
};

struct vm_fault___337;

struct vm_operations_struct___337 {
	void (*open)(struct vm_area_struct___350 *);
	void (*close)(struct vm_area_struct___350 *);
	int (*split)(struct vm_area_struct___350 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___350 *);
	vm_fault_t (*fault)(struct vm_fault___337 *);
	vm_fault_t (*huge_fault)(struct vm_fault___337 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___337 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___350 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___337 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___337 *);
	int (*access)(struct vm_area_struct___350 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___350 *);
	int (*set_policy)(struct vm_area_struct___350 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___350 *, long unsigned int);
	struct page___350 * (*find_special_page)(struct vm_area_struct___350 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___219)(struct file___349 *, wait_queue_head_t *, struct poll_table_struct___213 *);

struct poll_table_struct___213 {
	poll_queue_proc___219 _qproc;
	__poll_t _key;
};

struct vm_area_struct___350 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___350 *vm_next;
	struct vm_area_struct___350 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___349 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___337 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___349 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___336;

struct bin_attribute___312;

struct attribute_group___313 {
	const char *name;
	umode_t (*is_visible)(struct kobject___336 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___336 *, struct bin_attribute___312 *, int);
	struct attribute **attrs;
	struct bin_attribute___312 **bin_attrs;
};

struct kset___335;

struct kobj_type___335;

struct kobject___336 {
	const char *name;
	struct list_head entry;
	struct kobject___336 *parent;
	struct kset___335 *kset;
	struct kobj_type___335 *ktype;
	struct kernfs_node___343 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___312 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___349 *, struct kobject___336 *, struct bin_attribute___312 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___349 *, struct kobject___336 *, struct bin_attribute___312 *, char *, loff_t, size_t);
	int (*mmap)(struct file___349 *, struct kobject___336 *, struct bin_attribute___312 *, struct vm_area_struct___350 *);
};

struct sysfs_ops___335 {
	ssize_t (*show)(struct kobject___336 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___336 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___335;

struct kset___335 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___336 kobj;
	const struct kset_uevent_ops___335 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___335 {
	void (*release)(struct kobject___336 *);
	const struct sysfs_ops___335 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___27 * (*child_ns_type)(struct kobject___336 *);
	const void * (*namespace)(struct kobject___336 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___335 {
	int (* const filter)(struct kset___335 *, struct kobject___336 *);
	const char * (* const name)(struct kset___335 *, struct kobject___336 *);
	int (* const uevent)(struct kset___335 *, struct kobject___336 *, struct kobj_uevent_env *);
};

struct kobj_attribute___327 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___336 *, struct kobj_attribute___327 *, char *);
	ssize_t (*store)(struct kobject___336 *, struct kobj_attribute___327 *, const char *, size_t);
};

struct kernel_param___283;

struct kernel_param_ops___283 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___283 *);
	int (*get)(char *, const struct kernel_param___283 *);
	void (*free)(void *);
};

struct kparam_array___283;

struct kernel_param___283 {
	const char *name;
	struct module___286 *mod;
	const struct kernel_param_ops___283 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___283 *arr;
	};
};

struct kparam_array___283 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___283 *ops;
	void *elem;
};

struct module_kobject___283 {
	struct kobject___336 kobj;
	struct module___286 *mod;
	struct kobject___336 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___283 {
	struct module___286 *mod;
	struct latch_tree_node node;
};

struct module_layout___283 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___283 mtn;
};

struct module_attribute___283;

struct module___286 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___283 mkobj;
	struct module_attribute___283 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___336 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___283 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___283 core_layout;
	struct module_layout___283 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___133 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___283 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___283 *, struct module_kobject___283 *, char *);
	ssize_t (*store)(struct module_attribute___283 *, struct module_kobject___283 *, const char *, size_t);
	void (*setup)(struct module___286 *, const char *);
	int (*test)(struct module___286 *);
	void (*free)(struct module___286 *);
};

struct trace_event_class___133;

struct trace_event_call___133 {
	struct list_head list;
	struct trace_event_class___133 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___13 event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___37 *prog_array;
	int (*perf_perm)(struct trace_event_call___133 *, struct perf_event___140 *);
};

struct upid___216 {
	int nr;
	struct pid_namespace___216 *ns;
};

struct pid_namespace___216 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___350 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___216 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___348 *proc_self;
	struct dentry___348 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___243 *user_ns;
	struct ucounts___243 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___9 ns;
};

struct pid___216 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___216 numbers[1];
};

struct user_struct___323 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___323 *uid_keyring;
	struct key___323 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___349;

struct mm_struct___349 {
	struct {
		struct vm_area_struct___350 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___349 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___350 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___349 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___350 *owner;
		struct user_namespace___243 *user_ns;
		struct file___349 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___349 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___228;

struct nsproxy___273 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___216 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___228 *cgroup_ns;
};

struct signal_struct___253 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___350 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___350 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___216 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___216 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___349 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___216 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide50;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___166;

struct bio_list___166 {
	struct bio___166 *head;
	struct bio___166 *tail;
};

struct bdi_writeback_congested___166;

struct cgroup_subsys_state___228;

struct bdi_writeback___166 {
	struct backing_dev_info___166 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___166 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___228 *memcg_css;
	struct cgroup_subsys_state___228 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___316;

struct backing_dev_info___166 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___166 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___316 *dev;
	struct device___316 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___348 *debug_dir;
	struct dentry___348 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___86;

struct io_context___86 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___86 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___228;

struct css_set___228 {
	struct cgroup_subsys_state___228 *subsys[13];
	refcount_t refcount;
	struct css_set___228 *dom_cset;
	struct cgroup___228 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___228 *mg_src_cgrp;
	struct cgroup___228 *mg_dst_cgrp;
	struct css_set___228 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___140 {
	struct pmu___140 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___350 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___140 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

typedef blk_qc_t make_request_fn___82(struct request_queue___82 *, struct bio___166 *);

struct request___82;

typedef int dma_drain_needed_fn___82(struct request___82 *);

struct bsg_ops___82;

struct bsg_class_device___82 {
	struct device___316 *class_dev;
	int minor;
	struct request_queue___82 *queue;
	const struct bsg_ops___82 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___166 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___166 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___82;

struct blk_mq_ops___20;

struct blk_mq_hw_ctx___20;

struct blk_mq_tag_set___20;

struct request_queue___82 {
	struct list_head queue_head;
	struct request___82 *last_merge;
	struct elevator_queue___82 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___82 *make_request_fn;
	dma_drain_needed_fn___82 *dma_drain_needed;
	const struct blk_mq_ops___20 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___20 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___166 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___336 kobj;
	struct kobject___336 *mq_kobj;
	struct blk_integrity integrity;
	struct device___316 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	struct bsg_class_device___82 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set___20 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___166 bio_split;
	struct dentry___348 *debugfs_dir;
	struct dentry___348 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___255 {
	struct vm_struct___255 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___350 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___265 {
	struct task_struct___350 task;
	long unsigned int stack[8192];
};

struct bio_vec___168 {
	struct page___350 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

typedef void bio_end_io_t___166(struct bio___166 *);

struct gendisk___86;

struct bio_integrity_payload___166;

struct bio___166 {
	struct bio___166 *bi_next;
	struct gendisk___86 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___166 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___166 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___168 *bi_io_vec;
	struct bio_set___166 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___168 bi_inline_vecs[0];
};

struct bio_integrity_payload___166 {
	struct bio___166 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___168 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___168 bip_inline_vecs[0];
};

struct dev_pm_info___316 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___5 *subsys_data;
	void (*set_latency_tolerance)(struct device___316 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___316;

struct bus_type___316;

struct device_driver___316;

struct dev_pm_domain___316;

struct dma_map_ops___105;

struct fwnode_handle___238;

struct class___316;

struct device___316 {
	struct device___316 *parent;
	struct device_private *p;
	struct kobject___336 kobj;
	const char *init_name;
	const struct device_type___316 *type;
	struct mutex mutex;
	struct bus_type___316 *bus;
	struct device_driver___316 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___316 power;
	struct dev_pm_domain___316 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___105 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___238 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___316 *class;
	const struct attribute_group___313 **groups;
	void (*release)(struct device___316 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___86 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___316 __dev;
	struct kobject___336 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___86;

struct block_device_operations___83;

struct gendisk___86 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___86 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___86 *part_tbl;
	struct hd_struct___86 part0;
	const struct block_device_operations___83 *fops;
	struct request_queue___82 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___350 lookup_sem;
	struct kobject___336 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___336 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_ops___316;

struct device_type___316 {
	const char *name;
	const struct attribute_group___313 **groups;
	int (*uevent)(struct device___316 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___316 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___316 *);
	const struct dev_pm_ops___316 *pm;
};

struct class___316 {
	const char *name;
	struct module___286 *owner;
	const struct attribute_group___313 **class_groups;
	const struct attribute_group___313 **dev_groups;
	struct kobject___336 *dev_kobj;
	int (*dev_uevent)(struct device___316 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___316 *, umode_t *);
	void (*class_release)(struct class___316 *);
	void (*dev_release)(struct device___316 *);
	int (*shutdown_pre)(struct device___316 *);
	const struct kobj_ns_type_operations___27 *ns_type;
	const void * (*namespace)(struct device___316 *);
	const struct dev_pm_ops___316 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dev_pm_ops___316 {
	int (*prepare)(struct device___316 *);
	void (*complete)(struct device___316 *);
	int (*suspend)(struct device___316 *);
	int (*resume)(struct device___316 *);
	int (*freeze)(struct device___316 *);
	int (*thaw)(struct device___316 *);
	int (*poweroff)(struct device___316 *);
	int (*restore)(struct device___316 *);
	int (*suspend_late)(struct device___316 *);
	int (*resume_early)(struct device___316 *);
	int (*freeze_late)(struct device___316 *);
	int (*thaw_early)(struct device___316 *);
	int (*poweroff_late)(struct device___316 *);
	int (*restore_early)(struct device___316 *);
	int (*suspend_noirq)(struct device___316 *);
	int (*resume_noirq)(struct device___316 *);
	int (*freeze_noirq)(struct device___316 *);
	int (*thaw_noirq)(struct device___316 *);
	int (*poweroff_noirq)(struct device___316 *);
	int (*restore_noirq)(struct device___316 *);
	int (*runtime_suspend)(struct device___316 *);
	int (*runtime_resume)(struct device___316 *);
	int (*runtime_idle)(struct device___316 *);
};

struct dev_pm_domain___316 {
	struct dev_pm_ops___316 ops;
	void (*detach)(struct device___316 *, bool);
	int (*activate)(struct device___316 *);
	void (*sync)(struct device___316 *);
	void (*dismiss)(struct device___316 *);
};

struct bus_type___316 {
	const char *name;
	const char *dev_name;
	struct device___316 *dev_root;
	const struct attribute_group___313 **bus_groups;
	const struct attribute_group___313 **dev_groups;
	const struct attribute_group___313 **drv_groups;
	int (*match)(struct device___316 *, struct device_driver___316 *);
	int (*uevent)(struct device___316 *, struct kobj_uevent_env *);
	int (*probe)(struct device___316 *);
	int (*remove)(struct device___316 *);
	void (*shutdown)(struct device___316 *);
	int (*online)(struct device___316 *);
	int (*offline)(struct device___316 *);
	int (*suspend)(struct device___316 *, pm_message_t);
	int (*resume)(struct device___316 *);
	int (*num_vf)(struct device___316 *);
	int (*dma_configure)(struct device___316 *);
	const struct dev_pm_ops___316 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___316 {
	const char *name;
	struct bus_type___316 *bus;
	struct module___286 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___316 *);
	int (*remove)(struct device___316 *);
	void (*shutdown)(struct device___316 *);
	int (*suspend)(struct device___316 *, pm_message_t);
	int (*resume)(struct device___316 *);
	const struct attribute_group___313 **groups;
	const struct dev_pm_ops___316 *pm;
	void (*coredump)(struct device___316 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_attribute___35 {
	struct attribute attr;
	ssize_t (*show)(struct device___316 *, struct device_attribute___35 *, char *);
	ssize_t (*store)(struct device___316 *, struct device_attribute___35 *, const char *, size_t);
};

struct dma_map_ops___105 {
	void * (*alloc)(struct device___316 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___316 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___316 *, struct vm_area_struct___350 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___316 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___316 *, struct page___350 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___316 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___316 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___316 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___316 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___316 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___316 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide42;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___316 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___316 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___316 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___316 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___316 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___316 *, u64);
	u64 (*get_required_mask)(struct device___316 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___238;

struct fwnode_handle___238 {
	struct fwnode_handle___238 *secondary;
	const struct fwnode_operations___238 *ops;
};

struct dentry_operations___348;

struct super_block___348;

struct dentry___348 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___348 *d_parent;
	struct qstr d_name;
	struct inode___349 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___348 *d_op;
	struct super_block___348 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___348;

struct address_space___348 {
	struct inode___349 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___350 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___348 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___348;

struct block_device___348;

struct inode___349 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___348 *i_op;
	struct super_block___348 *i_sb;
	struct address_space___348 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___350 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___166 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___349 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___348 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___348 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___348 {
	int (*d_revalidate)(struct dentry___348 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___348 *, unsigned int);
	int (*d_hash)(const struct dentry___348 *, struct qstr *);
	int (*d_compare)(const struct dentry___348 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___348 *);
	int (*d_init)(struct dentry___348 *);
	void (*d_release)(struct dentry___348 *);
	void (*d_prune)(struct dentry___348 *);
	void (*d_iput)(struct dentry___348 *, struct inode___349 *);
	char * (*d_dname)(struct dentry___348 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___349 *);
	int (*d_manage)(const struct path___349 *, bool);
	struct dentry___348 * (*d_real)(struct dentry___348 *, const struct inode___349 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___348;

struct mem_dqinfo___348 {
	struct quota_format_type___348 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___348;

struct quota_info___348 {
	unsigned int flags;
	struct rw_semaphore___350 dqio_sem;
	struct inode___349 *files[3];
	struct mem_dqinfo___348 info[3];
	const struct quota_format_ops___348 *ops[3];
};

struct rcuwait___348 {
	struct task_struct___350 *task;
};

struct percpu_rw_semaphore___348 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___350 rw_sem;
	struct rcuwait___348 writer;
	int readers_block;
};

struct sb_writers___348 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___348 rw_sem[3];
};

struct file_system_type___348;

struct super_operations___348;

struct dquot_operations___348;

struct quotactl_ops___348;

struct super_block___348 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___348 *s_type;
	const struct super_operations___348 *s_op;
	const struct dquot_operations___348 *dq_op;
	const struct quotactl_ops___348 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___348 *s_root;
	struct rw_semaphore___350 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___348 *s_bdev;
	struct backing_dev_info___166 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___348 s_dquot;
	struct sb_writers___348 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___348 *s_d_op;
	int cleancache_poolid;
	struct shrinker___130 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___243 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

typedef int (*dev_page_fault_t___337)(struct vm_area_struct___350 *, long unsigned int, const struct page___350 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___337)(struct page___350 *, void *);

struct dev_pagemap___337 {
	dev_page_fault_t___337 page_fault;
	dev_page_free_t___337 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___316 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___349 {
	struct task_struct___350 *task;
	struct core_thread___349 *next;
};

struct core_state___349 {
	atomic_t nr_threads;
	struct core_thread___349 dumper;
	struct completion startup;
};

struct vm_fault___337 {
	struct vm_area_struct___350 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___350 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___350 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___349 prealloc_pte;
};

struct io_cq___86 {
	struct request_queue___82 *q;
	struct io_context___86 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___349 {
	struct file___349 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___349 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___348 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___349 *ia_file;
};

struct dquot___348 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___348 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___348 {
	int qf_fmt_id;
	const struct quota_format_ops___348 *qf_ops;
	struct module___286 *qf_owner;
	struct quota_format_type___348 *qf_next;
};

struct quota_format_ops___348 {
	int (*check_quota_file)(struct super_block___348 *, int);
	int (*read_file_info)(struct super_block___348 *, int);
	int (*write_file_info)(struct super_block___348 *, int);
	int (*free_file_info)(struct super_block___348 *, int);
	int (*read_dqblk)(struct dquot___348 *);
	int (*commit_dqblk)(struct dquot___348 *);
	int (*release_dqblk)(struct dquot___348 *);
	int (*get_next_id)(struct super_block___348 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___348 {
	int (*write_dquot)(struct dquot___348 *);
	struct dquot___348 * (*alloc_dquot)(struct super_block___348 *, int);
	void (*destroy_dquot)(struct dquot___348 *);
	int (*acquire_dquot)(struct dquot___348 *);
	int (*release_dquot)(struct dquot___348 *);
	int (*mark_dirty)(struct dquot___348 *);
	int (*write_info)(struct super_block___348 *, int);
	qsize_t * (*get_reserved_space)(struct inode___349 *);
	int (*get_projid)(struct inode___349 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___349 *, qsize_t *);
	int (*get_next_id)(struct super_block___348 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___348 {
	int (*quota_on)(struct super_block___348 *, int, int, const struct path___349 *);
	int (*quota_off)(struct super_block___348 *, int);
	int (*quota_enable)(struct super_block___348 *, unsigned int);
	int (*quota_disable)(struct super_block___348 *, unsigned int);
	int (*quota_sync)(struct super_block___348 *, int);
	int (*set_info)(struct super_block___348 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___348 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___348 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___348 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___348 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___348 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___348 {
	int (*writepage)(struct page___350 *, struct writeback_control___3 *);
	int (*readpage)(struct file___349 *, struct page___350 *);
	int (*writepages)(struct address_space___348 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___350 *);
	int (*readpages)(struct file___349 *, struct address_space___348 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___349 *, struct address_space___348 *, loff_t, unsigned int, unsigned int, struct page___350 **, void **);
	int (*write_end)(struct file___349 *, struct address_space___348 *, loff_t, unsigned int, unsigned int, struct page___350 *, void *);
	sector_t (*bmap)(struct address_space___348 *, sector_t);
	void (*invalidatepage)(struct page___350 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___350 *, gfp_t);
	void (*freepage)(struct page___350 *);
	ssize_t (*direct_IO)(struct kiocb___349 *, struct iov_iter___153 *);
	int (*migratepage)(struct address_space___348 *, struct page___350 *, struct page___350 *, enum migrate_mode);
	bool (*isolate_page)(struct page___350 *, isolate_mode_t);
	void (*putback_page)(struct page___350 *);
	int (*launder_page)(struct page___350 *);
	int (*is_partially_uptodate)(struct page___350 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___350 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___348 *, struct page___350 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___349 *, sector_t *);
	void (*swap_deactivate)(struct file___349 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct iov_iter___153 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___168 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___348 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___349 *bd_inode;
	struct super_block___348 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___348 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___86 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___86 *bd_disk;
	struct request_queue___82 *bd_queue;
	struct backing_dev_info___166 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___348 {
	struct dentry___348 * (*lookup)(struct inode___349 *, struct dentry___348 *, unsigned int);
	const char * (*get_link)(struct dentry___348 *, struct inode___349 *, struct delayed_call *);
	int (*permission)(struct inode___349 *, int);
	struct posix_acl * (*get_acl)(struct inode___349 *, int);
	int (*readlink)(struct dentry___348 *, char *, int);
	int (*create)(struct inode___349 *, struct dentry___348 *, umode_t, bool);
	int (*link)(struct dentry___348 *, struct inode___349 *, struct dentry___348 *);
	int (*unlink)(struct inode___349 *, struct dentry___348 *);
	int (*symlink)(struct inode___349 *, struct dentry___348 *, const char *);
	int (*mkdir)(struct inode___349 *, struct dentry___348 *, umode_t);
	int (*rmdir)(struct inode___349 *, struct dentry___348 *);
	int (*mknod)(struct inode___349 *, struct dentry___348 *, umode_t, dev_t);
	int (*rename)(struct inode___349 *, struct dentry___348 *, struct inode___349 *, struct dentry___348 *, unsigned int);
	int (*setattr)(struct dentry___348 *, struct iattr___348 *);
	int (*getattr)(const struct path___349 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___348 *, char *, size_t);
	int (*fiemap)(struct inode___349 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___349 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___349 *, struct dentry___348 *, struct file___349 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___349 *, struct dentry___348 *, umode_t);
	int (*set_acl)(struct inode___349 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___348 {
	void (*fl_copy_lock)(struct file_lock___349 *, struct file_lock___349 *);
	void (*fl_release_private)(struct file_lock___349 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___348;

struct file_lock___349 {
	struct file_lock___349 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___349 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___348 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___348 *fl_ops;
	const struct lock_manager_operations___348 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___348 {
	int (*lm_compare_owner)(struct file_lock___349 *, struct file_lock___349 *);
	long unsigned int (*lm_owner_key)(struct file_lock___349 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___349 *);
	int (*lm_grant)(struct file_lock___349 *, int);
	bool (*lm_break)(struct file_lock___349 *);
	int (*lm_change)(struct file_lock___349 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___349 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___348 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___348 *fa_next;
	struct file___349 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___348 {
	const char *name;
	int fs_flags;
	struct dentry___348 * (*mount)(struct file_system_type___348 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___348 *);
	struct module___286 *owner;
	struct file_system_type___348 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___348 {
	struct inode___349 * (*alloc_inode)(struct super_block___348 *);
	void (*destroy_inode)(struct inode___349 *);
	void (*dirty_inode)(struct inode___349 *, int);
	int (*write_inode)(struct inode___349 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___349 *);
	void (*evict_inode)(struct inode___349 *);
	void (*put_super)(struct super_block___348 *);
	int (*sync_fs)(struct super_block___348 *, int);
	int (*freeze_super)(struct super_block___348 *);
	int (*freeze_fs)(struct super_block___348 *);
	int (*thaw_super)(struct super_block___348 *);
	int (*unfreeze_fs)(struct super_block___348 *);
	int (*statfs)(struct dentry___348 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___348 *, int *, char *);
	void (*umount_begin)(struct super_block___348 *);
	int (*show_options)(struct seq_file___296 *, struct dentry___348 *);
	int (*show_devname)(struct seq_file___296 *, struct dentry___348 *);
	int (*show_path)(struct seq_file___296 *, struct dentry___348 *);
	int (*show_stats)(struct seq_file___296 *, struct dentry___348 *);
	ssize_t (*quota_read)(struct super_block___348 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___348 *, int, const char *, size_t, loff_t);
	struct dquot___348 ** (*get_dquots)(struct inode___349 *);
	int (*bdev_try_to_free_page)(struct super_block___348 *, struct page___350 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___348 *, struct shrink_control___130 *);
	long int (*free_cached_objects)(struct super_block___348 *, struct shrink_control___130 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___86 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___86 *last_lookup;
	struct hd_struct___86 *part[0];
};

struct block_device_operations___83 {
	int (*open)(struct block_device___348 *, fmode_t);
	void (*release)(struct gendisk___86 *, fmode_t);
	int (*rw_page)(struct block_device___348 *, sector_t, struct page___350 *, unsigned int);
	int (*ioctl)(struct block_device___348 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___348 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___86 *, unsigned int);
	int (*media_changed)(struct gendisk___86 *);
	void (*unlock_native_capacity)(struct gendisk___86 *);
	int (*revalidate_disk)(struct gendisk___86 *);
	int (*getgeo)(struct block_device___348 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___348 *, long unsigned int);
	int (*report_zones)(struct gendisk___86 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___286 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___337(struct page___350 *);

struct bdi_writeback_congested___166 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___166 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct cgroup_subsys___228;

struct cgroup_subsys_state___228 {
	struct cgroup___228 *cgroup;
	struct cgroup_subsys___228 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___228 *parent;
};

struct bsg_ops___82 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___82 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___82 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___82 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___82(struct request___82 *, blk_status_t);

struct request___82 {
	struct request_queue___82 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___20 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___166 *bio;
	struct bio___166 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___168 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___86 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___82 *saved_end_io;
		} flush;
	};
	struct gendisk___86 *rq_disk;
	struct hd_struct___86 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___82 *end_io;
	void *end_io_data;
	struct request___82 *next_rq;
};

struct fwnode_reference_args___238;

struct fwnode_endpoint___238;

struct fwnode_operations___238 {
	struct fwnode_handle___238 * (*get)(struct fwnode_handle___238 *);
	void (*put)(struct fwnode_handle___238 *);
	bool (*device_is_available)(const struct fwnode_handle___238 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___238 *, const struct device___316 *);
	bool (*property_present)(const struct fwnode_handle___238 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___238 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___238 *, const char *, const char **, size_t);
	struct fwnode_handle___238 * (*get_parent)(const struct fwnode_handle___238 *);
	struct fwnode_handle___238 * (*get_next_child_node)(const struct fwnode_handle___238 *, struct fwnode_handle___238 *);
	struct fwnode_handle___238 * (*get_named_child_node)(const struct fwnode_handle___238 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___238 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___238 *);
	struct fwnode_handle___238 * (*graph_get_next_endpoint)(const struct fwnode_handle___238 *, struct fwnode_handle___238 *);
	struct fwnode_handle___238 * (*graph_get_remote_endpoint)(const struct fwnode_handle___238 *);
	struct fwnode_handle___238 * (*graph_get_port_parent)(struct fwnode_handle___238 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___238 *, struct fwnode_endpoint___238 *);
};

struct fwnode_endpoint___238 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___238 *local_fwnode;
};

struct fwnode_reference_args___238 {
	struct fwnode_handle___238 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct blk_mq_hw_ctx___20 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___82 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags___4 *tags;
	struct blk_mq_tags___4 *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	unsigned int rh_reserved_nr_expired;
	struct hlist_node cpuhp_dead;
	struct kobject___336 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___348 *debugfs_dir;
	struct dentry___348 *sched_debugfs_dir;
	struct list_head hctx_list;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___82;

struct elevator_mq_ops___82 {
	int (*init_sched)(struct request_queue___82 *, struct elevator_type___82 *);
	void (*exit_sched)(struct elevator_queue___82 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___20 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___20 *, unsigned int);
	bool (*allow_merge)(struct request_queue___82 *, struct request___82 *, struct bio___166 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx___20 *, struct bio___166 *);
	int (*request_merge)(struct request_queue___82 *, struct request___82 **, struct bio___166 *);
	void (*request_merged)(struct request_queue___82 *, struct request___82 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___82 *, struct request___82 *, struct request___82 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___82 *, struct bio___166 *);
	void (*finish_request)(struct request___82 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___20 *, struct list_head *, bool);
	struct request___82 * (*dispatch_request)(struct blk_mq_hw_ctx___20 *);
	bool (*has_work)(struct blk_mq_hw_ctx___20 *);
	void (*completed_request)(struct request___82 *, u64);
	void (*started_request)(struct request___82 *);
	void (*requeue_request)(struct request___82 *);
	struct request___82 * (*former_request)(struct request_queue___82 *, struct request___82 *);
	struct request___82 * (*next_request)(struct request_queue___82 *, struct request___82 *);
	void (*init_icq)(struct io_cq___86 *);
	void (*exit_icq)(struct io_cq___86 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx___20 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___82;

struct elevator_type___82 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___82 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___82 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___286 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___82 {
	struct elevator_type___82 *type;
	void *elevator_data;
	struct kobject___336 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___82 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___82 *, char *);
	ssize_t (*store)(struct elevator_queue___82 *, const char *, size_t);
};

struct blk_mq_queue_data___20;

typedef blk_status_t queue_rq_fn___20(struct blk_mq_hw_ctx___20 *, const struct blk_mq_queue_data___20 *);

typedef void commit_rqs_fn___20(struct blk_mq_hw_ctx___20 *);

typedef bool get_budget_fn___20(struct blk_mq_hw_ctx___20 *);

typedef void put_budget_fn___20(struct blk_mq_hw_ctx___20 *);

typedef enum blk_eh_timer_return timeout_fn___20(struct request___82 *, bool);

typedef int poll_fn___20(struct blk_mq_hw_ctx___20 *);

typedef void complete_fn___20(struct request___82 *);

typedef int init_hctx_fn___20(struct blk_mq_hw_ctx___20 *, void *, unsigned int);

typedef void exit_hctx_fn___20(struct blk_mq_hw_ctx___20 *, unsigned int);

typedef int init_request_fn___20(struct blk_mq_tag_set___20 *, struct request___82 *, unsigned int, unsigned int);

typedef void exit_request_fn___20(struct blk_mq_tag_set___20 *, struct request___82 *, unsigned int);

typedef bool busy_fn___20(struct request_queue___82 *);

typedef int map_queues_fn___20(struct blk_mq_tag_set___20 *);

typedef void cleanup_rq_fn___20(struct request___82 *);

struct blk_mq_ops___20 {
	queue_rq_fn___20 *queue_rq;
	commit_rqs_fn___20 *commit_rqs;
	get_budget_fn___20 *get_budget;
	put_budget_fn___20 *put_budget;
	timeout_fn___20 *timeout;
	poll_fn___20 *poll;
	complete_fn___20 *complete;
	init_hctx_fn___20 *init_hctx;
	exit_hctx_fn___20 *exit_hctx;
	init_request_fn___20 *init_request;
	exit_request_fn___20 *exit_request;
	void (*initialize_rq_fn)(struct request___82 *);
	busy_fn___20 *busy;
	map_queues_fn___20 *map_queues;
	void (*show_rq)(struct seq_file___296 *, struct request___82 *);
	union {
		cleanup_rq_fn___20 *cleanup_rq;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide47;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct blk_mq_tag_set___20 {
	struct blk_mq_queue_map map[6];
	unsigned int nr_maps;
	const struct blk_mq_ops___20 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	struct blk_mq_tags___4 **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct node___204 {
	struct device___316 dev;
};

struct scsi_sense_hdr {
	u8 response_code;
	u8 sense_key;
	u8 asc;
	u8 ascq;
	u8 byte4;
	u8 byte5;
	u8 byte6;
	u8 additional_length;
};

typedef __u64 blist_flags_t;

enum scsi_device_state {
	SDEV_CREATED = 1,
	SDEV_RUNNING = 2,
	SDEV_CANCEL = 3,
	SDEV_DEL = 4,
	SDEV_QUIESCE = 5,
	SDEV_OFFLINE = 6,
	SDEV_TRANSPORT_OFFLINE = 7,
	SDEV_BLOCK = 8,
	SDEV_CREATED_BLOCK = 9,
};

struct scsi_vpd {
	struct callback_head rcu;
	int len;
	unsigned char data[0];
};

struct Scsi_Host;

struct scsi_target;

struct scsi_device_handler;

struct scsi_device {
	struct Scsi_Host *host;
	struct request_queue___82 *request_queue;
	struct list_head siblings;
	struct list_head same_target_siblings;
	atomic_t device_busy;
	atomic_t device_blocked;
	spinlock_t list_lock;
	struct list_head cmd_list;
	struct list_head starved_entry;
	short unsigned int queue_depth;
	short unsigned int max_queue_depth;
	short unsigned int last_queue_full_depth;
	short unsigned int last_queue_full_count;
	long unsigned int last_queue_full_time;
	long unsigned int queue_ramp_up_period;
	long unsigned int last_queue_ramp_up;
	unsigned int id;
	unsigned int channel;
	u64 lun;
	unsigned int manufacturer;
	unsigned int sector_size;
	void *hostdata;
	unsigned char type;
	char scsi_level;
	char inq_periph_qual;
	struct mutex inquiry_mutex;
	unsigned char inquiry_len;
	unsigned char *inquiry;
	const char *vendor;
	const char *model;
	const char *rev;
	struct scsi_vpd *vpd_pg83;
	struct scsi_vpd *vpd_pg80;
	unsigned char current_tag;
	struct scsi_target *sdev_target;
	blist_flags_t sdev_bflags;
	unsigned int eh_timeout;
	unsigned int removable: 1;
	unsigned int changed: 1;
	unsigned int busy: 1;
	unsigned int lockable: 1;
	unsigned int locked: 1;
	unsigned int borken: 1;
	unsigned int disconnect: 1;
	unsigned int soft_reset: 1;
	unsigned int sdtr: 1;
	unsigned int wdtr: 1;
	unsigned int ppr: 1;
	unsigned int tagged_supported: 1;
	unsigned int simple_tags: 1;
	unsigned int was_reset: 1;
	unsigned int expecting_cc_ua: 1;
	unsigned int use_10_for_rw: 1;
	unsigned int use_10_for_ms: 1;
	unsigned int no_report_opcodes: 1;
	unsigned int no_write_same: 1;
	unsigned int use_16_for_rw: 1;
	unsigned int skip_ms_page_8: 1;
	unsigned int skip_ms_page_3f: 1;
	unsigned int skip_vpd_pages: 1;
	unsigned int try_vpd_pages: 1;
	unsigned int use_192_bytes_for_3f: 1;
	unsigned int no_start_on_add: 1;
	unsigned int allow_restart: 1;
	unsigned int manage_start_stop: 1;
	unsigned int start_stop_pwr_cond: 1;
	unsigned int no_uld_attach: 1;
	unsigned int select_no_atn: 1;
	unsigned int fix_capacity: 1;
	unsigned int guess_capacity: 1;
	unsigned int retry_hwerror: 1;
	unsigned int last_sector_bug: 1;
	unsigned int no_read_disc_info: 1;
	unsigned int no_read_capacity_16: 1;
	unsigned int try_rc_10_first: 1;
	unsigned int security_supported: 1;
	unsigned int is_visible: 1;
	unsigned int wce_default_on: 1;
	unsigned int no_dif: 1;
	unsigned int broken_fua: 1;
	unsigned int lun_in_cdb: 1;
	unsigned int unmap_limit_for_ws: 1;
	atomic_t disk_events_disable_depth;
	long unsigned int supported_events[1];
	long unsigned int pending_events[1];
	struct list_head event_list;
	struct work_struct event_work;
	unsigned int max_device_blocked;
	atomic_t iorequest_cnt;
	atomic_t iodone_cnt;
	atomic_t ioerr_cnt;
	struct device___316 sdev_gendev;
	struct device___316 sdev_dev;
	struct execute_work ew;
	struct work_struct requeue_work;
	struct scsi_device_handler *handler;
	void *handler_data;
	unsigned char access_state;
	struct mutex state_mutex;
	enum scsi_device_state sdev_state;
	struct task_struct___350 *quiesced_by;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int sdev_data[0];
};

enum scsi_host_state {
	SHOST_CREATED = 1,
	SHOST_RUNNING = 2,
	SHOST_CANCEL = 3,
	SHOST_DEL = 4,
	SHOST_RECOVERY = 5,
	SHOST_CANCEL_RECOVERY = 6,
	SHOST_DEL_RECOVERY = 7,
};

struct scsi_host_template;

struct scsi_transport_template;

struct Scsi_Host {
	struct list_head __devices;
	struct list_head __targets;
	struct list_head starved_list;
	spinlock_t default_lock;
	spinlock_t *host_lock;
	struct mutex scan_mutex;
	struct list_head eh_cmd_q;
	struct task_struct___350 *ehandler;
	struct completion *eh_action;
	wait_queue_head_t host_wait;
	struct scsi_host_template *hostt;
	struct scsi_transport_template *transportt;
	struct blk_mq_tag_set___20 tag_set;
	atomic_t host_busy;
	atomic_t host_blocked;
	unsigned int host_failed;
	unsigned int host_eh_scheduled;
	unsigned int host_no;
	int eh_deadline;
	long unsigned int last_reset;
	unsigned int max_channel;
	unsigned int max_id;
	u64 max_lun;
	unsigned int unique_id;
	short unsigned int max_cmd_len;
	int this_id;
	int can_queue;
	short int cmd_per_lun;
	short unsigned int sg_tablesize;
	short unsigned int sg_prot_tablesize;
	unsigned int max_sectors;
	long unsigned int dma_boundary;
	unsigned int nr_hw_queues;
	long unsigned int cmd_serial_number;
	unsigned int active_mode: 2;
	unsigned int unchecked_isa_dma: 1;
	unsigned int use_clustering: 1;
	unsigned int host_self_blocked: 1;
	unsigned int reverse_ordering: 1;
	unsigned int tmf_in_progress: 1;
	unsigned int async_scan: 1;
	unsigned int eh_noresume: 1;
	unsigned int no_write_same: 1;
	unsigned int use_cmd_list: 1;
	unsigned int short_inquiry: 1;
	char work_q_name[20];
	struct workqueue_struct *work_q;
	struct workqueue_struct *tmf_work_q;
	unsigned int no_scsi2_lun_in_cdb: 1;
	unsigned int max_host_blocked;
	unsigned int prot_capabilities;
	unsigned char prot_guard_type;
	long unsigned int base;
	long unsigned int io_port;
	unsigned char n_io_port;
	unsigned char dma_channel;
	unsigned int irq;
	enum scsi_host_state shost_state;
	struct device___316 shost_gendev;
	struct device___316 shost_dev;
	void *shost_data;
	struct device___316 *dma_dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int hostdata[0];
};

enum scsi_target_state {
	STARGET_CREATED = 1,
	STARGET_RUNNING = 2,
	STARGET_REMOVE = 3,
	STARGET_CREATED_REMOVE = 4,
	STARGET_DEL = 5,
};

struct scsi_target {
	struct scsi_device *starget_sdev_user;
	struct list_head siblings;
	struct list_head devices;
	struct device___316 dev;
	struct kref reap_ref;
	unsigned int channel;
	unsigned int id;
	unsigned int create: 1;
	unsigned int single_lun: 1;
	unsigned int pdt_1f_for_no_lun: 1;
	unsigned int no_report_luns: 1;
	unsigned int expecting_lun_change: 1;
	atomic_t target_busy;
	atomic_t target_blocked;
	unsigned int can_queue;
	unsigned int max_target_blocked;
	char scsi_level;
	enum scsi_target_state state;
	void *hostdata;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int starget_data[0];
};

struct blk_mq_queue_data___20 {
	struct request___82 *rq;
	bool last;
	long unsigned int rh_reserved1;
};

struct scsi_data_buffer {
	struct sg_table table;
	unsigned int length;
	int resid;
};

struct scsi_pointer {
	char *ptr;
	int this_residual;
	struct scatterlist *buffer;
	int buffers_residual;
	dma_addr_t dma_handle;
	volatile int Status;
	volatile int Message;
	volatile int have_data_in;
	volatile int sent_command;
	volatile int phase;
};

struct scsi_cmnd {
	struct scsi_request req;
	struct scsi_device *device;
	struct list_head list;
	struct list_head eh_entry;
	struct delayed_work abort_work;
	struct callback_head rcu;
	int eh_eflags;
	long unsigned int serial_number;
	long unsigned int jiffies_at_alloc;
	int retries;
	int allowed;
	unsigned char prot_op;
	unsigned char prot_type;
	unsigned char prot_flags;
	short unsigned int cmd_len;
	enum dma_data_direction sc_data_direction;
	unsigned char *cmnd;
	struct scsi_data_buffer sdb;
	struct scsi_data_buffer *prot_sdb;
	unsigned int underflow;
	unsigned int transfersize;
	struct request___82 *request;
	unsigned char *sense_buffer;
	void (*scsi_done)(struct scsi_cmnd *);
	struct scsi_pointer SCp;
	unsigned char *host_scribble;
	int result;
	int flags;
	long unsigned int state;
	unsigned char tag;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

enum scsi_prot_operations {
	SCSI_PROT_NORMAL = 0,
	SCSI_PROT_READ_INSERT = 1,
	SCSI_PROT_WRITE_STRIP = 2,
	SCSI_PROT_READ_STRIP = 3,
	SCSI_PROT_WRITE_INSERT = 4,
	SCSI_PROT_READ_PASS = 5,
	SCSI_PROT_WRITE_PASS = 6,
};

struct scsi_driver {
	struct device_driver___316 gendrv;
	void (*rescan)(struct device___316 *);
	blk_status_t (*init_command)(struct scsi_cmnd *);
	void (*uninit_command)(struct scsi_cmnd *);
	int (*done)(struct scsi_cmnd *);
	int (*eh_action)(struct scsi_cmnd *, int);
	void (*eh_reset)(struct scsi_cmnd *);
};

typedef int (*key_restrict_link_func_t___324)(struct key___323 *, const struct key_type *, const union key_payload *, struct key___323 *);

struct key_restriction___323;

struct key___323 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___350 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___323 *restrict_link;
};

struct key_restriction___323 {
	key_restrict_link_func_t___324 check;
	struct key___323 *key;
	struct key_type *keytype;
};

struct seq_operations___295 {
	void * (*start)(struct seq_file___296 *, loff_t *);
	void (*stop)(struct seq_file___296 *, void *);
	void * (*next)(struct seq_file___296 *, void *, loff_t *);
	int (*show)(struct seq_file___296 *, void *);
};

struct scsi_host_cmd_pool;

struct scsi_host_template {
	struct module___286 *module;
	const char *name;
	const char * (*info)(struct Scsi_Host *);
	int (*ioctl)(struct scsi_device *, int, void *);
	int (*queuecommand)(struct Scsi_Host *, struct scsi_cmnd *);
	int (*eh_abort_handler)(struct scsi_cmnd *);
	int (*eh_device_reset_handler)(struct scsi_cmnd *);
	int (*eh_target_reset_handler)(struct scsi_cmnd *);
	int (*eh_bus_reset_handler)(struct scsi_cmnd *);
	int (*eh_host_reset_handler)(struct scsi_cmnd *);
	int (*slave_alloc)(struct scsi_device *);
	int (*slave_configure)(struct scsi_device *);
	void (*slave_destroy)(struct scsi_device *);
	int (*target_alloc)(struct scsi_target *);
	void (*target_destroy)(struct scsi_target *);
	int (*scan_finished)(struct Scsi_Host *, long unsigned int);
	void (*scan_start)(struct Scsi_Host *);
	int (*change_queue_depth)(struct scsi_device *, int);
	int (*map_queues)(struct Scsi_Host *);
	int (*bios_param)(struct scsi_device *, struct block_device___348 *, sector_t, int *);
	void (*unlock_native_capacity)(struct scsi_device *);
	int (*show_info)(struct seq_file___296 *, struct Scsi_Host *);
	int (*write_info)(struct Scsi_Host *, char *, int);
	enum blk_eh_timer_return (*eh_timed_out)(struct scsi_cmnd *);
	int (*host_reset)(struct Scsi_Host *, int);
	const char *proc_name;
	struct proc_dir_entry *proc_dir;
	int can_queue;
	int this_id;
	short unsigned int sg_tablesize;
	short unsigned int sg_prot_tablesize;
	unsigned int max_sectors;
	long unsigned int dma_boundary;
	short int cmd_per_lun;
	unsigned char present;
	int tag_alloc_policy;
	unsigned int track_queue_depth: 1;
	unsigned int supported_mode: 2;
	unsigned int unchecked_isa_dma: 1;
	unsigned int use_clustering: 1;
	unsigned int emulated: 1;
	unsigned int skip_settle_delay: 1;
	unsigned int no_write_same: 1;
	unsigned int force_blk_mq: 1;
	unsigned int max_host_blocked;
	struct device_attribute___35 **shost_attrs;
	struct device_attribute___35 **sdev_attrs;
	const struct attribute_group___313 **sdev_groups;
	u64 vendor_id;
	unsigned int cmd_size;
	struct scsi_host_cmd_pool *cmd_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_namespace___228 {
	refcount_t count;
	struct ns_common___9 ns;
	struct user_namespace___243 *user_ns;
	struct ucounts___243 *ucounts;
	struct css_set___228 *root_cset;
};

struct ucounts___243 {
	struct hlist_node node;
	struct user_namespace___243 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___229;

struct bpf_map_ops___228 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___229 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___229 *, struct file___349 *);
	void (*map_free)(struct bpf_map___229 *);
	int (*map_get_next_key)(struct bpf_map___229 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___229 *);
	void * (*map_lookup_elem)(struct bpf_map___229 *, void *);
	int (*map_update_elem)(struct bpf_map___229 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___229 *, void *);
	int (*map_push_elem)(struct bpf_map___229 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___229 *, void *);
	int (*map_peek_elem)(struct bpf_map___229 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___229 *, struct file___349 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___229 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___229 *, void *, struct seq_file___296 *);
	int (*map_check_btf)(const struct bpf_map___229 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___229 {
	const struct bpf_map_ops___228 *ops;
	struct bpf_map___229 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___323 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___228;

typedef void (*kthread_work_func_t___228)(struct kthread_work___228 *);

struct kthread_worker___228;

struct kthread_work___228 {
	struct list_head node;
	kthread_work_func_t___228 func;
	struct kthread_worker___228 *worker;
	int canceling;
};

struct kthread_worker___228 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___350 *task;
	struct kthread_work___228 *current_work;
};

struct kthread_delayed_work___228 {
	struct kthread_work___228 work;
	struct timer_list timer;
};

struct psi_group___228 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___228 *poll_kworker;
	struct kthread_delayed_work___228 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___228 {
	struct kernfs_node___343 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_root___228;

struct cgroup_rstat_cpu___228;

struct cgroup___228 {
	struct cgroup_subsys_state___228 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___343 *kn;
	struct cgroup_file___228 procs_file;
	struct cgroup_file___228 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___228 *subsys[13];
	struct cgroup_root___228 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___228 *dom_cgrp;
	struct cgroup_rstat_cpu___228 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___37 bpf;
	atomic_t congestion_count;
	struct cgroup___228 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___228 psi;
	int ancestor_ids[0];
};

struct cftype___228;

struct cgroup_subsys___228 {
	struct cgroup_subsys_state___228 * (*css_alloc)(struct cgroup_subsys_state___228 *);
	int (*css_online)(struct cgroup_subsys_state___228 *);
	void (*css_offline)(struct cgroup_subsys_state___228 *);
	void (*css_released)(struct cgroup_subsys_state___228 *);
	void (*css_free)(struct cgroup_subsys_state___228 *);
	void (*css_reset)(struct cgroup_subsys_state___228 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___228 *, int);
	int (*css_extra_stat_show)(struct seq_file___296 *, struct cgroup_subsys_state___228 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___350 *);
	void (*cancel_fork)(struct task_struct___350 *);
	void (*fork)(struct task_struct___350 *);
	void (*exit)(struct task_struct___350 *);
	void (*free)(struct task_struct___350 *);
	void (*bind)(struct cgroup_subsys_state___228 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___228 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___228 *dfl_cftypes;
	struct cftype___228 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___228 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___228 *updated_children;
	struct cgroup___228 *updated_next;
};

struct cgroup_root___228 {
	struct kernfs_root___342 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___228 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___228 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___228 *ss;
	struct list_head node;
	struct kernfs_ops___342 *kf_ops;
	int (*open)(struct kernfs_open_file___342 *);
	void (*release)(struct kernfs_open_file___342 *);
	u64 (*read_u64)(struct cgroup_subsys_state___228 *, struct cftype___228 *);
	s64 (*read_s64)(struct cgroup_subsys_state___228 *, struct cftype___228 *);
	int (*seq_show)(struct seq_file___296 *, void *);
	void * (*seq_start)(struct seq_file___296 *, loff_t *);
	void * (*seq_next)(struct seq_file___296 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___296 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___228 *, struct cftype___228 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___228 *, struct cftype___228 *, s64);
	ssize_t (*write)(struct kernfs_open_file___342 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___342 *, struct poll_table_struct___213 *);
};

struct perf_cpu_context___140;

struct pmu___140 {
	struct list_head entry;
	struct module___286 *module;
	struct device___316 *dev;
	const struct attribute_group___313 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___140 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___140 *);
	void (*pmu_disable)(struct pmu___140 *);
	int (*event_init)(struct perf_event___140 *);
	void (*event_mapped)(struct perf_event___140 *, struct mm_struct___349 *);
	void (*event_unmapped)(struct perf_event___140 *, struct mm_struct___349 *);
	int (*add)(struct perf_event___140 *, int);
	void (*del)(struct perf_event___140 *, int);
	void (*start)(struct perf_event___140 *, int);
	void (*stop)(struct perf_event___140 *, int);
	void (*read)(struct perf_event___140 *);
	void (*start_txn)(struct pmu___140 *, unsigned int);
	int (*commit_txn)(struct pmu___140 *);
	void (*cancel_txn)(struct pmu___140 *);
	int (*event_idx)(struct perf_event___140 *);
	void (*sched_task)(struct perf_event_context___140 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___140 *);
	int (*filter_match)(struct perf_event___140 *);
	int (*check_period)(struct perf_event___140 *, u64);
};

struct perf_cpu_context___140 {
	struct perf_event_context___140 ctx;
	struct perf_event_context___140 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___140 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___140 {
	struct cgroup_subsys_state___228 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___133 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___133 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___133 *);
	struct list_head * (*get_fields)(struct trace_event_call___133 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___133 *);
};

struct trace_event_file___52;

struct trace_event_buffer___44 {
	struct ring_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___52 *trace_file;
	void *entry;
	long unsigned int flags;
	int pc;
};

struct trace_event_file___52 {
	struct list_head list;
	struct trace_event_call___133 *event_call;
	struct event_filter *filter;
	struct dentry___348 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_scsi_dispatch_cmd_start {
	struct trace_entry ent;
	unsigned int host_no;
	unsigned int channel;
	unsigned int id;
	unsigned int lun;
	unsigned int opcode;
	unsigned int cmd_len;
	unsigned int data_sglen;
	unsigned int prot_sglen;
	unsigned char prot_op;
	u32 __data_loc_cmnd;
	char __data[0];
};

struct trace_event_raw_scsi_dispatch_cmd_error {
	struct trace_entry ent;
	unsigned int host_no;
	unsigned int channel;
	unsigned int id;
	unsigned int lun;
	int rtn;
	unsigned int opcode;
	unsigned int cmd_len;
	unsigned int data_sglen;
	unsigned int prot_sglen;
	unsigned char prot_op;
	u32 __data_loc_cmnd;
	char __data[0];
};

struct trace_event_raw_scsi_cmd_done_timeout_template {
	struct trace_entry ent;
	unsigned int host_no;
	unsigned int channel;
	unsigned int id;
	unsigned int lun;
	int result;
	unsigned int opcode;
	unsigned int cmd_len;
	unsigned int data_sglen;
	unsigned int prot_sglen;
	unsigned char prot_op;
	u32 __data_loc_cmnd;
	char __data[0];
};

struct trace_event_raw_scsi_eh_wakeup {
	struct trace_entry ent;
	unsigned int host_no;
	char __data[0];
};

struct trace_event_data_offsets_scsi_dispatch_cmd_start {
	u32 cmnd;
};

struct trace_event_data_offsets_scsi_dispatch_cmd_error {
	u32 cmnd;
};

struct trace_event_data_offsets_scsi_cmd_done_timeout_template {
	u32 cmnd;
};

struct trace_event_data_offsets_scsi_eh_wakeup {};

struct attribute_container___2 {
	struct list_head node;
	struct klist containers;
	struct class___222 *class;
	const struct attribute_group___224 *grp;
	struct device_attribute___11 **attrs;
	int (*match)(struct attribute_container___2 *, struct device___222 *);
	long unsigned int flags;
};

struct transport_container___2 {
	struct attribute_container___2 ac;
	const struct attribute_group___224 *statistics;
};

struct Scsi_Host___2;

struct scsi_target___2;

struct scsi_device___2 {
	struct Scsi_Host___2 *host;
	struct request_queue___60 *request_queue;
	struct list_head siblings;
	struct list_head same_target_siblings;
	atomic_t device_busy;
	atomic_t device_blocked;
	spinlock_t list_lock;
	struct list_head cmd_list;
	struct list_head starved_entry;
	short unsigned int queue_depth;
	short unsigned int max_queue_depth;
	short unsigned int last_queue_full_depth;
	short unsigned int last_queue_full_count;
	long unsigned int last_queue_full_time;
	long unsigned int queue_ramp_up_period;
	long unsigned int last_queue_ramp_up;
	unsigned int id;
	unsigned int channel;
	u64 lun;
	unsigned int manufacturer;
	unsigned int sector_size;
	void *hostdata;
	unsigned char type;
	char scsi_level;
	char inq_periph_qual;
	struct mutex inquiry_mutex;
	unsigned char inquiry_len;
	unsigned char *inquiry;
	const char *vendor;
	const char *model;
	const char *rev;
	struct scsi_vpd *vpd_pg83;
	struct scsi_vpd *vpd_pg80;
	unsigned char current_tag;
	struct scsi_target___2 *sdev_target;
	blist_flags_t sdev_bflags;
	unsigned int eh_timeout;
	unsigned int removable: 1;
	unsigned int changed: 1;
	unsigned int busy: 1;
	unsigned int lockable: 1;
	unsigned int locked: 1;
	unsigned int borken: 1;
	unsigned int disconnect: 1;
	unsigned int soft_reset: 1;
	unsigned int sdtr: 1;
	unsigned int wdtr: 1;
	unsigned int ppr: 1;
	unsigned int tagged_supported: 1;
	unsigned int simple_tags: 1;
	unsigned int was_reset: 1;
	unsigned int expecting_cc_ua: 1;
	unsigned int use_10_for_rw: 1;
	unsigned int use_10_for_ms: 1;
	unsigned int no_report_opcodes: 1;
	unsigned int no_write_same: 1;
	unsigned int use_16_for_rw: 1;
	unsigned int skip_ms_page_8: 1;
	unsigned int skip_ms_page_3f: 1;
	unsigned int skip_vpd_pages: 1;
	unsigned int try_vpd_pages: 1;
	unsigned int use_192_bytes_for_3f: 1;
	unsigned int no_start_on_add: 1;
	unsigned int allow_restart: 1;
	unsigned int manage_start_stop: 1;
	unsigned int start_stop_pwr_cond: 1;
	unsigned int no_uld_attach: 1;
	unsigned int select_no_atn: 1;
	unsigned int fix_capacity: 1;
	unsigned int guess_capacity: 1;
	unsigned int retry_hwerror: 1;
	unsigned int last_sector_bug: 1;
	unsigned int no_read_disc_info: 1;
	unsigned int no_read_capacity_16: 1;
	unsigned int try_rc_10_first: 1;
	unsigned int security_supported: 1;
	unsigned int is_visible: 1;
	unsigned int wce_default_on: 1;
	unsigned int no_dif: 1;
	unsigned int broken_fua: 1;
	unsigned int lun_in_cdb: 1;
	unsigned int unmap_limit_for_ws: 1;
	atomic_t disk_events_disable_depth;
	long unsigned int supported_events[1];
	long unsigned int pending_events[1];
	struct list_head event_list;
	struct work_struct event_work;
	unsigned int max_device_blocked;
	atomic_t iorequest_cnt;
	atomic_t iodone_cnt;
	atomic_t ioerr_cnt;
	struct device___222 sdev_gendev;
	struct device___222 sdev_dev;
	struct execute_work ew;
	struct work_struct requeue_work;
	struct scsi_device_handler *handler;
	void *handler_data;
	unsigned char access_state;
	struct mutex state_mutex;
	enum scsi_device_state sdev_state;
	struct task_struct___260 *quiesced_by;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int sdev_data[0];
};

struct scsi_host_template___2;

struct scsi_transport_template___2;

struct Scsi_Host___2 {
	struct list_head __devices;
	struct list_head __targets;
	struct list_head starved_list;
	spinlock_t default_lock;
	spinlock_t *host_lock;
	struct mutex scan_mutex;
	struct list_head eh_cmd_q;
	struct task_struct___260 *ehandler;
	struct completion *eh_action;
	wait_queue_head_t host_wait;
	struct scsi_host_template___2 *hostt;
	struct scsi_transport_template___2 *transportt;
	struct blk_mq_tag_set___5 tag_set;
	atomic_t host_busy;
	atomic_t host_blocked;
	unsigned int host_failed;
	unsigned int host_eh_scheduled;
	unsigned int host_no;
	int eh_deadline;
	long unsigned int last_reset;
	unsigned int max_channel;
	unsigned int max_id;
	u64 max_lun;
	unsigned int unique_id;
	short unsigned int max_cmd_len;
	int this_id;
	int can_queue;
	short int cmd_per_lun;
	short unsigned int sg_tablesize;
	short unsigned int sg_prot_tablesize;
	unsigned int max_sectors;
	long unsigned int dma_boundary;
	unsigned int nr_hw_queues;
	long unsigned int cmd_serial_number;
	unsigned int active_mode: 2;
	unsigned int unchecked_isa_dma: 1;
	unsigned int use_clustering: 1;
	unsigned int host_self_blocked: 1;
	unsigned int reverse_ordering: 1;
	unsigned int tmf_in_progress: 1;
	unsigned int async_scan: 1;
	unsigned int eh_noresume: 1;
	unsigned int no_write_same: 1;
	unsigned int use_cmd_list: 1;
	unsigned int short_inquiry: 1;
	char work_q_name[20];
	struct workqueue_struct *work_q;
	struct workqueue_struct *tmf_work_q;
	unsigned int no_scsi2_lun_in_cdb: 1;
	unsigned int max_host_blocked;
	unsigned int prot_capabilities;
	unsigned char prot_guard_type;
	long unsigned int base;
	long unsigned int io_port;
	unsigned char n_io_port;
	unsigned char dma_channel;
	unsigned int irq;
	enum scsi_host_state shost_state;
	struct device___222 shost_gendev;
	struct device___222 shost_dev;
	void *shost_data;
	struct device___222 *dma_dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int hostdata[0];
};

struct scsi_target___2 {
	struct scsi_device___2 *starget_sdev_user;
	struct list_head siblings;
	struct list_head devices;
	struct device___222 dev;
	struct kref reap_ref;
	unsigned int channel;
	unsigned int id;
	unsigned int create: 1;
	unsigned int single_lun: 1;
	unsigned int pdt_1f_for_no_lun: 1;
	unsigned int no_report_luns: 1;
	unsigned int expecting_lun_change: 1;
	atomic_t target_busy;
	atomic_t target_blocked;
	unsigned int can_queue;
	unsigned int max_target_blocked;
	char scsi_level;
	enum scsi_target_state state;
	void *hostdata;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int starget_data[0];
};

struct scsi_cmnd___2;

struct scsi_host_template___2 {
	struct module___212 *module;
	const char *name;
	const char * (*info)(struct Scsi_Host___2 *);
	int (*ioctl)(struct scsi_device___2 *, int, void *);
	int (*queuecommand)(struct Scsi_Host___2 *, struct scsi_cmnd___2 *);
	int (*eh_abort_handler)(struct scsi_cmnd___2 *);
	int (*eh_device_reset_handler)(struct scsi_cmnd___2 *);
	int (*eh_target_reset_handler)(struct scsi_cmnd___2 *);
	int (*eh_bus_reset_handler)(struct scsi_cmnd___2 *);
	int (*eh_host_reset_handler)(struct scsi_cmnd___2 *);
	int (*slave_alloc)(struct scsi_device___2 *);
	int (*slave_configure)(struct scsi_device___2 *);
	void (*slave_destroy)(struct scsi_device___2 *);
	int (*target_alloc)(struct scsi_target___2 *);
	void (*target_destroy)(struct scsi_target___2 *);
	int (*scan_finished)(struct Scsi_Host___2 *, long unsigned int);
	void (*scan_start)(struct Scsi_Host___2 *);
	int (*change_queue_depth)(struct scsi_device___2 *, int);
	int (*map_queues)(struct Scsi_Host___2 *);
	int (*bios_param)(struct scsi_device___2 *, struct block_device___259 *, sector_t, int *);
	void (*unlock_native_capacity)(struct scsi_device___2 *);
	int (*show_info)(struct seq_file___232 *, struct Scsi_Host___2 *);
	int (*write_info)(struct Scsi_Host___2 *, char *, int);
	enum blk_eh_timer_return (*eh_timed_out)(struct scsi_cmnd___2 *);
	int (*host_reset)(struct Scsi_Host___2 *, int);
	const char *proc_name;
	struct proc_dir_entry *proc_dir;
	int can_queue;
	int this_id;
	short unsigned int sg_tablesize;
	short unsigned int sg_prot_tablesize;
	unsigned int max_sectors;
	long unsigned int dma_boundary;
	short int cmd_per_lun;
	unsigned char present;
	int tag_alloc_policy;
	unsigned int track_queue_depth: 1;
	unsigned int supported_mode: 2;
	unsigned int unchecked_isa_dma: 1;
	unsigned int use_clustering: 1;
	unsigned int emulated: 1;
	unsigned int skip_settle_delay: 1;
	unsigned int no_write_same: 1;
	unsigned int force_blk_mq: 1;
	unsigned int max_host_blocked;
	struct device_attribute___11 **shost_attrs;
	struct device_attribute___11 **sdev_attrs;
	const struct attribute_group___224 **sdev_groups;
	u64 vendor_id;
	unsigned int cmd_size;
	struct scsi_host_cmd_pool *cmd_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct scsi_transport_template___2 {
	struct transport_container___2 host_attrs;
	struct transport_container___2 target_attrs;
	struct transport_container___2 device_attrs;
	int (*user_scan)(struct Scsi_Host___2 *, uint, uint, u64);
	int device_size;
	int device_private_offset;
	int target_size;
	int target_private_offset;
	int host_size;
	unsigned int create_work_queue: 1;
	void (*eh_strategy_handler)(struct Scsi_Host___2 *);
};

struct scsi_idlun {
	__u32 dev_id;
	__u32 host_unique_id;
};

typedef void (*activate_complete)(void *, int);

struct scsi_device_handler {
	struct list_head list;
	struct module___286 *module;
	const char *name;
	int (*check_sense)(struct scsi_device *, struct scsi_sense_hdr *);
	int (*attach)(struct scsi_device *);
	void (*detach)(struct scsi_device *);
	int (*activate)(struct scsi_device *, activate_complete, void *);
	blk_status_t (*prep_fn)(struct scsi_device *, struct request___82 *);
	int (*set_params)(struct scsi_device *, const char *);
	void (*rescan)(struct scsi_device *);
};

struct scsi_eh_save {
	int result;
	int eh_eflags;
	enum dma_data_direction data_direction;
	unsigned int underflow;
	unsigned char cmd_len;
	unsigned char prot_op;
	unsigned char *cmnd;
	struct scsi_data_buffer sdb;
	struct request___82 *next_rq;
	unsigned char eh_cmnd[16];
	struct scatterlist sense_sgl;
};

struct attribute_container___3 {
	struct list_head node;
	struct klist containers;
	struct class___316 *class;
	const struct attribute_group___313 *grp;
	struct device_attribute___35 **attrs;
	int (*match)(struct attribute_container___3 *, struct device___316 *);
	long unsigned int flags;
};

struct transport_container___3 {
	struct attribute_container___3 ac;
	const struct attribute_group___313 *statistics;
};

struct scsi_transport_template {
	struct transport_container___3 host_attrs;
	struct transport_container___3 target_attrs;
	struct transport_container___3 device_attrs;
	int (*user_scan)(struct Scsi_Host *, uint, uint, u64);
	int device_size;
	int device_private_offset;
	int target_size;
	int target_private_offset;
	int host_size;
	unsigned int create_work_queue: 1;
	void (*eh_strategy_handler)(struct Scsi_Host *);
};

struct file___350;

struct kiocb___350;

struct vm_area_struct___351;

struct inode___350;

struct file_lock___350;

struct page___351;

struct seq_file___297;

struct file_operations___350 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___350 *, loff_t, int);
	ssize_t (*read)(struct file___350 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___350 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___350 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___350 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___350 *, bool);
	int (*iterate)(struct file___350 *, struct dir_context *);
	int (*iterate_shared)(struct file___350 *, struct dir_context *);
	__poll_t (*poll)(struct file___350 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___350 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___350 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___350 *, struct vm_area_struct___351 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___350 *, struct file___350 *);
	int (*flush)(struct file___350 *, fl_owner_t);
	int (*release)(struct inode___350 *, struct file___350 *);
	int (*fsync)(struct file___350 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___350 *, int);
	int (*lock)(struct file___350 *, int, struct file_lock___350 *);
	ssize_t (*sendpage)(struct file___350 *, struct page___351 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___350 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___350 *, int, struct file_lock___350 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___350 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___350 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___350 *, long int, struct file_lock___350 **, void **);
	long int (*fallocate)(struct file___350 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___297 *, struct file___350 *);
	ssize_t (*copy_file_range)(struct file___350 *, loff_t, struct file___350 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___350 *, loff_t, struct file___350 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___350 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___350 {
	u64 seqnum;
	struct vm_area_struct___351 *vmas[4];
};

struct page_frag___350 {
	struct page___351 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___350;

struct cred___324;

struct bio_list___167;

struct backing_dev_info___167;

struct io_context___87;

struct request_queue___83;

struct vm_struct___256;

struct task_struct___351 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___351 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___350 *mm;
	struct mm_struct___350 *active_mm;
	struct vmacache___350 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___351 *real_parent;
	struct task_struct___351 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___351 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___216 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___216 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___216 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___324 *ptracer_cred;
	const struct cred___324 *real_cred;
	const struct cred___324 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___351 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___167 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___167 *backing_dev_info;
	struct io_context___87 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___350 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___83 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___351 *oom_reaper_list;
	struct vm_struct___256 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___140 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___349;

struct super_block___349;

struct dentry___349 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___349 *d_parent;
	struct qstr d_name;
	struct inode___350 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___349 *d_op;
	struct super_block___349 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct rw_semaphore___351 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___351 *owner;
};

struct address_space_operations___349;

struct address_space___349 {
	struct inode___350 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___351 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___349 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___349;

struct bdi_writeback___167;

struct block_device___349;

struct inode___350 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___349 *i_op;
	struct super_block___349 *i_sb;
	struct address_space___349 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___351 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___167 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___350 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___349 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___349 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___350;

struct dentry_operations___349 {
	int (*d_revalidate)(struct dentry___349 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___349 *, unsigned int);
	int (*d_hash)(const struct dentry___349 *, struct qstr *);
	int (*d_compare)(const struct dentry___349 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___349 *);
	int (*d_init)(struct dentry___349 *);
	void (*d_release)(struct dentry___349 *);
	void (*d_prune)(struct dentry___349 *);
	void (*d_iput)(struct dentry___349 *, struct inode___350 *);
	char * (*d_dname)(struct dentry___349 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___350 *);
	int (*d_manage)(const struct path___350 *, bool);
	struct dentry___349 * (*d_real)(struct dentry___349 *, const struct inode___350 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___349;

struct mem_dqinfo___349 {
	struct quota_format_type___349 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___349;

struct quota_info___349 {
	unsigned int flags;
	struct rw_semaphore___351 dqio_sem;
	struct inode___350 *files[3];
	struct mem_dqinfo___349 info[3];
	const struct quota_format_ops___349 *ops[3];
};

struct rcuwait___349 {
	struct task_struct___351 *task;
};

struct percpu_rw_semaphore___349 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___351 rw_sem;
	struct rcuwait___349 writer;
	int readers_block;
};

struct sb_writers___349 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___349 rw_sem[3];
};

struct file_system_type___349;

struct super_operations___349;

struct dquot_operations___349;

struct quotactl_ops___349;

struct super_block___349 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___349 *s_type;
	const struct super_operations___349 *s_op;
	const struct dquot_operations___349 *dq_op;
	const struct quotactl_ops___349 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___349 *s_root;
	struct rw_semaphore___351 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___349 *s_bdev;
	struct backing_dev_info___167 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___349 s_dquot;
	struct sb_writers___349 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___349 *s_d_op;
	int cleancache_poolid;
	struct shrinker___130 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct path___350 {
	struct vfsmount *mnt;
	struct dentry___349 *dentry;
};

typedef struct page___351 *pgtable_t___350;

struct dev_pagemap___338;

struct page___351 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___349 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___351 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___350 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___350 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___338 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___350;

struct lruvec___350 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___350 *pgdat;
};

struct zone___350 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___350 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___350 {
	struct zone___350 *zone;
	int zone_idx;
};

struct zonelist___350 {
	struct zoneref___350 _zonerefs[25];
};

struct pglist_data___350 {
	struct zone___350 node_zones[3];
	struct zonelist___350 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___351 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___351 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___350 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___351 {
	void *stack;
	struct task_struct___351 *task;
	long int status;
};

struct blocking_notifier_head___350 {
	struct rw_semaphore___351 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___338;

struct vm_area_struct___351 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___351 *vm_next;
	struct vm_area_struct___351 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___350 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___338 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___350 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___350;

struct mm_struct___350 {
	struct {
		struct vm_area_struct___351 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___350 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___351 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___350 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___351 *owner;
		struct user_namespace___3 *user_ns;
		struct file___350 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___350 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___338)(struct vm_area_struct___351 *, long unsigned int, const struct page___351 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___338)(struct page___351 *, void *);

struct device___317;

struct dev_pagemap___338 {
	dev_page_fault_t___338 page_fault;
	dev_page_free_t___338 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___317 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct file___350 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___350 f_path;
	struct inode___350 *f_inode;
	const struct file_operations___350 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___216 f_owner;
	const struct cred___324 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___349 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___338;

struct vm_operations_struct___338 {
	void (*open)(struct vm_area_struct___351 *);
	void (*close)(struct vm_area_struct___351 *);
	int (*split)(struct vm_area_struct___351 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___351 *);
	vm_fault_t (*fault)(struct vm_fault___338 *);
	vm_fault_t (*huge_fault)(struct vm_fault___338 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___338 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___351 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___338 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___338 *);
	int (*access)(struct vm_area_struct___351 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___351 *);
	int (*set_policy)(struct vm_area_struct___351 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___351 *, long unsigned int);
	struct page___351 * (*find_special_page)(struct vm_area_struct___351 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___350 {
	struct task_struct___351 *task;
	struct core_thread___350 *next;
};

struct core_state___350 {
	atomic_t nr_threads;
	struct core_thread___350 dumper;
	struct completion startup;
};

struct vm_fault___338 {
	struct vm_area_struct___351 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___351 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___351 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___350 prealloc_pte;
};

struct key___324;

struct user_struct___324 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___324 *uid_keyring;
	struct key___324 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___324 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___324 *session_keyring;
	struct key___324 *process_keyring;
	struct key___324 *thread_keyring;
	struct key___324 *request_key_auth;
	void *security;
	struct user_struct___324 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct bio___167;

struct bio_list___167 {
	struct bio___167 *head;
	struct bio___167 *tail;
};

struct bdi_writeback_congested___167;

struct bdi_writeback___167 {
	struct backing_dev_info___167 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___167 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___157 *memcg_css;
	struct cgroup_subsys_state___157 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___167 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___167 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___317 *dev;
	struct device___317 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___349 *debug_dir;
	struct dentry___349 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___87;

struct io_context___87 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___87 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

typedef blk_qc_t make_request_fn___83(struct request_queue___83 *, struct bio___167 *);

struct request___83;

typedef int dma_drain_needed_fn___83(struct request___83 *);

struct kset___336;

struct kobj_type___336;

struct kernfs_node___344;

struct kobject___337 {
	const char *name;
	struct list_head entry;
	struct kobject___337 *parent;
	struct kset___336 *kset;
	struct kobj_type___336 *ktype;
	struct kernfs_node___344 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___83;

struct bsg_class_device___83 {
	struct device___317 *class_dev;
	int minor;
	struct request_queue___83 *queue;
	const struct bsg_ops___83 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___167 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___167 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___83;

struct blk_mq_ops___21;

struct blk_mq_hw_ctx___21;

struct blk_mq_tag_set___21;

struct request_queue___83 {
	struct list_head queue_head;
	struct request___83 *last_merge;
	struct elevator_queue___83 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___83 *make_request_fn;
	dma_drain_needed_fn___83 *dma_drain_needed;
	const struct blk_mq_ops___21 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___21 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___167 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___337 kobj;
	struct kobject___337 *mq_kobj;
	struct blk_integrity integrity;
	struct device___317 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	struct bsg_class_device___83 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set___21 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___167 bio_split;
	struct dentry___349 *debugfs_dir;
	struct dentry___349 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___256 {
	struct vm_struct___256 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___351 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct io_cq___87 {
	struct request_queue___83 *q;
	struct io_context___87 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___350 {
	struct file___350 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___350 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___349 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___350 *ia_file;
};

struct dquot___349 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___349 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___349 {
	int qf_fmt_id;
	const struct quota_format_ops___349 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___349 *qf_next;
};

struct quota_format_ops___349 {
	int (*check_quota_file)(struct super_block___349 *, int);
	int (*read_file_info)(struct super_block___349 *, int);
	int (*write_file_info)(struct super_block___349 *, int);
	int (*free_file_info)(struct super_block___349 *, int);
	int (*read_dqblk)(struct dquot___349 *);
	int (*commit_dqblk)(struct dquot___349 *);
	int (*release_dqblk)(struct dquot___349 *);
	int (*get_next_id)(struct super_block___349 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___349 {
	int (*write_dquot)(struct dquot___349 *);
	struct dquot___349 * (*alloc_dquot)(struct super_block___349 *, int);
	void (*destroy_dquot)(struct dquot___349 *);
	int (*acquire_dquot)(struct dquot___349 *);
	int (*release_dquot)(struct dquot___349 *);
	int (*mark_dirty)(struct dquot___349 *);
	int (*write_info)(struct super_block___349 *, int);
	qsize_t * (*get_reserved_space)(struct inode___350 *);
	int (*get_projid)(struct inode___350 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___350 *, qsize_t *);
	int (*get_next_id)(struct super_block___349 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___349 {
	int (*quota_on)(struct super_block___349 *, int, int, const struct path___350 *);
	int (*quota_off)(struct super_block___349 *, int);
	int (*quota_enable)(struct super_block___349 *, unsigned int);
	int (*quota_disable)(struct super_block___349 *, unsigned int);
	int (*quota_sync)(struct super_block___349 *, int);
	int (*set_info)(struct super_block___349 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___349 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___349 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___349 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___349 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___349 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___349 {
	int (*writepage)(struct page___351 *, struct writeback_control___3 *);
	int (*readpage)(struct file___350 *, struct page___351 *);
	int (*writepages)(struct address_space___349 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___351 *);
	int (*readpages)(struct file___350 *, struct address_space___349 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___350 *, struct address_space___349 *, loff_t, unsigned int, unsigned int, struct page___351 **, void **);
	int (*write_end)(struct file___350 *, struct address_space___349 *, loff_t, unsigned int, unsigned int, struct page___351 *, void *);
	sector_t (*bmap)(struct address_space___349 *, sector_t);
	void (*invalidatepage)(struct page___351 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___351 *, gfp_t);
	void (*freepage)(struct page___351 *);
	ssize_t (*direct_IO)(struct kiocb___350 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___349 *, struct page___351 *, struct page___351 *, enum migrate_mode);
	bool (*isolate_page)(struct page___351 *, isolate_mode_t);
	void (*putback_page)(struct page___351 *);
	int (*launder_page)(struct page___351 *);
	int (*is_partially_uptodate)(struct page___351 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___351 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___349 *, struct page___351 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___350 *, sector_t *);
	void (*swap_deactivate)(struct file___350 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct hd_struct___87;

struct gendisk___87;

struct block_device___349 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___350 *bd_inode;
	struct super_block___349 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___349 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___87 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___87 *bd_disk;
	struct request_queue___83 *bd_queue;
	struct backing_dev_info___167 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___317 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___5 *subsys_data;
	void (*set_latency_tolerance)(struct device___317 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___317;

struct bus_type___317;

struct device_driver___317;

struct dev_pm_domain___317;

struct dma_map_ops___106;

struct fwnode_handle___239;

struct class___317;

struct attribute_group___314;

struct device___317 {
	struct device___317 *parent;
	struct device_private *p;
	struct kobject___337 kobj;
	const char *init_name;
	const struct device_type___317 *type;
	struct mutex mutex;
	struct bus_type___317 *bus;
	struct device_driver___317 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___317 power;
	struct dev_pm_domain___317 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___106 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___239 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___317 *class;
	const struct attribute_group___314 **groups;
	void (*release)(struct device___317 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___87 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___317 __dev;
	struct kobject___337 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___87;

struct block_device_operations___84;

struct gendisk___87 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___87 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___87 *part_tbl;
	struct hd_struct___87 part0;
	const struct block_device_operations___84 *fops;
	struct request_queue___83 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___351 lookup_sem;
	struct kobject___337 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___337 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___349 {
	struct dentry___349 * (*lookup)(struct inode___350 *, struct dentry___349 *, unsigned int);
	const char * (*get_link)(struct dentry___349 *, struct inode___350 *, struct delayed_call *);
	int (*permission)(struct inode___350 *, int);
	struct posix_acl * (*get_acl)(struct inode___350 *, int);
	int (*readlink)(struct dentry___349 *, char *, int);
	int (*create)(struct inode___350 *, struct dentry___349 *, umode_t, bool);
	int (*link)(struct dentry___349 *, struct inode___350 *, struct dentry___349 *);
	int (*unlink)(struct inode___350 *, struct dentry___349 *);
	int (*symlink)(struct inode___350 *, struct dentry___349 *, const char *);
	int (*mkdir)(struct inode___350 *, struct dentry___349 *, umode_t);
	int (*rmdir)(struct inode___350 *, struct dentry___349 *);
	int (*mknod)(struct inode___350 *, struct dentry___349 *, umode_t, dev_t);
	int (*rename)(struct inode___350 *, struct dentry___349 *, struct inode___350 *, struct dentry___349 *, unsigned int);
	int (*setattr)(struct dentry___349 *, struct iattr___349 *);
	int (*getattr)(const struct path___350 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___349 *, char *, size_t);
	int (*fiemap)(struct inode___350 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___350 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___350 *, struct dentry___349 *, struct file___350 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___350 *, struct dentry___349 *, umode_t);
	int (*set_acl)(struct inode___350 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___349 {
	void (*fl_copy_lock)(struct file_lock___350 *, struct file_lock___350 *);
	void (*fl_release_private)(struct file_lock___350 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___349;

struct lock_manager_operations___349;

struct file_lock___350 {
	struct file_lock___350 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___350 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___349 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___349 *fl_ops;
	const struct lock_manager_operations___349 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___349 {
	int (*lm_compare_owner)(struct file_lock___350 *, struct file_lock___350 *);
	long unsigned int (*lm_owner_key)(struct file_lock___350 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___350 *);
	int (*lm_grant)(struct file_lock___350 *, int);
	bool (*lm_break)(struct file_lock___350 *);
	int (*lm_change)(struct file_lock___350 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___350 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___349 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___349 *fa_next;
	struct file___350 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___349 {
	const char *name;
	int fs_flags;
	struct dentry___349 * (*mount)(struct file_system_type___349 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___349 *);
	struct module___11 *owner;
	struct file_system_type___349 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___349 {
	struct inode___350 * (*alloc_inode)(struct super_block___349 *);
	void (*destroy_inode)(struct inode___350 *);
	void (*dirty_inode)(struct inode___350 *, int);
	int (*write_inode)(struct inode___350 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___350 *);
	void (*evict_inode)(struct inode___350 *);
	void (*put_super)(struct super_block___349 *);
	int (*sync_fs)(struct super_block___349 *, int);
	int (*freeze_super)(struct super_block___349 *);
	int (*freeze_fs)(struct super_block___349 *);
	int (*thaw_super)(struct super_block___349 *);
	int (*unfreeze_fs)(struct super_block___349 *);
	int (*statfs)(struct dentry___349 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___349 *, int *, char *);
	void (*umount_begin)(struct super_block___349 *);
	int (*show_options)(struct seq_file___297 *, struct dentry___349 *);
	int (*show_devname)(struct seq_file___297 *, struct dentry___349 *);
	int (*show_path)(struct seq_file___297 *, struct dentry___349 *);
	int (*show_stats)(struct seq_file___297 *, struct dentry___349 *);
	ssize_t (*quota_read)(struct super_block___349 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___349 *, int, const char *, size_t, loff_t);
	struct dquot___349 ** (*get_dquots)(struct inode___350 *);
	int (*bdev_try_to_free_page)(struct super_block___349 *, struct page___351 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___349 *, struct shrink_control___130 *);
	long int (*free_cached_objects)(struct super_block___349 *, struct shrink_control___130 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___296;

struct seq_file___297 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___296 *op;
	int poll_event;
	const struct file___350 *file;
	void *private;
};

typedef void bio_end_io_t___167(struct bio___167 *);

struct bio_vec___169 {
	struct page___351 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___167;

struct bio___167 {
	struct bio___167 *bi_next;
	struct gendisk___87 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___167 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___167 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___169 *bi_io_vec;
	struct bio_set___167 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___169 bi_inline_vecs[0];
};

struct kobj_attribute___328 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___337 *, struct kobj_attribute___328 *, char *);
	ssize_t (*store)(struct kobject___337 *, struct kobj_attribute___328 *, const char *, size_t);
};

typedef void compound_page_dtor___338(struct page___351 *);

struct bio_integrity_payload___167 {
	struct bio___167 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___169 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___169 bip_inline_vecs[0];
};

struct dev_pm_ops___317;

struct device_type___317 {
	const char *name;
	const struct attribute_group___314 **groups;
	int (*uevent)(struct device___317 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___317 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___317 *);
	const struct dev_pm_ops___317 *pm;
};

struct class___317 {
	const char *name;
	struct module___11 *owner;
	const struct attribute_group___314 **class_groups;
	const struct attribute_group___314 **dev_groups;
	struct kobject___337 *dev_kobj;
	int (*dev_uevent)(struct device___317 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___317 *, umode_t *);
	void (*class_release)(struct class___317 *);
	void (*dev_release)(struct device___317 *);
	int (*shutdown_pre)(struct device___317 *);
	const struct kobj_ns_type_operations___27 *ns_type;
	const void * (*namespace)(struct device___317 *);
	const struct dev_pm_ops___317 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct kernfs_root___343;

struct kernfs_elem_dir___343 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___343 *root;
};

struct kernfs_syscall_ops___343;

struct kernfs_root___343 {
	struct kernfs_node___344 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___343 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___343 {
	struct kernfs_node___344 *target_kn;
};

struct kernfs_ops___343;

struct kernfs_elem_attr___343 {
	const struct kernfs_ops___343 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___344 *notify_next;
};

struct kernfs_node___344 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___344 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___343 dir;
		struct kernfs_elem_symlink___343 symlink;
		struct kernfs_elem_attr___343 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___343;

struct kernfs_ops___343 {
	int (*open)(struct kernfs_open_file___343 *);
	void (*release)(struct kernfs_open_file___343 *);
	int (*seq_show)(struct seq_file___297 *, void *);
	void * (*seq_start)(struct seq_file___297 *, loff_t *);
	void * (*seq_next)(struct seq_file___297 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___297 *, void *);
	ssize_t (*read)(struct kernfs_open_file___343 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___343 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___343 *, struct vm_area_struct___351 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___343 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___343 {
	int (*remount_fs)(struct kernfs_root___343 *, int *, char *);
	int (*show_options)(struct seq_file___297 *, struct kernfs_root___343 *);
	int (*mkdir)(struct kernfs_node___344 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___344 *);
	int (*rename)(struct kernfs_node___344 *, struct kernfs_node___344 *, const char *);
	int (*show_path)(struct seq_file___297 *, struct kernfs_node___344 *, struct kernfs_root___343 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___343 {
	struct kernfs_node___344 *kn;
	struct file___350 *file;
	struct seq_file___297 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___338 *vm_ops;
};

struct bin_attribute___313;

struct attribute_group___314 {
	const char *name;
	umode_t (*is_visible)(struct kobject___337 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___337 *, struct bin_attribute___313 *, int);
	struct attribute **attrs;
	struct bin_attribute___313 **bin_attrs;
};

struct bin_attribute___313 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___350 *, struct kobject___337 *, struct bin_attribute___313 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___350 *, struct kobject___337 *, struct bin_attribute___313 *, char *, loff_t, size_t);
	int (*mmap)(struct file___350 *, struct kobject___337 *, struct bin_attribute___313 *, struct vm_area_struct___351 *);
};

struct sysfs_ops___336 {
	ssize_t (*show)(struct kobject___337 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___337 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___336;

struct kset___336 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___337 kobj;
	const struct kset_uevent_ops___336 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___336 {
	void (*release)(struct kobject___337 *);
	const struct sysfs_ops___336 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___27 * (*child_ns_type)(struct kobject___337 *);
	const void * (*namespace)(struct kobject___337 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___336 {
	int (* const filter)(struct kset___336 *, struct kobject___337 *);
	const char * (* const name)(struct kset___336 *, struct kobject___337 *);
	int (* const uevent)(struct kset___336 *, struct kobject___337 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___317 {
	int (*prepare)(struct device___317 *);
	void (*complete)(struct device___317 *);
	int (*suspend)(struct device___317 *);
	int (*resume)(struct device___317 *);
	int (*freeze)(struct device___317 *);
	int (*thaw)(struct device___317 *);
	int (*poweroff)(struct device___317 *);
	int (*restore)(struct device___317 *);
	int (*suspend_late)(struct device___317 *);
	int (*resume_early)(struct device___317 *);
	int (*freeze_late)(struct device___317 *);
	int (*thaw_early)(struct device___317 *);
	int (*poweroff_late)(struct device___317 *);
	int (*restore_early)(struct device___317 *);
	int (*suspend_noirq)(struct device___317 *);
	int (*resume_noirq)(struct device___317 *);
	int (*freeze_noirq)(struct device___317 *);
	int (*thaw_noirq)(struct device___317 *);
	int (*poweroff_noirq)(struct device___317 *);
	int (*restore_noirq)(struct device___317 *);
	int (*runtime_suspend)(struct device___317 *);
	int (*runtime_resume)(struct device___317 *);
	int (*runtime_idle)(struct device___317 *);
};

struct dev_pm_domain___317 {
	struct dev_pm_ops___317 ops;
	void (*detach)(struct device___317 *, bool);
	int (*activate)(struct device___317 *);
	void (*sync)(struct device___317 *);
	void (*dismiss)(struct device___317 *);
};

struct bus_type___317 {
	const char *name;
	const char *dev_name;
	struct device___317 *dev_root;
	const struct attribute_group___314 **bus_groups;
	const struct attribute_group___314 **dev_groups;
	const struct attribute_group___314 **drv_groups;
	int (*match)(struct device___317 *, struct device_driver___317 *);
	int (*uevent)(struct device___317 *, struct kobj_uevent_env *);
	int (*probe)(struct device___317 *);
	int (*remove)(struct device___317 *);
	void (*shutdown)(struct device___317 *);
	int (*online)(struct device___317 *);
	int (*offline)(struct device___317 *);
	int (*suspend)(struct device___317 *, pm_message_t);
	int (*resume)(struct device___317 *);
	int (*num_vf)(struct device___317 *);
	int (*dma_configure)(struct device___317 *);
	const struct dev_pm_ops___317 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___317 {
	const char *name;
	struct bus_type___317 *bus;
	struct module___11 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___317 *);
	int (*remove)(struct device___317 *);
	void (*shutdown)(struct device___317 *);
	int (*suspend)(struct device___317 *, pm_message_t);
	int (*resume)(struct device___317 *);
	const struct attribute_group___314 **groups;
	const struct dev_pm_ops___317 *pm;
	void (*coredump)(struct device___317 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_attribute___36 {
	struct attribute attr;
	ssize_t (*show)(struct device___317 *, struct device_attribute___36 *, char *);
	ssize_t (*store)(struct device___317 *, struct device_attribute___36 *, const char *, size_t);
};

struct dma_map_ops___106 {
	void * (*alloc)(struct device___317 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___317 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___317 *, struct vm_area_struct___351 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___317 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___317 *, struct page___351 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___317 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___317 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___317 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___317 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___317 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___317 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide40;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___317 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___317 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___317 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___317 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___317 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___317 *, u64);
	u64 (*get_required_mask)(struct device___317 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___239;

struct fwnode_handle___239 {
	struct fwnode_handle___239 *secondary;
	const struct fwnode_operations___239 *ops;
};

struct disk_part_tbl___87 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___87 *last_lookup;
	struct hd_struct___87 *part[0];
};

struct block_device_operations___84 {
	int (*open)(struct block_device___349 *, fmode_t);
	void (*release)(struct gendisk___87 *, fmode_t);
	int (*rw_page)(struct block_device___349 *, sector_t, struct page___351 *, unsigned int);
	int (*ioctl)(struct block_device___349 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___349 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___87 *, unsigned int);
	int (*media_changed)(struct gendisk___87 *);
	void (*unlock_native_capacity)(struct gendisk___87 *);
	int (*revalidate_disk)(struct gendisk___87 *);
	int (*getgeo)(struct block_device___349 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___349 *, long unsigned int);
	int (*report_zones)(struct gendisk___87 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___11 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bdi_writeback_congested___167 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___167 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bsg_ops___83 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___83 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___83 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___83 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___83(struct request___83 *, blk_status_t);

struct request___83 {
	struct request_queue___83 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___21 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___167 *bio;
	struct bio___167 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___169 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___87 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___83 *saved_end_io;
		} flush;
	};
	struct gendisk___87 *rq_disk;
	struct hd_struct___87 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___83 *end_io;
	void *end_io_data;
	struct request___83 *next_rq;
};

struct fwnode_reference_args___239;

struct fwnode_endpoint___239;

struct fwnode_operations___239 {
	struct fwnode_handle___239 * (*get)(struct fwnode_handle___239 *);
	void (*put)(struct fwnode_handle___239 *);
	bool (*device_is_available)(const struct fwnode_handle___239 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___239 *, const struct device___317 *);
	bool (*property_present)(const struct fwnode_handle___239 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___239 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___239 *, const char *, const char **, size_t);
	struct fwnode_handle___239 * (*get_parent)(const struct fwnode_handle___239 *);
	struct fwnode_handle___239 * (*get_next_child_node)(const struct fwnode_handle___239 *, struct fwnode_handle___239 *);
	struct fwnode_handle___239 * (*get_named_child_node)(const struct fwnode_handle___239 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___239 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___239 *);
	struct fwnode_handle___239 * (*graph_get_next_endpoint)(const struct fwnode_handle___239 *, struct fwnode_handle___239 *);
	struct fwnode_handle___239 * (*graph_get_remote_endpoint)(const struct fwnode_handle___239 *);
	struct fwnode_handle___239 * (*graph_get_port_parent)(struct fwnode_handle___239 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___239 *, struct fwnode_endpoint___239 *);
};

struct fwnode_endpoint___239 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___239 *local_fwnode;
};

struct fwnode_reference_args___239 {
	struct fwnode_handle___239 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct blk_mq_hw_ctx___21 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___83 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags___4 *tags;
	struct blk_mq_tags___4 *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	unsigned int rh_reserved_nr_expired;
	struct hlist_node cpuhp_dead;
	struct kobject___337 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___349 *debugfs_dir;
	struct dentry___349 *sched_debugfs_dir;
	struct list_head hctx_list;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___83;

struct elevator_mq_ops___83 {
	int (*init_sched)(struct request_queue___83 *, struct elevator_type___83 *);
	void (*exit_sched)(struct elevator_queue___83 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___21 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___21 *, unsigned int);
	bool (*allow_merge)(struct request_queue___83 *, struct request___83 *, struct bio___167 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx___21 *, struct bio___167 *);
	int (*request_merge)(struct request_queue___83 *, struct request___83 **, struct bio___167 *);
	void (*request_merged)(struct request_queue___83 *, struct request___83 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___83 *, struct request___83 *, struct request___83 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___83 *, struct bio___167 *);
	void (*finish_request)(struct request___83 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___21 *, struct list_head *, bool);
	struct request___83 * (*dispatch_request)(struct blk_mq_hw_ctx___21 *);
	bool (*has_work)(struct blk_mq_hw_ctx___21 *);
	void (*completed_request)(struct request___83 *, u64);
	void (*started_request)(struct request___83 *);
	void (*requeue_request)(struct request___83 *);
	struct request___83 * (*former_request)(struct request_queue___83 *, struct request___83 *);
	struct request___83 * (*next_request)(struct request_queue___83 *, struct request___83 *);
	void (*init_icq)(struct io_cq___87 *);
	void (*exit_icq)(struct io_cq___87 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx___21 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___83;

struct elevator_type___83 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___83 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___83 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___11 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___83 {
	struct elevator_type___83 *type;
	void *elevator_data;
	struct kobject___337 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___83 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___83 *, char *);
	ssize_t (*store)(struct elevator_queue___83 *, const char *, size_t);
};

struct blk_mq_queue_data___21;

typedef blk_status_t queue_rq_fn___21(struct blk_mq_hw_ctx___21 *, const struct blk_mq_queue_data___21 *);

typedef void commit_rqs_fn___21(struct blk_mq_hw_ctx___21 *);

typedef bool get_budget_fn___21(struct blk_mq_hw_ctx___21 *);

typedef void put_budget_fn___21(struct blk_mq_hw_ctx___21 *);

typedef enum blk_eh_timer_return timeout_fn___21(struct request___83 *, bool);

typedef int poll_fn___21(struct blk_mq_hw_ctx___21 *);

typedef void complete_fn___21(struct request___83 *);

typedef int init_hctx_fn___21(struct blk_mq_hw_ctx___21 *, void *, unsigned int);

typedef void exit_hctx_fn___21(struct blk_mq_hw_ctx___21 *, unsigned int);

typedef int init_request_fn___21(struct blk_mq_tag_set___21 *, struct request___83 *, unsigned int, unsigned int);

typedef void exit_request_fn___21(struct blk_mq_tag_set___21 *, struct request___83 *, unsigned int);

typedef bool busy_fn___21(struct request_queue___83 *);

typedef int map_queues_fn___21(struct blk_mq_tag_set___21 *);

typedef void cleanup_rq_fn___21(struct request___83 *);

struct blk_mq_ops___21 {
	queue_rq_fn___21 *queue_rq;
	commit_rqs_fn___21 *commit_rqs;
	get_budget_fn___21 *get_budget;
	put_budget_fn___21 *put_budget;
	timeout_fn___21 *timeout;
	poll_fn___21 *poll;
	complete_fn___21 *complete;
	init_hctx_fn___21 *init_hctx;
	exit_hctx_fn___21 *exit_hctx;
	init_request_fn___21 *init_request;
	exit_request_fn___21 *exit_request;
	void (*initialize_rq_fn)(struct request___83 *);
	busy_fn___21 *busy;
	map_queues_fn___21 *map_queues;
	void (*show_rq)(struct seq_file___297 *, struct request___83 *);
	union {
		cleanup_rq_fn___21 *cleanup_rq;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide45;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct blk_mq_tag_set___21 {
	struct blk_mq_queue_map map[6];
	unsigned int nr_maps;
	const struct blk_mq_ops___21 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	struct blk_mq_tags___4 **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct blk_mq_queue_data___21 {
	struct request___83 *rq;
	bool last;
	long unsigned int rh_reserved1;
};

struct scsi_varlen_cdb_hdr {
	__u8 opcode;
	__u8 control;
	__u8 misc[5];
	__u8 additional_cdb_length;
	__be16 service_action;
};

struct scsi_mode_data {
	__u32 length;
	__u16 block_descriptor_length;
	__u8 medium_type;
	__u8 device_specific;
	__u8 header_length;
	__u8 longlba: 1;
};

struct scsi_event {
	enum scsi_device_event evt_type;
	struct list_head node;
};

struct Scsi_Host___3;

struct scsi_target___3;

struct scsi_device_handler___2;

struct scsi_device___3 {
	struct Scsi_Host___3 *host;
	struct request_queue___83 *request_queue;
	struct list_head siblings;
	struct list_head same_target_siblings;
	atomic_t device_busy;
	atomic_t device_blocked;
	spinlock_t list_lock;
	struct list_head cmd_list;
	struct list_head starved_entry;
	short unsigned int queue_depth;
	short unsigned int max_queue_depth;
	short unsigned int last_queue_full_depth;
	short unsigned int last_queue_full_count;
	long unsigned int last_queue_full_time;
	long unsigned int queue_ramp_up_period;
	long unsigned int last_queue_ramp_up;
	unsigned int id;
	unsigned int channel;
	u64 lun;
	unsigned int manufacturer;
	unsigned int sector_size;
	void *hostdata;
	unsigned char type;
	char scsi_level;
	char inq_periph_qual;
	struct mutex inquiry_mutex;
	unsigned char inquiry_len;
	unsigned char *inquiry;
	const char *vendor;
	const char *model;
	const char *rev;
	struct scsi_vpd *vpd_pg83;
	struct scsi_vpd *vpd_pg80;
	unsigned char current_tag;
	struct scsi_target___3 *sdev_target;
	blist_flags_t sdev_bflags;
	unsigned int eh_timeout;
	unsigned int removable: 1;
	unsigned int changed: 1;
	unsigned int busy: 1;
	unsigned int lockable: 1;
	unsigned int locked: 1;
	unsigned int borken: 1;
	unsigned int disconnect: 1;
	unsigned int soft_reset: 1;
	unsigned int sdtr: 1;
	unsigned int wdtr: 1;
	unsigned int ppr: 1;
	unsigned int tagged_supported: 1;
	unsigned int simple_tags: 1;
	unsigned int was_reset: 1;
	unsigned int expecting_cc_ua: 1;
	unsigned int use_10_for_rw: 1;
	unsigned int use_10_for_ms: 1;
	unsigned int no_report_opcodes: 1;
	unsigned int no_write_same: 1;
	unsigned int use_16_for_rw: 1;
	unsigned int skip_ms_page_8: 1;
	unsigned int skip_ms_page_3f: 1;
	unsigned int skip_vpd_pages: 1;
	unsigned int try_vpd_pages: 1;
	unsigned int use_192_bytes_for_3f: 1;
	unsigned int no_start_on_add: 1;
	unsigned int allow_restart: 1;
	unsigned int manage_start_stop: 1;
	unsigned int start_stop_pwr_cond: 1;
	unsigned int no_uld_attach: 1;
	unsigned int select_no_atn: 1;
	unsigned int fix_capacity: 1;
	unsigned int guess_capacity: 1;
	unsigned int retry_hwerror: 1;
	unsigned int last_sector_bug: 1;
	unsigned int no_read_disc_info: 1;
	unsigned int no_read_capacity_16: 1;
	unsigned int try_rc_10_first: 1;
	unsigned int security_supported: 1;
	unsigned int is_visible: 1;
	unsigned int wce_default_on: 1;
	unsigned int no_dif: 1;
	unsigned int broken_fua: 1;
	unsigned int lun_in_cdb: 1;
	unsigned int unmap_limit_for_ws: 1;
	atomic_t disk_events_disable_depth;
	long unsigned int supported_events[1];
	long unsigned int pending_events[1];
	struct list_head event_list;
	struct work_struct event_work;
	unsigned int max_device_blocked;
	atomic_t iorequest_cnt;
	atomic_t iodone_cnt;
	atomic_t ioerr_cnt;
	struct device___317 sdev_gendev;
	struct device___317 sdev_dev;
	struct execute_work ew;
	struct work_struct requeue_work;
	struct scsi_device_handler___2 *handler;
	void *handler_data;
	unsigned char access_state;
	struct mutex state_mutex;
	enum scsi_device_state sdev_state;
	struct task_struct___351 *quiesced_by;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int sdev_data[0];
};

struct scsi_host_template___3;

struct scsi_transport_template___3;

struct Scsi_Host___3 {
	struct list_head __devices;
	struct list_head __targets;
	struct list_head starved_list;
	spinlock_t default_lock;
	spinlock_t *host_lock;
	struct mutex scan_mutex;
	struct list_head eh_cmd_q;
	struct task_struct___351 *ehandler;
	struct completion *eh_action;
	wait_queue_head_t host_wait;
	struct scsi_host_template___3 *hostt;
	struct scsi_transport_template___3 *transportt;
	struct blk_mq_tag_set___21 tag_set;
	atomic_t host_busy;
	atomic_t host_blocked;
	unsigned int host_failed;
	unsigned int host_eh_scheduled;
	unsigned int host_no;
	int eh_deadline;
	long unsigned int last_reset;
	unsigned int max_channel;
	unsigned int max_id;
	u64 max_lun;
	unsigned int unique_id;
	short unsigned int max_cmd_len;
	int this_id;
	int can_queue;
	short int cmd_per_lun;
	short unsigned int sg_tablesize;
	short unsigned int sg_prot_tablesize;
	unsigned int max_sectors;
	long unsigned int dma_boundary;
	unsigned int nr_hw_queues;
	long unsigned int cmd_serial_number;
	unsigned int active_mode: 2;
	unsigned int unchecked_isa_dma: 1;
	unsigned int use_clustering: 1;
	unsigned int host_self_blocked: 1;
	unsigned int reverse_ordering: 1;
	unsigned int tmf_in_progress: 1;
	unsigned int async_scan: 1;
	unsigned int eh_noresume: 1;
	unsigned int no_write_same: 1;
	unsigned int use_cmd_list: 1;
	unsigned int short_inquiry: 1;
	char work_q_name[20];
	struct workqueue_struct *work_q;
	struct workqueue_struct *tmf_work_q;
	unsigned int no_scsi2_lun_in_cdb: 1;
	unsigned int max_host_blocked;
	unsigned int prot_capabilities;
	unsigned char prot_guard_type;
	long unsigned int base;
	long unsigned int io_port;
	unsigned char n_io_port;
	unsigned char dma_channel;
	unsigned int irq;
	enum scsi_host_state shost_state;
	struct device___317 shost_gendev;
	struct device___317 shost_dev;
	void *shost_data;
	struct device___317 *dma_dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int hostdata[0];
};

struct scsi_target___3 {
	struct scsi_device___3 *starget_sdev_user;
	struct list_head siblings;
	struct list_head devices;
	struct device___317 dev;
	struct kref reap_ref;
	unsigned int channel;
	unsigned int id;
	unsigned int create: 1;
	unsigned int single_lun: 1;
	unsigned int pdt_1f_for_no_lun: 1;
	unsigned int no_report_luns: 1;
	unsigned int expecting_lun_change: 1;
	atomic_t target_busy;
	atomic_t target_blocked;
	unsigned int can_queue;
	unsigned int max_target_blocked;
	char scsi_level;
	enum scsi_target_state state;
	void *hostdata;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int starget_data[0];
};

struct scsi_device_handler___2 {
	struct list_head list;
	struct module___11 *module;
	const char *name;
	int (*check_sense)(struct scsi_device___3 *, struct scsi_sense_hdr *);
	int (*attach)(struct scsi_device___3 *);
	void (*detach)(struct scsi_device___3 *);
	int (*activate)(struct scsi_device___3 *, activate_complete, void *);
	blk_status_t (*prep_fn)(struct scsi_device___3 *, struct request___83 *);
	int (*set_params)(struct scsi_device___3 *, const char *);
	void (*rescan)(struct scsi_device___3 *);
};

struct scsi_cmnd___3 {
	struct scsi_request req;
	struct scsi_device___3 *device;
	struct list_head list;
	struct list_head eh_entry;
	struct delayed_work abort_work;
	struct callback_head rcu;
	int eh_eflags;
	long unsigned int serial_number;
	long unsigned int jiffies_at_alloc;
	int retries;
	int allowed;
	unsigned char prot_op;
	unsigned char prot_type;
	unsigned char prot_flags;
	short unsigned int cmd_len;
	enum dma_data_direction sc_data_direction;
	unsigned char *cmnd;
	struct scsi_data_buffer sdb;
	struct scsi_data_buffer *prot_sdb;
	unsigned int underflow;
	unsigned int transfersize;
	struct request___83 *request;
	unsigned char *sense_buffer;
	void (*scsi_done)(struct scsi_cmnd___3 *);
	struct scsi_pointer SCp;
	unsigned char *host_scribble;
	int result;
	int flags;
	long unsigned int state;
	unsigned char tag;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct scsi_driver___2 {
	struct device_driver___317 gendrv;
	void (*rescan)(struct device___317 *);
	blk_status_t (*init_command)(struct scsi_cmnd___3 *);
	void (*uninit_command)(struct scsi_cmnd___3 *);
	int (*done)(struct scsi_cmnd___3 *);
	int (*eh_action)(struct scsi_cmnd___3 *, int);
	void (*eh_reset)(struct scsi_cmnd___3 *);
};

typedef int (*key_restrict_link_func_t___325)(struct key___324 *, const struct key_type *, const union key_payload *, struct key___324 *);

struct key_restriction___324;

struct key___324 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___351 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___324 *restrict_link;
};

struct key_restriction___324 {
	key_restrict_link_func_t___325 check;
	struct key___324 *key;
	struct key_type *keytype;
};

struct seq_operations___296 {
	void * (*start)(struct seq_file___297 *, loff_t *);
	void (*stop)(struct seq_file___297 *, void *);
	void * (*next)(struct seq_file___297 *, void *, loff_t *);
	int (*show)(struct seq_file___297 *, void *);
};

struct scsi_host_template___3 {
	struct module___11 *module;
	const char *name;
	const char * (*info)(struct Scsi_Host___3 *);
	int (*ioctl)(struct scsi_device___3 *, int, void *);
	int (*queuecommand)(struct Scsi_Host___3 *, struct scsi_cmnd___3 *);
	int (*eh_abort_handler)(struct scsi_cmnd___3 *);
	int (*eh_device_reset_handler)(struct scsi_cmnd___3 *);
	int (*eh_target_reset_handler)(struct scsi_cmnd___3 *);
	int (*eh_bus_reset_handler)(struct scsi_cmnd___3 *);
	int (*eh_host_reset_handler)(struct scsi_cmnd___3 *);
	int (*slave_alloc)(struct scsi_device___3 *);
	int (*slave_configure)(struct scsi_device___3 *);
	void (*slave_destroy)(struct scsi_device___3 *);
	int (*target_alloc)(struct scsi_target___3 *);
	void (*target_destroy)(struct scsi_target___3 *);
	int (*scan_finished)(struct Scsi_Host___3 *, long unsigned int);
	void (*scan_start)(struct Scsi_Host___3 *);
	int (*change_queue_depth)(struct scsi_device___3 *, int);
	int (*map_queues)(struct Scsi_Host___3 *);
	int (*bios_param)(struct scsi_device___3 *, struct block_device___349 *, sector_t, int *);
	void (*unlock_native_capacity)(struct scsi_device___3 *);
	int (*show_info)(struct seq_file___297 *, struct Scsi_Host___3 *);
	int (*write_info)(struct Scsi_Host___3 *, char *, int);
	enum blk_eh_timer_return (*eh_timed_out)(struct scsi_cmnd___3 *);
	int (*host_reset)(struct Scsi_Host___3 *, int);
	const char *proc_name;
	struct proc_dir_entry *proc_dir;
	int can_queue;
	int this_id;
	short unsigned int sg_tablesize;
	short unsigned int sg_prot_tablesize;
	unsigned int max_sectors;
	long unsigned int dma_boundary;
	short int cmd_per_lun;
	unsigned char present;
	int tag_alloc_policy;
	unsigned int track_queue_depth: 1;
	unsigned int supported_mode: 2;
	unsigned int unchecked_isa_dma: 1;
	unsigned int use_clustering: 1;
	unsigned int emulated: 1;
	unsigned int skip_settle_delay: 1;
	unsigned int no_write_same: 1;
	unsigned int force_blk_mq: 1;
	unsigned int max_host_blocked;
	struct device_attribute___36 **shost_attrs;
	struct device_attribute___36 **sdev_attrs;
	const struct attribute_group___314 **sdev_groups;
	u64 vendor_id;
	unsigned int cmd_size;
	struct scsi_host_cmd_pool *cmd_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct attribute_container___4 {
	struct list_head node;
	struct klist containers;
	struct class___317 *class;
	const struct attribute_group___314 *grp;
	struct device_attribute___36 **attrs;
	int (*match)(struct attribute_container___4 *, struct device___317 *);
	long unsigned int flags;
};

struct transport_container___4 {
	struct attribute_container___4 ac;
	const struct attribute_group___314 *statistics;
};

struct scsi_transport_template___3 {
	struct transport_container___4 host_attrs;
	struct transport_container___4 target_attrs;
	struct transport_container___4 device_attrs;
	int (*user_scan)(struct Scsi_Host___3 *, uint, uint, u64);
	int device_size;
	int device_private_offset;
	int target_size;
	int target_private_offset;
	int host_size;
	unsigned int create_work_queue: 1;
	void (*eh_strategy_handler)(struct Scsi_Host___3 *);
};

enum scsi_host_prot_capabilities {
	SHOST_DIF_TYPE1_PROTECTION = 1,
	SHOST_DIF_TYPE2_PROTECTION = 2,
	SHOST_DIF_TYPE3_PROTECTION = 4,
	SHOST_DIX_TYPE0_PROTECTION = 8,
	SHOST_DIX_TYPE1_PROTECTION = 16,
	SHOST_DIX_TYPE2_PROTECTION = 32,
	SHOST_DIX_TYPE3_PROTECTION = 64,
};

enum {
	ACTION_FAIL = 0,
	ACTION_REPREP = 1,
	ACTION_RETRY = 2,
	ACTION_DELAYED_RETRY = 3,
};

struct module___287;

struct file___351;

struct kiocb___351;

struct vm_area_struct___352;

struct inode___351;

struct file_lock___351;

struct page___352;

struct seq_file___298;

struct file_operations___351 {
	struct module___287 *owner;
	loff_t (*llseek)(struct file___351 *, loff_t, int);
	ssize_t (*read)(struct file___351 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___351 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___351 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___351 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___351 *, bool);
	int (*iterate)(struct file___351 *, struct dir_context *);
	int (*iterate_shared)(struct file___351 *, struct dir_context *);
	__poll_t (*poll)(struct file___351 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___351 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___351 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___351 *, struct vm_area_struct___352 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___351 *, struct file___351 *);
	int (*flush)(struct file___351 *, fl_owner_t);
	int (*release)(struct inode___351 *, struct file___351 *);
	int (*fsync)(struct file___351 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___351 *, int);
	int (*lock)(struct file___351 *, int, struct file_lock___351 *);
	ssize_t (*sendpage)(struct file___351 *, struct page___352 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___351 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___351 *, int, struct file_lock___351 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___351 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___351 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___351 *, long int, struct file_lock___351 **, void **);
	long int (*fallocate)(struct file___351 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___298 *, struct file___351 *);
	ssize_t (*copy_file_range)(struct file___351 *, loff_t, struct file___351 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___351 *, loff_t, struct file___351 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___351 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___351 {
	u64 seqnum;
	struct vm_area_struct___352 *vmas[4];
};

struct page_frag___351 {
	struct page___352 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___351;

struct cred___325;

struct bio_list___168;

struct backing_dev_info___168;

struct io_context___88;

struct request_queue___84;

struct vm_struct___257;

struct task_struct___352 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___352 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___351 *mm;
	struct mm_struct___351 *active_mm;
	struct vmacache___351 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___352 *real_parent;
	struct task_struct___352 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___352 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___216 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___216 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___216 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___325 *ptracer_cred;
	const struct cred___325 *real_cred;
	const struct cred___325 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___352 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___168 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___168 *backing_dev_info;
	struct io_context___88 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___351 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___84 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___352 *oom_reaper_list;
	struct vm_struct___257 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___140 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct secondary_data___352 {
	void *stack;
	struct task_struct___352 *task;
	long int status;
};

typedef struct page___352 *pgtable_t___351;

struct address_space___350;

struct dev_pagemap___339;

struct page___352 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___350 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___352 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___351 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___351 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___339 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct key___325;

struct user_struct___325 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___325 *uid_keyring;
	struct key___325 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___339;

struct vm_area_struct___352 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___352 *vm_next;
	struct vm_area_struct___352 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___351 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___339 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___351 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct rw_semaphore___352 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___352 *owner;
};

struct core_state___351;

struct mm_struct___351 {
	struct {
		struct vm_area_struct___352 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___351 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___352 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___351 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___352 *owner;
		struct user_namespace___3 *user_ns;
		struct file___351 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___351 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___325 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___325 *session_keyring;
	struct key___325 *process_keyring;
	struct key___325 *thread_keyring;
	struct key___325 *request_key_auth;
	void *security;
	struct user_struct___325 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct bio___168;

struct bio_list___168 {
	struct bio___168 *head;
	struct bio___168 *tail;
};

struct bdi_writeback_congested___168;

struct bdi_writeback___168 {
	struct backing_dev_info___168 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___168 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___157 *memcg_css;
	struct cgroup_subsys_state___157 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___318;

struct dentry___350;

struct backing_dev_info___168 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___168 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___318 *dev;
	struct device___318 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___350 *debug_dir;
	struct dentry___350 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___88;

struct io_context___88 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___88 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

typedef blk_qc_t make_request_fn___84(struct request_queue___84 *, struct bio___168 *);

struct request___84;

typedef int dma_drain_needed_fn___84(struct request___84 *);

struct kset___337;

struct kobj_type___337;

struct kernfs_node___345;

struct kobject___338 {
	const char *name;
	struct list_head entry;
	struct kobject___338 *parent;
	struct kset___337 *kset;
	struct kobj_type___337 *ktype;
	struct kernfs_node___345 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___84;

struct bsg_class_device___84 {
	struct device___318 *class_dev;
	int minor;
	struct request_queue___84 *queue;
	const struct bsg_ops___84 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___168 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___168 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___84;

struct blk_mq_ops___22;

struct blk_mq_hw_ctx___22;

struct blk_mq_tag_set___22;

struct request_queue___84 {
	struct list_head queue_head;
	struct request___84 *last_merge;
	struct elevator_queue___84 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___84 *make_request_fn;
	dma_drain_needed_fn___84 *dma_drain_needed;
	const struct blk_mq_ops___22 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___22 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___168 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___338 kobj;
	struct kobject___338 *mq_kobj;
	struct blk_integrity integrity;
	struct device___318 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	struct bsg_class_device___84 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set___22 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___168 bio_split;
	struct dentry___350 *debugfs_dir;
	struct dentry___350 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___257 {
	struct vm_struct___257 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___352 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct pglist_data___351;

struct lruvec___351 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___351 *pgdat;
};

struct zone___351 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___351 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___351 {
	struct zone___351 *zone;
	int zone_idx;
};

struct zonelist___351 {
	struct zoneref___351 _zonerefs[25];
};

struct pglist_data___351 {
	struct zone___351 node_zones[3];
	struct zonelist___351 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___352 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___352 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___351 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___351 {
	struct rw_semaphore___352 rwsem;
	struct notifier_block *head;
};

struct bio_vec___170 {
	struct page___352 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

typedef void bio_end_io_t___168(struct bio___168 *);

struct gendisk___88;

struct bio_integrity_payload___168;

struct bio___168 {
	struct bio___168 *bi_next;
	struct gendisk___88 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___168 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___168 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___170 *bi_io_vec;
	struct bio_set___168 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___170 bi_inline_vecs[0];
};

struct bio_integrity_payload___168 {
	struct bio___168 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___170 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___170 bip_inline_vecs[0];
};

struct dev_pm_info___318 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___5 *subsys_data;
	void (*set_latency_tolerance)(struct device___318 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___318;

struct bus_type___318;

struct device_driver___318;

struct dev_pm_domain___318;

struct dma_map_ops___107;

struct fwnode_handle___240;

struct class___318;

struct attribute_group___315;

struct device___318 {
	struct device___318 *parent;
	struct device_private *p;
	struct kobject___338 kobj;
	const char *init_name;
	const struct device_type___318 *type;
	struct mutex mutex;
	struct bus_type___318 *bus;
	struct device_driver___318 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___318 power;
	struct dev_pm_domain___318 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___107 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___240 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___318 *class;
	const struct attribute_group___315 **groups;
	void (*release)(struct device___318 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___88 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___318 __dev;
	struct kobject___338 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___88;

struct block_device_operations___85;

struct gendisk___88 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___88 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___88 *part_tbl;
	struct hd_struct___88 part0;
	const struct block_device_operations___85 *fops;
	struct request_queue___84 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___352 lookup_sem;
	struct kobject___338 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___338 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_ops___318;

struct device_type___318 {
	const char *name;
	const struct attribute_group___315 **groups;
	int (*uevent)(struct device___318 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___318 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___318 *);
	const struct dev_pm_ops___318 *pm;
};

struct class___318 {
	const char *name;
	struct module___287 *owner;
	const struct attribute_group___315 **class_groups;
	const struct attribute_group___315 **dev_groups;
	struct kobject___338 *dev_kobj;
	int (*dev_uevent)(struct device___318 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___318 *, umode_t *);
	void (*class_release)(struct class___318 *);
	void (*dev_release)(struct device___318 *);
	int (*shutdown_pre)(struct device___318 *);
	const struct kobj_ns_type_operations___27 *ns_type;
	const void * (*namespace)(struct device___318 *);
	const struct dev_pm_ops___318 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct kernfs_root___344;

struct kernfs_elem_dir___344 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___344 *root;
};

struct kernfs_syscall_ops___344;

struct kernfs_root___344 {
	struct kernfs_node___345 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___344 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___344 {
	struct kernfs_node___345 *target_kn;
};

struct kernfs_ops___344;

struct kernfs_elem_attr___344 {
	const struct kernfs_ops___344 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___345 *notify_next;
};

struct kernfs_node___345 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___345 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___344 dir;
		struct kernfs_elem_symlink___344 symlink;
		struct kernfs_elem_attr___344 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___344;

struct kernfs_ops___344 {
	int (*open)(struct kernfs_open_file___344 *);
	void (*release)(struct kernfs_open_file___344 *);
	int (*seq_show)(struct seq_file___298 *, void *);
	void * (*seq_start)(struct seq_file___298 *, loff_t *);
	void * (*seq_next)(struct seq_file___298 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___298 *, void *);
	ssize_t (*read)(struct kernfs_open_file___344 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___344 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___344 *, struct vm_area_struct___352 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___344 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___344 {
	int (*remount_fs)(struct kernfs_root___344 *, int *, char *);
	int (*show_options)(struct seq_file___298 *, struct kernfs_root___344 *);
	int (*mkdir)(struct kernfs_node___345 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___345 *);
	int (*rename)(struct kernfs_node___345 *, struct kernfs_node___345 *, const char *);
	int (*show_path)(struct seq_file___298 *, struct kernfs_node___345 *, struct kernfs_root___344 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___297;

struct seq_file___298 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___297 *op;
	int poll_event;
	const struct file___351 *file;
	void *private;
};

struct kernfs_open_file___344 {
	struct kernfs_node___345 *kn;
	struct file___351 *file;
	struct seq_file___298 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___339 *vm_ops;
};

struct path___351 {
	struct vfsmount *mnt;
	struct dentry___350 *dentry;
};

struct file___351 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___351 f_path;
	struct inode___351 *f_inode;
	const struct file_operations___351 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___216 f_owner;
	const struct cred___325 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___350 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___339;

struct vm_operations_struct___339 {
	void (*open)(struct vm_area_struct___352 *);
	void (*close)(struct vm_area_struct___352 *);
	int (*split)(struct vm_area_struct___352 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___352 *);
	vm_fault_t (*fault)(struct vm_fault___339 *);
	vm_fault_t (*huge_fault)(struct vm_fault___339 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___339 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___352 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___339 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___339 *);
	int (*access)(struct vm_area_struct___352 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___352 *);
	int (*set_policy)(struct vm_area_struct___352 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___352 *, long unsigned int);
	struct page___352 * (*find_special_page)(struct vm_area_struct___352 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___314;

struct attribute_group___315 {
	const char *name;
	umode_t (*is_visible)(struct kobject___338 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___338 *, struct bin_attribute___314 *, int);
	struct attribute **attrs;
	struct bin_attribute___314 **bin_attrs;
};

struct bin_attribute___314 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___351 *, struct kobject___338 *, struct bin_attribute___314 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___351 *, struct kobject___338 *, struct bin_attribute___314 *, char *, loff_t, size_t);
	int (*mmap)(struct file___351 *, struct kobject___338 *, struct bin_attribute___314 *, struct vm_area_struct___352 *);
};

struct sysfs_ops___337 {
	ssize_t (*show)(struct kobject___338 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___338 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___337;

struct kset___337 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___338 kobj;
	const struct kset_uevent_ops___337 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___337 {
	void (*release)(struct kobject___338 *);
	const struct sysfs_ops___337 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___27 * (*child_ns_type)(struct kobject___338 *);
	const void * (*namespace)(struct kobject___338 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___337 {
	int (* const filter)(struct kset___337 *, struct kobject___338 *);
	const char * (* const name)(struct kset___337 *, struct kobject___338 *);
	int (* const uevent)(struct kset___337 *, struct kobject___338 *, struct kobj_uevent_env *);
};

struct kobj_attribute___329 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___338 *, struct kobj_attribute___329 *, char *);
	ssize_t (*store)(struct kobject___338 *, struct kobj_attribute___329 *, const char *, size_t);
};

struct dev_pm_ops___318 {
	int (*prepare)(struct device___318 *);
	void (*complete)(struct device___318 *);
	int (*suspend)(struct device___318 *);
	int (*resume)(struct device___318 *);
	int (*freeze)(struct device___318 *);
	int (*thaw)(struct device___318 *);
	int (*poweroff)(struct device___318 *);
	int (*restore)(struct device___318 *);
	int (*suspend_late)(struct device___318 *);
	int (*resume_early)(struct device___318 *);
	int (*freeze_late)(struct device___318 *);
	int (*thaw_early)(struct device___318 *);
	int (*poweroff_late)(struct device___318 *);
	int (*restore_early)(struct device___318 *);
	int (*suspend_noirq)(struct device___318 *);
	int (*resume_noirq)(struct device___318 *);
	int (*freeze_noirq)(struct device___318 *);
	int (*thaw_noirq)(struct device___318 *);
	int (*poweroff_noirq)(struct device___318 *);
	int (*restore_noirq)(struct device___318 *);
	int (*runtime_suspend)(struct device___318 *);
	int (*runtime_resume)(struct device___318 *);
	int (*runtime_idle)(struct device___318 *);
};

struct dev_pm_domain___318 {
	struct dev_pm_ops___318 ops;
	void (*detach)(struct device___318 *, bool);
	int (*activate)(struct device___318 *);
	void (*sync)(struct device___318 *);
	void (*dismiss)(struct device___318 *);
};

struct bus_type___318 {
	const char *name;
	const char *dev_name;
	struct device___318 *dev_root;
	const struct attribute_group___315 **bus_groups;
	const struct attribute_group___315 **dev_groups;
	const struct attribute_group___315 **drv_groups;
	int (*match)(struct device___318 *, struct device_driver___318 *);
	int (*uevent)(struct device___318 *, struct kobj_uevent_env *);
	int (*probe)(struct device___318 *);
	int (*remove)(struct device___318 *);
	void (*shutdown)(struct device___318 *);
	int (*online)(struct device___318 *);
	int (*offline)(struct device___318 *);
	int (*suspend)(struct device___318 *, pm_message_t);
	int (*resume)(struct device___318 *);
	int (*num_vf)(struct device___318 *);
	int (*dma_configure)(struct device___318 *);
	const struct dev_pm_ops___318 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___318 {
	const char *name;
	struct bus_type___318 *bus;
	struct module___287 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___318 *);
	int (*remove)(struct device___318 *);
	void (*shutdown)(struct device___318 *);
	int (*suspend)(struct device___318 *, pm_message_t);
	int (*resume)(struct device___318 *);
	const struct attribute_group___315 **groups;
	const struct dev_pm_ops___318 *pm;
	void (*coredump)(struct device___318 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct module_kobject___284 {
	struct kobject___338 kobj;
	struct module___287 *mod;
	struct kobject___338 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___284 {
	struct module___287 *mod;
	struct latch_tree_node node;
};

struct module_layout___284 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___284 mtn;
};

struct module_attribute___284;

struct kernel_param___284;

struct module___287 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___284 mkobj;
	struct module_attribute___284 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___338 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___284 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___284 core_layout;
	struct module_layout___284 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide40;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide41;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dma_map_ops___107 {
	void * (*alloc)(struct device___318 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___318 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___318 *, struct vm_area_struct___352 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___318 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___318 *, struct page___352 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___318 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___318 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___318 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___318 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___318 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___318 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide42;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___318 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___318 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___318 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___318 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___318 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___318 *, u64);
	u64 (*get_required_mask)(struct device___318 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___240;

struct fwnode_handle___240 {
	struct fwnode_handle___240 *secondary;
	const struct fwnode_operations___240 *ops;
};

struct dentry_operations___350;

struct super_block___350;

struct dentry___350 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___350 *d_parent;
	struct qstr d_name;
	struct inode___351 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___350 *d_op;
	struct super_block___350 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___350;

struct address_space___350 {
	struct inode___351 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___352 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___350 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___350;

struct block_device___350;

struct inode___351 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___350 *i_op;
	struct super_block___350 *i_sb;
	struct address_space___350 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___352 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___168 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___351 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___350 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___350 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___350 {
	int (*d_revalidate)(struct dentry___350 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___350 *, unsigned int);
	int (*d_hash)(const struct dentry___350 *, struct qstr *);
	int (*d_compare)(const struct dentry___350 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___350 *);
	int (*d_init)(struct dentry___350 *);
	void (*d_release)(struct dentry___350 *);
	void (*d_prune)(struct dentry___350 *);
	void (*d_iput)(struct dentry___350 *, struct inode___351 *);
	char * (*d_dname)(struct dentry___350 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___351 *);
	int (*d_manage)(const struct path___351 *, bool);
	struct dentry___350 * (*d_real)(struct dentry___350 *, const struct inode___351 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___350;

struct mem_dqinfo___350 {
	struct quota_format_type___350 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___350;

struct quota_info___350 {
	unsigned int flags;
	struct rw_semaphore___352 dqio_sem;
	struct inode___351 *files[3];
	struct mem_dqinfo___350 info[3];
	const struct quota_format_ops___350 *ops[3];
};

struct rcuwait___350 {
	struct task_struct___352 *task;
};

struct percpu_rw_semaphore___350 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___352 rw_sem;
	struct rcuwait___350 writer;
	int readers_block;
};

struct sb_writers___350 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___350 rw_sem[3];
};

struct file_system_type___350;

struct super_operations___350;

struct dquot_operations___350;

struct quotactl_ops___350;

struct super_block___350 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___350 *s_type;
	const struct super_operations___350 *s_op;
	const struct dquot_operations___350 *dq_op;
	const struct quotactl_ops___350 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___350 *s_root;
	struct rw_semaphore___352 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___350 *s_bdev;
	struct backing_dev_info___168 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___350 s_dquot;
	struct sb_writers___350 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___350 *s_d_op;
	int cleancache_poolid;
	struct shrinker___130 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

typedef int (*dev_page_fault_t___339)(struct vm_area_struct___352 *, long unsigned int, const struct page___352 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___339)(struct page___352 *, void *);

struct dev_pagemap___339 {
	dev_page_fault_t___339 page_fault;
	dev_page_free_t___339 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___318 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___351 {
	struct task_struct___352 *task;
	struct core_thread___351 *next;
};

struct core_state___351 {
	atomic_t nr_threads;
	struct core_thread___351 dumper;
	struct completion startup;
};

struct vm_fault___339 {
	struct vm_area_struct___352 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___352 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___352 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___351 prealloc_pte;
};

struct io_cq___88 {
	struct request_queue___84 *q;
	struct io_context___88 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___351 {
	struct file___351 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___351 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___350 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___351 *ia_file;
};

struct dquot___350 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___350 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___350 {
	int qf_fmt_id;
	const struct quota_format_ops___350 *qf_ops;
	struct module___287 *qf_owner;
	struct quota_format_type___350 *qf_next;
};

struct quota_format_ops___350 {
	int (*check_quota_file)(struct super_block___350 *, int);
	int (*read_file_info)(struct super_block___350 *, int);
	int (*write_file_info)(struct super_block___350 *, int);
	int (*free_file_info)(struct super_block___350 *, int);
	int (*read_dqblk)(struct dquot___350 *);
	int (*commit_dqblk)(struct dquot___350 *);
	int (*release_dqblk)(struct dquot___350 *);
	int (*get_next_id)(struct super_block___350 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___350 {
	int (*write_dquot)(struct dquot___350 *);
	struct dquot___350 * (*alloc_dquot)(struct super_block___350 *, int);
	void (*destroy_dquot)(struct dquot___350 *);
	int (*acquire_dquot)(struct dquot___350 *);
	int (*release_dquot)(struct dquot___350 *);
	int (*mark_dirty)(struct dquot___350 *);
	int (*write_info)(struct super_block___350 *, int);
	qsize_t * (*get_reserved_space)(struct inode___351 *);
	int (*get_projid)(struct inode___351 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___351 *, qsize_t *);
	int (*get_next_id)(struct super_block___350 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___350 {
	int (*quota_on)(struct super_block___350 *, int, int, const struct path___351 *);
	int (*quota_off)(struct super_block___350 *, int);
	int (*quota_enable)(struct super_block___350 *, unsigned int);
	int (*quota_disable)(struct super_block___350 *, unsigned int);
	int (*quota_sync)(struct super_block___350 *, int);
	int (*set_info)(struct super_block___350 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___350 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___350 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___350 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___350 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___350 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___350 {
	int (*writepage)(struct page___352 *, struct writeback_control___3 *);
	int (*readpage)(struct file___351 *, struct page___352 *);
	int (*writepages)(struct address_space___350 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___352 *);
	int (*readpages)(struct file___351 *, struct address_space___350 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___351 *, struct address_space___350 *, loff_t, unsigned int, unsigned int, struct page___352 **, void **);
	int (*write_end)(struct file___351 *, struct address_space___350 *, loff_t, unsigned int, unsigned int, struct page___352 *, void *);
	sector_t (*bmap)(struct address_space___350 *, sector_t);
	void (*invalidatepage)(struct page___352 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___352 *, gfp_t);
	void (*freepage)(struct page___352 *);
	ssize_t (*direct_IO)(struct kiocb___351 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___350 *, struct page___352 *, struct page___352 *, enum migrate_mode);
	bool (*isolate_page)(struct page___352 *, isolate_mode_t);
	void (*putback_page)(struct page___352 *);
	int (*launder_page)(struct page___352 *);
	int (*is_partially_uptodate)(struct page___352 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___352 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___350 *, struct page___352 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___351 *, sector_t *);
	void (*swap_deactivate)(struct file___351 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___350 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___351 *bd_inode;
	struct super_block___350 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___350 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___88 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___88 *bd_disk;
	struct request_queue___84 *bd_queue;
	struct backing_dev_info___168 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___350 {
	struct dentry___350 * (*lookup)(struct inode___351 *, struct dentry___350 *, unsigned int);
	const char * (*get_link)(struct dentry___350 *, struct inode___351 *, struct delayed_call *);
	int (*permission)(struct inode___351 *, int);
	struct posix_acl * (*get_acl)(struct inode___351 *, int);
	int (*readlink)(struct dentry___350 *, char *, int);
	int (*create)(struct inode___351 *, struct dentry___350 *, umode_t, bool);
	int (*link)(struct dentry___350 *, struct inode___351 *, struct dentry___350 *);
	int (*unlink)(struct inode___351 *, struct dentry___350 *);
	int (*symlink)(struct inode___351 *, struct dentry___350 *, const char *);
	int (*mkdir)(struct inode___351 *, struct dentry___350 *, umode_t);
	int (*rmdir)(struct inode___351 *, struct dentry___350 *);
	int (*mknod)(struct inode___351 *, struct dentry___350 *, umode_t, dev_t);
	int (*rename)(struct inode___351 *, struct dentry___350 *, struct inode___351 *, struct dentry___350 *, unsigned int);
	int (*setattr)(struct dentry___350 *, struct iattr___350 *);
	int (*getattr)(const struct path___351 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___350 *, char *, size_t);
	int (*fiemap)(struct inode___351 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___351 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___351 *, struct dentry___350 *, struct file___351 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___351 *, struct dentry___350 *, umode_t);
	int (*set_acl)(struct inode___351 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___350 {
	void (*fl_copy_lock)(struct file_lock___351 *, struct file_lock___351 *);
	void (*fl_release_private)(struct file_lock___351 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___350;

struct lock_manager_operations___350;

struct file_lock___351 {
	struct file_lock___351 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___351 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___350 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___350 *fl_ops;
	const struct lock_manager_operations___350 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___350 {
	int (*lm_compare_owner)(struct file_lock___351 *, struct file_lock___351 *);
	long unsigned int (*lm_owner_key)(struct file_lock___351 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___351 *);
	int (*lm_grant)(struct file_lock___351 *, int);
	bool (*lm_break)(struct file_lock___351 *);
	int (*lm_change)(struct file_lock___351 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___351 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___350 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___350 *fa_next;
	struct file___351 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___350 {
	const char *name;
	int fs_flags;
	struct dentry___350 * (*mount)(struct file_system_type___350 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___350 *);
	struct module___287 *owner;
	struct file_system_type___350 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___350 {
	struct inode___351 * (*alloc_inode)(struct super_block___350 *);
	void (*destroy_inode)(struct inode___351 *);
	void (*dirty_inode)(struct inode___351 *, int);
	int (*write_inode)(struct inode___351 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___351 *);
	void (*evict_inode)(struct inode___351 *);
	void (*put_super)(struct super_block___350 *);
	int (*sync_fs)(struct super_block___350 *, int);
	int (*freeze_super)(struct super_block___350 *);
	int (*freeze_fs)(struct super_block___350 *);
	int (*thaw_super)(struct super_block___350 *);
	int (*unfreeze_fs)(struct super_block___350 *);
	int (*statfs)(struct dentry___350 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___350 *, int *, char *);
	void (*umount_begin)(struct super_block___350 *);
	int (*show_options)(struct seq_file___298 *, struct dentry___350 *);
	int (*show_devname)(struct seq_file___298 *, struct dentry___350 *);
	int (*show_path)(struct seq_file___298 *, struct dentry___350 *);
	int (*show_stats)(struct seq_file___298 *, struct dentry___350 *);
	ssize_t (*quota_read)(struct super_block___350 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___350 *, int, const char *, size_t, loff_t);
	struct dquot___350 ** (*get_dquots)(struct inode___351 *);
	int (*bdev_try_to_free_page)(struct super_block___350 *, struct page___352 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___350 *, struct shrink_control___130 *);
	long int (*free_cached_objects)(struct super_block___350 *, struct shrink_control___130 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___88 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___88 *last_lookup;
	struct hd_struct___88 *part[0];
};

struct block_device_operations___85 {
	int (*open)(struct block_device___350 *, fmode_t);
	void (*release)(struct gendisk___88 *, fmode_t);
	int (*rw_page)(struct block_device___350 *, sector_t, struct page___352 *, unsigned int);
	int (*ioctl)(struct block_device___350 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___350 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___88 *, unsigned int);
	int (*media_changed)(struct gendisk___88 *);
	void (*unlock_native_capacity)(struct gendisk___88 *);
	int (*revalidate_disk)(struct gendisk___88 *);
	int (*getgeo)(struct block_device___350 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___350 *, long unsigned int);
	int (*report_zones)(struct gendisk___88 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___287 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___339(struct page___352 *);

struct bdi_writeback_congested___168 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___168 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bsg_ops___84 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___84 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___84 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___84 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___84(struct request___84 *, blk_status_t);

struct request___84 {
	struct request_queue___84 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___22 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___168 *bio;
	struct bio___168 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___170 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___88 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___84 *saved_end_io;
		} flush;
	};
	struct gendisk___88 *rq_disk;
	struct hd_struct___88 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___84 *end_io;
	void *end_io_data;
	struct request___84 *next_rq;
};

struct fwnode_reference_args___240;

struct fwnode_endpoint___240;

struct fwnode_operations___240 {
	struct fwnode_handle___240 * (*get)(struct fwnode_handle___240 *);
	void (*put)(struct fwnode_handle___240 *);
	bool (*device_is_available)(const struct fwnode_handle___240 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___240 *, const struct device___318 *);
	bool (*property_present)(const struct fwnode_handle___240 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___240 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___240 *, const char *, const char **, size_t);
	struct fwnode_handle___240 * (*get_parent)(const struct fwnode_handle___240 *);
	struct fwnode_handle___240 * (*get_next_child_node)(const struct fwnode_handle___240 *, struct fwnode_handle___240 *);
	struct fwnode_handle___240 * (*get_named_child_node)(const struct fwnode_handle___240 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___240 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___240 *);
	struct fwnode_handle___240 * (*graph_get_next_endpoint)(const struct fwnode_handle___240 *, struct fwnode_handle___240 *);
	struct fwnode_handle___240 * (*graph_get_remote_endpoint)(const struct fwnode_handle___240 *);
	struct fwnode_handle___240 * (*graph_get_port_parent)(struct fwnode_handle___240 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___240 *, struct fwnode_endpoint___240 *);
};

struct fwnode_endpoint___240 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___240 *local_fwnode;
};

struct fwnode_reference_args___240 {
	struct fwnode_handle___240 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct blk_mq_hw_ctx___22 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___84 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags___4 *tags;
	struct blk_mq_tags___4 *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	unsigned int rh_reserved_nr_expired;
	struct hlist_node cpuhp_dead;
	struct kobject___338 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___350 *debugfs_dir;
	struct dentry___350 *sched_debugfs_dir;
	struct list_head hctx_list;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___84;

struct elevator_mq_ops___84 {
	int (*init_sched)(struct request_queue___84 *, struct elevator_type___84 *);
	void (*exit_sched)(struct elevator_queue___84 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___22 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___22 *, unsigned int);
	bool (*allow_merge)(struct request_queue___84 *, struct request___84 *, struct bio___168 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx___22 *, struct bio___168 *);
	int (*request_merge)(struct request_queue___84 *, struct request___84 **, struct bio___168 *);
	void (*request_merged)(struct request_queue___84 *, struct request___84 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___84 *, struct request___84 *, struct request___84 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___84 *, struct bio___168 *);
	void (*finish_request)(struct request___84 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___22 *, struct list_head *, bool);
	struct request___84 * (*dispatch_request)(struct blk_mq_hw_ctx___22 *);
	bool (*has_work)(struct blk_mq_hw_ctx___22 *);
	void (*completed_request)(struct request___84 *, u64);
	void (*started_request)(struct request___84 *);
	void (*requeue_request)(struct request___84 *);
	struct request___84 * (*former_request)(struct request_queue___84 *, struct request___84 *);
	struct request___84 * (*next_request)(struct request_queue___84 *, struct request___84 *);
	void (*init_icq)(struct io_cq___88 *);
	void (*exit_icq)(struct io_cq___88 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx___22 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___84;

struct elevator_type___84 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___84 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___84 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___287 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___84 {
	struct elevator_type___84 *type;
	void *elevator_data;
	struct kobject___338 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___84 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___84 *, char *);
	ssize_t (*store)(struct elevator_queue___84 *, const char *, size_t);
};

struct blk_mq_queue_data___22;

typedef blk_status_t queue_rq_fn___22(struct blk_mq_hw_ctx___22 *, const struct blk_mq_queue_data___22 *);

typedef void commit_rqs_fn___22(struct blk_mq_hw_ctx___22 *);

typedef bool get_budget_fn___22(struct blk_mq_hw_ctx___22 *);

typedef void put_budget_fn___22(struct blk_mq_hw_ctx___22 *);

typedef enum blk_eh_timer_return timeout_fn___22(struct request___84 *, bool);

typedef int poll_fn___22(struct blk_mq_hw_ctx___22 *);

typedef void complete_fn___22(struct request___84 *);

typedef int init_hctx_fn___22(struct blk_mq_hw_ctx___22 *, void *, unsigned int);

typedef void exit_hctx_fn___22(struct blk_mq_hw_ctx___22 *, unsigned int);

typedef int init_request_fn___22(struct blk_mq_tag_set___22 *, struct request___84 *, unsigned int, unsigned int);

typedef void exit_request_fn___22(struct blk_mq_tag_set___22 *, struct request___84 *, unsigned int);

typedef bool busy_fn___22(struct request_queue___84 *);

typedef int map_queues_fn___22(struct blk_mq_tag_set___22 *);

typedef void cleanup_rq_fn___22(struct request___84 *);

struct blk_mq_ops___22 {
	queue_rq_fn___22 *queue_rq;
	commit_rqs_fn___22 *commit_rqs;
	get_budget_fn___22 *get_budget;
	put_budget_fn___22 *put_budget;
	timeout_fn___22 *timeout;
	poll_fn___22 *poll;
	complete_fn___22 *complete;
	init_hctx_fn___22 *init_hctx;
	exit_hctx_fn___22 *exit_hctx;
	init_request_fn___22 *init_request;
	exit_request_fn___22 *exit_request;
	void (*initialize_rq_fn)(struct request___84 *);
	busy_fn___22 *busy;
	map_queues_fn___22 *map_queues;
	void (*show_rq)(struct seq_file___298 *, struct request___84 *);
	union {
		cleanup_rq_fn___22 *cleanup_rq;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide47;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct blk_mq_tag_set___22 {
	struct blk_mq_queue_map map[6];
	unsigned int nr_maps;
	const struct blk_mq_ops___22 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	struct blk_mq_tags___4 **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct kernel_param_ops___284 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___284 *);
	int (*get)(char *, const struct kernel_param___284 *);
	void (*free)(void *);
};

struct kparam_array___284;

struct kernel_param___284 {
	const char *name;
	struct module___287 *mod;
	const struct kernel_param_ops___284 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___284 *arr;
	};
};

struct kparam_array___284 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___284 *ops;
	void *elem;
};

struct module_attribute___284 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___284 *, struct module_kobject___284 *, char *);
	ssize_t (*store)(struct module_attribute___284 *, struct module_kobject___284 *, const char *, size_t);
	void (*setup)(struct module___287 *, const char *);
	int (*test)(struct module___287 *);
	void (*free)(struct module___287 *);
};

struct blk_mq_queue_data___22 {
	struct request___84 *rq;
	bool last;
	long unsigned int rh_reserved1;
};

typedef int (*key_restrict_link_func_t___326)(struct key___325 *, const struct key_type *, const union key_payload *, struct key___325 *);

struct key_restriction___325;

struct key___325 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___352 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___325 *restrict_link;
};

struct key_restriction___325 {
	key_restrict_link_func_t___326 check;
	struct key___325 *key;
	struct key_type *keytype;
};

struct seq_operations___297 {
	void * (*start)(struct seq_file___298 *, loff_t *);
	void (*stop)(struct seq_file___298 *, void *);
	void * (*next)(struct seq_file___298 *, void *, loff_t *);
	int (*show)(struct seq_file___298 *, void *);
};

struct value_name_pair;

struct sa_name_list {
	int opcode;
	const struct value_name_pair *arr;
	int arr_sz;
};

struct value_name_pair {
	int value;
	const char *name;
};

struct error_info {
	short unsigned int code12;
	short unsigned int size;
};

struct error_info2 {
	unsigned char code1;
	unsigned char code2_min;
	unsigned char code2_max;
	const char *str;
	const char *fmt;
};

struct file___352;

struct kiocb___352;

struct vm_area_struct___353;

struct inode___352;

struct file_lock___352;

struct page___353;

struct seq_file___299;

struct file_operations___352 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___352 *, loff_t, int);
	ssize_t (*read)(struct file___352 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___352 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___352 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___352 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___352 *, bool);
	int (*iterate)(struct file___352 *, struct dir_context *);
	int (*iterate_shared)(struct file___352 *, struct dir_context *);
	__poll_t (*poll)(struct file___352 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___352 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___352 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___352 *, struct vm_area_struct___353 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___352 *, struct file___352 *);
	int (*flush)(struct file___352 *, fl_owner_t);
	int (*release)(struct inode___352 *, struct file___352 *);
	int (*fsync)(struct file___352 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___352 *, int);
	int (*lock)(struct file___352 *, int, struct file_lock___352 *);
	ssize_t (*sendpage)(struct file___352 *, struct page___353 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___352 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___352 *, int, struct file_lock___352 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___352 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___352 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___352 *, long int, struct file_lock___352 **, void **);
	long int (*fallocate)(struct file___352 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___299 *, struct file___352 *);
	ssize_t (*copy_file_range)(struct file___352 *, loff_t, struct file___352 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___352 *, loff_t, struct file___352 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___352 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___352 {
	u64 seqnum;
	struct vm_area_struct___353 *vmas[4];
};

struct page_frag___352 {
	struct page___353 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___352;

struct cred___326;

struct bio_list___169;

struct backing_dev_info___169;

struct io_context___89;

struct request_queue___85;

struct vm_struct___258;

struct task_struct___353 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___353 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___352 *mm;
	struct mm_struct___352 *active_mm;
	struct vmacache___352 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___353 *real_parent;
	struct task_struct___353 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___353 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___216 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___216 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___216 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___326 *ptracer_cred;
	const struct cred___326 *real_cred;
	const struct cred___326 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___353 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___169 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___169 *backing_dev_info;
	struct io_context___89 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___352 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___85 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___353 *oom_reaper_list;
	struct vm_struct___258 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___140 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct secondary_data___353 {
	void *stack;
	struct task_struct___353 *task;
	long int status;
};

typedef struct page___353 *pgtable_t___352;

struct address_space___351;

struct dev_pagemap___340;

struct page___353 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___351 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___353 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___352 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___352 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___340 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct key___326;

struct user_struct___326 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___326 *uid_keyring;
	struct key___326 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___340;

struct vm_area_struct___353 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___353 *vm_next;
	struct vm_area_struct___353 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___352 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___340 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___352 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct rw_semaphore___353 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___353 *owner;
};

struct core_state___352;

struct mm_struct___352 {
	struct {
		struct vm_area_struct___353 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___352 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___353 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___352 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___353 *owner;
		struct user_namespace___3 *user_ns;
		struct file___352 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___352 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___326 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___326 *session_keyring;
	struct key___326 *process_keyring;
	struct key___326 *thread_keyring;
	struct key___326 *request_key_auth;
	void *security;
	struct user_struct___326 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct bio___169;

struct bio_list___169 {
	struct bio___169 *head;
	struct bio___169 *tail;
};

struct bdi_writeback_congested___169;

struct bdi_writeback___169 {
	struct backing_dev_info___169 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___169 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___157 *memcg_css;
	struct cgroup_subsys_state___157 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___319;

struct dentry___351;

struct backing_dev_info___169 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___169 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___319 *dev;
	struct device___319 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___351 *debug_dir;
	struct dentry___351 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___89;

struct io_context___89 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___89 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

typedef blk_qc_t make_request_fn___85(struct request_queue___85 *, struct bio___169 *);

struct request___85;

typedef int dma_drain_needed_fn___85(struct request___85 *);

struct kset___338;

struct kobj_type___338;

struct kernfs_node___346;

struct kobject___339 {
	const char *name;
	struct list_head entry;
	struct kobject___339 *parent;
	struct kset___338 *kset;
	struct kobj_type___338 *ktype;
	struct kernfs_node___346 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___85;

struct bsg_class_device___85 {
	struct device___319 *class_dev;
	int minor;
	struct request_queue___85 *queue;
	const struct bsg_ops___85 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___169 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___169 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___85;

struct blk_mq_ops___23;

struct blk_mq_hw_ctx___23;

struct blk_mq_tag_set___23;

struct request_queue___85 {
	struct list_head queue_head;
	struct request___85 *last_merge;
	struct elevator_queue___85 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___85 *make_request_fn;
	dma_drain_needed_fn___85 *dma_drain_needed;
	const struct blk_mq_ops___23 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___23 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___169 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___339 kobj;
	struct kobject___339 *mq_kobj;
	struct blk_integrity integrity;
	struct device___319 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	struct bsg_class_device___85 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set___23 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___169 bio_split;
	struct dentry___351 *debugfs_dir;
	struct dentry___351 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___258 {
	struct vm_struct___258 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___353 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct pglist_data___352;

struct lruvec___352 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___352 *pgdat;
};

struct zone___352 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___352 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___352 {
	struct zone___352 *zone;
	int zone_idx;
};

struct zonelist___352 {
	struct zoneref___352 _zonerefs[25];
};

struct pglist_data___352 {
	struct zone___352 node_zones[3];
	struct zonelist___352 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___353 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___353 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___352 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___352 {
	struct rw_semaphore___353 rwsem;
	struct notifier_block *head;
};

struct bio_vec___171 {
	struct page___353 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

typedef void bio_end_io_t___169(struct bio___169 *);

struct gendisk___89;

struct bio_integrity_payload___169;

struct bio___169 {
	struct bio___169 *bi_next;
	struct gendisk___89 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___169 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___169 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___171 *bi_io_vec;
	struct bio_set___169 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___171 bi_inline_vecs[0];
};

struct bio_integrity_payload___169 {
	struct bio___169 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___171 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___171 bip_inline_vecs[0];
};

struct dev_pm_info___319 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___5 *subsys_data;
	void (*set_latency_tolerance)(struct device___319 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___319;

struct bus_type___319;

struct device_driver___319;

struct dev_pm_domain___319;

struct dma_map_ops___108;

struct fwnode_handle___241;

struct class___319;

struct attribute_group___316;

struct device___319 {
	struct device___319 *parent;
	struct device_private *p;
	struct kobject___339 kobj;
	const char *init_name;
	const struct device_type___319 *type;
	struct mutex mutex;
	struct bus_type___319 *bus;
	struct device_driver___319 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___319 power;
	struct dev_pm_domain___319 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___108 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___241 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___319 *class;
	const struct attribute_group___316 **groups;
	void (*release)(struct device___319 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___89 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___319 __dev;
	struct kobject___339 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___89;

struct block_device_operations___86;

struct gendisk___89 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___89 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___89 *part_tbl;
	struct hd_struct___89 part0;
	const struct block_device_operations___86 *fops;
	struct request_queue___85 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___353 lookup_sem;
	struct kobject___339 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___339 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_ops___319;

struct device_type___319 {
	const char *name;
	const struct attribute_group___316 **groups;
	int (*uevent)(struct device___319 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___319 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___319 *);
	const struct dev_pm_ops___319 *pm;
};

struct class___319 {
	const char *name;
	struct module___11 *owner;
	const struct attribute_group___316 **class_groups;
	const struct attribute_group___316 **dev_groups;
	struct kobject___339 *dev_kobj;
	int (*dev_uevent)(struct device___319 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___319 *, umode_t *);
	void (*class_release)(struct class___319 *);
	void (*dev_release)(struct device___319 *);
	int (*shutdown_pre)(struct device___319 *);
	const struct kobj_ns_type_operations___27 *ns_type;
	const void * (*namespace)(struct device___319 *);
	const struct dev_pm_ops___319 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct kernfs_root___345;

struct kernfs_elem_dir___345 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___345 *root;
};

struct kernfs_syscall_ops___345;

struct kernfs_root___345 {
	struct kernfs_node___346 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___345 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___345 {
	struct kernfs_node___346 *target_kn;
};

struct kernfs_ops___345;

struct kernfs_elem_attr___345 {
	const struct kernfs_ops___345 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___346 *notify_next;
};

struct kernfs_node___346 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___346 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___345 dir;
		struct kernfs_elem_symlink___345 symlink;
		struct kernfs_elem_attr___345 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___345;

struct kernfs_ops___345 {
	int (*open)(struct kernfs_open_file___345 *);
	void (*release)(struct kernfs_open_file___345 *);
	int (*seq_show)(struct seq_file___299 *, void *);
	void * (*seq_start)(struct seq_file___299 *, loff_t *);
	void * (*seq_next)(struct seq_file___299 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___299 *, void *);
	ssize_t (*read)(struct kernfs_open_file___345 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___345 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___345 *, struct vm_area_struct___353 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___345 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___345 {
	int (*remount_fs)(struct kernfs_root___345 *, int *, char *);
	int (*show_options)(struct seq_file___299 *, struct kernfs_root___345 *);
	int (*mkdir)(struct kernfs_node___346 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___346 *);
	int (*rename)(struct kernfs_node___346 *, struct kernfs_node___346 *, const char *);
	int (*show_path)(struct seq_file___299 *, struct kernfs_node___346 *, struct kernfs_root___345 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___298;

struct seq_file___299 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___298 *op;
	int poll_event;
	const struct file___352 *file;
	void *private;
};

struct kernfs_open_file___345 {
	struct kernfs_node___346 *kn;
	struct file___352 *file;
	struct seq_file___299 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___340 *vm_ops;
};

struct path___352 {
	struct vfsmount *mnt;
	struct dentry___351 *dentry;
};

struct file___352 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___352 f_path;
	struct inode___352 *f_inode;
	const struct file_operations___352 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___216 f_owner;
	const struct cred___326 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___351 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___340;

struct vm_operations_struct___340 {
	void (*open)(struct vm_area_struct___353 *);
	void (*close)(struct vm_area_struct___353 *);
	int (*split)(struct vm_area_struct___353 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___353 *);
	vm_fault_t (*fault)(struct vm_fault___340 *);
	vm_fault_t (*huge_fault)(struct vm_fault___340 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___340 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___353 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___340 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___340 *);
	int (*access)(struct vm_area_struct___353 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___353 *);
	int (*set_policy)(struct vm_area_struct___353 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___353 *, long unsigned int);
	struct page___353 * (*find_special_page)(struct vm_area_struct___353 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___315;

struct attribute_group___316 {
	const char *name;
	umode_t (*is_visible)(struct kobject___339 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___339 *, struct bin_attribute___315 *, int);
	struct attribute **attrs;
	struct bin_attribute___315 **bin_attrs;
};

struct bin_attribute___315 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___352 *, struct kobject___339 *, struct bin_attribute___315 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___352 *, struct kobject___339 *, struct bin_attribute___315 *, char *, loff_t, size_t);
	int (*mmap)(struct file___352 *, struct kobject___339 *, struct bin_attribute___315 *, struct vm_area_struct___353 *);
};

struct sysfs_ops___338 {
	ssize_t (*show)(struct kobject___339 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___339 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___338;

struct kset___338 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___339 kobj;
	const struct kset_uevent_ops___338 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___338 {
	void (*release)(struct kobject___339 *);
	const struct sysfs_ops___338 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___27 * (*child_ns_type)(struct kobject___339 *);
	const void * (*namespace)(struct kobject___339 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___338 {
	int (* const filter)(struct kset___338 *, struct kobject___339 *);
	const char * (* const name)(struct kset___338 *, struct kobject___339 *);
	int (* const uevent)(struct kset___338 *, struct kobject___339 *, struct kobj_uevent_env *);
};

struct kobj_attribute___330 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___339 *, struct kobj_attribute___330 *, char *);
	ssize_t (*store)(struct kobject___339 *, struct kobj_attribute___330 *, const char *, size_t);
};

struct dev_pm_ops___319 {
	int (*prepare)(struct device___319 *);
	void (*complete)(struct device___319 *);
	int (*suspend)(struct device___319 *);
	int (*resume)(struct device___319 *);
	int (*freeze)(struct device___319 *);
	int (*thaw)(struct device___319 *);
	int (*poweroff)(struct device___319 *);
	int (*restore)(struct device___319 *);
	int (*suspend_late)(struct device___319 *);
	int (*resume_early)(struct device___319 *);
	int (*freeze_late)(struct device___319 *);
	int (*thaw_early)(struct device___319 *);
	int (*poweroff_late)(struct device___319 *);
	int (*restore_early)(struct device___319 *);
	int (*suspend_noirq)(struct device___319 *);
	int (*resume_noirq)(struct device___319 *);
	int (*freeze_noirq)(struct device___319 *);
	int (*thaw_noirq)(struct device___319 *);
	int (*poweroff_noirq)(struct device___319 *);
	int (*restore_noirq)(struct device___319 *);
	int (*runtime_suspend)(struct device___319 *);
	int (*runtime_resume)(struct device___319 *);
	int (*runtime_idle)(struct device___319 *);
};

struct dev_pm_domain___319 {
	struct dev_pm_ops___319 ops;
	void (*detach)(struct device___319 *, bool);
	int (*activate)(struct device___319 *);
	void (*sync)(struct device___319 *);
	void (*dismiss)(struct device___319 *);
};

struct bus_type___319 {
	const char *name;
	const char *dev_name;
	struct device___319 *dev_root;
	const struct attribute_group___316 **bus_groups;
	const struct attribute_group___316 **dev_groups;
	const struct attribute_group___316 **drv_groups;
	int (*match)(struct device___319 *, struct device_driver___319 *);
	int (*uevent)(struct device___319 *, struct kobj_uevent_env *);
	int (*probe)(struct device___319 *);
	int (*remove)(struct device___319 *);
	void (*shutdown)(struct device___319 *);
	int (*online)(struct device___319 *);
	int (*offline)(struct device___319 *);
	int (*suspend)(struct device___319 *, pm_message_t);
	int (*resume)(struct device___319 *);
	int (*num_vf)(struct device___319 *);
	int (*dma_configure)(struct device___319 *);
	const struct dev_pm_ops___319 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___319 {
	const char *name;
	struct bus_type___319 *bus;
	struct module___11 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___319 *);
	int (*remove)(struct device___319 *);
	void (*shutdown)(struct device___319 *);
	int (*suspend)(struct device___319 *, pm_message_t);
	int (*resume)(struct device___319 *);
	const struct attribute_group___316 **groups;
	const struct dev_pm_ops___319 *pm;
	void (*coredump)(struct device___319 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_attribute___37 {
	struct attribute attr;
	ssize_t (*show)(struct device___319 *, struct device_attribute___37 *, char *);
	ssize_t (*store)(struct device___319 *, struct device_attribute___37 *, const char *, size_t);
};

struct dma_map_ops___108 {
	void * (*alloc)(struct device___319 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___319 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___319 *, struct vm_area_struct___353 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___319 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___319 *, struct page___353 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___319 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___319 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___319 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___319 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___319 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___319 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide40;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___319 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___319 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___319 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___319 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___319 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___319 *, u64);
	u64 (*get_required_mask)(struct device___319 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___241;

struct fwnode_handle___241 {
	struct fwnode_handle___241 *secondary;
	const struct fwnode_operations___241 *ops;
};

struct dentry_operations___351;

struct super_block___351;

struct dentry___351 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___351 *d_parent;
	struct qstr d_name;
	struct inode___352 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___351 *d_op;
	struct super_block___351 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___351;

struct address_space___351 {
	struct inode___352 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___353 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___351 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___351;

struct block_device___351;

struct inode___352 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___351 *i_op;
	struct super_block___351 *i_sb;
	struct address_space___351 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___353 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___169 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___352 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___351 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___351 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___351 {
	int (*d_revalidate)(struct dentry___351 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___351 *, unsigned int);
	int (*d_hash)(const struct dentry___351 *, struct qstr *);
	int (*d_compare)(const struct dentry___351 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___351 *);
	int (*d_init)(struct dentry___351 *);
	void (*d_release)(struct dentry___351 *);
	void (*d_prune)(struct dentry___351 *);
	void (*d_iput)(struct dentry___351 *, struct inode___352 *);
	char * (*d_dname)(struct dentry___351 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___352 *);
	int (*d_manage)(const struct path___352 *, bool);
	struct dentry___351 * (*d_real)(struct dentry___351 *, const struct inode___352 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___351;

struct mem_dqinfo___351 {
	struct quota_format_type___351 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___351;

struct quota_info___351 {
	unsigned int flags;
	struct rw_semaphore___353 dqio_sem;
	struct inode___352 *files[3];
	struct mem_dqinfo___351 info[3];
	const struct quota_format_ops___351 *ops[3];
};

struct rcuwait___351 {
	struct task_struct___353 *task;
};

struct percpu_rw_semaphore___351 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___353 rw_sem;
	struct rcuwait___351 writer;
	int readers_block;
};

struct sb_writers___351 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___351 rw_sem[3];
};

struct file_system_type___351;

struct super_operations___351;

struct dquot_operations___351;

struct quotactl_ops___351;

struct super_block___351 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___351 *s_type;
	const struct super_operations___351 *s_op;
	const struct dquot_operations___351 *dq_op;
	const struct quotactl_ops___351 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___351 *s_root;
	struct rw_semaphore___353 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___351 *s_bdev;
	struct backing_dev_info___169 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___351 s_dquot;
	struct sb_writers___351 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___351 *s_d_op;
	int cleancache_poolid;
	struct shrinker___130 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

typedef int (*dev_page_fault_t___340)(struct vm_area_struct___353 *, long unsigned int, const struct page___353 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___340)(struct page___353 *, void *);

struct dev_pagemap___340 {
	dev_page_fault_t___340 page_fault;
	dev_page_free_t___340 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___319 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___352 {
	struct task_struct___353 *task;
	struct core_thread___352 *next;
};

struct core_state___352 {
	atomic_t nr_threads;
	struct core_thread___352 dumper;
	struct completion startup;
};

struct vm_fault___340 {
	struct vm_area_struct___353 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___353 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___353 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___352 prealloc_pte;
};

struct io_cq___89 {
	struct request_queue___85 *q;
	struct io_context___89 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___352 {
	struct file___352 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___352 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___351 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___352 *ia_file;
};

struct dquot___351 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___351 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___351 {
	int qf_fmt_id;
	const struct quota_format_ops___351 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___351 *qf_next;
};

struct quota_format_ops___351 {
	int (*check_quota_file)(struct super_block___351 *, int);
	int (*read_file_info)(struct super_block___351 *, int);
	int (*write_file_info)(struct super_block___351 *, int);
	int (*free_file_info)(struct super_block___351 *, int);
	int (*read_dqblk)(struct dquot___351 *);
	int (*commit_dqblk)(struct dquot___351 *);
	int (*release_dqblk)(struct dquot___351 *);
	int (*get_next_id)(struct super_block___351 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___351 {
	int (*write_dquot)(struct dquot___351 *);
	struct dquot___351 * (*alloc_dquot)(struct super_block___351 *, int);
	void (*destroy_dquot)(struct dquot___351 *);
	int (*acquire_dquot)(struct dquot___351 *);
	int (*release_dquot)(struct dquot___351 *);
	int (*mark_dirty)(struct dquot___351 *);
	int (*write_info)(struct super_block___351 *, int);
	qsize_t * (*get_reserved_space)(struct inode___352 *);
	int (*get_projid)(struct inode___352 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___352 *, qsize_t *);
	int (*get_next_id)(struct super_block___351 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___351 {
	int (*quota_on)(struct super_block___351 *, int, int, const struct path___352 *);
	int (*quota_off)(struct super_block___351 *, int);
	int (*quota_enable)(struct super_block___351 *, unsigned int);
	int (*quota_disable)(struct super_block___351 *, unsigned int);
	int (*quota_sync)(struct super_block___351 *, int);
	int (*set_info)(struct super_block___351 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___351 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___351 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___351 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___351 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___351 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___351 {
	int (*writepage)(struct page___353 *, struct writeback_control___3 *);
	int (*readpage)(struct file___352 *, struct page___353 *);
	int (*writepages)(struct address_space___351 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___353 *);
	int (*readpages)(struct file___352 *, struct address_space___351 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___352 *, struct address_space___351 *, loff_t, unsigned int, unsigned int, struct page___353 **, void **);
	int (*write_end)(struct file___352 *, struct address_space___351 *, loff_t, unsigned int, unsigned int, struct page___353 *, void *);
	sector_t (*bmap)(struct address_space___351 *, sector_t);
	void (*invalidatepage)(struct page___353 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___353 *, gfp_t);
	void (*freepage)(struct page___353 *);
	ssize_t (*direct_IO)(struct kiocb___352 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___351 *, struct page___353 *, struct page___353 *, enum migrate_mode);
	bool (*isolate_page)(struct page___353 *, isolate_mode_t);
	void (*putback_page)(struct page___353 *);
	int (*launder_page)(struct page___353 *);
	int (*is_partially_uptodate)(struct page___353 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___353 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___351 *, struct page___353 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___352 *, sector_t *);
	void (*swap_deactivate)(struct file___352 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___351 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___352 *bd_inode;
	struct super_block___351 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___351 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___89 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___89 *bd_disk;
	struct request_queue___85 *bd_queue;
	struct backing_dev_info___169 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___351 {
	struct dentry___351 * (*lookup)(struct inode___352 *, struct dentry___351 *, unsigned int);
	const char * (*get_link)(struct dentry___351 *, struct inode___352 *, struct delayed_call *);
	int (*permission)(struct inode___352 *, int);
	struct posix_acl * (*get_acl)(struct inode___352 *, int);
	int (*readlink)(struct dentry___351 *, char *, int);
	int (*create)(struct inode___352 *, struct dentry___351 *, umode_t, bool);
	int (*link)(struct dentry___351 *, struct inode___352 *, struct dentry___351 *);
	int (*unlink)(struct inode___352 *, struct dentry___351 *);
	int (*symlink)(struct inode___352 *, struct dentry___351 *, const char *);
	int (*mkdir)(struct inode___352 *, struct dentry___351 *, umode_t);
	int (*rmdir)(struct inode___352 *, struct dentry___351 *);
	int (*mknod)(struct inode___352 *, struct dentry___351 *, umode_t, dev_t);
	int (*rename)(struct inode___352 *, struct dentry___351 *, struct inode___352 *, struct dentry___351 *, unsigned int);
	int (*setattr)(struct dentry___351 *, struct iattr___351 *);
	int (*getattr)(const struct path___352 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___351 *, char *, size_t);
	int (*fiemap)(struct inode___352 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___352 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___352 *, struct dentry___351 *, struct file___352 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___352 *, struct dentry___351 *, umode_t);
	int (*set_acl)(struct inode___352 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___351 {
	void (*fl_copy_lock)(struct file_lock___352 *, struct file_lock___352 *);
	void (*fl_release_private)(struct file_lock___352 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___351;

struct lock_manager_operations___351;

struct file_lock___352 {
	struct file_lock___352 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___352 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___351 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___351 *fl_ops;
	const struct lock_manager_operations___351 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___351 {
	int (*lm_compare_owner)(struct file_lock___352 *, struct file_lock___352 *);
	long unsigned int (*lm_owner_key)(struct file_lock___352 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___352 *);
	int (*lm_grant)(struct file_lock___352 *, int);
	bool (*lm_break)(struct file_lock___352 *);
	int (*lm_change)(struct file_lock___352 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___352 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___351 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___351 *fa_next;
	struct file___352 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___351 {
	const char *name;
	int fs_flags;
	struct dentry___351 * (*mount)(struct file_system_type___351 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___351 *);
	struct module___11 *owner;
	struct file_system_type___351 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___351 {
	struct inode___352 * (*alloc_inode)(struct super_block___351 *);
	void (*destroy_inode)(struct inode___352 *);
	void (*dirty_inode)(struct inode___352 *, int);
	int (*write_inode)(struct inode___352 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___352 *);
	void (*evict_inode)(struct inode___352 *);
	void (*put_super)(struct super_block___351 *);
	int (*sync_fs)(struct super_block___351 *, int);
	int (*freeze_super)(struct super_block___351 *);
	int (*freeze_fs)(struct super_block___351 *);
	int (*thaw_super)(struct super_block___351 *);
	int (*unfreeze_fs)(struct super_block___351 *);
	int (*statfs)(struct dentry___351 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___351 *, int *, char *);
	void (*umount_begin)(struct super_block___351 *);
	int (*show_options)(struct seq_file___299 *, struct dentry___351 *);
	int (*show_devname)(struct seq_file___299 *, struct dentry___351 *);
	int (*show_path)(struct seq_file___299 *, struct dentry___351 *);
	int (*show_stats)(struct seq_file___299 *, struct dentry___351 *);
	ssize_t (*quota_read)(struct super_block___351 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___351 *, int, const char *, size_t, loff_t);
	struct dquot___351 ** (*get_dquots)(struct inode___352 *);
	int (*bdev_try_to_free_page)(struct super_block___351 *, struct page___353 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___351 *, struct shrink_control___130 *);
	long int (*free_cached_objects)(struct super_block___351 *, struct shrink_control___130 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___89 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___89 *last_lookup;
	struct hd_struct___89 *part[0];
};

struct block_device_operations___86 {
	int (*open)(struct block_device___351 *, fmode_t);
	void (*release)(struct gendisk___89 *, fmode_t);
	int (*rw_page)(struct block_device___351 *, sector_t, struct page___353 *, unsigned int);
	int (*ioctl)(struct block_device___351 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___351 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___89 *, unsigned int);
	int (*media_changed)(struct gendisk___89 *);
	void (*unlock_native_capacity)(struct gendisk___89 *);
	int (*revalidate_disk)(struct gendisk___89 *);
	int (*getgeo)(struct block_device___351 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___351 *, long unsigned int);
	int (*report_zones)(struct gendisk___89 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___11 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___340(struct page___353 *);

struct bdi_writeback_congested___169 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___169 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bsg_ops___85 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___85 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___85 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___85 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___85(struct request___85 *, blk_status_t);

struct request___85 {
	struct request_queue___85 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___23 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___169 *bio;
	struct bio___169 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___171 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___89 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___85 *saved_end_io;
		} flush;
	};
	struct gendisk___89 *rq_disk;
	struct hd_struct___89 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___85 *end_io;
	void *end_io_data;
	struct request___85 *next_rq;
};

struct fwnode_reference_args___241;

struct fwnode_endpoint___241;

struct fwnode_operations___241 {
	struct fwnode_handle___241 * (*get)(struct fwnode_handle___241 *);
	void (*put)(struct fwnode_handle___241 *);
	bool (*device_is_available)(const struct fwnode_handle___241 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___241 *, const struct device___319 *);
	bool (*property_present)(const struct fwnode_handle___241 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___241 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___241 *, const char *, const char **, size_t);
	struct fwnode_handle___241 * (*get_parent)(const struct fwnode_handle___241 *);
	struct fwnode_handle___241 * (*get_next_child_node)(const struct fwnode_handle___241 *, struct fwnode_handle___241 *);
	struct fwnode_handle___241 * (*get_named_child_node)(const struct fwnode_handle___241 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___241 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___241 *);
	struct fwnode_handle___241 * (*graph_get_next_endpoint)(const struct fwnode_handle___241 *, struct fwnode_handle___241 *);
	struct fwnode_handle___241 * (*graph_get_remote_endpoint)(const struct fwnode_handle___241 *);
	struct fwnode_handle___241 * (*graph_get_port_parent)(struct fwnode_handle___241 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___241 *, struct fwnode_endpoint___241 *);
};

struct fwnode_endpoint___241 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___241 *local_fwnode;
};

struct fwnode_reference_args___241 {
	struct fwnode_handle___241 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct blk_mq_hw_ctx___23 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___85 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags___4 *tags;
	struct blk_mq_tags___4 *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	unsigned int rh_reserved_nr_expired;
	struct hlist_node cpuhp_dead;
	struct kobject___339 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___351 *debugfs_dir;
	struct dentry___351 *sched_debugfs_dir;
	struct list_head hctx_list;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___85;

struct elevator_mq_ops___85 {
	int (*init_sched)(struct request_queue___85 *, struct elevator_type___85 *);
	void (*exit_sched)(struct elevator_queue___85 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___23 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___23 *, unsigned int);
	bool (*allow_merge)(struct request_queue___85 *, struct request___85 *, struct bio___169 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx___23 *, struct bio___169 *);
	int (*request_merge)(struct request_queue___85 *, struct request___85 **, struct bio___169 *);
	void (*request_merged)(struct request_queue___85 *, struct request___85 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___85 *, struct request___85 *, struct request___85 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___85 *, struct bio___169 *);
	void (*finish_request)(struct request___85 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___23 *, struct list_head *, bool);
	struct request___85 * (*dispatch_request)(struct blk_mq_hw_ctx___23 *);
	bool (*has_work)(struct blk_mq_hw_ctx___23 *);
	void (*completed_request)(struct request___85 *, u64);
	void (*started_request)(struct request___85 *);
	void (*requeue_request)(struct request___85 *);
	struct request___85 * (*former_request)(struct request_queue___85 *, struct request___85 *);
	struct request___85 * (*next_request)(struct request_queue___85 *, struct request___85 *);
	void (*init_icq)(struct io_cq___89 *);
	void (*exit_icq)(struct io_cq___89 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx___23 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___85;

struct elevator_type___85 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___85 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___85 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___11 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___85 {
	struct elevator_type___85 *type;
	void *elevator_data;
	struct kobject___339 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___85 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___85 *, char *);
	ssize_t (*store)(struct elevator_queue___85 *, const char *, size_t);
};

struct blk_mq_queue_data___23;

typedef blk_status_t queue_rq_fn___23(struct blk_mq_hw_ctx___23 *, const struct blk_mq_queue_data___23 *);

typedef void commit_rqs_fn___23(struct blk_mq_hw_ctx___23 *);

typedef bool get_budget_fn___23(struct blk_mq_hw_ctx___23 *);

typedef void put_budget_fn___23(struct blk_mq_hw_ctx___23 *);

typedef enum blk_eh_timer_return timeout_fn___23(struct request___85 *, bool);

typedef int poll_fn___23(struct blk_mq_hw_ctx___23 *);

typedef void complete_fn___23(struct request___85 *);

typedef int init_hctx_fn___23(struct blk_mq_hw_ctx___23 *, void *, unsigned int);

typedef void exit_hctx_fn___23(struct blk_mq_hw_ctx___23 *, unsigned int);

typedef int init_request_fn___23(struct blk_mq_tag_set___23 *, struct request___85 *, unsigned int, unsigned int);

typedef void exit_request_fn___23(struct blk_mq_tag_set___23 *, struct request___85 *, unsigned int);

typedef bool busy_fn___23(struct request_queue___85 *);

typedef int map_queues_fn___23(struct blk_mq_tag_set___23 *);

typedef void cleanup_rq_fn___23(struct request___85 *);

struct blk_mq_ops___23 {
	queue_rq_fn___23 *queue_rq;
	commit_rqs_fn___23 *commit_rqs;
	get_budget_fn___23 *get_budget;
	put_budget_fn___23 *put_budget;
	timeout_fn___23 *timeout;
	poll_fn___23 *poll;
	complete_fn___23 *complete;
	init_hctx_fn___23 *init_hctx;
	exit_hctx_fn___23 *exit_hctx;
	init_request_fn___23 *init_request;
	exit_request_fn___23 *exit_request;
	void (*initialize_rq_fn)(struct request___85 *);
	busy_fn___23 *busy;
	map_queues_fn___23 *map_queues;
	void (*show_rq)(struct seq_file___299 *, struct request___85 *);
	union {
		cleanup_rq_fn___23 *cleanup_rq;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide45;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct blk_mq_tag_set___23 {
	struct blk_mq_queue_map map[6];
	unsigned int nr_maps;
	const struct blk_mq_ops___23 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	struct blk_mq_tags___4 **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct Scsi_Host___4;

struct scsi_target___4;

struct scsi_device___4 {
	struct Scsi_Host___4 *host;
	struct request_queue___85 *request_queue;
	struct list_head siblings;
	struct list_head same_target_siblings;
	atomic_t device_busy;
	atomic_t device_blocked;
	spinlock_t list_lock;
	struct list_head cmd_list;
	struct list_head starved_entry;
	short unsigned int queue_depth;
	short unsigned int max_queue_depth;
	short unsigned int last_queue_full_depth;
	short unsigned int last_queue_full_count;
	long unsigned int last_queue_full_time;
	long unsigned int queue_ramp_up_period;
	long unsigned int last_queue_ramp_up;
	unsigned int id;
	unsigned int channel;
	u64 lun;
	unsigned int manufacturer;
	unsigned int sector_size;
	void *hostdata;
	unsigned char type;
	char scsi_level;
	char inq_periph_qual;
	struct mutex inquiry_mutex;
	unsigned char inquiry_len;
	unsigned char *inquiry;
	const char *vendor;
	const char *model;
	const char *rev;
	struct scsi_vpd *vpd_pg83;
	struct scsi_vpd *vpd_pg80;
	unsigned char current_tag;
	struct scsi_target___4 *sdev_target;
	blist_flags_t sdev_bflags;
	unsigned int eh_timeout;
	unsigned int removable: 1;
	unsigned int changed: 1;
	unsigned int busy: 1;
	unsigned int lockable: 1;
	unsigned int locked: 1;
	unsigned int borken: 1;
	unsigned int disconnect: 1;
	unsigned int soft_reset: 1;
	unsigned int sdtr: 1;
	unsigned int wdtr: 1;
	unsigned int ppr: 1;
	unsigned int tagged_supported: 1;
	unsigned int simple_tags: 1;
	unsigned int was_reset: 1;
	unsigned int expecting_cc_ua: 1;
	unsigned int use_10_for_rw: 1;
	unsigned int use_10_for_ms: 1;
	unsigned int no_report_opcodes: 1;
	unsigned int no_write_same: 1;
	unsigned int use_16_for_rw: 1;
	unsigned int skip_ms_page_8: 1;
	unsigned int skip_ms_page_3f: 1;
	unsigned int skip_vpd_pages: 1;
	unsigned int try_vpd_pages: 1;
	unsigned int use_192_bytes_for_3f: 1;
	unsigned int no_start_on_add: 1;
	unsigned int allow_restart: 1;
	unsigned int manage_start_stop: 1;
	unsigned int start_stop_pwr_cond: 1;
	unsigned int no_uld_attach: 1;
	unsigned int select_no_atn: 1;
	unsigned int fix_capacity: 1;
	unsigned int guess_capacity: 1;
	unsigned int retry_hwerror: 1;
	unsigned int last_sector_bug: 1;
	unsigned int no_read_disc_info: 1;
	unsigned int no_read_capacity_16: 1;
	unsigned int try_rc_10_first: 1;
	unsigned int security_supported: 1;
	unsigned int is_visible: 1;
	unsigned int wce_default_on: 1;
	unsigned int no_dif: 1;
	unsigned int broken_fua: 1;
	unsigned int lun_in_cdb: 1;
	unsigned int unmap_limit_for_ws: 1;
	atomic_t disk_events_disable_depth;
	long unsigned int supported_events[1];
	long unsigned int pending_events[1];
	struct list_head event_list;
	struct work_struct event_work;
	unsigned int max_device_blocked;
	atomic_t iorequest_cnt;
	atomic_t iodone_cnt;
	atomic_t ioerr_cnt;
	struct device___319 sdev_gendev;
	struct device___319 sdev_dev;
	struct execute_work ew;
	struct work_struct requeue_work;
	struct scsi_device_handler *handler;
	void *handler_data;
	unsigned char access_state;
	struct mutex state_mutex;
	enum scsi_device_state sdev_state;
	struct task_struct___353 *quiesced_by;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int sdev_data[0];
};

struct scsi_host_template___4;

struct Scsi_Host___4 {
	struct list_head __devices;
	struct list_head __targets;
	struct list_head starved_list;
	spinlock_t default_lock;
	spinlock_t *host_lock;
	struct mutex scan_mutex;
	struct list_head eh_cmd_q;
	struct task_struct___353 *ehandler;
	struct completion *eh_action;
	wait_queue_head_t host_wait;
	struct scsi_host_template___4 *hostt;
	struct scsi_transport_template *transportt;
	struct blk_mq_tag_set___23 tag_set;
	atomic_t host_busy;
	atomic_t host_blocked;
	unsigned int host_failed;
	unsigned int host_eh_scheduled;
	unsigned int host_no;
	int eh_deadline;
	long unsigned int last_reset;
	unsigned int max_channel;
	unsigned int max_id;
	u64 max_lun;
	unsigned int unique_id;
	short unsigned int max_cmd_len;
	int this_id;
	int can_queue;
	short int cmd_per_lun;
	short unsigned int sg_tablesize;
	short unsigned int sg_prot_tablesize;
	unsigned int max_sectors;
	long unsigned int dma_boundary;
	unsigned int nr_hw_queues;
	long unsigned int cmd_serial_number;
	unsigned int active_mode: 2;
	unsigned int unchecked_isa_dma: 1;
	unsigned int use_clustering: 1;
	unsigned int host_self_blocked: 1;
	unsigned int reverse_ordering: 1;
	unsigned int tmf_in_progress: 1;
	unsigned int async_scan: 1;
	unsigned int eh_noresume: 1;
	unsigned int no_write_same: 1;
	unsigned int use_cmd_list: 1;
	unsigned int short_inquiry: 1;
	char work_q_name[20];
	struct workqueue_struct *work_q;
	struct workqueue_struct *tmf_work_q;
	unsigned int no_scsi2_lun_in_cdb: 1;
	unsigned int max_host_blocked;
	unsigned int prot_capabilities;
	unsigned char prot_guard_type;
	long unsigned int base;
	long unsigned int io_port;
	unsigned char n_io_port;
	unsigned char dma_channel;
	unsigned int irq;
	enum scsi_host_state shost_state;
	struct device___319 shost_gendev;
	struct device___319 shost_dev;
	void *shost_data;
	struct device___319 *dma_dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int hostdata[0];
};

struct scsi_target___4 {
	struct scsi_device___4 *starget_sdev_user;
	struct list_head siblings;
	struct list_head devices;
	struct device___319 dev;
	struct kref reap_ref;
	unsigned int channel;
	unsigned int id;
	unsigned int create: 1;
	unsigned int single_lun: 1;
	unsigned int pdt_1f_for_no_lun: 1;
	unsigned int no_report_luns: 1;
	unsigned int expecting_lun_change: 1;
	atomic_t target_busy;
	atomic_t target_blocked;
	unsigned int can_queue;
	unsigned int max_target_blocked;
	char scsi_level;
	enum scsi_target_state state;
	void *hostdata;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int starget_data[0];
};

struct blk_mq_queue_data___23 {
	struct request___85 *rq;
	bool last;
	long unsigned int rh_reserved1;
};

struct scsi_cmnd___4 {
	struct scsi_request req;
	struct scsi_device___4 *device;
	struct list_head list;
	struct list_head eh_entry;
	struct delayed_work abort_work;
	struct callback_head rcu;
	int eh_eflags;
	long unsigned int serial_number;
	long unsigned int jiffies_at_alloc;
	int retries;
	int allowed;
	unsigned char prot_op;
	unsigned char prot_type;
	unsigned char prot_flags;
	short unsigned int cmd_len;
	enum dma_data_direction sc_data_direction;
	unsigned char *cmnd;
	struct scsi_data_buffer sdb;
	struct scsi_data_buffer *prot_sdb;
	unsigned int underflow;
	unsigned int transfersize;
	struct request___85 *request;
	unsigned char *sense_buffer;
	void (*scsi_done)(struct scsi_cmnd___4 *);
	struct scsi_pointer SCp;
	unsigned char *host_scribble;
	int result;
	int flags;
	long unsigned int state;
	unsigned char tag;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*key_restrict_link_func_t___327)(struct key___326 *, const struct key_type *, const union key_payload *, struct key___326 *);

struct key_restriction___326;

struct key___326 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___353 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___326 *restrict_link;
};

struct key_restriction___326 {
	key_restrict_link_func_t___327 check;
	struct key___326 *key;
	struct key_type *keytype;
};

struct seq_operations___298 {
	void * (*start)(struct seq_file___299 *, loff_t *);
	void (*stop)(struct seq_file___299 *, void *);
	void * (*next)(struct seq_file___299 *, void *, loff_t *);
	int (*show)(struct seq_file___299 *, void *);
};

struct scsi_host_template___4 {
	struct module___11 *module;
	const char *name;
	const char * (*info)(struct Scsi_Host___4 *);
	int (*ioctl)(struct scsi_device___4 *, int, void *);
	int (*queuecommand)(struct Scsi_Host___4 *, struct scsi_cmnd___4 *);
	int (*eh_abort_handler)(struct scsi_cmnd___4 *);
	int (*eh_device_reset_handler)(struct scsi_cmnd___4 *);
	int (*eh_target_reset_handler)(struct scsi_cmnd___4 *);
	int (*eh_bus_reset_handler)(struct scsi_cmnd___4 *);
	int (*eh_host_reset_handler)(struct scsi_cmnd___4 *);
	int (*slave_alloc)(struct scsi_device___4 *);
	int (*slave_configure)(struct scsi_device___4 *);
	void (*slave_destroy)(struct scsi_device___4 *);
	int (*target_alloc)(struct scsi_target___4 *);
	void (*target_destroy)(struct scsi_target___4 *);
	int (*scan_finished)(struct Scsi_Host___4 *, long unsigned int);
	void (*scan_start)(struct Scsi_Host___4 *);
	int (*change_queue_depth)(struct scsi_device___4 *, int);
	int (*map_queues)(struct Scsi_Host___4 *);
	int (*bios_param)(struct scsi_device___4 *, struct block_device___351 *, sector_t, int *);
	void (*unlock_native_capacity)(struct scsi_device___4 *);
	int (*show_info)(struct seq_file___299 *, struct Scsi_Host___4 *);
	int (*write_info)(struct Scsi_Host___4 *, char *, int);
	enum blk_eh_timer_return (*eh_timed_out)(struct scsi_cmnd___4 *);
	int (*host_reset)(struct Scsi_Host___4 *, int);
	const char *proc_name;
	struct proc_dir_entry *proc_dir;
	int can_queue;
	int this_id;
	short unsigned int sg_tablesize;
	short unsigned int sg_prot_tablesize;
	unsigned int max_sectors;
	long unsigned int dma_boundary;
	short int cmd_per_lun;
	unsigned char present;
	int tag_alloc_policy;
	unsigned int track_queue_depth: 1;
	unsigned int supported_mode: 2;
	unsigned int unchecked_isa_dma: 1;
	unsigned int use_clustering: 1;
	unsigned int emulated: 1;
	unsigned int skip_settle_delay: 1;
	unsigned int no_write_same: 1;
	unsigned int force_blk_mq: 1;
	unsigned int max_host_blocked;
	struct device_attribute___37 **shost_attrs;
	struct device_attribute___37 **sdev_attrs;
	const struct attribute_group___316 **sdev_groups;
	u64 vendor_id;
	unsigned int cmd_size;
	struct scsi_host_cmd_pool *cmd_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct scsi_lun {
	__u8 scsi_lun[8];
};

enum scsi_timeouts {
	SCSI_DEFAULT_EH_TIMEOUT = 1000,
};

enum scsi_scan_mode {
	SCSI_SCAN_INITIAL = 0,
	SCSI_SCAN_RESCAN = 1,
	SCSI_SCAN_MANUAL = 2,
};

struct async_scan_data {
	struct list_head list;
	struct Scsi_Host *shost;
	struct completion prev_finished;
};

struct module___288;

struct file___353;

struct kiocb___353;

struct vm_area_struct___354;

struct inode___353;

struct file_lock___353;

struct page___354;

struct seq_file___300;

struct file_operations___353 {
	struct module___288 *owner;
	loff_t (*llseek)(struct file___353 *, loff_t, int);
	ssize_t (*read)(struct file___353 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___353 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___353 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___353 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___353 *, bool);
	int (*iterate)(struct file___353 *, struct dir_context *);
	int (*iterate_shared)(struct file___353 *, struct dir_context *);
	__poll_t (*poll)(struct file___353 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___353 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___353 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___353 *, struct vm_area_struct___354 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___353 *, struct file___353 *);
	int (*flush)(struct file___353 *, fl_owner_t);
	int (*release)(struct inode___353 *, struct file___353 *);
	int (*fsync)(struct file___353 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___353 *, int);
	int (*lock)(struct file___353 *, int, struct file_lock___353 *);
	ssize_t (*sendpage)(struct file___353 *, struct page___354 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___353 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___353 *, int, struct file_lock___353 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___353 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___353 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___353 *, long int, struct file_lock___353 **, void **);
	long int (*fallocate)(struct file___353 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___300 *, struct file___353 *);
	ssize_t (*copy_file_range)(struct file___353 *, loff_t, struct file___353 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___353 *, loff_t, struct file___353 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___353 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___353 {
	u64 seqnum;
	struct vm_area_struct___354 *vmas[4];
};

struct page_frag___353 {
	struct page___354 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___353;

struct cred___327;

struct bio_list___170;

struct backing_dev_info___170;

struct io_context___90;

struct request_queue___86;

struct vm_struct___259;

struct task_struct___354 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___354 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___353 *mm;
	struct mm_struct___353 *active_mm;
	struct vmacache___353 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___354 *real_parent;
	struct task_struct___354 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___354 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___216 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___216 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___216 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___327 *ptracer_cred;
	const struct cred___327 *real_cred;
	const struct cred___327 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___354 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___170 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___170 *backing_dev_info;
	struct io_context___90 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___353 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___86 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___354 *oom_reaper_list;
	struct vm_struct___259 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___140 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___354 *pgtable_t___353;

struct address_space___352;

struct dev_pagemap___341;

struct page___354 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___352 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___354 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___353 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___353 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___341 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___353;

struct lruvec___353 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___353 *pgdat;
};

struct zone___353 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___353 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___353 {
	struct zone___353 *zone;
	int zone_idx;
};

struct zonelist___353 {
	struct zoneref___353 _zonerefs[25];
};

struct pglist_data___353 {
	struct zone___353 node_zones[3];
	struct zonelist___353 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___354 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___354 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___353 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___354 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___354 *owner;
};

struct secondary_data___354 {
	void *stack;
	struct task_struct___354 *task;
	long int status;
};

struct blocking_notifier_head___353 {
	struct rw_semaphore___354 rwsem;
	struct notifier_block *head;
};

struct dentry___352;

struct path___353 {
	struct vfsmount *mnt;
	struct dentry___352 *dentry;
};

struct file___353 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___353 f_path;
	struct inode___353 *f_inode;
	const struct file_operations___353 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___216 f_owner;
	const struct cred___327 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___352 *f_mapping;
	errseq_t f_wb_err;
};

struct key___327;

struct user_struct___327;

struct cred___327 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___327 *session_keyring;
	struct key___327 *process_keyring;
	struct key___327 *thread_keyring;
	struct key___327 *request_key_auth;
	void *security;
	struct user_struct___327 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___346;

struct kernfs_elem_dir___346 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___346 *root;
};

struct kernfs_node___347;

struct kernfs_syscall_ops___346;

struct kernfs_root___346 {
	struct kernfs_node___347 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___346 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___346 {
	struct kernfs_node___347 *target_kn;
};

struct kernfs_ops___346;

struct kernfs_elem_attr___346 {
	const struct kernfs_ops___346 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___347 *notify_next;
};

struct kernfs_node___347 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___347 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___346 dir;
		struct kernfs_elem_symlink___346 symlink;
		struct kernfs_elem_attr___346 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___346;

struct kernfs_ops___346 {
	int (*open)(struct kernfs_open_file___346 *);
	void (*release)(struct kernfs_open_file___346 *);
	int (*seq_show)(struct seq_file___300 *, void *);
	void * (*seq_start)(struct seq_file___300 *, loff_t *);
	void * (*seq_next)(struct seq_file___300 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___300 *, void *);
	ssize_t (*read)(struct kernfs_open_file___346 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___346 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___346 *, struct vm_area_struct___354 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___346 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___346 {
	int (*remount_fs)(struct kernfs_root___346 *, int *, char *);
	int (*show_options)(struct seq_file___300 *, struct kernfs_root___346 *);
	int (*mkdir)(struct kernfs_node___347 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___347 *);
	int (*rename)(struct kernfs_node___347 *, struct kernfs_node___347 *, const char *);
	int (*show_path)(struct seq_file___300 *, struct kernfs_node___347 *, struct kernfs_root___346 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___299;

struct seq_file___300 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___299 *op;
	int poll_event;
	const struct file___353 *file;
	void *private;
};

struct vm_operations_struct___341;

struct kernfs_open_file___346 {
	struct kernfs_node___347 *kn;
	struct file___353 *file;
	struct seq_file___300 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___341 *vm_ops;
};

struct vm_fault___341;

struct vm_operations_struct___341 {
	void (*open)(struct vm_area_struct___354 *);
	void (*close)(struct vm_area_struct___354 *);
	int (*split)(struct vm_area_struct___354 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___354 *);
	vm_fault_t (*fault)(struct vm_fault___341 *);
	vm_fault_t (*huge_fault)(struct vm_fault___341 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___341 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___354 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___341 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___341 *);
	int (*access)(struct vm_area_struct___354 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___354 *);
	int (*set_policy)(struct vm_area_struct___354 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___354 *, long unsigned int);
	struct page___354 * (*find_special_page)(struct vm_area_struct___354 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_area_struct___354 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___354 *vm_next;
	struct vm_area_struct___354 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___353 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___341 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___353 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___340;

struct bin_attribute___316;

struct attribute_group___317 {
	const char *name;
	umode_t (*is_visible)(struct kobject___340 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___340 *, struct bin_attribute___316 *, int);
	struct attribute **attrs;
	struct bin_attribute___316 **bin_attrs;
};

struct kset___339;

struct kobj_type___339;

struct kobject___340 {
	const char *name;
	struct list_head entry;
	struct kobject___340 *parent;
	struct kset___339 *kset;
	struct kobj_type___339 *ktype;
	struct kernfs_node___347 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___316 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___353 *, struct kobject___340 *, struct bin_attribute___316 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___353 *, struct kobject___340 *, struct bin_attribute___316 *, char *, loff_t, size_t);
	int (*mmap)(struct file___353 *, struct kobject___340 *, struct bin_attribute___316 *, struct vm_area_struct___354 *);
};

struct sysfs_ops___339 {
	ssize_t (*show)(struct kobject___340 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___340 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___339;

struct kset___339 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___340 kobj;
	const struct kset_uevent_ops___339 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___339 {
	void (*release)(struct kobject___340 *);
	const struct sysfs_ops___339 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___27 * (*child_ns_type)(struct kobject___340 *);
	const void * (*namespace)(struct kobject___340 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___339 {
	int (* const filter)(struct kset___339 *, struct kobject___340 *);
	const char * (* const name)(struct kset___339 *, struct kobject___340 *);
	int (* const uevent)(struct kset___339 *, struct kobject___340 *, struct kobj_uevent_env *);
};

struct kobj_attribute___331 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___340 *, struct kobj_attribute___331 *, char *);
	ssize_t (*store)(struct kobject___340 *, struct kobj_attribute___331 *, const char *, size_t);
};

struct kernel_param___285;

struct kernel_param_ops___285 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___285 *);
	int (*get)(char *, const struct kernel_param___285 *);
	void (*free)(void *);
};

struct kparam_array___285;

struct kernel_param___285 {
	const char *name;
	struct module___288 *mod;
	const struct kernel_param_ops___285 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___285 *arr;
	};
};

struct kparam_array___285 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___285 *ops;
	void *elem;
};

struct module_kobject___285 {
	struct kobject___340 kobj;
	struct module___288 *mod;
	struct kobject___340 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___285 {
	struct module___288 *mod;
	struct latch_tree_node node;
};

struct module_layout___285 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___285 mtn;
};

struct module_attribute___285;

struct module___288 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___285 mkobj;
	struct module_attribute___285 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___340 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___285 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___285 core_layout;
	struct module_layout___285 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___285 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___285 *, struct module_kobject___285 *, char *);
	ssize_t (*store)(struct module_attribute___285 *, struct module_kobject___285 *, const char *, size_t);
	void (*setup)(struct module___288 *, const char *);
	int (*test)(struct module___288 *);
	void (*free)(struct module___288 *);
};

struct user_struct___327 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___327 *uid_keyring;
	struct key___327 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___353;

struct mm_struct___353 {
	struct {
		struct vm_area_struct___354 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___353 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___354 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___353 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___354 *owner;
		struct user_namespace___3 *user_ns;
		struct file___353 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___353 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct bio___170;

struct bio_list___170 {
	struct bio___170 *head;
	struct bio___170 *tail;
};

struct bdi_writeback_congested___170;

struct bdi_writeback___170 {
	struct backing_dev_info___170 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___170 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___157 *memcg_css;
	struct cgroup_subsys_state___157 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___320;

struct backing_dev_info___170 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___170 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___320 *dev;
	struct device___320 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___352 *debug_dir;
	struct dentry___352 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___90;

struct io_context___90 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___90 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

typedef blk_qc_t make_request_fn___86(struct request_queue___86 *, struct bio___170 *);

struct request___86;

typedef int dma_drain_needed_fn___86(struct request___86 *);

struct bsg_ops___86;

struct bsg_class_device___86 {
	struct device___320 *class_dev;
	int minor;
	struct request_queue___86 *queue;
	const struct bsg_ops___86 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___170 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___170 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___86;

struct blk_mq_ops___24;

struct blk_mq_hw_ctx___24;

struct blk_mq_tag_set___24;

struct request_queue___86 {
	struct list_head queue_head;
	struct request___86 *last_merge;
	struct elevator_queue___86 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___86 *make_request_fn;
	dma_drain_needed_fn___86 *dma_drain_needed;
	const struct blk_mq_ops___24 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___24 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___170 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___340 kobj;
	struct kobject___340 *mq_kobj;
	struct blk_integrity integrity;
	struct device___320 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	struct bsg_class_device___86 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set___24 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___170 bio_split;
	struct dentry___352 *debugfs_dir;
	struct dentry___352 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___259 {
	struct vm_struct___259 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___354 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bio_vec___172 {
	struct page___354 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

typedef void bio_end_io_t___170(struct bio___170 *);

struct gendisk___90;

struct bio_integrity_payload___170;

struct bio___170 {
	struct bio___170 *bi_next;
	struct gendisk___90 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___170 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___170 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___172 *bi_io_vec;
	struct bio_set___170 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___172 bi_inline_vecs[0];
};

struct bio_integrity_payload___170 {
	struct bio___170 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___172 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___172 bip_inline_vecs[0];
};

struct dev_pm_info___320 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___5 *subsys_data;
	void (*set_latency_tolerance)(struct device___320 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___320;

struct bus_type___320;

struct device_driver___320;

struct dev_pm_domain___320;

struct dma_map_ops___109;

struct fwnode_handle___242;

struct class___320;

struct device___320 {
	struct device___320 *parent;
	struct device_private *p;
	struct kobject___340 kobj;
	const char *init_name;
	const struct device_type___320 *type;
	struct mutex mutex;
	struct bus_type___320 *bus;
	struct device_driver___320 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___320 power;
	struct dev_pm_domain___320 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___109 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___242 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___320 *class;
	const struct attribute_group___317 **groups;
	void (*release)(struct device___320 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___90 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___320 __dev;
	struct kobject___340 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___90;

struct block_device_operations___87;

struct gendisk___90 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___90 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___90 *part_tbl;
	struct hd_struct___90 part0;
	const struct block_device_operations___87 *fops;
	struct request_queue___86 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___354 lookup_sem;
	struct kobject___340 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___340 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_ops___320;

struct device_type___320 {
	const char *name;
	const struct attribute_group___317 **groups;
	int (*uevent)(struct device___320 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___320 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___320 *);
	const struct dev_pm_ops___320 *pm;
};

struct class___320 {
	const char *name;
	struct module___288 *owner;
	const struct attribute_group___317 **class_groups;
	const struct attribute_group___317 **dev_groups;
	struct kobject___340 *dev_kobj;
	int (*dev_uevent)(struct device___320 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___320 *, umode_t *);
	void (*class_release)(struct class___320 *);
	void (*dev_release)(struct device___320 *);
	int (*shutdown_pre)(struct device___320 *);
	const struct kobj_ns_type_operations___27 *ns_type;
	const void * (*namespace)(struct device___320 *);
	const struct dev_pm_ops___320 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dev_pm_ops___320 {
	int (*prepare)(struct device___320 *);
	void (*complete)(struct device___320 *);
	int (*suspend)(struct device___320 *);
	int (*resume)(struct device___320 *);
	int (*freeze)(struct device___320 *);
	int (*thaw)(struct device___320 *);
	int (*poweroff)(struct device___320 *);
	int (*restore)(struct device___320 *);
	int (*suspend_late)(struct device___320 *);
	int (*resume_early)(struct device___320 *);
	int (*freeze_late)(struct device___320 *);
	int (*thaw_early)(struct device___320 *);
	int (*poweroff_late)(struct device___320 *);
	int (*restore_early)(struct device___320 *);
	int (*suspend_noirq)(struct device___320 *);
	int (*resume_noirq)(struct device___320 *);
	int (*freeze_noirq)(struct device___320 *);
	int (*thaw_noirq)(struct device___320 *);
	int (*poweroff_noirq)(struct device___320 *);
	int (*restore_noirq)(struct device___320 *);
	int (*runtime_suspend)(struct device___320 *);
	int (*runtime_resume)(struct device___320 *);
	int (*runtime_idle)(struct device___320 *);
};

struct dev_pm_domain___320 {
	struct dev_pm_ops___320 ops;
	void (*detach)(struct device___320 *, bool);
	int (*activate)(struct device___320 *);
	void (*sync)(struct device___320 *);
	void (*dismiss)(struct device___320 *);
};

struct bus_type___320 {
	const char *name;
	const char *dev_name;
	struct device___320 *dev_root;
	const struct attribute_group___317 **bus_groups;
	const struct attribute_group___317 **dev_groups;
	const struct attribute_group___317 **drv_groups;
	int (*match)(struct device___320 *, struct device_driver___320 *);
	int (*uevent)(struct device___320 *, struct kobj_uevent_env *);
	int (*probe)(struct device___320 *);
	int (*remove)(struct device___320 *);
	void (*shutdown)(struct device___320 *);
	int (*online)(struct device___320 *);
	int (*offline)(struct device___320 *);
	int (*suspend)(struct device___320 *, pm_message_t);
	int (*resume)(struct device___320 *);
	int (*num_vf)(struct device___320 *);
	int (*dma_configure)(struct device___320 *);
	const struct dev_pm_ops___320 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___320 {
	const char *name;
	struct bus_type___320 *bus;
	struct module___288 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___320 *);
	int (*remove)(struct device___320 *);
	void (*shutdown)(struct device___320 *);
	int (*suspend)(struct device___320 *, pm_message_t);
	int (*resume)(struct device___320 *);
	const struct attribute_group___317 **groups;
	const struct dev_pm_ops___320 *pm;
	void (*coredump)(struct device___320 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct class_interface___3 {
	struct list_head node;
	struct class___320 *class;
	int (*add_dev)(struct device___320 *, struct class_interface___3 *);
	void (*remove_dev)(struct device___320 *, struct class_interface___3 *);
};

struct device_attribute___38 {
	struct attribute attr;
	ssize_t (*show)(struct device___320 *, struct device_attribute___38 *, char *);
	ssize_t (*store)(struct device___320 *, struct device_attribute___38 *, const char *, size_t);
};

struct dma_map_ops___109 {
	void * (*alloc)(struct device___320 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___320 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___320 *, struct vm_area_struct___354 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___320 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___320 *, struct page___354 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___320 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___320 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___320 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___320 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___320 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___320 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide45;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___320 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___320 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___320 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___320 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___320 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___320 *, u64);
	u64 (*get_required_mask)(struct device___320 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___242;

struct fwnode_handle___242 {
	struct fwnode_handle___242 *secondary;
	const struct fwnode_operations___242 *ops;
};

struct dentry_operations___352;

struct super_block___352;

struct dentry___352 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___352 *d_parent;
	struct qstr d_name;
	struct inode___353 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___352 *d_op;
	struct super_block___352 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___352;

struct address_space___352 {
	struct inode___353 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___354 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___352 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___352;

struct block_device___352;

struct inode___353 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___352 *i_op;
	struct super_block___352 *i_sb;
	struct address_space___352 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___354 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___170 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___353 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___352 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___352 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___352 {
	int (*d_revalidate)(struct dentry___352 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___352 *, unsigned int);
	int (*d_hash)(const struct dentry___352 *, struct qstr *);
	int (*d_compare)(const struct dentry___352 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___352 *);
	int (*d_init)(struct dentry___352 *);
	void (*d_release)(struct dentry___352 *);
	void (*d_prune)(struct dentry___352 *);
	void (*d_iput)(struct dentry___352 *, struct inode___353 *);
	char * (*d_dname)(struct dentry___352 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___353 *);
	int (*d_manage)(const struct path___353 *, bool);
	struct dentry___352 * (*d_real)(struct dentry___352 *, const struct inode___353 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___352;

struct mem_dqinfo___352 {
	struct quota_format_type___352 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___352;

struct quota_info___352 {
	unsigned int flags;
	struct rw_semaphore___354 dqio_sem;
	struct inode___353 *files[3];
	struct mem_dqinfo___352 info[3];
	const struct quota_format_ops___352 *ops[3];
};

struct rcuwait___352 {
	struct task_struct___354 *task;
};

struct percpu_rw_semaphore___352 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___354 rw_sem;
	struct rcuwait___352 writer;
	int readers_block;
};

struct sb_writers___352 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___352 rw_sem[3];
};

struct file_system_type___352;

struct super_operations___352;

struct dquot_operations___352;

struct quotactl_ops___352;

struct super_block___352 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___352 *s_type;
	const struct super_operations___352 *s_op;
	const struct dquot_operations___352 *dq_op;
	const struct quotactl_ops___352 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___352 *s_root;
	struct rw_semaphore___354 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___352 *s_bdev;
	struct backing_dev_info___170 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___352 s_dquot;
	struct sb_writers___352 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___352 *s_d_op;
	int cleancache_poolid;
	struct shrinker___130 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

typedef int (*dev_page_fault_t___341)(struct vm_area_struct___354 *, long unsigned int, const struct page___354 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___341)(struct page___354 *, void *);

struct dev_pagemap___341 {
	dev_page_fault_t___341 page_fault;
	dev_page_free_t___341 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___320 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___353 {
	struct task_struct___354 *task;
	struct core_thread___353 *next;
};

struct core_state___353 {
	atomic_t nr_threads;
	struct core_thread___353 dumper;
	struct completion startup;
};

struct vm_fault___341 {
	struct vm_area_struct___354 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___354 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___354 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___353 prealloc_pte;
};

struct io_cq___90 {
	struct request_queue___86 *q;
	struct io_context___90 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___353 {
	struct file___353 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___353 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___352 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___353 *ia_file;
};

struct dquot___352 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___352 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___352 {
	int qf_fmt_id;
	const struct quota_format_ops___352 *qf_ops;
	struct module___288 *qf_owner;
	struct quota_format_type___352 *qf_next;
};

struct quota_format_ops___352 {
	int (*check_quota_file)(struct super_block___352 *, int);
	int (*read_file_info)(struct super_block___352 *, int);
	int (*write_file_info)(struct super_block___352 *, int);
	int (*free_file_info)(struct super_block___352 *, int);
	int (*read_dqblk)(struct dquot___352 *);
	int (*commit_dqblk)(struct dquot___352 *);
	int (*release_dqblk)(struct dquot___352 *);
	int (*get_next_id)(struct super_block___352 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___352 {
	int (*write_dquot)(struct dquot___352 *);
	struct dquot___352 * (*alloc_dquot)(struct super_block___352 *, int);
	void (*destroy_dquot)(struct dquot___352 *);
	int (*acquire_dquot)(struct dquot___352 *);
	int (*release_dquot)(struct dquot___352 *);
	int (*mark_dirty)(struct dquot___352 *);
	int (*write_info)(struct super_block___352 *, int);
	qsize_t * (*get_reserved_space)(struct inode___353 *);
	int (*get_projid)(struct inode___353 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___353 *, qsize_t *);
	int (*get_next_id)(struct super_block___352 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___352 {
	int (*quota_on)(struct super_block___352 *, int, int, const struct path___353 *);
	int (*quota_off)(struct super_block___352 *, int);
	int (*quota_enable)(struct super_block___352 *, unsigned int);
	int (*quota_disable)(struct super_block___352 *, unsigned int);
	int (*quota_sync)(struct super_block___352 *, int);
	int (*set_info)(struct super_block___352 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___352 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___352 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___352 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___352 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___352 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___352 {
	int (*writepage)(struct page___354 *, struct writeback_control___3 *);
	int (*readpage)(struct file___353 *, struct page___354 *);
	int (*writepages)(struct address_space___352 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___354 *);
	int (*readpages)(struct file___353 *, struct address_space___352 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___353 *, struct address_space___352 *, loff_t, unsigned int, unsigned int, struct page___354 **, void **);
	int (*write_end)(struct file___353 *, struct address_space___352 *, loff_t, unsigned int, unsigned int, struct page___354 *, void *);
	sector_t (*bmap)(struct address_space___352 *, sector_t);
	void (*invalidatepage)(struct page___354 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___354 *, gfp_t);
	void (*freepage)(struct page___354 *);
	ssize_t (*direct_IO)(struct kiocb___353 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___352 *, struct page___354 *, struct page___354 *, enum migrate_mode);
	bool (*isolate_page)(struct page___354 *, isolate_mode_t);
	void (*putback_page)(struct page___354 *);
	int (*launder_page)(struct page___354 *);
	int (*is_partially_uptodate)(struct page___354 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___354 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___352 *, struct page___354 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___353 *, sector_t *);
	void (*swap_deactivate)(struct file___353 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___352 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___353 *bd_inode;
	struct super_block___352 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___352 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___90 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___90 *bd_disk;
	struct request_queue___86 *bd_queue;
	struct backing_dev_info___170 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___352 {
	struct dentry___352 * (*lookup)(struct inode___353 *, struct dentry___352 *, unsigned int);
	const char * (*get_link)(struct dentry___352 *, struct inode___353 *, struct delayed_call *);
	int (*permission)(struct inode___353 *, int);
	struct posix_acl * (*get_acl)(struct inode___353 *, int);
	int (*readlink)(struct dentry___352 *, char *, int);
	int (*create)(struct inode___353 *, struct dentry___352 *, umode_t, bool);
	int (*link)(struct dentry___352 *, struct inode___353 *, struct dentry___352 *);
	int (*unlink)(struct inode___353 *, struct dentry___352 *);
	int (*symlink)(struct inode___353 *, struct dentry___352 *, const char *);
	int (*mkdir)(struct inode___353 *, struct dentry___352 *, umode_t);
	int (*rmdir)(struct inode___353 *, struct dentry___352 *);
	int (*mknod)(struct inode___353 *, struct dentry___352 *, umode_t, dev_t);
	int (*rename)(struct inode___353 *, struct dentry___352 *, struct inode___353 *, struct dentry___352 *, unsigned int);
	int (*setattr)(struct dentry___352 *, struct iattr___352 *);
	int (*getattr)(const struct path___353 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___352 *, char *, size_t);
	int (*fiemap)(struct inode___353 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___353 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___353 *, struct dentry___352 *, struct file___353 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___353 *, struct dentry___352 *, umode_t);
	int (*set_acl)(struct inode___353 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___352 {
	void (*fl_copy_lock)(struct file_lock___353 *, struct file_lock___353 *);
	void (*fl_release_private)(struct file_lock___353 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___352;

struct lock_manager_operations___352;

struct file_lock___353 {
	struct file_lock___353 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___353 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___352 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___352 *fl_ops;
	const struct lock_manager_operations___352 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___352 {
	int (*lm_compare_owner)(struct file_lock___353 *, struct file_lock___353 *);
	long unsigned int (*lm_owner_key)(struct file_lock___353 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___353 *);
	int (*lm_grant)(struct file_lock___353 *, int);
	bool (*lm_break)(struct file_lock___353 *);
	int (*lm_change)(struct file_lock___353 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___353 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___352 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___352 *fa_next;
	struct file___353 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___352 {
	const char *name;
	int fs_flags;
	struct dentry___352 * (*mount)(struct file_system_type___352 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___352 *);
	struct module___288 *owner;
	struct file_system_type___352 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___352 {
	struct inode___353 * (*alloc_inode)(struct super_block___352 *);
	void (*destroy_inode)(struct inode___353 *);
	void (*dirty_inode)(struct inode___353 *, int);
	int (*write_inode)(struct inode___353 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___353 *);
	void (*evict_inode)(struct inode___353 *);
	void (*put_super)(struct super_block___352 *);
	int (*sync_fs)(struct super_block___352 *, int);
	int (*freeze_super)(struct super_block___352 *);
	int (*freeze_fs)(struct super_block___352 *);
	int (*thaw_super)(struct super_block___352 *);
	int (*unfreeze_fs)(struct super_block___352 *);
	int (*statfs)(struct dentry___352 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___352 *, int *, char *);
	void (*umount_begin)(struct super_block___352 *);
	int (*show_options)(struct seq_file___300 *, struct dentry___352 *);
	int (*show_devname)(struct seq_file___300 *, struct dentry___352 *);
	int (*show_path)(struct seq_file___300 *, struct dentry___352 *);
	int (*show_stats)(struct seq_file___300 *, struct dentry___352 *);
	ssize_t (*quota_read)(struct super_block___352 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___352 *, int, const char *, size_t, loff_t);
	struct dquot___352 ** (*get_dquots)(struct inode___353 *);
	int (*bdev_try_to_free_page)(struct super_block___352 *, struct page___354 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___352 *, struct shrink_control___130 *);
	long int (*free_cached_objects)(struct super_block___352 *, struct shrink_control___130 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___90 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___90 *last_lookup;
	struct hd_struct___90 *part[0];
};

struct block_device_operations___87 {
	int (*open)(struct block_device___352 *, fmode_t);
	void (*release)(struct gendisk___90 *, fmode_t);
	int (*rw_page)(struct block_device___352 *, sector_t, struct page___354 *, unsigned int);
	int (*ioctl)(struct block_device___352 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___352 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___90 *, unsigned int);
	int (*media_changed)(struct gendisk___90 *);
	void (*unlock_native_capacity)(struct gendisk___90 *);
	int (*revalidate_disk)(struct gendisk___90 *);
	int (*getgeo)(struct block_device___352 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___352 *, long unsigned int);
	int (*report_zones)(struct gendisk___90 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___288 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___341(struct page___354 *);

struct bdi_writeback_congested___170 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___170 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bsg_ops___86 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___86 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___86 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___86 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___86(struct request___86 *, blk_status_t);

struct request___86 {
	struct request_queue___86 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___24 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___170 *bio;
	struct bio___170 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___172 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___90 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___86 *saved_end_io;
		} flush;
	};
	struct gendisk___90 *rq_disk;
	struct hd_struct___90 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___86 *end_io;
	void *end_io_data;
	struct request___86 *next_rq;
};

struct fwnode_reference_args___242;

struct fwnode_endpoint___242;

struct fwnode_operations___242 {
	struct fwnode_handle___242 * (*get)(struct fwnode_handle___242 *);
	void (*put)(struct fwnode_handle___242 *);
	bool (*device_is_available)(const struct fwnode_handle___242 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___242 *, const struct device___320 *);
	bool (*property_present)(const struct fwnode_handle___242 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___242 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___242 *, const char *, const char **, size_t);
	struct fwnode_handle___242 * (*get_parent)(const struct fwnode_handle___242 *);
	struct fwnode_handle___242 * (*get_next_child_node)(const struct fwnode_handle___242 *, struct fwnode_handle___242 *);
	struct fwnode_handle___242 * (*get_named_child_node)(const struct fwnode_handle___242 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___242 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___242 *);
	struct fwnode_handle___242 * (*graph_get_next_endpoint)(const struct fwnode_handle___242 *, struct fwnode_handle___242 *);
	struct fwnode_handle___242 * (*graph_get_remote_endpoint)(const struct fwnode_handle___242 *);
	struct fwnode_handle___242 * (*graph_get_port_parent)(struct fwnode_handle___242 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___242 *, struct fwnode_endpoint___242 *);
};

struct fwnode_endpoint___242 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___242 *local_fwnode;
};

struct fwnode_reference_args___242 {
	struct fwnode_handle___242 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct blk_mq_hw_ctx___24 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___86 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags___4 *tags;
	struct blk_mq_tags___4 *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	unsigned int rh_reserved_nr_expired;
	struct hlist_node cpuhp_dead;
	struct kobject___340 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___352 *debugfs_dir;
	struct dentry___352 *sched_debugfs_dir;
	struct list_head hctx_list;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___86;

struct elevator_mq_ops___86 {
	int (*init_sched)(struct request_queue___86 *, struct elevator_type___86 *);
	void (*exit_sched)(struct elevator_queue___86 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___24 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___24 *, unsigned int);
	bool (*allow_merge)(struct request_queue___86 *, struct request___86 *, struct bio___170 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx___24 *, struct bio___170 *);
	int (*request_merge)(struct request_queue___86 *, struct request___86 **, struct bio___170 *);
	void (*request_merged)(struct request_queue___86 *, struct request___86 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___86 *, struct request___86 *, struct request___86 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___86 *, struct bio___170 *);
	void (*finish_request)(struct request___86 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___24 *, struct list_head *, bool);
	struct request___86 * (*dispatch_request)(struct blk_mq_hw_ctx___24 *);
	bool (*has_work)(struct blk_mq_hw_ctx___24 *);
	void (*completed_request)(struct request___86 *, u64);
	void (*started_request)(struct request___86 *);
	void (*requeue_request)(struct request___86 *);
	struct request___86 * (*former_request)(struct request_queue___86 *, struct request___86 *);
	struct request___86 * (*next_request)(struct request_queue___86 *, struct request___86 *);
	void (*init_icq)(struct io_cq___90 *);
	void (*exit_icq)(struct io_cq___90 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx___24 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___86;

struct elevator_type___86 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___86 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___86 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___288 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___86 {
	struct elevator_type___86 *type;
	void *elevator_data;
	struct kobject___340 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___86 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___86 *, char *);
	ssize_t (*store)(struct elevator_queue___86 *, const char *, size_t);
};

struct blk_mq_queue_data___24;

typedef blk_status_t queue_rq_fn___24(struct blk_mq_hw_ctx___24 *, const struct blk_mq_queue_data___24 *);

typedef void commit_rqs_fn___24(struct blk_mq_hw_ctx___24 *);

typedef bool get_budget_fn___24(struct blk_mq_hw_ctx___24 *);

typedef void put_budget_fn___24(struct blk_mq_hw_ctx___24 *);

typedef enum blk_eh_timer_return timeout_fn___24(struct request___86 *, bool);

typedef int poll_fn___24(struct blk_mq_hw_ctx___24 *);

typedef void complete_fn___24(struct request___86 *);

typedef int init_hctx_fn___24(struct blk_mq_hw_ctx___24 *, void *, unsigned int);

typedef void exit_hctx_fn___24(struct blk_mq_hw_ctx___24 *, unsigned int);

typedef int init_request_fn___24(struct blk_mq_tag_set___24 *, struct request___86 *, unsigned int, unsigned int);

typedef void exit_request_fn___24(struct blk_mq_tag_set___24 *, struct request___86 *, unsigned int);

typedef bool busy_fn___24(struct request_queue___86 *);

typedef int map_queues_fn___24(struct blk_mq_tag_set___24 *);

typedef void cleanup_rq_fn___24(struct request___86 *);

struct blk_mq_ops___24 {
	queue_rq_fn___24 *queue_rq;
	commit_rqs_fn___24 *commit_rqs;
	get_budget_fn___24 *get_budget;
	put_budget_fn___24 *put_budget;
	timeout_fn___24 *timeout;
	poll_fn___24 *poll;
	complete_fn___24 *complete;
	init_hctx_fn___24 *init_hctx;
	exit_hctx_fn___24 *exit_hctx;
	init_request_fn___24 *init_request;
	exit_request_fn___24 *exit_request;
	void (*initialize_rq_fn)(struct request___86 *);
	busy_fn___24 *busy;
	map_queues_fn___24 *map_queues;
	void (*show_rq)(struct seq_file___300 *, struct request___86 *);
	union {
		cleanup_rq_fn___24 *cleanup_rq;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide44;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct blk_mq_tag_set___24 {
	struct blk_mq_queue_map map[6];
	unsigned int nr_maps;
	const struct blk_mq_ops___24 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	struct blk_mq_tags___4 **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct Scsi_Host___5;

struct scsi_target___5;

struct scsi_device_handler___3;

struct scsi_device___5 {
	struct Scsi_Host___5 *host;
	struct request_queue___86 *request_queue;
	struct list_head siblings;
	struct list_head same_target_siblings;
	atomic_t device_busy;
	atomic_t device_blocked;
	spinlock_t list_lock;
	struct list_head cmd_list;
	struct list_head starved_entry;
	short unsigned int queue_depth;
	short unsigned int max_queue_depth;
	short unsigned int last_queue_full_depth;
	short unsigned int last_queue_full_count;
	long unsigned int last_queue_full_time;
	long unsigned int queue_ramp_up_period;
	long unsigned int last_queue_ramp_up;
	unsigned int id;
	unsigned int channel;
	u64 lun;
	unsigned int manufacturer;
	unsigned int sector_size;
	void *hostdata;
	unsigned char type;
	char scsi_level;
	char inq_periph_qual;
	struct mutex inquiry_mutex;
	unsigned char inquiry_len;
	unsigned char *inquiry;
	const char *vendor;
	const char *model;
	const char *rev;
	struct scsi_vpd *vpd_pg83;
	struct scsi_vpd *vpd_pg80;
	unsigned char current_tag;
	struct scsi_target___5 *sdev_target;
	blist_flags_t sdev_bflags;
	unsigned int eh_timeout;
	unsigned int removable: 1;
	unsigned int changed: 1;
	unsigned int busy: 1;
	unsigned int lockable: 1;
	unsigned int locked: 1;
	unsigned int borken: 1;
	unsigned int disconnect: 1;
	unsigned int soft_reset: 1;
	unsigned int sdtr: 1;
	unsigned int wdtr: 1;
	unsigned int ppr: 1;
	unsigned int tagged_supported: 1;
	unsigned int simple_tags: 1;
	unsigned int was_reset: 1;
	unsigned int expecting_cc_ua: 1;
	unsigned int use_10_for_rw: 1;
	unsigned int use_10_for_ms: 1;
	unsigned int no_report_opcodes: 1;
	unsigned int no_write_same: 1;
	unsigned int use_16_for_rw: 1;
	unsigned int skip_ms_page_8: 1;
	unsigned int skip_ms_page_3f: 1;
	unsigned int skip_vpd_pages: 1;
	unsigned int try_vpd_pages: 1;
	unsigned int use_192_bytes_for_3f: 1;
	unsigned int no_start_on_add: 1;
	unsigned int allow_restart: 1;
	unsigned int manage_start_stop: 1;
	unsigned int start_stop_pwr_cond: 1;
	unsigned int no_uld_attach: 1;
	unsigned int select_no_atn: 1;
	unsigned int fix_capacity: 1;
	unsigned int guess_capacity: 1;
	unsigned int retry_hwerror: 1;
	unsigned int last_sector_bug: 1;
	unsigned int no_read_disc_info: 1;
	unsigned int no_read_capacity_16: 1;
	unsigned int try_rc_10_first: 1;
	unsigned int security_supported: 1;
	unsigned int is_visible: 1;
	unsigned int wce_default_on: 1;
	unsigned int no_dif: 1;
	unsigned int broken_fua: 1;
	unsigned int lun_in_cdb: 1;
	unsigned int unmap_limit_for_ws: 1;
	atomic_t disk_events_disable_depth;
	long unsigned int supported_events[1];
	long unsigned int pending_events[1];
	struct list_head event_list;
	struct work_struct event_work;
	unsigned int max_device_blocked;
	atomic_t iorequest_cnt;
	atomic_t iodone_cnt;
	atomic_t ioerr_cnt;
	struct device___320 sdev_gendev;
	struct device___320 sdev_dev;
	struct execute_work ew;
	struct work_struct requeue_work;
	struct scsi_device_handler___3 *handler;
	void *handler_data;
	unsigned char access_state;
	struct mutex state_mutex;
	enum scsi_device_state sdev_state;
	struct task_struct___354 *quiesced_by;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int sdev_data[0];
};

struct scsi_host_template___5;

struct scsi_transport_template___4;

struct Scsi_Host___5 {
	struct list_head __devices;
	struct list_head __targets;
	struct list_head starved_list;
	spinlock_t default_lock;
	spinlock_t *host_lock;
	struct mutex scan_mutex;
	struct list_head eh_cmd_q;
	struct task_struct___354 *ehandler;
	struct completion *eh_action;
	wait_queue_head_t host_wait;
	struct scsi_host_template___5 *hostt;
	struct scsi_transport_template___4 *transportt;
	struct blk_mq_tag_set___24 tag_set;
	atomic_t host_busy;
	atomic_t host_blocked;
	unsigned int host_failed;
	unsigned int host_eh_scheduled;
	unsigned int host_no;
	int eh_deadline;
	long unsigned int last_reset;
	unsigned int max_channel;
	unsigned int max_id;
	u64 max_lun;
	unsigned int unique_id;
	short unsigned int max_cmd_len;
	int this_id;
	int can_queue;
	short int cmd_per_lun;
	short unsigned int sg_tablesize;
	short unsigned int sg_prot_tablesize;
	unsigned int max_sectors;
	long unsigned int dma_boundary;
	unsigned int nr_hw_queues;
	long unsigned int cmd_serial_number;
	unsigned int active_mode: 2;
	unsigned int unchecked_isa_dma: 1;
	unsigned int use_clustering: 1;
	unsigned int host_self_blocked: 1;
	unsigned int reverse_ordering: 1;
	unsigned int tmf_in_progress: 1;
	unsigned int async_scan: 1;
	unsigned int eh_noresume: 1;
	unsigned int no_write_same: 1;
	unsigned int use_cmd_list: 1;
	unsigned int short_inquiry: 1;
	char work_q_name[20];
	struct workqueue_struct *work_q;
	struct workqueue_struct *tmf_work_q;
	unsigned int no_scsi2_lun_in_cdb: 1;
	unsigned int max_host_blocked;
	unsigned int prot_capabilities;
	unsigned char prot_guard_type;
	long unsigned int base;
	long unsigned int io_port;
	unsigned char n_io_port;
	unsigned char dma_channel;
	unsigned int irq;
	enum scsi_host_state shost_state;
	struct device___320 shost_gendev;
	struct device___320 shost_dev;
	void *shost_data;
	struct device___320 *dma_dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int hostdata[0];
};

struct scsi_target___5 {
	struct scsi_device___5 *starget_sdev_user;
	struct list_head siblings;
	struct list_head devices;
	struct device___320 dev;
	struct kref reap_ref;
	unsigned int channel;
	unsigned int id;
	unsigned int create: 1;
	unsigned int single_lun: 1;
	unsigned int pdt_1f_for_no_lun: 1;
	unsigned int no_report_luns: 1;
	unsigned int expecting_lun_change: 1;
	atomic_t target_busy;
	atomic_t target_blocked;
	unsigned int can_queue;
	unsigned int max_target_blocked;
	char scsi_level;
	enum scsi_target_state state;
	void *hostdata;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int starget_data[0];
};

struct scsi_device_handler___3 {
	struct list_head list;
	struct module___288 *module;
	const char *name;
	int (*check_sense)(struct scsi_device___5 *, struct scsi_sense_hdr *);
	int (*attach)(struct scsi_device___5 *);
	void (*detach)(struct scsi_device___5 *);
	int (*activate)(struct scsi_device___5 *, activate_complete, void *);
	blk_status_t (*prep_fn)(struct scsi_device___5 *, struct request___86 *);
	int (*set_params)(struct scsi_device___5 *, const char *);
	void (*rescan)(struct scsi_device___5 *);
};

typedef int (*key_restrict_link_func_t___328)(struct key___327 *, const struct key_type *, const union key_payload *, struct key___327 *);

struct key_restriction___327;

struct key___327 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___354 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___327 *restrict_link;
};

struct key_restriction___327 {
	key_restrict_link_func_t___328 check;
	struct key___327 *key;
	struct key_type *keytype;
};

struct seq_operations___299 {
	void * (*start)(struct seq_file___300 *, loff_t *);
	void (*stop)(struct seq_file___300 *, void *);
	void * (*next)(struct seq_file___300 *, void *, loff_t *);
	int (*show)(struct seq_file___300 *, void *);
};

struct blk_mq_queue_data___24 {
	struct request___86 *rq;
	bool last;
	long unsigned int rh_reserved1;
};

struct scsi_host_template___5 {
	struct module___288 *module;
	const char *name;
	const char * (*info)(struct Scsi_Host___5 *);
	int (*ioctl)(struct scsi_device___5 *, int, void *);
	int (*queuecommand)(struct Scsi_Host___5 *, struct scsi_cmnd___2 *);
	int (*eh_abort_handler)(struct scsi_cmnd___2 *);
	int (*eh_device_reset_handler)(struct scsi_cmnd___2 *);
	int (*eh_target_reset_handler)(struct scsi_cmnd___2 *);
	int (*eh_bus_reset_handler)(struct scsi_cmnd___2 *);
	int (*eh_host_reset_handler)(struct scsi_cmnd___2 *);
	int (*slave_alloc)(struct scsi_device___5 *);
	int (*slave_configure)(struct scsi_device___5 *);
	void (*slave_destroy)(struct scsi_device___5 *);
	int (*target_alloc)(struct scsi_target___5 *);
	void (*target_destroy)(struct scsi_target___5 *);
	int (*scan_finished)(struct Scsi_Host___5 *, long unsigned int);
	void (*scan_start)(struct Scsi_Host___5 *);
	int (*change_queue_depth)(struct scsi_device___5 *, int);
	int (*map_queues)(struct Scsi_Host___5 *);
	int (*bios_param)(struct scsi_device___5 *, struct block_device___352 *, sector_t, int *);
	void (*unlock_native_capacity)(struct scsi_device___5 *);
	int (*show_info)(struct seq_file___300 *, struct Scsi_Host___5 *);
	int (*write_info)(struct Scsi_Host___5 *, char *, int);
	enum blk_eh_timer_return (*eh_timed_out)(struct scsi_cmnd___2 *);
	int (*host_reset)(struct Scsi_Host___5 *, int);
	const char *proc_name;
	struct proc_dir_entry *proc_dir;
	int can_queue;
	int this_id;
	short unsigned int sg_tablesize;
	short unsigned int sg_prot_tablesize;
	unsigned int max_sectors;
	long unsigned int dma_boundary;
	short int cmd_per_lun;
	unsigned char present;
	int tag_alloc_policy;
	unsigned int track_queue_depth: 1;
	unsigned int supported_mode: 2;
	unsigned int unchecked_isa_dma: 1;
	unsigned int use_clustering: 1;
	unsigned int emulated: 1;
	unsigned int skip_settle_delay: 1;
	unsigned int no_write_same: 1;
	unsigned int force_blk_mq: 1;
	unsigned int max_host_blocked;
	struct device_attribute___38 **shost_attrs;
	struct device_attribute___38 **sdev_attrs;
	const struct attribute_group___317 **sdev_groups;
	u64 vendor_id;
	unsigned int cmd_size;
	struct scsi_host_cmd_pool *cmd_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct scsi_cmnd___2 {
	struct scsi_request req;
	struct scsi_device___5 *device;
	struct list_head list;
	struct list_head eh_entry;
	struct delayed_work abort_work;
	struct callback_head rcu;
	int eh_eflags;
	long unsigned int serial_number;
	long unsigned int jiffies_at_alloc;
	int retries;
	int allowed;
	unsigned char prot_op;
	unsigned char prot_type;
	unsigned char prot_flags;
	short unsigned int cmd_len;
	enum dma_data_direction sc_data_direction;
	unsigned char *cmnd;
	struct scsi_data_buffer sdb;
	struct scsi_data_buffer *prot_sdb;
	unsigned int underflow;
	unsigned int transfersize;
	struct request___86 *request;
	unsigned char *sense_buffer;
	void (*scsi_done)(struct scsi_cmnd___2 *);
	struct scsi_pointer SCp;
	unsigned char *host_scribble;
	int result;
	int flags;
	long unsigned int state;
	unsigned char tag;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct attribute_container___5 {
	struct list_head node;
	struct klist containers;
	struct class___320 *class;
	const struct attribute_group___317 *grp;
	struct device_attribute___38 **attrs;
	int (*match)(struct attribute_container___5 *, struct device___320 *);
	long unsigned int flags;
};

struct transport_container___5 {
	struct attribute_container___5 ac;
	const struct attribute_group___317 *statistics;
};

struct scsi_transport_template___4 {
	struct transport_container___5 host_attrs;
	struct transport_container___5 target_attrs;
	struct transport_container___5 device_attrs;
	int (*user_scan)(struct Scsi_Host___5 *, uint, uint, u64);
	int device_size;
	int device_private_offset;
	int target_size;
	int target_private_offset;
	int host_size;
	unsigned int create_work_queue: 1;
	void (*eh_strategy_handler)(struct Scsi_Host___5 *);
};

struct scsi_target___6;

struct scsi_device___6 {
	struct Scsi_Host___5 *host;
	struct request_queue___84 *request_queue;
	struct list_head siblings;
	struct list_head same_target_siblings;
	atomic_t device_busy;
	atomic_t device_blocked;
	spinlock_t list_lock;
	struct list_head cmd_list;
	struct list_head starved_entry;
	short unsigned int queue_depth;
	short unsigned int max_queue_depth;
	short unsigned int last_queue_full_depth;
	short unsigned int last_queue_full_count;
	long unsigned int last_queue_full_time;
	long unsigned int queue_ramp_up_period;
	long unsigned int last_queue_ramp_up;
	unsigned int id;
	unsigned int channel;
	u64 lun;
	unsigned int manufacturer;
	unsigned int sector_size;
	void *hostdata;
	unsigned char type;
	char scsi_level;
	char inq_periph_qual;
	struct mutex inquiry_mutex;
	unsigned char inquiry_len;
	unsigned char *inquiry;
	const char *vendor;
	const char *model;
	const char *rev;
	struct scsi_vpd *vpd_pg83;
	struct scsi_vpd *vpd_pg80;
	unsigned char current_tag;
	struct scsi_target___6 *sdev_target;
	blist_flags_t sdev_bflags;
	unsigned int eh_timeout;
	unsigned int removable: 1;
	unsigned int changed: 1;
	unsigned int busy: 1;
	unsigned int lockable: 1;
	unsigned int locked: 1;
	unsigned int borken: 1;
	unsigned int disconnect: 1;
	unsigned int soft_reset: 1;
	unsigned int sdtr: 1;
	unsigned int wdtr: 1;
	unsigned int ppr: 1;
	unsigned int tagged_supported: 1;
	unsigned int simple_tags: 1;
	unsigned int was_reset: 1;
	unsigned int expecting_cc_ua: 1;
	unsigned int use_10_for_rw: 1;
	unsigned int use_10_for_ms: 1;
	unsigned int no_report_opcodes: 1;
	unsigned int no_write_same: 1;
	unsigned int use_16_for_rw: 1;
	unsigned int skip_ms_page_8: 1;
	unsigned int skip_ms_page_3f: 1;
	unsigned int skip_vpd_pages: 1;
	unsigned int try_vpd_pages: 1;
	unsigned int use_192_bytes_for_3f: 1;
	unsigned int no_start_on_add: 1;
	unsigned int allow_restart: 1;
	unsigned int manage_start_stop: 1;
	unsigned int start_stop_pwr_cond: 1;
	unsigned int no_uld_attach: 1;
	unsigned int select_no_atn: 1;
	unsigned int fix_capacity: 1;
	unsigned int guess_capacity: 1;
	unsigned int retry_hwerror: 1;
	unsigned int last_sector_bug: 1;
	unsigned int no_read_disc_info: 1;
	unsigned int no_read_capacity_16: 1;
	unsigned int try_rc_10_first: 1;
	unsigned int security_supported: 1;
	unsigned int is_visible: 1;
	unsigned int wce_default_on: 1;
	unsigned int no_dif: 1;
	unsigned int broken_fua: 1;
	unsigned int lun_in_cdb: 1;
	unsigned int unmap_limit_for_ws: 1;
	atomic_t disk_events_disable_depth;
	long unsigned int supported_events[1];
	long unsigned int pending_events[1];
	struct list_head event_list;
	struct work_struct event_work;
	unsigned int max_device_blocked;
	atomic_t iorequest_cnt;
	atomic_t iodone_cnt;
	atomic_t ioerr_cnt;
	struct device___318 sdev_gendev;
	struct device___318 sdev_dev;
	struct execute_work ew;
	struct work_struct requeue_work;
	struct scsi_device_handler *handler;
	void *handler_data;
	unsigned char access_state;
	struct mutex state_mutex;
	enum scsi_device_state sdev_state;
	struct task_struct___352 *quiesced_by;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int sdev_data[0];
};

struct scsi_target___6 {
	struct scsi_device___6 *starget_sdev_user;
	struct list_head siblings;
	struct list_head devices;
	struct device___318 dev;
	struct kref reap_ref;
	unsigned int channel;
	unsigned int id;
	unsigned int create: 1;
	unsigned int single_lun: 1;
	unsigned int pdt_1f_for_no_lun: 1;
	unsigned int no_report_luns: 1;
	unsigned int expecting_lun_change: 1;
	atomic_t target_busy;
	atomic_t target_blocked;
	unsigned int can_queue;
	unsigned int max_target_blocked;
	char scsi_level;
	enum scsi_target_state state;
	void *hostdata;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int starget_data[0];
};

enum scsi_devinfo_key {
	SCSI_DEVINFO_GLOBAL = 0,
	SCSI_DEVINFO_SPI = 1,
};

struct scsi_dev_info_list {
	struct list_head dev_info_list;
	char vendor[8];
	char model[16];
	blist_flags_t flags;
	unsigned int compatible;
};

struct scsi_dev_info_list_table {
	struct list_head node;
	struct list_head scsi_dev_info_list;
	const char *name;
	int key;
};

struct double_list {
	struct list_head *top;
	struct list_head *bottom;
};

struct module___289;

struct file___354;

struct kiocb___354;

struct iov_iter___154;

struct poll_table_struct___214;

struct vm_area_struct___355;

struct inode___354;

struct file_lock___354;

struct page___355;

struct pipe_inode_info___74;

struct seq_file___301;

struct file_operations___354 {
	struct module___289 *owner;
	loff_t (*llseek)(struct file___354 *, loff_t, int);
	ssize_t (*read)(struct file___354 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___354 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___354 *, struct iov_iter___154 *);
	ssize_t (*write_iter)(struct kiocb___354 *, struct iov_iter___154 *);
	int (*iopoll)(struct kiocb___354 *, bool);
	int (*iterate)(struct file___354 *, struct dir_context *);
	int (*iterate_shared)(struct file___354 *, struct dir_context *);
	__poll_t (*poll)(struct file___354 *, struct poll_table_struct___214 *);
	long int (*unlocked_ioctl)(struct file___354 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___354 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___354 *, struct vm_area_struct___355 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___354 *, struct file___354 *);
	int (*flush)(struct file___354 *, fl_owner_t);
	int (*release)(struct inode___354 *, struct file___354 *);
	int (*fsync)(struct file___354 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___354 *, int);
	int (*lock)(struct file___354 *, int, struct file_lock___354 *);
	ssize_t (*sendpage)(struct file___354 *, struct page___355 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___354 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___354 *, int, struct file_lock___354 *);
	ssize_t (*splice_write)(struct pipe_inode_info___74 *, struct file___354 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___354 *, loff_t *, struct pipe_inode_info___74 *, size_t, unsigned int);
	int (*setlease)(struct file___354 *, long int, struct file_lock___354 **, void **);
	long int (*fallocate)(struct file___354 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___301 *, struct file___354 *);
	ssize_t (*copy_file_range)(struct file___354 *, loff_t, struct file___354 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___354 *, loff_t, struct file___354 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___354 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___354 {
	u64 seqnum;
	struct vm_area_struct___355 *vmas[4];
};

struct page_frag___354 {
	struct page___355 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___354;

struct mem_cgroup___131;

struct cred___328;

struct nsproxy___274;

struct signal_struct___254;

struct bio_list___171;

struct backing_dev_info___171;

struct io_context___91;

struct css_set___229;

struct request_queue___87;

struct vm_struct___260;

struct task_struct___355 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___355 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___354 *mm;
	struct mm_struct___354 *active_mm;
	struct vmacache___354 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___355 *real_parent;
	struct task_struct___355 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___355 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___131 *active_memcg;
	long int rh_reserved2;
	struct pid___216 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___216 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___216 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___328 *ptracer_cred;
	const struct cred___328 *real_cred;
	const struct cred___328 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___274 *nsproxy;
	struct signal_struct___254 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___355 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___171 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___171 *backing_dev_info;
	struct io_context___91 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___229 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___74 *splice_pipe;
	struct page_frag___354 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___131 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___87 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___355 *oom_reaper_list;
	struct vm_struct___260 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___140 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct secondary_data___355 {
	void *stack;
	struct task_struct___355 *task;
	long int status;
};

struct rw_semaphore___355 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___355 *owner;
};

struct key___328;

struct ucounts___244;

struct user_namespace___244 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___244 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___9 ns;
	long unsigned int flags;
	struct key___328 *persistent_keyring_register;
	struct rw_semaphore___355 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___244 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*key_restrict_link_func_t___329)(struct key___328 *, const struct key_type *, const union key_payload *, struct key___328 *);

struct key_restriction___328;

struct key___328 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___355 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___328 *restrict_link;
};

struct key_restriction___328 {
	key_restrict_link_func_t___329 check;
	struct key___328 *key;
	struct key_type *keytype;
};

struct dentry_operations___353;

struct super_block___353;

struct dentry___353 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___353 *d_parent;
	struct qstr d_name;
	struct inode___354 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___353 *d_op;
	struct super_block___353 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___353;

struct address_space___353 {
	struct inode___354 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___355 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___353 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___353;

struct bdi_writeback___171;

struct block_device___353;

struct inode___354 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___353 *i_op;
	struct super_block___353 *i_sb;
	struct address_space___353 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___355 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___171 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___354 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___353 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___74 *i_pipe;
		struct block_device___353 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___354;

struct dentry_operations___353 {
	int (*d_revalidate)(struct dentry___353 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___353 *, unsigned int);
	int (*d_hash)(const struct dentry___353 *, struct qstr *);
	int (*d_compare)(const struct dentry___353 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___353 *);
	int (*d_init)(struct dentry___353 *);
	void (*d_release)(struct dentry___353 *);
	void (*d_prune)(struct dentry___353 *);
	void (*d_iput)(struct dentry___353 *, struct inode___354 *);
	char * (*d_dname)(struct dentry___353 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___354 *);
	int (*d_manage)(const struct path___354 *, bool);
	struct dentry___353 * (*d_real)(struct dentry___353 *, const struct inode___354 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___353;

struct mem_dqinfo___353 {
	struct quota_format_type___353 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___353;

struct quota_info___353 {
	unsigned int flags;
	struct rw_semaphore___355 dqio_sem;
	struct inode___354 *files[3];
	struct mem_dqinfo___353 info[3];
	const struct quota_format_ops___353 *ops[3];
};

struct rcuwait___353 {
	struct task_struct___355 *task;
};

struct percpu_rw_semaphore___353 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___355 rw_sem;
	struct rcuwait___353 writer;
	int readers_block;
};

struct sb_writers___353 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___353 rw_sem[3];
};

struct shrink_control___131;

struct shrinker___131 {
	long unsigned int (*count_objects)(struct shrinker___131 *, struct shrink_control___131 *);
	long unsigned int (*scan_objects)(struct shrinker___131 *, struct shrink_control___131 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___353;

struct super_operations___353;

struct dquot_operations___353;

struct quotactl_ops___353;

struct super_block___353 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___353 *s_type;
	const struct super_operations___353 *s_op;
	const struct dquot_operations___353 *dq_op;
	const struct quotactl_ops___353 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___353 *s_root;
	struct rw_semaphore___355 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___353 *s_bdev;
	struct backing_dev_info___171 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___353 s_dquot;
	struct sb_writers___353 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___353 *s_d_op;
	int cleancache_poolid;
	struct shrinker___131 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___244 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct path___354 {
	struct vfsmount *mnt;
	struct dentry___353 *dentry;
};

struct shrink_control___131 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___131 *memcg;
};

struct cgroup___229;

struct cgroup_subsys___229;

struct cgroup_subsys_state___229 {
	struct cgroup___229 *cgroup;
	struct cgroup_subsys___229 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___229 *parent;
};

struct kernfs_node___348;

struct cgroup_file___229 {
	struct kernfs_node___348 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___131;

struct mem_cgroup___131 {
	struct cgroup_subsys_state___229 css;
	struct mem_cgroup_id___16 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___229 events_file;
	struct cgroup_file___229 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___355 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___131 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___355 *pgtable_t___354;

struct dev_pagemap___342;

struct page___355 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___353 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___355 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___354 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___354 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___342 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___131 *mem_cgroup;
};

struct pglist_data___354;

struct lruvec___354 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___354 *pgdat;
};

struct zone___354 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___354 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___354 {
	struct zone___354 *zone;
	int zone_idx;
};

struct zonelist___354 {
	struct zoneref___354 _zonerefs[25];
};

struct pglist_data___354 {
	struct zone___354 node_zones[3];
	struct zonelist___354 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___355 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___355 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___354 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___354 {
	struct rw_semaphore___355 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___342;

struct vm_area_struct___355 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___355 *vm_next;
	struct vm_area_struct___355 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___354 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___342 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___354 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___354;

struct mm_struct___354 {
	struct {
		struct vm_area_struct___355 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___354 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___355 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___354 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___355 *owner;
		struct user_namespace___244 *user_ns;
		struct file___354 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___354 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___342)(struct vm_area_struct___355 *, long unsigned int, const struct page___355 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___342)(struct page___355 *, void *);

struct device___321;

struct dev_pagemap___342 {
	dev_page_fault_t___342 page_fault;
	dev_page_free_t___342 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___321 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct file___354 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___354 f_path;
	struct inode___354 *f_inode;
	const struct file_operations___354 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___216 f_owner;
	const struct cred___328 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___353 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___342;

struct vm_operations_struct___342 {
	void (*open)(struct vm_area_struct___355 *);
	void (*close)(struct vm_area_struct___355 *);
	int (*split)(struct vm_area_struct___355 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___355 *);
	vm_fault_t (*fault)(struct vm_fault___342 *);
	vm_fault_t (*huge_fault)(struct vm_fault___342 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___342 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___355 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___342 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___342 *);
	int (*access)(struct vm_area_struct___355 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___355 *);
	int (*set_policy)(struct vm_area_struct___355 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___355 *, long unsigned int);
	struct page___355 * (*find_special_page)(struct vm_area_struct___355 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___354 {
	struct task_struct___355 *task;
	struct core_thread___354 *next;
};

struct core_state___354 {
	atomic_t nr_threads;
	struct core_thread___354 dumper;
	struct completion startup;
};

struct vm_fault___342 {
	struct vm_area_struct___355 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___355 *cow_page;
	struct mem_cgroup___131 *memcg;
	struct page___355 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___354 prealloc_pte;
};

struct user_struct___328 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___328 *uid_keyring;
	struct key___328 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___328 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___328 *session_keyring;
	struct key___328 *process_keyring;
	struct key___328 *thread_keyring;
	struct key___328 *request_key_auth;
	void *security;
	struct user_struct___328 *user;
	struct user_namespace___244 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___52;

struct cgroup_namespace___229;

struct nsproxy___274 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net___52 *net_ns;
	struct cgroup_namespace___229 *cgroup_ns;
};

struct signal_struct___254 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___355 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___355 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___216 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___216 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___354 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___216 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___171;

struct bio_list___171 {
	struct bio___171 *head;
	struct bio___171 *tail;
};

struct bdi_writeback_congested___171;

struct bdi_writeback___171 {
	struct backing_dev_info___171 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___171 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___229 *memcg_css;
	struct cgroup_subsys_state___229 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___171 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___171 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___321 *dev;
	struct device___321 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___353 *debug_dir;
	struct dentry___353 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___91;

struct io_context___91 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___91 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___229 {
	struct cgroup_subsys_state___229 *subsys[13];
	refcount_t refcount;
	struct css_set___229 *dom_cset;
	struct cgroup___229 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___229 *mg_src_cgrp;
	struct cgroup___229 *mg_dst_cgrp;
	struct css_set___229 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___353;

struct pipe_buffer___74;

struct pipe_inode_info___74 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___355 *tmp_page;
	struct fasync_struct___353 *fasync_readers;
	struct fasync_struct___353 *fasync_writers;
	struct pipe_buffer___74 *bufs;
	struct user_struct___328 *user;
};

typedef blk_qc_t make_request_fn___87(struct request_queue___87 *, struct bio___171 *);

struct request___87;

typedef int dma_drain_needed_fn___87(struct request___87 *);

struct kset___340;

struct kobj_type___340;

struct kobject___341 {
	const char *name;
	struct list_head entry;
	struct kobject___341 *parent;
	struct kset___340 *kset;
	struct kobj_type___340 *ktype;
	struct kernfs_node___348 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___87;

struct bsg_class_device___87 {
	struct device___321 *class_dev;
	int minor;
	struct request_queue___87 *queue;
	const struct bsg_ops___87 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___171 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___171 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___87;

struct request_queue___87 {
	struct list_head queue_head;
	struct request___87 *last_merge;
	struct elevator_queue___87 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___87 *make_request_fn;
	dma_drain_needed_fn___87 *dma_drain_needed;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___171 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___341 kobj;
	struct kobject___341 *mq_kobj;
	struct blk_integrity integrity;
	struct device___321 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide70;
		union {		};
	};
	struct bsg_class_device___87 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___171 bio_split;
	struct dentry___353 *debugfs_dir;
	struct dentry___353 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___260 {
	struct vm_struct___260 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___355 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___266 {
	struct task_struct___355 task;
	long unsigned int stack[8192];
};

struct io_cq___91 {
	struct request_queue___87 *q;
	struct io_context___91 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___354 {
	struct file___354 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___354 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___353 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___354 *ia_file;
};

struct dquot___353 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___353 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___353 {
	int qf_fmt_id;
	const struct quota_format_ops___353 *qf_ops;
	struct module___289 *qf_owner;
	struct quota_format_type___353 *qf_next;
};

struct quota_format_ops___353 {
	int (*check_quota_file)(struct super_block___353 *, int);
	int (*read_file_info)(struct super_block___353 *, int);
	int (*write_file_info)(struct super_block___353 *, int);
	int (*free_file_info)(struct super_block___353 *, int);
	int (*read_dqblk)(struct dquot___353 *);
	int (*commit_dqblk)(struct dquot___353 *);
	int (*release_dqblk)(struct dquot___353 *);
	int (*get_next_id)(struct super_block___353 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___353 {
	int (*write_dquot)(struct dquot___353 *);
	struct dquot___353 * (*alloc_dquot)(struct super_block___353 *, int);
	void (*destroy_dquot)(struct dquot___353 *);
	int (*acquire_dquot)(struct dquot___353 *);
	int (*release_dquot)(struct dquot___353 *);
	int (*mark_dirty)(struct dquot___353 *);
	int (*write_info)(struct super_block___353 *, int);
	qsize_t * (*get_reserved_space)(struct inode___354 *);
	int (*get_projid)(struct inode___354 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___354 *, qsize_t *);
	int (*get_next_id)(struct super_block___353 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___353 {
	int (*quota_on)(struct super_block___353 *, int, int, const struct path___354 *);
	int (*quota_off)(struct super_block___353 *, int);
	int (*quota_enable)(struct super_block___353 *, unsigned int);
	int (*quota_disable)(struct super_block___353 *, unsigned int);
	int (*quota_sync)(struct super_block___353 *, int);
	int (*set_info)(struct super_block___353 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___353 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___353 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___353 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___353 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___353 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___286 {
	struct kobject___341 kobj;
	struct module___289 *mod;
	struct kobject___341 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___286 {
	struct module___289 *mod;
	struct latch_tree_node node;
};

struct module_layout___286 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___286 mtn;
};

struct module_attribute___286;

struct kernel_param___286;

struct module___289 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___286 mkobj;
	struct module_attribute___286 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___341 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___286 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___286 core_layout;
	struct module_layout___286 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide53;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide54;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___148;

struct address_space_operations___353 {
	int (*writepage)(struct page___355 *, struct writeback_control___148 *);
	int (*readpage)(struct file___354 *, struct page___355 *);
	int (*writepages)(struct address_space___353 *, struct writeback_control___148 *);
	int (*set_page_dirty)(struct page___355 *);
	int (*readpages)(struct file___354 *, struct address_space___353 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___354 *, struct address_space___353 *, loff_t, unsigned int, unsigned int, struct page___355 **, void **);
	int (*write_end)(struct file___354 *, struct address_space___353 *, loff_t, unsigned int, unsigned int, struct page___355 *, void *);
	sector_t (*bmap)(struct address_space___353 *, sector_t);
	void (*invalidatepage)(struct page___355 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___355 *, gfp_t);
	void (*freepage)(struct page___355 *);
	ssize_t (*direct_IO)(struct kiocb___354 *, struct iov_iter___154 *);
	int (*migratepage)(struct address_space___353 *, struct page___355 *, struct page___355 *, enum migrate_mode);
	bool (*isolate_page)(struct page___355 *, isolate_mode_t);
	void (*putback_page)(struct page___355 *);
	int (*launder_page)(struct page___355 *);
	int (*is_partially_uptodate)(struct page___355 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___355 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___353 *, struct page___355 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___354 *, sector_t *);
	void (*swap_deactivate)(struct file___354 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___148 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___171 *wb;
	struct inode___354 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___173;

struct iov_iter___154 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___173 *bvec;
		struct pipe_inode_info___74 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct hd_struct___91;

struct gendisk___91;

struct block_device___353 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___354 *bd_inode;
	struct super_block___353 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___353 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___91 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___91 *bd_disk;
	struct request_queue___87 *bd_queue;
	struct backing_dev_info___171 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___321 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___5 *subsys_data;
	void (*set_latency_tolerance)(struct device___321 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___321;

struct bus_type___321;

struct device_driver___321;

struct dev_pm_domain___321;

struct dma_map_ops___110;

struct fwnode_handle___243;

struct class___321;

struct attribute_group___318;

struct device___321 {
	struct device___321 *parent;
	struct device_private *p;
	struct kobject___341 kobj;
	const char *init_name;
	const struct device_type___321 *type;
	struct mutex mutex;
	struct bus_type___321 *bus;
	struct device_driver___321 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___321 power;
	struct dev_pm_domain___321 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___110 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___243 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___321 *class;
	const struct attribute_group___318 **groups;
	void (*release)(struct device___321 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___91 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___321 __dev;
	struct kobject___341 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___91;

struct block_device_operations___88;

struct gendisk___91 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___91 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___91 *part_tbl;
	struct hd_struct___91 part0;
	const struct block_device_operations___88 *fops;
	struct request_queue___87 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___355 lookup_sem;
	struct kobject___341 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___341 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___353 {
	struct dentry___353 * (*lookup)(struct inode___354 *, struct dentry___353 *, unsigned int);
	const char * (*get_link)(struct dentry___353 *, struct inode___354 *, struct delayed_call *);
	int (*permission)(struct inode___354 *, int);
	struct posix_acl * (*get_acl)(struct inode___354 *, int);
	int (*readlink)(struct dentry___353 *, char *, int);
	int (*create)(struct inode___354 *, struct dentry___353 *, umode_t, bool);
	int (*link)(struct dentry___353 *, struct inode___354 *, struct dentry___353 *);
	int (*unlink)(struct inode___354 *, struct dentry___353 *);
	int (*symlink)(struct inode___354 *, struct dentry___353 *, const char *);
	int (*mkdir)(struct inode___354 *, struct dentry___353 *, umode_t);
	int (*rmdir)(struct inode___354 *, struct dentry___353 *);
	int (*mknod)(struct inode___354 *, struct dentry___353 *, umode_t, dev_t);
	int (*rename)(struct inode___354 *, struct dentry___353 *, struct inode___354 *, struct dentry___353 *, unsigned int);
	int (*setattr)(struct dentry___353 *, struct iattr___353 *);
	int (*getattr)(const struct path___354 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___353 *, char *, size_t);
	int (*fiemap)(struct inode___354 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___354 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___354 *, struct dentry___353 *, struct file___354 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___354 *, struct dentry___353 *, umode_t);
	int (*set_acl)(struct inode___354 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___353 {
	void (*fl_copy_lock)(struct file_lock___354 *, struct file_lock___354 *);
	void (*fl_release_private)(struct file_lock___354 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___353;

struct file_lock___354 {
	struct file_lock___354 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___354 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___353 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___353 *fl_ops;
	const struct lock_manager_operations___353 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___353 {
	int (*lm_compare_owner)(struct file_lock___354 *, struct file_lock___354 *);
	long unsigned int (*lm_owner_key)(struct file_lock___354 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___354 *);
	int (*lm_grant)(struct file_lock___354 *, int);
	bool (*lm_break)(struct file_lock___354 *);
	int (*lm_change)(struct file_lock___354 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___354 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___353 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___353 *fa_next;
	struct file___354 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___353 {
	const char *name;
	int fs_flags;
	struct dentry___353 * (*mount)(struct file_system_type___353 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___353 *);
	struct module___289 *owner;
	struct file_system_type___353 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___353 {
	struct inode___354 * (*alloc_inode)(struct super_block___353 *);
	void (*destroy_inode)(struct inode___354 *);
	void (*dirty_inode)(struct inode___354 *, int);
	int (*write_inode)(struct inode___354 *, struct writeback_control___148 *);
	int (*drop_inode)(struct inode___354 *);
	void (*evict_inode)(struct inode___354 *);
	void (*put_super)(struct super_block___353 *);
	int (*sync_fs)(struct super_block___353 *, int);
	int (*freeze_super)(struct super_block___353 *);
	int (*freeze_fs)(struct super_block___353 *);
	int (*thaw_super)(struct super_block___353 *);
	int (*unfreeze_fs)(struct super_block___353 *);
	int (*statfs)(struct dentry___353 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___353 *, int *, char *);
	void (*umount_begin)(struct super_block___353 *);
	int (*show_options)(struct seq_file___301 *, struct dentry___353 *);
	int (*show_devname)(struct seq_file___301 *, struct dentry___353 *);
	int (*show_path)(struct seq_file___301 *, struct dentry___353 *);
	int (*show_stats)(struct seq_file___301 *, struct dentry___353 *);
	ssize_t (*quota_read)(struct super_block___353 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___353 *, int, const char *, size_t, loff_t);
	struct dquot___353 ** (*get_dquots)(struct inode___354 *);
	int (*bdev_try_to_free_page)(struct super_block___353 *, struct page___355 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___353 *, struct shrink_control___131 *);
	long int (*free_cached_objects)(struct super_block___353 *, struct shrink_control___131 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___220)(struct file___354 *, wait_queue_head_t *, struct poll_table_struct___214 *);

struct poll_table_struct___214 {
	poll_queue_proc___220 _qproc;
	__poll_t _key;
};

struct seq_operations___300;

struct seq_file___301 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___300 *op;
	int poll_event;
	const struct file___354 *file;
	void *private;
};

typedef void bio_end_io_t___171(struct bio___171 *);

struct bio_vec___173 {
	struct page___355 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___171;

struct bio___171 {
	struct bio___171 *bi_next;
	struct gendisk___91 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___171 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___171 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___173 *bi_io_vec;
	struct bio_set___171 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___173 bi_inline_vecs[0];
};

struct kobj_attribute___332 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___341 *, struct kobj_attribute___332 *, char *);
	ssize_t (*store)(struct kobject___341 *, struct kobj_attribute___332 *, const char *, size_t);
};

typedef void compound_page_dtor___342(struct page___355 *);

struct msghdr___31 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___154 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___354 *msg_iocb;
};

struct socket_wq___29 {
	wait_queue_head_t wait;
	struct fasync_struct___353 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct sock___29;

struct proto_ops___29;

struct socket___30 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___29 *wq;
	struct file___354 *file;
	struct sock___29 *sk;
	const struct proto_ops___29 *ops;
};

typedef struct {
	struct net___52 *net;
} possible_net_t___42;

struct proto___28;

struct sock_common___28 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___28 *skc_prot;
	possible_net_t___42 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___29 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___43;

struct sk_buff_head___41 {
	struct sk_buff___43 *next;
	struct sk_buff___43 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___28;

struct dst_entry___28;

struct net_device___43;

struct sock___29 {
	struct sock_common___28 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___41 sk_error_queue;
	struct sk_buff_head___41 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___43 *head;
		struct sk_buff___43 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___28 *sk_filter;
	union {
		struct socket_wq___29 *sk_wq;
		struct socket_wq___29 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___28 *sk_rx_dst;
	struct dst_entry___28 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___43 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___41 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___354 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___28 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___216 *sk_peer_pid;
	const struct cred___328 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___30 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___131 *sk_memcg;
	void (*sk_state_change)(struct sock___29 *);
	void (*sk_data_ready)(struct sock___29 *);
	void (*sk_write_space)(struct sock___29 *);
	void (*sk_error_report)(struct sock___29 *);
	int (*sk_backlog_rcv)(struct sock___29 *, struct sk_buff___43 *);
	struct sk_buff___43 * (*sk_validate_xmit_skb)(struct sock___29 *, struct net_device___43 *, struct sk_buff___43 *);
	void (*sk_destruct)(struct sock___29 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

typedef int (*sk_read_actor_t___28)(read_descriptor_t *, struct sk_buff___43 *, unsigned int, size_t);

struct proto_ops___29 {
	int family;
	struct module___289 *owner;
	int (*release)(struct socket___30 *);
	int (*bind)(struct socket___30 *, struct sockaddr *, int);
	int (*connect)(struct socket___30 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___30 *, struct socket___30 *);
	int (*accept)(struct socket___30 *, struct socket___30 *, int, bool);
	int (*getname)(struct socket___30 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___354 *, struct socket___30 *, struct poll_table_struct___214 *);
	int (*ioctl)(struct socket___30 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___30 *, int);
	int (*shutdown)(struct socket___30 *, int);
	int (*setsockopt)(struct socket___30 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___30 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___30 *, struct msghdr___31 *, size_t);
	int (*recvmsg)(struct socket___30 *, struct msghdr___31 *, size_t, int);
	int (*mmap)(struct file___354 *, struct socket___30 *, struct vm_area_struct___355 *);
	ssize_t (*sendpage)(struct socket___30 *, struct page___355 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___30 *, loff_t *, struct pipe_inode_info___74 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___29 *, int);
	int (*peek_len)(struct socket___30 *);
	int (*read_sock)(struct sock___29 *, read_descriptor_t *, sk_read_actor_t___28);
	int (*sendpage_locked)(struct sock___29 *, struct page___355 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___29 *, struct msghdr___31 *, size_t);
	int (*set_rcvlowat)(struct sock___29 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct nf_bridge_info___41;

struct sk_buff___43 {
	union {
		struct {
			struct sk_buff___43 *next;
			struct sk_buff___43 *prev;
			union {
				struct net_device___43 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___29 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___43 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___41 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___41;

struct netns_frags___41 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___41 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_rules_ops___28;

struct fib_notifier_ops___28;

struct netns_ipv4___41 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___28 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___29 *fibnl;
	struct sock___29 **icmp_sk;
	struct sock___29 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___29 **tcp_sk;
	struct netns_frags___41 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___28 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___28 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___28 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___28;

struct dst_ops___51 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___51 *);
	struct dst_entry___28 * (*check)(struct dst_entry___28 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___28 *);
	unsigned int (*mtu)(const struct dst_entry___28 *);
	u32 * (*cow_metrics)(struct dst_entry___28 *, long unsigned int);
	void (*destroy)(struct dst_entry___28 *);
	void (*ifdown)(struct dst_entry___28 *, struct net_device___43 *, int);
	struct dst_entry___28 * (*negative_advice)(struct dst_entry___28 *);
	void (*link_failure)(struct sk_buff___43 *);
	void (*update_pmtu)(struct dst_entry___28 *, struct sock___29 *, struct sk_buff___43 *, u32);
	void (*redirect)(struct dst_entry___28 *, struct sock___29 *, struct sk_buff___43 *);
	int (*local_out)(struct net___52 *, struct sock___29 *, struct sk_buff___43 *);
	struct neighbour___28 * (*neigh_lookup)(const struct dst_entry___28 *, struct sk_buff___43 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___28 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___51 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___41 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___51 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___28 *fib6_rules_ops;
	struct sock___29 **icmp_sk;
	struct sock___29 *ndisc_sk;
	struct sock___29 *tcp_sk;
	struct sock___29 *igmp_sk;
	struct sock___29 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___28 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___28 *notifier_ops;
	struct fib_notifier_ops___28 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___29 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___29 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___41 {
	struct netns_frags___41 frags;
};

struct netns_xfrm___51 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___29 *nlsk;
	struct sock___29 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___51 xfrm4_dst_ops;
	struct dst_ops___51 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___38;

struct net___52 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___244 *user_ns;
	struct ucounts___244 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___9 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___29 *rtnl;
	struct sock___29 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___43 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___41 ipv4;
	struct netns_ipv6___51 ipv6;
	struct netns_sctp___29 sctp;
	struct netns_nf nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___41 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___29 *nfnl;
	struct sock___29 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___51 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___29 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___38 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kernfs_root___347;

struct kernfs_elem_dir___347 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___347 *root;
};

struct kernfs_syscall_ops___347;

struct kernfs_root___347 {
	struct kernfs_node___348 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___347 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___347 {
	struct kernfs_node___348 *target_kn;
};

struct kernfs_ops___347;

struct kernfs_elem_attr___347 {
	const struct kernfs_ops___347 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___348 *notify_next;
};

struct kernfs_node___348 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___348 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___347 dir;
		struct kernfs_elem_symlink___347 symlink;
		struct kernfs_elem_attr___347 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___347;

struct kernfs_ops___347 {
	int (*open)(struct kernfs_open_file___347 *);
	void (*release)(struct kernfs_open_file___347 *);
	int (*seq_show)(struct seq_file___301 *, void *);
	void * (*seq_start)(struct seq_file___301 *, loff_t *);
	void * (*seq_next)(struct seq_file___301 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___301 *, void *);
	ssize_t (*read)(struct kernfs_open_file___347 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___347 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___347 *, struct vm_area_struct___355 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___347 *, struct poll_table_struct___214 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___347 {
	int (*remount_fs)(struct kernfs_root___347 *, int *, char *);
	int (*show_options)(struct seq_file___301 *, struct kernfs_root___347 *);
	int (*mkdir)(struct kernfs_node___348 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___348 *);
	int (*rename)(struct kernfs_node___348 *, struct kernfs_node___348 *, const char *);
	int (*show_path)(struct seq_file___301 *, struct kernfs_node___348 *, struct kernfs_root___347 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___347 {
	struct kernfs_node___348 *kn;
	struct file___354 *file;
	struct seq_file___301 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___342 *vm_ops;
};

struct kobj_ns_type_operations___28 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___29 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___317;

struct attribute_group___318 {
	const char *name;
	umode_t (*is_visible)(struct kobject___341 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___341 *, struct bin_attribute___317 *, int);
	struct attribute **attrs;
	struct bin_attribute___317 **bin_attrs;
};

struct bin_attribute___317 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___354 *, struct kobject___341 *, struct bin_attribute___317 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___354 *, struct kobject___341 *, struct bin_attribute___317 *, char *, loff_t, size_t);
	int (*mmap)(struct file___354 *, struct kobject___341 *, struct bin_attribute___317 *, struct vm_area_struct___355 *);
};

struct sysfs_ops___340 {
	ssize_t (*show)(struct kobject___341 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___341 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___340;

struct kset___340 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___341 kobj;
	const struct kset_uevent_ops___340 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___340 {
	void (*release)(struct kobject___341 *);
	const struct sysfs_ops___340 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___28 * (*child_ns_type)(struct kobject___341 *);
	const void * (*namespace)(struct kobject___341 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___340 {
	int (* const filter)(struct kset___340 *, struct kobject___341 *);
	const char * (* const name)(struct kset___340 *, struct kobject___341 *);
	int (* const uevent)(struct kset___340 *, struct kobject___341 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___321 {
	int (*prepare)(struct device___321 *);
	void (*complete)(struct device___321 *);
	int (*suspend)(struct device___321 *);
	int (*resume)(struct device___321 *);
	int (*freeze)(struct device___321 *);
	int (*thaw)(struct device___321 *);
	int (*poweroff)(struct device___321 *);
	int (*restore)(struct device___321 *);
	int (*suspend_late)(struct device___321 *);
	int (*resume_early)(struct device___321 *);
	int (*freeze_late)(struct device___321 *);
	int (*thaw_early)(struct device___321 *);
	int (*poweroff_late)(struct device___321 *);
	int (*restore_early)(struct device___321 *);
	int (*suspend_noirq)(struct device___321 *);
	int (*resume_noirq)(struct device___321 *);
	int (*freeze_noirq)(struct device___321 *);
	int (*thaw_noirq)(struct device___321 *);
	int (*poweroff_noirq)(struct device___321 *);
	int (*restore_noirq)(struct device___321 *);
	int (*runtime_suspend)(struct device___321 *);
	int (*runtime_resume)(struct device___321 *);
	int (*runtime_idle)(struct device___321 *);
};

struct dev_pm_domain___321 {
	struct dev_pm_ops___321 ops;
	void (*detach)(struct device___321 *, bool);
	int (*activate)(struct device___321 *);
	void (*sync)(struct device___321 *);
	void (*dismiss)(struct device___321 *);
};

struct bus_type___321 {
	const char *name;
	const char *dev_name;
	struct device___321 *dev_root;
	const struct attribute_group___318 **bus_groups;
	const struct attribute_group___318 **dev_groups;
	const struct attribute_group___318 **drv_groups;
	int (*match)(struct device___321 *, struct device_driver___321 *);
	int (*uevent)(struct device___321 *, struct kobj_uevent_env *);
	int (*probe)(struct device___321 *);
	int (*remove)(struct device___321 *);
	void (*shutdown)(struct device___321 *);
	int (*online)(struct device___321 *);
	int (*offline)(struct device___321 *);
	int (*suspend)(struct device___321 *, pm_message_t);
	int (*resume)(struct device___321 *);
	int (*num_vf)(struct device___321 *);
	int (*dma_configure)(struct device___321 *);
	const struct dev_pm_ops___321 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___321 {
	const char *name;
	struct bus_type___321 *bus;
	struct module___289 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___321 *);
	int (*remove)(struct device___321 *);
	void (*shutdown)(struct device___321 *);
	int (*suspend)(struct device___321 *, pm_message_t);
	int (*resume)(struct device___321 *);
	const struct attribute_group___318 **groups;
	const struct dev_pm_ops___321 *pm;
	void (*coredump)(struct device___321 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___321 {
	const char *name;
	const struct attribute_group___318 **groups;
	int (*uevent)(struct device___321 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___321 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___321 *);
	const struct dev_pm_ops___321 *pm;
};

struct class___321 {
	const char *name;
	struct module___289 *owner;
	const struct attribute_group___318 **class_groups;
	const struct attribute_group___318 **dev_groups;
	struct kobject___341 *dev_kobj;
	int (*dev_uevent)(struct device___321 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___321 *, umode_t *);
	void (*class_release)(struct class___321 *);
	void (*dev_release)(struct device___321 *);
	int (*shutdown_pre)(struct device___321 *);
	const struct kobj_ns_type_operations___28 *ns_type;
	const void * (*namespace)(struct device___321 *);
	const struct dev_pm_ops___321 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___110 {
	void * (*alloc)(struct device___321 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___321 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___321 *, struct vm_area_struct___355 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___321 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___321 *, struct page___355 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___321 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___321 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___321 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___321 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___321 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___321 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___321 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___321 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___321 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___321 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___321 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___321 *, u64);
	u64 (*get_required_mask)(struct device___321 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___243;

struct fwnode_handle___243 {
	struct fwnode_handle___243 *secondary;
	const struct fwnode_operations___243 *ops;
};

struct fwnode_reference_args___243;

struct fwnode_endpoint___243;

struct fwnode_operations___243 {
	struct fwnode_handle___243 * (*get)(struct fwnode_handle___243 *);
	void (*put)(struct fwnode_handle___243 *);
	bool (*device_is_available)(const struct fwnode_handle___243 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___243 *, const struct device___321 *);
	bool (*property_present)(const struct fwnode_handle___243 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___243 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___243 *, const char *, const char **, size_t);
	struct fwnode_handle___243 * (*get_parent)(const struct fwnode_handle___243 *);
	struct fwnode_handle___243 * (*get_next_child_node)(const struct fwnode_handle___243 *, struct fwnode_handle___243 *);
	struct fwnode_handle___243 * (*get_named_child_node)(const struct fwnode_handle___243 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___243 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___243 *);
	struct fwnode_handle___243 * (*graph_get_next_endpoint)(const struct fwnode_handle___243 *, struct fwnode_handle___243 *);
	struct fwnode_handle___243 * (*graph_get_remote_endpoint)(const struct fwnode_handle___243 *);
	struct fwnode_handle___243 * (*graph_get_port_parent)(struct fwnode_handle___243 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___243 *, struct fwnode_endpoint___243 *);
};

struct fwnode_endpoint___243 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___243 *local_fwnode;
};

struct fwnode_reference_args___243 {
	struct fwnode_handle___243 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___74;

struct pipe_buffer___74 {
	struct page___355 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___74 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___74 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___74 *, struct pipe_buffer___74 *);
	void (*release)(struct pipe_inode_info___74 *, struct pipe_buffer___74 *);
	int (*steal)(struct pipe_inode_info___74 *, struct pipe_buffer___74 *);
	union {
		bool (*get)(struct pipe_inode_info___74 *, struct pipe_buffer___74 *);
		struct {
			void (*get)(struct pipe_inode_info___74 *, struct pipe_buffer___74 *);
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
};

struct nf_bridge_info___41 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___41 = 0,
		BRNF_PROTO_8021Q___41 = 1,
		BRNF_PROTO_PPPOE___41 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___43 *physindev;
	struct net_device___43 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___41(struct sk_buff___43 **);

struct net_device_ops___41;

struct ethtool_ops___41;

struct l3mdev_ops___28;

struct xfrmdev_ops___41;

struct tlsdev_ops___41;

struct header_ops___41;

struct netdev_rx_queue___41;

struct mini_Qdisc___38;

struct netdev_queue___41;

struct Qdisc___38;

struct rtnl_link_ops___38;

struct dcbnl_rtnl_ops___41;

struct net_device___43 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___41 *netdev_ops;
	const struct ethtool_ops___41 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___28 *l3mdev_ops;
	const struct ndisc_ops___2 *ndisc_ops;
	const struct xfrmdev_ops___41 *xfrmdev_ops;
	const struct tlsdev_ops___41 *tlsdev_ops;
	const struct header_ops___41 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___340 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___2 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___41 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___38 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___41 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___38 *miniq_ingress;
	struct netdev_queue___41 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___41 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___38 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___38 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___41 = 0,
		NETREG_REGISTERED___41 = 1,
		NETREG_UNREGISTERING___41 = 2,
		NETREG_UNREGISTERED___41 = 3,
		NETREG_RELEASED___41 = 4,
		NETREG_DUMMY___41 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___41 = 0,
		RTNL_LINK_INITIALIZING___41 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___43 *);
	struct netpoll_info *npinfo;
	possible_net_t___42 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___321 dev;
	const struct attribute_group___318 *sysfs_groups[4];
	const struct attribute_group___318 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___38 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___41 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct ethtool_ops___41 {
	int (*get_settings)(struct net_device___43 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___43 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___43 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___43 *);
	void (*get_regs)(struct net_device___43 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___43 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___43 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___43 *);
	void (*set_msglevel)(struct net_device___43 *, u32);
	int (*nway_reset)(struct net_device___43 *);
	u32 (*get_link)(struct net_device___43 *);
	int (*get_eeprom_len)(struct net_device___43 *);
	int (*get_eeprom)(struct net_device___43 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___43 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___43 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___43 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___43 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___43 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___43 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___43 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___43 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___43 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___43 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___43 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___43 *);
	void (*complete)(struct net_device___43 *);
	u32 (*get_priv_flags)(struct net_device___43 *);
	int (*set_priv_flags)(struct net_device___43 *, u32);
	int (*get_sset_count)(struct net_device___43 *, int);
	int (*get_rxnfc)(struct net_device___43 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___43 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___43 *, struct ethtool_flash *);
	int (*reset)(struct net_device___43 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___43 *);
	u32 (*get_rxfh_indir_size)(struct net_device___43 *);
	int (*get_rxfh)(struct net_device___43 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___43 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___43 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___43 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___43 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___43 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___43 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___43 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___43 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___43 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___43 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___43 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___43 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___43 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___43 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___43 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___43 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___43 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___43 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___43 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___43 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___43 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	int (*get_fecparam)(struct net_device___43 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___43 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___43 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___43 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___43 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___41;

struct inet_frags___41 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___41 *, const void *);
	void (*destructor)(struct inet_frag_queue___41 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___41 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___43 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___43 *fragments_tail;
	struct sk_buff___43 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___41 *net;
	struct callback_head rcu;
};

struct fib_rule___28;

struct fib_lookup_arg___28;

struct fib_rules_ops___28 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___28 *, struct flowi *, int, struct fib_lookup_arg___28 *);
	bool (*suppress)(struct fib_rule___28 *, struct fib_lookup_arg___28 *);
	int (*match)(struct fib_rule___28 *, struct flowi *, int);
	int (*configure)(struct fib_rule___28 *, struct sk_buff___43 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___28 *);
	int (*compare)(struct fib_rule___28 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___28 *, struct sk_buff___43 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___28 *);
	void (*flush_cache)(struct fib_rules_ops___28 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___289 *owner;
	struct net___52 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___28 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___52 *);
	int (*fib_dump)(struct net___52 *, struct notifier_block *);
	struct module___289 *owner;
	struct callback_head rcu;
};

struct dst_entry___28 {
	struct net_device___43 *dev;
	struct dst_ops___51 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___43 *);
	int (*output)(struct net___52 *, struct sock___29 *, struct sk_buff___43 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___28;

struct neigh_parms___28;

struct neigh_ops___28;

struct neighbour___28 {
	struct neighbour___28 *next;
	struct neigh_table___28 *tbl;
	struct neigh_parms___28 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___41 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___28 *, struct sk_buff___43 *);
	const struct neigh_ops___28 *ops;
	struct callback_head rcu;
	struct net_device___43 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct ucounts___244 {
	struct hlist_node node;
	struct user_namespace___244 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_prog_aux___41;

struct bpf_prog___38 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___41 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

struct seq_operations___300 {
	void * (*start)(struct seq_file___301 *, loff_t *);
	void (*stop)(struct seq_file___301 *, void *);
	void * (*next)(struct seq_file___301 *, void *, loff_t *);
	int (*show)(struct seq_file___301 *, void *);
};

struct pernet_operations___42 {
	struct list_head list;
	int (*init)(struct net___52 *);
	void (*exit)(struct net___52 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___41 {
	int (*ieee_getets)(struct net_device___43 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___43 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___43 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___43 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___43 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___43 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___43 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___43 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___43 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___43 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___43 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___43 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___43 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___43 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___43 *);
	u8 (*setstate)(struct net_device___43 *, u8);
	void (*getpermhwaddr)(struct net_device___43 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___43 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___43 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___43 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___43 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___43 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___43 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___43 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___43 *, int, u8 *);
	void (*setpfccfg)(struct net_device___43 *, int, u8);
	void (*getpfccfg)(struct net_device___43 *, int, u8 *);
	u8 (*setall)(struct net_device___43 *);
	u8 (*getcap)(struct net_device___43 *, int, u8 *);
	int (*getnumtcs)(struct net_device___43 *, int, u8 *);
	int (*setnumtcs)(struct net_device___43 *, int, u8);
	u8 (*getpfcstate)(struct net_device___43 *);
	void (*setpfcstate)(struct net_device___43 *, u8);
	void (*getbcncfg)(struct net_device___43 *, int, u32 *);
	void (*setbcncfg)(struct net_device___43 *, int, u32);
	void (*getbcnrp)(struct net_device___43 *, int, u8 *);
	void (*setbcnrp)(struct net_device___43 *, int, u8);
	int (*setapp)(struct net_device___43 *, u8, u16, u8);
	int (*getapp)(struct net_device___43 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___43 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___43 *, int, u8);
	u8 (*getdcbx)(struct net_device___43 *);
	u8 (*setdcbx)(struct net_device___43 *, u8);
	int (*peer_getappinfo)(struct net_device___43 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___43 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___43 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___43 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___43 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___43 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___229 {
	refcount_t count;
	struct ns_common___9 ns;
	struct user_namespace___244 *user_ns;
	struct ucounts___244 *ucounts;
	struct css_set___229 *root_cset;
};

struct bpf_map___230;

struct bpf_map_ops___229 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___230 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___230 *, struct file___354 *);
	void (*map_free)(struct bpf_map___230 *);
	int (*map_get_next_key)(struct bpf_map___230 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___230 *);
	void * (*map_lookup_elem)(struct bpf_map___230 *, void *);
	int (*map_update_elem)(struct bpf_map___230 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___230 *, void *);
	int (*map_push_elem)(struct bpf_map___230 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___230 *, void *);
	int (*map_peek_elem)(struct bpf_map___230 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___230 *, struct file___354 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___230 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___230 *, void *, struct seq_file___301 *);
	int (*map_check_btf)(const struct bpf_map___230 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___230 {
	const struct bpf_map_ops___229 *ops;
	struct bpf_map___230 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___328 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___41;

struct bpf_map_dev_ops___41 {
	int (*map_get_next_key)(struct bpf_offloaded_map___41 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___41 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___41 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___41 *, void *);
};

struct bpf_offloaded_map___41 {
	struct bpf_map___230 map;
	struct net_device___43 *netdev;
	const struct bpf_map_dev_ops___41 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___38 {
	int (*test_run)(struct bpf_prog___38 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___38 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___38 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___38 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___38 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___38 *, u32 *);
};

struct bpf_prog_offload_ops___38 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___38 *);
	int (*translate)(struct bpf_prog___38 *);
	void (*destroy)(struct bpf_prog___38 *);
};

struct bpf_prog_offload___38 {
	struct bpf_prog___38 *prog;
	struct net_device___43 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___38 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___41 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___38 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___38 *ops;
	struct bpf_map___230 **used_maps;
	struct bpf_prog___38 *prog;
	struct user_struct___328 *user;
	u64 load_time;
	struct bpf_map___230 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___38 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___38 {
	struct bpf_prog___38 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___38 {
	struct callback_head rcu;
	struct bpf_prog_array_item___38 items[0];
};

struct cgroup_bpf___38 {
	struct bpf_prog_array___38 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___38 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___229;

typedef void (*kthread_work_func_t___229)(struct kthread_work___229 *);

struct kthread_worker___229;

struct kthread_work___229 {
	struct list_head node;
	kthread_work_func_t___229 func;
	struct kthread_worker___229 *worker;
	int canceling;
};

struct kthread_worker___229 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___355 *task;
	struct kthread_work___229 *current_work;
};

struct kthread_delayed_work___229 {
	struct kthread_work___229 work;
	struct timer_list timer;
};

struct psi_group___229 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___229 *poll_kworker;
	struct kthread_delayed_work___229 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___229;

struct cgroup_rstat_cpu___229;

struct cgroup___229 {
	struct cgroup_subsys_state___229 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___348 *kn;
	struct cgroup_file___229 procs_file;
	struct cgroup_file___229 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___229 *subsys[13];
	struct cgroup_root___229 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___229 *dom_cgrp;
	struct cgroup_rstat_cpu___229 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___38 bpf;
	atomic_t congestion_count;
	struct cgroup___229 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___229 psi;
	int ancestor_ids[0];
};

struct cftype___229;

struct cgroup_subsys___229 {
	struct cgroup_subsys_state___229 * (*css_alloc)(struct cgroup_subsys_state___229 *);
	int (*css_online)(struct cgroup_subsys_state___229 *);
	void (*css_offline)(struct cgroup_subsys_state___229 *);
	void (*css_released)(struct cgroup_subsys_state___229 *);
	void (*css_free)(struct cgroup_subsys_state___229 *);
	void (*css_reset)(struct cgroup_subsys_state___229 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___229 *, int);
	int (*css_extra_stat_show)(struct seq_file___301 *, struct cgroup_subsys_state___229 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___355 *);
	void (*cancel_fork)(struct task_struct___355 *);
	void (*fork)(struct task_struct___355 *);
	void (*exit)(struct task_struct___355 *);
	void (*free)(struct task_struct___355 *);
	void (*bind)(struct cgroup_subsys_state___229 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___229 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___229 *dfl_cftypes;
	struct cftype___229 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___229 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___229 *updated_children;
	struct cgroup___229 *updated_next;
};

struct cgroup_root___229 {
	struct kernfs_root___347 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___229 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___229 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___229 *ss;
	struct list_head node;
	struct kernfs_ops___347 *kf_ops;
	int (*open)(struct kernfs_open_file___347 *);
	void (*release)(struct kernfs_open_file___347 *);
	u64 (*read_u64)(struct cgroup_subsys_state___229 *, struct cftype___229 *);
	s64 (*read_s64)(struct cgroup_subsys_state___229 *, struct cftype___229 *);
	int (*seq_show)(struct seq_file___301 *, void *);
	void * (*seq_start)(struct seq_file___301 *, loff_t *);
	void * (*seq_next)(struct seq_file___301 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___301 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___229 *, struct cftype___229 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___229 *, struct cftype___229 *, s64);
	ssize_t (*write)(struct kernfs_open_file___347 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___347 *, struct poll_table_struct___214 *);
};

struct xdp_rxq_info___41 {
	struct net_device___43 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___41 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___43 *dev_rx;
};

struct netlink_kernel_cfg___3 {
	unsigned int groups;
	unsigned int flags;
	void (*input)(struct sk_buff___43 *);
	struct mutex *cb_mutex;
	int (*bind)(struct net___52 *, int);
	void (*unbind)(struct net___52 *, int);
	bool (*compare)(struct net___52 *, struct sock___29 *);
};

struct netlink_callback___42 {
	struct sk_buff___43 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___42 *);
	int (*dump)(struct sk_buff___43 *, struct netlink_callback___42 *);
	int (*done)(struct netlink_callback___42 *);
	void *data;
	struct module___289 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___41 {
	int (*create)(struct sk_buff___43 *, struct net_device___43 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___43 *, unsigned char *);
	int (*cache)(const struct neighbour___28 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___43 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___41 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___41 *, int);
	int poll_owner;
	struct net_device___43 *dev;
	struct sk_buff___43 *gro_list;
	struct sk_buff___43 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___41 {
	struct net_device___43 *dev;
	struct Qdisc___38 *qdisc;
	struct Qdisc___38 *qdisc_sleeping;
	struct kobject___341 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___43 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___38 {
	struct sk_buff___43 *head;
	struct sk_buff___43 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___38;

struct Qdisc___38 {
	int (*enqueue)(struct sk_buff___43 *, struct Qdisc___38 *, struct sk_buff___43 **);
	struct sk_buff___43 * (*dequeue)(struct Qdisc___38 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___38 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___41 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___41 gso_skb;
	struct qdisc_skb_head___38 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___38 *next_sched;
	struct sk_buff_head___41 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___41 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___341 kobj;
	struct net_device___43 *dev;
	long: 64;
	struct xdp_rxq_info___41 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___41)(struct net_device___43 *, struct sk_buff___43 *, struct net_device___43 *);

struct netdev_bpf___41 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___38 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___38 *prog;
			const struct bpf_prog_offload_ops___38 *ops;
		} verifier;
		struct {
			struct bpf_prog___38 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___41 *offmap;
		};
		struct {
			struct xdp_umem *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___41 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___43 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___41 {
	int (*tls_dev_add)(struct net_device___43 *, struct sock___29 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___43 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___43 *, struct sock___29 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___41 {
	int (*ndo_init)(struct net_device___43 *);
	void (*ndo_uninit)(struct net_device___43 *);
	int (*ndo_open)(struct net_device___43 *);
	int (*ndo_stop)(struct net_device___43 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___43 *, struct net_device___43 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___43 *, struct net_device___43 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___43 *, struct sk_buff___43 *, struct net_device___43 *, select_queue_fallback_t___41);
	void (*ndo_change_rx_flags)(struct net_device___43 *, int);
	void (*ndo_set_rx_mode)(struct net_device___43 *);
	int (*ndo_set_mac_address)(struct net_device___43 *, void *);
	int (*ndo_validate_addr)(struct net_device___43 *);
	int (*ndo_do_ioctl)(struct net_device___43 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___43 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___43 *, int);
	int (*ndo_neigh_setup)(struct net_device___43 *, struct neigh_parms___28 *);
	void (*ndo_tx_timeout)(struct net_device___43 *);
	void (*ndo_get_stats64)(struct net_device___43 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___43 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___43 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___43 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___43 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___43 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___43 *);
	int (*ndo_netpoll_setup)(struct net_device___43 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___43 *);
	int (*ndo_set_vf_mac)(struct net_device___43 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___43 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___43 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___43 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___43 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___43 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___43 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___43 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___43 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___43 *, int, struct sk_buff___43 *);
	int (*ndo_set_vf_guid)(struct net_device___43 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___43 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___43 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___43 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___43 *, const struct sk_buff___43 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___43 *, struct net_device___43 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___43 *, struct net_device___43 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___43 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___43 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___43 *, struct neighbour___28 *);
	void (*ndo_neigh_destroy)(struct net_device___43 *, struct neighbour___28 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___43 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___43 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___43 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___43 *, struct netlink_callback___42 *, struct net_device___43 *, struct net_device___43 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___43 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___43 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___43 *, u32, u32, struct net_device___43 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___43 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___43 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___43 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___43 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___43 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___43 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___43 *, struct net_device___43 *);
	void (*ndo_dfwd_del_station)(struct net_device___43 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___43 *);
	int (*ndo_set_tx_maxrate)(struct net_device___43 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___43 *);
	int (*ndo_change_proto_down)(struct net_device___43 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___43 *, struct sk_buff___43 *);
	void (*ndo_set_rx_headroom)(struct net_device___43 *, int);
	int (*ndo_bpf)(struct net_device___43 *, struct netdev_bpf___41 *);
	int (*ndo_xdp_xmit)(struct net_device___43 *, int, struct xdp_frame___41 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___43 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___43 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___28 {
	possible_net_t___42 net;
	struct net_device___43 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___28 *);
	void (*neigh_cleanup)(struct neighbour___28 *);
	struct neigh_table___28 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___28 {
	u32 (*l3mdev_fib_table)(const struct net_device___43 *);
	struct sk_buff___43 * (*l3mdev_l3_rcv)(struct net_device___43 *, struct sk_buff___43 *, u16);
	struct sk_buff___43 * (*l3mdev_l3_out)(struct net_device___43 *, struct sock___29 *, struct sk_buff___43 *, u16);
	struct dst_entry___28 * (*l3mdev_link_scope_lookup)(const struct net_device___43 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct tcf_proto___38;

struct mini_Qdisc___38 {
	struct tcf_proto___38 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___38 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___43 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___52 *, struct net_device___43 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___43 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___43 *, struct list_head *);
	size_t (*get_size)(const struct net_device___43 *);
	int (*fill_info)(struct sk_buff___43 *, const struct net_device___43 *);
	size_t (*get_xstats_size)(const struct net_device___43 *);
	int (*fill_xstats)(struct sk_buff___43 *, const struct net_device___43 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___43 *, struct net_device___43 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___43 *, const struct net_device___43 *);
	int (*fill_slave_info)(struct sk_buff___43 *, const struct net_device___43 *, const struct net_device___43 *);
	struct net___52 * (*get_link_net)(const struct net_device___43 *);
	size_t (*get_linkxstats_size)(const struct net_device___43 *, int);
	int (*fill_linkxstats)(struct sk_buff___43 *, const struct net_device___43 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___41 {
	struct list_head poll_list;
	struct sk_buff_head___41 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___41 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___38 *output_queue;
	struct Qdisc___38 **output_queue_tailp;
	struct sk_buff___43 *completion_queue;
	struct sk_buff_head___41 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___41 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___41 input_pkt_queue;
	struct napi_struct___41 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bdi_writeback_congested___171 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___171 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___171 {
	struct bio___171 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___173 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___173 bip_inline_vecs[0];
};

struct mem_cgroup_reclaim_iter___131 {
	struct mem_cgroup___131 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___131 {
	struct lruvec___354 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___131 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___131 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct kernel_param_ops___286 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___286 *);
	int (*get)(char *, const struct kernel_param___286 *);
	void (*free)(void *);
};

struct kparam_array___286;

struct kernel_param___286 {
	const char *name;
	struct module___289 *mod;
	const struct kernel_param_ops___286 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___286 *arr;
	};
};

struct kparam_array___286 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___286 *ops;
	void *elem;
};

struct module_attribute___286 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___286 *, struct module_kobject___286 *, char *);
	ssize_t (*store)(struct module_attribute___286 *, struct module_kobject___286 *, const char *, size_t);
	void (*setup)(struct module___289 *, const char *);
	int (*test)(struct module___289 *);
	void (*free)(struct module___289 *);
};

struct gnet_dump___38 {
	spinlock_t *lock;
	struct sk_buff___43 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___38;

struct Qdisc_ops___38 {
	struct Qdisc_ops___38 *next;
	const struct Qdisc_class_ops___38 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___43 *, struct Qdisc___38 *, struct sk_buff___43 **);
	struct sk_buff___43 * (*dequeue)(struct Qdisc___38 *);
	struct sk_buff___43 * (*peek)(struct Qdisc___38 *);
	int (*init)(struct Qdisc___38 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___38 *);
	void (*destroy)(struct Qdisc___38 *);
	int (*change)(struct Qdisc___38 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___38 *);
	int (*change_tx_queue_len)(struct Qdisc___38 *, unsigned int);
	int (*dump)(struct Qdisc___38 *, struct sk_buff___43 *);
	int (*dump_stats)(struct Qdisc___38 *, struct gnet_dump___38 *);
	void (*ingress_block_set)(struct Qdisc___38 *, u32);
	void (*egress_block_set)(struct Qdisc___38 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___38 *);
	u32 (*egress_block_get)(struct Qdisc___38 *);
	struct module___289 *owner;
};

struct tcf_block___38;

struct Qdisc_class_ops___38 {
	unsigned int flags;
	struct netdev_queue___41 * (*select_queue)(struct Qdisc___38 *, struct tcmsg *);
	int (*graft)(struct Qdisc___38 *, long unsigned int, struct Qdisc___38 *, struct Qdisc___38 **, struct netlink_ext_ack *);
	struct Qdisc___38 * (*leaf)(struct Qdisc___38 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___38 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___38 *, u32);
	int (*change)(struct Qdisc___38 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___38 *, long unsigned int);
	void (*walk)(struct Qdisc___38 *, struct qdisc_walker *);
	struct tcf_block___38 * (*tcf_block)(struct Qdisc___38 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___38 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___38 *, long unsigned int);
	int (*dump)(struct Qdisc___38 *, long unsigned int, struct sk_buff___43 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___38 *, long unsigned int, struct gnet_dump___38 *);
};

struct tcf_chain___38;

struct tcf_block___38 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___52 *net;
	struct Qdisc___38 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___38 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___38;

struct tcf_proto_ops___38;

struct tcf_proto___38 {
	struct tcf_proto___38 *next;
	void *root;
	int (*classify)(struct sk_buff___43 *, const struct tcf_proto___38 *, struct tcf_result___38 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___38 *ops;
	struct tcf_chain___38 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___38 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___38 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___38 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___43 *, const struct tcf_proto___38 *, struct tcf_result___38 *);
	int (*init)(struct tcf_proto___38 *);
	void (*destroy)(struct tcf_proto___38 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___38 *, u32);
	void (*put)(struct tcf_proto___38 *, void *);
	int (*change)(struct net___52 *, struct sk_buff___43 *, struct tcf_proto___38 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___38 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___38 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___38 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___52 *, struct tcf_chain___38 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___52 *, struct tcf_proto___38 *, void *, struct sk_buff___43 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___43 *, struct net___52 *, void *);
	struct module___289 *owner;
	int flags;
};

struct tcf_chain___38 {
	struct mutex filter_chain_lock;
	struct tcf_proto___38 *filter_chain;
	struct list_head list;
	struct tcf_block___38 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___38 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___28 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___38 *prog;
};

struct bpf_redirect_info___38 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___230 *map;
	struct bpf_map___230 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___28;

struct neigh_hash_table___28;

struct neigh_table___28 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___43 *, __u32 *);
	bool (*key_eq)(const struct neighbour___28 *, const void *);
	int (*constructor)(struct neighbour___28 *);
	int (*pconstructor)(struct pneigh_entry___28 *);
	void (*pdestructor)(struct pneigh_entry___28 *);
	void (*proxy_redo)(struct sk_buff___43 *);
	char *id;
	struct neigh_parms___28 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___41 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___28 *nht;
	struct pneigh_entry___28 **phash_buckets;
};

struct neigh_ops___28 {
	int family;
	void (*solicit)(struct neighbour___28 *, struct sk_buff___43 *);
	void (*error_report)(struct neighbour___28 *, struct sk_buff___43 *);
	int (*output)(struct neighbour___28 *, struct sk_buff___43 *);
	int (*connected_output)(struct neighbour___28 *, struct sk_buff___43 *);
};

struct pneigh_entry___28 {
	struct pneigh_entry___28 *next;
	possible_net_t___42 net;
	struct net_device___43 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___28 {
	struct neighbour___28 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___28 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___28 *ctarget;
	struct net___52 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___28 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___28 *rule;
	u32 table;
	int flags;
};

struct proto___28 {
	void (*close)(struct sock___29 *, long int);
	int (*pre_connect)(struct sock___29 *, struct sockaddr *, int);
	int (*connect)(struct sock___29 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___29 *, int);
	struct sock___29 * (*accept)(struct sock___29 *, int, int *, bool);
	int (*ioctl)(struct sock___29 *, int, long unsigned int);
	int (*init)(struct sock___29 *);
	void (*destroy)(struct sock___29 *);
	void (*shutdown)(struct sock___29 *, int);
	int (*setsockopt)(struct sock___29 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___29 *, int, int, char *, int *);
	void (*keepalive)(struct sock___29 *, int);
	int (*sendmsg)(struct sock___29 *, struct msghdr___31 *, size_t);
	int (*recvmsg)(struct sock___29 *, struct msghdr___31 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___29 *, struct page___355 *, int, size_t, int);
	int (*bind)(struct sock___29 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___29 *, struct sk_buff___43 *);
	void (*release_cb)(struct sock___29 *);
	int (*hash)(struct sock___29 *);
	void (*unhash)(struct sock___29 *);
	void (*rehash)(struct sock___29 *);
	int (*get_port)(struct sock___29 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___29 *);
	bool (*stream_memory_read)(const struct sock___29 *);
	void (*enter_memory_pressure)(struct sock___29 *);
	void (*leave_memory_pressure)(struct sock___29 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___3 *rsk_prot;
	struct timewait_sock_ops___3 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___289 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___29 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct scsi_nl_hdr {
	uint8_t version;
	uint8_t transport;
	uint16_t magic;
	uint16_t msgtype;
	uint16_t msglen;
};

struct disk_part_tbl___91 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___91 *last_lookup;
	struct hd_struct___91 *part[0];
};

struct block_device_operations___88 {
	int (*open)(struct block_device___353 *, fmode_t);
	void (*release)(struct gendisk___91 *, fmode_t);
	int (*rw_page)(struct block_device___353 *, sector_t, struct page___355 *, unsigned int);
	int (*ioctl)(struct block_device___353 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___353 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___91 *, unsigned int);
	int (*media_changed)(struct gendisk___91 *);
	void (*unlock_native_capacity)(struct gendisk___91 *);
	int (*revalidate_disk)(struct gendisk___91 *);
	int (*getgeo)(struct block_device___353 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___353 *, long unsigned int);
	int (*report_zones)(struct gendisk___91 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___289 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___87 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___87 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___87 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___87 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___87(struct request___87 *, blk_status_t);

struct request___87 {
	struct request_queue___87 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___171 *bio;
	struct bio___171 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___173 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___91 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___87 *saved_end_io;
		} flush;
	};
	struct gendisk___91 *rq_disk;
	struct hd_struct___91 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___87 *end_io;
	void *end_io_data;
	struct request___87 *next_rq;
};

struct elevator_type___87;

struct elevator_mq_ops___87 {
	int (*init_sched)(struct request_queue___87 *, struct elevator_type___87 *);
	void (*exit_sched)(struct elevator_queue___87 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	bool (*allow_merge)(struct request_queue___87 *, struct request___87 *, struct bio___171 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx *, struct bio___171 *);
	int (*request_merge)(struct request_queue___87 *, struct request___87 **, struct bio___171 *);
	void (*request_merged)(struct request_queue___87 *, struct request___87 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___87 *, struct request___87 *, struct request___87 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___87 *, struct bio___171 *);
	void (*finish_request)(struct request___87 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___87 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___87 *, u64);
	void (*started_request)(struct request___87 *);
	void (*requeue_request)(struct request___87 *);
	struct request___87 * (*former_request)(struct request_queue___87 *, struct request___87 *);
	struct request___87 * (*next_request)(struct request_queue___87 *, struct request___87 *);
	void (*init_icq)(struct io_cq___91 *);
	void (*exit_icq)(struct io_cq___91 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide69;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___87;

struct elevator_type___87 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___87 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___87 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___289 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___87 {
	struct elevator_type___87 *type;
	void *elevator_data;
	struct kobject___341 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___87 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___87 *, char *);
	ssize_t (*store)(struct elevator_queue___87 *, const char *, size_t);
};

struct file___355;

struct kiocb___355;

struct vm_area_struct___356;

struct inode___355;

struct file_lock___355;

struct page___356;

struct seq_file___302;

struct file_operations___355 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___355 *, loff_t, int);
	ssize_t (*read)(struct file___355 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___355 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___355 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___355 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___355 *, bool);
	int (*iterate)(struct file___355 *, struct dir_context *);
	int (*iterate_shared)(struct file___355 *, struct dir_context *);
	__poll_t (*poll)(struct file___355 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___355 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___355 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___355 *, struct vm_area_struct___356 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___355 *, struct file___355 *);
	int (*flush)(struct file___355 *, fl_owner_t);
	int (*release)(struct inode___355 *, struct file___355 *);
	int (*fsync)(struct file___355 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___355 *, int);
	int (*lock)(struct file___355 *, int, struct file_lock___355 *);
	ssize_t (*sendpage)(struct file___355 *, struct page___356 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___355 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___355 *, int, struct file_lock___355 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___355 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___355 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___355 *, long int, struct file_lock___355 **, void **);
	long int (*fallocate)(struct file___355 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___302 *, struct file___355 *);
	ssize_t (*copy_file_range)(struct file___355 *, loff_t, struct file___355 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___355 *, loff_t, struct file___355 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___355 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___355 {
	u64 seqnum;
	struct vm_area_struct___356 *vmas[4];
};

struct page_frag___355 {
	struct page___356 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___355;

struct cred___329;

struct bio_list___172;

struct backing_dev_info___172;

struct io_context___92;

struct request_queue___88;

struct vm_struct___261;

struct task_struct___356 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___356 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___355 *mm;
	struct mm_struct___355 *active_mm;
	struct vmacache___355 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___356 *real_parent;
	struct task_struct___356 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___356 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___216 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___216 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___216 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___329 *ptracer_cred;
	const struct cred___329 *real_cred;
	const struct cred___329 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___356 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___172 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___172 *backing_dev_info;
	struct io_context___92 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___355 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___88 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___356 *oom_reaper_list;
	struct vm_struct___261 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___140 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___354;

struct super_block___354;

struct dentry___354 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___354 *d_parent;
	struct qstr d_name;
	struct inode___355 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___354 *d_op;
	struct super_block___354 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct rw_semaphore___356 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___356 *owner;
};

struct address_space_operations___354;

struct address_space___354 {
	struct inode___355 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___356 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___354 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___354;

struct bdi_writeback___172;

struct block_device___354;

struct inode___355 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___354 *i_op;
	struct super_block___354 *i_sb;
	struct address_space___354 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___356 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___172 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___355 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___354 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___354 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___355;

struct dentry_operations___354 {
	int (*d_revalidate)(struct dentry___354 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___354 *, unsigned int);
	int (*d_hash)(const struct dentry___354 *, struct qstr *);
	int (*d_compare)(const struct dentry___354 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___354 *);
	int (*d_init)(struct dentry___354 *);
	void (*d_release)(struct dentry___354 *);
	void (*d_prune)(struct dentry___354 *);
	void (*d_iput)(struct dentry___354 *, struct inode___355 *);
	char * (*d_dname)(struct dentry___354 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___355 *);
	int (*d_manage)(const struct path___355 *, bool);
	struct dentry___354 * (*d_real)(struct dentry___354 *, const struct inode___355 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___354;

struct mem_dqinfo___354 {
	struct quota_format_type___354 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___354;

struct quota_info___354 {
	unsigned int flags;
	struct rw_semaphore___356 dqio_sem;
	struct inode___355 *files[3];
	struct mem_dqinfo___354 info[3];
	const struct quota_format_ops___354 *ops[3];
};

struct rcuwait___354 {
	struct task_struct___356 *task;
};

struct percpu_rw_semaphore___354 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___356 rw_sem;
	struct rcuwait___354 writer;
	int readers_block;
};

struct sb_writers___354 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___354 rw_sem[3];
};

struct file_system_type___354;

struct super_operations___354;

struct dquot_operations___354;

struct quotactl_ops___354;

struct super_block___354 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___354 *s_type;
	const struct super_operations___354 *s_op;
	const struct dquot_operations___354 *dq_op;
	const struct quotactl_ops___354 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___354 *s_root;
	struct rw_semaphore___356 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___354 *s_bdev;
	struct backing_dev_info___172 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___354 s_dquot;
	struct sb_writers___354 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___354 *s_d_op;
	int cleancache_poolid;
	struct shrinker___131 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct path___355 {
	struct vfsmount *mnt;
	struct dentry___354 *dentry;
};

typedef struct page___356 *pgtable_t___355;

struct dev_pagemap___343;

struct page___356 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___354 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___356 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___355 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___355 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___343 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___355;

struct lruvec___355 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___355 *pgdat;
};

struct zone___355 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___355 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___355 {
	struct zone___355 *zone;
	int zone_idx;
};

struct zonelist___355 {
	struct zoneref___355 _zonerefs[25];
};

struct pglist_data___355 {
	struct zone___355 node_zones[3];
	struct zonelist___355 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___356 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___356 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___355 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___356 {
	void *stack;
	struct task_struct___356 *task;
	long int status;
};

struct blocking_notifier_head___355 {
	struct rw_semaphore___356 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___343;

struct vm_area_struct___356 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___356 *vm_next;
	struct vm_area_struct___356 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___355 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___343 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___355 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___355;

struct mm_struct___355 {
	struct {
		struct vm_area_struct___356 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___355 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___356 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___355 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___356 *owner;
		struct user_namespace___3 *user_ns;
		struct file___355 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___355 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___343)(struct vm_area_struct___356 *, long unsigned int, const struct page___356 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___343)(struct page___356 *, void *);

struct device___322;

struct dev_pagemap___343 {
	dev_page_fault_t___343 page_fault;
	dev_page_free_t___343 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___322 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct file___355 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___355 f_path;
	struct inode___355 *f_inode;
	const struct file_operations___355 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___216 f_owner;
	const struct cred___329 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___354 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___343;

struct vm_operations_struct___343 {
	void (*open)(struct vm_area_struct___356 *);
	void (*close)(struct vm_area_struct___356 *);
	int (*split)(struct vm_area_struct___356 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___356 *);
	vm_fault_t (*fault)(struct vm_fault___343 *);
	vm_fault_t (*huge_fault)(struct vm_fault___343 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___343 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___356 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___343 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___343 *);
	int (*access)(struct vm_area_struct___356 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___356 *);
	int (*set_policy)(struct vm_area_struct___356 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___356 *, long unsigned int);
	struct page___356 * (*find_special_page)(struct vm_area_struct___356 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___355 {
	struct task_struct___356 *task;
	struct core_thread___355 *next;
};

struct core_state___355 {
	atomic_t nr_threads;
	struct core_thread___355 dumper;
	struct completion startup;
};

struct vm_fault___343 {
	struct vm_area_struct___356 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___356 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___356 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___355 prealloc_pte;
};

struct key___329;

struct user_struct___329 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___329 *uid_keyring;
	struct key___329 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___329 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___329 *session_keyring;
	struct key___329 *process_keyring;
	struct key___329 *thread_keyring;
	struct key___329 *request_key_auth;
	void *security;
	struct user_struct___329 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct bio___172;

struct bio_list___172 {
	struct bio___172 *head;
	struct bio___172 *tail;
};

struct bdi_writeback_congested___172;

struct bdi_writeback___172 {
	struct backing_dev_info___172 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___172 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___157 *memcg_css;
	struct cgroup_subsys_state___157 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___172 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___172 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___322 *dev;
	struct device___322 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___354 *debug_dir;
	struct dentry___354 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___92;

struct io_context___92 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___92 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

typedef blk_qc_t make_request_fn___88(struct request_queue___88 *, struct bio___172 *);

struct request___88;

typedef int dma_drain_needed_fn___88(struct request___88 *);

struct kset___341;

struct kobj_type___341;

struct kernfs_node___349;

struct kobject___342 {
	const char *name;
	struct list_head entry;
	struct kobject___342 *parent;
	struct kset___341 *kset;
	struct kobj_type___341 *ktype;
	struct kernfs_node___349 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___88;

struct bsg_class_device___88 {
	struct device___322 *class_dev;
	int minor;
	struct request_queue___88 *queue;
	const struct bsg_ops___88 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___172 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___172 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___88;

struct blk_mq_ops___25;

struct blk_mq_hw_ctx___25;

struct blk_mq_tag_set___25;

struct request_queue___88 {
	struct list_head queue_head;
	struct request___88 *last_merge;
	struct elevator_queue___88 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___88 *make_request_fn;
	dma_drain_needed_fn___88 *dma_drain_needed;
	const struct blk_mq_ops___25 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___25 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___172 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___342 kobj;
	struct kobject___342 *mq_kobj;
	struct blk_integrity integrity;
	struct device___322 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	struct bsg_class_device___88 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set___25 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___172 bio_split;
	struct dentry___354 *debugfs_dir;
	struct dentry___354 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___261 {
	struct vm_struct___261 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___356 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct io_cq___92 {
	struct request_queue___88 *q;
	struct io_context___92 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___355 {
	struct file___355 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___355 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___354 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___355 *ia_file;
};

struct dquot___354 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___354 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___354 {
	int qf_fmt_id;
	const struct quota_format_ops___354 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___354 *qf_next;
};

struct quota_format_ops___354 {
	int (*check_quota_file)(struct super_block___354 *, int);
	int (*read_file_info)(struct super_block___354 *, int);
	int (*write_file_info)(struct super_block___354 *, int);
	int (*free_file_info)(struct super_block___354 *, int);
	int (*read_dqblk)(struct dquot___354 *);
	int (*commit_dqblk)(struct dquot___354 *);
	int (*release_dqblk)(struct dquot___354 *);
	int (*get_next_id)(struct super_block___354 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___354 {
	int (*write_dquot)(struct dquot___354 *);
	struct dquot___354 * (*alloc_dquot)(struct super_block___354 *, int);
	void (*destroy_dquot)(struct dquot___354 *);
	int (*acquire_dquot)(struct dquot___354 *);
	int (*release_dquot)(struct dquot___354 *);
	int (*mark_dirty)(struct dquot___354 *);
	int (*write_info)(struct super_block___354 *, int);
	qsize_t * (*get_reserved_space)(struct inode___355 *);
	int (*get_projid)(struct inode___355 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___355 *, qsize_t *);
	int (*get_next_id)(struct super_block___354 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___354 {
	int (*quota_on)(struct super_block___354 *, int, int, const struct path___355 *);
	int (*quota_off)(struct super_block___354 *, int);
	int (*quota_enable)(struct super_block___354 *, unsigned int);
	int (*quota_disable)(struct super_block___354 *, unsigned int);
	int (*quota_sync)(struct super_block___354 *, int);
	int (*set_info)(struct super_block___354 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___354 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___354 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___354 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___354 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___354 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___354 {
	int (*writepage)(struct page___356 *, struct writeback_control___3 *);
	int (*readpage)(struct file___355 *, struct page___356 *);
	int (*writepages)(struct address_space___354 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___356 *);
	int (*readpages)(struct file___355 *, struct address_space___354 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___355 *, struct address_space___354 *, loff_t, unsigned int, unsigned int, struct page___356 **, void **);
	int (*write_end)(struct file___355 *, struct address_space___354 *, loff_t, unsigned int, unsigned int, struct page___356 *, void *);
	sector_t (*bmap)(struct address_space___354 *, sector_t);
	void (*invalidatepage)(struct page___356 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___356 *, gfp_t);
	void (*freepage)(struct page___356 *);
	ssize_t (*direct_IO)(struct kiocb___355 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___354 *, struct page___356 *, struct page___356 *, enum migrate_mode);
	bool (*isolate_page)(struct page___356 *, isolate_mode_t);
	void (*putback_page)(struct page___356 *);
	int (*launder_page)(struct page___356 *);
	int (*is_partially_uptodate)(struct page___356 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___356 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___354 *, struct page___356 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___355 *, sector_t *);
	void (*swap_deactivate)(struct file___355 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct hd_struct___92;

struct gendisk___92;

struct block_device___354 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___355 *bd_inode;
	struct super_block___354 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___354 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___92 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___92 *bd_disk;
	struct request_queue___88 *bd_queue;
	struct backing_dev_info___172 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___322 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___5 *subsys_data;
	void (*set_latency_tolerance)(struct device___322 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___322;

struct bus_type___322;

struct device_driver___322;

struct dev_pm_domain___322;

struct dma_map_ops___111;

struct fwnode_handle___244;

struct class___322;

struct attribute_group___319;

struct device___322 {
	struct device___322 *parent;
	struct device_private *p;
	struct kobject___342 kobj;
	const char *init_name;
	const struct device_type___322 *type;
	struct mutex mutex;
	struct bus_type___322 *bus;
	struct device_driver___322 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___322 power;
	struct dev_pm_domain___322 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___111 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___244 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___322 *class;
	const struct attribute_group___319 **groups;
	void (*release)(struct device___322 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___92 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___322 __dev;
	struct kobject___342 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___92;

struct block_device_operations___89;

struct gendisk___92 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___92 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___92 *part_tbl;
	struct hd_struct___92 part0;
	const struct block_device_operations___89 *fops;
	struct request_queue___88 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___356 lookup_sem;
	struct kobject___342 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___342 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___354 {
	struct dentry___354 * (*lookup)(struct inode___355 *, struct dentry___354 *, unsigned int);
	const char * (*get_link)(struct dentry___354 *, struct inode___355 *, struct delayed_call *);
	int (*permission)(struct inode___355 *, int);
	struct posix_acl * (*get_acl)(struct inode___355 *, int);
	int (*readlink)(struct dentry___354 *, char *, int);
	int (*create)(struct inode___355 *, struct dentry___354 *, umode_t, bool);
	int (*link)(struct dentry___354 *, struct inode___355 *, struct dentry___354 *);
	int (*unlink)(struct inode___355 *, struct dentry___354 *);
	int (*symlink)(struct inode___355 *, struct dentry___354 *, const char *);
	int (*mkdir)(struct inode___355 *, struct dentry___354 *, umode_t);
	int (*rmdir)(struct inode___355 *, struct dentry___354 *);
	int (*mknod)(struct inode___355 *, struct dentry___354 *, umode_t, dev_t);
	int (*rename)(struct inode___355 *, struct dentry___354 *, struct inode___355 *, struct dentry___354 *, unsigned int);
	int (*setattr)(struct dentry___354 *, struct iattr___354 *);
	int (*getattr)(const struct path___355 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___354 *, char *, size_t);
	int (*fiemap)(struct inode___355 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___355 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___355 *, struct dentry___354 *, struct file___355 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___355 *, struct dentry___354 *, umode_t);
	int (*set_acl)(struct inode___355 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___354 {
	void (*fl_copy_lock)(struct file_lock___355 *, struct file_lock___355 *);
	void (*fl_release_private)(struct file_lock___355 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___354;

struct lock_manager_operations___354;

struct file_lock___355 {
	struct file_lock___355 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___355 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___354 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___354 *fl_ops;
	const struct lock_manager_operations___354 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___354 {
	int (*lm_compare_owner)(struct file_lock___355 *, struct file_lock___355 *);
	long unsigned int (*lm_owner_key)(struct file_lock___355 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___355 *);
	int (*lm_grant)(struct file_lock___355 *, int);
	bool (*lm_break)(struct file_lock___355 *);
	int (*lm_change)(struct file_lock___355 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___355 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___354 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___354 *fa_next;
	struct file___355 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___354 {
	const char *name;
	int fs_flags;
	struct dentry___354 * (*mount)(struct file_system_type___354 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___354 *);
	struct module___11 *owner;
	struct file_system_type___354 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___354 {
	struct inode___355 * (*alloc_inode)(struct super_block___354 *);
	void (*destroy_inode)(struct inode___355 *);
	void (*dirty_inode)(struct inode___355 *, int);
	int (*write_inode)(struct inode___355 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___355 *);
	void (*evict_inode)(struct inode___355 *);
	void (*put_super)(struct super_block___354 *);
	int (*sync_fs)(struct super_block___354 *, int);
	int (*freeze_super)(struct super_block___354 *);
	int (*freeze_fs)(struct super_block___354 *);
	int (*thaw_super)(struct super_block___354 *);
	int (*unfreeze_fs)(struct super_block___354 *);
	int (*statfs)(struct dentry___354 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___354 *, int *, char *);
	void (*umount_begin)(struct super_block___354 *);
	int (*show_options)(struct seq_file___302 *, struct dentry___354 *);
	int (*show_devname)(struct seq_file___302 *, struct dentry___354 *);
	int (*show_path)(struct seq_file___302 *, struct dentry___354 *);
	int (*show_stats)(struct seq_file___302 *, struct dentry___354 *);
	ssize_t (*quota_read)(struct super_block___354 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___354 *, int, const char *, size_t, loff_t);
	struct dquot___354 ** (*get_dquots)(struct inode___355 *);
	int (*bdev_try_to_free_page)(struct super_block___354 *, struct page___356 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___354 *, struct shrink_control___131 *);
	long int (*free_cached_objects)(struct super_block___354 *, struct shrink_control___131 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___301;

struct seq_file___302 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___301 *op;
	int poll_event;
	const struct file___355 *file;
	void *private;
};

typedef void bio_end_io_t___172(struct bio___172 *);

struct bio_vec___174 {
	struct page___356 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___172;

struct bio___172 {
	struct bio___172 *bi_next;
	struct gendisk___92 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___172 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___172 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___174 *bi_io_vec;
	struct bio_set___172 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___174 bi_inline_vecs[0];
};

typedef int (*key_restrict_link_func_t___330)(struct key___329 *, const struct key_type *, const union key_payload *, struct key___329 *);

struct key_restriction___329;

struct key___329 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___356 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___329 *restrict_link;
};

struct key_restriction___329 {
	key_restrict_link_func_t___330 check;
	struct key___329 *key;
	struct key_type *keytype;
};

struct seq_operations___301 {
	void * (*start)(struct seq_file___302 *, loff_t *);
	void (*stop)(struct seq_file___302 *, void *);
	void * (*next)(struct seq_file___302 *, void *, loff_t *);
	int (*show)(struct seq_file___302 *, void *);
};

struct kernfs_root___348;

struct kernfs_elem_dir___348 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___348 *root;
};

struct kernfs_syscall_ops___348;

struct kernfs_root___348 {
	struct kernfs_node___349 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___348 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___348 {
	struct kernfs_node___349 *target_kn;
};

struct kernfs_ops___348;

struct kernfs_elem_attr___348 {
	const struct kernfs_ops___348 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___349 *notify_next;
};

struct kernfs_node___349 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___349 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___348 dir;
		struct kernfs_elem_symlink___348 symlink;
		struct kernfs_elem_attr___348 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___348;

struct kernfs_ops___348 {
	int (*open)(struct kernfs_open_file___348 *);
	void (*release)(struct kernfs_open_file___348 *);
	int (*seq_show)(struct seq_file___302 *, void *);
	void * (*seq_start)(struct seq_file___302 *, loff_t *);
	void * (*seq_next)(struct seq_file___302 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___302 *, void *);
	ssize_t (*read)(struct kernfs_open_file___348 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___348 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___348 *, struct vm_area_struct___356 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___348 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___348 {
	int (*remount_fs)(struct kernfs_root___348 *, int *, char *);
	int (*show_options)(struct seq_file___302 *, struct kernfs_root___348 *);
	int (*mkdir)(struct kernfs_node___349 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___349 *);
	int (*rename)(struct kernfs_node___349 *, struct kernfs_node___349 *, const char *);
	int (*show_path)(struct seq_file___302 *, struct kernfs_node___349 *, struct kernfs_root___348 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___348 {
	struct kernfs_node___349 *kn;
	struct file___355 *file;
	struct seq_file___302 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___343 *vm_ops;
};

struct bin_attribute___318;

struct attribute_group___319 {
	const char *name;
	umode_t (*is_visible)(struct kobject___342 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___342 *, struct bin_attribute___318 *, int);
	struct attribute **attrs;
	struct bin_attribute___318 **bin_attrs;
};

struct bin_attribute___318 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___355 *, struct kobject___342 *, struct bin_attribute___318 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___355 *, struct kobject___342 *, struct bin_attribute___318 *, char *, loff_t, size_t);
	int (*mmap)(struct file___355 *, struct kobject___342 *, struct bin_attribute___318 *, struct vm_area_struct___356 *);
};

struct sysfs_ops___341 {
	ssize_t (*show)(struct kobject___342 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___342 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___341;

struct kset___341 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___342 kobj;
	const struct kset_uevent_ops___341 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___341 {
	void (*release)(struct kobject___342 *);
	const struct sysfs_ops___341 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___28 * (*child_ns_type)(struct kobject___342 *);
	const void * (*namespace)(struct kobject___342 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___341 {
	int (* const filter)(struct kset___341 *, struct kobject___342 *);
	const char * (* const name)(struct kset___341 *, struct kobject___342 *);
	int (* const uevent)(struct kset___341 *, struct kobject___342 *, struct kobj_uevent_env *);
};

struct kobj_attribute___333 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___342 *, struct kobj_attribute___333 *, char *);
	ssize_t (*store)(struct kobject___342 *, struct kobj_attribute___333 *, const char *, size_t);
};

struct dev_pm_ops___322 {
	int (*prepare)(struct device___322 *);
	void (*complete)(struct device___322 *);
	int (*suspend)(struct device___322 *);
	int (*resume)(struct device___322 *);
	int (*freeze)(struct device___322 *);
	int (*thaw)(struct device___322 *);
	int (*poweroff)(struct device___322 *);
	int (*restore)(struct device___322 *);
	int (*suspend_late)(struct device___322 *);
	int (*resume_early)(struct device___322 *);
	int (*freeze_late)(struct device___322 *);
	int (*thaw_early)(struct device___322 *);
	int (*poweroff_late)(struct device___322 *);
	int (*restore_early)(struct device___322 *);
	int (*suspend_noirq)(struct device___322 *);
	int (*resume_noirq)(struct device___322 *);
	int (*freeze_noirq)(struct device___322 *);
	int (*thaw_noirq)(struct device___322 *);
	int (*poweroff_noirq)(struct device___322 *);
	int (*restore_noirq)(struct device___322 *);
	int (*runtime_suspend)(struct device___322 *);
	int (*runtime_resume)(struct device___322 *);
	int (*runtime_idle)(struct device___322 *);
};

struct dev_pm_domain___322 {
	struct dev_pm_ops___322 ops;
	void (*detach)(struct device___322 *, bool);
	int (*activate)(struct device___322 *);
	void (*sync)(struct device___322 *);
	void (*dismiss)(struct device___322 *);
};

struct bus_type___322 {
	const char *name;
	const char *dev_name;
	struct device___322 *dev_root;
	const struct attribute_group___319 **bus_groups;
	const struct attribute_group___319 **dev_groups;
	const struct attribute_group___319 **drv_groups;
	int (*match)(struct device___322 *, struct device_driver___322 *);
	int (*uevent)(struct device___322 *, struct kobj_uevent_env *);
	int (*probe)(struct device___322 *);
	int (*remove)(struct device___322 *);
	void (*shutdown)(struct device___322 *);
	int (*online)(struct device___322 *);
	int (*offline)(struct device___322 *);
	int (*suspend)(struct device___322 *, pm_message_t);
	int (*resume)(struct device___322 *);
	int (*num_vf)(struct device___322 *);
	int (*dma_configure)(struct device___322 *);
	const struct dev_pm_ops___322 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___322 {
	const char *name;
	struct bus_type___322 *bus;
	struct module___11 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___322 *);
	int (*remove)(struct device___322 *);
	void (*shutdown)(struct device___322 *);
	int (*suspend)(struct device___322 *, pm_message_t);
	int (*resume)(struct device___322 *);
	const struct attribute_group___319 **groups;
	const struct dev_pm_ops___322 *pm;
	void (*coredump)(struct device___322 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___322 {
	const char *name;
	const struct attribute_group___319 **groups;
	int (*uevent)(struct device___322 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___322 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___322 *);
	const struct dev_pm_ops___322 *pm;
};

struct class___322 {
	const char *name;
	struct module___11 *owner;
	const struct attribute_group___319 **class_groups;
	const struct attribute_group___319 **dev_groups;
	struct kobject___342 *dev_kobj;
	int (*dev_uevent)(struct device___322 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___322 *, umode_t *);
	void (*class_release)(struct class___322 *);
	void (*dev_release)(struct device___322 *);
	int (*shutdown_pre)(struct device___322 *);
	const struct kobj_ns_type_operations___28 *ns_type;
	const void * (*namespace)(struct device___322 *);
	const struct dev_pm_ops___322 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___111 {
	void * (*alloc)(struct device___322 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___322 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___322 *, struct vm_area_struct___356 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___322 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___322 *, struct page___356 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___322 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___322 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___322 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___322 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___322 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___322 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___322 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___322 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___322 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___322 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___322 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___322 *, u64);
	u64 (*get_required_mask)(struct device___322 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___244;

struct fwnode_handle___244 {
	struct fwnode_handle___244 *secondary;
	const struct fwnode_operations___244 *ops;
};

typedef void compound_page_dtor___343(struct page___356 *);

struct fwnode_reference_args___244;

struct fwnode_endpoint___244;

struct fwnode_operations___244 {
	struct fwnode_handle___244 * (*get)(struct fwnode_handle___244 *);
	void (*put)(struct fwnode_handle___244 *);
	bool (*device_is_available)(const struct fwnode_handle___244 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___244 *, const struct device___322 *);
	bool (*property_present)(const struct fwnode_handle___244 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___244 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___244 *, const char *, const char **, size_t);
	struct fwnode_handle___244 * (*get_parent)(const struct fwnode_handle___244 *);
	struct fwnode_handle___244 * (*get_next_child_node)(const struct fwnode_handle___244 *, struct fwnode_handle___244 *);
	struct fwnode_handle___244 * (*get_named_child_node)(const struct fwnode_handle___244 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___244 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___244 *);
	struct fwnode_handle___244 * (*graph_get_next_endpoint)(const struct fwnode_handle___244 *, struct fwnode_handle___244 *);
	struct fwnode_handle___244 * (*graph_get_remote_endpoint)(const struct fwnode_handle___244 *);
	struct fwnode_handle___244 * (*graph_get_port_parent)(struct fwnode_handle___244 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___244 *, struct fwnode_endpoint___244 *);
};

struct fwnode_endpoint___244 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___244 *local_fwnode;
};

struct fwnode_reference_args___244 {
	struct fwnode_handle___244 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct bio_integrity_payload___172 {
	struct bio___172 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___174 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___174 bip_inline_vecs[0];
};

struct disk_part_tbl___92 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___92 *last_lookup;
	struct hd_struct___92 *part[0];
};

struct block_device_operations___89 {
	int (*open)(struct block_device___354 *, fmode_t);
	void (*release)(struct gendisk___92 *, fmode_t);
	int (*rw_page)(struct block_device___354 *, sector_t, struct page___356 *, unsigned int);
	int (*ioctl)(struct block_device___354 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___354 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___92 *, unsigned int);
	int (*media_changed)(struct gendisk___92 *);
	void (*unlock_native_capacity)(struct gendisk___92 *);
	int (*revalidate_disk)(struct gendisk___92 *);
	int (*getgeo)(struct block_device___354 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___354 *, long unsigned int);
	int (*report_zones)(struct gendisk___92 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___11 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bdi_writeback_congested___172 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___172 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bsg_ops___88 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___88 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___88 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___88 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___88(struct request___88 *, blk_status_t);

struct request___88 {
	struct request_queue___88 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___25 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___172 *bio;
	struct bio___172 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___174 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___92 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___88 *saved_end_io;
		} flush;
	};
	struct gendisk___92 *rq_disk;
	struct hd_struct___92 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___88 *end_io;
	void *end_io_data;
	struct request___88 *next_rq;
};

struct blk_mq_hw_ctx___25 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___88 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags___4 *tags;
	struct blk_mq_tags___4 *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	unsigned int rh_reserved_nr_expired;
	struct hlist_node cpuhp_dead;
	struct kobject___342 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___354 *debugfs_dir;
	struct dentry___354 *sched_debugfs_dir;
	struct list_head hctx_list;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___88;

struct elevator_mq_ops___88 {
	int (*init_sched)(struct request_queue___88 *, struct elevator_type___88 *);
	void (*exit_sched)(struct elevator_queue___88 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___25 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___25 *, unsigned int);
	bool (*allow_merge)(struct request_queue___88 *, struct request___88 *, struct bio___172 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx___25 *, struct bio___172 *);
	int (*request_merge)(struct request_queue___88 *, struct request___88 **, struct bio___172 *);
	void (*request_merged)(struct request_queue___88 *, struct request___88 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___88 *, struct request___88 *, struct request___88 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___88 *, struct bio___172 *);
	void (*finish_request)(struct request___88 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___25 *, struct list_head *, bool);
	struct request___88 * (*dispatch_request)(struct blk_mq_hw_ctx___25 *);
	bool (*has_work)(struct blk_mq_hw_ctx___25 *);
	void (*completed_request)(struct request___88 *, u64);
	void (*started_request)(struct request___88 *);
	void (*requeue_request)(struct request___88 *);
	struct request___88 * (*former_request)(struct request_queue___88 *, struct request___88 *);
	struct request___88 * (*next_request)(struct request_queue___88 *, struct request___88 *);
	void (*init_icq)(struct io_cq___92 *);
	void (*exit_icq)(struct io_cq___92 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx___25 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___88;

struct elevator_type___88 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___88 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___88 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___11 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___88 {
	struct elevator_type___88 *type;
	void *elevator_data;
	struct kobject___342 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___88 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___88 *, char *);
	ssize_t (*store)(struct elevator_queue___88 *, const char *, size_t);
};

struct blk_mq_queue_data___25;

typedef blk_status_t queue_rq_fn___25(struct blk_mq_hw_ctx___25 *, const struct blk_mq_queue_data___25 *);

typedef void commit_rqs_fn___25(struct blk_mq_hw_ctx___25 *);

typedef bool get_budget_fn___25(struct blk_mq_hw_ctx___25 *);

typedef void put_budget_fn___25(struct blk_mq_hw_ctx___25 *);

typedef enum blk_eh_timer_return timeout_fn___25(struct request___88 *, bool);

typedef int poll_fn___25(struct blk_mq_hw_ctx___25 *);

typedef void complete_fn___25(struct request___88 *);

typedef int init_hctx_fn___25(struct blk_mq_hw_ctx___25 *, void *, unsigned int);

typedef void exit_hctx_fn___25(struct blk_mq_hw_ctx___25 *, unsigned int);

typedef int init_request_fn___25(struct blk_mq_tag_set___25 *, struct request___88 *, unsigned int, unsigned int);

typedef void exit_request_fn___25(struct blk_mq_tag_set___25 *, struct request___88 *, unsigned int);

typedef bool busy_fn___25(struct request_queue___88 *);

typedef int map_queues_fn___25(struct blk_mq_tag_set___25 *);

typedef void cleanup_rq_fn___25(struct request___88 *);

struct blk_mq_ops___25 {
	queue_rq_fn___25 *queue_rq;
	commit_rqs_fn___25 *commit_rqs;
	get_budget_fn___25 *get_budget;
	put_budget_fn___25 *put_budget;
	timeout_fn___25 *timeout;
	poll_fn___25 *poll;
	complete_fn___25 *complete;
	init_hctx_fn___25 *init_hctx;
	exit_hctx_fn___25 *exit_hctx;
	init_request_fn___25 *init_request;
	exit_request_fn___25 *exit_request;
	void (*initialize_rq_fn)(struct request___88 *);
	busy_fn___25 *busy;
	map_queues_fn___25 *map_queues;
	void (*show_rq)(struct seq_file___302 *, struct request___88 *);
	union {
		cleanup_rq_fn___25 *cleanup_rq;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide45;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct blk_mq_tag_set___25 {
	struct blk_mq_queue_map map[6];
	unsigned int nr_maps;
	const struct blk_mq_ops___25 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	struct blk_mq_tags___4 **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct scsi_target___7;

struct scsi_device___7 {
	struct Scsi_Host___5 *host;
	struct request_queue___88 *request_queue;
	struct list_head siblings;
	struct list_head same_target_siblings;
	atomic_t device_busy;
	atomic_t device_blocked;
	spinlock_t list_lock;
	struct list_head cmd_list;
	struct list_head starved_entry;
	short unsigned int queue_depth;
	short unsigned int max_queue_depth;
	short unsigned int last_queue_full_depth;
	short unsigned int last_queue_full_count;
	long unsigned int last_queue_full_time;
	long unsigned int queue_ramp_up_period;
	long unsigned int last_queue_ramp_up;
	unsigned int id;
	unsigned int channel;
	u64 lun;
	unsigned int manufacturer;
	unsigned int sector_size;
	void *hostdata;
	unsigned char type;
	char scsi_level;
	char inq_periph_qual;
	struct mutex inquiry_mutex;
	unsigned char inquiry_len;
	unsigned char *inquiry;
	const char *vendor;
	const char *model;
	const char *rev;
	struct scsi_vpd *vpd_pg83;
	struct scsi_vpd *vpd_pg80;
	unsigned char current_tag;
	struct scsi_target___7 *sdev_target;
	blist_flags_t sdev_bflags;
	unsigned int eh_timeout;
	unsigned int removable: 1;
	unsigned int changed: 1;
	unsigned int busy: 1;
	unsigned int lockable: 1;
	unsigned int locked: 1;
	unsigned int borken: 1;
	unsigned int disconnect: 1;
	unsigned int soft_reset: 1;
	unsigned int sdtr: 1;
	unsigned int wdtr: 1;
	unsigned int ppr: 1;
	unsigned int tagged_supported: 1;
	unsigned int simple_tags: 1;
	unsigned int was_reset: 1;
	unsigned int expecting_cc_ua: 1;
	unsigned int use_10_for_rw: 1;
	unsigned int use_10_for_ms: 1;
	unsigned int no_report_opcodes: 1;
	unsigned int no_write_same: 1;
	unsigned int use_16_for_rw: 1;
	unsigned int skip_ms_page_8: 1;
	unsigned int skip_ms_page_3f: 1;
	unsigned int skip_vpd_pages: 1;
	unsigned int try_vpd_pages: 1;
	unsigned int use_192_bytes_for_3f: 1;
	unsigned int no_start_on_add: 1;
	unsigned int allow_restart: 1;
	unsigned int manage_start_stop: 1;
	unsigned int start_stop_pwr_cond: 1;
	unsigned int no_uld_attach: 1;
	unsigned int select_no_atn: 1;
	unsigned int fix_capacity: 1;
	unsigned int guess_capacity: 1;
	unsigned int retry_hwerror: 1;
	unsigned int last_sector_bug: 1;
	unsigned int no_read_disc_info: 1;
	unsigned int no_read_capacity_16: 1;
	unsigned int try_rc_10_first: 1;
	unsigned int security_supported: 1;
	unsigned int is_visible: 1;
	unsigned int wce_default_on: 1;
	unsigned int no_dif: 1;
	unsigned int broken_fua: 1;
	unsigned int lun_in_cdb: 1;
	unsigned int unmap_limit_for_ws: 1;
	atomic_t disk_events_disable_depth;
	long unsigned int supported_events[1];
	long unsigned int pending_events[1];
	struct list_head event_list;
	struct work_struct event_work;
	unsigned int max_device_blocked;
	atomic_t iorequest_cnt;
	atomic_t iodone_cnt;
	atomic_t ioerr_cnt;
	struct device___322 sdev_gendev;
	struct device___322 sdev_dev;
	struct execute_work ew;
	struct work_struct requeue_work;
	struct scsi_device_handler *handler;
	void *handler_data;
	unsigned char access_state;
	struct mutex state_mutex;
	enum scsi_device_state sdev_state;
	struct task_struct___356 *quiesced_by;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int sdev_data[0];
};

struct scsi_target___7 {
	struct scsi_device___7 *starget_sdev_user;
	struct list_head siblings;
	struct list_head devices;
	struct device___322 dev;
	struct kref reap_ref;
	unsigned int channel;
	unsigned int id;
	unsigned int create: 1;
	unsigned int single_lun: 1;
	unsigned int pdt_1f_for_no_lun: 1;
	unsigned int no_report_luns: 1;
	unsigned int expecting_lun_change: 1;
	atomic_t target_busy;
	atomic_t target_blocked;
	unsigned int can_queue;
	unsigned int max_target_blocked;
	char scsi_level;
	enum scsi_target_state state;
	void *hostdata;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int starget_data[0];
};

struct blk_mq_queue_data___25 {
	struct request___88 *rq;
	bool last;
	long unsigned int rh_reserved1;
};

struct scsi_cmnd___5 {
	struct scsi_request req;
	struct scsi_device___7 *device;
	struct list_head list;
	struct list_head eh_entry;
	struct delayed_work abort_work;
	struct callback_head rcu;
	int eh_eflags;
	long unsigned int serial_number;
	long unsigned int jiffies_at_alloc;
	int retries;
	int allowed;
	unsigned char prot_op;
	unsigned char prot_type;
	unsigned char prot_flags;
	short unsigned int cmd_len;
	enum dma_data_direction sc_data_direction;
	unsigned char *cmnd;
	struct scsi_data_buffer sdb;
	struct scsi_data_buffer *prot_sdb;
	unsigned int underflow;
	unsigned int transfersize;
	struct request___88 *request;
	unsigned char *sense_buffer;
	void (*scsi_done)(struct scsi_cmnd___5 *);
	struct scsi_pointer SCp;
	unsigned char *host_scribble;
	int result;
	int flags;
	long unsigned int state;
	unsigned char tag;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct file___356;

struct kiocb___356;

struct vm_area_struct___357;

struct inode___356;

struct file_lock___356;

struct page___357;

struct seq_file___303;

struct file_operations___356 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___356 *, loff_t, int);
	ssize_t (*read)(struct file___356 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___356 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___356 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___356 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___356 *, bool);
	int (*iterate)(struct file___356 *, struct dir_context *);
	int (*iterate_shared)(struct file___356 *, struct dir_context *);
	__poll_t (*poll)(struct file___356 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___356 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___356 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___356 *, struct vm_area_struct___357 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___356 *, struct file___356 *);
	int (*flush)(struct file___356 *, fl_owner_t);
	int (*release)(struct inode___356 *, struct file___356 *);
	int (*fsync)(struct file___356 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___356 *, int);
	int (*lock)(struct file___356 *, int, struct file_lock___356 *);
	ssize_t (*sendpage)(struct file___356 *, struct page___357 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___356 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___356 *, int, struct file_lock___356 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___356 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___356 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___356 *, long int, struct file_lock___356 **, void **);
	long int (*fallocate)(struct file___356 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___303 *, struct file___356 *);
	ssize_t (*copy_file_range)(struct file___356 *, loff_t, struct file___356 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___356 *, loff_t, struct file___356 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___356 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___356 {
	u64 seqnum;
	struct vm_area_struct___357 *vmas[4];
};

struct page_frag___356 {
	struct page___357 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___356;

struct cred___330;

struct bio_list___173;

struct backing_dev_info___173;

struct io_context___93;

struct request_queue___89;

struct vm_struct___262;

struct task_struct___357 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___357 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___356 *mm;
	struct mm_struct___356 *active_mm;
	struct vmacache___356 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___357 *real_parent;
	struct task_struct___357 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___357 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___216 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___216 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___216 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___330 *ptracer_cred;
	const struct cred___330 *real_cred;
	const struct cred___330 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___357 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___173 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___173 *backing_dev_info;
	struct io_context___93 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___356 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___89 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___357 *oom_reaper_list;
	struct vm_struct___262 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___140 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___355;

struct super_block___355;

struct dentry___355 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___355 *d_parent;
	struct qstr d_name;
	struct inode___356 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___355 *d_op;
	struct super_block___355 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct rw_semaphore___357 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___357 *owner;
};

struct address_space_operations___355;

struct address_space___355 {
	struct inode___356 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___357 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___355 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___355;

struct bdi_writeback___173;

struct block_device___355;

struct inode___356 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___355 *i_op;
	struct super_block___355 *i_sb;
	struct address_space___355 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___357 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___173 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___356 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___355 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___355 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___356;

struct dentry_operations___355 {
	int (*d_revalidate)(struct dentry___355 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___355 *, unsigned int);
	int (*d_hash)(const struct dentry___355 *, struct qstr *);
	int (*d_compare)(const struct dentry___355 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___355 *);
	int (*d_init)(struct dentry___355 *);
	void (*d_release)(struct dentry___355 *);
	void (*d_prune)(struct dentry___355 *);
	void (*d_iput)(struct dentry___355 *, struct inode___356 *);
	char * (*d_dname)(struct dentry___355 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___356 *);
	int (*d_manage)(const struct path___356 *, bool);
	struct dentry___355 * (*d_real)(struct dentry___355 *, const struct inode___356 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___355;

struct mem_dqinfo___355 {
	struct quota_format_type___355 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___355;

struct quota_info___355 {
	unsigned int flags;
	struct rw_semaphore___357 dqio_sem;
	struct inode___356 *files[3];
	struct mem_dqinfo___355 info[3];
	const struct quota_format_ops___355 *ops[3];
};

struct rcuwait___355 {
	struct task_struct___357 *task;
};

struct percpu_rw_semaphore___355 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___357 rw_sem;
	struct rcuwait___355 writer;
	int readers_block;
};

struct sb_writers___355 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___355 rw_sem[3];
};

struct file_system_type___355;

struct super_operations___355;

struct dquot_operations___355;

struct quotactl_ops___355;

struct super_block___355 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___355 *s_type;
	const struct super_operations___355 *s_op;
	const struct dquot_operations___355 *dq_op;
	const struct quotactl_ops___355 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___355 *s_root;
	struct rw_semaphore___357 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___355 *s_bdev;
	struct backing_dev_info___173 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___355 s_dquot;
	struct sb_writers___355 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___355 *s_d_op;
	int cleancache_poolid;
	struct shrinker___131 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct path___356 {
	struct vfsmount *mnt;
	struct dentry___355 *dentry;
};

typedef struct page___357 *pgtable_t___356;

struct dev_pagemap___344;

struct page___357 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___355 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___357 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___356 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___356 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___344 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___356;

struct lruvec___356 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___356 *pgdat;
};

struct zone___356 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___356 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___356 {
	struct zone___356 *zone;
	int zone_idx;
};

struct zonelist___356 {
	struct zoneref___356 _zonerefs[25];
};

struct pglist_data___356 {
	struct zone___356 node_zones[3];
	struct zonelist___356 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___357 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___357 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___356 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___357 {
	void *stack;
	struct task_struct___357 *task;
	long int status;
};

struct blocking_notifier_head___356 {
	struct rw_semaphore___357 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___344;

struct vm_area_struct___357 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___357 *vm_next;
	struct vm_area_struct___357 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___356 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___344 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___356 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___356;

struct mm_struct___356 {
	struct {
		struct vm_area_struct___357 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___356 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___357 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___356 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___357 *owner;
		struct user_namespace___3 *user_ns;
		struct file___356 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___356 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___344)(struct vm_area_struct___357 *, long unsigned int, const struct page___357 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___344)(struct page___357 *, void *);

struct device___323;

struct dev_pagemap___344 {
	dev_page_fault_t___344 page_fault;
	dev_page_free_t___344 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___323 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct file___356 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___356 f_path;
	struct inode___356 *f_inode;
	const struct file_operations___356 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___216 f_owner;
	const struct cred___330 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___355 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___344;

struct vm_operations_struct___344 {
	void (*open)(struct vm_area_struct___357 *);
	void (*close)(struct vm_area_struct___357 *);
	int (*split)(struct vm_area_struct___357 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___357 *);
	vm_fault_t (*fault)(struct vm_fault___344 *);
	vm_fault_t (*huge_fault)(struct vm_fault___344 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___344 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___357 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___344 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___344 *);
	int (*access)(struct vm_area_struct___357 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___357 *);
	int (*set_policy)(struct vm_area_struct___357 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___357 *, long unsigned int);
	struct page___357 * (*find_special_page)(struct vm_area_struct___357 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___356 {
	struct task_struct___357 *task;
	struct core_thread___356 *next;
};

struct core_state___356 {
	atomic_t nr_threads;
	struct core_thread___356 dumper;
	struct completion startup;
};

struct vm_fault___344 {
	struct vm_area_struct___357 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___357 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___357 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___356 prealloc_pte;
};

struct key___330;

struct user_struct___330 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___330 *uid_keyring;
	struct key___330 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___330 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___330 *session_keyring;
	struct key___330 *process_keyring;
	struct key___330 *thread_keyring;
	struct key___330 *request_key_auth;
	void *security;
	struct user_struct___330 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct bio___173;

struct bio_list___173 {
	struct bio___173 *head;
	struct bio___173 *tail;
};

struct bdi_writeback_congested___173;

struct bdi_writeback___173 {
	struct backing_dev_info___173 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___173 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___157 *memcg_css;
	struct cgroup_subsys_state___157 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___173 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___173 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___323 *dev;
	struct device___323 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___355 *debug_dir;
	struct dentry___355 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___93;

struct io_context___93 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___93 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

typedef blk_qc_t make_request_fn___89(struct request_queue___89 *, struct bio___173 *);

struct request___89;

typedef int dma_drain_needed_fn___89(struct request___89 *);

struct kset___342;

struct kobj_type___342;

struct kernfs_node___350;

struct kobject___343 {
	const char *name;
	struct list_head entry;
	struct kobject___343 *parent;
	struct kset___342 *kset;
	struct kobj_type___342 *ktype;
	struct kernfs_node___350 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___89;

struct bsg_class_device___89 {
	struct device___323 *class_dev;
	int minor;
	struct request_queue___89 *queue;
	const struct bsg_ops___89 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___173 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___173 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___89;

struct blk_mq_ops___26;

struct blk_mq_hw_ctx___26;

struct blk_mq_tag_set___26;

struct request_queue___89 {
	struct list_head queue_head;
	struct request___89 *last_merge;
	struct elevator_queue___89 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___89 *make_request_fn;
	dma_drain_needed_fn___89 *dma_drain_needed;
	const struct blk_mq_ops___26 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___26 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___173 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___343 kobj;
	struct kobject___343 *mq_kobj;
	struct blk_integrity integrity;
	struct device___323 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	struct bsg_class_device___89 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set___26 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___173 bio_split;
	struct dentry___355 *debugfs_dir;
	struct dentry___355 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___262 {
	struct vm_struct___262 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___357 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct io_cq___93 {
	struct request_queue___89 *q;
	struct io_context___93 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___356 {
	struct file___356 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___356 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___355 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___356 *ia_file;
};

struct dquot___355 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___355 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___355 {
	int qf_fmt_id;
	const struct quota_format_ops___355 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___355 *qf_next;
};

struct quota_format_ops___355 {
	int (*check_quota_file)(struct super_block___355 *, int);
	int (*read_file_info)(struct super_block___355 *, int);
	int (*write_file_info)(struct super_block___355 *, int);
	int (*free_file_info)(struct super_block___355 *, int);
	int (*read_dqblk)(struct dquot___355 *);
	int (*commit_dqblk)(struct dquot___355 *);
	int (*release_dqblk)(struct dquot___355 *);
	int (*get_next_id)(struct super_block___355 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___355 {
	int (*write_dquot)(struct dquot___355 *);
	struct dquot___355 * (*alloc_dquot)(struct super_block___355 *, int);
	void (*destroy_dquot)(struct dquot___355 *);
	int (*acquire_dquot)(struct dquot___355 *);
	int (*release_dquot)(struct dquot___355 *);
	int (*mark_dirty)(struct dquot___355 *);
	int (*write_info)(struct super_block___355 *, int);
	qsize_t * (*get_reserved_space)(struct inode___356 *);
	int (*get_projid)(struct inode___356 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___356 *, qsize_t *);
	int (*get_next_id)(struct super_block___355 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___355 {
	int (*quota_on)(struct super_block___355 *, int, int, const struct path___356 *);
	int (*quota_off)(struct super_block___355 *, int);
	int (*quota_enable)(struct super_block___355 *, unsigned int);
	int (*quota_disable)(struct super_block___355 *, unsigned int);
	int (*quota_sync)(struct super_block___355 *, int);
	int (*set_info)(struct super_block___355 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___355 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___355 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___355 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___355 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___355 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___355 {
	int (*writepage)(struct page___357 *, struct writeback_control___3 *);
	int (*readpage)(struct file___356 *, struct page___357 *);
	int (*writepages)(struct address_space___355 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___357 *);
	int (*readpages)(struct file___356 *, struct address_space___355 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___356 *, struct address_space___355 *, loff_t, unsigned int, unsigned int, struct page___357 **, void **);
	int (*write_end)(struct file___356 *, struct address_space___355 *, loff_t, unsigned int, unsigned int, struct page___357 *, void *);
	sector_t (*bmap)(struct address_space___355 *, sector_t);
	void (*invalidatepage)(struct page___357 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___357 *, gfp_t);
	void (*freepage)(struct page___357 *);
	ssize_t (*direct_IO)(struct kiocb___356 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___355 *, struct page___357 *, struct page___357 *, enum migrate_mode);
	bool (*isolate_page)(struct page___357 *, isolate_mode_t);
	void (*putback_page)(struct page___357 *);
	int (*launder_page)(struct page___357 *);
	int (*is_partially_uptodate)(struct page___357 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___357 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___355 *, struct page___357 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___356 *, sector_t *);
	void (*swap_deactivate)(struct file___356 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct hd_struct___93;

struct gendisk___93;

struct block_device___355 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___356 *bd_inode;
	struct super_block___355 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___355 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___93 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___93 *bd_disk;
	struct request_queue___89 *bd_queue;
	struct backing_dev_info___173 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___323 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___5 *subsys_data;
	void (*set_latency_tolerance)(struct device___323 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___323;

struct bus_type___323;

struct device_driver___323;

struct dev_pm_domain___323;

struct dma_map_ops___112;

struct fwnode_handle___245;

struct class___323;

struct attribute_group___320;

struct device___323 {
	struct device___323 *parent;
	struct device_private *p;
	struct kobject___343 kobj;
	const char *init_name;
	const struct device_type___323 *type;
	struct mutex mutex;
	struct bus_type___323 *bus;
	struct device_driver___323 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___323 power;
	struct dev_pm_domain___323 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___112 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___245 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___323 *class;
	const struct attribute_group___320 **groups;
	void (*release)(struct device___323 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___93 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___323 __dev;
	struct kobject___343 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___93;

struct block_device_operations___90;

struct gendisk___93 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___93 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___93 *part_tbl;
	struct hd_struct___93 part0;
	const struct block_device_operations___90 *fops;
	struct request_queue___89 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___357 lookup_sem;
	struct kobject___343 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___343 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___355 {
	struct dentry___355 * (*lookup)(struct inode___356 *, struct dentry___355 *, unsigned int);
	const char * (*get_link)(struct dentry___355 *, struct inode___356 *, struct delayed_call *);
	int (*permission)(struct inode___356 *, int);
	struct posix_acl * (*get_acl)(struct inode___356 *, int);
	int (*readlink)(struct dentry___355 *, char *, int);
	int (*create)(struct inode___356 *, struct dentry___355 *, umode_t, bool);
	int (*link)(struct dentry___355 *, struct inode___356 *, struct dentry___355 *);
	int (*unlink)(struct inode___356 *, struct dentry___355 *);
	int (*symlink)(struct inode___356 *, struct dentry___355 *, const char *);
	int (*mkdir)(struct inode___356 *, struct dentry___355 *, umode_t);
	int (*rmdir)(struct inode___356 *, struct dentry___355 *);
	int (*mknod)(struct inode___356 *, struct dentry___355 *, umode_t, dev_t);
	int (*rename)(struct inode___356 *, struct dentry___355 *, struct inode___356 *, struct dentry___355 *, unsigned int);
	int (*setattr)(struct dentry___355 *, struct iattr___355 *);
	int (*getattr)(const struct path___356 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___355 *, char *, size_t);
	int (*fiemap)(struct inode___356 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___356 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___356 *, struct dentry___355 *, struct file___356 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___356 *, struct dentry___355 *, umode_t);
	int (*set_acl)(struct inode___356 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___355 {
	void (*fl_copy_lock)(struct file_lock___356 *, struct file_lock___356 *);
	void (*fl_release_private)(struct file_lock___356 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___355;

struct lock_manager_operations___355;

struct file_lock___356 {
	struct file_lock___356 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___356 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___355 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___355 *fl_ops;
	const struct lock_manager_operations___355 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___355 {
	int (*lm_compare_owner)(struct file_lock___356 *, struct file_lock___356 *);
	long unsigned int (*lm_owner_key)(struct file_lock___356 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___356 *);
	int (*lm_grant)(struct file_lock___356 *, int);
	bool (*lm_break)(struct file_lock___356 *);
	int (*lm_change)(struct file_lock___356 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___356 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___355 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___355 *fa_next;
	struct file___356 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___355 {
	const char *name;
	int fs_flags;
	struct dentry___355 * (*mount)(struct file_system_type___355 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___355 *);
	struct module___11 *owner;
	struct file_system_type___355 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___355 {
	struct inode___356 * (*alloc_inode)(struct super_block___355 *);
	void (*destroy_inode)(struct inode___356 *);
	void (*dirty_inode)(struct inode___356 *, int);
	int (*write_inode)(struct inode___356 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___356 *);
	void (*evict_inode)(struct inode___356 *);
	void (*put_super)(struct super_block___355 *);
	int (*sync_fs)(struct super_block___355 *, int);
	int (*freeze_super)(struct super_block___355 *);
	int (*freeze_fs)(struct super_block___355 *);
	int (*thaw_super)(struct super_block___355 *);
	int (*unfreeze_fs)(struct super_block___355 *);
	int (*statfs)(struct dentry___355 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___355 *, int *, char *);
	void (*umount_begin)(struct super_block___355 *);
	int (*show_options)(struct seq_file___303 *, struct dentry___355 *);
	int (*show_devname)(struct seq_file___303 *, struct dentry___355 *);
	int (*show_path)(struct seq_file___303 *, struct dentry___355 *);
	int (*show_stats)(struct seq_file___303 *, struct dentry___355 *);
	ssize_t (*quota_read)(struct super_block___355 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___355 *, int, const char *, size_t, loff_t);
	struct dquot___355 ** (*get_dquots)(struct inode___356 *);
	int (*bdev_try_to_free_page)(struct super_block___355 *, struct page___357 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___355 *, struct shrink_control___131 *);
	long int (*free_cached_objects)(struct super_block___355 *, struct shrink_control___131 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___302;

struct seq_file___303 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___302 *op;
	int poll_event;
	const struct file___356 *file;
	void *private;
};

typedef void bio_end_io_t___173(struct bio___173 *);

struct bio_vec___175 {
	struct page___357 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___173;

struct bio___173 {
	struct bio___173 *bi_next;
	struct gendisk___93 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___173 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___173 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___175 *bi_io_vec;
	struct bio_set___173 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___175 bi_inline_vecs[0];
};

struct kernfs_root___349;

struct kernfs_elem_dir___349 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___349 *root;
};

struct kernfs_syscall_ops___349;

struct kernfs_root___349 {
	struct kernfs_node___350 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___349 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___349 {
	struct kernfs_node___350 *target_kn;
};

struct kernfs_ops___349;

struct kernfs_elem_attr___349 {
	const struct kernfs_ops___349 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___350 *notify_next;
};

struct kernfs_node___350 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___350 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___349 dir;
		struct kernfs_elem_symlink___349 symlink;
		struct kernfs_elem_attr___349 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___349;

struct kernfs_ops___349 {
	int (*open)(struct kernfs_open_file___349 *);
	void (*release)(struct kernfs_open_file___349 *);
	int (*seq_show)(struct seq_file___303 *, void *);
	void * (*seq_start)(struct seq_file___303 *, loff_t *);
	void * (*seq_next)(struct seq_file___303 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___303 *, void *);
	ssize_t (*read)(struct kernfs_open_file___349 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___349 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___349 *, struct vm_area_struct___357 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___349 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___349 {
	int (*remount_fs)(struct kernfs_root___349 *, int *, char *);
	int (*show_options)(struct seq_file___303 *, struct kernfs_root___349 *);
	int (*mkdir)(struct kernfs_node___350 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___350 *);
	int (*rename)(struct kernfs_node___350 *, struct kernfs_node___350 *, const char *);
	int (*show_path)(struct seq_file___303 *, struct kernfs_node___350 *, struct kernfs_root___349 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___349 {
	struct kernfs_node___350 *kn;
	struct file___356 *file;
	struct seq_file___303 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___344 *vm_ops;
};

struct bin_attribute___319;

struct attribute_group___320 {
	const char *name;
	umode_t (*is_visible)(struct kobject___343 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___343 *, struct bin_attribute___319 *, int);
	struct attribute **attrs;
	struct bin_attribute___319 **bin_attrs;
};

struct bin_attribute___319 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___356 *, struct kobject___343 *, struct bin_attribute___319 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___356 *, struct kobject___343 *, struct bin_attribute___319 *, char *, loff_t, size_t);
	int (*mmap)(struct file___356 *, struct kobject___343 *, struct bin_attribute___319 *, struct vm_area_struct___357 *);
};

struct sysfs_ops___342 {
	ssize_t (*show)(struct kobject___343 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___343 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___342;

struct kset___342 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___343 kobj;
	const struct kset_uevent_ops___342 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___342 {
	void (*release)(struct kobject___343 *);
	const struct sysfs_ops___342 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___28 * (*child_ns_type)(struct kobject___343 *);
	const void * (*namespace)(struct kobject___343 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___342 {
	int (* const filter)(struct kset___342 *, struct kobject___343 *);
	const char * (* const name)(struct kset___342 *, struct kobject___343 *);
	int (* const uevent)(struct kset___342 *, struct kobject___343 *, struct kobj_uevent_env *);
};

struct kobj_attribute___334 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___343 *, struct kobj_attribute___334 *, char *);
	ssize_t (*store)(struct kobject___343 *, struct kobj_attribute___334 *, const char *, size_t);
};

struct dev_pm_ops___323 {
	int (*prepare)(struct device___323 *);
	void (*complete)(struct device___323 *);
	int (*suspend)(struct device___323 *);
	int (*resume)(struct device___323 *);
	int (*freeze)(struct device___323 *);
	int (*thaw)(struct device___323 *);
	int (*poweroff)(struct device___323 *);
	int (*restore)(struct device___323 *);
	int (*suspend_late)(struct device___323 *);
	int (*resume_early)(struct device___323 *);
	int (*freeze_late)(struct device___323 *);
	int (*thaw_early)(struct device___323 *);
	int (*poweroff_late)(struct device___323 *);
	int (*restore_early)(struct device___323 *);
	int (*suspend_noirq)(struct device___323 *);
	int (*resume_noirq)(struct device___323 *);
	int (*freeze_noirq)(struct device___323 *);
	int (*thaw_noirq)(struct device___323 *);
	int (*poweroff_noirq)(struct device___323 *);
	int (*restore_noirq)(struct device___323 *);
	int (*runtime_suspend)(struct device___323 *);
	int (*runtime_resume)(struct device___323 *);
	int (*runtime_idle)(struct device___323 *);
};

struct dev_pm_domain___323 {
	struct dev_pm_ops___323 ops;
	void (*detach)(struct device___323 *, bool);
	int (*activate)(struct device___323 *);
	void (*sync)(struct device___323 *);
	void (*dismiss)(struct device___323 *);
};

struct bus_type___323 {
	const char *name;
	const char *dev_name;
	struct device___323 *dev_root;
	const struct attribute_group___320 **bus_groups;
	const struct attribute_group___320 **dev_groups;
	const struct attribute_group___320 **drv_groups;
	int (*match)(struct device___323 *, struct device_driver___323 *);
	int (*uevent)(struct device___323 *, struct kobj_uevent_env *);
	int (*probe)(struct device___323 *);
	int (*remove)(struct device___323 *);
	void (*shutdown)(struct device___323 *);
	int (*online)(struct device___323 *);
	int (*offline)(struct device___323 *);
	int (*suspend)(struct device___323 *, pm_message_t);
	int (*resume)(struct device___323 *);
	int (*num_vf)(struct device___323 *);
	int (*dma_configure)(struct device___323 *);
	const struct dev_pm_ops___323 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___323 {
	const char *name;
	struct bus_type___323 *bus;
	struct module___11 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___323 *);
	int (*remove)(struct device___323 *);
	void (*shutdown)(struct device___323 *);
	int (*suspend)(struct device___323 *, pm_message_t);
	int (*resume)(struct device___323 *);
	const struct attribute_group___320 **groups;
	const struct dev_pm_ops___323 *pm;
	void (*coredump)(struct device___323 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___323 {
	const char *name;
	const struct attribute_group___320 **groups;
	int (*uevent)(struct device___323 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___323 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___323 *);
	const struct dev_pm_ops___323 *pm;
};

struct class___323 {
	const char *name;
	struct module___11 *owner;
	const struct attribute_group___320 **class_groups;
	const struct attribute_group___320 **dev_groups;
	struct kobject___343 *dev_kobj;
	int (*dev_uevent)(struct device___323 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___323 *, umode_t *);
	void (*class_release)(struct class___323 *);
	void (*dev_release)(struct device___323 *);
	int (*shutdown_pre)(struct device___323 *);
	const struct kobj_ns_type_operations___28 *ns_type;
	const void * (*namespace)(struct device___323 *);
	const struct dev_pm_ops___323 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___112 {
	void * (*alloc)(struct device___323 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___323 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___323 *, struct vm_area_struct___357 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___323 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___323 *, struct page___357 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___323 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___323 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___323 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___323 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___323 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___323 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___323 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___323 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___323 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___323 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___323 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___323 *, u64);
	u64 (*get_required_mask)(struct device___323 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___245;

struct fwnode_handle___245 {
	struct fwnode_handle___245 *secondary;
	const struct fwnode_operations___245 *ops;
};

typedef void compound_page_dtor___344(struct page___357 *);

struct fwnode_reference_args___245;

struct fwnode_endpoint___245;

struct fwnode_operations___245 {
	struct fwnode_handle___245 * (*get)(struct fwnode_handle___245 *);
	void (*put)(struct fwnode_handle___245 *);
	bool (*device_is_available)(const struct fwnode_handle___245 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___245 *, const struct device___323 *);
	bool (*property_present)(const struct fwnode_handle___245 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___245 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___245 *, const char *, const char **, size_t);
	struct fwnode_handle___245 * (*get_parent)(const struct fwnode_handle___245 *);
	struct fwnode_handle___245 * (*get_next_child_node)(const struct fwnode_handle___245 *, struct fwnode_handle___245 *);
	struct fwnode_handle___245 * (*get_named_child_node)(const struct fwnode_handle___245 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___245 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___245 *);
	struct fwnode_handle___245 * (*graph_get_next_endpoint)(const struct fwnode_handle___245 *, struct fwnode_handle___245 *);
	struct fwnode_handle___245 * (*graph_get_remote_endpoint)(const struct fwnode_handle___245 *);
	struct fwnode_handle___245 * (*graph_get_port_parent)(struct fwnode_handle___245 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___245 *, struct fwnode_endpoint___245 *);
};

struct fwnode_endpoint___245 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___245 *local_fwnode;
};

struct fwnode_reference_args___245 {
	struct fwnode_handle___245 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct bio_integrity_payload___173 {
	struct bio___173 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___175 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___175 bip_inline_vecs[0];
};

struct disk_part_tbl___93 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___93 *last_lookup;
	struct hd_struct___93 *part[0];
};

struct block_device_operations___90 {
	int (*open)(struct block_device___355 *, fmode_t);
	void (*release)(struct gendisk___93 *, fmode_t);
	int (*rw_page)(struct block_device___355 *, sector_t, struct page___357 *, unsigned int);
	int (*ioctl)(struct block_device___355 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___355 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___93 *, unsigned int);
	int (*media_changed)(struct gendisk___93 *);
	void (*unlock_native_capacity)(struct gendisk___93 *);
	int (*revalidate_disk)(struct gendisk___93 *);
	int (*getgeo)(struct block_device___355 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___355 *, long unsigned int);
	int (*report_zones)(struct gendisk___93 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___11 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bdi_writeback_congested___173 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___173 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bsg_ops___89 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___89 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___89 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___89 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___89(struct request___89 *, blk_status_t);

struct request___89 {
	struct request_queue___89 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___26 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___173 *bio;
	struct bio___173 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___175 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___93 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___89 *saved_end_io;
		} flush;
	};
	struct gendisk___93 *rq_disk;
	struct hd_struct___93 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___89 *end_io;
	void *end_io_data;
	struct request___89 *next_rq;
};

struct blk_mq_hw_ctx___26 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___89 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags___4 *tags;
	struct blk_mq_tags___4 *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	unsigned int rh_reserved_nr_expired;
	struct hlist_node cpuhp_dead;
	struct kobject___343 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___355 *debugfs_dir;
	struct dentry___355 *sched_debugfs_dir;
	struct list_head hctx_list;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___89;

struct elevator_mq_ops___89 {
	int (*init_sched)(struct request_queue___89 *, struct elevator_type___89 *);
	void (*exit_sched)(struct elevator_queue___89 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___26 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___26 *, unsigned int);
	bool (*allow_merge)(struct request_queue___89 *, struct request___89 *, struct bio___173 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx___26 *, struct bio___173 *);
	int (*request_merge)(struct request_queue___89 *, struct request___89 **, struct bio___173 *);
	void (*request_merged)(struct request_queue___89 *, struct request___89 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___89 *, struct request___89 *, struct request___89 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___89 *, struct bio___173 *);
	void (*finish_request)(struct request___89 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___26 *, struct list_head *, bool);
	struct request___89 * (*dispatch_request)(struct blk_mq_hw_ctx___26 *);
	bool (*has_work)(struct blk_mq_hw_ctx___26 *);
	void (*completed_request)(struct request___89 *, u64);
	void (*started_request)(struct request___89 *);
	void (*requeue_request)(struct request___89 *);
	struct request___89 * (*former_request)(struct request_queue___89 *, struct request___89 *);
	struct request___89 * (*next_request)(struct request_queue___89 *, struct request___89 *);
	void (*init_icq)(struct io_cq___93 *);
	void (*exit_icq)(struct io_cq___93 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx___26 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___89;

struct elevator_type___89 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___89 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___89 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___11 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___89 {
	struct elevator_type___89 *type;
	void *elevator_data;
	struct kobject___343 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___89 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___89 *, char *);
	ssize_t (*store)(struct elevator_queue___89 *, const char *, size_t);
};

struct blk_mq_queue_data___26;

typedef blk_status_t queue_rq_fn___26(struct blk_mq_hw_ctx___26 *, const struct blk_mq_queue_data___26 *);

typedef void commit_rqs_fn___26(struct blk_mq_hw_ctx___26 *);

typedef bool get_budget_fn___26(struct blk_mq_hw_ctx___26 *);

typedef void put_budget_fn___26(struct blk_mq_hw_ctx___26 *);

typedef enum blk_eh_timer_return timeout_fn___26(struct request___89 *, bool);

typedef int poll_fn___26(struct blk_mq_hw_ctx___26 *);

typedef void complete_fn___26(struct request___89 *);

typedef int init_hctx_fn___26(struct blk_mq_hw_ctx___26 *, void *, unsigned int);

typedef void exit_hctx_fn___26(struct blk_mq_hw_ctx___26 *, unsigned int);

typedef int init_request_fn___26(struct blk_mq_tag_set___26 *, struct request___89 *, unsigned int, unsigned int);

typedef void exit_request_fn___26(struct blk_mq_tag_set___26 *, struct request___89 *, unsigned int);

typedef bool busy_fn___26(struct request_queue___89 *);

typedef int map_queues_fn___26(struct blk_mq_tag_set___26 *);

typedef void cleanup_rq_fn___26(struct request___89 *);

struct blk_mq_ops___26 {
	queue_rq_fn___26 *queue_rq;
	commit_rqs_fn___26 *commit_rqs;
	get_budget_fn___26 *get_budget;
	put_budget_fn___26 *put_budget;
	timeout_fn___26 *timeout;
	poll_fn___26 *poll;
	complete_fn___26 *complete;
	init_hctx_fn___26 *init_hctx;
	exit_hctx_fn___26 *exit_hctx;
	init_request_fn___26 *init_request;
	exit_request_fn___26 *exit_request;
	void (*initialize_rq_fn)(struct request___89 *);
	busy_fn___26 *busy;
	map_queues_fn___26 *map_queues;
	void (*show_rq)(struct seq_file___303 *, struct request___89 *);
	union {
		cleanup_rq_fn___26 *cleanup_rq;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide47;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct blk_mq_tag_set___26 {
	struct blk_mq_queue_map map[6];
	unsigned int nr_maps;
	const struct blk_mq_ops___26 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	struct blk_mq_tags___4 **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct blk_mq_queue_data___26 {
	struct request___89 *rq;
	bool last;
	long unsigned int rh_reserved1;
};

typedef int (*key_restrict_link_func_t___331)(struct key___330 *, const struct key_type *, const union key_payload *, struct key___330 *);

struct key_restriction___330;

struct key___330 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___357 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___330 *restrict_link;
};

struct key_restriction___330 {
	key_restrict_link_func_t___331 check;
	struct key___330 *key;
	struct key_type *keytype;
};

struct seq_operations___302 {
	void * (*start)(struct seq_file___303 *, loff_t *);
	void (*stop)(struct seq_file___303 *, void *);
	void * (*next)(struct seq_file___303 *, void *, loff_t *);
	int (*show)(struct seq_file___303 *, void *);
};

struct file___357;

struct kiocb___357;

struct vm_area_struct___358;

struct inode___357;

struct file_lock___357;

struct page___358;

struct file_operations___357 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___357 *, loff_t, int);
	ssize_t (*read)(struct file___357 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___357 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___357 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___357 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___357 *, bool);
	int (*iterate)(struct file___357 *, struct dir_context *);
	int (*iterate_shared)(struct file___357 *, struct dir_context *);
	__poll_t (*poll)(struct file___357 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___357 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___357 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___357 *, struct vm_area_struct___358 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___357 *, struct file___357 *);
	int (*flush)(struct file___357 *, fl_owner_t);
	int (*release)(struct inode___357 *, struct file___357 *);
	int (*fsync)(struct file___357 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___357 *, int);
	int (*lock)(struct file___357 *, int, struct file_lock___357 *);
	ssize_t (*sendpage)(struct file___357 *, struct page___358 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___357 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___357 *, int, struct file_lock___357 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___357 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___357 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___357 *, long int, struct file_lock___357 **, void **);
	long int (*fallocate)(struct file___357 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___357 *);
	ssize_t (*copy_file_range)(struct file___357 *, loff_t, struct file___357 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___357 *, loff_t, struct file___357 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___357 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___357 {
	u64 seqnum;
	struct vm_area_struct___358 *vmas[4];
};

struct page_frag___357 {
	struct page___358 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___357;

struct bio_list___174;

struct backing_dev_info___174;

struct io_context___94;

struct request_queue___90;

struct vm_struct___263;

struct task_struct___358 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___358 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___357 *mm;
	struct mm_struct___357 *active_mm;
	struct vmacache___357 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___358 *real_parent;
	struct task_struct___358 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___358 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___216 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___216 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___216 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___2 *ptracer_cred;
	const struct cred___2 *real_cred;
	const struct cred___2 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___358 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___174 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___174 *backing_dev_info;
	struct io_context___94 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___357 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___90 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___358 *oom_reaper_list;
	struct vm_struct___263 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___140 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___358 *pgtable_t___357;

struct address_space___356;

struct dev_pagemap___345;

struct page___358 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___356 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___358 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___357 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___357 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___345 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___357;

struct lruvec___357 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___357 *pgdat;
};

struct zone___357 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___357 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___357 {
	struct zone___357 *zone;
	int zone_idx;
};

struct zonelist___357 {
	struct zoneref___357 _zonerefs[25];
};

struct pglist_data___357 {
	struct zone___357 node_zones[3];
	struct zonelist___357 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___358 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___358 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___357 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___358 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___358 *owner;
};

struct secondary_data___358 {
	void *stack;
	struct task_struct___358 *task;
	long int status;
};

struct blocking_notifier_head___357 {
	struct rw_semaphore___358 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___345;

struct vm_area_struct___358 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___358 *vm_next;
	struct vm_area_struct___358 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___357 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___345 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___357 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___357;

struct mm_struct___357 {
	struct {
		struct vm_area_struct___358 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___357 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___358 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___357 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___358 *owner;
		struct user_namespace___3 *user_ns;
		struct file___357 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___357 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___356;

struct address_space___356 {
	struct inode___357 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___358 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___356 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___345)(struct vm_area_struct___358 *, long unsigned int, const struct page___358 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___345)(struct page___358 *, void *);

struct device___324;

struct dev_pagemap___345 {
	dev_page_fault_t___345 page_fault;
	dev_page_free_t___345 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___324 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct dentry___356;

struct path___357 {
	struct vfsmount *mnt;
	struct dentry___356 *dentry;
};

struct file___357 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___357 f_path;
	struct inode___357 *f_inode;
	const struct file_operations___357 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___216 f_owner;
	const struct cred___2 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___356 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___345;

struct vm_operations_struct___345 {
	void (*open)(struct vm_area_struct___358 *);
	void (*close)(struct vm_area_struct___358 *);
	int (*split)(struct vm_area_struct___358 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___358 *);
	vm_fault_t (*fault)(struct vm_fault___345 *);
	vm_fault_t (*huge_fault)(struct vm_fault___345 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___345 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___358 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___345 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___345 *);
	int (*access)(struct vm_area_struct___358 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___358 *);
	int (*set_policy)(struct vm_area_struct___358 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___358 *, long unsigned int);
	struct page___358 * (*find_special_page)(struct vm_area_struct___358 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___357 {
	struct task_struct___358 *task;
	struct core_thread___357 *next;
};

struct core_state___357 {
	atomic_t nr_threads;
	struct core_thread___357 dumper;
	struct completion startup;
};

struct vm_fault___345 {
	struct vm_area_struct___358 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___358 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___358 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___357 prealloc_pte;
};

struct bio___174;

struct bio_list___174 {
	struct bio___174 *head;
	struct bio___174 *tail;
};

struct bdi_writeback_congested___174;

struct bdi_writeback___174 {
	struct backing_dev_info___174 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___174 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___157 *memcg_css;
	struct cgroup_subsys_state___157 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___174 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___174 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___324 *dev;
	struct device___324 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___356 *debug_dir;
	struct dentry___356 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___94;

struct io_context___94 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___94 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

typedef blk_qc_t make_request_fn___90(struct request_queue___90 *, struct bio___174 *);

struct request___90;

typedef int dma_drain_needed_fn___90(struct request___90 *);

struct kset___343;

struct kobj_type___343;

struct kernfs_node___351;

struct kobject___344 {
	const char *name;
	struct list_head entry;
	struct kobject___344 *parent;
	struct kset___343 *kset;
	struct kobj_type___343 *ktype;
	struct kernfs_node___351 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___90;

struct bsg_class_device___90 {
	struct device___324 *class_dev;
	int minor;
	struct request_queue___90 *queue;
	const struct bsg_ops___90 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___174 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___174 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___90;

struct blk_mq_ops___27;

struct blk_mq_hw_ctx___27;

struct blk_mq_tag_set___27;

struct request_queue___90 {
	struct list_head queue_head;
	struct request___90 *last_merge;
	struct elevator_queue___90 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___90 *make_request_fn;
	dma_drain_needed_fn___90 *dma_drain_needed;
	const struct blk_mq_ops___27 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___27 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___174 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___344 kobj;
	struct kobject___344 *mq_kobj;
	struct blk_integrity integrity;
	struct device___324 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	struct bsg_class_device___90 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set___27 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___174 bio_split;
	struct dentry___356 *debugfs_dir;
	struct dentry___356 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___263 {
	struct vm_struct___263 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___358 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dev_pm_info___324 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___5 *subsys_data;
	void (*set_latency_tolerance)(struct device___324 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___324;

struct bus_type___324;

struct device_driver___324;

struct dev_pm_domain___324;

struct dma_map_ops___113;

struct fwnode_handle___246;

struct class___324;

struct attribute_group___321;

struct device___324 {
	struct device___324 *parent;
	struct device_private *p;
	struct kobject___344 kobj;
	const char *init_name;
	const struct device_type___324 *type;
	struct mutex mutex;
	struct bus_type___324 *bus;
	struct device_driver___324 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___324 power;
	struct dev_pm_domain___324 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___113 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___246 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___324 *class;
	const struct attribute_group___321 **groups;
	void (*release)(struct device___324 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___356;

struct super_block___356;

struct dentry___356 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___356 *d_parent;
	struct qstr d_name;
	struct inode___357 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___356 *d_op;
	struct super_block___356 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___356;

struct block_device___356;

struct inode___357 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___356 *i_op;
	struct super_block___356 *i_sb;
	struct address_space___356 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___358 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___174 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___357 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___356 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___356 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___356 {
	int (*d_revalidate)(struct dentry___356 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___356 *, unsigned int);
	int (*d_hash)(const struct dentry___356 *, struct qstr *);
	int (*d_compare)(const struct dentry___356 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___356 *);
	int (*d_init)(struct dentry___356 *);
	void (*d_release)(struct dentry___356 *);
	void (*d_prune)(struct dentry___356 *);
	void (*d_iput)(struct dentry___356 *, struct inode___357 *);
	char * (*d_dname)(struct dentry___356 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___357 *);
	int (*d_manage)(const struct path___357 *, bool);
	struct dentry___356 * (*d_real)(struct dentry___356 *, const struct inode___357 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___356;

struct mem_dqinfo___356 {
	struct quota_format_type___356 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___356;

struct quota_info___356 {
	unsigned int flags;
	struct rw_semaphore___358 dqio_sem;
	struct inode___357 *files[3];
	struct mem_dqinfo___356 info[3];
	const struct quota_format_ops___356 *ops[3];
};

struct rcuwait___356 {
	struct task_struct___358 *task;
};

struct percpu_rw_semaphore___356 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___358 rw_sem;
	struct rcuwait___356 writer;
	int readers_block;
};

struct sb_writers___356 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___356 rw_sem[3];
};

struct file_system_type___356;

struct super_operations___356;

struct dquot_operations___356;

struct quotactl_ops___356;

struct super_block___356 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___356 *s_type;
	const struct super_operations___356 *s_op;
	const struct dquot_operations___356 *dq_op;
	const struct quotactl_ops___356 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___356 *s_root;
	struct rw_semaphore___358 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___356 *s_bdev;
	struct backing_dev_info___174 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___356 s_dquot;
	struct sb_writers___356 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___356 *s_d_op;
	int cleancache_poolid;
	struct shrinker___131 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct io_cq___94 {
	struct request_queue___90 *q;
	struct io_context___94 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___357 {
	struct file___357 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___357 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___356 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___357 *ia_file;
};

struct dquot___356 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___356 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___356 {
	int qf_fmt_id;
	const struct quota_format_ops___356 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___356 *qf_next;
};

struct quota_format_ops___356 {
	int (*check_quota_file)(struct super_block___356 *, int);
	int (*read_file_info)(struct super_block___356 *, int);
	int (*write_file_info)(struct super_block___356 *, int);
	int (*free_file_info)(struct super_block___356 *, int);
	int (*read_dqblk)(struct dquot___356 *);
	int (*commit_dqblk)(struct dquot___356 *);
	int (*release_dqblk)(struct dquot___356 *);
	int (*get_next_id)(struct super_block___356 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___356 {
	int (*write_dquot)(struct dquot___356 *);
	struct dquot___356 * (*alloc_dquot)(struct super_block___356 *, int);
	void (*destroy_dquot)(struct dquot___356 *);
	int (*acquire_dquot)(struct dquot___356 *);
	int (*release_dquot)(struct dquot___356 *);
	int (*mark_dirty)(struct dquot___356 *);
	int (*write_info)(struct super_block___356 *, int);
	qsize_t * (*get_reserved_space)(struct inode___357 *);
	int (*get_projid)(struct inode___357 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___357 *, qsize_t *);
	int (*get_next_id)(struct super_block___356 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___356 {
	int (*quota_on)(struct super_block___356 *, int, int, const struct path___357 *);
	int (*quota_off)(struct super_block___356 *, int);
	int (*quota_enable)(struct super_block___356 *, unsigned int);
	int (*quota_disable)(struct super_block___356 *, unsigned int);
	int (*quota_sync)(struct super_block___356 *, int);
	int (*set_info)(struct super_block___356 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___356 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___356 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___356 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___356 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___356 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___356 {
	int (*writepage)(struct page___358 *, struct writeback_control___3 *);
	int (*readpage)(struct file___357 *, struct page___358 *);
	int (*writepages)(struct address_space___356 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___358 *);
	int (*readpages)(struct file___357 *, struct address_space___356 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___357 *, struct address_space___356 *, loff_t, unsigned int, unsigned int, struct page___358 **, void **);
	int (*write_end)(struct file___357 *, struct address_space___356 *, loff_t, unsigned int, unsigned int, struct page___358 *, void *);
	sector_t (*bmap)(struct address_space___356 *, sector_t);
	void (*invalidatepage)(struct page___358 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___358 *, gfp_t);
	void (*freepage)(struct page___358 *);
	ssize_t (*direct_IO)(struct kiocb___357 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___356 *, struct page___358 *, struct page___358 *, enum migrate_mode);
	bool (*isolate_page)(struct page___358 *, isolate_mode_t);
	void (*putback_page)(struct page___358 *);
	int (*launder_page)(struct page___358 *);
	int (*is_partially_uptodate)(struct page___358 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___358 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___356 *, struct page___358 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___357 *, sector_t *);
	void (*swap_deactivate)(struct file___357 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct hd_struct___94;

struct gendisk___94;

struct block_device___356 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___357 *bd_inode;
	struct super_block___356 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___356 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___94 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___94 *bd_disk;
	struct request_queue___90 *bd_queue;
	struct backing_dev_info___174 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct hd_struct___94 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___324 __dev;
	struct kobject___344 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___94;

struct block_device_operations___91;

struct gendisk___94 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___94 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___94 *part_tbl;
	struct hd_struct___94 part0;
	const struct block_device_operations___91 *fops;
	struct request_queue___90 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___358 lookup_sem;
	struct kobject___344 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___344 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___356 {
	struct dentry___356 * (*lookup)(struct inode___357 *, struct dentry___356 *, unsigned int);
	const char * (*get_link)(struct dentry___356 *, struct inode___357 *, struct delayed_call *);
	int (*permission)(struct inode___357 *, int);
	struct posix_acl * (*get_acl)(struct inode___357 *, int);
	int (*readlink)(struct dentry___356 *, char *, int);
	int (*create)(struct inode___357 *, struct dentry___356 *, umode_t, bool);
	int (*link)(struct dentry___356 *, struct inode___357 *, struct dentry___356 *);
	int (*unlink)(struct inode___357 *, struct dentry___356 *);
	int (*symlink)(struct inode___357 *, struct dentry___356 *, const char *);
	int (*mkdir)(struct inode___357 *, struct dentry___356 *, umode_t);
	int (*rmdir)(struct inode___357 *, struct dentry___356 *);
	int (*mknod)(struct inode___357 *, struct dentry___356 *, umode_t, dev_t);
	int (*rename)(struct inode___357 *, struct dentry___356 *, struct inode___357 *, struct dentry___356 *, unsigned int);
	int (*setattr)(struct dentry___356 *, struct iattr___356 *);
	int (*getattr)(const struct path___357 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___356 *, char *, size_t);
	int (*fiemap)(struct inode___357 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___357 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___357 *, struct dentry___356 *, struct file___357 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___357 *, struct dentry___356 *, umode_t);
	int (*set_acl)(struct inode___357 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___356 {
	void (*fl_copy_lock)(struct file_lock___357 *, struct file_lock___357 *);
	void (*fl_release_private)(struct file_lock___357 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___356;

struct lock_manager_operations___356;

struct file_lock___357 {
	struct file_lock___357 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___357 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___356 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___356 *fl_ops;
	const struct lock_manager_operations___356 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___356 {
	int (*lm_compare_owner)(struct file_lock___357 *, struct file_lock___357 *);
	long unsigned int (*lm_owner_key)(struct file_lock___357 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___357 *);
	int (*lm_grant)(struct file_lock___357 *, int);
	bool (*lm_break)(struct file_lock___357 *);
	int (*lm_change)(struct file_lock___357 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___357 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___356 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___356 *fa_next;
	struct file___357 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___356 {
	const char *name;
	int fs_flags;
	struct dentry___356 * (*mount)(struct file_system_type___356 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___356 *);
	struct module___11 *owner;
	struct file_system_type___356 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___356 {
	struct inode___357 * (*alloc_inode)(struct super_block___356 *);
	void (*destroy_inode)(struct inode___357 *);
	void (*dirty_inode)(struct inode___357 *, int);
	int (*write_inode)(struct inode___357 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___357 *);
	void (*evict_inode)(struct inode___357 *);
	void (*put_super)(struct super_block___356 *);
	int (*sync_fs)(struct super_block___356 *, int);
	int (*freeze_super)(struct super_block___356 *);
	int (*freeze_fs)(struct super_block___356 *);
	int (*thaw_super)(struct super_block___356 *);
	int (*unfreeze_fs)(struct super_block___356 *);
	int (*statfs)(struct dentry___356 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___356 *, int *, char *);
	void (*umount_begin)(struct super_block___356 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___356 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___356 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___356 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___356 *);
	ssize_t (*quota_read)(struct super_block___356 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___356 *, int, const char *, size_t, loff_t);
	struct dquot___356 ** (*get_dquots)(struct inode___357 *);
	int (*bdev_try_to_free_page)(struct super_block___356 *, struct page___358 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___356 *, struct shrink_control___131 *);
	long int (*free_cached_objects)(struct super_block___356 *, struct shrink_control___131 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___174(struct bio___174 *);

struct bio_vec___176 {
	struct page___358 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___174;

struct bio___174 {
	struct bio___174 *bi_next;
	struct gendisk___94 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___174 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___174 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___176 *bi_io_vec;
	struct bio_set___174 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___176 bi_inline_vecs[0];
};

struct kobj_attribute___335 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___344 *, struct kobj_attribute___335 *, char *);
	ssize_t (*store)(struct kobject___344 *, struct kobj_attribute___335 *, const char *, size_t);
};

typedef void compound_page_dtor___345(struct page___358 *);

struct fwnode_operations___246;

struct fwnode_handle___246 {
	struct fwnode_handle___246 *secondary;
	const struct fwnode_operations___246 *ops;
};

struct fwnode_reference_args___246;

struct fwnode_endpoint___246;

struct fwnode_operations___246 {
	struct fwnode_handle___246 * (*get)(struct fwnode_handle___246 *);
	void (*put)(struct fwnode_handle___246 *);
	bool (*device_is_available)(const struct fwnode_handle___246 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___246 *, const struct device___324 *);
	bool (*property_present)(const struct fwnode_handle___246 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___246 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___246 *, const char *, const char **, size_t);
	struct fwnode_handle___246 * (*get_parent)(const struct fwnode_handle___246 *);
	struct fwnode_handle___246 * (*get_next_child_node)(const struct fwnode_handle___246 *, struct fwnode_handle___246 *);
	struct fwnode_handle___246 * (*get_named_child_node)(const struct fwnode_handle___246 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___246 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___246 *);
	struct fwnode_handle___246 * (*graph_get_next_endpoint)(const struct fwnode_handle___246 *, struct fwnode_handle___246 *);
	struct fwnode_handle___246 * (*graph_get_remote_endpoint)(const struct fwnode_handle___246 *);
	struct fwnode_handle___246 * (*graph_get_port_parent)(struct fwnode_handle___246 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___246 *, struct fwnode_endpoint___246 *);
};

struct fwnode_endpoint___246 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___246 *local_fwnode;
};

struct fwnode_reference_args___246 {
	struct fwnode_handle___246 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct kernfs_root___350;

struct kernfs_elem_dir___350 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___350 *root;
};

struct kernfs_syscall_ops___350;

struct kernfs_root___350 {
	struct kernfs_node___351 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___350 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___350 {
	struct kernfs_node___351 *target_kn;
};

struct kernfs_ops___350;

struct kernfs_elem_attr___350 {
	const struct kernfs_ops___350 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___351 *notify_next;
};

struct kernfs_node___351 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___351 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___350 dir;
		struct kernfs_elem_symlink___350 symlink;
		struct kernfs_elem_attr___350 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___350;

struct kernfs_ops___350 {
	int (*open)(struct kernfs_open_file___350 *);
	void (*release)(struct kernfs_open_file___350 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___350 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___350 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___350 *, struct vm_area_struct___358 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___350 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___350 {
	int (*remount_fs)(struct kernfs_root___350 *, int *, char *);
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___350 *);
	int (*mkdir)(struct kernfs_node___351 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___351 *);
	int (*rename)(struct kernfs_node___351 *, struct kernfs_node___351 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___351 *, struct kernfs_root___350 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___350 {
	struct kernfs_node___351 *kn;
	struct file___357 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___345 *vm_ops;
};

struct bin_attribute___320;

struct attribute_group___321 {
	const char *name;
	umode_t (*is_visible)(struct kobject___344 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___344 *, struct bin_attribute___320 *, int);
	struct attribute **attrs;
	struct bin_attribute___320 **bin_attrs;
};

struct bin_attribute___320 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___357 *, struct kobject___344 *, struct bin_attribute___320 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___357 *, struct kobject___344 *, struct bin_attribute___320 *, char *, loff_t, size_t);
	int (*mmap)(struct file___357 *, struct kobject___344 *, struct bin_attribute___320 *, struct vm_area_struct___358 *);
};

struct sysfs_ops___343 {
	ssize_t (*show)(struct kobject___344 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___344 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___343;

struct kset___343 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___344 kobj;
	const struct kset_uevent_ops___343 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___343 {
	void (*release)(struct kobject___344 *);
	const struct sysfs_ops___343 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___28 * (*child_ns_type)(struct kobject___344 *);
	const void * (*namespace)(struct kobject___344 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___343 {
	int (* const filter)(struct kset___343 *, struct kobject___344 *);
	const char * (* const name)(struct kset___343 *, struct kobject___344 *);
	int (* const uevent)(struct kset___343 *, struct kobject___344 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___324 {
	int (*prepare)(struct device___324 *);
	void (*complete)(struct device___324 *);
	int (*suspend)(struct device___324 *);
	int (*resume)(struct device___324 *);
	int (*freeze)(struct device___324 *);
	int (*thaw)(struct device___324 *);
	int (*poweroff)(struct device___324 *);
	int (*restore)(struct device___324 *);
	int (*suspend_late)(struct device___324 *);
	int (*resume_early)(struct device___324 *);
	int (*freeze_late)(struct device___324 *);
	int (*thaw_early)(struct device___324 *);
	int (*poweroff_late)(struct device___324 *);
	int (*restore_early)(struct device___324 *);
	int (*suspend_noirq)(struct device___324 *);
	int (*resume_noirq)(struct device___324 *);
	int (*freeze_noirq)(struct device___324 *);
	int (*thaw_noirq)(struct device___324 *);
	int (*poweroff_noirq)(struct device___324 *);
	int (*restore_noirq)(struct device___324 *);
	int (*runtime_suspend)(struct device___324 *);
	int (*runtime_resume)(struct device___324 *);
	int (*runtime_idle)(struct device___324 *);
};

struct dev_pm_domain___324 {
	struct dev_pm_ops___324 ops;
	void (*detach)(struct device___324 *, bool);
	int (*activate)(struct device___324 *);
	void (*sync)(struct device___324 *);
	void (*dismiss)(struct device___324 *);
};

struct bus_type___324 {
	const char *name;
	const char *dev_name;
	struct device___324 *dev_root;
	const struct attribute_group___321 **bus_groups;
	const struct attribute_group___321 **dev_groups;
	const struct attribute_group___321 **drv_groups;
	int (*match)(struct device___324 *, struct device_driver___324 *);
	int (*uevent)(struct device___324 *, struct kobj_uevent_env *);
	int (*probe)(struct device___324 *);
	int (*remove)(struct device___324 *);
	void (*shutdown)(struct device___324 *);
	int (*online)(struct device___324 *);
	int (*offline)(struct device___324 *);
	int (*suspend)(struct device___324 *, pm_message_t);
	int (*resume)(struct device___324 *);
	int (*num_vf)(struct device___324 *);
	int (*dma_configure)(struct device___324 *);
	const struct dev_pm_ops___324 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___324 {
	const char *name;
	struct bus_type___324 *bus;
	struct module___11 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___324 *);
	int (*remove)(struct device___324 *);
	void (*shutdown)(struct device___324 *);
	int (*suspend)(struct device___324 *, pm_message_t);
	int (*resume)(struct device___324 *);
	const struct attribute_group___321 **groups;
	const struct dev_pm_ops___324 *pm;
	void (*coredump)(struct device___324 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___324 {
	const char *name;
	const struct attribute_group___321 **groups;
	int (*uevent)(struct device___324 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___324 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___324 *);
	const struct dev_pm_ops___324 *pm;
};

struct class___324 {
	const char *name;
	struct module___11 *owner;
	const struct attribute_group___321 **class_groups;
	const struct attribute_group___321 **dev_groups;
	struct kobject___344 *dev_kobj;
	int (*dev_uevent)(struct device___324 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___324 *, umode_t *);
	void (*class_release)(struct class___324 *);
	void (*dev_release)(struct device___324 *);
	int (*shutdown_pre)(struct device___324 *);
	const struct kobj_ns_type_operations___28 *ns_type;
	const void * (*namespace)(struct device___324 *);
	const struct dev_pm_ops___324 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___113 {
	void * (*alloc)(struct device___324 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___324 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___324 *, struct vm_area_struct___358 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___324 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___324 *, struct page___358 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___324 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___324 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___324 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___324 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___324 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___324 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___324 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___324 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___324 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___324 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___324 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___324 *, u64);
	u64 (*get_required_mask)(struct device___324 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct bio_integrity_payload___174 {
	struct bio___174 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___176 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___176 bip_inline_vecs[0];
};

struct disk_part_tbl___94 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___94 *last_lookup;
	struct hd_struct___94 *part[0];
};

struct block_device_operations___91 {
	int (*open)(struct block_device___356 *, fmode_t);
	void (*release)(struct gendisk___94 *, fmode_t);
	int (*rw_page)(struct block_device___356 *, sector_t, struct page___358 *, unsigned int);
	int (*ioctl)(struct block_device___356 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___356 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___94 *, unsigned int);
	int (*media_changed)(struct gendisk___94 *);
	void (*unlock_native_capacity)(struct gendisk___94 *);
	int (*revalidate_disk)(struct gendisk___94 *);
	int (*getgeo)(struct block_device___356 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___356 *, long unsigned int);
	int (*report_zones)(struct gendisk___94 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___11 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bdi_writeback_congested___174 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___174 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bsg_ops___90 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___90 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___90 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___90 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___90(struct request___90 *, blk_status_t);

struct request___90 {
	struct request_queue___90 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___27 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___174 *bio;
	struct bio___174 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___176 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___94 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___90 *saved_end_io;
		} flush;
	};
	struct gendisk___94 *rq_disk;
	struct hd_struct___94 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___90 *end_io;
	void *end_io_data;
	struct request___90 *next_rq;
};

struct blk_mq_hw_ctx___27 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___90 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags___4 *tags;
	struct blk_mq_tags___4 *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	unsigned int rh_reserved_nr_expired;
	struct hlist_node cpuhp_dead;
	struct kobject___344 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___356 *debugfs_dir;
	struct dentry___356 *sched_debugfs_dir;
	struct list_head hctx_list;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___90;

struct elevator_mq_ops___90 {
	int (*init_sched)(struct request_queue___90 *, struct elevator_type___90 *);
	void (*exit_sched)(struct elevator_queue___90 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___27 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___27 *, unsigned int);
	bool (*allow_merge)(struct request_queue___90 *, struct request___90 *, struct bio___174 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx___27 *, struct bio___174 *);
	int (*request_merge)(struct request_queue___90 *, struct request___90 **, struct bio___174 *);
	void (*request_merged)(struct request_queue___90 *, struct request___90 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___90 *, struct request___90 *, struct request___90 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___90 *, struct bio___174 *);
	void (*finish_request)(struct request___90 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___27 *, struct list_head *, bool);
	struct request___90 * (*dispatch_request)(struct blk_mq_hw_ctx___27 *);
	bool (*has_work)(struct blk_mq_hw_ctx___27 *);
	void (*completed_request)(struct request___90 *, u64);
	void (*started_request)(struct request___90 *);
	void (*requeue_request)(struct request___90 *);
	struct request___90 * (*former_request)(struct request_queue___90 *, struct request___90 *);
	struct request___90 * (*next_request)(struct request_queue___90 *, struct request___90 *);
	void (*init_icq)(struct io_cq___94 *);
	void (*exit_icq)(struct io_cq___94 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx___27 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___90;

struct elevator_type___90 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___90 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___90 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___11 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___90 {
	struct elevator_type___90 *type;
	void *elevator_data;
	struct kobject___344 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___90 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___90 *, char *);
	ssize_t (*store)(struct elevator_queue___90 *, const char *, size_t);
};

struct blk_mq_queue_data___27;

typedef blk_status_t queue_rq_fn___27(struct blk_mq_hw_ctx___27 *, const struct blk_mq_queue_data___27 *);

typedef void commit_rqs_fn___27(struct blk_mq_hw_ctx___27 *);

typedef bool get_budget_fn___27(struct blk_mq_hw_ctx___27 *);

typedef void put_budget_fn___27(struct blk_mq_hw_ctx___27 *);

typedef enum blk_eh_timer_return timeout_fn___27(struct request___90 *, bool);

typedef int poll_fn___27(struct blk_mq_hw_ctx___27 *);

typedef void complete_fn___27(struct request___90 *);

typedef int init_hctx_fn___27(struct blk_mq_hw_ctx___27 *, void *, unsigned int);

typedef void exit_hctx_fn___27(struct blk_mq_hw_ctx___27 *, unsigned int);

typedef int init_request_fn___27(struct blk_mq_tag_set___27 *, struct request___90 *, unsigned int, unsigned int);

typedef void exit_request_fn___27(struct blk_mq_tag_set___27 *, struct request___90 *, unsigned int);

typedef bool busy_fn___27(struct request_queue___90 *);

typedef int map_queues_fn___27(struct blk_mq_tag_set___27 *);

typedef void cleanup_rq_fn___27(struct request___90 *);

struct blk_mq_ops___27 {
	queue_rq_fn___27 *queue_rq;
	commit_rqs_fn___27 *commit_rqs;
	get_budget_fn___27 *get_budget;
	put_budget_fn___27 *put_budget;
	timeout_fn___27 *timeout;
	poll_fn___27 *poll;
	complete_fn___27 *complete;
	init_hctx_fn___27 *init_hctx;
	exit_hctx_fn___27 *exit_hctx;
	init_request_fn___27 *init_request;
	exit_request_fn___27 *exit_request;
	void (*initialize_rq_fn)(struct request___90 *);
	busy_fn___27 *busy;
	map_queues_fn___27 *map_queues;
	void (*show_rq)(struct seq_file___9 *, struct request___90 *);
	union {
		cleanup_rq_fn___27 *cleanup_rq;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide45;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct blk_mq_tag_set___27 {
	struct blk_mq_queue_map map[6];
	unsigned int nr_maps;
	const struct blk_mq_ops___27 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	struct blk_mq_tags___4 **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct scsi_target___8;

struct scsi_device___8 {
	struct Scsi_Host___5 *host;
	struct request_queue___90 *request_queue;
	struct list_head siblings;
	struct list_head same_target_siblings;
	atomic_t device_busy;
	atomic_t device_blocked;
	spinlock_t list_lock;
	struct list_head cmd_list;
	struct list_head starved_entry;
	short unsigned int queue_depth;
	short unsigned int max_queue_depth;
	short unsigned int last_queue_full_depth;
	short unsigned int last_queue_full_count;
	long unsigned int last_queue_full_time;
	long unsigned int queue_ramp_up_period;
	long unsigned int last_queue_ramp_up;
	unsigned int id;
	unsigned int channel;
	u64 lun;
	unsigned int manufacturer;
	unsigned int sector_size;
	void *hostdata;
	unsigned char type;
	char scsi_level;
	char inq_periph_qual;
	struct mutex inquiry_mutex;
	unsigned char inquiry_len;
	unsigned char *inquiry;
	const char *vendor;
	const char *model;
	const char *rev;
	struct scsi_vpd *vpd_pg83;
	struct scsi_vpd *vpd_pg80;
	unsigned char current_tag;
	struct scsi_target___8 *sdev_target;
	blist_flags_t sdev_bflags;
	unsigned int eh_timeout;
	unsigned int removable: 1;
	unsigned int changed: 1;
	unsigned int busy: 1;
	unsigned int lockable: 1;
	unsigned int locked: 1;
	unsigned int borken: 1;
	unsigned int disconnect: 1;
	unsigned int soft_reset: 1;
	unsigned int sdtr: 1;
	unsigned int wdtr: 1;
	unsigned int ppr: 1;
	unsigned int tagged_supported: 1;
	unsigned int simple_tags: 1;
	unsigned int was_reset: 1;
	unsigned int expecting_cc_ua: 1;
	unsigned int use_10_for_rw: 1;
	unsigned int use_10_for_ms: 1;
	unsigned int no_report_opcodes: 1;
	unsigned int no_write_same: 1;
	unsigned int use_16_for_rw: 1;
	unsigned int skip_ms_page_8: 1;
	unsigned int skip_ms_page_3f: 1;
	unsigned int skip_vpd_pages: 1;
	unsigned int try_vpd_pages: 1;
	unsigned int use_192_bytes_for_3f: 1;
	unsigned int no_start_on_add: 1;
	unsigned int allow_restart: 1;
	unsigned int manage_start_stop: 1;
	unsigned int start_stop_pwr_cond: 1;
	unsigned int no_uld_attach: 1;
	unsigned int select_no_atn: 1;
	unsigned int fix_capacity: 1;
	unsigned int guess_capacity: 1;
	unsigned int retry_hwerror: 1;
	unsigned int last_sector_bug: 1;
	unsigned int no_read_disc_info: 1;
	unsigned int no_read_capacity_16: 1;
	unsigned int try_rc_10_first: 1;
	unsigned int security_supported: 1;
	unsigned int is_visible: 1;
	unsigned int wce_default_on: 1;
	unsigned int no_dif: 1;
	unsigned int broken_fua: 1;
	unsigned int lun_in_cdb: 1;
	unsigned int unmap_limit_for_ws: 1;
	atomic_t disk_events_disable_depth;
	long unsigned int supported_events[1];
	long unsigned int pending_events[1];
	struct list_head event_list;
	struct work_struct event_work;
	unsigned int max_device_blocked;
	atomic_t iorequest_cnt;
	atomic_t iodone_cnt;
	atomic_t ioerr_cnt;
	struct device___324 sdev_gendev;
	struct device___324 sdev_dev;
	struct execute_work ew;
	struct work_struct requeue_work;
	struct scsi_device_handler *handler;
	void *handler_data;
	unsigned char access_state;
	struct mutex state_mutex;
	enum scsi_device_state sdev_state;
	struct task_struct___358 *quiesced_by;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int sdev_data[0];
};

struct scsi_target___8 {
	struct scsi_device___8 *starget_sdev_user;
	struct list_head siblings;
	struct list_head devices;
	struct device___324 dev;
	struct kref reap_ref;
	unsigned int channel;
	unsigned int id;
	unsigned int create: 1;
	unsigned int single_lun: 1;
	unsigned int pdt_1f_for_no_lun: 1;
	unsigned int no_report_luns: 1;
	unsigned int expecting_lun_change: 1;
	atomic_t target_busy;
	atomic_t target_blocked;
	unsigned int can_queue;
	unsigned int max_target_blocked;
	char scsi_level;
	enum scsi_target_state state;
	void *hostdata;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int starget_data[0];
};

struct blk_mq_queue_data___27 {
	struct request___90 *rq;
	bool last;
	long unsigned int rh_reserved1;
};

struct scsi_cmnd___6 {
	struct scsi_request req;
	struct scsi_device___8 *device;
	struct list_head list;
	struct list_head eh_entry;
	struct delayed_work abort_work;
	struct callback_head rcu;
	int eh_eflags;
	long unsigned int serial_number;
	long unsigned int jiffies_at_alloc;
	int retries;
	int allowed;
	unsigned char prot_op;
	unsigned char prot_type;
	unsigned char prot_flags;
	short unsigned int cmd_len;
	enum dma_data_direction sc_data_direction;
	unsigned char *cmnd;
	struct scsi_data_buffer sdb;
	struct scsi_data_buffer *prot_sdb;
	unsigned int underflow;
	unsigned int transfersize;
	struct request___90 *request;
	unsigned char *sense_buffer;
	void (*scsi_done)(struct scsi_cmnd___6 *);
	struct scsi_pointer SCp;
	unsigned char *host_scribble;
	int result;
	int flags;
	long unsigned int state;
	unsigned char tag;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct scsi_log_buf {
	char buffer[4096];
	long unsigned int map;
};

struct file___358;

struct kiocb___358;

struct vm_area_struct___359;

struct inode___358;

struct file_lock___358;

struct page___359;

struct seq_file___304;

struct file_operations___358 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___358 *, loff_t, int);
	ssize_t (*read)(struct file___358 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___358 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___358 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___358 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___358 *, bool);
	int (*iterate)(struct file___358 *, struct dir_context *);
	int (*iterate_shared)(struct file___358 *, struct dir_context *);
	__poll_t (*poll)(struct file___358 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___358 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___358 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___358 *, struct vm_area_struct___359 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___358 *, struct file___358 *);
	int (*flush)(struct file___358 *, fl_owner_t);
	int (*release)(struct inode___358 *, struct file___358 *);
	int (*fsync)(struct file___358 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___358 *, int);
	int (*lock)(struct file___358 *, int, struct file_lock___358 *);
	ssize_t (*sendpage)(struct file___358 *, struct page___359 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___358 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___358 *, int, struct file_lock___358 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___358 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___358 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___358 *, long int, struct file_lock___358 **, void **);
	long int (*fallocate)(struct file___358 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___304 *, struct file___358 *);
	ssize_t (*copy_file_range)(struct file___358 *, loff_t, struct file___358 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___358 *, loff_t, struct file___358 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___358 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___358 {
	u64 seqnum;
	struct vm_area_struct___359 *vmas[4];
};

struct page_frag___358 {
	struct page___359 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___358;

struct cred___331;

struct bio_list___175;

struct backing_dev_info___175;

struct io_context___95;

struct request_queue___91;

struct vm_struct___264;

struct task_struct___359 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___359 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___358 *mm;
	struct mm_struct___358 *active_mm;
	struct vmacache___358 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___359 *real_parent;
	struct task_struct___359 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___359 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___216 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___216 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___216 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___331 *ptracer_cred;
	const struct cred___331 *real_cred;
	const struct cred___331 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___359 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___175 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___175 *backing_dev_info;
	struct io_context___95 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___358 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___91 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___359 *oom_reaper_list;
	struct vm_struct___264 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___140 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___359 *pgtable_t___358;

struct address_space___357;

struct dev_pagemap___346;

struct page___359 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___357 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___359 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___358 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___358 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___346 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___358;

struct lruvec___358 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___358 *pgdat;
};

struct zone___358 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___358 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___358 {
	struct zone___358 *zone;
	int zone_idx;
};

struct zonelist___358 {
	struct zoneref___358 _zonerefs[25];
};

struct pglist_data___358 {
	struct zone___358 node_zones[3];
	struct zonelist___358 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___359 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___359 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___358 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___359 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___359 *owner;
};

struct secondary_data___359 {
	void *stack;
	struct task_struct___359 *task;
	long int status;
};

struct blocking_notifier_head___358 {
	struct rw_semaphore___359 rwsem;
	struct notifier_block *head;
};

struct kernfs_root___351;

struct kernfs_elem_dir___351 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___351 *root;
};

struct kernfs_node___352;

struct kernfs_syscall_ops___351;

struct kernfs_root___351 {
	struct kernfs_node___352 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___351 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___351 {
	struct kernfs_node___352 *target_kn;
};

struct kernfs_ops___351;

struct kernfs_elem_attr___351 {
	const struct kernfs_ops___351 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___352 *notify_next;
};

struct kernfs_node___352 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___352 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___351 dir;
		struct kernfs_elem_symlink___351 symlink;
		struct kernfs_elem_attr___351 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___351;

struct kernfs_ops___351 {
	int (*open)(struct kernfs_open_file___351 *);
	void (*release)(struct kernfs_open_file___351 *);
	int (*seq_show)(struct seq_file___304 *, void *);
	void * (*seq_start)(struct seq_file___304 *, loff_t *);
	void * (*seq_next)(struct seq_file___304 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___304 *, void *);
	ssize_t (*read)(struct kernfs_open_file___351 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___351 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___351 *, struct vm_area_struct___359 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___351 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___351 {
	int (*remount_fs)(struct kernfs_root___351 *, int *, char *);
	int (*show_options)(struct seq_file___304 *, struct kernfs_root___351 *);
	int (*mkdir)(struct kernfs_node___352 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___352 *);
	int (*rename)(struct kernfs_node___352 *, struct kernfs_node___352 *, const char *);
	int (*show_path)(struct seq_file___304 *, struct kernfs_node___352 *, struct kernfs_root___351 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___303;

struct seq_file___304 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___303 *op;
	int poll_event;
	const struct file___358 *file;
	void *private;
};

struct vm_operations_struct___346;

struct kernfs_open_file___351 {
	struct kernfs_node___352 *kn;
	struct file___358 *file;
	struct seq_file___304 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___346 *vm_ops;
};

struct dentry___357;

struct path___358 {
	struct vfsmount *mnt;
	struct dentry___357 *dentry;
};

struct file___358 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___358 f_path;
	struct inode___358 *f_inode;
	const struct file_operations___358 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___216 f_owner;
	const struct cred___331 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___357 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___346;

struct vm_operations_struct___346 {
	void (*open)(struct vm_area_struct___359 *);
	void (*close)(struct vm_area_struct___359 *);
	int (*split)(struct vm_area_struct___359 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___359 *);
	vm_fault_t (*fault)(struct vm_fault___346 *);
	vm_fault_t (*huge_fault)(struct vm_fault___346 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___346 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___359 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___346 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___346 *);
	int (*access)(struct vm_area_struct___359 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___359 *);
	int (*set_policy)(struct vm_area_struct___359 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___359 *, long unsigned int);
	struct page___359 * (*find_special_page)(struct vm_area_struct___359 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_area_struct___359 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___359 *vm_next;
	struct vm_area_struct___359 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___358 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___346 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___358 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___345;

struct bin_attribute___321;

struct attribute_group___322 {
	const char *name;
	umode_t (*is_visible)(struct kobject___345 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___345 *, struct bin_attribute___321 *, int);
	struct attribute **attrs;
	struct bin_attribute___321 **bin_attrs;
};

struct kset___344;

struct kobj_type___344;

struct kobject___345 {
	const char *name;
	struct list_head entry;
	struct kobject___345 *parent;
	struct kset___344 *kset;
	struct kobj_type___344 *ktype;
	struct kernfs_node___352 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___321 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___358 *, struct kobject___345 *, struct bin_attribute___321 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___358 *, struct kobject___345 *, struct bin_attribute___321 *, char *, loff_t, size_t);
	int (*mmap)(struct file___358 *, struct kobject___345 *, struct bin_attribute___321 *, struct vm_area_struct___359 *);
};

struct sysfs_ops___344 {
	ssize_t (*show)(struct kobject___345 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___345 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___344;

struct kset___344 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___345 kobj;
	const struct kset_uevent_ops___344 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___344 {
	void (*release)(struct kobject___345 *);
	const struct sysfs_ops___344 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___28 * (*child_ns_type)(struct kobject___345 *);
	const void * (*namespace)(struct kobject___345 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___344 {
	int (* const filter)(struct kset___344 *, struct kobject___345 *);
	const char * (* const name)(struct kset___344 *, struct kobject___345 *);
	int (* const uevent)(struct kset___344 *, struct kobject___345 *, struct kobj_uevent_env *);
};

struct kobj_attribute___336 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___345 *, struct kobj_attribute___336 *, char *);
	ssize_t (*store)(struct kobject___345 *, struct kobj_attribute___336 *, const char *, size_t);
};

struct device___325;

struct dev_pm_ops___325 {
	int (*prepare)(struct device___325 *);
	void (*complete)(struct device___325 *);
	int (*suspend)(struct device___325 *);
	int (*resume)(struct device___325 *);
	int (*freeze)(struct device___325 *);
	int (*thaw)(struct device___325 *);
	int (*poweroff)(struct device___325 *);
	int (*restore)(struct device___325 *);
	int (*suspend_late)(struct device___325 *);
	int (*resume_early)(struct device___325 *);
	int (*freeze_late)(struct device___325 *);
	int (*thaw_early)(struct device___325 *);
	int (*poweroff_late)(struct device___325 *);
	int (*restore_early)(struct device___325 *);
	int (*suspend_noirq)(struct device___325 *);
	int (*resume_noirq)(struct device___325 *);
	int (*freeze_noirq)(struct device___325 *);
	int (*thaw_noirq)(struct device___325 *);
	int (*poweroff_noirq)(struct device___325 *);
	int (*restore_noirq)(struct device___325 *);
	int (*runtime_suspend)(struct device___325 *);
	int (*runtime_resume)(struct device___325 *);
	int (*runtime_idle)(struct device___325 *);
};

struct dev_pm_info___325 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___5 *subsys_data;
	void (*set_latency_tolerance)(struct device___325 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___325;

struct bus_type___325;

struct device_driver___325;

struct dev_pm_domain___325;

struct fwnode_handle___247;

struct class___325;

struct device___325 {
	struct device___325 *parent;
	struct device_private *p;
	struct kobject___345 kobj;
	const char *init_name;
	const struct device_type___325 *type;
	struct mutex mutex;
	struct bus_type___325 *bus;
	struct device_driver___325 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___325 power;
	struct dev_pm_domain___325 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___247 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___325 *class;
	const struct attribute_group___322 **groups;
	void (*release)(struct device___325 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___325 {
	struct dev_pm_ops___325 ops;
	void (*detach)(struct device___325 *, bool);
	int (*activate)(struct device___325 *);
	void (*sync)(struct device___325 *);
	void (*dismiss)(struct device___325 *);
};

struct key___331;

struct user_struct___331 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___331 *uid_keyring;
	struct key___331 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___358;

struct mm_struct___358 {
	struct {
		struct vm_area_struct___359 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___358 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___359 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___358 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___359 *owner;
		struct user_namespace___3 *user_ns;
		struct file___358 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___358 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___331 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___331 *session_keyring;
	struct key___331 *process_keyring;
	struct key___331 *thread_keyring;
	struct key___331 *request_key_auth;
	void *security;
	struct user_struct___331 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct bio___175;

struct bio_list___175 {
	struct bio___175 *head;
	struct bio___175 *tail;
};

struct bdi_writeback_congested___175;

struct bdi_writeback___175 {
	struct backing_dev_info___175 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___175 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___157 *memcg_css;
	struct cgroup_subsys_state___157 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___175 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___175 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___325 *dev;
	struct device___325 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___357 *debug_dir;
	struct dentry___357 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___95;

struct io_context___95 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___95 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

typedef blk_qc_t make_request_fn___91(struct request_queue___91 *, struct bio___175 *);

struct request___91;

typedef int dma_drain_needed_fn___91(struct request___91 *);

struct bsg_ops___91;

struct bsg_class_device___91 {
	struct device___325 *class_dev;
	int minor;
	struct request_queue___91 *queue;
	const struct bsg_ops___91 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___175 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___175 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___91;

struct blk_mq_ops___28;

struct blk_mq_hw_ctx___28;

struct blk_mq_tag_set___28;

struct request_queue___91 {
	struct list_head queue_head;
	struct request___91 *last_merge;
	struct elevator_queue___91 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___91 *make_request_fn;
	dma_drain_needed_fn___91 *dma_drain_needed;
	const struct blk_mq_ops___28 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___28 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___175 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___345 kobj;
	struct kobject___345 *mq_kobj;
	struct blk_integrity integrity;
	struct device___325 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	struct bsg_class_device___91 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set___28 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___175 bio_split;
	struct dentry___357 *debugfs_dir;
	struct dentry___357 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___264 {
	struct vm_struct___264 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___359 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bus_type___325 {
	const char *name;
	const char *dev_name;
	struct device___325 *dev_root;
	const struct attribute_group___322 **bus_groups;
	const struct attribute_group___322 **dev_groups;
	const struct attribute_group___322 **drv_groups;
	int (*match)(struct device___325 *, struct device_driver___325 *);
	int (*uevent)(struct device___325 *, struct kobj_uevent_env *);
	int (*probe)(struct device___325 *);
	int (*remove)(struct device___325 *);
	void (*shutdown)(struct device___325 *);
	int (*online)(struct device___325 *);
	int (*offline)(struct device___325 *);
	int (*suspend)(struct device___325 *, pm_message_t);
	int (*resume)(struct device___325 *);
	int (*num_vf)(struct device___325 *);
	int (*dma_configure)(struct device___325 *);
	const struct dev_pm_ops___325 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___325 {
	const char *name;
	struct bus_type___325 *bus;
	struct module___11 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___325 *);
	int (*remove)(struct device___325 *);
	void (*shutdown)(struct device___325 *);
	int (*suspend)(struct device___325 *, pm_message_t);
	int (*resume)(struct device___325 *);
	const struct attribute_group___322 **groups;
	const struct dev_pm_ops___325 *pm;
	void (*coredump)(struct device___325 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___325 {
	const char *name;
	const struct attribute_group___322 **groups;
	int (*uevent)(struct device___325 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___325 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___325 *);
	const struct dev_pm_ops___325 *pm;
};

struct class___325 {
	const char *name;
	struct module___11 *owner;
	const struct attribute_group___322 **class_groups;
	const struct attribute_group___322 **dev_groups;
	struct kobject___345 *dev_kobj;
	int (*dev_uevent)(struct device___325 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___325 *, umode_t *);
	void (*class_release)(struct class___325 *);
	void (*dev_release)(struct device___325 *);
	int (*shutdown_pre)(struct device___325 *);
	const struct kobj_ns_type_operations___28 *ns_type;
	const void * (*namespace)(struct device___325 *);
	const struct dev_pm_ops___325 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct device_attribute___39 {
	struct attribute attr;
	ssize_t (*show)(struct device___325 *, struct device_attribute___39 *, char *);
	ssize_t (*store)(struct device___325 *, struct device_attribute___39 *, const char *, size_t);
};

struct fwnode_operations___247;

struct fwnode_handle___247 {
	struct fwnode_handle___247 *secondary;
	const struct fwnode_operations___247 *ops;
};

struct address_space_operations___357;

struct address_space___357 {
	struct inode___358 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___359 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___357 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___346)(struct vm_area_struct___359 *, long unsigned int, const struct page___359 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___346)(struct page___359 *, void *);

struct dev_pagemap___346 {
	dev_page_fault_t___346 page_fault;
	dev_page_free_t___346 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___325 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___358 {
	struct task_struct___359 *task;
	struct core_thread___358 *next;
};

struct core_state___358 {
	atomic_t nr_threads;
	struct core_thread___358 dumper;
	struct completion startup;
};

struct vm_fault___346 {
	struct vm_area_struct___359 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___359 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___359 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___358 prealloc_pte;
};

struct dentry_operations___357;

struct super_block___357;

struct dentry___357 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___357 *d_parent;
	struct qstr d_name;
	struct inode___358 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___357 *d_op;
	struct super_block___357 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___357;

struct block_device___357;

struct inode___358 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___357 *i_op;
	struct super_block___357 *i_sb;
	struct address_space___357 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___359 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___175 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___358 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___357 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___357 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___357 {
	int (*d_revalidate)(struct dentry___357 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___357 *, unsigned int);
	int (*d_hash)(const struct dentry___357 *, struct qstr *);
	int (*d_compare)(const struct dentry___357 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___357 *);
	int (*d_init)(struct dentry___357 *);
	void (*d_release)(struct dentry___357 *);
	void (*d_prune)(struct dentry___357 *);
	void (*d_iput)(struct dentry___357 *, struct inode___358 *);
	char * (*d_dname)(struct dentry___357 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___358 *);
	int (*d_manage)(const struct path___358 *, bool);
	struct dentry___357 * (*d_real)(struct dentry___357 *, const struct inode___358 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___357;

struct mem_dqinfo___357 {
	struct quota_format_type___357 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___357;

struct quota_info___357 {
	unsigned int flags;
	struct rw_semaphore___359 dqio_sem;
	struct inode___358 *files[3];
	struct mem_dqinfo___357 info[3];
	const struct quota_format_ops___357 *ops[3];
};

struct rcuwait___357 {
	struct task_struct___359 *task;
};

struct percpu_rw_semaphore___357 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___359 rw_sem;
	struct rcuwait___357 writer;
	int readers_block;
};

struct sb_writers___357 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___357 rw_sem[3];
};

struct file_system_type___357;

struct super_operations___357;

struct dquot_operations___357;

struct quotactl_ops___357;

struct super_block___357 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___357 *s_type;
	const struct super_operations___357 *s_op;
	const struct dquot_operations___357 *dq_op;
	const struct quotactl_ops___357 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___357 *s_root;
	struct rw_semaphore___359 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___357 *s_bdev;
	struct backing_dev_info___175 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___357 s_dquot;
	struct sb_writers___357 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___357 *s_d_op;
	int cleancache_poolid;
	struct shrinker___131 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct io_cq___95 {
	struct request_queue___91 *q;
	struct io_context___95 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___358 {
	struct file___358 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___358 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___357 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___358 *ia_file;
};

struct dquot___357 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___357 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___357 {
	int qf_fmt_id;
	const struct quota_format_ops___357 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___357 *qf_next;
};

struct quota_format_ops___357 {
	int (*check_quota_file)(struct super_block___357 *, int);
	int (*read_file_info)(struct super_block___357 *, int);
	int (*write_file_info)(struct super_block___357 *, int);
	int (*free_file_info)(struct super_block___357 *, int);
	int (*read_dqblk)(struct dquot___357 *);
	int (*commit_dqblk)(struct dquot___357 *);
	int (*release_dqblk)(struct dquot___357 *);
	int (*get_next_id)(struct super_block___357 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___357 {
	int (*write_dquot)(struct dquot___357 *);
	struct dquot___357 * (*alloc_dquot)(struct super_block___357 *, int);
	void (*destroy_dquot)(struct dquot___357 *);
	int (*acquire_dquot)(struct dquot___357 *);
	int (*release_dquot)(struct dquot___357 *);
	int (*mark_dirty)(struct dquot___357 *);
	int (*write_info)(struct super_block___357 *, int);
	qsize_t * (*get_reserved_space)(struct inode___358 *);
	int (*get_projid)(struct inode___358 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___358 *, qsize_t *);
	int (*get_next_id)(struct super_block___357 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___357 {
	int (*quota_on)(struct super_block___357 *, int, int, const struct path___358 *);
	int (*quota_off)(struct super_block___357 *, int);
	int (*quota_enable)(struct super_block___357 *, unsigned int);
	int (*quota_disable)(struct super_block___357 *, unsigned int);
	int (*quota_sync)(struct super_block___357 *, int);
	int (*set_info)(struct super_block___357 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___357 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___357 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___357 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___357 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___357 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___357 {
	int (*writepage)(struct page___359 *, struct writeback_control___3 *);
	int (*readpage)(struct file___358 *, struct page___359 *);
	int (*writepages)(struct address_space___357 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___359 *);
	int (*readpages)(struct file___358 *, struct address_space___357 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___358 *, struct address_space___357 *, loff_t, unsigned int, unsigned int, struct page___359 **, void **);
	int (*write_end)(struct file___358 *, struct address_space___357 *, loff_t, unsigned int, unsigned int, struct page___359 *, void *);
	sector_t (*bmap)(struct address_space___357 *, sector_t);
	void (*invalidatepage)(struct page___359 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___359 *, gfp_t);
	void (*freepage)(struct page___359 *);
	ssize_t (*direct_IO)(struct kiocb___358 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___357 *, struct page___359 *, struct page___359 *, enum migrate_mode);
	bool (*isolate_page)(struct page___359 *, isolate_mode_t);
	void (*putback_page)(struct page___359 *);
	int (*launder_page)(struct page___359 *);
	int (*is_partially_uptodate)(struct page___359 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___359 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___357 *, struct page___359 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___358 *, sector_t *);
	void (*swap_deactivate)(struct file___358 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct hd_struct___95;

struct gendisk___95;

struct block_device___357 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___358 *bd_inode;
	struct super_block___357 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___357 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___95 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___95 *bd_disk;
	struct request_queue___91 *bd_queue;
	struct backing_dev_info___175 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct hd_struct___95 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___325 __dev;
	struct kobject___345 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___95;

struct block_device_operations___92;

struct gendisk___95 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___95 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___95 *part_tbl;
	struct hd_struct___95 part0;
	const struct block_device_operations___92 *fops;
	struct request_queue___91 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___359 lookup_sem;
	struct kobject___345 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___345 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___357 {
	struct dentry___357 * (*lookup)(struct inode___358 *, struct dentry___357 *, unsigned int);
	const char * (*get_link)(struct dentry___357 *, struct inode___358 *, struct delayed_call *);
	int (*permission)(struct inode___358 *, int);
	struct posix_acl * (*get_acl)(struct inode___358 *, int);
	int (*readlink)(struct dentry___357 *, char *, int);
	int (*create)(struct inode___358 *, struct dentry___357 *, umode_t, bool);
	int (*link)(struct dentry___357 *, struct inode___358 *, struct dentry___357 *);
	int (*unlink)(struct inode___358 *, struct dentry___357 *);
	int (*symlink)(struct inode___358 *, struct dentry___357 *, const char *);
	int (*mkdir)(struct inode___358 *, struct dentry___357 *, umode_t);
	int (*rmdir)(struct inode___358 *, struct dentry___357 *);
	int (*mknod)(struct inode___358 *, struct dentry___357 *, umode_t, dev_t);
	int (*rename)(struct inode___358 *, struct dentry___357 *, struct inode___358 *, struct dentry___357 *, unsigned int);
	int (*setattr)(struct dentry___357 *, struct iattr___357 *);
	int (*getattr)(const struct path___358 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___357 *, char *, size_t);
	int (*fiemap)(struct inode___358 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___358 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___358 *, struct dentry___357 *, struct file___358 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___358 *, struct dentry___357 *, umode_t);
	int (*set_acl)(struct inode___358 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___357 {
	void (*fl_copy_lock)(struct file_lock___358 *, struct file_lock___358 *);
	void (*fl_release_private)(struct file_lock___358 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___357;

struct lock_manager_operations___357;

struct file_lock___358 {
	struct file_lock___358 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___358 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___357 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___357 *fl_ops;
	const struct lock_manager_operations___357 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___357 {
	int (*lm_compare_owner)(struct file_lock___358 *, struct file_lock___358 *);
	long unsigned int (*lm_owner_key)(struct file_lock___358 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___358 *);
	int (*lm_grant)(struct file_lock___358 *, int);
	bool (*lm_break)(struct file_lock___358 *);
	int (*lm_change)(struct file_lock___358 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___358 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___357 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___357 *fa_next;
	struct file___358 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___357 {
	const char *name;
	int fs_flags;
	struct dentry___357 * (*mount)(struct file_system_type___357 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___357 *);
	struct module___11 *owner;
	struct file_system_type___357 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___357 {
	struct inode___358 * (*alloc_inode)(struct super_block___357 *);
	void (*destroy_inode)(struct inode___358 *);
	void (*dirty_inode)(struct inode___358 *, int);
	int (*write_inode)(struct inode___358 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___358 *);
	void (*evict_inode)(struct inode___358 *);
	void (*put_super)(struct super_block___357 *);
	int (*sync_fs)(struct super_block___357 *, int);
	int (*freeze_super)(struct super_block___357 *);
	int (*freeze_fs)(struct super_block___357 *);
	int (*thaw_super)(struct super_block___357 *);
	int (*unfreeze_fs)(struct super_block___357 *);
	int (*statfs)(struct dentry___357 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___357 *, int *, char *);
	void (*umount_begin)(struct super_block___357 *);
	int (*show_options)(struct seq_file___304 *, struct dentry___357 *);
	int (*show_devname)(struct seq_file___304 *, struct dentry___357 *);
	int (*show_path)(struct seq_file___304 *, struct dentry___357 *);
	int (*show_stats)(struct seq_file___304 *, struct dentry___357 *);
	ssize_t (*quota_read)(struct super_block___357 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___357 *, int, const char *, size_t, loff_t);
	struct dquot___357 ** (*get_dquots)(struct inode___358 *);
	int (*bdev_try_to_free_page)(struct super_block___357 *, struct page___359 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___357 *, struct shrink_control___131 *);
	long int (*free_cached_objects)(struct super_block___357 *, struct shrink_control___131 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___175(struct bio___175 *);

struct bio_vec___177 {
	struct page___359 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___175;

struct bio___175 {
	struct bio___175 *bi_next;
	struct gendisk___95 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___175 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___175 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___177 *bi_io_vec;
	struct bio_set___175 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___177 bi_inline_vecs[0];
};

typedef void compound_page_dtor___346(struct page___359 *);

struct fwnode_reference_args___247;

struct fwnode_endpoint___247;

struct fwnode_operations___247 {
	struct fwnode_handle___247 * (*get)(struct fwnode_handle___247 *);
	void (*put)(struct fwnode_handle___247 *);
	bool (*device_is_available)(const struct fwnode_handle___247 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___247 *, const struct device___325 *);
	bool (*property_present)(const struct fwnode_handle___247 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___247 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___247 *, const char *, const char **, size_t);
	struct fwnode_handle___247 * (*get_parent)(const struct fwnode_handle___247 *);
	struct fwnode_handle___247 * (*get_next_child_node)(const struct fwnode_handle___247 *, struct fwnode_handle___247 *);
	struct fwnode_handle___247 * (*get_named_child_node)(const struct fwnode_handle___247 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___247 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___247 *);
	struct fwnode_handle___247 * (*graph_get_next_endpoint)(const struct fwnode_handle___247 *, struct fwnode_handle___247 *);
	struct fwnode_handle___247 * (*graph_get_remote_endpoint)(const struct fwnode_handle___247 *);
	struct fwnode_handle___247 * (*graph_get_port_parent)(struct fwnode_handle___247 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___247 *, struct fwnode_endpoint___247 *);
};

struct fwnode_endpoint___247 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___247 *local_fwnode;
};

struct fwnode_reference_args___247 {
	struct fwnode_handle___247 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct bio_integrity_payload___175 {
	struct bio___175 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___177 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___177 bip_inline_vecs[0];
};

struct disk_part_tbl___95 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___95 *last_lookup;
	struct hd_struct___95 *part[0];
};

struct block_device_operations___92 {
	int (*open)(struct block_device___357 *, fmode_t);
	void (*release)(struct gendisk___95 *, fmode_t);
	int (*rw_page)(struct block_device___357 *, sector_t, struct page___359 *, unsigned int);
	int (*ioctl)(struct block_device___357 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___357 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___95 *, unsigned int);
	int (*media_changed)(struct gendisk___95 *);
	void (*unlock_native_capacity)(struct gendisk___95 *);
	int (*revalidate_disk)(struct gendisk___95 *);
	int (*getgeo)(struct block_device___357 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___357 *, long unsigned int);
	int (*report_zones)(struct gendisk___95 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___11 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bdi_writeback_congested___175 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___175 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bsg_ops___91 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___91 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___91 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___91 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___91(struct request___91 *, blk_status_t);

struct request___91 {
	struct request_queue___91 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___28 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___175 *bio;
	struct bio___175 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___177 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___95 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___91 *saved_end_io;
		} flush;
	};
	struct gendisk___95 *rq_disk;
	struct hd_struct___95 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___91 *end_io;
	void *end_io_data;
	struct request___91 *next_rq;
};

struct blk_mq_hw_ctx___28 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___91 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags___4 *tags;
	struct blk_mq_tags___4 *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	unsigned int rh_reserved_nr_expired;
	struct hlist_node cpuhp_dead;
	struct kobject___345 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___357 *debugfs_dir;
	struct dentry___357 *sched_debugfs_dir;
	struct list_head hctx_list;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___91;

struct elevator_mq_ops___91 {
	int (*init_sched)(struct request_queue___91 *, struct elevator_type___91 *);
	void (*exit_sched)(struct elevator_queue___91 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___28 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___28 *, unsigned int);
	bool (*allow_merge)(struct request_queue___91 *, struct request___91 *, struct bio___175 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx___28 *, struct bio___175 *);
	int (*request_merge)(struct request_queue___91 *, struct request___91 **, struct bio___175 *);
	void (*request_merged)(struct request_queue___91 *, struct request___91 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___91 *, struct request___91 *, struct request___91 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___91 *, struct bio___175 *);
	void (*finish_request)(struct request___91 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___28 *, struct list_head *, bool);
	struct request___91 * (*dispatch_request)(struct blk_mq_hw_ctx___28 *);
	bool (*has_work)(struct blk_mq_hw_ctx___28 *);
	void (*completed_request)(struct request___91 *, u64);
	void (*started_request)(struct request___91 *);
	void (*requeue_request)(struct request___91 *);
	struct request___91 * (*former_request)(struct request_queue___91 *, struct request___91 *);
	struct request___91 * (*next_request)(struct request_queue___91 *, struct request___91 *);
	void (*init_icq)(struct io_cq___95 *);
	void (*exit_icq)(struct io_cq___95 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx___28 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___91;

struct elevator_type___91 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___91 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___91 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___11 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___91 {
	struct elevator_type___91 *type;
	void *elevator_data;
	struct kobject___345 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___91 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___91 *, char *);
	ssize_t (*store)(struct elevator_queue___91 *, const char *, size_t);
};

struct blk_mq_queue_data___28;

typedef blk_status_t queue_rq_fn___28(struct blk_mq_hw_ctx___28 *, const struct blk_mq_queue_data___28 *);

typedef void commit_rqs_fn___28(struct blk_mq_hw_ctx___28 *);

typedef bool get_budget_fn___28(struct blk_mq_hw_ctx___28 *);

typedef void put_budget_fn___28(struct blk_mq_hw_ctx___28 *);

typedef enum blk_eh_timer_return timeout_fn___28(struct request___91 *, bool);

typedef int poll_fn___28(struct blk_mq_hw_ctx___28 *);

typedef void complete_fn___28(struct request___91 *);

typedef int init_hctx_fn___28(struct blk_mq_hw_ctx___28 *, void *, unsigned int);

typedef void exit_hctx_fn___28(struct blk_mq_hw_ctx___28 *, unsigned int);

typedef int init_request_fn___28(struct blk_mq_tag_set___28 *, struct request___91 *, unsigned int, unsigned int);

typedef void exit_request_fn___28(struct blk_mq_tag_set___28 *, struct request___91 *, unsigned int);

typedef bool busy_fn___28(struct request_queue___91 *);

typedef int map_queues_fn___28(struct blk_mq_tag_set___28 *);

typedef void cleanup_rq_fn___28(struct request___91 *);

struct blk_mq_ops___28 {
	queue_rq_fn___28 *queue_rq;
	commit_rqs_fn___28 *commit_rqs;
	get_budget_fn___28 *get_budget;
	put_budget_fn___28 *put_budget;
	timeout_fn___28 *timeout;
	poll_fn___28 *poll;
	complete_fn___28 *complete;
	init_hctx_fn___28 *init_hctx;
	exit_hctx_fn___28 *exit_hctx;
	init_request_fn___28 *init_request;
	exit_request_fn___28 *exit_request;
	void (*initialize_rq_fn)(struct request___91 *);
	busy_fn___28 *busy;
	map_queues_fn___28 *map_queues;
	void (*show_rq)(struct seq_file___304 *, struct request___91 *);
	union {
		cleanup_rq_fn___28 *cleanup_rq;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide42;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct blk_mq_tag_set___28 {
	struct blk_mq_queue_map map[6];
	unsigned int nr_maps;
	const struct blk_mq_ops___28 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	struct blk_mq_tags___4 **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct Scsi_Host___6;

struct scsi_target___9;

struct scsi_device___9 {
	struct Scsi_Host___6 *host;
	struct request_queue___91 *request_queue;
	struct list_head siblings;
	struct list_head same_target_siblings;
	atomic_t device_busy;
	atomic_t device_blocked;
	spinlock_t list_lock;
	struct list_head cmd_list;
	struct list_head starved_entry;
	short unsigned int queue_depth;
	short unsigned int max_queue_depth;
	short unsigned int last_queue_full_depth;
	short unsigned int last_queue_full_count;
	long unsigned int last_queue_full_time;
	long unsigned int queue_ramp_up_period;
	long unsigned int last_queue_ramp_up;
	unsigned int id;
	unsigned int channel;
	u64 lun;
	unsigned int manufacturer;
	unsigned int sector_size;
	void *hostdata;
	unsigned char type;
	char scsi_level;
	char inq_periph_qual;
	struct mutex inquiry_mutex;
	unsigned char inquiry_len;
	unsigned char *inquiry;
	const char *vendor;
	const char *model;
	const char *rev;
	struct scsi_vpd *vpd_pg83;
	struct scsi_vpd *vpd_pg80;
	unsigned char current_tag;
	struct scsi_target___9 *sdev_target;
	blist_flags_t sdev_bflags;
	unsigned int eh_timeout;
	unsigned int removable: 1;
	unsigned int changed: 1;
	unsigned int busy: 1;
	unsigned int lockable: 1;
	unsigned int locked: 1;
	unsigned int borken: 1;
	unsigned int disconnect: 1;
	unsigned int soft_reset: 1;
	unsigned int sdtr: 1;
	unsigned int wdtr: 1;
	unsigned int ppr: 1;
	unsigned int tagged_supported: 1;
	unsigned int simple_tags: 1;
	unsigned int was_reset: 1;
	unsigned int expecting_cc_ua: 1;
	unsigned int use_10_for_rw: 1;
	unsigned int use_10_for_ms: 1;
	unsigned int no_report_opcodes: 1;
	unsigned int no_write_same: 1;
	unsigned int use_16_for_rw: 1;
	unsigned int skip_ms_page_8: 1;
	unsigned int skip_ms_page_3f: 1;
	unsigned int skip_vpd_pages: 1;
	unsigned int try_vpd_pages: 1;
	unsigned int use_192_bytes_for_3f: 1;
	unsigned int no_start_on_add: 1;
	unsigned int allow_restart: 1;
	unsigned int manage_start_stop: 1;
	unsigned int start_stop_pwr_cond: 1;
	unsigned int no_uld_attach: 1;
	unsigned int select_no_atn: 1;
	unsigned int fix_capacity: 1;
	unsigned int guess_capacity: 1;
	unsigned int retry_hwerror: 1;
	unsigned int last_sector_bug: 1;
	unsigned int no_read_disc_info: 1;
	unsigned int no_read_capacity_16: 1;
	unsigned int try_rc_10_first: 1;
	unsigned int security_supported: 1;
	unsigned int is_visible: 1;
	unsigned int wce_default_on: 1;
	unsigned int no_dif: 1;
	unsigned int broken_fua: 1;
	unsigned int lun_in_cdb: 1;
	unsigned int unmap_limit_for_ws: 1;
	atomic_t disk_events_disable_depth;
	long unsigned int supported_events[1];
	long unsigned int pending_events[1];
	struct list_head event_list;
	struct work_struct event_work;
	unsigned int max_device_blocked;
	atomic_t iorequest_cnt;
	atomic_t iodone_cnt;
	atomic_t ioerr_cnt;
	struct device___325 sdev_gendev;
	struct device___325 sdev_dev;
	struct execute_work ew;
	struct work_struct requeue_work;
	struct scsi_device_handler *handler;
	void *handler_data;
	unsigned char access_state;
	struct mutex state_mutex;
	enum scsi_device_state sdev_state;
	struct task_struct___359 *quiesced_by;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int sdev_data[0];
};

struct scsi_host_template___6;

struct Scsi_Host___6 {
	struct list_head __devices;
	struct list_head __targets;
	struct list_head starved_list;
	spinlock_t default_lock;
	spinlock_t *host_lock;
	struct mutex scan_mutex;
	struct list_head eh_cmd_q;
	struct task_struct___359 *ehandler;
	struct completion *eh_action;
	wait_queue_head_t host_wait;
	struct scsi_host_template___6 *hostt;
	struct scsi_transport_template *transportt;
	struct blk_mq_tag_set___28 tag_set;
	atomic_t host_busy;
	atomic_t host_blocked;
	unsigned int host_failed;
	unsigned int host_eh_scheduled;
	unsigned int host_no;
	int eh_deadline;
	long unsigned int last_reset;
	unsigned int max_channel;
	unsigned int max_id;
	u64 max_lun;
	unsigned int unique_id;
	short unsigned int max_cmd_len;
	int this_id;
	int can_queue;
	short int cmd_per_lun;
	short unsigned int sg_tablesize;
	short unsigned int sg_prot_tablesize;
	unsigned int max_sectors;
	long unsigned int dma_boundary;
	unsigned int nr_hw_queues;
	long unsigned int cmd_serial_number;
	unsigned int active_mode: 2;
	unsigned int unchecked_isa_dma: 1;
	unsigned int use_clustering: 1;
	unsigned int host_self_blocked: 1;
	unsigned int reverse_ordering: 1;
	unsigned int tmf_in_progress: 1;
	unsigned int async_scan: 1;
	unsigned int eh_noresume: 1;
	unsigned int no_write_same: 1;
	unsigned int use_cmd_list: 1;
	unsigned int short_inquiry: 1;
	char work_q_name[20];
	struct workqueue_struct *work_q;
	struct workqueue_struct *tmf_work_q;
	unsigned int no_scsi2_lun_in_cdb: 1;
	unsigned int max_host_blocked;
	unsigned int prot_capabilities;
	unsigned char prot_guard_type;
	long unsigned int base;
	long unsigned int io_port;
	unsigned char n_io_port;
	unsigned char dma_channel;
	unsigned int irq;
	enum scsi_host_state shost_state;
	struct device___325 shost_gendev;
	struct device___325 shost_dev;
	void *shost_data;
	struct device___325 *dma_dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int hostdata[0];
};

struct scsi_target___9 {
	struct scsi_device___9 *starget_sdev_user;
	struct list_head siblings;
	struct list_head devices;
	struct device___325 dev;
	struct kref reap_ref;
	unsigned int channel;
	unsigned int id;
	unsigned int create: 1;
	unsigned int single_lun: 1;
	unsigned int pdt_1f_for_no_lun: 1;
	unsigned int no_report_luns: 1;
	unsigned int expecting_lun_change: 1;
	atomic_t target_busy;
	atomic_t target_blocked;
	unsigned int can_queue;
	unsigned int max_target_blocked;
	char scsi_level;
	enum scsi_target_state state;
	void *hostdata;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int starget_data[0];
};

typedef int (*key_restrict_link_func_t___332)(struct key___331 *, const struct key_type *, const union key_payload *, struct key___331 *);

struct key_restriction___331;

struct key___331 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___359 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___331 *restrict_link;
};

struct key_restriction___331 {
	key_restrict_link_func_t___332 check;
	struct key___331 *key;
	struct key_type *keytype;
};

struct seq_operations___303 {
	void * (*start)(struct seq_file___304 *, loff_t *);
	void (*stop)(struct seq_file___304 *, void *);
	void * (*next)(struct seq_file___304 *, void *, loff_t *);
	int (*show)(struct seq_file___304 *, void *);
};

struct blk_mq_queue_data___28 {
	struct request___91 *rq;
	bool last;
	long unsigned int rh_reserved1;
};

struct scsi_host_template___6 {
	struct module___11 *module;
	const char *name;
	const char * (*info)(struct Scsi_Host___6 *);
	int (*ioctl)(struct scsi_device___9 *, int, void *);
	int (*queuecommand)(struct Scsi_Host___6 *, struct scsi_cmnd___2 *);
	int (*eh_abort_handler)(struct scsi_cmnd___2 *);
	int (*eh_device_reset_handler)(struct scsi_cmnd___2 *);
	int (*eh_target_reset_handler)(struct scsi_cmnd___2 *);
	int (*eh_bus_reset_handler)(struct scsi_cmnd___2 *);
	int (*eh_host_reset_handler)(struct scsi_cmnd___2 *);
	int (*slave_alloc)(struct scsi_device___9 *);
	int (*slave_configure)(struct scsi_device___9 *);
	void (*slave_destroy)(struct scsi_device___9 *);
	int (*target_alloc)(struct scsi_target___9 *);
	void (*target_destroy)(struct scsi_target___9 *);
	int (*scan_finished)(struct Scsi_Host___6 *, long unsigned int);
	void (*scan_start)(struct Scsi_Host___6 *);
	int (*change_queue_depth)(struct scsi_device___9 *, int);
	int (*map_queues)(struct Scsi_Host___6 *);
	int (*bios_param)(struct scsi_device___9 *, struct block_device___357 *, sector_t, int *);
	void (*unlock_native_capacity)(struct scsi_device___9 *);
	int (*show_info)(struct seq_file___304 *, struct Scsi_Host___6 *);
	int (*write_info)(struct Scsi_Host___6 *, char *, int);
	enum blk_eh_timer_return (*eh_timed_out)(struct scsi_cmnd___2 *);
	int (*host_reset)(struct Scsi_Host___6 *, int);
	const char *proc_name;
	struct proc_dir_entry *proc_dir;
	int can_queue;
	int this_id;
	short unsigned int sg_tablesize;
	short unsigned int sg_prot_tablesize;
	unsigned int max_sectors;
	long unsigned int dma_boundary;
	short int cmd_per_lun;
	unsigned char present;
	int tag_alloc_policy;
	unsigned int track_queue_depth: 1;
	unsigned int supported_mode: 2;
	unsigned int unchecked_isa_dma: 1;
	unsigned int use_clustering: 1;
	unsigned int emulated: 1;
	unsigned int skip_settle_delay: 1;
	unsigned int no_write_same: 1;
	unsigned int force_blk_mq: 1;
	unsigned int max_host_blocked;
	struct device_attribute___39 **shost_attrs;
	struct device_attribute___39 **sdev_attrs;
	const struct attribute_group___322 **sdev_groups;
	u64 vendor_id;
	unsigned int cmd_size;
	struct scsi_host_cmd_pool *cmd_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

enum {
	SCSI_DH_OK = 0,
	SCSI_DH_DEV_FAILED = 1,
	SCSI_DH_DEV_TEMP_BUSY = 2,
	SCSI_DH_DEV_UNSUPP = 3,
	SCSI_DH_DEVICE_MAX = 4,
	SCSI_DH_NOTCONN = 5,
	SCSI_DH_CONN_FAILURE = 6,
	SCSI_DH_TRANSPORT_MAX = 7,
	SCSI_DH_IO = 8,
	SCSI_DH_INVALID_IO = 9,
	SCSI_DH_RETRY = 10,
	SCSI_DH_IMM_RETRY = 11,
	SCSI_DH_TIMED_OUT = 12,
	SCSI_DH_RES_TEMP_UNAVAIL = 13,
	SCSI_DH_DEV_OFFLINED = 14,
	SCSI_DH_NOMEM = 15,
	SCSI_DH_NOSYS = 16,
	SCSI_DH_DRIVER_MAX = 17,
};

struct scsi_dh_blist {
	const char *vendor;
	const char *model;
	const char *driver;
};

struct module___290;

struct file___359;

struct kiocb___359;

struct vm_area_struct___360;

struct inode___359;

struct file_lock___359;

struct page___360;

struct file_operations___359 {
	struct module___290 *owner;
	loff_t (*llseek)(struct file___359 *, loff_t, int);
	ssize_t (*read)(struct file___359 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___359 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___359 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___359 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___359 *, bool);
	int (*iterate)(struct file___359 *, struct dir_context *);
	int (*iterate_shared)(struct file___359 *, struct dir_context *);
	__poll_t (*poll)(struct file___359 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___359 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___359 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___359 *, struct vm_area_struct___360 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___359 *, struct file___359 *);
	int (*flush)(struct file___359 *, fl_owner_t);
	int (*release)(struct inode___359 *, struct file___359 *);
	int (*fsync)(struct file___359 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___359 *, int);
	int (*lock)(struct file___359 *, int, struct file_lock___359 *);
	ssize_t (*sendpage)(struct file___359 *, struct page___360 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___359 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___359 *, int, struct file_lock___359 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___359 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___359 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___359 *, long int, struct file_lock___359 **, void **);
	long int (*fallocate)(struct file___359 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___359 *);
	ssize_t (*copy_file_range)(struct file___359 *, loff_t, struct file___359 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___359 *, loff_t, struct file___359 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___359 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___359 {
	u64 seqnum;
	struct vm_area_struct___360 *vmas[4];
};

struct page_frag___359 {
	struct page___360 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___359;

struct bio_list___176;

struct backing_dev_info___176;

struct io_context___96;

struct request_queue___92;

struct vm_struct___265;

struct task_struct___360 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___360 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___359 *mm;
	struct mm_struct___359 *active_mm;
	struct vmacache___359 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___360 *real_parent;
	struct task_struct___360 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___360 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___216 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___216 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___216 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___2 *ptracer_cred;
	const struct cred___2 *real_cred;
	const struct cred___2 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___360 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___176 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___176 *backing_dev_info;
	struct io_context___96 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___359 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___92 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___360 *oom_reaper_list;
	struct vm_struct___265 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___140 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___360 *pgtable_t___359;

struct address_space___358;

struct dev_pagemap___347;

struct page___360 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___358 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___360 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___359 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___359 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___347 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___359;

struct lruvec___359 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___359 *pgdat;
};

struct zone___359 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___359 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___359 {
	struct zone___359 *zone;
	int zone_idx;
};

struct zonelist___359 {
	struct zoneref___359 _zonerefs[25];
};

struct pglist_data___359 {
	struct zone___359 node_zones[3];
	struct zonelist___359 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___360 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___360 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___359 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___360 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___360 *owner;
};

struct secondary_data___360 {
	void *stack;
	struct task_struct___360 *task;
	long int status;
};

struct blocking_notifier_head___359 {
	struct rw_semaphore___360 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___347;

struct vm_area_struct___360 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___360 *vm_next;
	struct vm_area_struct___360 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___359 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___347 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___359 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___359;

struct mm_struct___359 {
	struct {
		struct vm_area_struct___360 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___359 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___360 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___359 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___360 *owner;
		struct user_namespace___3 *user_ns;
		struct file___359 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___359 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___358;

struct address_space___358 {
	struct inode___359 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___360 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___358 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___347)(struct vm_area_struct___360 *, long unsigned int, const struct page___360 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___347)(struct page___360 *, void *);

struct device___326;

struct dev_pagemap___347 {
	dev_page_fault_t___347 page_fault;
	dev_page_free_t___347 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___326 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct dentry___358;

struct path___359 {
	struct vfsmount *mnt;
	struct dentry___358 *dentry;
};

struct file___359 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___359 f_path;
	struct inode___359 *f_inode;
	const struct file_operations___359 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___216 f_owner;
	const struct cred___2 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___358 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___347;

struct vm_operations_struct___347 {
	void (*open)(struct vm_area_struct___360 *);
	void (*close)(struct vm_area_struct___360 *);
	int (*split)(struct vm_area_struct___360 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___360 *);
	vm_fault_t (*fault)(struct vm_fault___347 *);
	vm_fault_t (*huge_fault)(struct vm_fault___347 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___347 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___360 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___347 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___347 *);
	int (*access)(struct vm_area_struct___360 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___360 *);
	int (*set_policy)(struct vm_area_struct___360 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___360 *, long unsigned int);
	struct page___360 * (*find_special_page)(struct vm_area_struct___360 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___359 {
	struct task_struct___360 *task;
	struct core_thread___359 *next;
};

struct core_state___359 {
	atomic_t nr_threads;
	struct core_thread___359 dumper;
	struct completion startup;
};

struct vm_fault___347 {
	struct vm_area_struct___360 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___360 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___360 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___359 prealloc_pte;
};

struct bio___176;

struct bio_list___176 {
	struct bio___176 *head;
	struct bio___176 *tail;
};

struct bdi_writeback_congested___176;

struct bdi_writeback___176 {
	struct backing_dev_info___176 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___176 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___157 *memcg_css;
	struct cgroup_subsys_state___157 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___176 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___176 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___326 *dev;
	struct device___326 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___358 *debug_dir;
	struct dentry___358 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___96;

struct io_context___96 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___96 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

typedef blk_qc_t make_request_fn___92(struct request_queue___92 *, struct bio___176 *);

struct request___92;

typedef int dma_drain_needed_fn___92(struct request___92 *);

struct kset___345;

struct kobj_type___345;

struct kernfs_node___353;

struct kobject___346 {
	const char *name;
	struct list_head entry;
	struct kobject___346 *parent;
	struct kset___345 *kset;
	struct kobj_type___345 *ktype;
	struct kernfs_node___353 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___92;

struct bsg_class_device___92 {
	struct device___326 *class_dev;
	int minor;
	struct request_queue___92 *queue;
	const struct bsg_ops___92 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___176 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___176 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___92;

struct blk_mq_ops___29;

struct blk_mq_hw_ctx___29;

struct blk_mq_tag_set___29;

struct request_queue___92 {
	struct list_head queue_head;
	struct request___92 *last_merge;
	struct elevator_queue___92 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___92 *make_request_fn;
	dma_drain_needed_fn___92 *dma_drain_needed;
	const struct blk_mq_ops___29 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___29 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___176 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___346 kobj;
	struct kobject___346 *mq_kobj;
	struct blk_integrity integrity;
	struct device___326 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	struct bsg_class_device___92 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set___29 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___176 bio_split;
	struct dentry___358 *debugfs_dir;
	struct dentry___358 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___265 {
	struct vm_struct___265 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___360 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dev_pm_info___326 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___5 *subsys_data;
	void (*set_latency_tolerance)(struct device___326 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___326;

struct bus_type___326;

struct device_driver___326;

struct dev_pm_domain___326;

struct dma_map_ops___114;

struct fwnode_handle___248;

struct class___326;

struct attribute_group___323;

struct device___326 {
	struct device___326 *parent;
	struct device_private *p;
	struct kobject___346 kobj;
	const char *init_name;
	const struct device_type___326 *type;
	struct mutex mutex;
	struct bus_type___326 *bus;
	struct device_driver___326 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___326 power;
	struct dev_pm_domain___326 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___114 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___248 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___326 *class;
	const struct attribute_group___323 **groups;
	void (*release)(struct device___326 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___358;

struct super_block___358;

struct dentry___358 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___358 *d_parent;
	struct qstr d_name;
	struct inode___359 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___358 *d_op;
	struct super_block___358 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___358;

struct block_device___358;

struct inode___359 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___358 *i_op;
	struct super_block___358 *i_sb;
	struct address_space___358 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___360 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___176 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___359 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___358 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___358 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___358 {
	int (*d_revalidate)(struct dentry___358 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___358 *, unsigned int);
	int (*d_hash)(const struct dentry___358 *, struct qstr *);
	int (*d_compare)(const struct dentry___358 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___358 *);
	int (*d_init)(struct dentry___358 *);
	void (*d_release)(struct dentry___358 *);
	void (*d_prune)(struct dentry___358 *);
	void (*d_iput)(struct dentry___358 *, struct inode___359 *);
	char * (*d_dname)(struct dentry___358 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___359 *);
	int (*d_manage)(const struct path___359 *, bool);
	struct dentry___358 * (*d_real)(struct dentry___358 *, const struct inode___359 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___358;

struct mem_dqinfo___358 {
	struct quota_format_type___358 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___358;

struct quota_info___358 {
	unsigned int flags;
	struct rw_semaphore___360 dqio_sem;
	struct inode___359 *files[3];
	struct mem_dqinfo___358 info[3];
	const struct quota_format_ops___358 *ops[3];
};

struct rcuwait___358 {
	struct task_struct___360 *task;
};

struct percpu_rw_semaphore___358 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___360 rw_sem;
	struct rcuwait___358 writer;
	int readers_block;
};

struct sb_writers___358 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___358 rw_sem[3];
};

struct file_system_type___358;

struct super_operations___358;

struct dquot_operations___358;

struct quotactl_ops___358;

struct super_block___358 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___358 *s_type;
	const struct super_operations___358 *s_op;
	const struct dquot_operations___358 *dq_op;
	const struct quotactl_ops___358 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___358 *s_root;
	struct rw_semaphore___360 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___358 *s_bdev;
	struct backing_dev_info___176 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___358 s_dquot;
	struct sb_writers___358 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___358 *s_d_op;
	int cleancache_poolid;
	struct shrinker___131 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct io_cq___96 {
	struct request_queue___92 *q;
	struct io_context___96 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___359 {
	struct file___359 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___359 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___358 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___359 *ia_file;
};

struct dquot___358 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___358 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___358 {
	int qf_fmt_id;
	const struct quota_format_ops___358 *qf_ops;
	struct module___290 *qf_owner;
	struct quota_format_type___358 *qf_next;
};

struct quota_format_ops___358 {
	int (*check_quota_file)(struct super_block___358 *, int);
	int (*read_file_info)(struct super_block___358 *, int);
	int (*write_file_info)(struct super_block___358 *, int);
	int (*free_file_info)(struct super_block___358 *, int);
	int (*read_dqblk)(struct dquot___358 *);
	int (*commit_dqblk)(struct dquot___358 *);
	int (*release_dqblk)(struct dquot___358 *);
	int (*get_next_id)(struct super_block___358 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___358 {
	int (*write_dquot)(struct dquot___358 *);
	struct dquot___358 * (*alloc_dquot)(struct super_block___358 *, int);
	void (*destroy_dquot)(struct dquot___358 *);
	int (*acquire_dquot)(struct dquot___358 *);
	int (*release_dquot)(struct dquot___358 *);
	int (*mark_dirty)(struct dquot___358 *);
	int (*write_info)(struct super_block___358 *, int);
	qsize_t * (*get_reserved_space)(struct inode___359 *);
	int (*get_projid)(struct inode___359 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___359 *, qsize_t *);
	int (*get_next_id)(struct super_block___358 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___358 {
	int (*quota_on)(struct super_block___358 *, int, int, const struct path___359 *);
	int (*quota_off)(struct super_block___358 *, int);
	int (*quota_enable)(struct super_block___358 *, unsigned int);
	int (*quota_disable)(struct super_block___358 *, unsigned int);
	int (*quota_sync)(struct super_block___358 *, int);
	int (*set_info)(struct super_block___358 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___358 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___358 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___358 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___358 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___358 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___287 {
	struct kobject___346 kobj;
	struct module___290 *mod;
	struct kobject___346 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___287 {
	struct module___290 *mod;
	struct latch_tree_node node;
};

struct module_layout___287 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___287 mtn;
};

struct module_attribute___287;

struct kernel_param___287;

struct module___290 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___287 mkobj;
	struct module_attribute___287 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___346 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___287 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___287 core_layout;
	struct module_layout___287 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide46;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide47;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___358 {
	int (*writepage)(struct page___360 *, struct writeback_control___3 *);
	int (*readpage)(struct file___359 *, struct page___360 *);
	int (*writepages)(struct address_space___358 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___360 *);
	int (*readpages)(struct file___359 *, struct address_space___358 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___359 *, struct address_space___358 *, loff_t, unsigned int, unsigned int, struct page___360 **, void **);
	int (*write_end)(struct file___359 *, struct address_space___358 *, loff_t, unsigned int, unsigned int, struct page___360 *, void *);
	sector_t (*bmap)(struct address_space___358 *, sector_t);
	void (*invalidatepage)(struct page___360 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___360 *, gfp_t);
	void (*freepage)(struct page___360 *);
	ssize_t (*direct_IO)(struct kiocb___359 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___358 *, struct page___360 *, struct page___360 *, enum migrate_mode);
	bool (*isolate_page)(struct page___360 *, isolate_mode_t);
	void (*putback_page)(struct page___360 *);
	int (*launder_page)(struct page___360 *);
	int (*is_partially_uptodate)(struct page___360 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___360 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___358 *, struct page___360 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___359 *, sector_t *);
	void (*swap_deactivate)(struct file___359 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct hd_struct___96;

struct gendisk___96;

struct block_device___358 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___359 *bd_inode;
	struct super_block___358 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___358 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___96 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___96 *bd_disk;
	struct request_queue___92 *bd_queue;
	struct backing_dev_info___176 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct hd_struct___96 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___326 __dev;
	struct kobject___346 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___96;

struct block_device_operations___93;

struct gendisk___96 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___96 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___96 *part_tbl;
	struct hd_struct___96 part0;
	const struct block_device_operations___93 *fops;
	struct request_queue___92 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___360 lookup_sem;
	struct kobject___346 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___346 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___358 {
	struct dentry___358 * (*lookup)(struct inode___359 *, struct dentry___358 *, unsigned int);
	const char * (*get_link)(struct dentry___358 *, struct inode___359 *, struct delayed_call *);
	int (*permission)(struct inode___359 *, int);
	struct posix_acl * (*get_acl)(struct inode___359 *, int);
	int (*readlink)(struct dentry___358 *, char *, int);
	int (*create)(struct inode___359 *, struct dentry___358 *, umode_t, bool);
	int (*link)(struct dentry___358 *, struct inode___359 *, struct dentry___358 *);
	int (*unlink)(struct inode___359 *, struct dentry___358 *);
	int (*symlink)(struct inode___359 *, struct dentry___358 *, const char *);
	int (*mkdir)(struct inode___359 *, struct dentry___358 *, umode_t);
	int (*rmdir)(struct inode___359 *, struct dentry___358 *);
	int (*mknod)(struct inode___359 *, struct dentry___358 *, umode_t, dev_t);
	int (*rename)(struct inode___359 *, struct dentry___358 *, struct inode___359 *, struct dentry___358 *, unsigned int);
	int (*setattr)(struct dentry___358 *, struct iattr___358 *);
	int (*getattr)(const struct path___359 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___358 *, char *, size_t);
	int (*fiemap)(struct inode___359 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___359 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___359 *, struct dentry___358 *, struct file___359 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___359 *, struct dentry___358 *, umode_t);
	int (*set_acl)(struct inode___359 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___358 {
	void (*fl_copy_lock)(struct file_lock___359 *, struct file_lock___359 *);
	void (*fl_release_private)(struct file_lock___359 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___358;

struct lock_manager_operations___358;

struct file_lock___359 {
	struct file_lock___359 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___359 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___358 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___358 *fl_ops;
	const struct lock_manager_operations___358 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___358 {
	int (*lm_compare_owner)(struct file_lock___359 *, struct file_lock___359 *);
	long unsigned int (*lm_owner_key)(struct file_lock___359 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___359 *);
	int (*lm_grant)(struct file_lock___359 *, int);
	bool (*lm_break)(struct file_lock___359 *);
	int (*lm_change)(struct file_lock___359 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___359 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___358 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___358 *fa_next;
	struct file___359 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___358 {
	const char *name;
	int fs_flags;
	struct dentry___358 * (*mount)(struct file_system_type___358 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___358 *);
	struct module___290 *owner;
	struct file_system_type___358 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___358 {
	struct inode___359 * (*alloc_inode)(struct super_block___358 *);
	void (*destroy_inode)(struct inode___359 *);
	void (*dirty_inode)(struct inode___359 *, int);
	int (*write_inode)(struct inode___359 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___359 *);
	void (*evict_inode)(struct inode___359 *);
	void (*put_super)(struct super_block___358 *);
	int (*sync_fs)(struct super_block___358 *, int);
	int (*freeze_super)(struct super_block___358 *);
	int (*freeze_fs)(struct super_block___358 *);
	int (*thaw_super)(struct super_block___358 *);
	int (*unfreeze_fs)(struct super_block___358 *);
	int (*statfs)(struct dentry___358 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___358 *, int *, char *);
	void (*umount_begin)(struct super_block___358 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___358 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___358 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___358 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___358 *);
	ssize_t (*quota_read)(struct super_block___358 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___358 *, int, const char *, size_t, loff_t);
	struct dquot___358 ** (*get_dquots)(struct inode___359 *);
	int (*bdev_try_to_free_page)(struct super_block___358 *, struct page___360 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___358 *, struct shrink_control___131 *);
	long int (*free_cached_objects)(struct super_block___358 *, struct shrink_control___131 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___176(struct bio___176 *);

struct bio_vec___178 {
	struct page___360 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___176;

struct bio___176 {
	struct bio___176 *bi_next;
	struct gendisk___96 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___176 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___176 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___178 *bi_io_vec;
	struct bio_set___176 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___178 bi_inline_vecs[0];
};

struct kobj_attribute___337 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___346 *, struct kobj_attribute___337 *, char *);
	ssize_t (*store)(struct kobject___346 *, struct kobj_attribute___337 *, const char *, size_t);
};

typedef void compound_page_dtor___347(struct page___360 *);

struct fwnode_operations___248;

struct fwnode_handle___248 {
	struct fwnode_handle___248 *secondary;
	const struct fwnode_operations___248 *ops;
};

struct fwnode_reference_args___248;

struct fwnode_endpoint___248;

struct fwnode_operations___248 {
	struct fwnode_handle___248 * (*get)(struct fwnode_handle___248 *);
	void (*put)(struct fwnode_handle___248 *);
	bool (*device_is_available)(const struct fwnode_handle___248 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___248 *, const struct device___326 *);
	bool (*property_present)(const struct fwnode_handle___248 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___248 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___248 *, const char *, const char **, size_t);
	struct fwnode_handle___248 * (*get_parent)(const struct fwnode_handle___248 *);
	struct fwnode_handle___248 * (*get_next_child_node)(const struct fwnode_handle___248 *, struct fwnode_handle___248 *);
	struct fwnode_handle___248 * (*get_named_child_node)(const struct fwnode_handle___248 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___248 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___248 *);
	struct fwnode_handle___248 * (*graph_get_next_endpoint)(const struct fwnode_handle___248 *, struct fwnode_handle___248 *);
	struct fwnode_handle___248 * (*graph_get_remote_endpoint)(const struct fwnode_handle___248 *);
	struct fwnode_handle___248 * (*graph_get_port_parent)(struct fwnode_handle___248 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___248 *, struct fwnode_endpoint___248 *);
};

struct fwnode_endpoint___248 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___248 *local_fwnode;
};

struct fwnode_reference_args___248 {
	struct fwnode_handle___248 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct kernfs_root___352;

struct kernfs_elem_dir___352 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___352 *root;
};

struct kernfs_syscall_ops___352;

struct kernfs_root___352 {
	struct kernfs_node___353 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___352 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___352 {
	struct kernfs_node___353 *target_kn;
};

struct kernfs_ops___352;

struct kernfs_elem_attr___352 {
	const struct kernfs_ops___352 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___353 *notify_next;
};

struct kernfs_node___353 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___353 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___352 dir;
		struct kernfs_elem_symlink___352 symlink;
		struct kernfs_elem_attr___352 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___352;

struct kernfs_ops___352 {
	int (*open)(struct kernfs_open_file___352 *);
	void (*release)(struct kernfs_open_file___352 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___352 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___352 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___352 *, struct vm_area_struct___360 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___352 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___352 {
	int (*remount_fs)(struct kernfs_root___352 *, int *, char *);
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___352 *);
	int (*mkdir)(struct kernfs_node___353 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___353 *);
	int (*rename)(struct kernfs_node___353 *, struct kernfs_node___353 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___353 *, struct kernfs_root___352 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___352 {
	struct kernfs_node___353 *kn;
	struct file___359 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___347 *vm_ops;
};

struct bin_attribute___322;

struct attribute_group___323 {
	const char *name;
	umode_t (*is_visible)(struct kobject___346 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___346 *, struct bin_attribute___322 *, int);
	struct attribute **attrs;
	struct bin_attribute___322 **bin_attrs;
};

struct bin_attribute___322 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___359 *, struct kobject___346 *, struct bin_attribute___322 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___359 *, struct kobject___346 *, struct bin_attribute___322 *, char *, loff_t, size_t);
	int (*mmap)(struct file___359 *, struct kobject___346 *, struct bin_attribute___322 *, struct vm_area_struct___360 *);
};

struct sysfs_ops___345 {
	ssize_t (*show)(struct kobject___346 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___346 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___345;

struct kset___345 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___346 kobj;
	const struct kset_uevent_ops___345 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___345 {
	void (*release)(struct kobject___346 *);
	const struct sysfs_ops___345 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___28 * (*child_ns_type)(struct kobject___346 *);
	const void * (*namespace)(struct kobject___346 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___345 {
	int (* const filter)(struct kset___345 *, struct kobject___346 *);
	const char * (* const name)(struct kset___345 *, struct kobject___346 *);
	int (* const uevent)(struct kset___345 *, struct kobject___346 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___326 {
	int (*prepare)(struct device___326 *);
	void (*complete)(struct device___326 *);
	int (*suspend)(struct device___326 *);
	int (*resume)(struct device___326 *);
	int (*freeze)(struct device___326 *);
	int (*thaw)(struct device___326 *);
	int (*poweroff)(struct device___326 *);
	int (*restore)(struct device___326 *);
	int (*suspend_late)(struct device___326 *);
	int (*resume_early)(struct device___326 *);
	int (*freeze_late)(struct device___326 *);
	int (*thaw_early)(struct device___326 *);
	int (*poweroff_late)(struct device___326 *);
	int (*restore_early)(struct device___326 *);
	int (*suspend_noirq)(struct device___326 *);
	int (*resume_noirq)(struct device___326 *);
	int (*freeze_noirq)(struct device___326 *);
	int (*thaw_noirq)(struct device___326 *);
	int (*poweroff_noirq)(struct device___326 *);
	int (*restore_noirq)(struct device___326 *);
	int (*runtime_suspend)(struct device___326 *);
	int (*runtime_resume)(struct device___326 *);
	int (*runtime_idle)(struct device___326 *);
};

struct dev_pm_domain___326 {
	struct dev_pm_ops___326 ops;
	void (*detach)(struct device___326 *, bool);
	int (*activate)(struct device___326 *);
	void (*sync)(struct device___326 *);
	void (*dismiss)(struct device___326 *);
};

struct bus_type___326 {
	const char *name;
	const char *dev_name;
	struct device___326 *dev_root;
	const struct attribute_group___323 **bus_groups;
	const struct attribute_group___323 **dev_groups;
	const struct attribute_group___323 **drv_groups;
	int (*match)(struct device___326 *, struct device_driver___326 *);
	int (*uevent)(struct device___326 *, struct kobj_uevent_env *);
	int (*probe)(struct device___326 *);
	int (*remove)(struct device___326 *);
	void (*shutdown)(struct device___326 *);
	int (*online)(struct device___326 *);
	int (*offline)(struct device___326 *);
	int (*suspend)(struct device___326 *, pm_message_t);
	int (*resume)(struct device___326 *);
	int (*num_vf)(struct device___326 *);
	int (*dma_configure)(struct device___326 *);
	const struct dev_pm_ops___326 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___326 {
	const char *name;
	struct bus_type___326 *bus;
	struct module___290 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___326 *);
	int (*remove)(struct device___326 *);
	void (*shutdown)(struct device___326 *);
	int (*suspend)(struct device___326 *, pm_message_t);
	int (*resume)(struct device___326 *);
	const struct attribute_group___323 **groups;
	const struct dev_pm_ops___326 *pm;
	void (*coredump)(struct device___326 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___326 {
	const char *name;
	const struct attribute_group___323 **groups;
	int (*uevent)(struct device___326 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___326 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___326 *);
	const struct dev_pm_ops___326 *pm;
};

struct class___326 {
	const char *name;
	struct module___290 *owner;
	const struct attribute_group___323 **class_groups;
	const struct attribute_group___323 **dev_groups;
	struct kobject___346 *dev_kobj;
	int (*dev_uevent)(struct device___326 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___326 *, umode_t *);
	void (*class_release)(struct class___326 *);
	void (*dev_release)(struct device___326 *);
	int (*shutdown_pre)(struct device___326 *);
	const struct kobj_ns_type_operations___28 *ns_type;
	const void * (*namespace)(struct device___326 *);
	const struct dev_pm_ops___326 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___114 {
	void * (*alloc)(struct device___326 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___326 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___326 *, struct vm_area_struct___360 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___326 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___326 *, struct page___360 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___326 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___326 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___326 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___326 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___326 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___326 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___326 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___326 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___326 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___326 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___326 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___326 *, u64);
	u64 (*get_required_mask)(struct device___326 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct bio_integrity_payload___176 {
	struct bio___176 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___178 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___178 bip_inline_vecs[0];
};

struct disk_part_tbl___96 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___96 *last_lookup;
	struct hd_struct___96 *part[0];
};

struct block_device_operations___93 {
	int (*open)(struct block_device___358 *, fmode_t);
	void (*release)(struct gendisk___96 *, fmode_t);
	int (*rw_page)(struct block_device___358 *, sector_t, struct page___360 *, unsigned int);
	int (*ioctl)(struct block_device___358 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___358 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___96 *, unsigned int);
	int (*media_changed)(struct gendisk___96 *);
	void (*unlock_native_capacity)(struct gendisk___96 *);
	int (*revalidate_disk)(struct gendisk___96 *);
	int (*getgeo)(struct block_device___358 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___358 *, long unsigned int);
	int (*report_zones)(struct gendisk___96 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___290 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bdi_writeback_congested___176 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___176 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bsg_ops___92 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___92 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___92 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___92 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___92(struct request___92 *, blk_status_t);

struct request___92 {
	struct request_queue___92 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___29 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___176 *bio;
	struct bio___176 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___178 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___96 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___92 *saved_end_io;
		} flush;
	};
	struct gendisk___96 *rq_disk;
	struct hd_struct___96 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___92 *end_io;
	void *end_io_data;
	struct request___92 *next_rq;
};

struct blk_mq_hw_ctx___29 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___92 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags___4 *tags;
	struct blk_mq_tags___4 *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	unsigned int rh_reserved_nr_expired;
	struct hlist_node cpuhp_dead;
	struct kobject___346 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___358 *debugfs_dir;
	struct dentry___358 *sched_debugfs_dir;
	struct list_head hctx_list;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___92;

struct elevator_mq_ops___92 {
	int (*init_sched)(struct request_queue___92 *, struct elevator_type___92 *);
	void (*exit_sched)(struct elevator_queue___92 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___29 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___29 *, unsigned int);
	bool (*allow_merge)(struct request_queue___92 *, struct request___92 *, struct bio___176 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx___29 *, struct bio___176 *);
	int (*request_merge)(struct request_queue___92 *, struct request___92 **, struct bio___176 *);
	void (*request_merged)(struct request_queue___92 *, struct request___92 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___92 *, struct request___92 *, struct request___92 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___92 *, struct bio___176 *);
	void (*finish_request)(struct request___92 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___29 *, struct list_head *, bool);
	struct request___92 * (*dispatch_request)(struct blk_mq_hw_ctx___29 *);
	bool (*has_work)(struct blk_mq_hw_ctx___29 *);
	void (*completed_request)(struct request___92 *, u64);
	void (*started_request)(struct request___92 *);
	void (*requeue_request)(struct request___92 *);
	struct request___92 * (*former_request)(struct request_queue___92 *, struct request___92 *);
	struct request___92 * (*next_request)(struct request_queue___92 *, struct request___92 *);
	void (*init_icq)(struct io_cq___96 *);
	void (*exit_icq)(struct io_cq___96 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx___29 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___92;

struct elevator_type___92 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___92 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___92 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___290 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___92 {
	struct elevator_type___92 *type;
	void *elevator_data;
	struct kobject___346 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___92 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___92 *, char *);
	ssize_t (*store)(struct elevator_queue___92 *, const char *, size_t);
};

struct blk_mq_queue_data___29;

typedef blk_status_t queue_rq_fn___29(struct blk_mq_hw_ctx___29 *, const struct blk_mq_queue_data___29 *);

typedef void commit_rqs_fn___29(struct blk_mq_hw_ctx___29 *);

typedef bool get_budget_fn___29(struct blk_mq_hw_ctx___29 *);

typedef void put_budget_fn___29(struct blk_mq_hw_ctx___29 *);

typedef enum blk_eh_timer_return timeout_fn___29(struct request___92 *, bool);

typedef int poll_fn___29(struct blk_mq_hw_ctx___29 *);

typedef void complete_fn___29(struct request___92 *);

typedef int init_hctx_fn___29(struct blk_mq_hw_ctx___29 *, void *, unsigned int);

typedef void exit_hctx_fn___29(struct blk_mq_hw_ctx___29 *, unsigned int);

typedef int init_request_fn___29(struct blk_mq_tag_set___29 *, struct request___92 *, unsigned int, unsigned int);

typedef void exit_request_fn___29(struct blk_mq_tag_set___29 *, struct request___92 *, unsigned int);

typedef bool busy_fn___29(struct request_queue___92 *);

typedef int map_queues_fn___29(struct blk_mq_tag_set___29 *);

typedef void cleanup_rq_fn___29(struct request___92 *);

struct blk_mq_ops___29 {
	queue_rq_fn___29 *queue_rq;
	commit_rqs_fn___29 *commit_rqs;
	get_budget_fn___29 *get_budget;
	put_budget_fn___29 *put_budget;
	timeout_fn___29 *timeout;
	poll_fn___29 *poll;
	complete_fn___29 *complete;
	init_hctx_fn___29 *init_hctx;
	exit_hctx_fn___29 *exit_hctx;
	init_request_fn___29 *init_request;
	exit_request_fn___29 *exit_request;
	void (*initialize_rq_fn)(struct request___92 *);
	busy_fn___29 *busy;
	map_queues_fn___29 *map_queues;
	void (*show_rq)(struct seq_file___9 *, struct request___92 *);
	union {
		cleanup_rq_fn___29 *cleanup_rq;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide45;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct blk_mq_tag_set___29 {
	struct blk_mq_queue_map map[6];
	unsigned int nr_maps;
	const struct blk_mq_ops___29 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	struct blk_mq_tags___4 **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct scsi_target___10;

struct scsi_device_handler___4;

struct scsi_device___10 {
	struct Scsi_Host___5 *host;
	struct request_queue___92 *request_queue;
	struct list_head siblings;
	struct list_head same_target_siblings;
	atomic_t device_busy;
	atomic_t device_blocked;
	spinlock_t list_lock;
	struct list_head cmd_list;
	struct list_head starved_entry;
	short unsigned int queue_depth;
	short unsigned int max_queue_depth;
	short unsigned int last_queue_full_depth;
	short unsigned int last_queue_full_count;
	long unsigned int last_queue_full_time;
	long unsigned int queue_ramp_up_period;
	long unsigned int last_queue_ramp_up;
	unsigned int id;
	unsigned int channel;
	u64 lun;
	unsigned int manufacturer;
	unsigned int sector_size;
	void *hostdata;
	unsigned char type;
	char scsi_level;
	char inq_periph_qual;
	struct mutex inquiry_mutex;
	unsigned char inquiry_len;
	unsigned char *inquiry;
	const char *vendor;
	const char *model;
	const char *rev;
	struct scsi_vpd *vpd_pg83;
	struct scsi_vpd *vpd_pg80;
	unsigned char current_tag;
	struct scsi_target___10 *sdev_target;
	blist_flags_t sdev_bflags;
	unsigned int eh_timeout;
	unsigned int removable: 1;
	unsigned int changed: 1;
	unsigned int busy: 1;
	unsigned int lockable: 1;
	unsigned int locked: 1;
	unsigned int borken: 1;
	unsigned int disconnect: 1;
	unsigned int soft_reset: 1;
	unsigned int sdtr: 1;
	unsigned int wdtr: 1;
	unsigned int ppr: 1;
	unsigned int tagged_supported: 1;
	unsigned int simple_tags: 1;
	unsigned int was_reset: 1;
	unsigned int expecting_cc_ua: 1;
	unsigned int use_10_for_rw: 1;
	unsigned int use_10_for_ms: 1;
	unsigned int no_report_opcodes: 1;
	unsigned int no_write_same: 1;
	unsigned int use_16_for_rw: 1;
	unsigned int skip_ms_page_8: 1;
	unsigned int skip_ms_page_3f: 1;
	unsigned int skip_vpd_pages: 1;
	unsigned int try_vpd_pages: 1;
	unsigned int use_192_bytes_for_3f: 1;
	unsigned int no_start_on_add: 1;
	unsigned int allow_restart: 1;
	unsigned int manage_start_stop: 1;
	unsigned int start_stop_pwr_cond: 1;
	unsigned int no_uld_attach: 1;
	unsigned int select_no_atn: 1;
	unsigned int fix_capacity: 1;
	unsigned int guess_capacity: 1;
	unsigned int retry_hwerror: 1;
	unsigned int last_sector_bug: 1;
	unsigned int no_read_disc_info: 1;
	unsigned int no_read_capacity_16: 1;
	unsigned int try_rc_10_first: 1;
	unsigned int security_supported: 1;
	unsigned int is_visible: 1;
	unsigned int wce_default_on: 1;
	unsigned int no_dif: 1;
	unsigned int broken_fua: 1;
	unsigned int lun_in_cdb: 1;
	unsigned int unmap_limit_for_ws: 1;
	atomic_t disk_events_disable_depth;
	long unsigned int supported_events[1];
	long unsigned int pending_events[1];
	struct list_head event_list;
	struct work_struct event_work;
	unsigned int max_device_blocked;
	atomic_t iorequest_cnt;
	atomic_t iodone_cnt;
	atomic_t ioerr_cnt;
	struct device___326 sdev_gendev;
	struct device___326 sdev_dev;
	struct execute_work ew;
	struct work_struct requeue_work;
	struct scsi_device_handler___4 *handler;
	void *handler_data;
	unsigned char access_state;
	struct mutex state_mutex;
	enum scsi_device_state sdev_state;
	struct task_struct___360 *quiesced_by;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int sdev_data[0];
};

struct scsi_target___10 {
	struct scsi_device___10 *starget_sdev_user;
	struct list_head siblings;
	struct list_head devices;
	struct device___326 dev;
	struct kref reap_ref;
	unsigned int channel;
	unsigned int id;
	unsigned int create: 1;
	unsigned int single_lun: 1;
	unsigned int pdt_1f_for_no_lun: 1;
	unsigned int no_report_luns: 1;
	unsigned int expecting_lun_change: 1;
	atomic_t target_busy;
	atomic_t target_blocked;
	unsigned int can_queue;
	unsigned int max_target_blocked;
	char scsi_level;
	enum scsi_target_state state;
	void *hostdata;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int starget_data[0];
};

struct scsi_device_handler___4 {
	struct list_head list;
	struct module___290 *module;
	const char *name;
	int (*check_sense)(struct scsi_device___10 *, struct scsi_sense_hdr *);
	int (*attach)(struct scsi_device___10 *);
	void (*detach)(struct scsi_device___10 *);
	int (*activate)(struct scsi_device___10 *, activate_complete, void *);
	blk_status_t (*prep_fn)(struct scsi_device___10 *, struct request___92 *);
	int (*set_params)(struct scsi_device___10 *, const char *);
	void (*rescan)(struct scsi_device___10 *);
};

struct blk_mq_queue_data___29 {
	struct request___92 *rq;
	bool last;
	long unsigned int rh_reserved1;
};

struct kernel_param_ops___287 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___287 *);
	int (*get)(char *, const struct kernel_param___287 *);
	void (*free)(void *);
};

struct kparam_array___287;

struct kernel_param___287 {
	const char *name;
	struct module___290 *mod;
	const struct kernel_param_ops___287 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___287 *arr;
	};
};

struct kparam_array___287 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___287 *ops;
	void *elem;
};

struct module_attribute___287 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___287 *, struct module_kobject___287 *, char *);
	ssize_t (*store)(struct module_attribute___287 *, struct module_kobject___287 *, const char *, size_t);
	void (*setup)(struct module___290 *, const char *);
	int (*test)(struct module___290 *);
	void (*free)(struct module___290 *);
};

struct module_version_attribute___7 {
	struct module_attribute___287 mattr;
	const char *module_name;
	const char *version;
};

struct rdac_mode_6_hdr {
	u8 data_len;
	u8 medium_type;
	u8 device_params;
	u8 block_desc_len;
};

struct rdac_mode_10_hdr {
	u16 data_len;
	u8 medium_type;
	u8 device_params;
	u16 reserved;
	u16 block_desc_len;
};

struct rdac_mode_common {
	u8 controller_serial[16];
	u8 alt_controller_serial[16];
	u8 rdac_mode[2];
	u8 alt_rdac_mode[2];
	u8 quiescence_timeout;
	u8 rdac_options;
};

struct rdac_pg_legacy {
	struct rdac_mode_6_hdr hdr;
	u8 page_code;
	u8 page_len;
	struct rdac_mode_common common;
	u8 lun_table[32];
	u8 reserved2[32];
	u8 reserved3;
	u8 reserved4;
};

struct rdac_pg_expanded {
	struct rdac_mode_10_hdr hdr;
	u8 page_code;
	u8 subpage_code;
	u8 page_len[2];
	struct rdac_mode_common common;
	u8 lun_table[256];
	u8 reserved3;
	u8 reserved4;
};

struct c9_inquiry {
	u8 peripheral_info;
	u8 page_code;
	u8 reserved1;
	u8 page_len;
	u8 page_id[4];
	u8 avte_cvp;
	u8 path_prio;
	u8 reserved2[38];
};

struct c4_inquiry {
	u8 peripheral_info;
	u8 page_code;
	u8 reserved1;
	u8 page_len;
	u8 page_id[4];
	u8 subsys_id[16];
	u8 revision[4];
	u8 slot_id[2];
	u8 reserved[2];
};

struct c8_inquiry {
	u8 peripheral_info;
	u8 page_code;
	u8 reserved1;
	u8 page_len;
	u8 page_id[4];
	u8 reserved2[3];
	u8 vol_uniq_id_len;
	u8 vol_uniq_id[16];
	u8 vol_user_label_len;
	u8 vol_user_label[60];
	u8 array_uniq_id_len;
	u8 array_unique_id[16];
	u8 array_user_label_len;
	u8 array_user_label[60];
	u8 lun[8];
};

struct rdac_controller {
	u8 array_id[16];
	int use_ms10;
	struct kref kref;
	struct list_head node;
	union {
		struct rdac_pg_legacy legacy;
		struct rdac_pg_expanded expanded;
	} mode_select;
	u8 index;
	u8 array_name[31];
	struct Scsi_Host___5 *host;
	spinlock_t ms_lock;
	int ms_queued;
	struct work_struct ms_work;
	struct scsi_device___10 *ms_sdev;
	struct list_head ms_head;
	struct list_head dh_list;
};

struct c2_inquiry {
	u8 peripheral_info;
	u8 page_code;
	u8 reserved1;
	u8 page_len;
	u8 page_id[4];
	u8 sw_version[3];
	u8 sw_date[3];
	u8 features_enabled;
	u8 max_lun_supported;
	u8 partitions[239];
};

struct rdac_dh_data {
	struct list_head node;
	struct rdac_controller *ctlr;
	struct scsi_device___10 *sdev;
	unsigned int lun;
	unsigned char mode;
	unsigned char state;
	char lun_state;
	char preferred;
	union {
		struct c2_inquiry c2;
		struct c4_inquiry c4;
		struct c8_inquiry c8;
		struct c9_inquiry c9;
	} inq;
};

struct rdac_queue_data {
	struct list_head entry;
	struct rdac_dh_data *h;
	activate_complete callback_fn;
	void *callback_data;
};

struct module___291;

struct file___360;

struct kiocb___360;

struct vm_area_struct___361;

struct inode___360;

struct file_lock___360;

struct page___361;

struct file_operations___360 {
	struct module___291 *owner;
	loff_t (*llseek)(struct file___360 *, loff_t, int);
	ssize_t (*read)(struct file___360 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___360 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___360 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___360 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___360 *, bool);
	int (*iterate)(struct file___360 *, struct dir_context *);
	int (*iterate_shared)(struct file___360 *, struct dir_context *);
	__poll_t (*poll)(struct file___360 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___360 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___360 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___360 *, struct vm_area_struct___361 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___360 *, struct file___360 *);
	int (*flush)(struct file___360 *, fl_owner_t);
	int (*release)(struct inode___360 *, struct file___360 *);
	int (*fsync)(struct file___360 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___360 *, int);
	int (*lock)(struct file___360 *, int, struct file_lock___360 *);
	ssize_t (*sendpage)(struct file___360 *, struct page___361 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___360 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___360 *, int, struct file_lock___360 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___360 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___360 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___360 *, long int, struct file_lock___360 **, void **);
	long int (*fallocate)(struct file___360 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___360 *);
	ssize_t (*copy_file_range)(struct file___360 *, loff_t, struct file___360 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___360 *, loff_t, struct file___360 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___360 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___360 {
	u64 seqnum;
	struct vm_area_struct___361 *vmas[4];
};

struct page_frag___360 {
	struct page___361 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___360;

struct bio_list___177;

struct backing_dev_info___177;

struct io_context___97;

struct request_queue___93;

struct vm_struct___266;

struct task_struct___361 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___361 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___360 *mm;
	struct mm_struct___360 *active_mm;
	struct vmacache___360 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___361 *real_parent;
	struct task_struct___361 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___361 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___216 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___216 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___216 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___2 *ptracer_cred;
	const struct cred___2 *real_cred;
	const struct cred___2 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___361 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___177 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___177 *backing_dev_info;
	struct io_context___97 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___360 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___93 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___361 *oom_reaper_list;
	struct vm_struct___266 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___140 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___361 *pgtable_t___360;

struct address_space___359;

struct dev_pagemap___348;

struct page___361 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___359 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___361 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___360 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___360 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___348 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___360;

struct lruvec___360 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___360 *pgdat;
};

struct zone___360 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___360 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___360 {
	struct zone___360 *zone;
	int zone_idx;
};

struct zonelist___360 {
	struct zoneref___360 _zonerefs[25];
};

struct pglist_data___360 {
	struct zone___360 node_zones[3];
	struct zonelist___360 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___361 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___361 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___360 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___361 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___361 *owner;
};

struct secondary_data___361 {
	void *stack;
	struct task_struct___361 *task;
	long int status;
};

struct blocking_notifier_head___360 {
	struct rw_semaphore___361 rwsem;
	struct notifier_block *head;
};

struct dentry___359;

struct path___360 {
	struct vfsmount *mnt;
	struct dentry___359 *dentry;
};

struct file___360 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___360 f_path;
	struct inode___360 *f_inode;
	const struct file_operations___360 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___216 f_owner;
	const struct cred___2 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___359 *f_mapping;
	errseq_t f_wb_err;
};

struct kernfs_root___353;

struct kernfs_elem_dir___353 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___353 *root;
};

struct kernfs_node___354;

struct kernfs_syscall_ops___353;

struct kernfs_root___353 {
	struct kernfs_node___354 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___353 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___353 {
	struct kernfs_node___354 *target_kn;
};

struct kernfs_ops___353;

struct kernfs_elem_attr___353 {
	const struct kernfs_ops___353 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___354 *notify_next;
};

struct kernfs_node___354 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___354 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___353 dir;
		struct kernfs_elem_symlink___353 symlink;
		struct kernfs_elem_attr___353 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___353;

struct kernfs_ops___353 {
	int (*open)(struct kernfs_open_file___353 *);
	void (*release)(struct kernfs_open_file___353 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___353 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___353 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___353 *, struct vm_area_struct___361 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___353 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___353 {
	int (*remount_fs)(struct kernfs_root___353 *, int *, char *);
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___353 *);
	int (*mkdir)(struct kernfs_node___354 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___354 *);
	int (*rename)(struct kernfs_node___354 *, struct kernfs_node___354 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___354 *, struct kernfs_root___353 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_operations_struct___348;

struct kernfs_open_file___353 {
	struct kernfs_node___354 *kn;
	struct file___360 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___348 *vm_ops;
};

struct vm_fault___348;

struct vm_operations_struct___348 {
	void (*open)(struct vm_area_struct___361 *);
	void (*close)(struct vm_area_struct___361 *);
	int (*split)(struct vm_area_struct___361 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___361 *);
	vm_fault_t (*fault)(struct vm_fault___348 *);
	vm_fault_t (*huge_fault)(struct vm_fault___348 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___348 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___361 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___348 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___348 *);
	int (*access)(struct vm_area_struct___361 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___361 *);
	int (*set_policy)(struct vm_area_struct___361 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___361 *, long unsigned int);
	struct page___361 * (*find_special_page)(struct vm_area_struct___361 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_area_struct___361 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___361 *vm_next;
	struct vm_area_struct___361 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___360 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___348 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___360 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___347;

struct bin_attribute___323;

struct attribute_group___324 {
	const char *name;
	umode_t (*is_visible)(struct kobject___347 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___347 *, struct bin_attribute___323 *, int);
	struct attribute **attrs;
	struct bin_attribute___323 **bin_attrs;
};

struct kset___346;

struct kobj_type___346;

struct kobject___347 {
	const char *name;
	struct list_head entry;
	struct kobject___347 *parent;
	struct kset___346 *kset;
	struct kobj_type___346 *ktype;
	struct kernfs_node___354 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___323 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___360 *, struct kobject___347 *, struct bin_attribute___323 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___360 *, struct kobject___347 *, struct bin_attribute___323 *, char *, loff_t, size_t);
	int (*mmap)(struct file___360 *, struct kobject___347 *, struct bin_attribute___323 *, struct vm_area_struct___361 *);
};

struct sysfs_ops___346 {
	ssize_t (*show)(struct kobject___347 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___347 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___346;

struct kset___346 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___347 kobj;
	const struct kset_uevent_ops___346 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___346 {
	void (*release)(struct kobject___347 *);
	const struct sysfs_ops___346 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___28 * (*child_ns_type)(struct kobject___347 *);
	const void * (*namespace)(struct kobject___347 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___346 {
	int (* const filter)(struct kset___346 *, struct kobject___347 *);
	const char * (* const name)(struct kset___346 *, struct kobject___347 *);
	int (* const uevent)(struct kset___346 *, struct kobject___347 *, struct kobj_uevent_env *);
};

struct kobj_attribute___338 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___347 *, struct kobj_attribute___338 *, char *);
	ssize_t (*store)(struct kobject___347 *, struct kobj_attribute___338 *, const char *, size_t);
};

struct kernel_param___288;

struct kernel_param_ops___288 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___288 *);
	int (*get)(char *, const struct kernel_param___288 *);
	void (*free)(void *);
};

struct kparam_array___288;

struct kernel_param___288 {
	const char *name;
	struct module___291 *mod;
	const struct kernel_param_ops___288 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___288 *arr;
	};
};

struct kparam_array___288 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___288 *ops;
	void *elem;
};

struct module_kobject___288 {
	struct kobject___347 kobj;
	struct module___291 *mod;
	struct kobject___347 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___288 {
	struct module___291 *mod;
	struct latch_tree_node node;
};

struct module_layout___288 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___288 mtn;
};

struct module_attribute___288;

struct module___291 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___288 mkobj;
	struct module_attribute___288 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___347 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___288 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___288 core_layout;
	struct module_layout___288 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___288 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___288 *, struct module_kobject___288 *, char *);
	ssize_t (*store)(struct module_attribute___288 *, struct module_kobject___288 *, const char *, size_t);
	void (*setup)(struct module___291 *, const char *);
	int (*test)(struct module___291 *);
	void (*free)(struct module___291 *);
};

struct core_state___360;

struct mm_struct___360 {
	struct {
		struct vm_area_struct___361 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___360 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___361 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___360 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___361 *owner;
		struct user_namespace___3 *user_ns;
		struct file___360 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___360 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___359;

struct address_space___359 {
	struct inode___360 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___361 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___359 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___348)(struct vm_area_struct___361 *, long unsigned int, const struct page___361 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___348)(struct page___361 *, void *);

struct device___327;

struct dev_pagemap___348 {
	dev_page_fault_t___348 page_fault;
	dev_page_free_t___348 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___327 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___360 {
	struct task_struct___361 *task;
	struct core_thread___360 *next;
};

struct core_state___360 {
	atomic_t nr_threads;
	struct core_thread___360 dumper;
	struct completion startup;
};

struct vm_fault___348 {
	struct vm_area_struct___361 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___361 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___361 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___360 prealloc_pte;
};

struct bio___177;

struct bio_list___177 {
	struct bio___177 *head;
	struct bio___177 *tail;
};

struct bdi_writeback_congested___177;

struct bdi_writeback___177 {
	struct backing_dev_info___177 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___177 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___157 *memcg_css;
	struct cgroup_subsys_state___157 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___177 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___177 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___327 *dev;
	struct device___327 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___359 *debug_dir;
	struct dentry___359 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___97;

struct io_context___97 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___97 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

typedef blk_qc_t make_request_fn___93(struct request_queue___93 *, struct bio___177 *);

struct request___93;

typedef int dma_drain_needed_fn___93(struct request___93 *);

struct bsg_ops___93;

struct bsg_class_device___93 {
	struct device___327 *class_dev;
	int minor;
	struct request_queue___93 *queue;
	const struct bsg_ops___93 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___177 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___177 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___93;

struct blk_mq_ops___30;

struct blk_mq_hw_ctx___30;

struct blk_mq_tag_set___30;

struct request_queue___93 {
	struct list_head queue_head;
	struct request___93 *last_merge;
	struct elevator_queue___93 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___93 *make_request_fn;
	dma_drain_needed_fn___93 *dma_drain_needed;
	const struct blk_mq_ops___30 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___30 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___177 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___347 kobj;
	struct kobject___347 *mq_kobj;
	struct blk_integrity integrity;
	struct device___327 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	struct bsg_class_device___93 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set___30 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___177 bio_split;
	struct dentry___359 *debugfs_dir;
	struct dentry___359 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___266 {
	struct vm_struct___266 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___361 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dev_pm_info___327 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___5 *subsys_data;
	void (*set_latency_tolerance)(struct device___327 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___327;

struct bus_type___327;

struct device_driver___327;

struct dev_pm_domain___327;

struct dma_map_ops___115;

struct fwnode_handle___249;

struct class___327;

struct device___327 {
	struct device___327 *parent;
	struct device_private *p;
	struct kobject___347 kobj;
	const char *init_name;
	const struct device_type___327 *type;
	struct mutex mutex;
	struct bus_type___327 *bus;
	struct device_driver___327 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___327 power;
	struct dev_pm_domain___327 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___115 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___249 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___327 *class;
	const struct attribute_group___324 **groups;
	void (*release)(struct device___327 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___359;

struct super_block___359;

struct dentry___359 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___359 *d_parent;
	struct qstr d_name;
	struct inode___360 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___359 *d_op;
	struct super_block___359 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___359;

struct block_device___359;

struct inode___360 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___359 *i_op;
	struct super_block___359 *i_sb;
	struct address_space___359 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___361 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___177 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___360 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___359 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___359 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___359 {
	int (*d_revalidate)(struct dentry___359 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___359 *, unsigned int);
	int (*d_hash)(const struct dentry___359 *, struct qstr *);
	int (*d_compare)(const struct dentry___359 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___359 *);
	int (*d_init)(struct dentry___359 *);
	void (*d_release)(struct dentry___359 *);
	void (*d_prune)(struct dentry___359 *);
	void (*d_iput)(struct dentry___359 *, struct inode___360 *);
	char * (*d_dname)(struct dentry___359 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___360 *);
	int (*d_manage)(const struct path___360 *, bool);
	struct dentry___359 * (*d_real)(struct dentry___359 *, const struct inode___360 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___359;

struct mem_dqinfo___359 {
	struct quota_format_type___359 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___359;

struct quota_info___359 {
	unsigned int flags;
	struct rw_semaphore___361 dqio_sem;
	struct inode___360 *files[3];
	struct mem_dqinfo___359 info[3];
	const struct quota_format_ops___359 *ops[3];
};

struct rcuwait___359 {
	struct task_struct___361 *task;
};

struct percpu_rw_semaphore___359 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___361 rw_sem;
	struct rcuwait___359 writer;
	int readers_block;
};

struct sb_writers___359 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___359 rw_sem[3];
};

struct file_system_type___359;

struct super_operations___359;

struct dquot_operations___359;

struct quotactl_ops___359;

struct super_block___359 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___359 *s_type;
	const struct super_operations___359 *s_op;
	const struct dquot_operations___359 *dq_op;
	const struct quotactl_ops___359 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___359 *s_root;
	struct rw_semaphore___361 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___359 *s_bdev;
	struct backing_dev_info___177 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___359 s_dquot;
	struct sb_writers___359 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___359 *s_d_op;
	int cleancache_poolid;
	struct shrinker___131 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct io_cq___97 {
	struct request_queue___93 *q;
	struct io_context___97 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___360 {
	struct file___360 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___360 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___359 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___360 *ia_file;
};

struct dquot___359 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___359 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___359 {
	int qf_fmt_id;
	const struct quota_format_ops___359 *qf_ops;
	struct module___291 *qf_owner;
	struct quota_format_type___359 *qf_next;
};

struct quota_format_ops___359 {
	int (*check_quota_file)(struct super_block___359 *, int);
	int (*read_file_info)(struct super_block___359 *, int);
	int (*write_file_info)(struct super_block___359 *, int);
	int (*free_file_info)(struct super_block___359 *, int);
	int (*read_dqblk)(struct dquot___359 *);
	int (*commit_dqblk)(struct dquot___359 *);
	int (*release_dqblk)(struct dquot___359 *);
	int (*get_next_id)(struct super_block___359 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___359 {
	int (*write_dquot)(struct dquot___359 *);
	struct dquot___359 * (*alloc_dquot)(struct super_block___359 *, int);
	void (*destroy_dquot)(struct dquot___359 *);
	int (*acquire_dquot)(struct dquot___359 *);
	int (*release_dquot)(struct dquot___359 *);
	int (*mark_dirty)(struct dquot___359 *);
	int (*write_info)(struct super_block___359 *, int);
	qsize_t * (*get_reserved_space)(struct inode___360 *);
	int (*get_projid)(struct inode___360 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___360 *, qsize_t *);
	int (*get_next_id)(struct super_block___359 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___359 {
	int (*quota_on)(struct super_block___359 *, int, int, const struct path___360 *);
	int (*quota_off)(struct super_block___359 *, int);
	int (*quota_enable)(struct super_block___359 *, unsigned int);
	int (*quota_disable)(struct super_block___359 *, unsigned int);
	int (*quota_sync)(struct super_block___359 *, int);
	int (*set_info)(struct super_block___359 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___359 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___359 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___359 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___359 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___359 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___359 {
	int (*writepage)(struct page___361 *, struct writeback_control___3 *);
	int (*readpage)(struct file___360 *, struct page___361 *);
	int (*writepages)(struct address_space___359 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___361 *);
	int (*readpages)(struct file___360 *, struct address_space___359 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___360 *, struct address_space___359 *, loff_t, unsigned int, unsigned int, struct page___361 **, void **);
	int (*write_end)(struct file___360 *, struct address_space___359 *, loff_t, unsigned int, unsigned int, struct page___361 *, void *);
	sector_t (*bmap)(struct address_space___359 *, sector_t);
	void (*invalidatepage)(struct page___361 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___361 *, gfp_t);
	void (*freepage)(struct page___361 *);
	ssize_t (*direct_IO)(struct kiocb___360 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___359 *, struct page___361 *, struct page___361 *, enum migrate_mode);
	bool (*isolate_page)(struct page___361 *, isolate_mode_t);
	void (*putback_page)(struct page___361 *);
	int (*launder_page)(struct page___361 *);
	int (*is_partially_uptodate)(struct page___361 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___361 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___359 *, struct page___361 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___360 *, sector_t *);
	void (*swap_deactivate)(struct file___360 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct hd_struct___97;

struct gendisk___97;

struct block_device___359 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___360 *bd_inode;
	struct super_block___359 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___359 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___97 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___97 *bd_disk;
	struct request_queue___93 *bd_queue;
	struct backing_dev_info___177 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct hd_struct___97 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___327 __dev;
	struct kobject___347 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___97;

struct block_device_operations___94;

struct gendisk___97 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___97 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___97 *part_tbl;
	struct hd_struct___97 part0;
	const struct block_device_operations___94 *fops;
	struct request_queue___93 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___361 lookup_sem;
	struct kobject___347 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___347 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___359 {
	struct dentry___359 * (*lookup)(struct inode___360 *, struct dentry___359 *, unsigned int);
	const char * (*get_link)(struct dentry___359 *, struct inode___360 *, struct delayed_call *);
	int (*permission)(struct inode___360 *, int);
	struct posix_acl * (*get_acl)(struct inode___360 *, int);
	int (*readlink)(struct dentry___359 *, char *, int);
	int (*create)(struct inode___360 *, struct dentry___359 *, umode_t, bool);
	int (*link)(struct dentry___359 *, struct inode___360 *, struct dentry___359 *);
	int (*unlink)(struct inode___360 *, struct dentry___359 *);
	int (*symlink)(struct inode___360 *, struct dentry___359 *, const char *);
	int (*mkdir)(struct inode___360 *, struct dentry___359 *, umode_t);
	int (*rmdir)(struct inode___360 *, struct dentry___359 *);
	int (*mknod)(struct inode___360 *, struct dentry___359 *, umode_t, dev_t);
	int (*rename)(struct inode___360 *, struct dentry___359 *, struct inode___360 *, struct dentry___359 *, unsigned int);
	int (*setattr)(struct dentry___359 *, struct iattr___359 *);
	int (*getattr)(const struct path___360 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___359 *, char *, size_t);
	int (*fiemap)(struct inode___360 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___360 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___360 *, struct dentry___359 *, struct file___360 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___360 *, struct dentry___359 *, umode_t);
	int (*set_acl)(struct inode___360 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___359 {
	void (*fl_copy_lock)(struct file_lock___360 *, struct file_lock___360 *);
	void (*fl_release_private)(struct file_lock___360 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___359;

struct lock_manager_operations___359;

struct file_lock___360 {
	struct file_lock___360 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___360 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___359 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___359 *fl_ops;
	const struct lock_manager_operations___359 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___359 {
	int (*lm_compare_owner)(struct file_lock___360 *, struct file_lock___360 *);
	long unsigned int (*lm_owner_key)(struct file_lock___360 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___360 *);
	int (*lm_grant)(struct file_lock___360 *, int);
	bool (*lm_break)(struct file_lock___360 *);
	int (*lm_change)(struct file_lock___360 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___360 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___359 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___359 *fa_next;
	struct file___360 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___359 {
	const char *name;
	int fs_flags;
	struct dentry___359 * (*mount)(struct file_system_type___359 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___359 *);
	struct module___291 *owner;
	struct file_system_type___359 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___359 {
	struct inode___360 * (*alloc_inode)(struct super_block___359 *);
	void (*destroy_inode)(struct inode___360 *);
	void (*dirty_inode)(struct inode___360 *, int);
	int (*write_inode)(struct inode___360 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___360 *);
	void (*evict_inode)(struct inode___360 *);
	void (*put_super)(struct super_block___359 *);
	int (*sync_fs)(struct super_block___359 *, int);
	int (*freeze_super)(struct super_block___359 *);
	int (*freeze_fs)(struct super_block___359 *);
	int (*thaw_super)(struct super_block___359 *);
	int (*unfreeze_fs)(struct super_block___359 *);
	int (*statfs)(struct dentry___359 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___359 *, int *, char *);
	void (*umount_begin)(struct super_block___359 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___359 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___359 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___359 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___359 *);
	ssize_t (*quota_read)(struct super_block___359 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___359 *, int, const char *, size_t, loff_t);
	struct dquot___359 ** (*get_dquots)(struct inode___360 *);
	int (*bdev_try_to_free_page)(struct super_block___359 *, struct page___361 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___359 *, struct shrink_control___131 *);
	long int (*free_cached_objects)(struct super_block___359 *, struct shrink_control___131 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___177(struct bio___177 *);

struct bio_vec___179 {
	struct page___361 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___177;

struct bio___177 {
	struct bio___177 *bi_next;
	struct gendisk___97 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___177 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___177 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___179 *bi_io_vec;
	struct bio_set___177 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___179 bi_inline_vecs[0];
};

typedef void compound_page_dtor___348(struct page___361 *);

struct fwnode_operations___249;

struct fwnode_handle___249 {
	struct fwnode_handle___249 *secondary;
	const struct fwnode_operations___249 *ops;
};

struct fwnode_reference_args___249;

struct fwnode_endpoint___249;

struct fwnode_operations___249 {
	struct fwnode_handle___249 * (*get)(struct fwnode_handle___249 *);
	void (*put)(struct fwnode_handle___249 *);
	bool (*device_is_available)(const struct fwnode_handle___249 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___249 *, const struct device___327 *);
	bool (*property_present)(const struct fwnode_handle___249 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___249 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___249 *, const char *, const char **, size_t);
	struct fwnode_handle___249 * (*get_parent)(const struct fwnode_handle___249 *);
	struct fwnode_handle___249 * (*get_next_child_node)(const struct fwnode_handle___249 *, struct fwnode_handle___249 *);
	struct fwnode_handle___249 * (*get_named_child_node)(const struct fwnode_handle___249 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___249 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___249 *);
	struct fwnode_handle___249 * (*graph_get_next_endpoint)(const struct fwnode_handle___249 *, struct fwnode_handle___249 *);
	struct fwnode_handle___249 * (*graph_get_remote_endpoint)(const struct fwnode_handle___249 *);
	struct fwnode_handle___249 * (*graph_get_port_parent)(struct fwnode_handle___249 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___249 *, struct fwnode_endpoint___249 *);
};

struct fwnode_endpoint___249 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___249 *local_fwnode;
};

struct fwnode_reference_args___249 {
	struct fwnode_handle___249 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct dev_pm_ops___327 {
	int (*prepare)(struct device___327 *);
	void (*complete)(struct device___327 *);
	int (*suspend)(struct device___327 *);
	int (*resume)(struct device___327 *);
	int (*freeze)(struct device___327 *);
	int (*thaw)(struct device___327 *);
	int (*poweroff)(struct device___327 *);
	int (*restore)(struct device___327 *);
	int (*suspend_late)(struct device___327 *);
	int (*resume_early)(struct device___327 *);
	int (*freeze_late)(struct device___327 *);
	int (*thaw_early)(struct device___327 *);
	int (*poweroff_late)(struct device___327 *);
	int (*restore_early)(struct device___327 *);
	int (*suspend_noirq)(struct device___327 *);
	int (*resume_noirq)(struct device___327 *);
	int (*freeze_noirq)(struct device___327 *);
	int (*thaw_noirq)(struct device___327 *);
	int (*poweroff_noirq)(struct device___327 *);
	int (*restore_noirq)(struct device___327 *);
	int (*runtime_suspend)(struct device___327 *);
	int (*runtime_resume)(struct device___327 *);
	int (*runtime_idle)(struct device___327 *);
};

struct dev_pm_domain___327 {
	struct dev_pm_ops___327 ops;
	void (*detach)(struct device___327 *, bool);
	int (*activate)(struct device___327 *);
	void (*sync)(struct device___327 *);
	void (*dismiss)(struct device___327 *);
};

struct bus_type___327 {
	const char *name;
	const char *dev_name;
	struct device___327 *dev_root;
	const struct attribute_group___324 **bus_groups;
	const struct attribute_group___324 **dev_groups;
	const struct attribute_group___324 **drv_groups;
	int (*match)(struct device___327 *, struct device_driver___327 *);
	int (*uevent)(struct device___327 *, struct kobj_uevent_env *);
	int (*probe)(struct device___327 *);
	int (*remove)(struct device___327 *);
	void (*shutdown)(struct device___327 *);
	int (*online)(struct device___327 *);
	int (*offline)(struct device___327 *);
	int (*suspend)(struct device___327 *, pm_message_t);
	int (*resume)(struct device___327 *);
	int (*num_vf)(struct device___327 *);
	int (*dma_configure)(struct device___327 *);
	const struct dev_pm_ops___327 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___327 {
	const char *name;
	struct bus_type___327 *bus;
	struct module___291 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___327 *);
	int (*remove)(struct device___327 *);
	void (*shutdown)(struct device___327 *);
	int (*suspend)(struct device___327 *, pm_message_t);
	int (*resume)(struct device___327 *);
	const struct attribute_group___324 **groups;
	const struct dev_pm_ops___327 *pm;
	void (*coredump)(struct device___327 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___327 {
	const char *name;
	const struct attribute_group___324 **groups;
	int (*uevent)(struct device___327 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___327 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___327 *);
	const struct dev_pm_ops___327 *pm;
};

struct class___327 {
	const char *name;
	struct module___291 *owner;
	const struct attribute_group___324 **class_groups;
	const struct attribute_group___324 **dev_groups;
	struct kobject___347 *dev_kobj;
	int (*dev_uevent)(struct device___327 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___327 *, umode_t *);
	void (*class_release)(struct class___327 *);
	void (*dev_release)(struct device___327 *);
	int (*shutdown_pre)(struct device___327 *);
	const struct kobj_ns_type_operations___28 *ns_type;
	const void * (*namespace)(struct device___327 *);
	const struct dev_pm_ops___327 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___115 {
	void * (*alloc)(struct device___327 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___327 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___327 *, struct vm_area_struct___361 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___327 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___327 *, struct page___361 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___327 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___327 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___327 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___327 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___327 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___327 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___327 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___327 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___327 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___327 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___327 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___327 *, u64);
	u64 (*get_required_mask)(struct device___327 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct bio_integrity_payload___177 {
	struct bio___177 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___179 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___179 bip_inline_vecs[0];
};

struct disk_part_tbl___97 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___97 *last_lookup;
	struct hd_struct___97 *part[0];
};

struct block_device_operations___94 {
	int (*open)(struct block_device___359 *, fmode_t);
	void (*release)(struct gendisk___97 *, fmode_t);
	int (*rw_page)(struct block_device___359 *, sector_t, struct page___361 *, unsigned int);
	int (*ioctl)(struct block_device___359 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___359 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___97 *, unsigned int);
	int (*media_changed)(struct gendisk___97 *);
	void (*unlock_native_capacity)(struct gendisk___97 *);
	int (*revalidate_disk)(struct gendisk___97 *);
	int (*getgeo)(struct block_device___359 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___359 *, long unsigned int);
	int (*report_zones)(struct gendisk___97 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___291 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bdi_writeback_congested___177 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___177 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bsg_ops___93 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___93 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___93 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___93 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___93(struct request___93 *, blk_status_t);

struct request___93 {
	struct request_queue___93 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___30 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___177 *bio;
	struct bio___177 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___179 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___97 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___93 *saved_end_io;
		} flush;
	};
	struct gendisk___97 *rq_disk;
	struct hd_struct___97 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___93 *end_io;
	void *end_io_data;
	struct request___93 *next_rq;
};

struct blk_mq_hw_ctx___30 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___93 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags___4 *tags;
	struct blk_mq_tags___4 *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	unsigned int rh_reserved_nr_expired;
	struct hlist_node cpuhp_dead;
	struct kobject___347 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___359 *debugfs_dir;
	struct dentry___359 *sched_debugfs_dir;
	struct list_head hctx_list;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___93;

struct elevator_mq_ops___93 {
	int (*init_sched)(struct request_queue___93 *, struct elevator_type___93 *);
	void (*exit_sched)(struct elevator_queue___93 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___30 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___30 *, unsigned int);
	bool (*allow_merge)(struct request_queue___93 *, struct request___93 *, struct bio___177 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx___30 *, struct bio___177 *);
	int (*request_merge)(struct request_queue___93 *, struct request___93 **, struct bio___177 *);
	void (*request_merged)(struct request_queue___93 *, struct request___93 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___93 *, struct request___93 *, struct request___93 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___93 *, struct bio___177 *);
	void (*finish_request)(struct request___93 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___30 *, struct list_head *, bool);
	struct request___93 * (*dispatch_request)(struct blk_mq_hw_ctx___30 *);
	bool (*has_work)(struct blk_mq_hw_ctx___30 *);
	void (*completed_request)(struct request___93 *, u64);
	void (*started_request)(struct request___93 *);
	void (*requeue_request)(struct request___93 *);
	struct request___93 * (*former_request)(struct request_queue___93 *, struct request___93 *);
	struct request___93 * (*next_request)(struct request_queue___93 *, struct request___93 *);
	void (*init_icq)(struct io_cq___97 *);
	void (*exit_icq)(struct io_cq___97 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx___30 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___93;

struct elevator_type___93 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___93 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___93 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___291 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___93 {
	struct elevator_type___93 *type;
	void *elevator_data;
	struct kobject___347 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___93 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___93 *, char *);
	ssize_t (*store)(struct elevator_queue___93 *, const char *, size_t);
};

struct blk_mq_queue_data___30;

typedef blk_status_t queue_rq_fn___30(struct blk_mq_hw_ctx___30 *, const struct blk_mq_queue_data___30 *);

typedef void commit_rqs_fn___30(struct blk_mq_hw_ctx___30 *);

typedef bool get_budget_fn___30(struct blk_mq_hw_ctx___30 *);

typedef void put_budget_fn___30(struct blk_mq_hw_ctx___30 *);

typedef enum blk_eh_timer_return timeout_fn___30(struct request___93 *, bool);

typedef int poll_fn___30(struct blk_mq_hw_ctx___30 *);

typedef void complete_fn___30(struct request___93 *);

typedef int init_hctx_fn___30(struct blk_mq_hw_ctx___30 *, void *, unsigned int);

typedef void exit_hctx_fn___30(struct blk_mq_hw_ctx___30 *, unsigned int);

typedef int init_request_fn___30(struct blk_mq_tag_set___30 *, struct request___93 *, unsigned int, unsigned int);

typedef void exit_request_fn___30(struct blk_mq_tag_set___30 *, struct request___93 *, unsigned int);

typedef bool busy_fn___30(struct request_queue___93 *);

typedef int map_queues_fn___30(struct blk_mq_tag_set___30 *);

typedef void cleanup_rq_fn___30(struct request___93 *);

struct blk_mq_ops___30 {
	queue_rq_fn___30 *queue_rq;
	commit_rqs_fn___30 *commit_rqs;
	get_budget_fn___30 *get_budget;
	put_budget_fn___30 *put_budget;
	timeout_fn___30 *timeout;
	poll_fn___30 *poll;
	complete_fn___30 *complete;
	init_hctx_fn___30 *init_hctx;
	exit_hctx_fn___30 *exit_hctx;
	init_request_fn___30 *init_request;
	exit_request_fn___30 *exit_request;
	void (*initialize_rq_fn)(struct request___93 *);
	busy_fn___30 *busy;
	map_queues_fn___30 *map_queues;
	void (*show_rq)(struct seq_file___9 *, struct request___93 *);
	union {
		cleanup_rq_fn___30 *cleanup_rq;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide47;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct blk_mq_tag_set___30 {
	struct blk_mq_queue_map map[6];
	unsigned int nr_maps;
	const struct blk_mq_ops___30 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	struct blk_mq_tags___4 **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct scsi_target___11;

struct scsi_device_handler___5;

struct scsi_device___11 {
	struct Scsi_Host___5 *host;
	struct request_queue___93 *request_queue;
	struct list_head siblings;
	struct list_head same_target_siblings;
	atomic_t device_busy;
	atomic_t device_blocked;
	spinlock_t list_lock;
	struct list_head cmd_list;
	struct list_head starved_entry;
	short unsigned int queue_depth;
	short unsigned int max_queue_depth;
	short unsigned int last_queue_full_depth;
	short unsigned int last_queue_full_count;
	long unsigned int last_queue_full_time;
	long unsigned int queue_ramp_up_period;
	long unsigned int last_queue_ramp_up;
	unsigned int id;
	unsigned int channel;
	u64 lun;
	unsigned int manufacturer;
	unsigned int sector_size;
	void *hostdata;
	unsigned char type;
	char scsi_level;
	char inq_periph_qual;
	struct mutex inquiry_mutex;
	unsigned char inquiry_len;
	unsigned char *inquiry;
	const char *vendor;
	const char *model;
	const char *rev;
	struct scsi_vpd *vpd_pg83;
	struct scsi_vpd *vpd_pg80;
	unsigned char current_tag;
	struct scsi_target___11 *sdev_target;
	blist_flags_t sdev_bflags;
	unsigned int eh_timeout;
	unsigned int removable: 1;
	unsigned int changed: 1;
	unsigned int busy: 1;
	unsigned int lockable: 1;
	unsigned int locked: 1;
	unsigned int borken: 1;
	unsigned int disconnect: 1;
	unsigned int soft_reset: 1;
	unsigned int sdtr: 1;
	unsigned int wdtr: 1;
	unsigned int ppr: 1;
	unsigned int tagged_supported: 1;
	unsigned int simple_tags: 1;
	unsigned int was_reset: 1;
	unsigned int expecting_cc_ua: 1;
	unsigned int use_10_for_rw: 1;
	unsigned int use_10_for_ms: 1;
	unsigned int no_report_opcodes: 1;
	unsigned int no_write_same: 1;
	unsigned int use_16_for_rw: 1;
	unsigned int skip_ms_page_8: 1;
	unsigned int skip_ms_page_3f: 1;
	unsigned int skip_vpd_pages: 1;
	unsigned int try_vpd_pages: 1;
	unsigned int use_192_bytes_for_3f: 1;
	unsigned int no_start_on_add: 1;
	unsigned int allow_restart: 1;
	unsigned int manage_start_stop: 1;
	unsigned int start_stop_pwr_cond: 1;
	unsigned int no_uld_attach: 1;
	unsigned int select_no_atn: 1;
	unsigned int fix_capacity: 1;
	unsigned int guess_capacity: 1;
	unsigned int retry_hwerror: 1;
	unsigned int last_sector_bug: 1;
	unsigned int no_read_disc_info: 1;
	unsigned int no_read_capacity_16: 1;
	unsigned int try_rc_10_first: 1;
	unsigned int security_supported: 1;
	unsigned int is_visible: 1;
	unsigned int wce_default_on: 1;
	unsigned int no_dif: 1;
	unsigned int broken_fua: 1;
	unsigned int lun_in_cdb: 1;
	unsigned int unmap_limit_for_ws: 1;
	atomic_t disk_events_disable_depth;
	long unsigned int supported_events[1];
	long unsigned int pending_events[1];
	struct list_head event_list;
	struct work_struct event_work;
	unsigned int max_device_blocked;
	atomic_t iorequest_cnt;
	atomic_t iodone_cnt;
	atomic_t ioerr_cnt;
	struct device___327 sdev_gendev;
	struct device___327 sdev_dev;
	struct execute_work ew;
	struct work_struct requeue_work;
	struct scsi_device_handler___5 *handler;
	void *handler_data;
	unsigned char access_state;
	struct mutex state_mutex;
	enum scsi_device_state sdev_state;
	struct task_struct___361 *quiesced_by;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int sdev_data[0];
};

struct scsi_target___11 {
	struct scsi_device___11 *starget_sdev_user;
	struct list_head siblings;
	struct list_head devices;
	struct device___327 dev;
	struct kref reap_ref;
	unsigned int channel;
	unsigned int id;
	unsigned int create: 1;
	unsigned int single_lun: 1;
	unsigned int pdt_1f_for_no_lun: 1;
	unsigned int no_report_luns: 1;
	unsigned int expecting_lun_change: 1;
	atomic_t target_busy;
	atomic_t target_blocked;
	unsigned int can_queue;
	unsigned int max_target_blocked;
	char scsi_level;
	enum scsi_target_state state;
	void *hostdata;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int starget_data[0];
};

struct scsi_device_handler___5 {
	struct list_head list;
	struct module___291 *module;
	const char *name;
	int (*check_sense)(struct scsi_device___11 *, struct scsi_sense_hdr *);
	int (*attach)(struct scsi_device___11 *);
	void (*detach)(struct scsi_device___11 *);
	int (*activate)(struct scsi_device___11 *, activate_complete, void *);
	blk_status_t (*prep_fn)(struct scsi_device___11 *, struct request___93 *);
	int (*set_params)(struct scsi_device___11 *, const char *);
	void (*rescan)(struct scsi_device___11 *);
};

struct blk_mq_queue_data___30 {
	struct request___93 *rq;
	bool last;
	long unsigned int rh_reserved1;
};

struct hp_sw_dh_data {
	int path_state;
	int retries;
	int retry_cnt;
	struct scsi_device___11 *sdev;
};

struct clariion_dh_data {
	unsigned int flags;
	unsigned char buffer[252];
	int lun_state;
	int port;
	int default_sp;
	int current_sp;
};

struct module_version_attribute___8 {
	struct module_attribute___288 mattr;
	const char *module_name;
	const char *version;
};

struct alua_port_group {
	struct kref kref;
	struct callback_head rcu;
	struct list_head node;
	struct list_head dh_list;
	unsigned char device_id_str[256];
	int device_id_len;
	int group_id;
	int tpgs;
	int state;
	int pref;
	int valid_states;
	unsigned int flags;
	unsigned char transition_tmo;
	long unsigned int expiry;
	long unsigned int interval;
	struct delayed_work rtpg_work;
	spinlock_t lock;
	struct list_head rtpg_list;
	struct scsi_device___11 *rtpg_sdev;
};

struct alua_dh_data {
	struct list_head node;
	struct alua_port_group *pg;
	int group_id;
	spinlock_t pg_lock;
	struct scsi_device___11 *sdev;
	int init_error;
	struct mutex init_mutex;
};

struct alua_queue_data {
	struct list_head entry;
	activate_complete callback_fn;
	void *callback_data;
};

struct module___292;

struct file___361;

struct kiocb___361;

struct iov_iter___155;

struct vm_area_struct___362;

struct inode___361;

struct file_lock___361;

struct page___362;

struct seq_file___305;

struct file_operations___361 {
	struct module___292 *owner;
	loff_t (*llseek)(struct file___361 *, loff_t, int);
	ssize_t (*read)(struct file___361 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___361 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___361 *, struct iov_iter___155 *);
	ssize_t (*write_iter)(struct kiocb___361 *, struct iov_iter___155 *);
	int (*iopoll)(struct kiocb___361 *, bool);
	int (*iterate)(struct file___361 *, struct dir_context *);
	int (*iterate_shared)(struct file___361 *, struct dir_context *);
	__poll_t (*poll)(struct file___361 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___361 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___361 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___361 *, struct vm_area_struct___362 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___361 *, struct file___361 *);
	int (*flush)(struct file___361 *, fl_owner_t);
	int (*release)(struct inode___361 *, struct file___361 *);
	int (*fsync)(struct file___361 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___361 *, int);
	int (*lock)(struct file___361 *, int, struct file_lock___361 *);
	ssize_t (*sendpage)(struct file___361 *, struct page___362 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___361 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___361 *, int, struct file_lock___361 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___361 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___361 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___361 *, long int, struct file_lock___361 **, void **);
	long int (*fallocate)(struct file___361 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___305 *, struct file___361 *);
	ssize_t (*copy_file_range)(struct file___361 *, loff_t, struct file___361 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___361 *, loff_t, struct file___361 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___361 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___361 {
	u64 seqnum;
	struct vm_area_struct___362 *vmas[4];
};

struct page_frag___361 {
	struct page___362 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___361;

struct cred___332;

struct bio_list___178;

struct backing_dev_info___178;

struct io_context___98;

struct request_queue___94;

struct vm_struct___267;

struct task_struct___362 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___362 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___361 *mm;
	struct mm_struct___361 *active_mm;
	struct vmacache___361 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___362 *real_parent;
	struct task_struct___362 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___362 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___216 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___216 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___216 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___332 *ptracer_cred;
	const struct cred___332 *real_cred;
	const struct cred___332 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___362 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___178 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___178 *backing_dev_info;
	struct io_context___98 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___361 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___94 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___362 *oom_reaper_list;
	struct vm_struct___267 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___140 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___362 *pgtable_t___361;

struct address_space___360;

struct dev_pagemap___349;

struct page___362 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___360 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___362 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___361 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___361 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___349 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___361;

struct lruvec___361 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___361 *pgdat;
};

struct zone___361 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___361 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___361 {
	struct zone___361 *zone;
	int zone_idx;
};

struct zonelist___361 {
	struct zoneref___361 _zonerefs[25];
};

struct pglist_data___361 {
	struct zone___361 node_zones[3];
	struct zonelist___361 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___362 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___362 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___361 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___362 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___362 *owner;
};

struct secondary_data___362 {
	void *stack;
	struct task_struct___362 *task;
	long int status;
};

struct blocking_notifier_head___361 {
	struct rw_semaphore___362 rwsem;
	struct notifier_block *head;
};

struct dentry___360;

struct path___361 {
	struct vfsmount *mnt;
	struct dentry___360 *dentry;
};

struct file___361 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___361 f_path;
	struct inode___361 *f_inode;
	const struct file_operations___361 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___216 f_owner;
	const struct cred___332 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___360 *f_mapping;
	errseq_t f_wb_err;
};

struct key___332;

struct user_struct___332;

struct cred___332 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___332 *session_keyring;
	struct key___332 *process_keyring;
	struct key___332 *thread_keyring;
	struct key___332 *request_key_auth;
	void *security;
	struct user_struct___332 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___354;

struct kernfs_elem_dir___354 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___354 *root;
};

struct kernfs_node___355;

struct kernfs_syscall_ops___354;

struct kernfs_root___354 {
	struct kernfs_node___355 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___354 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___354 {
	struct kernfs_node___355 *target_kn;
};

struct kernfs_ops___354;

struct kernfs_elem_attr___354 {
	const struct kernfs_ops___354 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___355 *notify_next;
};

struct kernfs_node___355 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___355 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___354 dir;
		struct kernfs_elem_symlink___354 symlink;
		struct kernfs_elem_attr___354 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___354;

struct kernfs_ops___354 {
	int (*open)(struct kernfs_open_file___354 *);
	void (*release)(struct kernfs_open_file___354 *);
	int (*seq_show)(struct seq_file___305 *, void *);
	void * (*seq_start)(struct seq_file___305 *, loff_t *);
	void * (*seq_next)(struct seq_file___305 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___305 *, void *);
	ssize_t (*read)(struct kernfs_open_file___354 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___354 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___354 *, struct vm_area_struct___362 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___354 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___354 {
	int (*remount_fs)(struct kernfs_root___354 *, int *, char *);
	int (*show_options)(struct seq_file___305 *, struct kernfs_root___354 *);
	int (*mkdir)(struct kernfs_node___355 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___355 *);
	int (*rename)(struct kernfs_node___355 *, struct kernfs_node___355 *, const char *);
	int (*show_path)(struct seq_file___305 *, struct kernfs_node___355 *, struct kernfs_root___354 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___304;

struct seq_file___305 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___304 *op;
	int poll_event;
	const struct file___361 *file;
	void *private;
};

struct vm_operations_struct___349;

struct kernfs_open_file___354 {
	struct kernfs_node___355 *kn;
	struct file___361 *file;
	struct seq_file___305 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___349 *vm_ops;
};

struct vm_fault___349;

struct vm_operations_struct___349 {
	void (*open)(struct vm_area_struct___362 *);
	void (*close)(struct vm_area_struct___362 *);
	int (*split)(struct vm_area_struct___362 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___362 *);
	vm_fault_t (*fault)(struct vm_fault___349 *);
	vm_fault_t (*huge_fault)(struct vm_fault___349 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___349 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___362 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___349 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___349 *);
	int (*access)(struct vm_area_struct___362 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___362 *);
	int (*set_policy)(struct vm_area_struct___362 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___362 *, long unsigned int);
	struct page___362 * (*find_special_page)(struct vm_area_struct___362 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_area_struct___362 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___362 *vm_next;
	struct vm_area_struct___362 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___361 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___349 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___361 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___348;

struct bin_attribute___324;

struct attribute_group___325 {
	const char *name;
	umode_t (*is_visible)(struct kobject___348 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___348 *, struct bin_attribute___324 *, int);
	struct attribute **attrs;
	struct bin_attribute___324 **bin_attrs;
};

struct kset___347;

struct kobj_type___347;

struct kobject___348 {
	const char *name;
	struct list_head entry;
	struct kobject___348 *parent;
	struct kset___347 *kset;
	struct kobj_type___347 *ktype;
	struct kernfs_node___355 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___324 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___361 *, struct kobject___348 *, struct bin_attribute___324 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___361 *, struct kobject___348 *, struct bin_attribute___324 *, char *, loff_t, size_t);
	int (*mmap)(struct file___361 *, struct kobject___348 *, struct bin_attribute___324 *, struct vm_area_struct___362 *);
};

struct sysfs_ops___347 {
	ssize_t (*show)(struct kobject___348 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___348 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___347;

struct kset___347 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___348 kobj;
	const struct kset_uevent_ops___347 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___347 {
	void (*release)(struct kobject___348 *);
	const struct sysfs_ops___347 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___28 * (*child_ns_type)(struct kobject___348 *);
	const void * (*namespace)(struct kobject___348 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___347 {
	int (* const filter)(struct kset___347 *, struct kobject___348 *);
	const char * (* const name)(struct kset___347 *, struct kobject___348 *);
	int (* const uevent)(struct kset___347 *, struct kobject___348 *, struct kobj_uevent_env *);
};

struct kobj_attribute___339 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___348 *, struct kobj_attribute___339 *, char *);
	ssize_t (*store)(struct kobject___348 *, struct kobj_attribute___339 *, const char *, size_t);
};

struct kernel_param___289;

struct kernel_param_ops___289 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___289 *);
	int (*get)(char *, const struct kernel_param___289 *);
	void (*free)(void *);
};

struct kparam_array___289;

struct kernel_param___289 {
	const char *name;
	struct module___292 *mod;
	const struct kernel_param_ops___289 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___289 *arr;
	};
};

struct kparam_array___289 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___289 *ops;
	void *elem;
};

struct module_kobject___289 {
	struct kobject___348 kobj;
	struct module___292 *mod;
	struct kobject___348 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___289 {
	struct module___292 *mod;
	struct latch_tree_node node;
};

struct module_layout___289 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___289 mtn;
};

struct module_attribute___289;

struct module___292 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___289 mkobj;
	struct module_attribute___289 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___348 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___289 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___289 core_layout;
	struct module_layout___289 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___289 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___289 *, struct module_kobject___289 *, char *);
	ssize_t (*store)(struct module_attribute___289 *, struct module_kobject___289 *, const char *, size_t);
	void (*setup)(struct module___292 *, const char *);
	int (*test)(struct module___292 *);
	void (*free)(struct module___292 *);
};

struct dentry_operations___360;

struct super_block___360;

struct dentry___360 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___360 *d_parent;
	struct qstr d_name;
	struct inode___361 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___360 *d_op;
	struct super_block___360 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___360;

struct address_space___360 {
	struct inode___361 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___362 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___360 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___360;

struct bdi_writeback___178;

struct block_device___360;

struct inode___361 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___360 *i_op;
	struct super_block___360 *i_sb;
	struct address_space___360 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___362 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___178 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___361 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___360 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___360 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___360 {
	int (*d_revalidate)(struct dentry___360 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___360 *, unsigned int);
	int (*d_hash)(const struct dentry___360 *, struct qstr *);
	int (*d_compare)(const struct dentry___360 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___360 *);
	int (*d_init)(struct dentry___360 *);
	void (*d_release)(struct dentry___360 *);
	void (*d_prune)(struct dentry___360 *);
	void (*d_iput)(struct dentry___360 *, struct inode___361 *);
	char * (*d_dname)(struct dentry___360 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___361 *);
	int (*d_manage)(const struct path___361 *, bool);
	struct dentry___360 * (*d_real)(struct dentry___360 *, const struct inode___361 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___360;

struct mem_dqinfo___360 {
	struct quota_format_type___360 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___360;

struct quota_info___360 {
	unsigned int flags;
	struct rw_semaphore___362 dqio_sem;
	struct inode___361 *files[3];
	struct mem_dqinfo___360 info[3];
	const struct quota_format_ops___360 *ops[3];
};

struct rcuwait___360 {
	struct task_struct___362 *task;
};

struct percpu_rw_semaphore___360 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___362 rw_sem;
	struct rcuwait___360 writer;
	int readers_block;
};

struct sb_writers___360 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___360 rw_sem[3];
};

struct file_system_type___360;

struct super_operations___360;

struct dquot_operations___360;

struct quotactl_ops___360;

struct super_block___360 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___360 *s_type;
	const struct super_operations___360 *s_op;
	const struct dquot_operations___360 *dq_op;
	const struct quotactl_ops___360 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___360 *s_root;
	struct rw_semaphore___362 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___360 *s_bdev;
	struct backing_dev_info___178 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___360 s_dquot;
	struct sb_writers___360 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___360 *s_d_op;
	int cleancache_poolid;
	struct shrinker___131 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct core_state___361;

struct mm_struct___361 {
	struct {
		struct vm_area_struct___362 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___361 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___362 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___361 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___362 *owner;
		struct user_namespace___3 *user_ns;
		struct file___361 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___361 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___349)(struct vm_area_struct___362 *, long unsigned int, const struct page___362 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___349)(struct page___362 *, void *);

struct device___328;

struct dev_pagemap___349 {
	dev_page_fault_t___349 page_fault;
	dev_page_free_t___349 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___328 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___361 {
	struct task_struct___362 *task;
	struct core_thread___361 *next;
};

struct core_state___361 {
	atomic_t nr_threads;
	struct core_thread___361 dumper;
	struct completion startup;
};

struct vm_fault___349 {
	struct vm_area_struct___362 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___362 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___362 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___361 prealloc_pte;
};

struct user_struct___332 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___332 *uid_keyring;
	struct key___332 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio___178;

struct bio_list___178 {
	struct bio___178 *head;
	struct bio___178 *tail;
};

struct bdi_writeback_congested___178;

struct bdi_writeback___178 {
	struct backing_dev_info___178 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___178 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___157 *memcg_css;
	struct cgroup_subsys_state___157 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___178 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___178 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___328 *dev;
	struct device___328 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___360 *debug_dir;
	struct dentry___360 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___98;

struct io_context___98 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___98 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

typedef blk_qc_t make_request_fn___94(struct request_queue___94 *, struct bio___178 *);

struct request___94;

typedef int dma_drain_needed_fn___94(struct request___94 *);

struct bsg_ops___94;

struct bsg_class_device___94 {
	struct device___328 *class_dev;
	int minor;
	struct request_queue___94 *queue;
	const struct bsg_ops___94 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___178 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___178 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___94;

struct blk_mq_ops___31;

struct blk_mq_hw_ctx___31;

struct blk_mq_tag_set___31;

struct request_queue___94 {
	struct list_head queue_head;
	struct request___94 *last_merge;
	struct elevator_queue___94 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___94 *make_request_fn;
	dma_drain_needed_fn___94 *dma_drain_needed;
	const struct blk_mq_ops___31 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___31 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___178 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___348 kobj;
	struct kobject___348 *mq_kobj;
	struct blk_integrity integrity;
	struct device___328 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	struct bsg_class_device___94 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set___31 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___178 bio_split;
	struct dentry___360 *debugfs_dir;
	struct dentry___360 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___267 {
	struct vm_struct___267 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___362 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct io_cq___98 {
	struct request_queue___94 *q;
	struct io_context___98 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___361 {
	struct file___361 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___361 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___360 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___361 *ia_file;
};

struct dquot___360 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___360 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___360 {
	int qf_fmt_id;
	const struct quota_format_ops___360 *qf_ops;
	struct module___292 *qf_owner;
	struct quota_format_type___360 *qf_next;
};

struct quota_format_ops___360 {
	int (*check_quota_file)(struct super_block___360 *, int);
	int (*read_file_info)(struct super_block___360 *, int);
	int (*write_file_info)(struct super_block___360 *, int);
	int (*free_file_info)(struct super_block___360 *, int);
	int (*read_dqblk)(struct dquot___360 *);
	int (*commit_dqblk)(struct dquot___360 *);
	int (*release_dqblk)(struct dquot___360 *);
	int (*get_next_id)(struct super_block___360 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___360 {
	int (*write_dquot)(struct dquot___360 *);
	struct dquot___360 * (*alloc_dquot)(struct super_block___360 *, int);
	void (*destroy_dquot)(struct dquot___360 *);
	int (*acquire_dquot)(struct dquot___360 *);
	int (*release_dquot)(struct dquot___360 *);
	int (*mark_dirty)(struct dquot___360 *);
	int (*write_info)(struct super_block___360 *, int);
	qsize_t * (*get_reserved_space)(struct inode___361 *);
	int (*get_projid)(struct inode___361 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___361 *, qsize_t *);
	int (*get_next_id)(struct super_block___360 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___360 {
	int (*quota_on)(struct super_block___360 *, int, int, const struct path___361 *);
	int (*quota_off)(struct super_block___360 *, int);
	int (*quota_enable)(struct super_block___360 *, unsigned int);
	int (*quota_disable)(struct super_block___360 *, unsigned int);
	int (*quota_sync)(struct super_block___360 *, int);
	int (*set_info)(struct super_block___360 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___360 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___360 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___360 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___360 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___360 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___360 {
	int (*writepage)(struct page___362 *, struct writeback_control___3 *);
	int (*readpage)(struct file___361 *, struct page___362 *);
	int (*writepages)(struct address_space___360 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___362 *);
	int (*readpages)(struct file___361 *, struct address_space___360 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___361 *, struct address_space___360 *, loff_t, unsigned int, unsigned int, struct page___362 **, void **);
	int (*write_end)(struct file___361 *, struct address_space___360 *, loff_t, unsigned int, unsigned int, struct page___362 *, void *);
	sector_t (*bmap)(struct address_space___360 *, sector_t);
	void (*invalidatepage)(struct page___362 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___362 *, gfp_t);
	void (*freepage)(struct page___362 *);
	ssize_t (*direct_IO)(struct kiocb___361 *, struct iov_iter___155 *);
	int (*migratepage)(struct address_space___360 *, struct page___362 *, struct page___362 *, enum migrate_mode);
	bool (*isolate_page)(struct page___362 *, isolate_mode_t);
	void (*putback_page)(struct page___362 *);
	int (*launder_page)(struct page___362 *);
	int (*is_partially_uptodate)(struct page___362 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___362 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___360 *, struct page___362 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___361 *, sector_t *);
	void (*swap_deactivate)(struct file___361 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio_vec___180;

struct iov_iter___155 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___180 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct hd_struct___98;

struct gendisk___98;

struct block_device___360 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___361 *bd_inode;
	struct super_block___360 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___360 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___98 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___98 *bd_disk;
	struct request_queue___94 *bd_queue;
	struct backing_dev_info___178 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___328 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___5 *subsys_data;
	void (*set_latency_tolerance)(struct device___328 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___328;

struct bus_type___328;

struct device_driver___328;

struct dev_pm_domain___328;

struct dma_map_ops___116;

struct fwnode_handle___250;

struct class___328;

struct device___328 {
	struct device___328 *parent;
	struct device_private *p;
	struct kobject___348 kobj;
	const char *init_name;
	const struct device_type___328 *type;
	struct mutex mutex;
	struct bus_type___328 *bus;
	struct device_driver___328 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___328 power;
	struct dev_pm_domain___328 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___116 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___250 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___328 *class;
	const struct attribute_group___325 **groups;
	void (*release)(struct device___328 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___98 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___328 __dev;
	struct kobject___348 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___98;

struct block_device_operations___95;

struct gendisk___98 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___98 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___98 *part_tbl;
	struct hd_struct___98 part0;
	const struct block_device_operations___95 *fops;
	struct request_queue___94 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___362 lookup_sem;
	struct kobject___348 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___348 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___360 {
	struct dentry___360 * (*lookup)(struct inode___361 *, struct dentry___360 *, unsigned int);
	const char * (*get_link)(struct dentry___360 *, struct inode___361 *, struct delayed_call *);
	int (*permission)(struct inode___361 *, int);
	struct posix_acl * (*get_acl)(struct inode___361 *, int);
	int (*readlink)(struct dentry___360 *, char *, int);
	int (*create)(struct inode___361 *, struct dentry___360 *, umode_t, bool);
	int (*link)(struct dentry___360 *, struct inode___361 *, struct dentry___360 *);
	int (*unlink)(struct inode___361 *, struct dentry___360 *);
	int (*symlink)(struct inode___361 *, struct dentry___360 *, const char *);
	int (*mkdir)(struct inode___361 *, struct dentry___360 *, umode_t);
	int (*rmdir)(struct inode___361 *, struct dentry___360 *);
	int (*mknod)(struct inode___361 *, struct dentry___360 *, umode_t, dev_t);
	int (*rename)(struct inode___361 *, struct dentry___360 *, struct inode___361 *, struct dentry___360 *, unsigned int);
	int (*setattr)(struct dentry___360 *, struct iattr___360 *);
	int (*getattr)(const struct path___361 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___360 *, char *, size_t);
	int (*fiemap)(struct inode___361 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___361 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___361 *, struct dentry___360 *, struct file___361 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___361 *, struct dentry___360 *, umode_t);
	int (*set_acl)(struct inode___361 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___360 {
	void (*fl_copy_lock)(struct file_lock___361 *, struct file_lock___361 *);
	void (*fl_release_private)(struct file_lock___361 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___360;

struct lock_manager_operations___360;

struct file_lock___361 {
	struct file_lock___361 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___361 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___360 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___360 *fl_ops;
	const struct lock_manager_operations___360 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___360 {
	int (*lm_compare_owner)(struct file_lock___361 *, struct file_lock___361 *);
	long unsigned int (*lm_owner_key)(struct file_lock___361 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___361 *);
	int (*lm_grant)(struct file_lock___361 *, int);
	bool (*lm_break)(struct file_lock___361 *);
	int (*lm_change)(struct file_lock___361 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___361 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___360 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___360 *fa_next;
	struct file___361 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___360 {
	const char *name;
	int fs_flags;
	struct dentry___360 * (*mount)(struct file_system_type___360 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___360 *);
	struct module___292 *owner;
	struct file_system_type___360 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___360 {
	struct inode___361 * (*alloc_inode)(struct super_block___360 *);
	void (*destroy_inode)(struct inode___361 *);
	void (*dirty_inode)(struct inode___361 *, int);
	int (*write_inode)(struct inode___361 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___361 *);
	void (*evict_inode)(struct inode___361 *);
	void (*put_super)(struct super_block___360 *);
	int (*sync_fs)(struct super_block___360 *, int);
	int (*freeze_super)(struct super_block___360 *);
	int (*freeze_fs)(struct super_block___360 *);
	int (*thaw_super)(struct super_block___360 *);
	int (*unfreeze_fs)(struct super_block___360 *);
	int (*statfs)(struct dentry___360 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___360 *, int *, char *);
	void (*umount_begin)(struct super_block___360 *);
	int (*show_options)(struct seq_file___305 *, struct dentry___360 *);
	int (*show_devname)(struct seq_file___305 *, struct dentry___360 *);
	int (*show_path)(struct seq_file___305 *, struct dentry___360 *);
	int (*show_stats)(struct seq_file___305 *, struct dentry___360 *);
	ssize_t (*quota_read)(struct super_block___360 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___360 *, int, const char *, size_t, loff_t);
	struct dquot___360 ** (*get_dquots)(struct inode___361 *);
	int (*bdev_try_to_free_page)(struct super_block___360 *, struct page___362 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___360 *, struct shrink_control___131 *);
	long int (*free_cached_objects)(struct super_block___360 *, struct shrink_control___131 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___178(struct bio___178 *);

struct bio_vec___180 {
	struct page___362 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___178;

struct bio___178 {
	struct bio___178 *bi_next;
	struct gendisk___98 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___178 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___178 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___180 *bi_io_vec;
	struct bio_set___178 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___180 bi_inline_vecs[0];
};

typedef void compound_page_dtor___349(struct page___362 *);

struct bio_integrity_payload___178 {
	struct bio___178 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___180 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___180 bip_inline_vecs[0];
};

struct dev_pm_ops___328;

struct device_type___328 {
	const char *name;
	const struct attribute_group___325 **groups;
	int (*uevent)(struct device___328 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___328 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___328 *);
	const struct dev_pm_ops___328 *pm;
};

struct class___328 {
	const char *name;
	struct module___292 *owner;
	const struct attribute_group___325 **class_groups;
	const struct attribute_group___325 **dev_groups;
	struct kobject___348 *dev_kobj;
	int (*dev_uevent)(struct device___328 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___328 *, umode_t *);
	void (*class_release)(struct class___328 *);
	void (*dev_release)(struct device___328 *);
	int (*shutdown_pre)(struct device___328 *);
	const struct kobj_ns_type_operations___28 *ns_type;
	const void * (*namespace)(struct device___328 *);
	const struct dev_pm_ops___328 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dev_pm_ops___328 {
	int (*prepare)(struct device___328 *);
	void (*complete)(struct device___328 *);
	int (*suspend)(struct device___328 *);
	int (*resume)(struct device___328 *);
	int (*freeze)(struct device___328 *);
	int (*thaw)(struct device___328 *);
	int (*poweroff)(struct device___328 *);
	int (*restore)(struct device___328 *);
	int (*suspend_late)(struct device___328 *);
	int (*resume_early)(struct device___328 *);
	int (*freeze_late)(struct device___328 *);
	int (*thaw_early)(struct device___328 *);
	int (*poweroff_late)(struct device___328 *);
	int (*restore_early)(struct device___328 *);
	int (*suspend_noirq)(struct device___328 *);
	int (*resume_noirq)(struct device___328 *);
	int (*freeze_noirq)(struct device___328 *);
	int (*thaw_noirq)(struct device___328 *);
	int (*poweroff_noirq)(struct device___328 *);
	int (*restore_noirq)(struct device___328 *);
	int (*runtime_suspend)(struct device___328 *);
	int (*runtime_resume)(struct device___328 *);
	int (*runtime_idle)(struct device___328 *);
};

struct dev_pm_domain___328 {
	struct dev_pm_ops___328 ops;
	void (*detach)(struct device___328 *, bool);
	int (*activate)(struct device___328 *);
	void (*sync)(struct device___328 *);
	void (*dismiss)(struct device___328 *);
};

struct bus_type___328 {
	const char *name;
	const char *dev_name;
	struct device___328 *dev_root;
	const struct attribute_group___325 **bus_groups;
	const struct attribute_group___325 **dev_groups;
	const struct attribute_group___325 **drv_groups;
	int (*match)(struct device___328 *, struct device_driver___328 *);
	int (*uevent)(struct device___328 *, struct kobj_uevent_env *);
	int (*probe)(struct device___328 *);
	int (*remove)(struct device___328 *);
	void (*shutdown)(struct device___328 *);
	int (*online)(struct device___328 *);
	int (*offline)(struct device___328 *);
	int (*suspend)(struct device___328 *, pm_message_t);
	int (*resume)(struct device___328 *);
	int (*num_vf)(struct device___328 *);
	int (*dma_configure)(struct device___328 *);
	const struct dev_pm_ops___328 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___328 {
	const char *name;
	struct bus_type___328 *bus;
	struct module___292 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___328 *);
	int (*remove)(struct device___328 *);
	void (*shutdown)(struct device___328 *);
	int (*suspend)(struct device___328 *, pm_message_t);
	int (*resume)(struct device___328 *);
	const struct attribute_group___325 **groups;
	const struct dev_pm_ops___328 *pm;
	void (*coredump)(struct device___328 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_attribute___40 {
	struct attribute attr;
	ssize_t (*show)(struct device___328 *, struct device_attribute___40 *, char *);
	ssize_t (*store)(struct device___328 *, struct device_attribute___40 *, const char *, size_t);
};

struct dma_map_ops___116 {
	void * (*alloc)(struct device___328 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___328 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___328 *, struct vm_area_struct___362 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___328 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___328 *, struct page___362 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___328 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___328 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___328 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___328 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___328 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___328 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide44;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___328 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___328 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___328 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___328 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___328 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___328 *, u64);
	u64 (*get_required_mask)(struct device___328 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___250;

struct fwnode_handle___250 {
	struct fwnode_handle___250 *secondary;
	const struct fwnode_operations___250 *ops;
};

struct disk_part_tbl___98 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___98 *last_lookup;
	struct hd_struct___98 *part[0];
};

struct pr_ops___2;

struct block_device_operations___95 {
	int (*open)(struct block_device___360 *, fmode_t);
	void (*release)(struct gendisk___98 *, fmode_t);
	int (*rw_page)(struct block_device___360 *, sector_t, struct page___362 *, unsigned int);
	int (*ioctl)(struct block_device___360 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___360 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___98 *, unsigned int);
	int (*media_changed)(struct gendisk___98 *);
	void (*unlock_native_capacity)(struct gendisk___98 *);
	int (*revalidate_disk)(struct gendisk___98 *);
	int (*getgeo)(struct block_device___360 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___360 *, long unsigned int);
	int (*report_zones)(struct gendisk___98 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___292 *owner;
	const struct pr_ops___2 *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bdi_writeback_congested___178 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___178 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bsg_ops___94 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___94 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___94 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___94 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___94(struct request___94 *, blk_status_t);

struct request___94 {
	struct request_queue___94 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___31 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___178 *bio;
	struct bio___178 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___180 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___98 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___94 *saved_end_io;
		} flush;
	};
	struct gendisk___98 *rq_disk;
	struct hd_struct___98 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___94 *end_io;
	void *end_io_data;
	struct request___94 *next_rq;
};

struct fwnode_reference_args___250;

struct fwnode_endpoint___250;

struct fwnode_operations___250 {
	struct fwnode_handle___250 * (*get)(struct fwnode_handle___250 *);
	void (*put)(struct fwnode_handle___250 *);
	bool (*device_is_available)(const struct fwnode_handle___250 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___250 *, const struct device___328 *);
	bool (*property_present)(const struct fwnode_handle___250 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___250 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___250 *, const char *, const char **, size_t);
	struct fwnode_handle___250 * (*get_parent)(const struct fwnode_handle___250 *);
	struct fwnode_handle___250 * (*get_next_child_node)(const struct fwnode_handle___250 *, struct fwnode_handle___250 *);
	struct fwnode_handle___250 * (*get_named_child_node)(const struct fwnode_handle___250 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___250 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___250 *);
	struct fwnode_handle___250 * (*graph_get_next_endpoint)(const struct fwnode_handle___250 *, struct fwnode_handle___250 *);
	struct fwnode_handle___250 * (*graph_get_remote_endpoint)(const struct fwnode_handle___250 *);
	struct fwnode_handle___250 * (*graph_get_port_parent)(struct fwnode_handle___250 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___250 *, struct fwnode_endpoint___250 *);
};

struct fwnode_endpoint___250 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___250 *local_fwnode;
};

struct fwnode_reference_args___250 {
	struct fwnode_handle___250 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct blk_mq_hw_ctx___31 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___94 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags___4 *tags;
	struct blk_mq_tags___4 *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	unsigned int rh_reserved_nr_expired;
	struct hlist_node cpuhp_dead;
	struct kobject___348 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___360 *debugfs_dir;
	struct dentry___360 *sched_debugfs_dir;
	struct list_head hctx_list;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___94;

struct elevator_mq_ops___94 {
	int (*init_sched)(struct request_queue___94 *, struct elevator_type___94 *);
	void (*exit_sched)(struct elevator_queue___94 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___31 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___31 *, unsigned int);
	bool (*allow_merge)(struct request_queue___94 *, struct request___94 *, struct bio___178 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx___31 *, struct bio___178 *);
	int (*request_merge)(struct request_queue___94 *, struct request___94 **, struct bio___178 *);
	void (*request_merged)(struct request_queue___94 *, struct request___94 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___94 *, struct request___94 *, struct request___94 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___94 *, struct bio___178 *);
	void (*finish_request)(struct request___94 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___31 *, struct list_head *, bool);
	struct request___94 * (*dispatch_request)(struct blk_mq_hw_ctx___31 *);
	bool (*has_work)(struct blk_mq_hw_ctx___31 *);
	void (*completed_request)(struct request___94 *, u64);
	void (*started_request)(struct request___94 *);
	void (*requeue_request)(struct request___94 *);
	struct request___94 * (*former_request)(struct request_queue___94 *, struct request___94 *);
	struct request___94 * (*next_request)(struct request_queue___94 *, struct request___94 *);
	void (*init_icq)(struct io_cq___98 *);
	void (*exit_icq)(struct io_cq___98 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx___31 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___94;

struct elevator_type___94 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___94 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___94 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___292 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___94 {
	struct elevator_type___94 *type;
	void *elevator_data;
	struct kobject___348 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___94 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___94 *, char *);
	ssize_t (*store)(struct elevator_queue___94 *, const char *, size_t);
};

struct blk_mq_queue_data___31;

typedef blk_status_t queue_rq_fn___31(struct blk_mq_hw_ctx___31 *, const struct blk_mq_queue_data___31 *);

typedef void commit_rqs_fn___31(struct blk_mq_hw_ctx___31 *);

typedef bool get_budget_fn___31(struct blk_mq_hw_ctx___31 *);

typedef void put_budget_fn___31(struct blk_mq_hw_ctx___31 *);

typedef enum blk_eh_timer_return timeout_fn___31(struct request___94 *, bool);

typedef int poll_fn___31(struct blk_mq_hw_ctx___31 *);

typedef void complete_fn___31(struct request___94 *);

typedef int init_hctx_fn___31(struct blk_mq_hw_ctx___31 *, void *, unsigned int);

typedef void exit_hctx_fn___31(struct blk_mq_hw_ctx___31 *, unsigned int);

typedef int init_request_fn___31(struct blk_mq_tag_set___31 *, struct request___94 *, unsigned int, unsigned int);

typedef void exit_request_fn___31(struct blk_mq_tag_set___31 *, struct request___94 *, unsigned int);

typedef bool busy_fn___31(struct request_queue___94 *);

typedef int map_queues_fn___31(struct blk_mq_tag_set___31 *);

typedef void cleanup_rq_fn___31(struct request___94 *);

struct blk_mq_ops___31 {
	queue_rq_fn___31 *queue_rq;
	commit_rqs_fn___31 *commit_rqs;
	get_budget_fn___31 *get_budget;
	put_budget_fn___31 *put_budget;
	timeout_fn___31 *timeout;
	poll_fn___31 *poll;
	complete_fn___31 *complete;
	init_hctx_fn___31 *init_hctx;
	exit_hctx_fn___31 *exit_hctx;
	init_request_fn___31 *init_request;
	exit_request_fn___31 *exit_request;
	void (*initialize_rq_fn)(struct request___94 *);
	busy_fn___31 *busy;
	map_queues_fn___31 *map_queues;
	void (*show_rq)(struct seq_file___305 *, struct request___94 *);
	union {
		cleanup_rq_fn___31 *cleanup_rq;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide49;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct blk_mq_tag_set___31 {
	struct blk_mq_queue_map map[6];
	unsigned int nr_maps;
	const struct blk_mq_ops___31 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	struct blk_mq_tags___4 **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct pr_ops___2 {
	int (*pr_register)(struct block_device___360 *, u64, u64, u32);
	int (*pr_reserve)(struct block_device___360 *, u64, enum pr_type, u32);
	int (*pr_release)(struct block_device___360 *, u64, enum pr_type);
	int (*pr_preempt)(struct block_device___360 *, u64, u64, enum pr_type, bool);
	int (*pr_clear)(struct block_device___360 *, u64);
};

struct Scsi_Host___7;

struct scsi_target___12;

struct scsi_device___12 {
	struct Scsi_Host___7 *host;
	struct request_queue___94 *request_queue;
	struct list_head siblings;
	struct list_head same_target_siblings;
	atomic_t device_busy;
	atomic_t device_blocked;
	spinlock_t list_lock;
	struct list_head cmd_list;
	struct list_head starved_entry;
	short unsigned int queue_depth;
	short unsigned int max_queue_depth;
	short unsigned int last_queue_full_depth;
	short unsigned int last_queue_full_count;
	long unsigned int last_queue_full_time;
	long unsigned int queue_ramp_up_period;
	long unsigned int last_queue_ramp_up;
	unsigned int id;
	unsigned int channel;
	u64 lun;
	unsigned int manufacturer;
	unsigned int sector_size;
	void *hostdata;
	unsigned char type;
	char scsi_level;
	char inq_periph_qual;
	struct mutex inquiry_mutex;
	unsigned char inquiry_len;
	unsigned char *inquiry;
	const char *vendor;
	const char *model;
	const char *rev;
	struct scsi_vpd *vpd_pg83;
	struct scsi_vpd *vpd_pg80;
	unsigned char current_tag;
	struct scsi_target___12 *sdev_target;
	blist_flags_t sdev_bflags;
	unsigned int eh_timeout;
	unsigned int removable: 1;
	unsigned int changed: 1;
	unsigned int busy: 1;
	unsigned int lockable: 1;
	unsigned int locked: 1;
	unsigned int borken: 1;
	unsigned int disconnect: 1;
	unsigned int soft_reset: 1;
	unsigned int sdtr: 1;
	unsigned int wdtr: 1;
	unsigned int ppr: 1;
	unsigned int tagged_supported: 1;
	unsigned int simple_tags: 1;
	unsigned int was_reset: 1;
	unsigned int expecting_cc_ua: 1;
	unsigned int use_10_for_rw: 1;
	unsigned int use_10_for_ms: 1;
	unsigned int no_report_opcodes: 1;
	unsigned int no_write_same: 1;
	unsigned int use_16_for_rw: 1;
	unsigned int skip_ms_page_8: 1;
	unsigned int skip_ms_page_3f: 1;
	unsigned int skip_vpd_pages: 1;
	unsigned int try_vpd_pages: 1;
	unsigned int use_192_bytes_for_3f: 1;
	unsigned int no_start_on_add: 1;
	unsigned int allow_restart: 1;
	unsigned int manage_start_stop: 1;
	unsigned int start_stop_pwr_cond: 1;
	unsigned int no_uld_attach: 1;
	unsigned int select_no_atn: 1;
	unsigned int fix_capacity: 1;
	unsigned int guess_capacity: 1;
	unsigned int retry_hwerror: 1;
	unsigned int last_sector_bug: 1;
	unsigned int no_read_disc_info: 1;
	unsigned int no_read_capacity_16: 1;
	unsigned int try_rc_10_first: 1;
	unsigned int security_supported: 1;
	unsigned int is_visible: 1;
	unsigned int wce_default_on: 1;
	unsigned int no_dif: 1;
	unsigned int broken_fua: 1;
	unsigned int lun_in_cdb: 1;
	unsigned int unmap_limit_for_ws: 1;
	atomic_t disk_events_disable_depth;
	long unsigned int supported_events[1];
	long unsigned int pending_events[1];
	struct list_head event_list;
	struct work_struct event_work;
	unsigned int max_device_blocked;
	atomic_t iorequest_cnt;
	atomic_t iodone_cnt;
	atomic_t ioerr_cnt;
	struct device___328 sdev_gendev;
	struct device___328 sdev_dev;
	struct execute_work ew;
	struct work_struct requeue_work;
	struct scsi_device_handler *handler;
	void *handler_data;
	unsigned char access_state;
	struct mutex state_mutex;
	enum scsi_device_state sdev_state;
	struct task_struct___362 *quiesced_by;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int sdev_data[0];
};

struct scsi_host_template___7;

struct Scsi_Host___7 {
	struct list_head __devices;
	struct list_head __targets;
	struct list_head starved_list;
	spinlock_t default_lock;
	spinlock_t *host_lock;
	struct mutex scan_mutex;
	struct list_head eh_cmd_q;
	struct task_struct___362 *ehandler;
	struct completion *eh_action;
	wait_queue_head_t host_wait;
	struct scsi_host_template___7 *hostt;
	struct scsi_transport_template *transportt;
	struct blk_mq_tag_set___31 tag_set;
	atomic_t host_busy;
	atomic_t host_blocked;
	unsigned int host_failed;
	unsigned int host_eh_scheduled;
	unsigned int host_no;
	int eh_deadline;
	long unsigned int last_reset;
	unsigned int max_channel;
	unsigned int max_id;
	u64 max_lun;
	unsigned int unique_id;
	short unsigned int max_cmd_len;
	int this_id;
	int can_queue;
	short int cmd_per_lun;
	short unsigned int sg_tablesize;
	short unsigned int sg_prot_tablesize;
	unsigned int max_sectors;
	long unsigned int dma_boundary;
	unsigned int nr_hw_queues;
	long unsigned int cmd_serial_number;
	unsigned int active_mode: 2;
	unsigned int unchecked_isa_dma: 1;
	unsigned int use_clustering: 1;
	unsigned int host_self_blocked: 1;
	unsigned int reverse_ordering: 1;
	unsigned int tmf_in_progress: 1;
	unsigned int async_scan: 1;
	unsigned int eh_noresume: 1;
	unsigned int no_write_same: 1;
	unsigned int use_cmd_list: 1;
	unsigned int short_inquiry: 1;
	char work_q_name[20];
	struct workqueue_struct *work_q;
	struct workqueue_struct *tmf_work_q;
	unsigned int no_scsi2_lun_in_cdb: 1;
	unsigned int max_host_blocked;
	unsigned int prot_capabilities;
	unsigned char prot_guard_type;
	long unsigned int base;
	long unsigned int io_port;
	unsigned char n_io_port;
	unsigned char dma_channel;
	unsigned int irq;
	enum scsi_host_state shost_state;
	struct device___328 shost_gendev;
	struct device___328 shost_dev;
	void *shost_data;
	struct device___328 *dma_dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int hostdata[0];
};

struct scsi_target___12 {
	struct scsi_device___12 *starget_sdev_user;
	struct list_head siblings;
	struct list_head devices;
	struct device___328 dev;
	struct kref reap_ref;
	unsigned int channel;
	unsigned int id;
	unsigned int create: 1;
	unsigned int single_lun: 1;
	unsigned int pdt_1f_for_no_lun: 1;
	unsigned int no_report_luns: 1;
	unsigned int expecting_lun_change: 1;
	atomic_t target_busy;
	atomic_t target_blocked;
	unsigned int can_queue;
	unsigned int max_target_blocked;
	char scsi_level;
	enum scsi_target_state state;
	void *hostdata;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int starget_data[0];
};

struct blk_mq_queue_data___31 {
	struct request___94 *rq;
	bool last;
	long unsigned int rh_reserved1;
};

struct scsi_cmnd___7 {
	struct scsi_request req;
	struct scsi_device___12 *device;
	struct list_head list;
	struct list_head eh_entry;
	struct delayed_work abort_work;
	struct callback_head rcu;
	int eh_eflags;
	long unsigned int serial_number;
	long unsigned int jiffies_at_alloc;
	int retries;
	int allowed;
	unsigned char prot_op;
	unsigned char prot_type;
	unsigned char prot_flags;
	short unsigned int cmd_len;
	enum dma_data_direction sc_data_direction;
	unsigned char *cmnd;
	struct scsi_data_buffer sdb;
	struct scsi_data_buffer *prot_sdb;
	unsigned int underflow;
	unsigned int transfersize;
	struct request___94 *request;
	unsigned char *sense_buffer;
	void (*scsi_done)(struct scsi_cmnd___7 *);
	struct scsi_pointer SCp;
	unsigned char *host_scribble;
	int result;
	int flags;
	long unsigned int state;
	unsigned char tag;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

enum scsi_prot_flags {
	SCSI_PROT_TRANSFER_PI = 1,
	SCSI_PROT_GUARD_CHECK = 2,
	SCSI_PROT_REF_CHECK = 4,
	SCSI_PROT_REF_INCREMENT = 8,
	SCSI_PROT_IP_CHECKSUM = 16,
};

struct scsi_driver___3 {
	struct device_driver___328 gendrv;
	void (*rescan)(struct device___328 *);
	blk_status_t (*init_command)(struct scsi_cmnd___7 *);
	void (*uninit_command)(struct scsi_cmnd___7 *);
	int (*done)(struct scsi_cmnd___7 *);
	int (*eh_action)(struct scsi_cmnd___7 *, int);
	void (*eh_reset)(struct scsi_cmnd___7 *);
};

typedef int (*key_restrict_link_func_t___333)(struct key___332 *, const struct key_type *, const union key_payload *, struct key___332 *);

struct key_restriction___332;

struct key___332 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___362 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___332 *restrict_link;
};

struct key_restriction___332 {
	key_restrict_link_func_t___333 check;
	struct key___332 *key;
	struct key_type *keytype;
};

struct seq_operations___304 {
	void * (*start)(struct seq_file___305 *, loff_t *);
	void (*stop)(struct seq_file___305 *, void *);
	void * (*next)(struct seq_file___305 *, void *, loff_t *);
	int (*show)(struct seq_file___305 *, void *);
};

struct scsi_host_template___7 {
	struct module___292 *module;
	const char *name;
	const char * (*info)(struct Scsi_Host___7 *);
	int (*ioctl)(struct scsi_device___12 *, int, void *);
	int (*queuecommand)(struct Scsi_Host___7 *, struct scsi_cmnd___7 *);
	int (*eh_abort_handler)(struct scsi_cmnd___7 *);
	int (*eh_device_reset_handler)(struct scsi_cmnd___7 *);
	int (*eh_target_reset_handler)(struct scsi_cmnd___7 *);
	int (*eh_bus_reset_handler)(struct scsi_cmnd___7 *);
	int (*eh_host_reset_handler)(struct scsi_cmnd___7 *);
	int (*slave_alloc)(struct scsi_device___12 *);
	int (*slave_configure)(struct scsi_device___12 *);
	void (*slave_destroy)(struct scsi_device___12 *);
	int (*target_alloc)(struct scsi_target___12 *);
	void (*target_destroy)(struct scsi_target___12 *);
	int (*scan_finished)(struct Scsi_Host___7 *, long unsigned int);
	void (*scan_start)(struct Scsi_Host___7 *);
	int (*change_queue_depth)(struct scsi_device___12 *, int);
	int (*map_queues)(struct Scsi_Host___7 *);
	int (*bios_param)(struct scsi_device___12 *, struct block_device___360 *, sector_t, int *);
	void (*unlock_native_capacity)(struct scsi_device___12 *);
	int (*show_info)(struct seq_file___305 *, struct Scsi_Host___7 *);
	int (*write_info)(struct Scsi_Host___7 *, char *, int);
	enum blk_eh_timer_return (*eh_timed_out)(struct scsi_cmnd___7 *);
	int (*host_reset)(struct Scsi_Host___7 *, int);
	const char *proc_name;
	struct proc_dir_entry *proc_dir;
	int can_queue;
	int this_id;
	short unsigned int sg_tablesize;
	short unsigned int sg_prot_tablesize;
	unsigned int max_sectors;
	long unsigned int dma_boundary;
	short int cmd_per_lun;
	unsigned char present;
	int tag_alloc_policy;
	unsigned int track_queue_depth: 1;
	unsigned int supported_mode: 2;
	unsigned int unchecked_isa_dma: 1;
	unsigned int use_clustering: 1;
	unsigned int emulated: 1;
	unsigned int skip_settle_delay: 1;
	unsigned int no_write_same: 1;
	unsigned int force_blk_mq: 1;
	unsigned int max_host_blocked;
	struct device_attribute___40 **shost_attrs;
	struct device_attribute___40 **sdev_attrs;
	const struct attribute_group___325 **sdev_groups;
	u64 vendor_id;
	unsigned int cmd_size;
	struct scsi_host_cmd_pool *cmd_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

enum {
	SD_EXT_CDB_SIZE = 32,
	SD_MEMPOOL_SIZE = 2,
};

enum {
	SD_DEF_XFER_BLOCKS = 65535,
	SD_MAX_XFER_BLOCKS = 4294967295,
	SD_MAX_WS10_BLOCKS = 65535,
	SD_MAX_WS16_BLOCKS = 8388607,
};

enum {
	SD_LBP_FULL = 0,
	SD_LBP_UNMAP = 1,
	SD_LBP_WS16 = 2,
	SD_LBP_WS10 = 3,
	SD_LBP_ZERO = 4,
	SD_LBP_DISABLE = 5,
};

enum {
	SD_ZERO_WRITE = 0,
	SD_ZERO_WS = 1,
	SD_ZERO_WS16_UNMAP = 2,
	SD_ZERO_WS10_UNMAP = 3,
};

struct opal_dev;

struct scsi_disk {
	struct scsi_driver___3 *driver;
	struct scsi_device___12 *device;
	struct device___328 dev;
	struct gendisk___98 *disk;
	struct opal_dev *opal_dev;
	u32 nr_zones;
	u32 zone_blocks;
	u32 zones_optimal_open;
	u32 zones_optimal_nonseq;
	u32 zones_max_open;
	atomic_t openers;
	sector_t capacity;
	u32 max_xfer_blocks;
	u32 opt_xfer_blocks;
	u32 max_ws_blocks;
	u32 max_unmap_blocks;
	u32 unmap_granularity;
	u32 unmap_alignment;
	u32 index;
	unsigned int physical_block_size;
	unsigned int max_medium_access_timeouts;
	unsigned int medium_access_timed_out;
	u8 media_present;
	u8 write_prot;
	u8 protection_type;
	u8 provisioning_mode;
	u8 zeroing_mode;
	unsigned int ATO: 1;
	unsigned int cache_override: 1;
	unsigned int WCE: 1;
	unsigned int RCD: 1;
	unsigned int DPOFUA: 1;
	unsigned int first_scan: 1;
	unsigned int lbpme: 1;
	unsigned int lbprz: 1;
	unsigned int lbpu: 1;
	unsigned int lbpws: 1;
	unsigned int lbpws10: 1;
	unsigned int lbpvpd: 1;
	unsigned int ws10: 1;
	unsigned int ws16: 1;
	unsigned int rc_basis: 2;
	unsigned int zoned: 2;
	unsigned int urswrz: 1;
	unsigned int security: 1;
	unsigned int ignore_medium_access_errors: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct scsi_driver___4 {
	struct device_driver___319 gendrv;
	void (*rescan)(struct device___319 *);
	blk_status_t (*init_command)(struct scsi_cmnd___4 *);
	void (*uninit_command)(struct scsi_cmnd___4 *);
	int (*done)(struct scsi_cmnd___4 *);
	int (*eh_action)(struct scsi_cmnd___4 *, int);
	void (*eh_reset)(struct scsi_cmnd___4 *);
};

enum scsi_host_guard_type {
	SHOST_DIX_GUARD_CRC = 1,
	SHOST_DIX_GUARD_IP = 2,
};

struct scsi_disk___2 {
	struct scsi_driver___4 *driver;
	struct scsi_device___4 *device;
	struct device___319 dev;
	struct gendisk___89 *disk;
	struct opal_dev *opal_dev;
	u32 nr_zones;
	u32 zone_blocks;
	u32 zones_optimal_open;
	u32 zones_optimal_nonseq;
	u32 zones_max_open;
	atomic_t openers;
	sector_t capacity;
	u32 max_xfer_blocks;
	u32 opt_xfer_blocks;
	u32 max_ws_blocks;
	u32 max_unmap_blocks;
	u32 unmap_granularity;
	u32 unmap_alignment;
	u32 index;
	unsigned int physical_block_size;
	unsigned int max_medium_access_timeouts;
	unsigned int medium_access_timed_out;
	u8 media_present;
	u8 write_prot;
	u8 protection_type;
	u8 provisioning_mode;
	u8 zeroing_mode;
	unsigned int ATO: 1;
	unsigned int cache_override: 1;
	unsigned int WCE: 1;
	unsigned int RCD: 1;
	unsigned int DPOFUA: 1;
	unsigned int first_scan: 1;
	unsigned int lbpme: 1;
	unsigned int lbprz: 1;
	unsigned int lbpu: 1;
	unsigned int lbpws: 1;
	unsigned int lbpws10: 1;
	unsigned int lbpvpd: 1;
	unsigned int ws10: 1;
	unsigned int ws16: 1;
	unsigned int rc_basis: 2;
	unsigned int zoned: 2;
	unsigned int urswrz: 1;
	unsigned int security: 1;
	unsigned int ignore_medium_access_errors: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct module___293;

struct file___362;

struct kiocb___362;

struct iov_iter___156;

struct poll_table_struct___215;

struct vm_area_struct___363;

struct inode___362;

struct file_lock___362;

struct page___363;

struct seq_file___306;

struct file_operations___362 {
	struct module___293 *owner;
	loff_t (*llseek)(struct file___362 *, loff_t, int);
	ssize_t (*read)(struct file___362 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___362 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___362 *, struct iov_iter___156 *);
	ssize_t (*write_iter)(struct kiocb___362 *, struct iov_iter___156 *);
	int (*iopoll)(struct kiocb___362 *, bool);
	int (*iterate)(struct file___362 *, struct dir_context *);
	int (*iterate_shared)(struct file___362 *, struct dir_context *);
	__poll_t (*poll)(struct file___362 *, struct poll_table_struct___215 *);
	long int (*unlocked_ioctl)(struct file___362 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___362 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___362 *, struct vm_area_struct___363 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___362 *, struct file___362 *);
	int (*flush)(struct file___362 *, fl_owner_t);
	int (*release)(struct inode___362 *, struct file___362 *);
	int (*fsync)(struct file___362 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___362 *, int);
	int (*lock)(struct file___362 *, int, struct file_lock___362 *);
	ssize_t (*sendpage)(struct file___362 *, struct page___363 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___362 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___362 *, int, struct file_lock___362 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___362 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___362 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___362 *, long int, struct file_lock___362 **, void **);
	long int (*fallocate)(struct file___362 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___306 *, struct file___362 *);
	ssize_t (*copy_file_range)(struct file___362 *, loff_t, struct file___362 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___362 *, loff_t, struct file___362 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___362 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___362 {
	u64 seqnum;
	struct vm_area_struct___363 *vmas[4];
};

struct page_frag___362 {
	struct page___363 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___141;

struct debug_info___141 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___141 *hbp_break[16];
	struct perf_event___141 *hbp_watch[16];
};

struct thread_struct___141 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___141 debug;
	long: 64;
};

struct mm_struct___362;

struct mem_cgroup___132;

struct pid___217;

struct cred___333;

struct nsproxy___275;

struct signal_struct___255;

struct bio_list___179;

struct backing_dev_info___179;

struct io_context___99;

struct css_set___230;

struct perf_event_context___141;

struct request_queue___95;

struct vm_struct___268;

struct task_struct___363 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___363 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___362 *mm;
	struct mm_struct___362 *active_mm;
	struct vmacache___362 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___363 *real_parent;
	struct task_struct___363 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___363 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___132 *active_memcg;
	long int rh_reserved2;
	struct pid___217 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___217 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___217 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___333 *ptracer_cred;
	const struct cred___333 *real_cred;
	const struct cred___333 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___275 *nsproxy;
	struct signal_struct___255 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___363 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___179 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___179 *backing_dev_info;
	struct io_context___99 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___230 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___141 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___362 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___132 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___95 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___363 *oom_reaper_list;
	struct vm_struct___268 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___141 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___141 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___363 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___141)(struct perf_event___141 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___141;

struct fasync_struct___361;

struct pid_namespace___217;

struct trace_event_call___134;

struct perf_cgroup___141;

struct perf_event___141 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___141 *group_leader;
	struct pmu___141 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___141 hw;
	struct perf_event_context___141 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___141 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___363 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___361 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___141 *);
	struct callback_head callback_head;
	struct pid_namespace___217 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___141 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___141 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___134 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___141 *cgrp;
	struct list_head sb_list;
};

struct rw_semaphore___363 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___363 *owner;
};

struct key___333;

struct ucounts___245;

struct user_namespace___245 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___245 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___9 ns;
	long unsigned int flags;
	struct key___333 *persistent_keyring_register;
	struct rw_semaphore___363 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___245 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___363 *pgtable_t___362;

struct address_space___361;

struct dev_pagemap___350;

struct page___363 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___361 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___363 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___362 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___362 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___350 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___132 *mem_cgroup;
};

struct pglist_data___362;

struct lruvec___362 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___362 *pgdat;
};

struct zone___362 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___362 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___362 {
	struct zone___362 *zone;
	int zone_idx;
};

struct zonelist___362 {
	struct zoneref___362 _zonerefs[25];
};

struct pglist_data___362 {
	struct zone___362 node_zones[3];
	struct zonelist___362 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___363 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___363 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___362 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___363 {
	void *stack;
	struct task_struct___363 *task;
	long int status;
};

struct blocking_notifier_head___362 {
	struct rw_semaphore___363 rwsem;
	struct notifier_block *head;
};

struct dentry___361;

struct path___362 {
	struct vfsmount *mnt;
	struct dentry___361 *dentry;
};

struct fown_struct___217 {
	rwlock_t lock;
	struct pid___217 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___362 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___362 f_path;
	struct inode___362 *f_inode;
	const struct file_operations___362 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___217 f_owner;
	const struct cred___333 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___361 *f_mapping;
	errseq_t f_wb_err;
};

struct user_struct___333;

struct cred___333 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___333 *session_keyring;
	struct key___333 *process_keyring;
	struct key___333 *thread_keyring;
	struct key___333 *request_key_auth;
	void *security;
	struct user_struct___333 *user;
	struct user_namespace___245 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___355;

struct kernfs_elem_dir___355 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___355 *root;
};

struct kernfs_node___356;

struct kernfs_syscall_ops___355;

struct kernfs_root___355 {
	struct kernfs_node___356 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___355 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___355 {
	struct kernfs_node___356 *target_kn;
};

struct kernfs_ops___355;

struct kernfs_elem_attr___355 {
	const struct kernfs_ops___355 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___356 *notify_next;
};

struct kernfs_node___356 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___356 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___355 dir;
		struct kernfs_elem_symlink___355 symlink;
		struct kernfs_elem_attr___355 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___355;

struct kernfs_ops___355 {
	int (*open)(struct kernfs_open_file___355 *);
	void (*release)(struct kernfs_open_file___355 *);
	int (*seq_show)(struct seq_file___306 *, void *);
	void * (*seq_start)(struct seq_file___306 *, loff_t *);
	void * (*seq_next)(struct seq_file___306 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___306 *, void *);
	ssize_t (*read)(struct kernfs_open_file___355 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___355 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___355 *, struct vm_area_struct___363 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___355 *, struct poll_table_struct___215 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___355 {
	int (*remount_fs)(struct kernfs_root___355 *, int *, char *);
	int (*show_options)(struct seq_file___306 *, struct kernfs_root___355 *);
	int (*mkdir)(struct kernfs_node___356 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___356 *);
	int (*rename)(struct kernfs_node___356 *, struct kernfs_node___356 *, const char *);
	int (*show_path)(struct seq_file___306 *, struct kernfs_node___356 *, struct kernfs_root___355 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___305;

struct seq_file___306 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___305 *op;
	int poll_event;
	const struct file___362 *file;
	void *private;
};

struct vm_operations_struct___350;

struct kernfs_open_file___355 {
	struct kernfs_node___356 *kn;
	struct file___362 *file;
	struct seq_file___306 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___350 *vm_ops;
};

struct vm_fault___350;

struct vm_operations_struct___350 {
	void (*open)(struct vm_area_struct___363 *);
	void (*close)(struct vm_area_struct___363 *);
	int (*split)(struct vm_area_struct___363 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___363 *);
	vm_fault_t (*fault)(struct vm_fault___350 *);
	vm_fault_t (*huge_fault)(struct vm_fault___350 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___350 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___363 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___350 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___350 *);
	int (*access)(struct vm_area_struct___363 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___363 *);
	int (*set_policy)(struct vm_area_struct___363 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___363 *, long unsigned int);
	struct page___363 * (*find_special_page)(struct vm_area_struct___363 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___221)(struct file___362 *, wait_queue_head_t *, struct poll_table_struct___215 *);

struct poll_table_struct___215 {
	poll_queue_proc___221 _qproc;
	__poll_t _key;
};

struct vm_area_struct___363 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___363 *vm_next;
	struct vm_area_struct___363 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___362 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___350 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___362 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___349;

struct bin_attribute___325;

struct attribute_group___326 {
	const char *name;
	umode_t (*is_visible)(struct kobject___349 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___349 *, struct bin_attribute___325 *, int);
	struct attribute **attrs;
	struct bin_attribute___325 **bin_attrs;
};

struct kset___348;

struct kobj_type___348;

struct kobject___349 {
	const char *name;
	struct list_head entry;
	struct kobject___349 *parent;
	struct kset___348 *kset;
	struct kobj_type___348 *ktype;
	struct kernfs_node___356 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___325 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___362 *, struct kobject___349 *, struct bin_attribute___325 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___362 *, struct kobject___349 *, struct bin_attribute___325 *, char *, loff_t, size_t);
	int (*mmap)(struct file___362 *, struct kobject___349 *, struct bin_attribute___325 *, struct vm_area_struct___363 *);
};

struct sysfs_ops___348 {
	ssize_t (*show)(struct kobject___349 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___349 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___348;

struct kset___348 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___349 kobj;
	const struct kset_uevent_ops___348 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___348 {
	void (*release)(struct kobject___349 *);
	const struct sysfs_ops___348 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___28 * (*child_ns_type)(struct kobject___349 *);
	const void * (*namespace)(struct kobject___349 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___348 {
	int (* const filter)(struct kset___348 *, struct kobject___349 *);
	const char * (* const name)(struct kset___348 *, struct kobject___349 *);
	int (* const uevent)(struct kset___348 *, struct kobject___349 *, struct kobj_uevent_env *);
};

struct kobj_attribute___340 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___349 *, struct kobj_attribute___340 *, char *);
	ssize_t (*store)(struct kobject___349 *, struct kobj_attribute___340 *, const char *, size_t);
};

struct kernel_param___290;

struct kernel_param_ops___290 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___290 *);
	int (*get)(char *, const struct kernel_param___290 *);
	void (*free)(void *);
};

struct kparam_array___290;

struct kernel_param___290 {
	const char *name;
	struct module___293 *mod;
	const struct kernel_param_ops___290 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___290 *arr;
	};
};

struct kparam_array___290 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___290 *ops;
	void *elem;
};

struct module_kobject___290 {
	struct kobject___349 kobj;
	struct module___293 *mod;
	struct kobject___349 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___290 {
	struct module___293 *mod;
	struct latch_tree_node node;
};

struct module_layout___290 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___290 mtn;
};

struct module_attribute___290;

struct module___293 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___290 mkobj;
	struct module_attribute___290 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___349 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___290 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___290 core_layout;
	struct module_layout___290 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___134 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___290 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___290 *, struct module_kobject___290 *, char *);
	ssize_t (*store)(struct module_attribute___290 *, struct module_kobject___290 *, const char *, size_t);
	void (*setup)(struct module___293 *, const char *);
	int (*test)(struct module___293 *);
	void (*free)(struct module___293 *);
};

struct module_version_attribute___9 {
	struct module_attribute___290 mattr;
	const char *module_name;
	const char *version;
};

struct trace_event_class___134;

struct trace_event_call___134 {
	struct list_head list;
	struct trace_event_class___134 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___13 event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___38 *prog_array;
	int (*perf_perm)(struct trace_event_call___134 *, struct perf_event___141 *);
};

struct device___329;

struct dev_pm_ops___329 {
	int (*prepare)(struct device___329 *);
	void (*complete)(struct device___329 *);
	int (*suspend)(struct device___329 *);
	int (*resume)(struct device___329 *);
	int (*freeze)(struct device___329 *);
	int (*thaw)(struct device___329 *);
	int (*poweroff)(struct device___329 *);
	int (*restore)(struct device___329 *);
	int (*suspend_late)(struct device___329 *);
	int (*resume_early)(struct device___329 *);
	int (*freeze_late)(struct device___329 *);
	int (*thaw_early)(struct device___329 *);
	int (*poweroff_late)(struct device___329 *);
	int (*restore_early)(struct device___329 *);
	int (*suspend_noirq)(struct device___329 *);
	int (*resume_noirq)(struct device___329 *);
	int (*freeze_noirq)(struct device___329 *);
	int (*thaw_noirq)(struct device___329 *);
	int (*poweroff_noirq)(struct device___329 *);
	int (*restore_noirq)(struct device___329 *);
	int (*runtime_suspend)(struct device___329 *);
	int (*runtime_resume)(struct device___329 *);
	int (*runtime_idle)(struct device___329 *);
};

struct dev_pm_info___329 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___5 *subsys_data;
	void (*set_latency_tolerance)(struct device___329 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___329;

struct bus_type___329;

struct device_driver___329;

struct dev_pm_domain___329;

struct dma_map_ops___117;

struct fwnode_handle___251;

struct class___329;

struct device___329 {
	struct device___329 *parent;
	struct device_private *p;
	struct kobject___349 kobj;
	const char *init_name;
	const struct device_type___329 *type;
	struct mutex mutex;
	struct bus_type___329 *bus;
	struct device_driver___329 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___329 power;
	struct dev_pm_domain___329 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___117 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___251 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___329 *class;
	const struct attribute_group___326 **groups;
	void (*release)(struct device___329 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___329 {
	struct dev_pm_ops___329 ops;
	void (*detach)(struct device___329 *, bool);
	int (*activate)(struct device___329 *);
	void (*sync)(struct device___329 *);
	void (*dismiss)(struct device___329 *);
};

struct upid___217 {
	int nr;
	struct pid_namespace___217 *ns;
};

struct pid_namespace___217 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___363 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___217 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___361 *proc_self;
	struct dentry___361 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___245 *user_ns;
	struct ucounts___245 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___9 ns;
};

struct pid___217 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___217 numbers[1];
};

struct user_struct___333 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___333 *uid_keyring;
	struct key___333 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___362;

struct mm_struct___362 {
	struct {
		struct vm_area_struct___363 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___362 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___363 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___362 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___363 *owner;
		struct user_namespace___245 *user_ns;
		struct file___362 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___362 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup___230;

struct cgroup_subsys___230;

struct cgroup_subsys_state___230 {
	struct cgroup___230 *cgroup;
	struct cgroup_subsys___230 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___230 *parent;
};

struct cgroup_file___230 {
	struct kernfs_node___356 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___132;

struct mem_cgroup___132 {
	struct cgroup_subsys_state___230 css;
	struct mem_cgroup_id___23 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___230 events_file;
	struct cgroup_file___230 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___363 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___132 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cgroup_namespace___230;

struct nsproxy___275 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___217 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___230 *cgroup_ns;
};

struct signal_struct___255 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___363 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___363 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___217 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___217 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___362 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___217 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide53;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___179;

struct bio_list___179 {
	struct bio___179 *head;
	struct bio___179 *tail;
};

struct bdi_writeback_congested___179;

struct bdi_writeback___179 {
	struct backing_dev_info___179 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___179 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___230 *memcg_css;
	struct cgroup_subsys_state___230 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___179 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___179 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___329 *dev;
	struct device___329 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___361 *debug_dir;
	struct dentry___361 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___99;

struct io_context___99 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___99 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___230 {
	struct cgroup_subsys_state___230 *subsys[13];
	refcount_t refcount;
	struct css_set___230 *dom_cset;
	struct cgroup___230 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___230 *mg_src_cgrp;
	struct cgroup___230 *mg_dst_cgrp;
	struct css_set___230 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___141 {
	struct pmu___141 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___363 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___141 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

typedef blk_qc_t make_request_fn___95(struct request_queue___95 *, struct bio___179 *);

struct request___95;

typedef int dma_drain_needed_fn___95(struct request___95 *);

struct bsg_ops___95;

struct bsg_class_device___95 {
	struct device___329 *class_dev;
	int minor;
	struct request_queue___95 *queue;
	const struct bsg_ops___95 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___179 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___179 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___95;

struct blk_mq_ops___32;

struct blk_mq_hw_ctx___32;

struct blk_mq_tag_set___32;

struct request_queue___95 {
	struct list_head queue_head;
	struct request___95 *last_merge;
	struct elevator_queue___95 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___95 *make_request_fn;
	dma_drain_needed_fn___95 *dma_drain_needed;
	const struct blk_mq_ops___32 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___32 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___179 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___349 kobj;
	struct kobject___349 *mq_kobj;
	struct blk_integrity integrity;
	struct device___329 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	struct bsg_class_device___95 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set___32 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___179 bio_split;
	struct dentry___361 *debugfs_dir;
	struct dentry___361 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___268 {
	struct vm_struct___268 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___363 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___267 {
	struct task_struct___363 task;
	long unsigned int stack[8192];
};

struct bus_type___329 {
	const char *name;
	const char *dev_name;
	struct device___329 *dev_root;
	const struct attribute_group___326 **bus_groups;
	const struct attribute_group___326 **dev_groups;
	const struct attribute_group___326 **drv_groups;
	int (*match)(struct device___329 *, struct device_driver___329 *);
	int (*uevent)(struct device___329 *, struct kobj_uevent_env *);
	int (*probe)(struct device___329 *);
	int (*remove)(struct device___329 *);
	void (*shutdown)(struct device___329 *);
	int (*online)(struct device___329 *);
	int (*offline)(struct device___329 *);
	int (*suspend)(struct device___329 *, pm_message_t);
	int (*resume)(struct device___329 *);
	int (*num_vf)(struct device___329 *);
	int (*dma_configure)(struct device___329 *);
	const struct dev_pm_ops___329 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___329 {
	const char *name;
	struct bus_type___329 *bus;
	struct module___293 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___329 *);
	int (*remove)(struct device___329 *);
	void (*shutdown)(struct device___329 *);
	int (*suspend)(struct device___329 *, pm_message_t);
	int (*resume)(struct device___329 *);
	const struct attribute_group___326 **groups;
	const struct dev_pm_ops___329 *pm;
	void (*coredump)(struct device___329 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___329 {
	const char *name;
	const struct attribute_group___326 **groups;
	int (*uevent)(struct device___329 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___329 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___329 *);
	const struct dev_pm_ops___329 *pm;
};

struct class___329 {
	const char *name;
	struct module___293 *owner;
	const struct attribute_group___326 **class_groups;
	const struct attribute_group___326 **dev_groups;
	struct kobject___349 *dev_kobj;
	int (*dev_uevent)(struct device___329 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___329 *, umode_t *);
	void (*class_release)(struct class___329 *);
	void (*dev_release)(struct device___329 *);
	int (*shutdown_pre)(struct device___329 *);
	const struct kobj_ns_type_operations___28 *ns_type;
	const void * (*namespace)(struct device___329 *);
	const struct dev_pm_ops___329 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct device_attribute___41 {
	struct attribute attr;
	ssize_t (*show)(struct device___329 *, struct device_attribute___41 *, char *);
	ssize_t (*store)(struct device___329 *, struct device_attribute___41 *, const char *, size_t);
};

typedef void (*dr_release_t___21)(struct device___329 *, void *);

struct dma_map_ops___117 {
	void * (*alloc)(struct device___329 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___329 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___329 *, struct vm_area_struct___363 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___329 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___329 *, struct page___363 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___329 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___329 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___329 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___329 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___329 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___329 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___329 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___329 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___329 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___329 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___329 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___329 *, u64);
	u64 (*get_required_mask)(struct device___329 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___251;

struct fwnode_handle___251 {
	struct fwnode_handle___251 *secondary;
	const struct fwnode_operations___251 *ops;
};

struct address_space_operations___361;

struct address_space___361 {
	struct inode___362 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___363 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___361 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___350)(struct vm_area_struct___363 *, long unsigned int, const struct page___363 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___350)(struct page___363 *, void *);

struct dev_pagemap___350 {
	dev_page_fault_t___350 page_fault;
	dev_page_free_t___350 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___329 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___362 {
	struct task_struct___363 *task;
	struct core_thread___362 *next;
};

struct core_state___362 {
	atomic_t nr_threads;
	struct core_thread___362 dumper;
	struct completion startup;
};

struct vm_fault___350 {
	struct vm_area_struct___363 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___363 *cow_page;
	struct mem_cgroup___132 *memcg;
	struct page___363 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___362 prealloc_pte;
};

struct fwnode_reference_args___251;

struct fwnode_endpoint___251;

struct fwnode_operations___251 {
	struct fwnode_handle___251 * (*get)(struct fwnode_handle___251 *);
	void (*put)(struct fwnode_handle___251 *);
	bool (*device_is_available)(const struct fwnode_handle___251 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___251 *, const struct device___329 *);
	bool (*property_present)(const struct fwnode_handle___251 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___251 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___251 *, const char *, const char **, size_t);
	struct fwnode_handle___251 * (*get_parent)(const struct fwnode_handle___251 *);
	struct fwnode_handle___251 * (*get_next_child_node)(const struct fwnode_handle___251 *, struct fwnode_handle___251 *);
	struct fwnode_handle___251 * (*get_named_child_node)(const struct fwnode_handle___251 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___251 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___251 *);
	struct fwnode_handle___251 * (*graph_get_next_endpoint)(const struct fwnode_handle___251 *, struct fwnode_handle___251 *);
	struct fwnode_handle___251 * (*graph_get_remote_endpoint)(const struct fwnode_handle___251 *);
	struct fwnode_handle___251 * (*graph_get_port_parent)(struct fwnode_handle___251 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___251 *, struct fwnode_endpoint___251 *);
};

struct fwnode_endpoint___251 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___251 *local_fwnode;
};

struct fwnode_reference_args___251 {
	struct fwnode_handle___251 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pci_bus___30;

struct pci_slot___30 {
	struct pci_bus___30 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject___349 kobj;
};

struct pci_dev___30;

struct pci_ops___30;

struct pci_bus___30 {
	struct list_head node;
	struct pci_bus___30 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___30 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___30 *ops;
	struct msi_controller___2 *msi;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	int domain_nr;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___329 *bridge;
	struct device___329 dev;
	struct bin_attribute___325 *legacy_io;
	struct bin_attribute___325 *legacy_mem;
	unsigned int is_added: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
};

struct pci_driver___30;

struct pci_dev___30 {
	struct list_head bus_list;
	struct pci_bus___30 *bus;
	struct pci_bus___30 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___30 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u16 aer_cap;
	struct aer_stats *aer_stats;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	long unsigned int *dma_alias_mask;
	struct pci_driver___30 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	unsigned int imm_ready: 1;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int bridge_d3: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int hotplug_user_indicators: 1;
	unsigned int clear_retrain_link: 1;
	unsigned int d3_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	unsigned int ltr_path: 1;
	unsigned int eetlp_prefix_path: 1;
	pci_channel_state_t error_state;
	struct device___329 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int multifunction: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int ats_enabled: 1;
	unsigned int pasid_enabled: 1;
	unsigned int pri_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int reset_fn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int shpc_managed: 1;
	unsigned int is_thunderbolt: 1;
	unsigned int __aer_firmware_first_valid: 1;
	unsigned int __aer_firmware_first: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int irq_managed: 1;
	unsigned int has_secondary_link: 1;
	unsigned int non_compliant_bars: 1;
	unsigned int is_probed: 1;
	unsigned int link_active_reporting: 1;
	unsigned int untrusted: 1;
	unsigned int no_vf_scan: 1;
	unsigned int io_window: 1;
	unsigned int pref_window: 1;
	unsigned int pref_64_window: 1;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	struct bin_attribute___325 *rom_attr;
	int rom_attr_enabled;
	struct bin_attribute___325 *res_attr[17];
	struct bin_attribute___325 *res_attr_wc[17];
	unsigned int broken_cmd_compl: 1;
	const struct attribute_group___326 **msi_irq_groups;
	struct pci_vpd *vpd;
	union {
		struct pci_sriov *sriov;
		struct pci_dev___30 *physfn;
	};
	u16 ats_cap;
	u8 ats_stu;
	atomic_t ats_ref_cnt;
	u32 pri_reqs_alloc;
	u16 pasid_features;
	struct pci_p2pdma *p2pdma;
	phys_addr_t rom;
	size_t romlen;
	char *driver_override;
	long unsigned int priv_flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t pci_dev_extended_size_rh;
	struct pci_dev_extended_rh pci_dev_extended_rh;
};

struct pci_error_handlers___30;

struct pci_driver___30 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___30 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___30 *);
	int (*suspend)(struct pci_dev___30 *, pm_message_t);
	int (*suspend_late)(struct pci_dev___30 *, pm_message_t);
	int (*resume_early)(struct pci_dev___30 *);
	int (*resume)(struct pci_dev___30 *);
	void (*shutdown)(struct pci_dev___30 *);
	int (*sriov_configure)(struct pci_dev___30 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	const struct pci_error_handlers___30 *err_handler;
	const struct attribute_group___326 **groups;
	struct device_driver___329 driver;
	struct pci_dynids dynids;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct pci_ops___30 {
	int (*add_bus)(struct pci_bus___30 *);
	void (*remove_bus)(struct pci_bus___30 *);
	void * (*map_bus)(struct pci_bus___30 *, unsigned int, int);
	int (*read)(struct pci_bus___30 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___30 *, unsigned int, int, int, u32);
};

struct pci_error_handlers___30 {
	pci_ers_result_t (*error_detected)(struct pci_dev___30 *, enum pci_channel_state);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___30 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___30 *);
	void (*reset_prepare)(struct pci_dev___30 *);
	void (*reset_done)(struct pci_dev___30 *);
	void (*resume)(struct pci_dev___30 *);
};

struct shrink_control___132 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___132 *memcg;
};

struct shrinker___132 {
	long unsigned int (*count_objects)(struct shrinker___132 *, struct shrink_control___132 *);
	long unsigned int (*scan_objects)(struct shrinker___132 *, struct shrink_control___132 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct dentry_operations___361;

struct super_block___361;

struct dentry___361 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___361 *d_parent;
	struct qstr d_name;
	struct inode___362 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___361 *d_op;
	struct super_block___361 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___361;

struct block_device___361;

struct cdev___81;

struct inode___362 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___361 *i_op;
	struct super_block___361 *i_sb;
	struct address_space___361 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___363 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___179 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___362 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___361 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___361 *i_bdev;
		struct cdev___81 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___361 {
	int (*d_revalidate)(struct dentry___361 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___361 *, unsigned int);
	int (*d_hash)(const struct dentry___361 *, struct qstr *);
	int (*d_compare)(const struct dentry___361 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___361 *);
	int (*d_init)(struct dentry___361 *);
	void (*d_release)(struct dentry___361 *);
	void (*d_prune)(struct dentry___361 *);
	void (*d_iput)(struct dentry___361 *, struct inode___362 *);
	char * (*d_dname)(struct dentry___361 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___362 *);
	int (*d_manage)(const struct path___362 *, bool);
	struct dentry___361 * (*d_real)(struct dentry___361 *, const struct inode___362 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___361;

struct mem_dqinfo___361 {
	struct quota_format_type___361 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___361;

struct quota_info___361 {
	unsigned int flags;
	struct rw_semaphore___363 dqio_sem;
	struct inode___362 *files[3];
	struct mem_dqinfo___361 info[3];
	const struct quota_format_ops___361 *ops[3];
};

struct rcuwait___361 {
	struct task_struct___363 *task;
};

struct percpu_rw_semaphore___361 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___363 rw_sem;
	struct rcuwait___361 writer;
	int readers_block;
};

struct sb_writers___361 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___361 rw_sem[3];
};

struct file_system_type___361;

struct super_operations___361;

struct dquot_operations___361;

struct quotactl_ops___361;

struct super_block___361 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___361 *s_type;
	const struct super_operations___361 *s_op;
	const struct dquot_operations___361 *dq_op;
	const struct quotactl_ops___361 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___361 *s_root;
	struct rw_semaphore___363 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___361 *s_bdev;
	struct backing_dev_info___179 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___361 s_dquot;
	struct sb_writers___361 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___361 *s_d_op;
	int cleancache_poolid;
	struct shrinker___132 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___245 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct io_cq___99 {
	struct request_queue___95 *q;
	struct io_context___99 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___362 {
	struct file___362 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___362 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___361 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___362 *ia_file;
};

struct dquot___361 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___361 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___361 {
	int qf_fmt_id;
	const struct quota_format_ops___361 *qf_ops;
	struct module___293 *qf_owner;
	struct quota_format_type___361 *qf_next;
};

struct quota_format_ops___361 {
	int (*check_quota_file)(struct super_block___361 *, int);
	int (*read_file_info)(struct super_block___361 *, int);
	int (*write_file_info)(struct super_block___361 *, int);
	int (*free_file_info)(struct super_block___361 *, int);
	int (*read_dqblk)(struct dquot___361 *);
	int (*commit_dqblk)(struct dquot___361 *);
	int (*release_dqblk)(struct dquot___361 *);
	int (*get_next_id)(struct super_block___361 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___361 {
	int (*write_dquot)(struct dquot___361 *);
	struct dquot___361 * (*alloc_dquot)(struct super_block___361 *, int);
	void (*destroy_dquot)(struct dquot___361 *);
	int (*acquire_dquot)(struct dquot___361 *);
	int (*release_dquot)(struct dquot___361 *);
	int (*mark_dirty)(struct dquot___361 *);
	int (*write_info)(struct super_block___361 *, int);
	qsize_t * (*get_reserved_space)(struct inode___362 *);
	int (*get_projid)(struct inode___362 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___362 *, qsize_t *);
	int (*get_next_id)(struct super_block___361 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___361 {
	int (*quota_on)(struct super_block___361 *, int, int, const struct path___362 *);
	int (*quota_off)(struct super_block___361 *, int);
	int (*quota_enable)(struct super_block___361 *, unsigned int);
	int (*quota_disable)(struct super_block___361 *, unsigned int);
	int (*quota_sync)(struct super_block___361 *, int);
	int (*set_info)(struct super_block___361 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___361 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___361 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___361 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___361 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___361 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___149;

struct swap_info_struct___88;

struct address_space_operations___361 {
	int (*writepage)(struct page___363 *, struct writeback_control___149 *);
	int (*readpage)(struct file___362 *, struct page___363 *);
	int (*writepages)(struct address_space___361 *, struct writeback_control___149 *);
	int (*set_page_dirty)(struct page___363 *);
	int (*readpages)(struct file___362 *, struct address_space___361 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___362 *, struct address_space___361 *, loff_t, unsigned int, unsigned int, struct page___363 **, void **);
	int (*write_end)(struct file___362 *, struct address_space___361 *, loff_t, unsigned int, unsigned int, struct page___363 *, void *);
	sector_t (*bmap)(struct address_space___361 *, sector_t);
	void (*invalidatepage)(struct page___363 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___363 *, gfp_t);
	void (*freepage)(struct page___363 *);
	ssize_t (*direct_IO)(struct kiocb___362 *, struct iov_iter___156 *);
	int (*migratepage)(struct address_space___361 *, struct page___363 *, struct page___363 *, enum migrate_mode);
	bool (*isolate_page)(struct page___363 *, isolate_mode_t);
	void (*putback_page)(struct page___363 *);
	int (*launder_page)(struct page___363 *);
	int (*is_partially_uptodate)(struct page___363 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___363 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___361 *, struct page___363 *);
	int (*swap_activate)(struct swap_info_struct___88 *, struct file___362 *, sector_t *);
	void (*swap_deactivate)(struct file___362 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___149 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___179 *wb;
	struct inode___362 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___181;

struct iov_iter___156 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___181 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct swap_info_struct___88 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___361 *bdev;
	struct file___362 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct hd_struct___99;

struct gendisk___99;

struct block_device___361 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___362 *bd_inode;
	struct super_block___361 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___361 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___99 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___99 *bd_disk;
	struct request_queue___95 *bd_queue;
	struct backing_dev_info___179 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct hd_struct___99 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___329 __dev;
	struct kobject___349 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___99;

struct block_device_operations___96;

struct gendisk___99 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___99 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___99 *part_tbl;
	struct hd_struct___99 part0;
	const struct block_device_operations___96 *fops;
	struct request_queue___95 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___363 lookup_sem;
	struct kobject___349 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___349 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___81 {
	struct kobject___349 kobj;
	struct module___293 *owner;
	const struct file_operations___362 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___361 {
	struct dentry___361 * (*lookup)(struct inode___362 *, struct dentry___361 *, unsigned int);
	const char * (*get_link)(struct dentry___361 *, struct inode___362 *, struct delayed_call *);
	int (*permission)(struct inode___362 *, int);
	struct posix_acl * (*get_acl)(struct inode___362 *, int);
	int (*readlink)(struct dentry___361 *, char *, int);
	int (*create)(struct inode___362 *, struct dentry___361 *, umode_t, bool);
	int (*link)(struct dentry___361 *, struct inode___362 *, struct dentry___361 *);
	int (*unlink)(struct inode___362 *, struct dentry___361 *);
	int (*symlink)(struct inode___362 *, struct dentry___361 *, const char *);
	int (*mkdir)(struct inode___362 *, struct dentry___361 *, umode_t);
	int (*rmdir)(struct inode___362 *, struct dentry___361 *);
	int (*mknod)(struct inode___362 *, struct dentry___361 *, umode_t, dev_t);
	int (*rename)(struct inode___362 *, struct dentry___361 *, struct inode___362 *, struct dentry___361 *, unsigned int);
	int (*setattr)(struct dentry___361 *, struct iattr___361 *);
	int (*getattr)(const struct path___362 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___361 *, char *, size_t);
	int (*fiemap)(struct inode___362 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___362 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___362 *, struct dentry___361 *, struct file___362 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___362 *, struct dentry___361 *, umode_t);
	int (*set_acl)(struct inode___362 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___361 {
	void (*fl_copy_lock)(struct file_lock___362 *, struct file_lock___362 *);
	void (*fl_release_private)(struct file_lock___362 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___361;

struct file_lock___362 {
	struct file_lock___362 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___362 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___361 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___361 *fl_ops;
	const struct lock_manager_operations___361 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___361 {
	int (*lm_compare_owner)(struct file_lock___362 *, struct file_lock___362 *);
	long unsigned int (*lm_owner_key)(struct file_lock___362 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___362 *);
	int (*lm_grant)(struct file_lock___362 *, int);
	bool (*lm_break)(struct file_lock___362 *);
	int (*lm_change)(struct file_lock___362 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___362 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___361 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___361 *fa_next;
	struct file___362 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___361 {
	const char *name;
	int fs_flags;
	struct dentry___361 * (*mount)(struct file_system_type___361 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___361 *);
	struct module___293 *owner;
	struct file_system_type___361 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___361 {
	struct inode___362 * (*alloc_inode)(struct super_block___361 *);
	void (*destroy_inode)(struct inode___362 *);
	void (*dirty_inode)(struct inode___362 *, int);
	int (*write_inode)(struct inode___362 *, struct writeback_control___149 *);
	int (*drop_inode)(struct inode___362 *);
	void (*evict_inode)(struct inode___362 *);
	void (*put_super)(struct super_block___361 *);
	int (*sync_fs)(struct super_block___361 *, int);
	int (*freeze_super)(struct super_block___361 *);
	int (*freeze_fs)(struct super_block___361 *);
	int (*thaw_super)(struct super_block___361 *);
	int (*unfreeze_fs)(struct super_block___361 *);
	int (*statfs)(struct dentry___361 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___361 *, int *, char *);
	void (*umount_begin)(struct super_block___361 *);
	int (*show_options)(struct seq_file___306 *, struct dentry___361 *);
	int (*show_devname)(struct seq_file___306 *, struct dentry___361 *);
	int (*show_path)(struct seq_file___306 *, struct dentry___361 *);
	int (*show_stats)(struct seq_file___306 *, struct dentry___361 *);
	ssize_t (*quota_read)(struct super_block___361 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___361 *, int, const char *, size_t, loff_t);
	struct dquot___361 ** (*get_dquots)(struct inode___362 *);
	int (*bdev_try_to_free_page)(struct super_block___361 *, struct page___363 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___361 *, struct shrink_control___132 *);
	long int (*free_cached_objects)(struct super_block___361 *, struct shrink_control___132 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___179(struct bio___179 *);

struct bio_vec___181 {
	struct page___363 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___179;

struct bio___179 {
	struct bio___179 *bi_next;
	struct gendisk___99 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___179 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___179 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___181 *bi_io_vec;
	struct bio_set___179 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___181 bi_inline_vecs[0];
};

typedef void compound_page_dtor___350(struct page___363 *);

struct bio_integrity_payload___179 {
	struct bio___179 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___181 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___181 bip_inline_vecs[0];
};

struct disk_part_tbl___99 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___99 *last_lookup;
	struct hd_struct___99 *part[0];
};

struct block_device_operations___96 {
	int (*open)(struct block_device___361 *, fmode_t);
	void (*release)(struct gendisk___99 *, fmode_t);
	int (*rw_page)(struct block_device___361 *, sector_t, struct page___363 *, unsigned int);
	int (*ioctl)(struct block_device___361 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___361 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___99 *, unsigned int);
	int (*media_changed)(struct gendisk___99 *);
	void (*unlock_native_capacity)(struct gendisk___99 *);
	int (*revalidate_disk)(struct gendisk___99 *);
	int (*getgeo)(struct block_device___361 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___361 *, long unsigned int);
	int (*report_zones)(struct gendisk___99 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___293 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bdi_writeback_congested___179 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___179 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bsg_ops___95 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___95 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___95 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___95 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___95(struct request___95 *, blk_status_t);

struct request___95 {
	struct request_queue___95 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___32 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___179 *bio;
	struct bio___179 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___181 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___99 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___95 *saved_end_io;
		} flush;
	};
	struct gendisk___99 *rq_disk;
	struct hd_struct___99 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___95 *end_io;
	void *end_io_data;
	struct request___95 *next_rq;
};

struct blk_mq_hw_ctx___32 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___95 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags___4 *tags;
	struct blk_mq_tags___4 *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	unsigned int rh_reserved_nr_expired;
	struct hlist_node cpuhp_dead;
	struct kobject___349 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___361 *debugfs_dir;
	struct dentry___361 *sched_debugfs_dir;
	struct list_head hctx_list;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___95;

struct elevator_mq_ops___95 {
	int (*init_sched)(struct request_queue___95 *, struct elevator_type___95 *);
	void (*exit_sched)(struct elevator_queue___95 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___32 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___32 *, unsigned int);
	bool (*allow_merge)(struct request_queue___95 *, struct request___95 *, struct bio___179 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx___32 *, struct bio___179 *);
	int (*request_merge)(struct request_queue___95 *, struct request___95 **, struct bio___179 *);
	void (*request_merged)(struct request_queue___95 *, struct request___95 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___95 *, struct request___95 *, struct request___95 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___95 *, struct bio___179 *);
	void (*finish_request)(struct request___95 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___32 *, struct list_head *, bool);
	struct request___95 * (*dispatch_request)(struct blk_mq_hw_ctx___32 *);
	bool (*has_work)(struct blk_mq_hw_ctx___32 *);
	void (*completed_request)(struct request___95 *, u64);
	void (*started_request)(struct request___95 *);
	void (*requeue_request)(struct request___95 *);
	struct request___95 * (*former_request)(struct request_queue___95 *, struct request___95 *);
	struct request___95 * (*next_request)(struct request_queue___95 *, struct request___95 *);
	void (*init_icq)(struct io_cq___99 *);
	void (*exit_icq)(struct io_cq___99 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx___32 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___95;

struct elevator_type___95 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___95 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___95 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___293 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___95 {
	struct elevator_type___95 *type;
	void *elevator_data;
	struct kobject___349 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___95 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___95 *, char *);
	ssize_t (*store)(struct elevator_queue___95 *, const char *, size_t);
};

struct blk_mq_queue_data___32;

typedef blk_status_t queue_rq_fn___32(struct blk_mq_hw_ctx___32 *, const struct blk_mq_queue_data___32 *);

typedef void commit_rqs_fn___32(struct blk_mq_hw_ctx___32 *);

typedef bool get_budget_fn___32(struct blk_mq_hw_ctx___32 *);

typedef void put_budget_fn___32(struct blk_mq_hw_ctx___32 *);

typedef enum blk_eh_timer_return timeout_fn___32(struct request___95 *, bool);

typedef int poll_fn___32(struct blk_mq_hw_ctx___32 *);

typedef void complete_fn___32(struct request___95 *);

typedef int init_hctx_fn___32(struct blk_mq_hw_ctx___32 *, void *, unsigned int);

typedef void exit_hctx_fn___32(struct blk_mq_hw_ctx___32 *, unsigned int);

typedef int init_request_fn___32(struct blk_mq_tag_set___32 *, struct request___95 *, unsigned int, unsigned int);

typedef void exit_request_fn___32(struct blk_mq_tag_set___32 *, struct request___95 *, unsigned int);

typedef bool busy_fn___32(struct request_queue___95 *);

typedef int map_queues_fn___32(struct blk_mq_tag_set___32 *);

typedef void cleanup_rq_fn___32(struct request___95 *);

struct blk_mq_ops___32 {
	queue_rq_fn___32 *queue_rq;
	commit_rqs_fn___32 *commit_rqs;
	get_budget_fn___32 *get_budget;
	put_budget_fn___32 *put_budget;
	timeout_fn___32 *timeout;
	poll_fn___32 *poll;
	complete_fn___32 *complete;
	init_hctx_fn___32 *init_hctx;
	exit_hctx_fn___32 *exit_hctx;
	init_request_fn___32 *init_request;
	exit_request_fn___32 *exit_request;
	void (*initialize_rq_fn)(struct request___95 *);
	busy_fn___32 *busy;
	map_queues_fn___32 *map_queues;
	void (*show_rq)(struct seq_file___306 *, struct request___95 *);
	union {
		cleanup_rq_fn___32 *cleanup_rq;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide48;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct blk_mq_tag_set___32 {
	struct blk_mq_queue_map map[6];
	unsigned int nr_maps;
	const struct blk_mq_ops___32 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	struct blk_mq_tags___4 **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef int (*key_restrict_link_func_t___334)(struct key___333 *, const struct key_type *, const union key_payload *, struct key___333 *);

struct key_restriction___333;

struct key___333 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___363 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___333 *restrict_link;
};

struct key_restriction___333 {
	key_restrict_link_func_t___334 check;
	struct key___333 *key;
	struct key_type *keytype;
};

struct seq_operations___305 {
	void * (*start)(struct seq_file___306 *, loff_t *);
	void (*stop)(struct seq_file___306 *, void *);
	void * (*next)(struct seq_file___306 *, void *, loff_t *);
	int (*show)(struct seq_file___306 *, void *);
};

struct cgroup_namespace___230 {
	refcount_t count;
	struct ns_common___9 ns;
	struct user_namespace___245 *user_ns;
	struct ucounts___245 *ucounts;
	struct css_set___230 *root_cset;
};

struct ucounts___245 {
	struct hlist_node node;
	struct user_namespace___245 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___231;

struct bpf_map_ops___230 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___231 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___231 *, struct file___362 *);
	void (*map_free)(struct bpf_map___231 *);
	int (*map_get_next_key)(struct bpf_map___231 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___231 *);
	void * (*map_lookup_elem)(struct bpf_map___231 *, void *);
	int (*map_update_elem)(struct bpf_map___231 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___231 *, void *);
	int (*map_push_elem)(struct bpf_map___231 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___231 *, void *);
	int (*map_peek_elem)(struct bpf_map___231 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___231 *, struct file___362 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___231 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___231 *, void *, struct seq_file___306 *);
	int (*map_check_btf)(const struct bpf_map___231 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___231 {
	const struct bpf_map_ops___230 *ops;
	struct bpf_map___231 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___333 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___230;

typedef void (*kthread_work_func_t___230)(struct kthread_work___230 *);

struct kthread_worker___230;

struct kthread_work___230 {
	struct list_head node;
	kthread_work_func_t___230 func;
	struct kthread_worker___230 *worker;
	int canceling;
};

struct kthread_worker___230 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___363 *task;
	struct kthread_work___230 *current_work;
};

struct kthread_delayed_work___230 {
	struct kthread_work___230 work;
	struct timer_list timer;
};

struct psi_group___230 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___230 *poll_kworker;
	struct kthread_delayed_work___230 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___230;

struct cgroup_rstat_cpu___230;

struct cgroup___230 {
	struct cgroup_subsys_state___230 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___356 *kn;
	struct cgroup_file___230 procs_file;
	struct cgroup_file___230 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___230 *subsys[13];
	struct cgroup_root___230 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___230 *dom_cgrp;
	struct cgroup_rstat_cpu___230 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___38 bpf;
	atomic_t congestion_count;
	struct cgroup___230 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___230 psi;
	int ancestor_ids[0];
};

struct cftype___230;

struct cgroup_subsys___230 {
	struct cgroup_subsys_state___230 * (*css_alloc)(struct cgroup_subsys_state___230 *);
	int (*css_online)(struct cgroup_subsys_state___230 *);
	void (*css_offline)(struct cgroup_subsys_state___230 *);
	void (*css_released)(struct cgroup_subsys_state___230 *);
	void (*css_free)(struct cgroup_subsys_state___230 *);
	void (*css_reset)(struct cgroup_subsys_state___230 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___230 *, int);
	int (*css_extra_stat_show)(struct seq_file___306 *, struct cgroup_subsys_state___230 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___363 *);
	void (*cancel_fork)(struct task_struct___363 *);
	void (*fork)(struct task_struct___363 *);
	void (*exit)(struct task_struct___363 *);
	void (*free)(struct task_struct___363 *);
	void (*bind)(struct cgroup_subsys_state___230 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___230 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___230 *dfl_cftypes;
	struct cftype___230 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___230 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___230 *updated_children;
	struct cgroup___230 *updated_next;
};

struct cgroup_root___230 {
	struct kernfs_root___355 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___230 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___230 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___230 *ss;
	struct list_head node;
	struct kernfs_ops___355 *kf_ops;
	int (*open)(struct kernfs_open_file___355 *);
	void (*release)(struct kernfs_open_file___355 *);
	u64 (*read_u64)(struct cgroup_subsys_state___230 *, struct cftype___230 *);
	s64 (*read_s64)(struct cgroup_subsys_state___230 *, struct cftype___230 *);
	int (*seq_show)(struct seq_file___306 *, void *);
	void * (*seq_start)(struct seq_file___306 *, loff_t *);
	void * (*seq_next)(struct seq_file___306 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___306 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___230 *, struct cftype___230 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___230 *, struct cftype___230 *, s64);
	ssize_t (*write)(struct kernfs_open_file___355 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___355 *, struct poll_table_struct___215 *);
};

struct mem_cgroup_reclaim_iter___132 {
	struct mem_cgroup___132 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___132 {
	struct lruvec___362 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___132 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___132 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct node___205 {
	struct device___329 dev;
};

struct Scsi_Host___8;

struct scsi_target___13;

struct scsi_device___13 {
	struct Scsi_Host___8 *host;
	struct request_queue___95 *request_queue;
	struct list_head siblings;
	struct list_head same_target_siblings;
	atomic_t device_busy;
	atomic_t device_blocked;
	spinlock_t list_lock;
	struct list_head cmd_list;
	struct list_head starved_entry;
	short unsigned int queue_depth;
	short unsigned int max_queue_depth;
	short unsigned int last_queue_full_depth;
	short unsigned int last_queue_full_count;
	long unsigned int last_queue_full_time;
	long unsigned int queue_ramp_up_period;
	long unsigned int last_queue_ramp_up;
	unsigned int id;
	unsigned int channel;
	u64 lun;
	unsigned int manufacturer;
	unsigned int sector_size;
	void *hostdata;
	unsigned char type;
	char scsi_level;
	char inq_periph_qual;
	struct mutex inquiry_mutex;
	unsigned char inquiry_len;
	unsigned char *inquiry;
	const char *vendor;
	const char *model;
	const char *rev;
	struct scsi_vpd *vpd_pg83;
	struct scsi_vpd *vpd_pg80;
	unsigned char current_tag;
	struct scsi_target___13 *sdev_target;
	blist_flags_t sdev_bflags;
	unsigned int eh_timeout;
	unsigned int removable: 1;
	unsigned int changed: 1;
	unsigned int busy: 1;
	unsigned int lockable: 1;
	unsigned int locked: 1;
	unsigned int borken: 1;
	unsigned int disconnect: 1;
	unsigned int soft_reset: 1;
	unsigned int sdtr: 1;
	unsigned int wdtr: 1;
	unsigned int ppr: 1;
	unsigned int tagged_supported: 1;
	unsigned int simple_tags: 1;
	unsigned int was_reset: 1;
	unsigned int expecting_cc_ua: 1;
	unsigned int use_10_for_rw: 1;
	unsigned int use_10_for_ms: 1;
	unsigned int no_report_opcodes: 1;
	unsigned int no_write_same: 1;
	unsigned int use_16_for_rw: 1;
	unsigned int skip_ms_page_8: 1;
	unsigned int skip_ms_page_3f: 1;
	unsigned int skip_vpd_pages: 1;
	unsigned int try_vpd_pages: 1;
	unsigned int use_192_bytes_for_3f: 1;
	unsigned int no_start_on_add: 1;
	unsigned int allow_restart: 1;
	unsigned int manage_start_stop: 1;
	unsigned int start_stop_pwr_cond: 1;
	unsigned int no_uld_attach: 1;
	unsigned int select_no_atn: 1;
	unsigned int fix_capacity: 1;
	unsigned int guess_capacity: 1;
	unsigned int retry_hwerror: 1;
	unsigned int last_sector_bug: 1;
	unsigned int no_read_disc_info: 1;
	unsigned int no_read_capacity_16: 1;
	unsigned int try_rc_10_first: 1;
	unsigned int security_supported: 1;
	unsigned int is_visible: 1;
	unsigned int wce_default_on: 1;
	unsigned int no_dif: 1;
	unsigned int broken_fua: 1;
	unsigned int lun_in_cdb: 1;
	unsigned int unmap_limit_for_ws: 1;
	atomic_t disk_events_disable_depth;
	long unsigned int supported_events[1];
	long unsigned int pending_events[1];
	struct list_head event_list;
	struct work_struct event_work;
	unsigned int max_device_blocked;
	atomic_t iorequest_cnt;
	atomic_t iodone_cnt;
	atomic_t ioerr_cnt;
	struct device___329 sdev_gendev;
	struct device___329 sdev_dev;
	struct execute_work ew;
	struct work_struct requeue_work;
	struct scsi_device_handler *handler;
	void *handler_data;
	unsigned char access_state;
	struct mutex state_mutex;
	enum scsi_device_state sdev_state;
	struct task_struct___363 *quiesced_by;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int sdev_data[0];
};

struct scsi_host_template___8;

struct Scsi_Host___8 {
	struct list_head __devices;
	struct list_head __targets;
	struct list_head starved_list;
	spinlock_t default_lock;
	spinlock_t *host_lock;
	struct mutex scan_mutex;
	struct list_head eh_cmd_q;
	struct task_struct___363 *ehandler;
	struct completion *eh_action;
	wait_queue_head_t host_wait;
	struct scsi_host_template___8 *hostt;
	struct scsi_transport_template *transportt;
	struct blk_mq_tag_set___32 tag_set;
	atomic_t host_busy;
	atomic_t host_blocked;
	unsigned int host_failed;
	unsigned int host_eh_scheduled;
	unsigned int host_no;
	int eh_deadline;
	long unsigned int last_reset;
	unsigned int max_channel;
	unsigned int max_id;
	u64 max_lun;
	unsigned int unique_id;
	short unsigned int max_cmd_len;
	int this_id;
	int can_queue;
	short int cmd_per_lun;
	short unsigned int sg_tablesize;
	short unsigned int sg_prot_tablesize;
	unsigned int max_sectors;
	long unsigned int dma_boundary;
	unsigned int nr_hw_queues;
	long unsigned int cmd_serial_number;
	unsigned int active_mode: 2;
	unsigned int unchecked_isa_dma: 1;
	unsigned int use_clustering: 1;
	unsigned int host_self_blocked: 1;
	unsigned int reverse_ordering: 1;
	unsigned int tmf_in_progress: 1;
	unsigned int async_scan: 1;
	unsigned int eh_noresume: 1;
	unsigned int no_write_same: 1;
	unsigned int use_cmd_list: 1;
	unsigned int short_inquiry: 1;
	char work_q_name[20];
	struct workqueue_struct *work_q;
	struct workqueue_struct *tmf_work_q;
	unsigned int no_scsi2_lun_in_cdb: 1;
	unsigned int max_host_blocked;
	unsigned int prot_capabilities;
	unsigned char prot_guard_type;
	long unsigned int base;
	long unsigned int io_port;
	unsigned char n_io_port;
	unsigned char dma_channel;
	unsigned int irq;
	enum scsi_host_state shost_state;
	struct device___329 shost_gendev;
	struct device___329 shost_dev;
	void *shost_data;
	struct device___329 *dma_dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int hostdata[0];
};

struct scsi_target___13 {
	struct scsi_device___13 *starget_sdev_user;
	struct list_head siblings;
	struct list_head devices;
	struct device___329 dev;
	struct kref reap_ref;
	unsigned int channel;
	unsigned int id;
	unsigned int create: 1;
	unsigned int single_lun: 1;
	unsigned int pdt_1f_for_no_lun: 1;
	unsigned int no_report_luns: 1;
	unsigned int expecting_lun_change: 1;
	atomic_t target_busy;
	atomic_t target_blocked;
	unsigned int can_queue;
	unsigned int max_target_blocked;
	char scsi_level;
	enum scsi_target_state state;
	void *hostdata;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int starget_data[0];
};

struct blk_mq_queue_data___32 {
	struct request___95 *rq;
	bool last;
	long unsigned int rh_reserved1;
};

struct scsi_cmnd___8 {
	struct scsi_request req;
	struct scsi_device___13 *device;
	struct list_head list;
	struct list_head eh_entry;
	struct delayed_work abort_work;
	struct callback_head rcu;
	int eh_eflags;
	long unsigned int serial_number;
	long unsigned int jiffies_at_alloc;
	int retries;
	int allowed;
	unsigned char prot_op;
	unsigned char prot_type;
	unsigned char prot_flags;
	short unsigned int cmd_len;
	enum dma_data_direction sc_data_direction;
	unsigned char *cmnd;
	struct scsi_data_buffer sdb;
	struct scsi_data_buffer *prot_sdb;
	unsigned int underflow;
	unsigned int transfersize;
	struct request___95 *request;
	unsigned char *sense_buffer;
	void (*scsi_done)(struct scsi_cmnd___8 *);
	struct scsi_pointer SCp;
	unsigned char *host_scribble;
	int result;
	int flags;
	long unsigned int state;
	unsigned char tag;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct scsi_host_template___8 {
	struct module___293 *module;
	const char *name;
	const char * (*info)(struct Scsi_Host___8 *);
	int (*ioctl)(struct scsi_device___13 *, int, void *);
	int (*queuecommand)(struct Scsi_Host___8 *, struct scsi_cmnd___8 *);
	int (*eh_abort_handler)(struct scsi_cmnd___8 *);
	int (*eh_device_reset_handler)(struct scsi_cmnd___8 *);
	int (*eh_target_reset_handler)(struct scsi_cmnd___8 *);
	int (*eh_bus_reset_handler)(struct scsi_cmnd___8 *);
	int (*eh_host_reset_handler)(struct scsi_cmnd___8 *);
	int (*slave_alloc)(struct scsi_device___13 *);
	int (*slave_configure)(struct scsi_device___13 *);
	void (*slave_destroy)(struct scsi_device___13 *);
	int (*target_alloc)(struct scsi_target___13 *);
	void (*target_destroy)(struct scsi_target___13 *);
	int (*scan_finished)(struct Scsi_Host___8 *, long unsigned int);
	void (*scan_start)(struct Scsi_Host___8 *);
	int (*change_queue_depth)(struct scsi_device___13 *, int);
	int (*map_queues)(struct Scsi_Host___8 *);
	int (*bios_param)(struct scsi_device___13 *, struct block_device___361 *, sector_t, int *);
	void (*unlock_native_capacity)(struct scsi_device___13 *);
	int (*show_info)(struct seq_file___306 *, struct Scsi_Host___8 *);
	int (*write_info)(struct Scsi_Host___8 *, char *, int);
	enum blk_eh_timer_return (*eh_timed_out)(struct scsi_cmnd___8 *);
	int (*host_reset)(struct Scsi_Host___8 *, int);
	const char *proc_name;
	struct proc_dir_entry *proc_dir;
	int can_queue;
	int this_id;
	short unsigned int sg_tablesize;
	short unsigned int sg_prot_tablesize;
	unsigned int max_sectors;
	long unsigned int dma_boundary;
	short int cmd_per_lun;
	unsigned char present;
	int tag_alloc_policy;
	unsigned int track_queue_depth: 1;
	unsigned int supported_mode: 2;
	unsigned int unchecked_isa_dma: 1;
	unsigned int use_clustering: 1;
	unsigned int emulated: 1;
	unsigned int skip_settle_delay: 1;
	unsigned int no_write_same: 1;
	unsigned int force_blk_mq: 1;
	unsigned int max_host_blocked;
	struct device_attribute___41 **shost_attrs;
	struct device_attribute___41 **sdev_attrs;
	const struct attribute_group___326 **sdev_groups;
	u64 vendor_id;
	unsigned int cmd_size;
	struct scsi_host_cmd_pool *cmd_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

enum {
	ATA_MAX_DEVICES = 2,
	ATA_MAX_PRD = 256,
	ATA_SECT_SIZE = 512,
	ATA_MAX_SECTORS_128 = 128,
	ATA_MAX_SECTORS = 256,
	ATA_MAX_SECTORS_1024 = 1024,
	ATA_MAX_SECTORS_LBA48 = 65535,
	ATA_MAX_SECTORS_TAPE = 65535,
	ATA_MAX_TRIM_RNUM = 64,
	ATA_ID_WORDS = 256,
	ATA_ID_CONFIG = 0,
	ATA_ID_CYLS = 1,
	ATA_ID_HEADS = 3,
	ATA_ID_SECTORS = 6,
	ATA_ID_SERNO = 10,
	ATA_ID_BUF_SIZE = 21,
	ATA_ID_FW_REV = 23,
	ATA_ID_PROD = 27,
	ATA_ID_MAX_MULTSECT = 47,
	ATA_ID_DWORD_IO = 48,
	ATA_ID_TRUSTED = 48,
	ATA_ID_CAPABILITY = 49,
	ATA_ID_OLD_PIO_MODES = 51,
	ATA_ID_OLD_DMA_MODES = 52,
	ATA_ID_FIELD_VALID = 53,
	ATA_ID_CUR_CYLS = 54,
	ATA_ID_CUR_HEADS = 55,
	ATA_ID_CUR_SECTORS = 56,
	ATA_ID_MULTSECT = 59,
	ATA_ID_LBA_CAPACITY = 60,
	ATA_ID_SWDMA_MODES = 62,
	ATA_ID_MWDMA_MODES = 63,
	ATA_ID_PIO_MODES = 64,
	ATA_ID_EIDE_DMA_MIN = 65,
	ATA_ID_EIDE_DMA_TIME = 66,
	ATA_ID_EIDE_PIO = 67,
	ATA_ID_EIDE_PIO_IORDY = 68,
	ATA_ID_ADDITIONAL_SUPP = 69,
	ATA_ID_QUEUE_DEPTH = 75,
	ATA_ID_SATA_CAPABILITY = 76,
	ATA_ID_SATA_CAPABILITY_2 = 77,
	ATA_ID_FEATURE_SUPP = 78,
	ATA_ID_MAJOR_VER = 80,
	ATA_ID_COMMAND_SET_1 = 82,
	ATA_ID_COMMAND_SET_2 = 83,
	ATA_ID_CFSSE = 84,
	ATA_ID_CFS_ENABLE_1 = 85,
	ATA_ID_CFS_ENABLE_2 = 86,
	ATA_ID_CSF_DEFAULT = 87,
	ATA_ID_UDMA_MODES = 88,
	ATA_ID_HW_CONFIG = 93,
	ATA_ID_SPG = 98,
	ATA_ID_LBA_CAPACITY_2 = 100,
	ATA_ID_SECTOR_SIZE = 106,
	ATA_ID_WWN = 108,
	ATA_ID_LOGICAL_SECTOR_SIZE = 117,
	ATA_ID_COMMAND_SET_3 = 119,
	ATA_ID_COMMAND_SET_4 = 120,
	ATA_ID_LAST_LUN = 126,
	ATA_ID_DLF = 128,
	ATA_ID_CSFO = 129,
	ATA_ID_CFA_POWER = 160,
	ATA_ID_CFA_KEY_MGMT = 162,
	ATA_ID_CFA_MODES = 163,
	ATA_ID_DATA_SET_MGMT = 169,
	ATA_ID_SCT_CMD_XPORT = 206,
	ATA_ID_ROT_SPEED = 217,
	ATA_ID_PIO4 = 2,
	ATA_ID_SERNO_LEN = 20,
	ATA_ID_FW_REV_LEN = 8,
	ATA_ID_PROD_LEN = 40,
	ATA_ID_WWN_LEN = 8,
	ATA_PCI_CTL_OFS = 2,
	ATA_PIO0 = 1,
	ATA_PIO1 = 3,
	ATA_PIO2 = 7,
	ATA_PIO3 = 15,
	ATA_PIO4 = 31,
	ATA_PIO5 = 63,
	ATA_PIO6 = 127,
	ATA_PIO4_ONLY = 16,
	ATA_SWDMA0 = 1,
	ATA_SWDMA1 = 3,
	ATA_SWDMA2 = 7,
	ATA_SWDMA2_ONLY = 4,
	ATA_MWDMA0 = 1,
	ATA_MWDMA1 = 3,
	ATA_MWDMA2 = 7,
	ATA_MWDMA3 = 15,
	ATA_MWDMA4 = 31,
	ATA_MWDMA12_ONLY = 6,
	ATA_MWDMA2_ONLY = 4,
	ATA_UDMA0 = 1,
	ATA_UDMA1 = 3,
	ATA_UDMA2 = 7,
	ATA_UDMA3 = 15,
	ATA_UDMA4 = 31,
	ATA_UDMA5 = 63,
	ATA_UDMA6 = 127,
	ATA_UDMA7 = 255,
	ATA_UDMA24_ONLY = 20,
	ATA_UDMA_MASK_40C = 7,
	ATA_PRD_SZ = 8,
	ATA_PRD_TBL_SZ = 2048,
	ATA_PRD_EOT = 2147483648,
	ATA_DMA_TABLE_OFS = 4,
	ATA_DMA_STATUS = 2,
	ATA_DMA_CMD = 0,
	ATA_DMA_WR = 8,
	ATA_DMA_START = 1,
	ATA_DMA_INTR = 4,
	ATA_DMA_ERR = 2,
	ATA_DMA_ACTIVE = 1,
	ATA_HOB = 128,
	ATA_NIEN = 2,
	ATA_LBA = 64,
	ATA_DEV1 = 16,
	ATA_DEVICE_OBS = 160,
	ATA_DEVCTL_OBS = 8,
	ATA_BUSY = 128,
	ATA_DRDY = 64,
	ATA_DF = 32,
	ATA_DSC = 16,
	ATA_DRQ = 8,
	ATA_CORR = 4,
	ATA_SENSE = 2,
	ATA_ERR = 1,
	ATA_SRST = 4,
	ATA_ICRC = 128,
	ATA_BBK = 128,
	ATA_UNC = 64,
	ATA_MC = 32,
	ATA_IDNF = 16,
	ATA_MCR = 8,
	ATA_ABORTED = 4,
	ATA_TRK0NF = 2,
	ATA_AMNF = 1,
	ATAPI_LFS = 240,
	ATAPI_EOM = 2,
	ATAPI_ILI = 1,
	ATAPI_IO = 2,
	ATAPI_COD = 1,
	ATA_REG_DATA = 0,
	ATA_REG_ERR = 1,
	ATA_REG_NSECT = 2,
	ATA_REG_LBAL = 3,
	ATA_REG_LBAM = 4,
	ATA_REG_LBAH = 5,
	ATA_REG_DEVICE = 6,
	ATA_REG_STATUS = 7,
	ATA_REG_FEATURE = 1,
	ATA_REG_CMD = 7,
	ATA_REG_BYTEL = 4,
	ATA_REG_BYTEH = 5,
	ATA_REG_DEVSEL = 6,
	ATA_REG_IRQ = 2,
	ATA_CMD_DEV_RESET = 8,
	ATA_CMD_CHK_POWER = 229,
	ATA_CMD_STANDBY = 226,
	ATA_CMD_IDLE = 227,
	ATA_CMD_EDD = 144,
	ATA_CMD_DOWNLOAD_MICRO = 146,
	ATA_CMD_DOWNLOAD_MICRO_DMA = 147,
	ATA_CMD_NOP = 0,
	ATA_CMD_FLUSH = 231,
	ATA_CMD_FLUSH_EXT = 234,
	ATA_CMD_ID_ATA = 236,
	ATA_CMD_ID_ATAPI = 161,
	ATA_CMD_SERVICE = 162,
	ATA_CMD_READ = 200,
	ATA_CMD_READ_EXT = 37,
	ATA_CMD_READ_QUEUED = 38,
	ATA_CMD_READ_STREAM_EXT = 43,
	ATA_CMD_READ_STREAM_DMA_EXT = 42,
	ATA_CMD_WRITE = 202,
	ATA_CMD_WRITE_EXT = 53,
	ATA_CMD_WRITE_QUEUED = 54,
	ATA_CMD_WRITE_STREAM_EXT = 59,
	ATA_CMD_WRITE_STREAM_DMA_EXT = 58,
	ATA_CMD_WRITE_FUA_EXT = 61,
	ATA_CMD_WRITE_QUEUED_FUA_EXT = 62,
	ATA_CMD_FPDMA_READ = 96,
	ATA_CMD_FPDMA_WRITE = 97,
	ATA_CMD_NCQ_NON_DATA = 99,
	ATA_CMD_FPDMA_SEND = 100,
	ATA_CMD_FPDMA_RECV = 101,
	ATA_CMD_PIO_READ = 32,
	ATA_CMD_PIO_READ_EXT = 36,
	ATA_CMD_PIO_WRITE = 48,
	ATA_CMD_PIO_WRITE_EXT = 52,
	ATA_CMD_READ_MULTI = 196,
	ATA_CMD_READ_MULTI_EXT = 41,
	ATA_CMD_WRITE_MULTI = 197,
	ATA_CMD_WRITE_MULTI_EXT = 57,
	ATA_CMD_WRITE_MULTI_FUA_EXT = 206,
	ATA_CMD_SET_FEATURES = 239,
	ATA_CMD_SET_MULTI = 198,
	ATA_CMD_PACKET = 160,
	ATA_CMD_VERIFY = 64,
	ATA_CMD_VERIFY_EXT = 66,
	ATA_CMD_WRITE_UNCORR_EXT = 69,
	ATA_CMD_STANDBYNOW1 = 224,
	ATA_CMD_IDLEIMMEDIATE = 225,
	ATA_CMD_SLEEP = 230,
	ATA_CMD_INIT_DEV_PARAMS = 145,
	ATA_CMD_READ_NATIVE_MAX = 248,
	ATA_CMD_READ_NATIVE_MAX_EXT = 39,
	ATA_CMD_SET_MAX = 249,
	ATA_CMD_SET_MAX_EXT = 55,
	ATA_CMD_READ_LOG_EXT = 47,
	ATA_CMD_WRITE_LOG_EXT = 63,
	ATA_CMD_READ_LOG_DMA_EXT = 71,
	ATA_CMD_WRITE_LOG_DMA_EXT = 87,
	ATA_CMD_TRUSTED_NONDATA = 91,
	ATA_CMD_TRUSTED_RCV = 92,
	ATA_CMD_TRUSTED_RCV_DMA = 93,
	ATA_CMD_TRUSTED_SND = 94,
	ATA_CMD_TRUSTED_SND_DMA = 95,
	ATA_CMD_PMP_READ = 228,
	ATA_CMD_PMP_READ_DMA = 233,
	ATA_CMD_PMP_WRITE = 232,
	ATA_CMD_PMP_WRITE_DMA = 235,
	ATA_CMD_CONF_OVERLAY = 177,
	ATA_CMD_SEC_SET_PASS = 241,
	ATA_CMD_SEC_UNLOCK = 242,
	ATA_CMD_SEC_ERASE_PREP = 243,
	ATA_CMD_SEC_ERASE_UNIT = 244,
	ATA_CMD_SEC_FREEZE_LOCK = 245,
	ATA_CMD_SEC_DISABLE_PASS = 246,
	ATA_CMD_CONFIG_STREAM = 81,
	ATA_CMD_SMART = 176,
	ATA_CMD_MEDIA_LOCK = 222,
	ATA_CMD_MEDIA_UNLOCK = 223,
	ATA_CMD_DSM = 6,
	ATA_CMD_CHK_MED_CRD_TYP = 209,
	ATA_CMD_CFA_REQ_EXT_ERR = 3,
	ATA_CMD_CFA_WRITE_NE = 56,
	ATA_CMD_CFA_TRANS_SECT = 135,
	ATA_CMD_CFA_ERASE = 192,
	ATA_CMD_CFA_WRITE_MULT_NE = 205,
	ATA_CMD_REQ_SENSE_DATA = 11,
	ATA_CMD_SANITIZE_DEVICE = 180,
	ATA_CMD_ZAC_MGMT_IN = 74,
	ATA_CMD_ZAC_MGMT_OUT = 159,
	ATA_CMD_RESTORE = 16,
	ATA_SUBCMD_FPDMA_RECV_RD_LOG_DMA_EXT = 1,
	ATA_SUBCMD_FPDMA_RECV_ZAC_MGMT_IN = 2,
	ATA_SUBCMD_FPDMA_SEND_DSM = 0,
	ATA_SUBCMD_FPDMA_SEND_WR_LOG_DMA_EXT = 2,
	ATA_SUBCMD_NCQ_NON_DATA_ABORT_QUEUE = 0,
	ATA_SUBCMD_NCQ_NON_DATA_SET_FEATURES = 5,
	ATA_SUBCMD_NCQ_NON_DATA_ZERO_EXT = 6,
	ATA_SUBCMD_NCQ_NON_DATA_ZAC_MGMT_OUT = 7,
	ATA_SUBCMD_ZAC_MGMT_IN_REPORT_ZONES = 0,
	ATA_SUBCMD_ZAC_MGMT_OUT_CLOSE_ZONE = 1,
	ATA_SUBCMD_ZAC_MGMT_OUT_FINISH_ZONE = 2,
	ATA_SUBCMD_ZAC_MGMT_OUT_OPEN_ZONE = 3,
	ATA_SUBCMD_ZAC_MGMT_OUT_RESET_WRITE_POINTER = 4,
	ATA_LOG_DIRECTORY = 0,
	ATA_LOG_SATA_NCQ = 16,
	ATA_LOG_NCQ_NON_DATA = 18,
	ATA_LOG_NCQ_SEND_RECV = 19,
	ATA_LOG_IDENTIFY_DEVICE = 48,
	ATA_LOG_SECURITY = 6,
	ATA_LOG_SATA_SETTINGS = 8,
	ATA_LOG_ZONED_INFORMATION = 9,
	ATA_LOG_DEVSLP_OFFSET = 48,
	ATA_LOG_DEVSLP_SIZE = 8,
	ATA_LOG_DEVSLP_MDAT = 0,
	ATA_LOG_DEVSLP_MDAT_MASK = 31,
	ATA_LOG_DEVSLP_DETO = 1,
	ATA_LOG_DEVSLP_VALID = 7,
	ATA_LOG_DEVSLP_VALID_MASK = 128,
	ATA_LOG_NCQ_PRIO_OFFSET = 9,
	ATA_LOG_NCQ_SEND_RECV_SUBCMDS_OFFSET = 0,
	ATA_LOG_NCQ_SEND_RECV_SUBCMDS_DSM = 1,
	ATA_LOG_NCQ_SEND_RECV_DSM_OFFSET = 4,
	ATA_LOG_NCQ_SEND_RECV_DSM_TRIM = 1,
	ATA_LOG_NCQ_SEND_RECV_RD_LOG_OFFSET = 8,
	ATA_LOG_NCQ_SEND_RECV_RD_LOG_SUPPORTED = 1,
	ATA_LOG_NCQ_SEND_RECV_WR_LOG_OFFSET = 12,
	ATA_LOG_NCQ_SEND_RECV_WR_LOG_SUPPORTED = 1,
	ATA_LOG_NCQ_SEND_RECV_ZAC_MGMT_OFFSET = 16,
	ATA_LOG_NCQ_SEND_RECV_ZAC_MGMT_OUT_SUPPORTED = 1,
	ATA_LOG_NCQ_SEND_RECV_ZAC_MGMT_IN_SUPPORTED = 2,
	ATA_LOG_NCQ_SEND_RECV_SIZE = 20,
	ATA_LOG_NCQ_NON_DATA_SUBCMDS_OFFSET = 0,
	ATA_LOG_NCQ_NON_DATA_ABORT_OFFSET = 0,
	ATA_LOG_NCQ_NON_DATA_ABORT_NCQ = 1,
	ATA_LOG_NCQ_NON_DATA_ABORT_ALL = 2,
	ATA_LOG_NCQ_NON_DATA_ABORT_STREAMING = 4,
	ATA_LOG_NCQ_NON_DATA_ABORT_NON_STREAMING = 8,
	ATA_LOG_NCQ_NON_DATA_ABORT_SELECTED = 16,
	ATA_LOG_NCQ_NON_DATA_ZAC_MGMT_OFFSET = 28,
	ATA_LOG_NCQ_NON_DATA_ZAC_MGMT_OUT = 1,
	ATA_LOG_NCQ_NON_DATA_SIZE = 64,
	ATA_CMD_READ_LONG = 34,
	ATA_CMD_READ_LONG_ONCE = 35,
	ATA_CMD_WRITE_LONG = 50,
	ATA_CMD_WRITE_LONG_ONCE = 51,
	SETFEATURES_XFER = 3,
	XFER_UDMA_7 = 71,
	XFER_UDMA_6 = 70,
	XFER_UDMA_5 = 69,
	XFER_UDMA_4 = 68,
	XFER_UDMA_3 = 67,
	XFER_UDMA_2 = 66,
	XFER_UDMA_1 = 65,
	XFER_UDMA_0 = 64,
	XFER_MW_DMA_4 = 36,
	XFER_MW_DMA_3 = 35,
	XFER_MW_DMA_2 = 34,
	XFER_MW_DMA_1 = 33,
	XFER_MW_DMA_0 = 32,
	XFER_SW_DMA_2 = 18,
	XFER_SW_DMA_1 = 17,
	XFER_SW_DMA_0 = 16,
	XFER_PIO_6 = 14,
	XFER_PIO_5 = 13,
	XFER_PIO_4 = 12,
	XFER_PIO_3 = 11,
	XFER_PIO_2 = 10,
	XFER_PIO_1 = 9,
	XFER_PIO_0 = 8,
	XFER_PIO_SLOW = 0,
	SETFEATURES_WC_ON = 2,
	SETFEATURES_WC_OFF = 130,
	SETFEATURES_RA_ON = 170,
	SETFEATURES_RA_OFF = 85,
	SETFEATURES_AAM_ON = 66,
	SETFEATURES_AAM_OFF = 194,
	SETFEATURES_SPINUP = 7,
	SETFEATURES_SPINUP_TIMEOUT = 30000,
	SETFEATURES_SATA_ENABLE = 16,
	SETFEATURES_SATA_DISABLE = 144,
	SATA_FPDMA_OFFSET = 1,
	SATA_FPDMA_AA = 2,
	SATA_DIPM = 3,
	SATA_FPDMA_IN_ORDER = 4,
	SATA_AN = 5,
	SATA_SSP = 6,
	SATA_DEVSLP = 9,
	SETFEATURE_SENSE_DATA = 195,
	ATA_SET_MAX_ADDR = 0,
	ATA_SET_MAX_PASSWD = 1,
	ATA_SET_MAX_LOCK = 2,
	ATA_SET_MAX_UNLOCK = 3,
	ATA_SET_MAX_FREEZE_LOCK = 4,
	ATA_SET_MAX_PASSWD_DMA = 5,
	ATA_SET_MAX_UNLOCK_DMA = 6,
	ATA_DCO_RESTORE = 192,
	ATA_DCO_FREEZE_LOCK = 193,
	ATA_DCO_IDENTIFY = 194,
	ATA_DCO_SET = 195,
	ATA_SMART_ENABLE = 216,
	ATA_SMART_READ_VALUES = 208,
	ATA_SMART_READ_THRESHOLDS = 209,
	ATA_DSM_TRIM = 1,
	ATA_SMART_LBAM_PASS = 79,
	ATA_SMART_LBAH_PASS = 194,
	ATAPI_PKT_DMA = 1,
	ATAPI_DMADIR = 4,
	ATAPI_CDB_LEN = 16,
	SATA_PMP_MAX_PORTS = 15,
	SATA_PMP_CTRL_PORT = 15,
	SATA_PMP_GSCR_DWORDS = 128,
	SATA_PMP_GSCR_PROD_ID = 0,
	SATA_PMP_GSCR_REV = 1,
	SATA_PMP_GSCR_PORT_INFO = 2,
	SATA_PMP_GSCR_ERROR = 32,
	SATA_PMP_GSCR_ERROR_EN = 33,
	SATA_PMP_GSCR_FEAT = 64,
	SATA_PMP_GSCR_FEAT_EN = 96,
	SATA_PMP_PSCR_STATUS = 0,
	SATA_PMP_PSCR_ERROR = 1,
	SATA_PMP_PSCR_CONTROL = 2,
	SATA_PMP_FEAT_BIST = 1,
	SATA_PMP_FEAT_PMREQ = 2,
	SATA_PMP_FEAT_DYNSSC = 4,
	SATA_PMP_FEAT_NOTIFY = 8,
	ATA_CBL_NONE = 0,
	ATA_CBL_PATA40 = 1,
	ATA_CBL_PATA80 = 2,
	ATA_CBL_PATA40_SHORT = 3,
	ATA_CBL_PATA_UNK = 4,
	ATA_CBL_PATA_IGN = 5,
	ATA_CBL_SATA = 6,
	SCR_STATUS = 0,
	SCR_ERROR = 1,
	SCR_CONTROL = 2,
	SCR_ACTIVE = 3,
	SCR_NOTIFICATION = 4,
	SERR_DATA_RECOVERED = 1,
	SERR_COMM_RECOVERED = 2,
	SERR_DATA = 256,
	SERR_PERSISTENT = 512,
	SERR_PROTOCOL = 1024,
	SERR_INTERNAL = 2048,
	SERR_PHYRDY_CHG = 65536,
	SERR_PHY_INT_ERR = 131072,
	SERR_COMM_WAKE = 262144,
	SERR_10B_8B_ERR = 524288,
	SERR_DISPARITY = 1048576,
	SERR_CRC = 2097152,
	SERR_HANDSHAKE = 4194304,
	SERR_LINK_SEQ_ERR = 8388608,
	SERR_TRANS_ST_ERROR = 16777216,
	SERR_UNRECOG_FIS = 33554432,
	SERR_DEV_XCHG = 67108864,
};

enum ata_prot_flags {
	ATA_PROT_FLAG_PIO = 1,
	ATA_PROT_FLAG_DMA = 2,
	ATA_PROT_FLAG_NCQ = 4,
	ATA_PROT_FLAG_ATAPI = 8,
	ATA_PROT_UNKNOWN = 255,
	ATA_PROT_NODATA = 0,
	ATA_PROT_PIO = 1,
	ATA_PROT_DMA = 2,
	ATA_PROT_NCQ_NODATA = 4,
	ATA_PROT_NCQ = 6,
	ATAPI_PROT_NODATA = 8,
	ATAPI_PROT_PIO = 9,
	ATAPI_PROT_DMA = 10,
};

struct ata_bmdma_prd {
	__le32 addr;
	__le32 flags_len;
};

enum {
	ATA_MSG_DRV = 1,
	ATA_MSG_INFO = 2,
	ATA_MSG_PROBE = 4,
	ATA_MSG_WARN = 8,
	ATA_MSG_MALLOC = 16,
	ATA_MSG_CTL = 32,
	ATA_MSG_INTR = 64,
	ATA_MSG_ERR = 128,
};

enum {
	LIBATA_MAX_PRD = 128,
	LIBATA_DUMB_MAX_PRD = 64,
	ATA_DEF_QUEUE = 1,
	ATA_MAX_QUEUE = 32,
	ATA_TAG_INTERNAL = 32,
	ATA_SHORT_PAUSE = 16,
	ATAPI_MAX_DRAIN = 16384,
	ATA_ALL_DEVICES = 3,
	ATA_SHT_EMULATED = 1,
	ATA_SHT_THIS_ID = 4294967295,
	ATA_SHT_USE_CLUSTERING = 1,
	ATA_TFLAG_LBA48 = 1,
	ATA_TFLAG_ISADDR = 2,
	ATA_TFLAG_DEVICE = 4,
	ATA_TFLAG_WRITE = 8,
	ATA_TFLAG_LBA = 16,
	ATA_TFLAG_FUA = 32,
	ATA_TFLAG_POLLING = 64,
	ATA_DFLAG_LBA = 1,
	ATA_DFLAG_LBA48 = 2,
	ATA_DFLAG_CDB_INTR = 4,
	ATA_DFLAG_NCQ = 8,
	ATA_DFLAG_FLUSH_EXT = 16,
	ATA_DFLAG_ACPI_PENDING = 32,
	ATA_DFLAG_ACPI_FAILED = 64,
	ATA_DFLAG_AN = 128,
	ATA_DFLAG_TRUSTED = 256,
	ATA_DFLAG_DMADIR = 1024,
	ATA_DFLAG_CFG_MASK = 4095,
	ATA_DFLAG_PIO = 4096,
	ATA_DFLAG_NCQ_OFF = 8192,
	ATA_DFLAG_SLEEPING = 32768,
	ATA_DFLAG_DUBIOUS_XFER = 65536,
	ATA_DFLAG_NO_UNLOAD = 131072,
	ATA_DFLAG_UNLOCK_HPA = 262144,
	ATA_DFLAG_NCQ_SEND_RECV = 524288,
	ATA_DFLAG_NCQ_PRIO = 1048576,
	ATA_DFLAG_NCQ_PRIO_ENABLE = 2097152,
	ATA_DFLAG_INIT_MASK = 16777215,
	ATA_DFLAG_DETACH = 16777216,
	ATA_DFLAG_DETACHED = 33554432,
	ATA_DFLAG_DA = 67108864,
	ATA_DFLAG_DEVSLP = 134217728,
	ATA_DFLAG_ACPI_DISABLED = 268435456,
	ATA_DFLAG_D_SENSE = 536870912,
	ATA_DFLAG_ZAC = 1073741824,
	ATA_DEV_UNKNOWN = 0,
	ATA_DEV_ATA = 1,
	ATA_DEV_ATA_UNSUP = 2,
	ATA_DEV_ATAPI = 3,
	ATA_DEV_ATAPI_UNSUP = 4,
	ATA_DEV_PMP = 5,
	ATA_DEV_PMP_UNSUP = 6,
	ATA_DEV_SEMB = 7,
	ATA_DEV_SEMB_UNSUP = 8,
	ATA_DEV_ZAC = 9,
	ATA_DEV_ZAC_UNSUP = 10,
	ATA_DEV_NONE = 11,
	ATA_LFLAG_NO_HRST = 2,
	ATA_LFLAG_NO_SRST = 4,
	ATA_LFLAG_ASSUME_ATA = 8,
	ATA_LFLAG_ASSUME_SEMB = 16,
	ATA_LFLAG_ASSUME_CLASS = 24,
	ATA_LFLAG_NO_RETRY = 32,
	ATA_LFLAG_DISABLED = 64,
	ATA_LFLAG_SW_ACTIVITY = 128,
	ATA_LFLAG_NO_LPM = 256,
	ATA_LFLAG_RST_ONCE = 512,
	ATA_LFLAG_CHANGED = 1024,
	ATA_LFLAG_NO_DB_DELAY = 2048,
	ATA_FLAG_SLAVE_POSS = 1,
	ATA_FLAG_SATA = 2,
	ATA_FLAG_NO_LPM = 4,
	ATA_FLAG_NO_LOG_PAGE = 32,
	ATA_FLAG_NO_ATAPI = 64,
	ATA_FLAG_PIO_DMA = 128,
	ATA_FLAG_PIO_LBA48 = 256,
	ATA_FLAG_PIO_POLLING = 512,
	ATA_FLAG_NCQ = 1024,
	ATA_FLAG_NO_POWEROFF_SPINDOWN = 2048,
	ATA_FLAG_NO_HIBERNATE_SPINDOWN = 4096,
	ATA_FLAG_DEBUGMSG = 8192,
	ATA_FLAG_FPDMA_AA = 16384,
	ATA_FLAG_IGN_SIMPLEX = 32768,
	ATA_FLAG_NO_IORDY = 65536,
	ATA_FLAG_ACPI_SATA = 131072,
	ATA_FLAG_AN = 262144,
	ATA_FLAG_PMP = 524288,
	ATA_FLAG_FPDMA_AUX = 1048576,
	ATA_FLAG_EM = 2097152,
	ATA_FLAG_SW_ACTIVITY = 4194304,
	ATA_FLAG_NO_DIPM = 8388608,
	ATA_FLAG_SAS_HOST = 16777216,
	ATA_PFLAG_EH_PENDING = 1,
	ATA_PFLAG_EH_IN_PROGRESS = 2,
	ATA_PFLAG_FROZEN = 4,
	ATA_PFLAG_RECOVERED = 8,
	ATA_PFLAG_LOADING = 16,
	ATA_PFLAG_SCSI_HOTPLUG = 64,
	ATA_PFLAG_INITIALIZING = 128,
	ATA_PFLAG_RESETTING = 256,
	ATA_PFLAG_UNLOADING = 512,
	ATA_PFLAG_UNLOADED = 1024,
	ATA_PFLAG_SUSPENDED = 131072,
	ATA_PFLAG_PM_PENDING = 262144,
	ATA_PFLAG_INIT_GTM_VALID = 524288,
	ATA_PFLAG_PIO32 = 1048576,
	ATA_PFLAG_PIO32CHANGE = 2097152,
	ATA_PFLAG_EXTERNAL = 4194304,
	ATA_QCFLAG_ACTIVE = 1,
	ATA_QCFLAG_DMAMAP = 2,
	ATA_QCFLAG_IO = 8,
	ATA_QCFLAG_RESULT_TF = 16,
	ATA_QCFLAG_CLEAR_EXCL = 32,
	ATA_QCFLAG_QUIET = 64,
	ATA_QCFLAG_RETRY = 128,
	ATA_QCFLAG_FAILED = 65536,
	ATA_QCFLAG_SENSE_VALID = 131072,
	ATA_QCFLAG_EH_SCHEDULED = 262144,
	ATA_HOST_SIMPLEX = 1,
	ATA_HOST_STARTED = 2,
	ATA_HOST_PARALLEL_SCAN = 4,
	ATA_HOST_IGNORE_ATA = 8,
	ATA_TMOUT_BOOT = 30000,
	ATA_TMOUT_BOOT_QUICK = 7000,
	ATA_TMOUT_INTERNAL_QUICK = 5000,
	ATA_TMOUT_MAX_PARK = 30000,
	ATA_TMOUT_FF_WAIT_LONG = 2000,
	ATA_TMOUT_FF_WAIT = 800,
	ATA_WAIT_AFTER_RESET = 150,
	ATA_TMOUT_PMP_SRST_WAIT = 5000,
	ATA_TMOUT_SPURIOUS_PHY = 10000,
	BUS_UNKNOWN = 0,
	BUS_DMA = 1,
	BUS_IDLE = 2,
	BUS_NOINTR = 3,
	BUS_NODATA = 4,
	BUS_TIMER = 5,
	BUS_PIO = 6,
	BUS_EDD = 7,
	BUS_IDENTIFY = 8,
	BUS_PACKET = 9,
	PORT_UNKNOWN = 0,
	PORT_ENABLED = 1,
	PORT_DISABLED = 2,
	ATA_NR_PIO_MODES = 7,
	ATA_NR_MWDMA_MODES = 5,
	ATA_NR_UDMA_MODES = 8,
	ATA_SHIFT_PIO = 0,
	ATA_SHIFT_MWDMA = 7,
	ATA_SHIFT_UDMA = 12,
	ATA_SHIFT_PRIO = 6,
	ATA_PRIO_HIGH = 2,
	ATA_DMA_PAD_SZ = 4,
	ATA_ERING_SIZE = 32,
	ATA_DEFER_LINK = 1,
	ATA_DEFER_PORT = 2,
	ATA_EH_DESC_LEN = 80,
	ATA_EH_REVALIDATE = 1,
	ATA_EH_SOFTRESET = 2,
	ATA_EH_HARDRESET = 4,
	ATA_EH_RESET = 6,
	ATA_EH_ENABLE_LINK = 8,
	ATA_EH_PARK = 32,
	ATA_EH_PERDEV_MASK = 33,
	ATA_EH_ALL_ACTIONS = 15,
	ATA_EHI_HOTPLUGGED = 1,
	ATA_EHI_NO_AUTOPSY = 4,
	ATA_EHI_QUIET = 8,
	ATA_EHI_NO_RECOVERY = 16,
	ATA_EHI_DID_SOFTRESET = 65536,
	ATA_EHI_DID_HARDRESET = 131072,
	ATA_EHI_PRINTINFO = 262144,
	ATA_EHI_SETMODE = 524288,
	ATA_EHI_POST_SETMODE = 1048576,
	ATA_EHI_DID_RESET = 196608,
	ATA_EHI_TO_SLAVE_MASK = 12,
	ATA_EH_MAX_TRIES = 5,
	ATA_LINK_RESUME_TRIES = 5,
	ATA_PROBE_MAX_TRIES = 3,
	ATA_EH_DEV_TRIES = 3,
	ATA_EH_PMP_TRIES = 5,
	ATA_EH_PMP_LINK_TRIES = 3,
	SATA_PMP_RW_TIMEOUT = 3000,
	ATA_EH_CMD_TIMEOUT_TABLE_SIZE = 6,
	ATA_HORKAGE_DIAGNOSTIC = 1,
	ATA_HORKAGE_NODMA = 2,
	ATA_HORKAGE_NONCQ = 4,
	ATA_HORKAGE_MAX_SEC_128 = 8,
	ATA_HORKAGE_BROKEN_HPA = 16,
	ATA_HORKAGE_DISABLE = 32,
	ATA_HORKAGE_HPA_SIZE = 64,
	ATA_HORKAGE_IVB = 256,
	ATA_HORKAGE_STUCK_ERR = 512,
	ATA_HORKAGE_BRIDGE_OK = 1024,
	ATA_HORKAGE_ATAPI_MOD16_DMA = 2048,
	ATA_HORKAGE_FIRMWARE_WARN = 4096,
	ATA_HORKAGE_1_5_GBPS = 8192,
	ATA_HORKAGE_NOSETXFER = 16384,
	ATA_HORKAGE_BROKEN_FPDMA_AA = 32768,
	ATA_HORKAGE_DUMP_ID = 65536,
	ATA_HORKAGE_MAX_SEC_LBA48 = 131072,
	ATA_HORKAGE_ATAPI_DMADIR = 262144,
	ATA_HORKAGE_NO_NCQ_TRIM = 524288,
	ATA_HORKAGE_NOLPM = 1048576,
	ATA_HORKAGE_WD_BROKEN_LPM = 2097152,
	ATA_HORKAGE_ZERO_AFTER_TRIM = 4194304,
	ATA_HORKAGE_NO_DMA_LOG = 8388608,
	ATA_HORKAGE_NOTRIM = 16777216,
	ATA_HORKAGE_MAX_SEC_1024 = 33554432,
	ATA_DMA_MASK_ATA = 1,
	ATA_DMA_MASK_ATAPI = 2,
	ATA_DMA_MASK_CFA = 4,
	ATAPI_READ = 0,
	ATAPI_WRITE = 1,
	ATAPI_READ_CD = 2,
	ATAPI_PASS_THRU = 3,
	ATAPI_MISC = 4,
	ATA_TIMING_SETUP = 1,
	ATA_TIMING_ACT8B = 2,
	ATA_TIMING_REC8B = 4,
	ATA_TIMING_CYC8B = 8,
	ATA_TIMING_8BIT = 14,
	ATA_TIMING_ACTIVE = 16,
	ATA_TIMING_RECOVER = 32,
	ATA_TIMING_DMACK_HOLD = 64,
	ATA_TIMING_CYCLE = 128,
	ATA_TIMING_UDMA = 256,
	ATA_TIMING_ALL = 511,
	ATA_ACPI_FILTER_SETXFER = 1,
	ATA_ACPI_FILTER_LOCK = 2,
	ATA_ACPI_FILTER_DIPM = 4,
	ATA_ACPI_FILTER_FPDMA_OFFSET = 8,
	ATA_ACPI_FILTER_FPDMA_AA = 16,
	ATA_ACPI_FILTER_DEFAULT = 7,
};

enum ata_xfer_mask {
	ATA_MASK_PIO = 127,
	ATA_MASK_MWDMA = 3968,
	ATA_MASK_UDMA = 1044480,
};

enum ata_completion_errors {
	AC_ERR_DEV = 1,
	AC_ERR_HSM = 2,
	AC_ERR_TIMEOUT = 4,
	AC_ERR_MEDIA = 8,
	AC_ERR_ATA_BUS = 16,
	AC_ERR_HOST_BUS = 32,
	AC_ERR_SYSTEM = 64,
	AC_ERR_INVALID = 128,
	AC_ERR_OTHER = 256,
	AC_ERR_NODEV_HINT = 512,
	AC_ERR_NCQ = 1024,
};

enum ata_lpm_policy {
	ATA_LPM_UNKNOWN = 0,
	ATA_LPM_MAX_POWER = 1,
	ATA_LPM_MED_POWER = 2,
	ATA_LPM_MED_POWER_WITH_DIPM = 3,
	ATA_LPM_MIN_POWER = 4,
};

struct ata_queued_cmd;

typedef void (*ata_qc_cb_t)(struct ata_queued_cmd *);

struct ata_taskfile {
	long unsigned int flags;
	u8 protocol;
	u8 ctl;
	u8 hob_feature;
	u8 hob_nsect;
	u8 hob_lbal;
	u8 hob_lbam;
	u8 hob_lbah;
	u8 feature;
	u8 nsect;
	u8 lbal;
	u8 lbam;
	u8 lbah;
	u8 device;
	u8 command;
	u32 auxiliary;
};

struct ata_port;

struct ata_device;

struct ata_queued_cmd {
	struct ata_port *ap;
	struct ata_device *dev;
	struct scsi_cmnd___8 *scsicmd;
	void (*scsidone)(struct scsi_cmnd___8 *);
	struct ata_taskfile tf;
	u8 cdb[16];
	long unsigned int flags;
	unsigned int tag;
	unsigned int hw_tag;
	unsigned int n_elem;
	unsigned int orig_n_elem;
	int dma_dir;
	unsigned int sect_size;
	unsigned int nbytes;
	unsigned int extrabytes;
	unsigned int curbytes;
	struct scatterlist sgent;
	struct scatterlist *sg;
	struct scatterlist *cursg;
	unsigned int cursg_ofs;
	unsigned int err_mask;
	struct ata_taskfile result_tf;
	ata_qc_cb_t complete_fn;
	void *private_data;
	void *lldd_task;
};

struct ata_link;

typedef int (*ata_prereset_fn_t)(struct ata_link *, long unsigned int);

struct ata_eh_info {
	struct ata_device *dev;
	u32 serror;
	unsigned int err_mask;
	unsigned int action;
	unsigned int dev_action[2];
	unsigned int flags;
	unsigned int probe_mask;
	char desc[80];
	int desc_len;
};

struct ata_eh_context {
	struct ata_eh_info i;
	int tries[2];
	int cmd_timeout_idx[12];
	unsigned int classes[2];
	unsigned int did_probe_mask;
	unsigned int unloaded_mask;
	unsigned int saved_ncq_enabled;
	u8 saved_xfer_mode[2];
	long unsigned int last_reset;
};

struct ata_ering_entry {
	unsigned int eflags;
	unsigned int err_mask;
	u64 timestamp;
};

struct ata_ering {
	int cursor;
	struct ata_ering_entry ring[32];
};

struct ata_device {
	struct ata_link *link;
	unsigned int devno;
	unsigned int horkage;
	long unsigned int flags;
	struct scsi_device___13 *sdev;
	void *private_data;
	union acpi_object *gtf_cache;
	unsigned int gtf_filter;
	struct device___329 tdev;
	u64 n_sectors;
	u64 n_native_sectors;
	unsigned int class;
	long unsigned int unpark_deadline;
	u8 pio_mode;
	u8 dma_mode;
	u8 xfer_mode;
	unsigned int xfer_shift;
	unsigned int multi_count;
	unsigned int max_sectors;
	unsigned int cdb_len;
	long unsigned int pio_mask;
	long unsigned int mwdma_mask;
	long unsigned int udma_mask;
	u16 cylinders;
	u16 heads;
	u16 sectors;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	union {
		u16 id[256];
		u32 gscr[128];
	};
	u8 devslp_timing[8];
	u8 ncq_send_recv_cmds[20];
	u8 ncq_non_data_cmds[64];
	u32 zac_zoned_cap;
	u32 zac_zones_optimal_open;
	u32 zac_zones_optimal_nonseq;
	u32 zac_zones_max_open;
	int spdn_cnt;
	struct ata_ering ering;
	long: 64;
};

struct ata_link {
	struct ata_port *ap;
	int pmp;
	struct device___329 tdev;
	unsigned int active_tag;
	u32 sactive;
	unsigned int flags;
	u32 saved_scontrol;
	unsigned int hw_sata_spd_limit;
	unsigned int sata_spd_limit;
	unsigned int sata_spd;
	enum ata_lpm_policy lpm_policy;
	struct ata_eh_info eh_info;
	struct ata_eh_context eh_context;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ata_device device[2];
	long unsigned int last_lpm_change;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef int (*ata_reset_fn_t)(struct ata_link *, unsigned int *, long unsigned int);

typedef void (*ata_postreset_fn_t)(struct ata_link *, unsigned int *);

enum sw_activity {
	OFF = 0,
	BLINK_ON = 1,
	BLINK_OFF = 2,
};

struct ata_ioports {
	void *cmd_addr;
	void *data_addr;
	void *error_addr;
	void *feature_addr;
	void *nsect_addr;
	void *lbal_addr;
	void *lbam_addr;
	void *lbah_addr;
	void *device_addr;
	void *status_addr;
	void *command_addr;
	void *altstatus_addr;
	void *ctl_addr;
	void *bmdma_addr;
	void *scr_addr;
};

struct ata_port_operations;

struct ata_host {
	spinlock_t lock;
	struct device___329 *dev;
	void * const *iomap;
	unsigned int n_ports;
	unsigned int n_tags;
	void *private_data;
	struct ata_port_operations *ops;
	long unsigned int flags;
	struct kref kref;
	struct mutex eh_mutex;
	struct task_struct___363 *eh_owner;
	struct ata_port *simplex_claimed;
	struct ata_port *ports[0];
};

struct ata_port_operations {
	int (*qc_defer)(struct ata_queued_cmd *);
	int (*check_atapi_dma)(struct ata_queued_cmd *);
	void (*qc_prep)(struct ata_queued_cmd *);
	unsigned int (*qc_issue)(struct ata_queued_cmd *);
	bool (*qc_fill_rtf)(struct ata_queued_cmd *);
	int (*cable_detect)(struct ata_port *);
	long unsigned int (*mode_filter)(struct ata_device *, long unsigned int);
	void (*set_piomode)(struct ata_port *, struct ata_device *);
	void (*set_dmamode)(struct ata_port *, struct ata_device *);
	int (*set_mode)(struct ata_link *, struct ata_device **);
	unsigned int (*read_id)(struct ata_device *, struct ata_taskfile *, u16 *);
	void (*dev_config)(struct ata_device *);
	void (*freeze)(struct ata_port *);
	void (*thaw)(struct ata_port *);
	ata_prereset_fn_t prereset;
	ata_reset_fn_t softreset;
	ata_reset_fn_t hardreset;
	ata_postreset_fn_t postreset;
	ata_prereset_fn_t pmp_prereset;
	ata_reset_fn_t pmp_softreset;
	ata_reset_fn_t pmp_hardreset;
	ata_postreset_fn_t pmp_postreset;
	void (*error_handler)(struct ata_port *);
	void (*lost_interrupt)(struct ata_port *);
	void (*post_internal_cmd)(struct ata_queued_cmd *);
	void (*sched_eh)(struct ata_port *);
	void (*end_eh)(struct ata_port *);
	int (*scr_read)(struct ata_link *, unsigned int, u32 *);
	int (*scr_write)(struct ata_link *, unsigned int, u32);
	void (*pmp_attach)(struct ata_port *);
	void (*pmp_detach)(struct ata_port *);
	int (*set_lpm)(struct ata_link *, enum ata_lpm_policy, unsigned int);
	int (*port_suspend)(struct ata_port *, pm_message_t);
	int (*port_resume)(struct ata_port *);
	int (*port_start)(struct ata_port *);
	void (*port_stop)(struct ata_port *);
	void (*host_stop)(struct ata_host *);
	void (*sff_dev_select)(struct ata_port *, unsigned int);
	void (*sff_set_devctl)(struct ata_port *, u8);
	u8 (*sff_check_status)(struct ata_port *);
	u8 (*sff_check_altstatus)(struct ata_port *);
	void (*sff_tf_load)(struct ata_port *, const struct ata_taskfile *);
	void (*sff_tf_read)(struct ata_port *, struct ata_taskfile *);
	void (*sff_exec_command)(struct ata_port *, const struct ata_taskfile *);
	unsigned int (*sff_data_xfer)(struct ata_queued_cmd *, unsigned char *, unsigned int, int);
	void (*sff_irq_on)(struct ata_port *);
	bool (*sff_irq_check)(struct ata_port *);
	void (*sff_irq_clear)(struct ata_port *);
	void (*sff_drain_fifo)(struct ata_queued_cmd *);
	void (*bmdma_setup)(struct ata_queued_cmd *);
	void (*bmdma_start)(struct ata_queued_cmd *);
	void (*bmdma_stop)(struct ata_queued_cmd *);
	u8 (*bmdma_status)(struct ata_port *);
	ssize_t (*em_show)(struct ata_port *, char *);
	ssize_t (*em_store)(struct ata_port *, const char *, size_t);
	ssize_t (*sw_activity_show)(struct ata_device *, char *);
	ssize_t (*sw_activity_store)(struct ata_device *, enum sw_activity);
	ssize_t (*transmit_led_message)(struct ata_port *, u32, ssize_t);
	void (*phy_reset)(struct ata_port *);
	void (*eng_timeout)(struct ata_port *);
	const struct ata_port_operations *inherits;
};

struct ata_port_stats {
	long unsigned int unhandled_irq;
	long unsigned int idle_irq;
	long unsigned int rw_reqbuf;
};

struct ata_acpi_drive {
	u32 pio;
	u32 dma;
};

struct ata_acpi_gtm {
	struct ata_acpi_drive drive[2];
	u32 flags;
};

struct ata_port {
	struct Scsi_Host___8 *scsi_host;
	struct ata_port_operations *ops;
	spinlock_t *lock;
	long unsigned int flags;
	unsigned int pflags;
	unsigned int print_id;
	unsigned int local_port_no;
	unsigned int port_no;
	struct ata_ioports ioaddr;
	u8 ctl;
	u8 last_ctl;
	struct ata_link *sff_pio_task_link;
	struct delayed_work sff_pio_task;
	struct ata_bmdma_prd *bmdma_prd;
	dma_addr_t bmdma_prd_dma;
	unsigned int pio_mask;
	unsigned int mwdma_mask;
	unsigned int udma_mask;
	unsigned int cbl;
	struct ata_queued_cmd qcmd[33];
	long unsigned int sas_tag_allocated;
	u64 qc_active;
	int nr_active_links;
	unsigned int sas_last_tag;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ata_link link;
	struct ata_link *slave_link;
	int nr_pmp_links;
	struct ata_link *pmp_link;
	struct ata_link *excl_link;
	struct ata_port_stats stats;
	struct ata_host *host;
	struct device___329 *dev;
	struct device___329 tdev;
	struct mutex scsi_scan_mutex;
	struct delayed_work hotplug_task;
	struct work_struct scsi_rescan_task;
	unsigned int hsm_task_state;
	u32 msg_enable;
	struct list_head eh_done_q;
	wait_queue_head_t eh_wait_q;
	int eh_tries;
	struct completion park_req_pending;
	pm_message_t pm_mesg;
	enum ata_lpm_policy target_lpm_policy;
	struct timer_list fastdrain_timer;
	long unsigned int fastdrain_cnt;
	int em_message_type;
	void *private_data;
	struct ata_acpi_gtm __acpi_init_gtm;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sector_buf[512];
};

struct ata_port_info {
	long unsigned int flags;
	long unsigned int link_flags;
	long unsigned int pio_mask;
	long unsigned int mwdma_mask;
	long unsigned int udma_mask;
	struct ata_port_operations *port_ops;
	void *private_data;
};

struct ata_timing {
	short unsigned int mode;
	short unsigned int setup;
	short unsigned int act8b;
	short unsigned int rec8b;
	short unsigned int cyc8b;
	short unsigned int active;
	short unsigned int recover;
	short unsigned int dmack_hold;
	short unsigned int cycle;
	short unsigned int udma;
};

struct pci_bits {
	unsigned int reg;
	unsigned int width;
	long unsigned int mask;
	long unsigned int val;
};

enum ata_link_iter_mode {
	ATA_LITER_EDGE = 0,
	ATA_LITER_HOST_FIRST = 1,
	ATA_LITER_PMP_FIRST = 2,
};

enum ata_dev_iter_mode {
	ATA_DITER_ENABLED = 0,
	ATA_DITER_ENABLED_REVERSE = 1,
	ATA_DITER_ALL = 2,
	ATA_DITER_ALL_REVERSE = 3,
};

struct platform_device___19 {
	const char *name;
	int id;
	bool id_auto;
	struct device___329 dev;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct perf_cpu_context___141;

struct pmu___141 {
	struct list_head entry;
	struct module___293 *module;
	struct device___329 *dev;
	const struct attribute_group___326 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___141 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___141 *);
	void (*pmu_disable)(struct pmu___141 *);
	int (*event_init)(struct perf_event___141 *);
	void (*event_mapped)(struct perf_event___141 *, struct mm_struct___362 *);
	void (*event_unmapped)(struct perf_event___141 *, struct mm_struct___362 *);
	int (*add)(struct perf_event___141 *, int);
	void (*del)(struct perf_event___141 *, int);
	void (*start)(struct perf_event___141 *, int);
	void (*stop)(struct perf_event___141 *, int);
	void (*read)(struct perf_event___141 *);
	void (*start_txn)(struct pmu___141 *, unsigned int);
	int (*commit_txn)(struct pmu___141 *);
	void (*cancel_txn)(struct pmu___141 *);
	int (*event_idx)(struct perf_event___141 *);
	void (*sched_task)(struct perf_event_context___141 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___141 *);
	int (*filter_match)(struct perf_event___141 *);
	int (*check_period)(struct perf_event___141 *, u64);
};

struct perf_cpu_context___141 {
	struct perf_event_context___141 ctx;
	struct perf_event_context___141 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___141 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___141 {
	struct cgroup_subsys_state___230 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___134 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___134 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___134 *);
	struct list_head * (*get_fields)(struct trace_event_call___134 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___134 *);
};

struct trace_event_file___53;

struct trace_event_buffer___45 {
	struct ring_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___53 *trace_file;
	void *entry;
	long unsigned int flags;
	int pc;
};

struct trace_event_file___53 {
	struct list_head list;
	struct trace_event_call___134 *event_call;
	struct event_filter *filter;
	struct dentry___361 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_ata_qc_issue {
	struct trace_entry ent;
	unsigned int ata_port;
	unsigned int ata_dev;
	unsigned int tag;
	unsigned char cmd;
	unsigned char dev;
	unsigned char lbal;
	unsigned char lbam;
	unsigned char lbah;
	unsigned char nsect;
	unsigned char feature;
	unsigned char hob_lbal;
	unsigned char hob_lbam;
	unsigned char hob_lbah;
	unsigned char hob_nsect;
	unsigned char hob_feature;
	unsigned char ctl;
	unsigned char proto;
	long unsigned int flags;
	char __data[0];
};

struct trace_event_raw_ata_qc_complete_template {
	struct trace_entry ent;
	unsigned int ata_port;
	unsigned int ata_dev;
	unsigned int tag;
	unsigned char status;
	unsigned char dev;
	unsigned char lbal;
	unsigned char lbam;
	unsigned char lbah;
	unsigned char nsect;
	unsigned char error;
	unsigned char hob_lbal;
	unsigned char hob_lbam;
	unsigned char hob_lbah;
	unsigned char hob_nsect;
	unsigned char hob_feature;
	unsigned char ctl;
	long unsigned int flags;
	char __data[0];
};

struct trace_event_raw_ata_eh_link_autopsy {
	struct trace_entry ent;
	unsigned int ata_port;
	unsigned int ata_dev;
	unsigned int eh_action;
	unsigned int eh_err_mask;
	char __data[0];
};

struct trace_event_raw_ata_eh_link_autopsy_qc {
	struct trace_entry ent;
	unsigned int ata_port;
	unsigned int ata_dev;
	unsigned int tag;
	unsigned int qc_flags;
	unsigned int eh_err_mask;
	char __data[0];
};

struct trace_event_data_offsets_ata_qc_issue {};

struct trace_event_data_offsets_ata_qc_complete_template {};

struct trace_event_data_offsets_ata_eh_link_autopsy {};

struct trace_event_data_offsets_ata_eh_link_autopsy_qc {};

enum {
	ATA_READID_POSTRESET = 1,
	ATA_DNXFER_PIO = 0,
	ATA_DNXFER_DMA = 1,
	ATA_DNXFER_40C = 2,
	ATA_DNXFER_FORCE_PIO = 3,
	ATA_DNXFER_FORCE_PIO0 = 4,
	ATA_DNXFER_QUIET = 2147483648,
};

struct ata_force_param {
	const char *name;
	unsigned int cbl;
	int spd_limit;
	long unsigned int xfer_mask;
	unsigned int horkage_on;
	unsigned int horkage_off;
	unsigned int lflags;
};

struct ata_force_ent {
	int port;
	int device;
	struct ata_force_param param;
};

struct ata_xfer_ent {
	int shift;
	int bits;
	u8 base;
};

struct ata_blacklist_entry {
	const char *model_num;
	const char *model_rev;
	long unsigned int horkage;
};

struct module___294;

struct file___363;

struct kiocb___363;

struct poll_table_struct___216;

struct vm_area_struct___364;

struct inode___363;

struct file_lock___363;

struct page___364;

struct seq_file___307;

struct file_operations___363 {
	struct module___294 *owner;
	loff_t (*llseek)(struct file___363 *, loff_t, int);
	ssize_t (*read)(struct file___363 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___363 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___363 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___363 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___363 *, bool);
	int (*iterate)(struct file___363 *, struct dir_context *);
	int (*iterate_shared)(struct file___363 *, struct dir_context *);
	__poll_t (*poll)(struct file___363 *, struct poll_table_struct___216 *);
	long int (*unlocked_ioctl)(struct file___363 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___363 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___363 *, struct vm_area_struct___364 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___363 *, struct file___363 *);
	int (*flush)(struct file___363 *, fl_owner_t);
	int (*release)(struct inode___363 *, struct file___363 *);
	int (*fsync)(struct file___363 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___363 *, int);
	int (*lock)(struct file___363 *, int, struct file_lock___363 *);
	ssize_t (*sendpage)(struct file___363 *, struct page___364 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___363 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___363 *, int, struct file_lock___363 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___363 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___363 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___363 *, long int, struct file_lock___363 **, void **);
	long int (*fallocate)(struct file___363 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___307 *, struct file___363 *);
	ssize_t (*copy_file_range)(struct file___363 *, loff_t, struct file___363 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___363 *, loff_t, struct file___363 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___363 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___363 {
	u64 seqnum;
	struct vm_area_struct___364 *vmas[4];
};

struct page_frag___363 {
	struct page___364 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___363;

struct mem_cgroup___133;

struct cred___334;

struct nsproxy___276;

struct bio_list___180;

struct backing_dev_info___180;

struct io_context___100;

struct css_set___231;

struct request_queue___96;

struct vm_struct___269;

struct task_struct___364 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___364 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___363 *mm;
	struct mm_struct___363 *active_mm;
	struct vmacache___363 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___364 *real_parent;
	struct task_struct___364 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___364 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___133 *active_memcg;
	long int rh_reserved2;
	struct pid___217 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___217 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___217 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___334 *ptracer_cred;
	const struct cred___334 *real_cred;
	const struct cred___334 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___276 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___364 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___180 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___180 *backing_dev_info;
	struct io_context___100 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___231 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___363 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___133 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___96 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___364 *oom_reaper_list;
	struct vm_struct___269 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___141 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___364 *pgtable_t___363;

struct address_space___362;

struct dev_pagemap___351;

struct page___364 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___362 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___364 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___363 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___363 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___351 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___133 *mem_cgroup;
};

struct pglist_data___363;

struct lruvec___363 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___363 *pgdat;
};

struct zone___363 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___363 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___363 {
	struct zone___363 *zone;
	int zone_idx;
};

struct zonelist___363 {
	struct zoneref___363 _zonerefs[25];
};

struct pglist_data___363 {
	struct zone___363 node_zones[3];
	struct zonelist___363 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___364 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___364 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___363 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___364 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___364 *owner;
};

struct secondary_data___364 {
	void *stack;
	struct task_struct___364 *task;
	long int status;
};

struct blocking_notifier_head___363 {
	struct rw_semaphore___364 rwsem;
	struct notifier_block *head;
};

struct cgroup___231;

struct cgroup_subsys___231;

struct cgroup_subsys_state___231 {
	struct cgroup___231 *cgroup;
	struct cgroup_subsys___231 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___231 *parent;
};

struct mem_cgroup_id___27 {
	int id;
	union {
		refcount_t ref;
		struct {
			atomic_t ref;
		} __UNIQUE_ID_rh_kabi_hide50;
		union {		};
	};
};

struct kernfs_node___357;

struct cgroup_file___231 {
	struct kernfs_node___357 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___133;

struct mem_cgroup___133 {
	struct cgroup_subsys_state___231 css;
	struct mem_cgroup_id___27 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___231 events_file;
	struct cgroup_file___231 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___364 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___133 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct key___334;

struct ucounts___246;

struct user_namespace___246 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___246 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___9 ns;
	long unsigned int flags;
	struct key___334 *persistent_keyring_register;
	struct rw_semaphore___364 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___246 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct user_struct___334 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___334 *uid_keyring;
	struct key___334 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___351;

struct vm_area_struct___364 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___364 *vm_next;
	struct vm_area_struct___364 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___363 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___351 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___363 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___363;

struct mm_struct___363 {
	struct {
		struct vm_area_struct___364 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___363 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___364 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___363 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___364 *owner;
		struct user_namespace___246 *user_ns;
		struct file___363 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___363 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___334 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___334 *session_keyring;
	struct key___334 *process_keyring;
	struct key___334 *thread_keyring;
	struct key___334 *request_key_auth;
	void *security;
	struct user_struct___334 *user;
	struct user_namespace___246 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___231;

struct nsproxy___276 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___231 *cgroup_ns;
};

struct bio___180;

struct bio_list___180 {
	struct bio___180 *head;
	struct bio___180 *tail;
};

struct bdi_writeback_congested___180;

struct bdi_writeback___180 {
	struct backing_dev_info___180 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___180 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___231 *memcg_css;
	struct cgroup_subsys_state___231 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___330;

struct dentry___362;

struct backing_dev_info___180 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___180 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___330 *dev;
	struct device___330 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___362 *debug_dir;
	struct dentry___362 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___100;

struct io_context___100 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___100 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___231 {
	struct cgroup_subsys_state___231 *subsys[13];
	refcount_t refcount;
	struct css_set___231 *dom_cset;
	struct cgroup___231 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___231 *mg_src_cgrp;
	struct cgroup___231 *mg_dst_cgrp;
	struct css_set___231 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

typedef blk_qc_t make_request_fn___96(struct request_queue___96 *, struct bio___180 *);

struct request___96;

typedef int dma_drain_needed_fn___96(struct request___96 *);

struct kset___349;

struct kobj_type___349;

struct kobject___350 {
	const char *name;
	struct list_head entry;
	struct kobject___350 *parent;
	struct kset___349 *kset;
	struct kobj_type___349 *ktype;
	struct kernfs_node___357 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___96;

struct bsg_class_device___96 {
	struct device___330 *class_dev;
	int minor;
	struct request_queue___96 *queue;
	const struct bsg_ops___96 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___180 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___180 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___96;

struct blk_mq_ops___33;

struct blk_mq_hw_ctx___33;

struct blk_mq_tag_set___33;

struct request_queue___96 {
	struct list_head queue_head;
	struct request___96 *last_merge;
	struct elevator_queue___96 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___96 *make_request_fn;
	dma_drain_needed_fn___96 *dma_drain_needed;
	const struct blk_mq_ops___33 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___33 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___180 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___350 kobj;
	struct kobject___350 *mq_kobj;
	struct blk_integrity integrity;
	struct device___330 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	struct bsg_class_device___96 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set___33 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___180 bio_split;
	struct dentry___362 *debugfs_dir;
	struct dentry___362 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___269 {
	struct vm_struct___269 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___364 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bio_vec___182 {
	struct page___364 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

typedef void bio_end_io_t___180(struct bio___180 *);

struct gendisk___100;

struct bio_integrity_payload___180;

struct bio___180 {
	struct bio___180 *bi_next;
	struct gendisk___100 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___180 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___180 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___182 *bi_io_vec;
	struct bio_set___180 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___182 bi_inline_vecs[0];
};

struct bio_integrity_payload___180 {
	struct bio___180 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___182 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___182 bip_inline_vecs[0];
};

struct dev_pm_info___330 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___5 *subsys_data;
	void (*set_latency_tolerance)(struct device___330 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___330;

struct bus_type___330;

struct device_driver___330;

struct dev_pm_domain___330;

struct dma_map_ops___118;

struct fwnode_handle___252;

struct class___330;

struct attribute_group___327;

struct device___330 {
	struct device___330 *parent;
	struct device_private *p;
	struct kobject___350 kobj;
	const char *init_name;
	const struct device_type___330 *type;
	struct mutex mutex;
	struct bus_type___330 *bus;
	struct device_driver___330 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___330 power;
	struct dev_pm_domain___330 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___118 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___252 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___330 *class;
	const struct attribute_group___327 **groups;
	void (*release)(struct device___330 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___100 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___330 __dev;
	struct kobject___350 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___100;

struct block_device_operations___97;

struct gendisk___100 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___100 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___100 *part_tbl;
	struct hd_struct___100 part0;
	const struct block_device_operations___97 *fops;
	struct request_queue___96 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___364 lookup_sem;
	struct kobject___350 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___350 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_ops___330;

struct device_type___330 {
	const char *name;
	const struct attribute_group___327 **groups;
	int (*uevent)(struct device___330 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___330 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___330 *);
	const struct dev_pm_ops___330 *pm;
};

struct class___330 {
	const char *name;
	struct module___294 *owner;
	const struct attribute_group___327 **class_groups;
	const struct attribute_group___327 **dev_groups;
	struct kobject___350 *dev_kobj;
	int (*dev_uevent)(struct device___330 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___330 *, umode_t *);
	void (*class_release)(struct class___330 *);
	void (*dev_release)(struct device___330 *);
	int (*shutdown_pre)(struct device___330 *);
	const struct kobj_ns_type_operations___28 *ns_type;
	const void * (*namespace)(struct device___330 *);
	const struct dev_pm_ops___330 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct kernfs_root___356;

struct kernfs_elem_dir___356 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___356 *root;
};

struct kernfs_syscall_ops___356;

struct kernfs_root___356 {
	struct kernfs_node___357 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___356 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___356 {
	struct kernfs_node___357 *target_kn;
};

struct kernfs_ops___356;

struct kernfs_elem_attr___356 {
	const struct kernfs_ops___356 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___357 *notify_next;
};

struct kernfs_node___357 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___357 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___356 dir;
		struct kernfs_elem_symlink___356 symlink;
		struct kernfs_elem_attr___356 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___356;

struct kernfs_ops___356 {
	int (*open)(struct kernfs_open_file___356 *);
	void (*release)(struct kernfs_open_file___356 *);
	int (*seq_show)(struct seq_file___307 *, void *);
	void * (*seq_start)(struct seq_file___307 *, loff_t *);
	void * (*seq_next)(struct seq_file___307 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___307 *, void *);
	ssize_t (*read)(struct kernfs_open_file___356 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___356 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___356 *, struct vm_area_struct___364 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___356 *, struct poll_table_struct___216 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___356 {
	int (*remount_fs)(struct kernfs_root___356 *, int *, char *);
	int (*show_options)(struct seq_file___307 *, struct kernfs_root___356 *);
	int (*mkdir)(struct kernfs_node___357 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___357 *);
	int (*rename)(struct kernfs_node___357 *, struct kernfs_node___357 *, const char *);
	int (*show_path)(struct seq_file___307 *, struct kernfs_node___357 *, struct kernfs_root___356 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___306;

struct seq_file___307 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___306 *op;
	int poll_event;
	const struct file___363 *file;
	void *private;
};

struct kernfs_open_file___356 {
	struct kernfs_node___357 *kn;
	struct file___363 *file;
	struct seq_file___307 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___351 *vm_ops;
};

struct path___363 {
	struct vfsmount *mnt;
	struct dentry___362 *dentry;
};

struct file___363 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___363 f_path;
	struct inode___363 *f_inode;
	const struct file_operations___363 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___217 f_owner;
	const struct cred___334 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___362 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___351;

struct vm_operations_struct___351 {
	void (*open)(struct vm_area_struct___364 *);
	void (*close)(struct vm_area_struct___364 *);
	int (*split)(struct vm_area_struct___364 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___364 *);
	vm_fault_t (*fault)(struct vm_fault___351 *);
	vm_fault_t (*huge_fault)(struct vm_fault___351 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___351 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___364 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___351 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___351 *);
	int (*access)(struct vm_area_struct___364 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___364 *);
	int (*set_policy)(struct vm_area_struct___364 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___364 *, long unsigned int);
	struct page___364 * (*find_special_page)(struct vm_area_struct___364 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___222)(struct file___363 *, wait_queue_head_t *, struct poll_table_struct___216 *);

struct poll_table_struct___216 {
	poll_queue_proc___222 _qproc;
	__poll_t _key;
};

struct bin_attribute___326;

struct attribute_group___327 {
	const char *name;
	umode_t (*is_visible)(struct kobject___350 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___350 *, struct bin_attribute___326 *, int);
	struct attribute **attrs;
	struct bin_attribute___326 **bin_attrs;
};

struct bin_attribute___326 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___363 *, struct kobject___350 *, struct bin_attribute___326 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___363 *, struct kobject___350 *, struct bin_attribute___326 *, char *, loff_t, size_t);
	int (*mmap)(struct file___363 *, struct kobject___350 *, struct bin_attribute___326 *, struct vm_area_struct___364 *);
};

struct sysfs_ops___349 {
	ssize_t (*show)(struct kobject___350 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___350 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___349;

struct kset___349 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___350 kobj;
	const struct kset_uevent_ops___349 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___349 {
	void (*release)(struct kobject___350 *);
	const struct sysfs_ops___349 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___28 * (*child_ns_type)(struct kobject___350 *);
	const void * (*namespace)(struct kobject___350 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___349 {
	int (* const filter)(struct kset___349 *, struct kobject___350 *);
	const char * (* const name)(struct kset___349 *, struct kobject___350 *);
	int (* const uevent)(struct kset___349 *, struct kobject___350 *, struct kobj_uevent_env *);
};

struct kobj_attribute___341 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___350 *, struct kobj_attribute___341 *, char *);
	ssize_t (*store)(struct kobject___350 *, struct kobj_attribute___341 *, const char *, size_t);
};

struct dev_pm_ops___330 {
	int (*prepare)(struct device___330 *);
	void (*complete)(struct device___330 *);
	int (*suspend)(struct device___330 *);
	int (*resume)(struct device___330 *);
	int (*freeze)(struct device___330 *);
	int (*thaw)(struct device___330 *);
	int (*poweroff)(struct device___330 *);
	int (*restore)(struct device___330 *);
	int (*suspend_late)(struct device___330 *);
	int (*resume_early)(struct device___330 *);
	int (*freeze_late)(struct device___330 *);
	int (*thaw_early)(struct device___330 *);
	int (*poweroff_late)(struct device___330 *);
	int (*restore_early)(struct device___330 *);
	int (*suspend_noirq)(struct device___330 *);
	int (*resume_noirq)(struct device___330 *);
	int (*freeze_noirq)(struct device___330 *);
	int (*thaw_noirq)(struct device___330 *);
	int (*poweroff_noirq)(struct device___330 *);
	int (*restore_noirq)(struct device___330 *);
	int (*runtime_suspend)(struct device___330 *);
	int (*runtime_resume)(struct device___330 *);
	int (*runtime_idle)(struct device___330 *);
};

struct dev_pm_domain___330 {
	struct dev_pm_ops___330 ops;
	void (*detach)(struct device___330 *, bool);
	int (*activate)(struct device___330 *);
	void (*sync)(struct device___330 *);
	void (*dismiss)(struct device___330 *);
};

struct bus_type___330 {
	const char *name;
	const char *dev_name;
	struct device___330 *dev_root;
	const struct attribute_group___327 **bus_groups;
	const struct attribute_group___327 **dev_groups;
	const struct attribute_group___327 **drv_groups;
	int (*match)(struct device___330 *, struct device_driver___330 *);
	int (*uevent)(struct device___330 *, struct kobj_uevent_env *);
	int (*probe)(struct device___330 *);
	int (*remove)(struct device___330 *);
	void (*shutdown)(struct device___330 *);
	int (*online)(struct device___330 *);
	int (*offline)(struct device___330 *);
	int (*suspend)(struct device___330 *, pm_message_t);
	int (*resume)(struct device___330 *);
	int (*num_vf)(struct device___330 *);
	int (*dma_configure)(struct device___330 *);
	const struct dev_pm_ops___330 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___330 {
	const char *name;
	struct bus_type___330 *bus;
	struct module___294 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___330 *);
	int (*remove)(struct device___330 *);
	void (*shutdown)(struct device___330 *);
	int (*suspend)(struct device___330 *, pm_message_t);
	int (*resume)(struct device___330 *);
	const struct attribute_group___327 **groups;
	const struct dev_pm_ops___330 *pm;
	void (*coredump)(struct device___330 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct module_kobject___291 {
	struct kobject___350 kobj;
	struct module___294 *mod;
	struct kobject___350 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___291 {
	struct module___294 *mod;
	struct latch_tree_node node;
};

struct module_layout___291 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___291 mtn;
};

struct module_attribute___291;

struct kernel_param___291;

struct module___294 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___291 mkobj;
	struct module_attribute___291 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___350 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___291 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___291 core_layout;
	struct module_layout___291 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide46;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide47;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct device_attribute___42 {
	struct attribute attr;
	ssize_t (*show)(struct device___330 *, struct device_attribute___42 *, char *);
	ssize_t (*store)(struct device___330 *, struct device_attribute___42 *, const char *, size_t);
};

struct dma_map_ops___118 {
	void * (*alloc)(struct device___330 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___330 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___330 *, struct vm_area_struct___364 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___330 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___330 *, struct page___364 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___330 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___330 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___330 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___330 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___330 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___330 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide43;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___330 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___330 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___330 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___330 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___330 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___330 *, u64);
	u64 (*get_required_mask)(struct device___330 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___252;

struct fwnode_handle___252 {
	struct fwnode_handle___252 *secondary;
	const struct fwnode_operations___252 *ops;
};

struct dentry_operations___362;

struct super_block___362;

struct dentry___362 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___362 *d_parent;
	struct qstr d_name;
	struct inode___363 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___362 *d_op;
	struct super_block___362 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___362;

struct address_space___362 {
	struct inode___363 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___364 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___362 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___362;

struct block_device___362;

struct cdev___82;

struct inode___363 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___362 *i_op;
	struct super_block___362 *i_sb;
	struct address_space___362 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___364 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___180 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___363 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___362 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___362 *i_bdev;
		struct cdev___82 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___362 {
	int (*d_revalidate)(struct dentry___362 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___362 *, unsigned int);
	int (*d_hash)(const struct dentry___362 *, struct qstr *);
	int (*d_compare)(const struct dentry___362 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___362 *);
	int (*d_init)(struct dentry___362 *);
	void (*d_release)(struct dentry___362 *);
	void (*d_prune)(struct dentry___362 *);
	void (*d_iput)(struct dentry___362 *, struct inode___363 *);
	char * (*d_dname)(struct dentry___362 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___363 *);
	int (*d_manage)(const struct path___363 *, bool);
	struct dentry___362 * (*d_real)(struct dentry___362 *, const struct inode___363 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___362;

struct mem_dqinfo___362 {
	struct quota_format_type___362 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___362;

struct quota_info___362 {
	unsigned int flags;
	struct rw_semaphore___364 dqio_sem;
	struct inode___363 *files[3];
	struct mem_dqinfo___362 info[3];
	const struct quota_format_ops___362 *ops[3];
};

struct rcuwait___362 {
	struct task_struct___364 *task;
};

struct percpu_rw_semaphore___362 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___364 rw_sem;
	struct rcuwait___362 writer;
	int readers_block;
};

struct sb_writers___362 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___362 rw_sem[3];
};

struct shrink_control___133;

struct shrinker___133 {
	long unsigned int (*count_objects)(struct shrinker___133 *, struct shrink_control___133 *);
	long unsigned int (*scan_objects)(struct shrinker___133 *, struct shrink_control___133 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___362;

struct super_operations___362;

struct dquot_operations___362;

struct quotactl_ops___362;

struct super_block___362 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___362 *s_type;
	const struct super_operations___362 *s_op;
	const struct dquot_operations___362 *dq_op;
	const struct quotactl_ops___362 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___362 *s_root;
	struct rw_semaphore___364 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___362 *s_bdev;
	struct backing_dev_info___180 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___362 s_dquot;
	struct sb_writers___362 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___362 *s_d_op;
	int cleancache_poolid;
	struct shrinker___133 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___246 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___133 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___133 *memcg;
};

typedef int (*dev_page_fault_t___351)(struct vm_area_struct___364 *, long unsigned int, const struct page___364 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___351)(struct page___364 *, void *);

struct dev_pagemap___351 {
	dev_page_fault_t___351 page_fault;
	dev_page_free_t___351 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___330 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___363 {
	struct task_struct___364 *task;
	struct core_thread___363 *next;
};

struct core_state___363 {
	atomic_t nr_threads;
	struct core_thread___363 dumper;
	struct completion startup;
};

struct vm_fault___351 {
	struct vm_area_struct___364 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___364 *cow_page;
	struct mem_cgroup___133 *memcg;
	struct page___364 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___363 prealloc_pte;
};

struct io_cq___100 {
	struct request_queue___96 *q;
	struct io_context___100 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___363 {
	struct file___363 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___363 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___362 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___363 *ia_file;
};

struct dquot___362 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___362 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___362 {
	int qf_fmt_id;
	const struct quota_format_ops___362 *qf_ops;
	struct module___294 *qf_owner;
	struct quota_format_type___362 *qf_next;
};

struct quota_format_ops___362 {
	int (*check_quota_file)(struct super_block___362 *, int);
	int (*read_file_info)(struct super_block___362 *, int);
	int (*write_file_info)(struct super_block___362 *, int);
	int (*free_file_info)(struct super_block___362 *, int);
	int (*read_dqblk)(struct dquot___362 *);
	int (*commit_dqblk)(struct dquot___362 *);
	int (*release_dqblk)(struct dquot___362 *);
	int (*get_next_id)(struct super_block___362 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___362 {
	int (*write_dquot)(struct dquot___362 *);
	struct dquot___362 * (*alloc_dquot)(struct super_block___362 *, int);
	void (*destroy_dquot)(struct dquot___362 *);
	int (*acquire_dquot)(struct dquot___362 *);
	int (*release_dquot)(struct dquot___362 *);
	int (*mark_dirty)(struct dquot___362 *);
	int (*write_info)(struct super_block___362 *, int);
	qsize_t * (*get_reserved_space)(struct inode___363 *);
	int (*get_projid)(struct inode___363 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___363 *, qsize_t *);
	int (*get_next_id)(struct super_block___362 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___362 {
	int (*quota_on)(struct super_block___362 *, int, int, const struct path___363 *);
	int (*quota_off)(struct super_block___362 *, int);
	int (*quota_enable)(struct super_block___362 *, unsigned int);
	int (*quota_disable)(struct super_block___362 *, unsigned int);
	int (*quota_sync)(struct super_block___362 *, int);
	int (*set_info)(struct super_block___362 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___362 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___362 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___362 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___362 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___362 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___150;

struct swap_info_struct___89;

struct address_space_operations___362 {
	int (*writepage)(struct page___364 *, struct writeback_control___150 *);
	int (*readpage)(struct file___363 *, struct page___364 *);
	int (*writepages)(struct address_space___362 *, struct writeback_control___150 *);
	int (*set_page_dirty)(struct page___364 *);
	int (*readpages)(struct file___363 *, struct address_space___362 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___363 *, struct address_space___362 *, loff_t, unsigned int, unsigned int, struct page___364 **, void **);
	int (*write_end)(struct file___363 *, struct address_space___362 *, loff_t, unsigned int, unsigned int, struct page___364 *, void *);
	sector_t (*bmap)(struct address_space___362 *, sector_t);
	void (*invalidatepage)(struct page___364 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___364 *, gfp_t);
	void (*freepage)(struct page___364 *);
	ssize_t (*direct_IO)(struct kiocb___363 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___362 *, struct page___364 *, struct page___364 *, enum migrate_mode);
	bool (*isolate_page)(struct page___364 *, isolate_mode_t);
	void (*putback_page)(struct page___364 *);
	int (*launder_page)(struct page___364 *);
	int (*is_partially_uptodate)(struct page___364 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___364 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___362 *, struct page___364 *);
	int (*swap_activate)(struct swap_info_struct___89 *, struct file___363 *, sector_t *);
	void (*swap_deactivate)(struct file___363 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___150 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___180 *wb;
	struct inode___363 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct swap_info_struct___89 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___362 *bdev;
	struct file___363 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___362 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___363 *bd_inode;
	struct super_block___362 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___362 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___100 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___100 *bd_disk;
	struct request_queue___96 *bd_queue;
	struct backing_dev_info___180 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___82 {
	struct kobject___350 kobj;
	struct module___294 *owner;
	const struct file_operations___363 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___362 {
	struct dentry___362 * (*lookup)(struct inode___363 *, struct dentry___362 *, unsigned int);
	const char * (*get_link)(struct dentry___362 *, struct inode___363 *, struct delayed_call *);
	int (*permission)(struct inode___363 *, int);
	struct posix_acl * (*get_acl)(struct inode___363 *, int);
	int (*readlink)(struct dentry___362 *, char *, int);
	int (*create)(struct inode___363 *, struct dentry___362 *, umode_t, bool);
	int (*link)(struct dentry___362 *, struct inode___363 *, struct dentry___362 *);
	int (*unlink)(struct inode___363 *, struct dentry___362 *);
	int (*symlink)(struct inode___363 *, struct dentry___362 *, const char *);
	int (*mkdir)(struct inode___363 *, struct dentry___362 *, umode_t);
	int (*rmdir)(struct inode___363 *, struct dentry___362 *);
	int (*mknod)(struct inode___363 *, struct dentry___362 *, umode_t, dev_t);
	int (*rename)(struct inode___363 *, struct dentry___362 *, struct inode___363 *, struct dentry___362 *, unsigned int);
	int (*setattr)(struct dentry___362 *, struct iattr___362 *);
	int (*getattr)(const struct path___363 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___362 *, char *, size_t);
	int (*fiemap)(struct inode___363 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___363 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___363 *, struct dentry___362 *, struct file___363 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___363 *, struct dentry___362 *, umode_t);
	int (*set_acl)(struct inode___363 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___362 {
	void (*fl_copy_lock)(struct file_lock___363 *, struct file_lock___363 *);
	void (*fl_release_private)(struct file_lock___363 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___362;

struct lock_manager_operations___362;

struct file_lock___363 {
	struct file_lock___363 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___363 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___362 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___362 *fl_ops;
	const struct lock_manager_operations___362 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___362 {
	int (*lm_compare_owner)(struct file_lock___363 *, struct file_lock___363 *);
	long unsigned int (*lm_owner_key)(struct file_lock___363 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___363 *);
	int (*lm_grant)(struct file_lock___363 *, int);
	bool (*lm_break)(struct file_lock___363 *);
	int (*lm_change)(struct file_lock___363 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___363 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___362 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___362 *fa_next;
	struct file___363 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___362 {
	const char *name;
	int fs_flags;
	struct dentry___362 * (*mount)(struct file_system_type___362 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___362 *);
	struct module___294 *owner;
	struct file_system_type___362 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___362 {
	struct inode___363 * (*alloc_inode)(struct super_block___362 *);
	void (*destroy_inode)(struct inode___363 *);
	void (*dirty_inode)(struct inode___363 *, int);
	int (*write_inode)(struct inode___363 *, struct writeback_control___150 *);
	int (*drop_inode)(struct inode___363 *);
	void (*evict_inode)(struct inode___363 *);
	void (*put_super)(struct super_block___362 *);
	int (*sync_fs)(struct super_block___362 *, int);
	int (*freeze_super)(struct super_block___362 *);
	int (*freeze_fs)(struct super_block___362 *);
	int (*thaw_super)(struct super_block___362 *);
	int (*unfreeze_fs)(struct super_block___362 *);
	int (*statfs)(struct dentry___362 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___362 *, int *, char *);
	void (*umount_begin)(struct super_block___362 *);
	int (*show_options)(struct seq_file___307 *, struct dentry___362 *);
	int (*show_devname)(struct seq_file___307 *, struct dentry___362 *);
	int (*show_path)(struct seq_file___307 *, struct dentry___362 *);
	int (*show_stats)(struct seq_file___307 *, struct dentry___362 *);
	ssize_t (*quota_read)(struct super_block___362 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___362 *, int, const char *, size_t, loff_t);
	struct dquot___362 ** (*get_dquots)(struct inode___363 *);
	int (*bdev_try_to_free_page)(struct super_block___362 *, struct page___364 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___362 *, struct shrink_control___133 *);
	long int (*free_cached_objects)(struct super_block___362 *, struct shrink_control___133 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___100 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___100 *last_lookup;
	struct hd_struct___100 *part[0];
};

struct block_device_operations___97 {
	int (*open)(struct block_device___362 *, fmode_t);
	void (*release)(struct gendisk___100 *, fmode_t);
	int (*rw_page)(struct block_device___362 *, sector_t, struct page___364 *, unsigned int);
	int (*ioctl)(struct block_device___362 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___362 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___100 *, unsigned int);
	int (*media_changed)(struct gendisk___100 *);
	void (*unlock_native_capacity)(struct gendisk___100 *);
	int (*revalidate_disk)(struct gendisk___100 *);
	int (*getgeo)(struct block_device___362 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___362 *, long unsigned int);
	int (*report_zones)(struct gendisk___100 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___294 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___351(struct page___364 *);

struct bdi_writeback_congested___180 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___180 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bsg_ops___96 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___96 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___96 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___96 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___96(struct request___96 *, blk_status_t);

struct request___96 {
	struct request_queue___96 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___33 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___180 *bio;
	struct bio___180 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___182 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___100 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___96 *saved_end_io;
		} flush;
	};
	struct gendisk___100 *rq_disk;
	struct hd_struct___100 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___96 *end_io;
	void *end_io_data;
	struct request___96 *next_rq;
};

struct fwnode_reference_args___252;

struct fwnode_endpoint___252;

struct fwnode_operations___252 {
	struct fwnode_handle___252 * (*get)(struct fwnode_handle___252 *);
	void (*put)(struct fwnode_handle___252 *);
	bool (*device_is_available)(const struct fwnode_handle___252 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___252 *, const struct device___330 *);
	bool (*property_present)(const struct fwnode_handle___252 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___252 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___252 *, const char *, const char **, size_t);
	struct fwnode_handle___252 * (*get_parent)(const struct fwnode_handle___252 *);
	struct fwnode_handle___252 * (*get_next_child_node)(const struct fwnode_handle___252 *, struct fwnode_handle___252 *);
	struct fwnode_handle___252 * (*get_named_child_node)(const struct fwnode_handle___252 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___252 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___252 *);
	struct fwnode_handle___252 * (*graph_get_next_endpoint)(const struct fwnode_handle___252 *, struct fwnode_handle___252 *);
	struct fwnode_handle___252 * (*graph_get_remote_endpoint)(const struct fwnode_handle___252 *);
	struct fwnode_handle___252 * (*graph_get_port_parent)(struct fwnode_handle___252 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___252 *, struct fwnode_endpoint___252 *);
};

struct fwnode_endpoint___252 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___252 *local_fwnode;
};

struct fwnode_reference_args___252 {
	struct fwnode_handle___252 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct sg_mapping_iter___4 {
	struct page___364 *page;
	void *addr;
	size_t length;
	size_t consumed;
	struct sg_page_iter piter;
	unsigned int __offset;
	unsigned int __remaining;
	unsigned int __flags;
};

struct blk_mq_hw_ctx___33 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___96 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags___4 *tags;
	struct blk_mq_tags___4 *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	unsigned int rh_reserved_nr_expired;
	struct hlist_node cpuhp_dead;
	struct kobject___350 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___362 *debugfs_dir;
	struct dentry___362 *sched_debugfs_dir;
	struct list_head hctx_list;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___96;

struct elevator_mq_ops___96 {
	int (*init_sched)(struct request_queue___96 *, struct elevator_type___96 *);
	void (*exit_sched)(struct elevator_queue___96 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___33 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___33 *, unsigned int);
	bool (*allow_merge)(struct request_queue___96 *, struct request___96 *, struct bio___180 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx___33 *, struct bio___180 *);
	int (*request_merge)(struct request_queue___96 *, struct request___96 **, struct bio___180 *);
	void (*request_merged)(struct request_queue___96 *, struct request___96 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___96 *, struct request___96 *, struct request___96 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___96 *, struct bio___180 *);
	void (*finish_request)(struct request___96 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___33 *, struct list_head *, bool);
	struct request___96 * (*dispatch_request)(struct blk_mq_hw_ctx___33 *);
	bool (*has_work)(struct blk_mq_hw_ctx___33 *);
	void (*completed_request)(struct request___96 *, u64);
	void (*started_request)(struct request___96 *);
	void (*requeue_request)(struct request___96 *);
	struct request___96 * (*former_request)(struct request_queue___96 *, struct request___96 *);
	struct request___96 * (*next_request)(struct request_queue___96 *, struct request___96 *);
	void (*init_icq)(struct io_cq___100 *);
	void (*exit_icq)(struct io_cq___100 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx___33 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___96;

struct elevator_type___96 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___96 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___96 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___294 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___96 {
	struct elevator_type___96 *type;
	void *elevator_data;
	struct kobject___350 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___96 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___96 *, char *);
	ssize_t (*store)(struct elevator_queue___96 *, const char *, size_t);
};

struct blk_mq_queue_data___33;

typedef blk_status_t queue_rq_fn___33(struct blk_mq_hw_ctx___33 *, const struct blk_mq_queue_data___33 *);

typedef void commit_rqs_fn___33(struct blk_mq_hw_ctx___33 *);

typedef bool get_budget_fn___33(struct blk_mq_hw_ctx___33 *);

typedef void put_budget_fn___33(struct blk_mq_hw_ctx___33 *);

typedef enum blk_eh_timer_return timeout_fn___33(struct request___96 *, bool);

typedef int poll_fn___33(struct blk_mq_hw_ctx___33 *);

typedef void complete_fn___33(struct request___96 *);

typedef int init_hctx_fn___33(struct blk_mq_hw_ctx___33 *, void *, unsigned int);

typedef void exit_hctx_fn___33(struct blk_mq_hw_ctx___33 *, unsigned int);

typedef int init_request_fn___33(struct blk_mq_tag_set___33 *, struct request___96 *, unsigned int, unsigned int);

typedef void exit_request_fn___33(struct blk_mq_tag_set___33 *, struct request___96 *, unsigned int);

typedef bool busy_fn___33(struct request_queue___96 *);

typedef int map_queues_fn___33(struct blk_mq_tag_set___33 *);

typedef void cleanup_rq_fn___33(struct request___96 *);

struct blk_mq_ops___33 {
	queue_rq_fn___33 *queue_rq;
	commit_rqs_fn___33 *commit_rqs;
	get_budget_fn___33 *get_budget;
	put_budget_fn___33 *put_budget;
	timeout_fn___33 *timeout;
	poll_fn___33 *poll;
	complete_fn___33 *complete;
	init_hctx_fn___33 *init_hctx;
	exit_hctx_fn___33 *exit_hctx;
	init_request_fn___33 *init_request;
	exit_request_fn___33 *exit_request;
	void (*initialize_rq_fn)(struct request___96 *);
	busy_fn___33 *busy;
	map_queues_fn___33 *map_queues;
	void (*show_rq)(struct seq_file___307 *, struct request___96 *);
	union {
		cleanup_rq_fn___33 *cleanup_rq;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide42;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct blk_mq_tag_set___33 {
	struct blk_mq_queue_map map[6];
	unsigned int nr_maps;
	const struct blk_mq_ops___33 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	struct blk_mq_tags___4 **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef int (*key_restrict_link_func_t___335)(struct key___334 *, const struct key_type *, const union key_payload *, struct key___334 *);

struct key_restriction___334;

struct key___334 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___364 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___334 *restrict_link;
};

struct key_restriction___334 {
	key_restrict_link_func_t___335 check;
	struct key___334 *key;
	struct key_type *keytype;
};

struct seq_operations___306 {
	void * (*start)(struct seq_file___307 *, loff_t *);
	void (*stop)(struct seq_file___307 *, void *);
	void * (*next)(struct seq_file___307 *, void *, loff_t *);
	int (*show)(struct seq_file___307 *, void *);
};

struct blk_mq_queue_data___33 {
	struct request___96 *rq;
	bool last;
	long unsigned int rh_reserved1;
};

struct Scsi_Host___9;

struct scsi_device___14;

struct scsi_cmnd___9;

struct scsi_target___14;

struct scsi_host_template___9 {
	struct module___294 *module;
	const char *name;
	const char * (*info)(struct Scsi_Host___9 *);
	int (*ioctl)(struct scsi_device___14 *, int, void *);
	int (*queuecommand)(struct Scsi_Host___9 *, struct scsi_cmnd___9 *);
	int (*eh_abort_handler)(struct scsi_cmnd___9 *);
	int (*eh_device_reset_handler)(struct scsi_cmnd___9 *);
	int (*eh_target_reset_handler)(struct scsi_cmnd___9 *);
	int (*eh_bus_reset_handler)(struct scsi_cmnd___9 *);
	int (*eh_host_reset_handler)(struct scsi_cmnd___9 *);
	int (*slave_alloc)(struct scsi_device___14 *);
	int (*slave_configure)(struct scsi_device___14 *);
	void (*slave_destroy)(struct scsi_device___14 *);
	int (*target_alloc)(struct scsi_target___14 *);
	void (*target_destroy)(struct scsi_target___14 *);
	int (*scan_finished)(struct Scsi_Host___9 *, long unsigned int);
	void (*scan_start)(struct Scsi_Host___9 *);
	int (*change_queue_depth)(struct scsi_device___14 *, int);
	int (*map_queues)(struct Scsi_Host___9 *);
	int (*bios_param)(struct scsi_device___14 *, struct block_device___362 *, sector_t, int *);
	void (*unlock_native_capacity)(struct scsi_device___14 *);
	int (*show_info)(struct seq_file___307 *, struct Scsi_Host___9 *);
	int (*write_info)(struct Scsi_Host___9 *, char *, int);
	enum blk_eh_timer_return (*eh_timed_out)(struct scsi_cmnd___9 *);
	int (*host_reset)(struct Scsi_Host___9 *, int);
	const char *proc_name;
	struct proc_dir_entry *proc_dir;
	int can_queue;
	int this_id;
	short unsigned int sg_tablesize;
	short unsigned int sg_prot_tablesize;
	unsigned int max_sectors;
	long unsigned int dma_boundary;
	short int cmd_per_lun;
	unsigned char present;
	int tag_alloc_policy;
	unsigned int track_queue_depth: 1;
	unsigned int supported_mode: 2;
	unsigned int unchecked_isa_dma: 1;
	unsigned int use_clustering: 1;
	unsigned int emulated: 1;
	unsigned int skip_settle_delay: 1;
	unsigned int no_write_same: 1;
	unsigned int force_blk_mq: 1;
	unsigned int max_host_blocked;
	struct device_attribute___42 **shost_attrs;
	struct device_attribute___42 **sdev_attrs;
	const struct attribute_group___327 **sdev_groups;
	u64 vendor_id;
	unsigned int cmd_size;
	struct scsi_host_cmd_pool *cmd_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct scsi_transport_template___5;

struct Scsi_Host___9 {
	struct list_head __devices;
	struct list_head __targets;
	struct list_head starved_list;
	spinlock_t default_lock;
	spinlock_t *host_lock;
	struct mutex scan_mutex;
	struct list_head eh_cmd_q;
	struct task_struct___364 *ehandler;
	struct completion *eh_action;
	wait_queue_head_t host_wait;
	struct scsi_host_template___9 *hostt;
	struct scsi_transport_template___5 *transportt;
	struct blk_mq_tag_set___33 tag_set;
	atomic_t host_busy;
	atomic_t host_blocked;
	unsigned int host_failed;
	unsigned int host_eh_scheduled;
	unsigned int host_no;
	int eh_deadline;
	long unsigned int last_reset;
	unsigned int max_channel;
	unsigned int max_id;
	u64 max_lun;
	unsigned int unique_id;
	short unsigned int max_cmd_len;
	int this_id;
	int can_queue;
	short int cmd_per_lun;
	short unsigned int sg_tablesize;
	short unsigned int sg_prot_tablesize;
	unsigned int max_sectors;
	long unsigned int dma_boundary;
	unsigned int nr_hw_queues;
	long unsigned int cmd_serial_number;
	unsigned int active_mode: 2;
	unsigned int unchecked_isa_dma: 1;
	unsigned int use_clustering: 1;
	unsigned int host_self_blocked: 1;
	unsigned int reverse_ordering: 1;
	unsigned int tmf_in_progress: 1;
	unsigned int async_scan: 1;
	unsigned int eh_noresume: 1;
	unsigned int no_write_same: 1;
	unsigned int use_cmd_list: 1;
	unsigned int short_inquiry: 1;
	char work_q_name[20];
	struct workqueue_struct *work_q;
	struct workqueue_struct *tmf_work_q;
	unsigned int no_scsi2_lun_in_cdb: 1;
	unsigned int max_host_blocked;
	unsigned int prot_capabilities;
	unsigned char prot_guard_type;
	long unsigned int base;
	long unsigned int io_port;
	unsigned char n_io_port;
	unsigned char dma_channel;
	unsigned int irq;
	enum scsi_host_state shost_state;
	struct device___330 shost_gendev;
	struct device___330 shost_dev;
	void *shost_data;
	struct device___330 *dma_dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int hostdata[0];
};

struct scsi_device___14 {
	struct Scsi_Host___9 *host;
	struct request_queue___96 *request_queue;
	struct list_head siblings;
	struct list_head same_target_siblings;
	atomic_t device_busy;
	atomic_t device_blocked;
	spinlock_t list_lock;
	struct list_head cmd_list;
	struct list_head starved_entry;
	short unsigned int queue_depth;
	short unsigned int max_queue_depth;
	short unsigned int last_queue_full_depth;
	short unsigned int last_queue_full_count;
	long unsigned int last_queue_full_time;
	long unsigned int queue_ramp_up_period;
	long unsigned int last_queue_ramp_up;
	unsigned int id;
	unsigned int channel;
	u64 lun;
	unsigned int manufacturer;
	unsigned int sector_size;
	void *hostdata;
	unsigned char type;
	char scsi_level;
	char inq_periph_qual;
	struct mutex inquiry_mutex;
	unsigned char inquiry_len;
	unsigned char *inquiry;
	const char *vendor;
	const char *model;
	const char *rev;
	struct scsi_vpd *vpd_pg83;
	struct scsi_vpd *vpd_pg80;
	unsigned char current_tag;
	struct scsi_target___14 *sdev_target;
	blist_flags_t sdev_bflags;
	unsigned int eh_timeout;
	unsigned int removable: 1;
	unsigned int changed: 1;
	unsigned int busy: 1;
	unsigned int lockable: 1;
	unsigned int locked: 1;
	unsigned int borken: 1;
	unsigned int disconnect: 1;
	unsigned int soft_reset: 1;
	unsigned int sdtr: 1;
	unsigned int wdtr: 1;
	unsigned int ppr: 1;
	unsigned int tagged_supported: 1;
	unsigned int simple_tags: 1;
	unsigned int was_reset: 1;
	unsigned int expecting_cc_ua: 1;
	unsigned int use_10_for_rw: 1;
	unsigned int use_10_for_ms: 1;
	unsigned int no_report_opcodes: 1;
	unsigned int no_write_same: 1;
	unsigned int use_16_for_rw: 1;
	unsigned int skip_ms_page_8: 1;
	unsigned int skip_ms_page_3f: 1;
	unsigned int skip_vpd_pages: 1;
	unsigned int try_vpd_pages: 1;
	unsigned int use_192_bytes_for_3f: 1;
	unsigned int no_start_on_add: 1;
	unsigned int allow_restart: 1;
	unsigned int manage_start_stop: 1;
	unsigned int start_stop_pwr_cond: 1;
	unsigned int no_uld_attach: 1;
	unsigned int select_no_atn: 1;
	unsigned int fix_capacity: 1;
	unsigned int guess_capacity: 1;
	unsigned int retry_hwerror: 1;
	unsigned int last_sector_bug: 1;
	unsigned int no_read_disc_info: 1;
	unsigned int no_read_capacity_16: 1;
	unsigned int try_rc_10_first: 1;
	unsigned int security_supported: 1;
	unsigned int is_visible: 1;
	unsigned int wce_default_on: 1;
	unsigned int no_dif: 1;
	unsigned int broken_fua: 1;
	unsigned int lun_in_cdb: 1;
	unsigned int unmap_limit_for_ws: 1;
	atomic_t disk_events_disable_depth;
	long unsigned int supported_events[1];
	long unsigned int pending_events[1];
	struct list_head event_list;
	struct work_struct event_work;
	unsigned int max_device_blocked;
	atomic_t iorequest_cnt;
	atomic_t iodone_cnt;
	atomic_t ioerr_cnt;
	struct device___330 sdev_gendev;
	struct device___330 sdev_dev;
	struct execute_work ew;
	struct work_struct requeue_work;
	struct scsi_device_handler *handler;
	void *handler_data;
	unsigned char access_state;
	struct mutex state_mutex;
	enum scsi_device_state sdev_state;
	struct task_struct___364 *quiesced_by;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int sdev_data[0];
};

struct scsi_cmnd___9 {
	struct scsi_request req;
	struct scsi_device___14 *device;
	struct list_head list;
	struct list_head eh_entry;
	struct delayed_work abort_work;
	struct callback_head rcu;
	int eh_eflags;
	long unsigned int serial_number;
	long unsigned int jiffies_at_alloc;
	int retries;
	int allowed;
	unsigned char prot_op;
	unsigned char prot_type;
	unsigned char prot_flags;
	short unsigned int cmd_len;
	enum dma_data_direction sc_data_direction;
	unsigned char *cmnd;
	struct scsi_data_buffer sdb;
	struct scsi_data_buffer *prot_sdb;
	unsigned int underflow;
	unsigned int transfersize;
	struct request___96 *request;
	unsigned char *sense_buffer;
	void (*scsi_done)(struct scsi_cmnd___9 *);
	struct scsi_pointer SCp;
	unsigned char *host_scribble;
	int result;
	int flags;
	long unsigned int state;
	unsigned char tag;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct scsi_target___14 {
	struct scsi_device___14 *starget_sdev_user;
	struct list_head siblings;
	struct list_head devices;
	struct device___330 dev;
	struct kref reap_ref;
	unsigned int channel;
	unsigned int id;
	unsigned int create: 1;
	unsigned int single_lun: 1;
	unsigned int pdt_1f_for_no_lun: 1;
	unsigned int no_report_luns: 1;
	unsigned int expecting_lun_change: 1;
	atomic_t target_busy;
	atomic_t target_blocked;
	unsigned int can_queue;
	unsigned int max_target_blocked;
	char scsi_level;
	enum scsi_target_state state;
	void *hostdata;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int starget_data[0];
};

struct attribute_container___6 {
	struct list_head node;
	struct klist containers;
	struct class___330 *class;
	const struct attribute_group___327 *grp;
	struct device_attribute___42 **attrs;
	int (*match)(struct attribute_container___6 *, struct device___330 *);
	long unsigned int flags;
};

struct transport_container___6 {
	struct attribute_container___6 ac;
	const struct attribute_group___327 *statistics;
};

struct scsi_transport_template___5 {
	struct transport_container___6 host_attrs;
	struct transport_container___6 target_attrs;
	struct transport_container___6 device_attrs;
	int (*user_scan)(struct Scsi_Host___9 *, uint, uint, u64);
	int device_size;
	int device_private_offset;
	int target_size;
	int target_private_offset;
	int host_size;
	unsigned int create_work_queue: 1;
	void (*eh_strategy_handler)(struct Scsi_Host___9 *);
};

struct kernel_param_ops___291 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___291 *);
	int (*get)(char *, const struct kernel_param___291 *);
	void (*free)(void *);
};

struct kparam_array___291;

struct kernel_param___291 {
	const char *name;
	struct module___294 *mod;
	const struct kernel_param_ops___291 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___291 *arr;
	};
};

struct kparam_array___291 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___291 *ops;
	void *elem;
};

struct module_attribute___291 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___291 *, struct module_kobject___291 *, char *);
	ssize_t (*store)(struct module_attribute___291 *, struct module_kobject___291 *, const char *, size_t);
	void (*setup)(struct module___294 *, const char *);
	int (*test)(struct module___294 *);
	void (*free)(struct module___294 *);
};

struct ata_queued_cmd___2;

typedef void (*ata_qc_cb_t___2)(struct ata_queued_cmd___2 *);

struct ata_port___2;

struct ata_device___2;

struct ata_queued_cmd___2 {
	struct ata_port___2 *ap;
	struct ata_device___2 *dev;
	struct scsi_cmnd___9 *scsicmd;
	void (*scsidone)(struct scsi_cmnd___9 *);
	struct ata_taskfile tf;
	u8 cdb[16];
	long unsigned int flags;
	unsigned int tag;
	unsigned int hw_tag;
	unsigned int n_elem;
	unsigned int orig_n_elem;
	int dma_dir;
	unsigned int sect_size;
	unsigned int nbytes;
	unsigned int extrabytes;
	unsigned int curbytes;
	struct scatterlist sgent;
	struct scatterlist *sg;
	struct scatterlist *cursg;
	unsigned int cursg_ofs;
	unsigned int err_mask;
	struct ata_taskfile result_tf;
	ata_qc_cb_t___2 complete_fn;
	void *private_data;
	void *lldd_task;
};

struct ata_link___2;

typedef int (*ata_prereset_fn_t___2)(struct ata_link___2 *, long unsigned int);

struct ata_eh_info___2 {
	struct ata_device___2 *dev;
	u32 serror;
	unsigned int err_mask;
	unsigned int action;
	unsigned int dev_action[2];
	unsigned int flags;
	unsigned int probe_mask;
	char desc[80];
	int desc_len;
};

struct ata_eh_context___2 {
	struct ata_eh_info___2 i;
	int tries[2];
	int cmd_timeout_idx[12];
	unsigned int classes[2];
	unsigned int did_probe_mask;
	unsigned int unloaded_mask;
	unsigned int saved_ncq_enabled;
	u8 saved_xfer_mode[2];
	long unsigned int last_reset;
};

struct ata_device___2 {
	struct ata_link___2 *link;
	unsigned int devno;
	unsigned int horkage;
	long unsigned int flags;
	struct scsi_device___14 *sdev;
	void *private_data;
	union acpi_object *gtf_cache;
	unsigned int gtf_filter;
	struct device___330 tdev;
	u64 n_sectors;
	u64 n_native_sectors;
	unsigned int class;
	long unsigned int unpark_deadline;
	u8 pio_mode;
	u8 dma_mode;
	u8 xfer_mode;
	unsigned int xfer_shift;
	unsigned int multi_count;
	unsigned int max_sectors;
	unsigned int cdb_len;
	long unsigned int pio_mask;
	long unsigned int mwdma_mask;
	long unsigned int udma_mask;
	u16 cylinders;
	u16 heads;
	u16 sectors;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	union {
		u16 id[256];
		u32 gscr[128];
	};
	u8 devslp_timing[8];
	u8 ncq_send_recv_cmds[20];
	u8 ncq_non_data_cmds[64];
	u32 zac_zoned_cap;
	u32 zac_zones_optimal_open;
	u32 zac_zones_optimal_nonseq;
	u32 zac_zones_max_open;
	int spdn_cnt;
	struct ata_ering ering;
	long: 64;
};

struct ata_link___2 {
	struct ata_port___2 *ap;
	int pmp;
	struct device___330 tdev;
	unsigned int active_tag;
	u32 sactive;
	unsigned int flags;
	u32 saved_scontrol;
	unsigned int hw_sata_spd_limit;
	unsigned int sata_spd_limit;
	unsigned int sata_spd;
	enum ata_lpm_policy lpm_policy;
	struct ata_eh_info___2 eh_info;
	struct ata_eh_context___2 eh_context;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ata_device___2 device[2];
	long unsigned int last_lpm_change;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef int (*ata_reset_fn_t___2)(struct ata_link___2 *, unsigned int *, long unsigned int);

typedef void (*ata_postreset_fn_t___2)(struct ata_link___2 *, unsigned int *);

struct ata_port_operations___2;

struct ata_host___2 {
	spinlock_t lock;
	struct device___330 *dev;
	void * const *iomap;
	unsigned int n_ports;
	unsigned int n_tags;
	void *private_data;
	struct ata_port_operations___2 *ops;
	long unsigned int flags;
	struct kref kref;
	struct mutex eh_mutex;
	struct task_struct___364 *eh_owner;
	struct ata_port___2 *simplex_claimed;
	struct ata_port___2 *ports[0];
};

struct ata_port_operations___2 {
	int (*qc_defer)(struct ata_queued_cmd___2 *);
	int (*check_atapi_dma)(struct ata_queued_cmd___2 *);
	void (*qc_prep)(struct ata_queued_cmd___2 *);
	unsigned int (*qc_issue)(struct ata_queued_cmd___2 *);
	bool (*qc_fill_rtf)(struct ata_queued_cmd___2 *);
	int (*cable_detect)(struct ata_port___2 *);
	long unsigned int (*mode_filter)(struct ata_device___2 *, long unsigned int);
	void (*set_piomode)(struct ata_port___2 *, struct ata_device___2 *);
	void (*set_dmamode)(struct ata_port___2 *, struct ata_device___2 *);
	int (*set_mode)(struct ata_link___2 *, struct ata_device___2 **);
	unsigned int (*read_id)(struct ata_device___2 *, struct ata_taskfile *, u16 *);
	void (*dev_config)(struct ata_device___2 *);
	void (*freeze)(struct ata_port___2 *);
	void (*thaw)(struct ata_port___2 *);
	ata_prereset_fn_t___2 prereset;
	ata_reset_fn_t___2 softreset;
	ata_reset_fn_t___2 hardreset;
	ata_postreset_fn_t___2 postreset;
	ata_prereset_fn_t___2 pmp_prereset;
	ata_reset_fn_t___2 pmp_softreset;
	ata_reset_fn_t___2 pmp_hardreset;
	ata_postreset_fn_t___2 pmp_postreset;
	void (*error_handler)(struct ata_port___2 *);
	void (*lost_interrupt)(struct ata_port___2 *);
	void (*post_internal_cmd)(struct ata_queued_cmd___2 *);
	void (*sched_eh)(struct ata_port___2 *);
	void (*end_eh)(struct ata_port___2 *);
	int (*scr_read)(struct ata_link___2 *, unsigned int, u32 *);
	int (*scr_write)(struct ata_link___2 *, unsigned int, u32);
	void (*pmp_attach)(struct ata_port___2 *);
	void (*pmp_detach)(struct ata_port___2 *);
	int (*set_lpm)(struct ata_link___2 *, enum ata_lpm_policy, unsigned int);
	int (*port_suspend)(struct ata_port___2 *, pm_message_t);
	int (*port_resume)(struct ata_port___2 *);
	int (*port_start)(struct ata_port___2 *);
	void (*port_stop)(struct ata_port___2 *);
	void (*host_stop)(struct ata_host___2 *);
	void (*sff_dev_select)(struct ata_port___2 *, unsigned int);
	void (*sff_set_devctl)(struct ata_port___2 *, u8);
	u8 (*sff_check_status)(struct ata_port___2 *);
	u8 (*sff_check_altstatus)(struct ata_port___2 *);
	void (*sff_tf_load)(struct ata_port___2 *, const struct ata_taskfile *);
	void (*sff_tf_read)(struct ata_port___2 *, struct ata_taskfile *);
	void (*sff_exec_command)(struct ata_port___2 *, const struct ata_taskfile *);
	unsigned int (*sff_data_xfer)(struct ata_queued_cmd___2 *, unsigned char *, unsigned int, int);
	void (*sff_irq_on)(struct ata_port___2 *);
	bool (*sff_irq_check)(struct ata_port___2 *);
	void (*sff_irq_clear)(struct ata_port___2 *);
	void (*sff_drain_fifo)(struct ata_queued_cmd___2 *);
	void (*bmdma_setup)(struct ata_queued_cmd___2 *);
	void (*bmdma_start)(struct ata_queued_cmd___2 *);
	void (*bmdma_stop)(struct ata_queued_cmd___2 *);
	u8 (*bmdma_status)(struct ata_port___2 *);
	ssize_t (*em_show)(struct ata_port___2 *, char *);
	ssize_t (*em_store)(struct ata_port___2 *, const char *, size_t);
	ssize_t (*sw_activity_show)(struct ata_device___2 *, char *);
	ssize_t (*sw_activity_store)(struct ata_device___2 *, enum sw_activity);
	ssize_t (*transmit_led_message)(struct ata_port___2 *, u32, ssize_t);
	void (*phy_reset)(struct ata_port___2 *);
	void (*eng_timeout)(struct ata_port___2 *);
	const struct ata_port_operations___2 *inherits;
};

struct ata_port___2 {
	struct Scsi_Host___9 *scsi_host;
	struct ata_port_operations___2 *ops;
	spinlock_t *lock;
	long unsigned int flags;
	unsigned int pflags;
	unsigned int print_id;
	unsigned int local_port_no;
	unsigned int port_no;
	struct ata_ioports ioaddr;
	u8 ctl;
	u8 last_ctl;
	struct ata_link___2 *sff_pio_task_link;
	struct delayed_work sff_pio_task;
	struct ata_bmdma_prd *bmdma_prd;
	dma_addr_t bmdma_prd_dma;
	unsigned int pio_mask;
	unsigned int mwdma_mask;
	unsigned int udma_mask;
	unsigned int cbl;
	struct ata_queued_cmd___2 qcmd[33];
	long unsigned int sas_tag_allocated;
	u64 qc_active;
	int nr_active_links;
	unsigned int sas_last_tag;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ata_link___2 link;
	struct ata_link___2 *slave_link;
	int nr_pmp_links;
	struct ata_link___2 *pmp_link;
	struct ata_link___2 *excl_link;
	struct ata_port_stats stats;
	struct ata_host___2 *host;
	struct device___330 *dev;
	struct device___330 tdev;
	struct mutex scsi_scan_mutex;
	struct delayed_work hotplug_task;
	struct work_struct scsi_rescan_task;
	unsigned int hsm_task_state;
	u32 msg_enable;
	struct list_head eh_done_q;
	wait_queue_head_t eh_wait_q;
	int eh_tries;
	struct completion park_req_pending;
	pm_message_t pm_mesg;
	enum ata_lpm_policy target_lpm_policy;
	struct timer_list fastdrain_timer;
	long unsigned int fastdrain_cnt;
	int em_message_type;
	void *private_data;
	struct ata_acpi_gtm __acpi_init_gtm;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sector_buf[512];
};

struct ata_port_info___2 {
	long unsigned int flags;
	long unsigned int link_flags;
	long unsigned int pio_mask;
	long unsigned int mwdma_mask;
	long unsigned int udma_mask;
	struct ata_port_operations___2 *port_ops;
	void *private_data;
};

struct cgroup_namespace___231 {
	refcount_t count;
	struct ns_common___9 ns;
	struct user_namespace___246 *user_ns;
	struct ucounts___246 *ucounts;
	struct css_set___231 *root_cset;
};

struct ucounts___246 {
	struct hlist_node node;
	struct user_namespace___246 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___232;

struct bpf_map_ops___231 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___232 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___232 *, struct file___363 *);
	void (*map_free)(struct bpf_map___232 *);
	int (*map_get_next_key)(struct bpf_map___232 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___232 *);
	void * (*map_lookup_elem)(struct bpf_map___232 *, void *);
	int (*map_update_elem)(struct bpf_map___232 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___232 *, void *);
	int (*map_push_elem)(struct bpf_map___232 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___232 *, void *);
	int (*map_peek_elem)(struct bpf_map___232 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___232 *, struct file___363 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___232 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___232 *, void *, struct seq_file___307 *);
	int (*map_check_btf)(const struct bpf_map___232 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___232 {
	const struct bpf_map_ops___231 *ops;
	struct bpf_map___232 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___334 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___231;

typedef void (*kthread_work_func_t___231)(struct kthread_work___231 *);

struct kthread_worker___231;

struct kthread_work___231 {
	struct list_head node;
	kthread_work_func_t___231 func;
	struct kthread_worker___231 *worker;
	int canceling;
};

struct kthread_worker___231 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___364 *task;
	struct kthread_work___231 *current_work;
};

struct kthread_delayed_work___231 {
	struct kthread_work___231 work;
	struct timer_list timer;
};

struct psi_group___231 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___231 *poll_kworker;
	struct kthread_delayed_work___231 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___231;

struct cgroup_rstat_cpu___231;

struct cgroup___231 {
	struct cgroup_subsys_state___231 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___357 *kn;
	struct cgroup_file___231 procs_file;
	struct cgroup_file___231 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___231 *subsys[13];
	struct cgroup_root___231 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___231 *dom_cgrp;
	struct cgroup_rstat_cpu___231 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___38 bpf;
	atomic_t congestion_count;
	struct cgroup___231 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___231 psi;
	int ancestor_ids[0];
};

struct cftype___231;

struct cgroup_subsys___231 {
	struct cgroup_subsys_state___231 * (*css_alloc)(struct cgroup_subsys_state___231 *);
	int (*css_online)(struct cgroup_subsys_state___231 *);
	void (*css_offline)(struct cgroup_subsys_state___231 *);
	void (*css_released)(struct cgroup_subsys_state___231 *);
	void (*css_free)(struct cgroup_subsys_state___231 *);
	void (*css_reset)(struct cgroup_subsys_state___231 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___231 *, int);
	int (*css_extra_stat_show)(struct seq_file___307 *, struct cgroup_subsys_state___231 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___364 *);
	void (*cancel_fork)(struct task_struct___364 *);
	void (*fork)(struct task_struct___364 *);
	void (*exit)(struct task_struct___364 *);
	void (*free)(struct task_struct___364 *);
	void (*bind)(struct cgroup_subsys_state___231 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___231 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___231 *dfl_cftypes;
	struct cftype___231 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___231 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___231 *updated_children;
	struct cgroup___231 *updated_next;
};

struct cgroup_root___231 {
	struct kernfs_root___356 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___231 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___231 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___231 *ss;
	struct list_head node;
	struct kernfs_ops___356 *kf_ops;
	int (*open)(struct kernfs_open_file___356 *);
	void (*release)(struct kernfs_open_file___356 *);
	u64 (*read_u64)(struct cgroup_subsys_state___231 *, struct cftype___231 *);
	s64 (*read_s64)(struct cgroup_subsys_state___231 *, struct cftype___231 *);
	int (*seq_show)(struct seq_file___307 *, void *);
	void * (*seq_start)(struct seq_file___307 *, loff_t *);
	void * (*seq_next)(struct seq_file___307 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___307 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___231 *, struct cftype___231 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___231 *, struct cftype___231 *, s64);
	ssize_t (*write)(struct kernfs_open_file___356 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___356 *, struct poll_table_struct___216 *);
};

struct mem_cgroup_reclaim_iter___133 {
	struct mem_cgroup___133 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___133 {
	struct lruvec___363 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___133 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___133 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct node___206 {
	struct device___330 dev;
};

typedef unsigned int (*ata_xlat_func_t)(struct ata_queued_cmd___2 *);

struct ata_scsi_args {
	struct ata_device___2 *dev;
	u16 *id;
	struct scsi_cmnd___9 *cmd;
};

struct module___295;

struct file___364;

struct kiocb___364;

struct poll_table_struct___217;

struct vm_area_struct___365;

struct inode___364;

struct file_lock___364;

struct page___365;

struct seq_file___308;

struct file_operations___364 {
	struct module___295 *owner;
	loff_t (*llseek)(struct file___364 *, loff_t, int);
	ssize_t (*read)(struct file___364 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___364 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___364 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___364 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___364 *, bool);
	int (*iterate)(struct file___364 *, struct dir_context *);
	int (*iterate_shared)(struct file___364 *, struct dir_context *);
	__poll_t (*poll)(struct file___364 *, struct poll_table_struct___217 *);
	long int (*unlocked_ioctl)(struct file___364 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___364 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___364 *, struct vm_area_struct___365 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___364 *, struct file___364 *);
	int (*flush)(struct file___364 *, fl_owner_t);
	int (*release)(struct inode___364 *, struct file___364 *);
	int (*fsync)(struct file___364 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___364 *, int);
	int (*lock)(struct file___364 *, int, struct file_lock___364 *);
	ssize_t (*sendpage)(struct file___364 *, struct page___365 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___364 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___364 *, int, struct file_lock___364 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___364 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___364 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___364 *, long int, struct file_lock___364 **, void **);
	long int (*fallocate)(struct file___364 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___308 *, struct file___364 *);
	ssize_t (*copy_file_range)(struct file___364 *, loff_t, struct file___364 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___364 *, loff_t, struct file___364 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___364 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___364 {
	u64 seqnum;
	struct vm_area_struct___365 *vmas[4];
};

struct page_frag___364 {
	struct page___365 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___364;

struct cred___335;

struct bio_list___181;

struct backing_dev_info___181;

struct io_context___101;

struct request_queue___97;

struct vm_struct___270;

struct task_struct___365 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___365 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___364 *mm;
	struct mm_struct___364 *active_mm;
	struct vmacache___364 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___365 *real_parent;
	struct task_struct___365 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___365 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___217 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___217 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___217 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___335 *ptracer_cred;
	const struct cred___335 *real_cred;
	const struct cred___335 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___365 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___181 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___181 *backing_dev_info;
	struct io_context___101 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___364 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___97 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___365 *oom_reaper_list;
	struct vm_struct___270 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___141 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct secondary_data___365 {
	void *stack;
	struct task_struct___365 *task;
	long int status;
};

typedef struct page___365 *pgtable_t___364;

struct address_space___363;

struct dev_pagemap___352;

struct page___365 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___363 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___365 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___364 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___364 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___352 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct key___335;

struct user_struct___335 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___335 *uid_keyring;
	struct key___335 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___352;

struct vm_area_struct___365 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___365 *vm_next;
	struct vm_area_struct___365 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___364 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___352 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___364 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct rw_semaphore___365 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___365 *owner;
};

struct core_state___364;

struct mm_struct___364 {
	struct {
		struct vm_area_struct___365 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___364 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___365 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___364 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___365 *owner;
		struct user_namespace___3 *user_ns;
		struct file___364 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___364 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___335 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___335 *session_keyring;
	struct key___335 *process_keyring;
	struct key___335 *thread_keyring;
	struct key___335 *request_key_auth;
	void *security;
	struct user_struct___335 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct bio___181;

struct bio_list___181 {
	struct bio___181 *head;
	struct bio___181 *tail;
};

struct bdi_writeback_congested___181;

struct bdi_writeback___181 {
	struct backing_dev_info___181 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___181 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___157 *memcg_css;
	struct cgroup_subsys_state___157 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___331;

struct dentry___363;

struct backing_dev_info___181 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___181 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___331 *dev;
	struct device___331 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___363 *debug_dir;
	struct dentry___363 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___101;

struct io_context___101 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___101 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

typedef blk_qc_t make_request_fn___97(struct request_queue___97 *, struct bio___181 *);

struct request___97;

typedef int dma_drain_needed_fn___97(struct request___97 *);

struct kset___350;

struct kobj_type___350;

struct kernfs_node___358;

struct kobject___351 {
	const char *name;
	struct list_head entry;
	struct kobject___351 *parent;
	struct kset___350 *kset;
	struct kobj_type___350 *ktype;
	struct kernfs_node___358 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___97;

struct bsg_class_device___97 {
	struct device___331 *class_dev;
	int minor;
	struct request_queue___97 *queue;
	const struct bsg_ops___97 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___181 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___181 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___97;

struct blk_mq_ops___34;

struct blk_mq_hw_ctx___34;

struct blk_mq_tag_set___34;

struct request_queue___97 {
	struct list_head queue_head;
	struct request___97 *last_merge;
	struct elevator_queue___97 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___97 *make_request_fn;
	dma_drain_needed_fn___97 *dma_drain_needed;
	const struct blk_mq_ops___34 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___34 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___181 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___351 kobj;
	struct kobject___351 *mq_kobj;
	struct blk_integrity integrity;
	struct device___331 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	struct bsg_class_device___97 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set___34 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___181 bio_split;
	struct dentry___363 *debugfs_dir;
	struct dentry___363 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___270 {
	struct vm_struct___270 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___365 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct pglist_data___364;

struct lruvec___364 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___364 *pgdat;
};

struct zone___364 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___364 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___364 {
	struct zone___364 *zone;
	int zone_idx;
};

struct zonelist___364 {
	struct zoneref___364 _zonerefs[25];
};

struct pglist_data___364 {
	struct zone___364 node_zones[3];
	struct zonelist___364 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___365 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___365 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___364 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___364 {
	struct rw_semaphore___365 rwsem;
	struct notifier_block *head;
};

struct bio_vec___183 {
	struct page___365 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

typedef void bio_end_io_t___181(struct bio___181 *);

struct gendisk___101;

struct bio_integrity_payload___181;

struct bio___181 {
	struct bio___181 *bi_next;
	struct gendisk___101 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___181 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___181 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___183 *bi_io_vec;
	struct bio_set___181 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___183 bi_inline_vecs[0];
};

struct bio_integrity_payload___181 {
	struct bio___181 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___183 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___183 bip_inline_vecs[0];
};

struct dev_pm_info___331 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___5 *subsys_data;
	void (*set_latency_tolerance)(struct device___331 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___331;

struct bus_type___331;

struct device_driver___331;

struct dev_pm_domain___331;

struct dma_map_ops___119;

struct fwnode_handle___253;

struct class___331;

struct attribute_group___328;

struct device___331 {
	struct device___331 *parent;
	struct device_private *p;
	struct kobject___351 kobj;
	const char *init_name;
	const struct device_type___331 *type;
	struct mutex mutex;
	struct bus_type___331 *bus;
	struct device_driver___331 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___331 power;
	struct dev_pm_domain___331 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___119 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___253 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___331 *class;
	const struct attribute_group___328 **groups;
	void (*release)(struct device___331 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___101 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___331 __dev;
	struct kobject___351 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___101;

struct block_device_operations___98;

struct gendisk___101 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___101 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___101 *part_tbl;
	struct hd_struct___101 part0;
	const struct block_device_operations___98 *fops;
	struct request_queue___97 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___365 lookup_sem;
	struct kobject___351 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___351 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_ops___331;

struct device_type___331 {
	const char *name;
	const struct attribute_group___328 **groups;
	int (*uevent)(struct device___331 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___331 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___331 *);
	const struct dev_pm_ops___331 *pm;
};

struct class___331 {
	const char *name;
	struct module___295 *owner;
	const struct attribute_group___328 **class_groups;
	const struct attribute_group___328 **dev_groups;
	struct kobject___351 *dev_kobj;
	int (*dev_uevent)(struct device___331 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___331 *, umode_t *);
	void (*class_release)(struct class___331 *);
	void (*dev_release)(struct device___331 *);
	int (*shutdown_pre)(struct device___331 *);
	const struct kobj_ns_type_operations___28 *ns_type;
	const void * (*namespace)(struct device___331 *);
	const struct dev_pm_ops___331 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct kernfs_root___357;

struct kernfs_elem_dir___357 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___357 *root;
};

struct kernfs_syscall_ops___357;

struct kernfs_root___357 {
	struct kernfs_node___358 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___357 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___357 {
	struct kernfs_node___358 *target_kn;
};

struct kernfs_ops___357;

struct kernfs_elem_attr___357 {
	const struct kernfs_ops___357 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___358 *notify_next;
};

struct kernfs_node___358 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___358 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___357 dir;
		struct kernfs_elem_symlink___357 symlink;
		struct kernfs_elem_attr___357 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___357;

struct kernfs_ops___357 {
	int (*open)(struct kernfs_open_file___357 *);
	void (*release)(struct kernfs_open_file___357 *);
	int (*seq_show)(struct seq_file___308 *, void *);
	void * (*seq_start)(struct seq_file___308 *, loff_t *);
	void * (*seq_next)(struct seq_file___308 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___308 *, void *);
	ssize_t (*read)(struct kernfs_open_file___357 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___357 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___357 *, struct vm_area_struct___365 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___357 *, struct poll_table_struct___217 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___357 {
	int (*remount_fs)(struct kernfs_root___357 *, int *, char *);
	int (*show_options)(struct seq_file___308 *, struct kernfs_root___357 *);
	int (*mkdir)(struct kernfs_node___358 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___358 *);
	int (*rename)(struct kernfs_node___358 *, struct kernfs_node___358 *, const char *);
	int (*show_path)(struct seq_file___308 *, struct kernfs_node___358 *, struct kernfs_root___357 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___307;

struct seq_file___308 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___307 *op;
	int poll_event;
	const struct file___364 *file;
	void *private;
};

struct kernfs_open_file___357 {
	struct kernfs_node___358 *kn;
	struct file___364 *file;
	struct seq_file___308 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___352 *vm_ops;
};

struct path___364 {
	struct vfsmount *mnt;
	struct dentry___363 *dentry;
};

struct file___364 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___364 f_path;
	struct inode___364 *f_inode;
	const struct file_operations___364 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___217 f_owner;
	const struct cred___335 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___363 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___352;

struct vm_operations_struct___352 {
	void (*open)(struct vm_area_struct___365 *);
	void (*close)(struct vm_area_struct___365 *);
	int (*split)(struct vm_area_struct___365 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___365 *);
	vm_fault_t (*fault)(struct vm_fault___352 *);
	vm_fault_t (*huge_fault)(struct vm_fault___352 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___352 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___365 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___352 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___352 *);
	int (*access)(struct vm_area_struct___365 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___365 *);
	int (*set_policy)(struct vm_area_struct___365 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___365 *, long unsigned int);
	struct page___365 * (*find_special_page)(struct vm_area_struct___365 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___223)(struct file___364 *, wait_queue_head_t *, struct poll_table_struct___217 *);

struct poll_table_struct___217 {
	poll_queue_proc___223 _qproc;
	__poll_t _key;
};

struct bin_attribute___327;

struct attribute_group___328 {
	const char *name;
	umode_t (*is_visible)(struct kobject___351 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___351 *, struct bin_attribute___327 *, int);
	struct attribute **attrs;
	struct bin_attribute___327 **bin_attrs;
};

struct bin_attribute___327 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___364 *, struct kobject___351 *, struct bin_attribute___327 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___364 *, struct kobject___351 *, struct bin_attribute___327 *, char *, loff_t, size_t);
	int (*mmap)(struct file___364 *, struct kobject___351 *, struct bin_attribute___327 *, struct vm_area_struct___365 *);
};

struct sysfs_ops___350 {
	ssize_t (*show)(struct kobject___351 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___351 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___350;

struct kset___350 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___351 kobj;
	const struct kset_uevent_ops___350 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___350 {
	void (*release)(struct kobject___351 *);
	const struct sysfs_ops___350 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___28 * (*child_ns_type)(struct kobject___351 *);
	const void * (*namespace)(struct kobject___351 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___350 {
	int (* const filter)(struct kset___350 *, struct kobject___351 *);
	const char * (* const name)(struct kset___350 *, struct kobject___351 *);
	int (* const uevent)(struct kset___350 *, struct kobject___351 *, struct kobj_uevent_env *);
};

struct kobj_attribute___342 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___351 *, struct kobj_attribute___342 *, char *);
	ssize_t (*store)(struct kobject___351 *, struct kobj_attribute___342 *, const char *, size_t);
};

struct dev_pm_ops___331 {
	int (*prepare)(struct device___331 *);
	void (*complete)(struct device___331 *);
	int (*suspend)(struct device___331 *);
	int (*resume)(struct device___331 *);
	int (*freeze)(struct device___331 *);
	int (*thaw)(struct device___331 *);
	int (*poweroff)(struct device___331 *);
	int (*restore)(struct device___331 *);
	int (*suspend_late)(struct device___331 *);
	int (*resume_early)(struct device___331 *);
	int (*freeze_late)(struct device___331 *);
	int (*thaw_early)(struct device___331 *);
	int (*poweroff_late)(struct device___331 *);
	int (*restore_early)(struct device___331 *);
	int (*suspend_noirq)(struct device___331 *);
	int (*resume_noirq)(struct device___331 *);
	int (*freeze_noirq)(struct device___331 *);
	int (*thaw_noirq)(struct device___331 *);
	int (*poweroff_noirq)(struct device___331 *);
	int (*restore_noirq)(struct device___331 *);
	int (*runtime_suspend)(struct device___331 *);
	int (*runtime_resume)(struct device___331 *);
	int (*runtime_idle)(struct device___331 *);
};

struct dev_pm_domain___331 {
	struct dev_pm_ops___331 ops;
	void (*detach)(struct device___331 *, bool);
	int (*activate)(struct device___331 *);
	void (*sync)(struct device___331 *);
	void (*dismiss)(struct device___331 *);
};

struct bus_type___331 {
	const char *name;
	const char *dev_name;
	struct device___331 *dev_root;
	const struct attribute_group___328 **bus_groups;
	const struct attribute_group___328 **dev_groups;
	const struct attribute_group___328 **drv_groups;
	int (*match)(struct device___331 *, struct device_driver___331 *);
	int (*uevent)(struct device___331 *, struct kobj_uevent_env *);
	int (*probe)(struct device___331 *);
	int (*remove)(struct device___331 *);
	void (*shutdown)(struct device___331 *);
	int (*online)(struct device___331 *);
	int (*offline)(struct device___331 *);
	int (*suspend)(struct device___331 *, pm_message_t);
	int (*resume)(struct device___331 *);
	int (*num_vf)(struct device___331 *);
	int (*dma_configure)(struct device___331 *);
	const struct dev_pm_ops___331 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___331 {
	const char *name;
	struct bus_type___331 *bus;
	struct module___295 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___331 *);
	int (*remove)(struct device___331 *);
	void (*shutdown)(struct device___331 *);
	int (*suspend)(struct device___331 *, pm_message_t);
	int (*resume)(struct device___331 *);
	const struct attribute_group___328 **groups;
	const struct dev_pm_ops___331 *pm;
	void (*coredump)(struct device___331 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct module_kobject___292 {
	struct kobject___351 kobj;
	struct module___295 *mod;
	struct kobject___351 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___292 {
	struct module___295 *mod;
	struct latch_tree_node node;
};

struct module_layout___292 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___292 mtn;
};

struct module_attribute___292;

struct kernel_param___292;

struct module___295 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___292 mkobj;
	struct module_attribute___292 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___351 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___292 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___292 core_layout;
	struct module_layout___292 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide46;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide47;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct device_attribute___43 {
	struct attribute attr;
	ssize_t (*show)(struct device___331 *, struct device_attribute___43 *, char *);
	ssize_t (*store)(struct device___331 *, struct device_attribute___43 *, const char *, size_t);
};

struct dma_map_ops___119 {
	void * (*alloc)(struct device___331 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___331 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___331 *, struct vm_area_struct___365 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___331 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___331 *, struct page___365 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___331 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___331 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___331 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___331 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___331 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___331 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide40;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___331 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___331 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___331 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___331 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___331 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___331 *, u64);
	u64 (*get_required_mask)(struct device___331 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___253;

struct fwnode_handle___253 {
	struct fwnode_handle___253 *secondary;
	const struct fwnode_operations___253 *ops;
};

struct dentry_operations___363;

struct super_block___363;

struct dentry___363 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___363 *d_parent;
	struct qstr d_name;
	struct inode___364 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___363 *d_op;
	struct super_block___363 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___363;

struct address_space___363 {
	struct inode___364 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___365 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___363 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___363;

struct block_device___363;

struct cdev___83;

struct inode___364 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___363 *i_op;
	struct super_block___363 *i_sb;
	struct address_space___363 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___365 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___181 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___364 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___363 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___363 *i_bdev;
		struct cdev___83 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___363 {
	int (*d_revalidate)(struct dentry___363 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___363 *, unsigned int);
	int (*d_hash)(const struct dentry___363 *, struct qstr *);
	int (*d_compare)(const struct dentry___363 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___363 *);
	int (*d_init)(struct dentry___363 *);
	void (*d_release)(struct dentry___363 *);
	void (*d_prune)(struct dentry___363 *);
	void (*d_iput)(struct dentry___363 *, struct inode___364 *);
	char * (*d_dname)(struct dentry___363 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___364 *);
	int (*d_manage)(const struct path___364 *, bool);
	struct dentry___363 * (*d_real)(struct dentry___363 *, const struct inode___364 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___363;

struct mem_dqinfo___363 {
	struct quota_format_type___363 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___363;

struct quota_info___363 {
	unsigned int flags;
	struct rw_semaphore___365 dqio_sem;
	struct inode___364 *files[3];
	struct mem_dqinfo___363 info[3];
	const struct quota_format_ops___363 *ops[3];
};

struct rcuwait___363 {
	struct task_struct___365 *task;
};

struct percpu_rw_semaphore___363 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___365 rw_sem;
	struct rcuwait___363 writer;
	int readers_block;
};

struct sb_writers___363 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___363 rw_sem[3];
};

struct file_system_type___363;

struct super_operations___363;

struct dquot_operations___363;

struct quotactl_ops___363;

struct super_block___363 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___363 *s_type;
	const struct super_operations___363 *s_op;
	const struct dquot_operations___363 *dq_op;
	const struct quotactl_ops___363 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___363 *s_root;
	struct rw_semaphore___365 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___363 *s_bdev;
	struct backing_dev_info___181 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___363 s_dquot;
	struct sb_writers___363 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___363 *s_d_op;
	int cleancache_poolid;
	struct shrinker___133 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

typedef int (*dev_page_fault_t___352)(struct vm_area_struct___365 *, long unsigned int, const struct page___365 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___352)(struct page___365 *, void *);

struct dev_pagemap___352 {
	dev_page_fault_t___352 page_fault;
	dev_page_free_t___352 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___331 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___364 {
	struct task_struct___365 *task;
	struct core_thread___364 *next;
};

struct core_state___364 {
	atomic_t nr_threads;
	struct core_thread___364 dumper;
	struct completion startup;
};

struct vm_fault___352 {
	struct vm_area_struct___365 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___365 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___365 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___364 prealloc_pte;
};

struct io_cq___101 {
	struct request_queue___97 *q;
	struct io_context___101 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___364 {
	struct file___364 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___364 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___363 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___364 *ia_file;
};

struct dquot___363 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___363 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___363 {
	int qf_fmt_id;
	const struct quota_format_ops___363 *qf_ops;
	struct module___295 *qf_owner;
	struct quota_format_type___363 *qf_next;
};

struct quota_format_ops___363 {
	int (*check_quota_file)(struct super_block___363 *, int);
	int (*read_file_info)(struct super_block___363 *, int);
	int (*write_file_info)(struct super_block___363 *, int);
	int (*free_file_info)(struct super_block___363 *, int);
	int (*read_dqblk)(struct dquot___363 *);
	int (*commit_dqblk)(struct dquot___363 *);
	int (*release_dqblk)(struct dquot___363 *);
	int (*get_next_id)(struct super_block___363 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___363 {
	int (*write_dquot)(struct dquot___363 *);
	struct dquot___363 * (*alloc_dquot)(struct super_block___363 *, int);
	void (*destroy_dquot)(struct dquot___363 *);
	int (*acquire_dquot)(struct dquot___363 *);
	int (*release_dquot)(struct dquot___363 *);
	int (*mark_dirty)(struct dquot___363 *);
	int (*write_info)(struct super_block___363 *, int);
	qsize_t * (*get_reserved_space)(struct inode___364 *);
	int (*get_projid)(struct inode___364 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___364 *, qsize_t *);
	int (*get_next_id)(struct super_block___363 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___363 {
	int (*quota_on)(struct super_block___363 *, int, int, const struct path___364 *);
	int (*quota_off)(struct super_block___363 *, int);
	int (*quota_enable)(struct super_block___363 *, unsigned int);
	int (*quota_disable)(struct super_block___363 *, unsigned int);
	int (*quota_sync)(struct super_block___363 *, int);
	int (*set_info)(struct super_block___363 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___363 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___363 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___363 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___363 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___363 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___363 {
	int (*writepage)(struct page___365 *, struct writeback_control___3 *);
	int (*readpage)(struct file___364 *, struct page___365 *);
	int (*writepages)(struct address_space___363 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___365 *);
	int (*readpages)(struct file___364 *, struct address_space___363 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___364 *, struct address_space___363 *, loff_t, unsigned int, unsigned int, struct page___365 **, void **);
	int (*write_end)(struct file___364 *, struct address_space___363 *, loff_t, unsigned int, unsigned int, struct page___365 *, void *);
	sector_t (*bmap)(struct address_space___363 *, sector_t);
	void (*invalidatepage)(struct page___365 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___365 *, gfp_t);
	void (*freepage)(struct page___365 *);
	ssize_t (*direct_IO)(struct kiocb___364 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___363 *, struct page___365 *, struct page___365 *, enum migrate_mode);
	bool (*isolate_page)(struct page___365 *, isolate_mode_t);
	void (*putback_page)(struct page___365 *);
	int (*launder_page)(struct page___365 *);
	int (*is_partially_uptodate)(struct page___365 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___365 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___363 *, struct page___365 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___364 *, sector_t *);
	void (*swap_deactivate)(struct file___364 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___363 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___364 *bd_inode;
	struct super_block___363 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___363 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___101 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___101 *bd_disk;
	struct request_queue___97 *bd_queue;
	struct backing_dev_info___181 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___83 {
	struct kobject___351 kobj;
	struct module___295 *owner;
	const struct file_operations___364 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___363 {
	struct dentry___363 * (*lookup)(struct inode___364 *, struct dentry___363 *, unsigned int);
	const char * (*get_link)(struct dentry___363 *, struct inode___364 *, struct delayed_call *);
	int (*permission)(struct inode___364 *, int);
	struct posix_acl * (*get_acl)(struct inode___364 *, int);
	int (*readlink)(struct dentry___363 *, char *, int);
	int (*create)(struct inode___364 *, struct dentry___363 *, umode_t, bool);
	int (*link)(struct dentry___363 *, struct inode___364 *, struct dentry___363 *);
	int (*unlink)(struct inode___364 *, struct dentry___363 *);
	int (*symlink)(struct inode___364 *, struct dentry___363 *, const char *);
	int (*mkdir)(struct inode___364 *, struct dentry___363 *, umode_t);
	int (*rmdir)(struct inode___364 *, struct dentry___363 *);
	int (*mknod)(struct inode___364 *, struct dentry___363 *, umode_t, dev_t);
	int (*rename)(struct inode___364 *, struct dentry___363 *, struct inode___364 *, struct dentry___363 *, unsigned int);
	int (*setattr)(struct dentry___363 *, struct iattr___363 *);
	int (*getattr)(const struct path___364 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___363 *, char *, size_t);
	int (*fiemap)(struct inode___364 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___364 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___364 *, struct dentry___363 *, struct file___364 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___364 *, struct dentry___363 *, umode_t);
	int (*set_acl)(struct inode___364 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___363 {
	void (*fl_copy_lock)(struct file_lock___364 *, struct file_lock___364 *);
	void (*fl_release_private)(struct file_lock___364 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___363;

struct lock_manager_operations___363;

struct file_lock___364 {
	struct file_lock___364 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___364 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___363 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___363 *fl_ops;
	const struct lock_manager_operations___363 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___363 {
	int (*lm_compare_owner)(struct file_lock___364 *, struct file_lock___364 *);
	long unsigned int (*lm_owner_key)(struct file_lock___364 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___364 *);
	int (*lm_grant)(struct file_lock___364 *, int);
	bool (*lm_break)(struct file_lock___364 *);
	int (*lm_change)(struct file_lock___364 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___364 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___363 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___363 *fa_next;
	struct file___364 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___363 {
	const char *name;
	int fs_flags;
	struct dentry___363 * (*mount)(struct file_system_type___363 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___363 *);
	struct module___295 *owner;
	struct file_system_type___363 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___363 {
	struct inode___364 * (*alloc_inode)(struct super_block___363 *);
	void (*destroy_inode)(struct inode___364 *);
	void (*dirty_inode)(struct inode___364 *, int);
	int (*write_inode)(struct inode___364 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___364 *);
	void (*evict_inode)(struct inode___364 *);
	void (*put_super)(struct super_block___363 *);
	int (*sync_fs)(struct super_block___363 *, int);
	int (*freeze_super)(struct super_block___363 *);
	int (*freeze_fs)(struct super_block___363 *);
	int (*thaw_super)(struct super_block___363 *);
	int (*unfreeze_fs)(struct super_block___363 *);
	int (*statfs)(struct dentry___363 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___363 *, int *, char *);
	void (*umount_begin)(struct super_block___363 *);
	int (*show_options)(struct seq_file___308 *, struct dentry___363 *);
	int (*show_devname)(struct seq_file___308 *, struct dentry___363 *);
	int (*show_path)(struct seq_file___308 *, struct dentry___363 *);
	int (*show_stats)(struct seq_file___308 *, struct dentry___363 *);
	ssize_t (*quota_read)(struct super_block___363 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___363 *, int, const char *, size_t, loff_t);
	struct dquot___363 ** (*get_dquots)(struct inode___364 *);
	int (*bdev_try_to_free_page)(struct super_block___363 *, struct page___365 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___363 *, struct shrink_control___133 *);
	long int (*free_cached_objects)(struct super_block___363 *, struct shrink_control___133 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___101 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___101 *last_lookup;
	struct hd_struct___101 *part[0];
};

struct block_device_operations___98 {
	int (*open)(struct block_device___363 *, fmode_t);
	void (*release)(struct gendisk___101 *, fmode_t);
	int (*rw_page)(struct block_device___363 *, sector_t, struct page___365 *, unsigned int);
	int (*ioctl)(struct block_device___363 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___363 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___101 *, unsigned int);
	int (*media_changed)(struct gendisk___101 *);
	void (*unlock_native_capacity)(struct gendisk___101 *);
	int (*revalidate_disk)(struct gendisk___101 *);
	int (*getgeo)(struct block_device___363 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___363 *, long unsigned int);
	int (*report_zones)(struct gendisk___101 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___295 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___352(struct page___365 *);

struct bdi_writeback_congested___181 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___181 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bsg_ops___97 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___97 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___97 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___97 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___97(struct request___97 *, blk_status_t);

struct request___97 {
	struct request_queue___97 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___34 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___181 *bio;
	struct bio___181 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___183 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___101 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___97 *saved_end_io;
		} flush;
	};
	struct gendisk___101 *rq_disk;
	struct hd_struct___101 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___97 *end_io;
	void *end_io_data;
	struct request___97 *next_rq;
};

struct fwnode_reference_args___253;

struct fwnode_endpoint___253;

struct fwnode_operations___253 {
	struct fwnode_handle___253 * (*get)(struct fwnode_handle___253 *);
	void (*put)(struct fwnode_handle___253 *);
	bool (*device_is_available)(const struct fwnode_handle___253 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___253 *, const struct device___331 *);
	bool (*property_present)(const struct fwnode_handle___253 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___253 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___253 *, const char *, const char **, size_t);
	struct fwnode_handle___253 * (*get_parent)(const struct fwnode_handle___253 *);
	struct fwnode_handle___253 * (*get_next_child_node)(const struct fwnode_handle___253 *, struct fwnode_handle___253 *);
	struct fwnode_handle___253 * (*get_named_child_node)(const struct fwnode_handle___253 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___253 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___253 *);
	struct fwnode_handle___253 * (*graph_get_next_endpoint)(const struct fwnode_handle___253 *, struct fwnode_handle___253 *);
	struct fwnode_handle___253 * (*graph_get_remote_endpoint)(const struct fwnode_handle___253 *);
	struct fwnode_handle___253 * (*graph_get_port_parent)(struct fwnode_handle___253 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___253 *, struct fwnode_endpoint___253 *);
};

struct fwnode_endpoint___253 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___253 *local_fwnode;
};

struct fwnode_reference_args___253 {
	struct fwnode_handle___253 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct blk_mq_hw_ctx___34 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___97 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags___4 *tags;
	struct blk_mq_tags___4 *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	unsigned int rh_reserved_nr_expired;
	struct hlist_node cpuhp_dead;
	struct kobject___351 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___363 *debugfs_dir;
	struct dentry___363 *sched_debugfs_dir;
	struct list_head hctx_list;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___97;

struct elevator_mq_ops___97 {
	int (*init_sched)(struct request_queue___97 *, struct elevator_type___97 *);
	void (*exit_sched)(struct elevator_queue___97 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___34 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___34 *, unsigned int);
	bool (*allow_merge)(struct request_queue___97 *, struct request___97 *, struct bio___181 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx___34 *, struct bio___181 *);
	int (*request_merge)(struct request_queue___97 *, struct request___97 **, struct bio___181 *);
	void (*request_merged)(struct request_queue___97 *, struct request___97 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___97 *, struct request___97 *, struct request___97 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___97 *, struct bio___181 *);
	void (*finish_request)(struct request___97 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___34 *, struct list_head *, bool);
	struct request___97 * (*dispatch_request)(struct blk_mq_hw_ctx___34 *);
	bool (*has_work)(struct blk_mq_hw_ctx___34 *);
	void (*completed_request)(struct request___97 *, u64);
	void (*started_request)(struct request___97 *);
	void (*requeue_request)(struct request___97 *);
	struct request___97 * (*former_request)(struct request_queue___97 *, struct request___97 *);
	struct request___97 * (*next_request)(struct request_queue___97 *, struct request___97 *);
	void (*init_icq)(struct io_cq___101 *);
	void (*exit_icq)(struct io_cq___101 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx___34 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___97;

struct elevator_type___97 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___97 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___97 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___295 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___97 {
	struct elevator_type___97 *type;
	void *elevator_data;
	struct kobject___351 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___97 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___97 *, char *);
	ssize_t (*store)(struct elevator_queue___97 *, const char *, size_t);
};

struct blk_mq_queue_data___34;

typedef blk_status_t queue_rq_fn___34(struct blk_mq_hw_ctx___34 *, const struct blk_mq_queue_data___34 *);

typedef void commit_rqs_fn___34(struct blk_mq_hw_ctx___34 *);

typedef bool get_budget_fn___34(struct blk_mq_hw_ctx___34 *);

typedef void put_budget_fn___34(struct blk_mq_hw_ctx___34 *);

typedef enum blk_eh_timer_return timeout_fn___34(struct request___97 *, bool);

typedef int poll_fn___34(struct blk_mq_hw_ctx___34 *);

typedef void complete_fn___34(struct request___97 *);

typedef int init_hctx_fn___34(struct blk_mq_hw_ctx___34 *, void *, unsigned int);

typedef void exit_hctx_fn___34(struct blk_mq_hw_ctx___34 *, unsigned int);

typedef int init_request_fn___34(struct blk_mq_tag_set___34 *, struct request___97 *, unsigned int, unsigned int);

typedef void exit_request_fn___34(struct blk_mq_tag_set___34 *, struct request___97 *, unsigned int);

typedef bool busy_fn___34(struct request_queue___97 *);

typedef int map_queues_fn___34(struct blk_mq_tag_set___34 *);

typedef void cleanup_rq_fn___34(struct request___97 *);

struct blk_mq_ops___34 {
	queue_rq_fn___34 *queue_rq;
	commit_rqs_fn___34 *commit_rqs;
	get_budget_fn___34 *get_budget;
	put_budget_fn___34 *put_budget;
	timeout_fn___34 *timeout;
	poll_fn___34 *poll;
	complete_fn___34 *complete;
	init_hctx_fn___34 *init_hctx;
	exit_hctx_fn___34 *exit_hctx;
	init_request_fn___34 *init_request;
	exit_request_fn___34 *exit_request;
	void (*initialize_rq_fn)(struct request___97 *);
	busy_fn___34 *busy;
	map_queues_fn___34 *map_queues;
	void (*show_rq)(struct seq_file___308 *, struct request___97 *);
	union {
		cleanup_rq_fn___34 *cleanup_rq;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide45;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct blk_mq_tag_set___34 {
	struct blk_mq_queue_map map[6];
	unsigned int nr_maps;
	const struct blk_mq_ops___34 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	struct blk_mq_tags___4 **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct pci_bus___31;

struct pci_slot___31 {
	struct pci_bus___31 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject___351 kobj;
};

struct pci_dev___31;

struct pci_ops___31;

struct pci_bus___31 {
	struct list_head node;
	struct pci_bus___31 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___31 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___31 *ops;
	struct msi_controller___2 *msi;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	int domain_nr;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___331 *bridge;
	struct device___331 dev;
	struct bin_attribute___327 *legacy_io;
	struct bin_attribute___327 *legacy_mem;
	unsigned int is_added: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
};

struct pci_driver___31;

struct pci_dev___31 {
	struct list_head bus_list;
	struct pci_bus___31 *bus;
	struct pci_bus___31 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___31 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u16 aer_cap;
	struct aer_stats *aer_stats;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	long unsigned int *dma_alias_mask;
	struct pci_driver___31 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	unsigned int imm_ready: 1;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int bridge_d3: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int hotplug_user_indicators: 1;
	unsigned int clear_retrain_link: 1;
	unsigned int d3_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	unsigned int ltr_path: 1;
	unsigned int eetlp_prefix_path: 1;
	pci_channel_state_t error_state;
	struct device___331 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int multifunction: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int ats_enabled: 1;
	unsigned int pasid_enabled: 1;
	unsigned int pri_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int reset_fn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int shpc_managed: 1;
	unsigned int is_thunderbolt: 1;
	unsigned int __aer_firmware_first_valid: 1;
	unsigned int __aer_firmware_first: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int irq_managed: 1;
	unsigned int has_secondary_link: 1;
	unsigned int non_compliant_bars: 1;
	unsigned int is_probed: 1;
	unsigned int link_active_reporting: 1;
	unsigned int untrusted: 1;
	unsigned int no_vf_scan: 1;
	unsigned int io_window: 1;
	unsigned int pref_window: 1;
	unsigned int pref_64_window: 1;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	struct bin_attribute___327 *rom_attr;
	int rom_attr_enabled;
	struct bin_attribute___327 *res_attr[17];
	struct bin_attribute___327 *res_attr_wc[17];
	unsigned int broken_cmd_compl: 1;
	const struct attribute_group___328 **msi_irq_groups;
	struct pci_vpd *vpd;
	union {
		struct pci_sriov *sriov;
		struct pci_dev___31 *physfn;
	};
	u16 ats_cap;
	u8 ats_stu;
	atomic_t ats_ref_cnt;
	u32 pri_reqs_alloc;
	u16 pasid_features;
	struct pci_p2pdma *p2pdma;
	phys_addr_t rom;
	size_t romlen;
	char *driver_override;
	long unsigned int priv_flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t pci_dev_extended_size_rh;
	struct pci_dev_extended_rh pci_dev_extended_rh;
};

struct pci_error_handlers___31;

struct pci_driver___31 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___31 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___31 *);
	int (*suspend)(struct pci_dev___31 *, pm_message_t);
	int (*suspend_late)(struct pci_dev___31 *, pm_message_t);
	int (*resume_early)(struct pci_dev___31 *);
	int (*resume)(struct pci_dev___31 *);
	void (*shutdown)(struct pci_dev___31 *);
	int (*sriov_configure)(struct pci_dev___31 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	const struct pci_error_handlers___31 *err_handler;
	const struct attribute_group___328 **groups;
	struct device_driver___331 driver;
	struct pci_dynids dynids;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct pci_ops___31 {
	int (*add_bus)(struct pci_bus___31 *);
	void (*remove_bus)(struct pci_bus___31 *);
	void * (*map_bus)(struct pci_bus___31 *, unsigned int, int);
	int (*read)(struct pci_bus___31 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___31 *, unsigned int, int, int, u32);
};

struct pci_error_handlers___31 {
	pci_ers_result_t (*error_detected)(struct pci_dev___31 *, enum pci_channel_state);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___31 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___31 *);
	void (*reset_prepare)(struct pci_dev___31 *);
	void (*reset_done)(struct pci_dev___31 *);
	void (*resume)(struct pci_dev___31 *);
};

typedef int (*key_restrict_link_func_t___336)(struct key___335 *, const struct key_type *, const union key_payload *, struct key___335 *);

struct key_restriction___335;

struct key___335 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___365 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___335 *restrict_link;
};

struct key_restriction___335 {
	key_restrict_link_func_t___336 check;
	struct key___335 *key;
	struct key_type *keytype;
};

struct seq_operations___307 {
	void * (*start)(struct seq_file___308 *, loff_t *);
	void (*stop)(struct seq_file___308 *, void *);
	void * (*next)(struct seq_file___308 *, void *, loff_t *);
	int (*show)(struct seq_file___308 *, void *);
};

struct blk_mq_queue_data___34 {
	struct request___97 *rq;
	bool last;
	long unsigned int rh_reserved1;
};

struct Scsi_Host___10;

struct scsi_device___15;

struct scsi_cmnd___10;

struct scsi_target___15;

struct scsi_host_template___10 {
	struct module___295 *module;
	const char *name;
	const char * (*info)(struct Scsi_Host___10 *);
	int (*ioctl)(struct scsi_device___15 *, int, void *);
	int (*queuecommand)(struct Scsi_Host___10 *, struct scsi_cmnd___10 *);
	int (*eh_abort_handler)(struct scsi_cmnd___10 *);
	int (*eh_device_reset_handler)(struct scsi_cmnd___10 *);
	int (*eh_target_reset_handler)(struct scsi_cmnd___10 *);
	int (*eh_bus_reset_handler)(struct scsi_cmnd___10 *);
	int (*eh_host_reset_handler)(struct scsi_cmnd___10 *);
	int (*slave_alloc)(struct scsi_device___15 *);
	int (*slave_configure)(struct scsi_device___15 *);
	void (*slave_destroy)(struct scsi_device___15 *);
	int (*target_alloc)(struct scsi_target___15 *);
	void (*target_destroy)(struct scsi_target___15 *);
	int (*scan_finished)(struct Scsi_Host___10 *, long unsigned int);
	void (*scan_start)(struct Scsi_Host___10 *);
	int (*change_queue_depth)(struct scsi_device___15 *, int);
	int (*map_queues)(struct Scsi_Host___10 *);
	int (*bios_param)(struct scsi_device___15 *, struct block_device___363 *, sector_t, int *);
	void (*unlock_native_capacity)(struct scsi_device___15 *);
	int (*show_info)(struct seq_file___308 *, struct Scsi_Host___10 *);
	int (*write_info)(struct Scsi_Host___10 *, char *, int);
	enum blk_eh_timer_return (*eh_timed_out)(struct scsi_cmnd___10 *);
	int (*host_reset)(struct Scsi_Host___10 *, int);
	const char *proc_name;
	struct proc_dir_entry *proc_dir;
	int can_queue;
	int this_id;
	short unsigned int sg_tablesize;
	short unsigned int sg_prot_tablesize;
	unsigned int max_sectors;
	long unsigned int dma_boundary;
	short int cmd_per_lun;
	unsigned char present;
	int tag_alloc_policy;
	unsigned int track_queue_depth: 1;
	unsigned int supported_mode: 2;
	unsigned int unchecked_isa_dma: 1;
	unsigned int use_clustering: 1;
	unsigned int emulated: 1;
	unsigned int skip_settle_delay: 1;
	unsigned int no_write_same: 1;
	unsigned int force_blk_mq: 1;
	unsigned int max_host_blocked;
	struct device_attribute___43 **shost_attrs;
	struct device_attribute___43 **sdev_attrs;
	const struct attribute_group___328 **sdev_groups;
	u64 vendor_id;
	unsigned int cmd_size;
	struct scsi_host_cmd_pool *cmd_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct Scsi_Host___10 {
	struct list_head __devices;
	struct list_head __targets;
	struct list_head starved_list;
	spinlock_t default_lock;
	spinlock_t *host_lock;
	struct mutex scan_mutex;
	struct list_head eh_cmd_q;
	struct task_struct___365 *ehandler;
	struct completion *eh_action;
	wait_queue_head_t host_wait;
	struct scsi_host_template___10 *hostt;
	struct scsi_transport_template *transportt;
	struct blk_mq_tag_set___34 tag_set;
	atomic_t host_busy;
	atomic_t host_blocked;
	unsigned int host_failed;
	unsigned int host_eh_scheduled;
	unsigned int host_no;
	int eh_deadline;
	long unsigned int last_reset;
	unsigned int max_channel;
	unsigned int max_id;
	u64 max_lun;
	unsigned int unique_id;
	short unsigned int max_cmd_len;
	int this_id;
	int can_queue;
	short int cmd_per_lun;
	short unsigned int sg_tablesize;
	short unsigned int sg_prot_tablesize;
	unsigned int max_sectors;
	long unsigned int dma_boundary;
	unsigned int nr_hw_queues;
	long unsigned int cmd_serial_number;
	unsigned int active_mode: 2;
	unsigned int unchecked_isa_dma: 1;
	unsigned int use_clustering: 1;
	unsigned int host_self_blocked: 1;
	unsigned int reverse_ordering: 1;
	unsigned int tmf_in_progress: 1;
	unsigned int async_scan: 1;
	unsigned int eh_noresume: 1;
	unsigned int no_write_same: 1;
	unsigned int use_cmd_list: 1;
	unsigned int short_inquiry: 1;
	char work_q_name[20];
	struct workqueue_struct *work_q;
	struct workqueue_struct *tmf_work_q;
	unsigned int no_scsi2_lun_in_cdb: 1;
	unsigned int max_host_blocked;
	unsigned int prot_capabilities;
	unsigned char prot_guard_type;
	long unsigned int base;
	long unsigned int io_port;
	unsigned char n_io_port;
	unsigned char dma_channel;
	unsigned int irq;
	enum scsi_host_state shost_state;
	struct device___331 shost_gendev;
	struct device___331 shost_dev;
	void *shost_data;
	struct device___331 *dma_dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int hostdata[0];
};

struct scsi_device___15 {
	struct Scsi_Host___10 *host;
	struct request_queue___97 *request_queue;
	struct list_head siblings;
	struct list_head same_target_siblings;
	atomic_t device_busy;
	atomic_t device_blocked;
	spinlock_t list_lock;
	struct list_head cmd_list;
	struct list_head starved_entry;
	short unsigned int queue_depth;
	short unsigned int max_queue_depth;
	short unsigned int last_queue_full_depth;
	short unsigned int last_queue_full_count;
	long unsigned int last_queue_full_time;
	long unsigned int queue_ramp_up_period;
	long unsigned int last_queue_ramp_up;
	unsigned int id;
	unsigned int channel;
	u64 lun;
	unsigned int manufacturer;
	unsigned int sector_size;
	void *hostdata;
	unsigned char type;
	char scsi_level;
	char inq_periph_qual;
	struct mutex inquiry_mutex;
	unsigned char inquiry_len;
	unsigned char *inquiry;
	const char *vendor;
	const char *model;
	const char *rev;
	struct scsi_vpd *vpd_pg83;
	struct scsi_vpd *vpd_pg80;
	unsigned char current_tag;
	struct scsi_target___15 *sdev_target;
	blist_flags_t sdev_bflags;
	unsigned int eh_timeout;
	unsigned int removable: 1;
	unsigned int changed: 1;
	unsigned int busy: 1;
	unsigned int lockable: 1;
	unsigned int locked: 1;
	unsigned int borken: 1;
	unsigned int disconnect: 1;
	unsigned int soft_reset: 1;
	unsigned int sdtr: 1;
	unsigned int wdtr: 1;
	unsigned int ppr: 1;
	unsigned int tagged_supported: 1;
	unsigned int simple_tags: 1;
	unsigned int was_reset: 1;
	unsigned int expecting_cc_ua: 1;
	unsigned int use_10_for_rw: 1;
	unsigned int use_10_for_ms: 1;
	unsigned int no_report_opcodes: 1;
	unsigned int no_write_same: 1;
	unsigned int use_16_for_rw: 1;
	unsigned int skip_ms_page_8: 1;
	unsigned int skip_ms_page_3f: 1;
	unsigned int skip_vpd_pages: 1;
	unsigned int try_vpd_pages: 1;
	unsigned int use_192_bytes_for_3f: 1;
	unsigned int no_start_on_add: 1;
	unsigned int allow_restart: 1;
	unsigned int manage_start_stop: 1;
	unsigned int start_stop_pwr_cond: 1;
	unsigned int no_uld_attach: 1;
	unsigned int select_no_atn: 1;
	unsigned int fix_capacity: 1;
	unsigned int guess_capacity: 1;
	unsigned int retry_hwerror: 1;
	unsigned int last_sector_bug: 1;
	unsigned int no_read_disc_info: 1;
	unsigned int no_read_capacity_16: 1;
	unsigned int try_rc_10_first: 1;
	unsigned int security_supported: 1;
	unsigned int is_visible: 1;
	unsigned int wce_default_on: 1;
	unsigned int no_dif: 1;
	unsigned int broken_fua: 1;
	unsigned int lun_in_cdb: 1;
	unsigned int unmap_limit_for_ws: 1;
	atomic_t disk_events_disable_depth;
	long unsigned int supported_events[1];
	long unsigned int pending_events[1];
	struct list_head event_list;
	struct work_struct event_work;
	unsigned int max_device_blocked;
	atomic_t iorequest_cnt;
	atomic_t iodone_cnt;
	atomic_t ioerr_cnt;
	struct device___331 sdev_gendev;
	struct device___331 sdev_dev;
	struct execute_work ew;
	struct work_struct requeue_work;
	struct scsi_device_handler *handler;
	void *handler_data;
	unsigned char access_state;
	struct mutex state_mutex;
	enum scsi_device_state sdev_state;
	struct task_struct___365 *quiesced_by;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int sdev_data[0];
};

struct scsi_cmnd___10 {
	struct scsi_request req;
	struct scsi_device___15 *device;
	struct list_head list;
	struct list_head eh_entry;
	struct delayed_work abort_work;
	struct callback_head rcu;
	int eh_eflags;
	long unsigned int serial_number;
	long unsigned int jiffies_at_alloc;
	int retries;
	int allowed;
	unsigned char prot_op;
	unsigned char prot_type;
	unsigned char prot_flags;
	short unsigned int cmd_len;
	enum dma_data_direction sc_data_direction;
	unsigned char *cmnd;
	struct scsi_data_buffer sdb;
	struct scsi_data_buffer *prot_sdb;
	unsigned int underflow;
	unsigned int transfersize;
	struct request___97 *request;
	unsigned char *sense_buffer;
	void (*scsi_done)(struct scsi_cmnd___10 *);
	struct scsi_pointer SCp;
	unsigned char *host_scribble;
	int result;
	int flags;
	long unsigned int state;
	unsigned char tag;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct scsi_target___15 {
	struct scsi_device___15 *starget_sdev_user;
	struct list_head siblings;
	struct list_head devices;
	struct device___331 dev;
	struct kref reap_ref;
	unsigned int channel;
	unsigned int id;
	unsigned int create: 1;
	unsigned int single_lun: 1;
	unsigned int pdt_1f_for_no_lun: 1;
	unsigned int no_report_luns: 1;
	unsigned int expecting_lun_change: 1;
	atomic_t target_busy;
	atomic_t target_blocked;
	unsigned int can_queue;
	unsigned int max_target_blocked;
	char scsi_level;
	enum scsi_target_state state;
	void *hostdata;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int starget_data[0];
};

struct kernel_param_ops___292 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___292 *);
	int (*get)(char *, const struct kernel_param___292 *);
	void (*free)(void *);
};

struct kparam_array___292;

struct kernel_param___292 {
	const char *name;
	struct module___295 *mod;
	const struct kernel_param_ops___292 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___292 *arr;
	};
};

struct kparam_array___292 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___292 *ops;
	void *elem;
};

struct module_attribute___292 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___292 *, struct module_kobject___292 *, char *);
	ssize_t (*store)(struct module_attribute___292 *, struct module_kobject___292 *, const char *, size_t);
	void (*setup)(struct module___295 *, const char *);
	int (*test)(struct module___295 *);
	void (*free)(struct module___295 *);
};

enum ata_lpm_hints {
	ATA_LPM_EMPTY = 1,
	ATA_LPM_HIPM = 2,
	ATA_LPM_WAKE_ONLY = 4,
};

struct ata_queued_cmd___3;

typedef void (*ata_qc_cb_t___3)(struct ata_queued_cmd___3 *);

struct ata_port___3;

struct ata_device___3;

struct ata_queued_cmd___3 {
	struct ata_port___3 *ap;
	struct ata_device___3 *dev;
	struct scsi_cmnd___10 *scsicmd;
	void (*scsidone)(struct scsi_cmnd___10 *);
	struct ata_taskfile tf;
	u8 cdb[16];
	long unsigned int flags;
	unsigned int tag;
	unsigned int hw_tag;
	unsigned int n_elem;
	unsigned int orig_n_elem;
	int dma_dir;
	unsigned int sect_size;
	unsigned int nbytes;
	unsigned int extrabytes;
	unsigned int curbytes;
	struct scatterlist sgent;
	struct scatterlist *sg;
	struct scatterlist *cursg;
	unsigned int cursg_ofs;
	unsigned int err_mask;
	struct ata_taskfile result_tf;
	ata_qc_cb_t___3 complete_fn;
	void *private_data;
	void *lldd_task;
};

struct ata_link___3;

typedef int (*ata_prereset_fn_t___3)(struct ata_link___3 *, long unsigned int);

struct ata_eh_info___3 {
	struct ata_device___3 *dev;
	u32 serror;
	unsigned int err_mask;
	unsigned int action;
	unsigned int dev_action[2];
	unsigned int flags;
	unsigned int probe_mask;
	char desc[80];
	int desc_len;
};

struct ata_eh_context___3 {
	struct ata_eh_info___3 i;
	int tries[2];
	int cmd_timeout_idx[12];
	unsigned int classes[2];
	unsigned int did_probe_mask;
	unsigned int unloaded_mask;
	unsigned int saved_ncq_enabled;
	u8 saved_xfer_mode[2];
	long unsigned int last_reset;
};

struct ata_device___3 {
	struct ata_link___3 *link;
	unsigned int devno;
	unsigned int horkage;
	long unsigned int flags;
	struct scsi_device___15 *sdev;
	void *private_data;
	union acpi_object *gtf_cache;
	unsigned int gtf_filter;
	struct device___331 tdev;
	u64 n_sectors;
	u64 n_native_sectors;
	unsigned int class;
	long unsigned int unpark_deadline;
	u8 pio_mode;
	u8 dma_mode;
	u8 xfer_mode;
	unsigned int xfer_shift;
	unsigned int multi_count;
	unsigned int max_sectors;
	unsigned int cdb_len;
	long unsigned int pio_mask;
	long unsigned int mwdma_mask;
	long unsigned int udma_mask;
	u16 cylinders;
	u16 heads;
	u16 sectors;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	union {
		u16 id[256];
		u32 gscr[128];
	};
	u8 devslp_timing[8];
	u8 ncq_send_recv_cmds[20];
	u8 ncq_non_data_cmds[64];
	u32 zac_zoned_cap;
	u32 zac_zones_optimal_open;
	u32 zac_zones_optimal_nonseq;
	u32 zac_zones_max_open;
	int spdn_cnt;
	struct ata_ering ering;
	long: 64;
};

struct ata_link___3 {
	struct ata_port___3 *ap;
	int pmp;
	struct device___331 tdev;
	unsigned int active_tag;
	u32 sactive;
	unsigned int flags;
	u32 saved_scontrol;
	unsigned int hw_sata_spd_limit;
	unsigned int sata_spd_limit;
	unsigned int sata_spd;
	enum ata_lpm_policy lpm_policy;
	struct ata_eh_info___3 eh_info;
	struct ata_eh_context___3 eh_context;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ata_device___3 device[2];
	long unsigned int last_lpm_change;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef int (*ata_reset_fn_t___3)(struct ata_link___3 *, unsigned int *, long unsigned int);

typedef void (*ata_postreset_fn_t___3)(struct ata_link___3 *, unsigned int *);

struct ata_port_operations___3;

struct ata_host___3 {
	spinlock_t lock;
	struct device___331 *dev;
	void * const *iomap;
	unsigned int n_ports;
	unsigned int n_tags;
	void *private_data;
	struct ata_port_operations___3 *ops;
	long unsigned int flags;
	struct kref kref;
	struct mutex eh_mutex;
	struct task_struct___365 *eh_owner;
	struct ata_port___3 *simplex_claimed;
	struct ata_port___3 *ports[0];
};

struct ata_port_operations___3 {
	int (*qc_defer)(struct ata_queued_cmd___3 *);
	int (*check_atapi_dma)(struct ata_queued_cmd___3 *);
	void (*qc_prep)(struct ata_queued_cmd___3 *);
	unsigned int (*qc_issue)(struct ata_queued_cmd___3 *);
	bool (*qc_fill_rtf)(struct ata_queued_cmd___3 *);
	int (*cable_detect)(struct ata_port___3 *);
	long unsigned int (*mode_filter)(struct ata_device___3 *, long unsigned int);
	void (*set_piomode)(struct ata_port___3 *, struct ata_device___3 *);
	void (*set_dmamode)(struct ata_port___3 *, struct ata_device___3 *);
	int (*set_mode)(struct ata_link___3 *, struct ata_device___3 **);
	unsigned int (*read_id)(struct ata_device___3 *, struct ata_taskfile *, u16 *);
	void (*dev_config)(struct ata_device___3 *);
	void (*freeze)(struct ata_port___3 *);
	void (*thaw)(struct ata_port___3 *);
	ata_prereset_fn_t___3 prereset;
	ata_reset_fn_t___3 softreset;
	ata_reset_fn_t___3 hardreset;
	ata_postreset_fn_t___3 postreset;
	ata_prereset_fn_t___3 pmp_prereset;
	ata_reset_fn_t___3 pmp_softreset;
	ata_reset_fn_t___3 pmp_hardreset;
	ata_postreset_fn_t___3 pmp_postreset;
	void (*error_handler)(struct ata_port___3 *);
	void (*lost_interrupt)(struct ata_port___3 *);
	void (*post_internal_cmd)(struct ata_queued_cmd___3 *);
	void (*sched_eh)(struct ata_port___3 *);
	void (*end_eh)(struct ata_port___3 *);
	int (*scr_read)(struct ata_link___3 *, unsigned int, u32 *);
	int (*scr_write)(struct ata_link___3 *, unsigned int, u32);
	void (*pmp_attach)(struct ata_port___3 *);
	void (*pmp_detach)(struct ata_port___3 *);
	int (*set_lpm)(struct ata_link___3 *, enum ata_lpm_policy, unsigned int);
	int (*port_suspend)(struct ata_port___3 *, pm_message_t);
	int (*port_resume)(struct ata_port___3 *);
	int (*port_start)(struct ata_port___3 *);
	void (*port_stop)(struct ata_port___3 *);
	void (*host_stop)(struct ata_host___3 *);
	void (*sff_dev_select)(struct ata_port___3 *, unsigned int);
	void (*sff_set_devctl)(struct ata_port___3 *, u8);
	u8 (*sff_check_status)(struct ata_port___3 *);
	u8 (*sff_check_altstatus)(struct ata_port___3 *);
	void (*sff_tf_load)(struct ata_port___3 *, const struct ata_taskfile *);
	void (*sff_tf_read)(struct ata_port___3 *, struct ata_taskfile *);
	void (*sff_exec_command)(struct ata_port___3 *, const struct ata_taskfile *);
	unsigned int (*sff_data_xfer)(struct ata_queued_cmd___3 *, unsigned char *, unsigned int, int);
	void (*sff_irq_on)(struct ata_port___3 *);
	bool (*sff_irq_check)(struct ata_port___3 *);
	void (*sff_irq_clear)(struct ata_port___3 *);
	void (*sff_drain_fifo)(struct ata_queued_cmd___3 *);
	void (*bmdma_setup)(struct ata_queued_cmd___3 *);
	void (*bmdma_start)(struct ata_queued_cmd___3 *);
	void (*bmdma_stop)(struct ata_queued_cmd___3 *);
	u8 (*bmdma_status)(struct ata_port___3 *);
	ssize_t (*em_show)(struct ata_port___3 *, char *);
	ssize_t (*em_store)(struct ata_port___3 *, const char *, size_t);
	ssize_t (*sw_activity_show)(struct ata_device___3 *, char *);
	ssize_t (*sw_activity_store)(struct ata_device___3 *, enum sw_activity);
	ssize_t (*transmit_led_message)(struct ata_port___3 *, u32, ssize_t);
	void (*phy_reset)(struct ata_port___3 *);
	void (*eng_timeout)(struct ata_port___3 *);
	const struct ata_port_operations___3 *inherits;
};

struct ata_port___3 {
	struct Scsi_Host___10 *scsi_host;
	struct ata_port_operations___3 *ops;
	spinlock_t *lock;
	long unsigned int flags;
	unsigned int pflags;
	unsigned int print_id;
	unsigned int local_port_no;
	unsigned int port_no;
	struct ata_ioports ioaddr;
	u8 ctl;
	u8 last_ctl;
	struct ata_link___3 *sff_pio_task_link;
	struct delayed_work sff_pio_task;
	struct ata_bmdma_prd *bmdma_prd;
	dma_addr_t bmdma_prd_dma;
	unsigned int pio_mask;
	unsigned int mwdma_mask;
	unsigned int udma_mask;
	unsigned int cbl;
	struct ata_queued_cmd___3 qcmd[33];
	long unsigned int sas_tag_allocated;
	u64 qc_active;
	int nr_active_links;
	unsigned int sas_last_tag;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ata_link___3 link;
	struct ata_link___3 *slave_link;
	int nr_pmp_links;
	struct ata_link___3 *pmp_link;
	struct ata_link___3 *excl_link;
	struct ata_port_stats stats;
	struct ata_host___3 *host;
	struct device___331 *dev;
	struct device___331 tdev;
	struct mutex scsi_scan_mutex;
	struct delayed_work hotplug_task;
	struct work_struct scsi_rescan_task;
	unsigned int hsm_task_state;
	u32 msg_enable;
	struct list_head eh_done_q;
	wait_queue_head_t eh_wait_q;
	int eh_tries;
	struct completion park_req_pending;
	pm_message_t pm_mesg;
	enum ata_lpm_policy target_lpm_policy;
	struct timer_list fastdrain_timer;
	long unsigned int fastdrain_cnt;
	int em_message_type;
	void *private_data;
	struct ata_acpi_gtm __acpi_init_gtm;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sector_buf[512];
};

struct ata_port_info___3 {
	long unsigned int flags;
	long unsigned int link_flags;
	long unsigned int pio_mask;
	long unsigned int mwdma_mask;
	long unsigned int udma_mask;
	struct ata_port_operations___3 *port_ops;
	void *private_data;
};

enum {
	ATA_EH_SPDN_NCQ_OFF = 1,
	ATA_EH_SPDN_SPEED_DOWN = 2,
	ATA_EH_SPDN_FALLBACK_TO_PIO = 4,
	ATA_EH_SPDN_KEEP_ERRORS = 8,
	ATA_EFLAG_IS_IO = 1,
	ATA_EFLAG_DUBIOUS_XFER = 2,
	ATA_EFLAG_OLD_ER = 2147483648,
	ATA_ECAT_NONE = 0,
	ATA_ECAT_ATA_BUS = 1,
	ATA_ECAT_TOUT_HSM = 2,
	ATA_ECAT_UNK_DEV = 3,
	ATA_ECAT_DUBIOUS_NONE = 4,
	ATA_ECAT_DUBIOUS_ATA_BUS = 5,
	ATA_ECAT_DUBIOUS_TOUT_HSM = 6,
	ATA_ECAT_DUBIOUS_UNK_DEV = 7,
	ATA_ECAT_NR = 8,
	ATA_EH_CMD_DFL_TIMEOUT = 5000,
	ATA_EH_RESET_COOL_DOWN = 5000,
	ATA_EH_PRERESET_TIMEOUT = 10000,
	ATA_EH_FASTDRAIN_INTERVAL = 3000,
	ATA_EH_UA_TRIES = 5,
	ATA_EH_PROBE_TRIAL_INTERVAL = 60000,
	ATA_EH_PROBE_TRIALS = 2,
};

struct ata_eh_cmd_timeout_ent {
	const u8 *commands;
	const long unsigned int *timeouts;
};

struct speed_down_verdict_arg {
	u64 since;
	int xfer_ok;
	int nr_errors[8];
};

struct transport_class___2 {
	struct class___330 class;
	int (*setup)(struct transport_container___6 *, struct device___330 *, struct device___330 *);
	int (*configure)(struct transport_container___6 *, struct device___330 *, struct device___330 *);
	int (*remove)(struct transport_container___6 *, struct device___330 *, struct device___330 *);
};

struct ata_internal {
	struct scsi_transport_template___5 t;
	struct device_attribute___42 private_port_attrs[3];
	struct device_attribute___42 private_link_attrs[3];
	struct device_attribute___42 private_dev_attrs[9];
	struct transport_container___6 link_attr_cont;
	struct transport_container___6 dev_attr_cont;
	struct device_attribute___42 *link_attrs[4];
	struct device_attribute___42 *port_attrs[4];
	struct device_attribute___42 *dev_attrs[10];
};

struct ata_show_ering_arg {
	char *buf;
	int written;
};

struct module___296;

struct file___365;

struct kiocb___365;

struct poll_table_struct___218;

struct vm_area_struct___366;

struct inode___365;

struct file_lock___365;

struct page___366;

struct seq_file___309;

struct file_operations___365 {
	struct module___296 *owner;
	loff_t (*llseek)(struct file___365 *, loff_t, int);
	ssize_t (*read)(struct file___365 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___365 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___365 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___365 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___365 *, bool);
	int (*iterate)(struct file___365 *, struct dir_context *);
	int (*iterate_shared)(struct file___365 *, struct dir_context *);
	__poll_t (*poll)(struct file___365 *, struct poll_table_struct___218 *);
	long int (*unlocked_ioctl)(struct file___365 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___365 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___365 *, struct vm_area_struct___366 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___365 *, struct file___365 *);
	int (*flush)(struct file___365 *, fl_owner_t);
	int (*release)(struct inode___365 *, struct file___365 *);
	int (*fsync)(struct file___365 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___365 *, int);
	int (*lock)(struct file___365 *, int, struct file_lock___365 *);
	ssize_t (*sendpage)(struct file___365 *, struct page___366 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___365 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___365 *, int, struct file_lock___365 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___365 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___365 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___365 *, long int, struct file_lock___365 **, void **);
	long int (*fallocate)(struct file___365 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___309 *, struct file___365 *);
	ssize_t (*copy_file_range)(struct file___365 *, loff_t, struct file___365 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___365 *, loff_t, struct file___365 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___365 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___365 {
	u64 seqnum;
	struct vm_area_struct___366 *vmas[4];
};

struct page_frag___365 {
	struct page___366 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___365;

struct cred___336;

struct bio_list___182;

struct backing_dev_info___182;

struct io_context___102;

struct request_queue___98;

struct vm_struct___271;

struct task_struct___366 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___366 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___365 *mm;
	struct mm_struct___365 *active_mm;
	struct vmacache___365 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___366 *real_parent;
	struct task_struct___366 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___366 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___217 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___217 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___217 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___336 *ptracer_cred;
	const struct cred___336 *real_cred;
	const struct cred___336 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___366 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___182 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___182 *backing_dev_info;
	struct io_context___102 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___365 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___98 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___366 *oom_reaper_list;
	struct vm_struct___271 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___141 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___364;

struct super_block___364;

struct dentry___364 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___364 *d_parent;
	struct qstr d_name;
	struct inode___365 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___364 *d_op;
	struct super_block___364 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct rw_semaphore___366 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___366 *owner;
};

struct address_space_operations___364;

struct address_space___364 {
	struct inode___365 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___366 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___364 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___364;

struct bdi_writeback___182;

struct block_device___364;

struct cdev___84;

struct inode___365 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___364 *i_op;
	struct super_block___364 *i_sb;
	struct address_space___364 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___366 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___182 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___365 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___364 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___364 *i_bdev;
		struct cdev___84 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___365;

struct dentry_operations___364 {
	int (*d_revalidate)(struct dentry___364 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___364 *, unsigned int);
	int (*d_hash)(const struct dentry___364 *, struct qstr *);
	int (*d_compare)(const struct dentry___364 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___364 *);
	int (*d_init)(struct dentry___364 *);
	void (*d_release)(struct dentry___364 *);
	void (*d_prune)(struct dentry___364 *);
	void (*d_iput)(struct dentry___364 *, struct inode___365 *);
	char * (*d_dname)(struct dentry___364 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___365 *);
	int (*d_manage)(const struct path___365 *, bool);
	struct dentry___364 * (*d_real)(struct dentry___364 *, const struct inode___365 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___364;

struct mem_dqinfo___364 {
	struct quota_format_type___364 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___364;

struct quota_info___364 {
	unsigned int flags;
	struct rw_semaphore___366 dqio_sem;
	struct inode___365 *files[3];
	struct mem_dqinfo___364 info[3];
	const struct quota_format_ops___364 *ops[3];
};

struct rcuwait___364 {
	struct task_struct___366 *task;
};

struct percpu_rw_semaphore___364 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___366 rw_sem;
	struct rcuwait___364 writer;
	int readers_block;
};

struct sb_writers___364 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___364 rw_sem[3];
};

struct file_system_type___364;

struct super_operations___364;

struct dquot_operations___364;

struct quotactl_ops___364;

struct super_block___364 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___364 *s_type;
	const struct super_operations___364 *s_op;
	const struct dquot_operations___364 *dq_op;
	const struct quotactl_ops___364 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___364 *s_root;
	struct rw_semaphore___366 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___364 *s_bdev;
	struct backing_dev_info___182 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___364 s_dquot;
	struct sb_writers___364 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___364 *s_d_op;
	int cleancache_poolid;
	struct shrinker___133 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct path___365 {
	struct vfsmount *mnt;
	struct dentry___364 *dentry;
};

typedef struct page___366 *pgtable_t___365;

struct dev_pagemap___353;

struct page___366 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___364 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___366 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___365 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___365 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___353 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___365;

struct lruvec___365 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___365 *pgdat;
};

struct zone___365 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___365 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___365 {
	struct zone___365 *zone;
	int zone_idx;
};

struct zonelist___365 {
	struct zoneref___365 _zonerefs[25];
};

struct pglist_data___365 {
	struct zone___365 node_zones[3];
	struct zonelist___365 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___366 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___366 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___365 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___366 {
	void *stack;
	struct task_struct___366 *task;
	long int status;
};

struct blocking_notifier_head___365 {
	struct rw_semaphore___366 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___353;

struct vm_area_struct___366 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___366 *vm_next;
	struct vm_area_struct___366 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___365 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___353 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___365 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___365;

struct mm_struct___365 {
	struct {
		struct vm_area_struct___366 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___365 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___366 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___365 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___366 *owner;
		struct user_namespace___3 *user_ns;
		struct file___365 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___365 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___353)(struct vm_area_struct___366 *, long unsigned int, const struct page___366 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___353)(struct page___366 *, void *);

struct device___332;

struct dev_pagemap___353 {
	dev_page_fault_t___353 page_fault;
	dev_page_free_t___353 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___332 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct file___365 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___365 f_path;
	struct inode___365 *f_inode;
	const struct file_operations___365 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___217 f_owner;
	const struct cred___336 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___364 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___353;

struct vm_operations_struct___353 {
	void (*open)(struct vm_area_struct___366 *);
	void (*close)(struct vm_area_struct___366 *);
	int (*split)(struct vm_area_struct___366 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___366 *);
	vm_fault_t (*fault)(struct vm_fault___353 *);
	vm_fault_t (*huge_fault)(struct vm_fault___353 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___353 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___366 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___353 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___353 *);
	int (*access)(struct vm_area_struct___366 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___366 *);
	int (*set_policy)(struct vm_area_struct___366 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___366 *, long unsigned int);
	struct page___366 * (*find_special_page)(struct vm_area_struct___366 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___365 {
	struct task_struct___366 *task;
	struct core_thread___365 *next;
};

struct core_state___365 {
	atomic_t nr_threads;
	struct core_thread___365 dumper;
	struct completion startup;
};

struct vm_fault___353 {
	struct vm_area_struct___366 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___366 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___366 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___365 prealloc_pte;
};

struct key___336;

struct user_struct___336 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___336 *uid_keyring;
	struct key___336 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___336 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___336 *session_keyring;
	struct key___336 *process_keyring;
	struct key___336 *thread_keyring;
	struct key___336 *request_key_auth;
	void *security;
	struct user_struct___336 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct bio___182;

struct bio_list___182 {
	struct bio___182 *head;
	struct bio___182 *tail;
};

struct bdi_writeback_congested___182;

struct bdi_writeback___182 {
	struct backing_dev_info___182 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___182 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___157 *memcg_css;
	struct cgroup_subsys_state___157 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___182 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___182 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___332 *dev;
	struct device___332 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___364 *debug_dir;
	struct dentry___364 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___102;

struct io_context___102 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___102 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

typedef blk_qc_t make_request_fn___98(struct request_queue___98 *, struct bio___182 *);

struct request___98;

typedef int dma_drain_needed_fn___98(struct request___98 *);

struct kset___351;

struct kobj_type___351;

struct kernfs_node___359;

struct kobject___352 {
	const char *name;
	struct list_head entry;
	struct kobject___352 *parent;
	struct kset___351 *kset;
	struct kobj_type___351 *ktype;
	struct kernfs_node___359 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___98;

struct bsg_class_device___98 {
	struct device___332 *class_dev;
	int minor;
	struct request_queue___98 *queue;
	const struct bsg_ops___98 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___182 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___182 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___98;

struct blk_mq_ops___35;

struct blk_mq_hw_ctx___35;

struct blk_mq_tag_set___35;

struct request_queue___98 {
	struct list_head queue_head;
	struct request___98 *last_merge;
	struct elevator_queue___98 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___98 *make_request_fn;
	dma_drain_needed_fn___98 *dma_drain_needed;
	const struct blk_mq_ops___35 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___35 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___182 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___352 kobj;
	struct kobject___352 *mq_kobj;
	struct blk_integrity integrity;
	struct device___332 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	struct bsg_class_device___98 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set___35 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___182 bio_split;
	struct dentry___364 *debugfs_dir;
	struct dentry___364 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___271 {
	struct vm_struct___271 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___366 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct io_cq___102 {
	struct request_queue___98 *q;
	struct io_context___102 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___365 {
	struct file___365 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___365 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___364 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___365 *ia_file;
};

struct dquot___364 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___364 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___364 {
	int qf_fmt_id;
	const struct quota_format_ops___364 *qf_ops;
	struct module___296 *qf_owner;
	struct quota_format_type___364 *qf_next;
};

struct quota_format_ops___364 {
	int (*check_quota_file)(struct super_block___364 *, int);
	int (*read_file_info)(struct super_block___364 *, int);
	int (*write_file_info)(struct super_block___364 *, int);
	int (*free_file_info)(struct super_block___364 *, int);
	int (*read_dqblk)(struct dquot___364 *);
	int (*commit_dqblk)(struct dquot___364 *);
	int (*release_dqblk)(struct dquot___364 *);
	int (*get_next_id)(struct super_block___364 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___364 {
	int (*write_dquot)(struct dquot___364 *);
	struct dquot___364 * (*alloc_dquot)(struct super_block___364 *, int);
	void (*destroy_dquot)(struct dquot___364 *);
	int (*acquire_dquot)(struct dquot___364 *);
	int (*release_dquot)(struct dquot___364 *);
	int (*mark_dirty)(struct dquot___364 *);
	int (*write_info)(struct super_block___364 *, int);
	qsize_t * (*get_reserved_space)(struct inode___365 *);
	int (*get_projid)(struct inode___365 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___365 *, qsize_t *);
	int (*get_next_id)(struct super_block___364 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___364 {
	int (*quota_on)(struct super_block___364 *, int, int, const struct path___365 *);
	int (*quota_off)(struct super_block___364 *, int);
	int (*quota_enable)(struct super_block___364 *, unsigned int);
	int (*quota_disable)(struct super_block___364 *, unsigned int);
	int (*quota_sync)(struct super_block___364 *, int);
	int (*set_info)(struct super_block___364 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___364 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___364 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___364 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___364 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___364 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___293 {
	struct kobject___352 kobj;
	struct module___296 *mod;
	struct kobject___352 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___293 {
	struct module___296 *mod;
	struct latch_tree_node node;
};

struct module_layout___293 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___293 mtn;
};

struct module_attribute___293;

struct kernel_param___293;

struct module___296 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___293 mkobj;
	struct module_attribute___293 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___352 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___293 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___293 core_layout;
	struct module_layout___293 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide48;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide49;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___364 {
	int (*writepage)(struct page___366 *, struct writeback_control___3 *);
	int (*readpage)(struct file___365 *, struct page___366 *);
	int (*writepages)(struct address_space___364 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___366 *);
	int (*readpages)(struct file___365 *, struct address_space___364 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___365 *, struct address_space___364 *, loff_t, unsigned int, unsigned int, struct page___366 **, void **);
	int (*write_end)(struct file___365 *, struct address_space___364 *, loff_t, unsigned int, unsigned int, struct page___366 *, void *);
	sector_t (*bmap)(struct address_space___364 *, sector_t);
	void (*invalidatepage)(struct page___366 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___366 *, gfp_t);
	void (*freepage)(struct page___366 *);
	ssize_t (*direct_IO)(struct kiocb___365 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___364 *, struct page___366 *, struct page___366 *, enum migrate_mode);
	bool (*isolate_page)(struct page___366 *, isolate_mode_t);
	void (*putback_page)(struct page___366 *);
	int (*launder_page)(struct page___366 *);
	int (*is_partially_uptodate)(struct page___366 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___366 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___364 *, struct page___366 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___365 *, sector_t *);
	void (*swap_deactivate)(struct file___365 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct hd_struct___102;

struct gendisk___102;

struct block_device___364 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___365 *bd_inode;
	struct super_block___364 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___364 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___102 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___102 *bd_disk;
	struct request_queue___98 *bd_queue;
	struct backing_dev_info___182 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___332 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___5 *subsys_data;
	void (*set_latency_tolerance)(struct device___332 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___332;

struct bus_type___332;

struct device_driver___332;

struct dev_pm_domain___332;

struct dma_map_ops___120;

struct fwnode_handle___254;

struct class___332;

struct attribute_group___329;

struct device___332 {
	struct device___332 *parent;
	struct device_private *p;
	struct kobject___352 kobj;
	const char *init_name;
	const struct device_type___332 *type;
	struct mutex mutex;
	struct bus_type___332 *bus;
	struct device_driver___332 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___332 power;
	struct dev_pm_domain___332 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___120 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___254 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___332 *class;
	const struct attribute_group___329 **groups;
	void (*release)(struct device___332 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___102 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___332 __dev;
	struct kobject___352 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___102;

struct block_device_operations___99;

struct gendisk___102 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___102 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___102 *part_tbl;
	struct hd_struct___102 part0;
	const struct block_device_operations___99 *fops;
	struct request_queue___98 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___366 lookup_sem;
	struct kobject___352 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___352 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___84 {
	struct kobject___352 kobj;
	struct module___296 *owner;
	const struct file_operations___365 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___364 {
	struct dentry___364 * (*lookup)(struct inode___365 *, struct dentry___364 *, unsigned int);
	const char * (*get_link)(struct dentry___364 *, struct inode___365 *, struct delayed_call *);
	int (*permission)(struct inode___365 *, int);
	struct posix_acl * (*get_acl)(struct inode___365 *, int);
	int (*readlink)(struct dentry___364 *, char *, int);
	int (*create)(struct inode___365 *, struct dentry___364 *, umode_t, bool);
	int (*link)(struct dentry___364 *, struct inode___365 *, struct dentry___364 *);
	int (*unlink)(struct inode___365 *, struct dentry___364 *);
	int (*symlink)(struct inode___365 *, struct dentry___364 *, const char *);
	int (*mkdir)(struct inode___365 *, struct dentry___364 *, umode_t);
	int (*rmdir)(struct inode___365 *, struct dentry___364 *);
	int (*mknod)(struct inode___365 *, struct dentry___364 *, umode_t, dev_t);
	int (*rename)(struct inode___365 *, struct dentry___364 *, struct inode___365 *, struct dentry___364 *, unsigned int);
	int (*setattr)(struct dentry___364 *, struct iattr___364 *);
	int (*getattr)(const struct path___365 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___364 *, char *, size_t);
	int (*fiemap)(struct inode___365 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___365 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___365 *, struct dentry___364 *, struct file___365 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___365 *, struct dentry___364 *, umode_t);
	int (*set_acl)(struct inode___365 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___364 {
	void (*fl_copy_lock)(struct file_lock___365 *, struct file_lock___365 *);
	void (*fl_release_private)(struct file_lock___365 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___364;

struct lock_manager_operations___364;

struct file_lock___365 {
	struct file_lock___365 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___365 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___364 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___364 *fl_ops;
	const struct lock_manager_operations___364 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___364 {
	int (*lm_compare_owner)(struct file_lock___365 *, struct file_lock___365 *);
	long unsigned int (*lm_owner_key)(struct file_lock___365 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___365 *);
	int (*lm_grant)(struct file_lock___365 *, int);
	bool (*lm_break)(struct file_lock___365 *);
	int (*lm_change)(struct file_lock___365 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___365 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___364 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___364 *fa_next;
	struct file___365 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___364 {
	const char *name;
	int fs_flags;
	struct dentry___364 * (*mount)(struct file_system_type___364 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___364 *);
	struct module___296 *owner;
	struct file_system_type___364 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___364 {
	struct inode___365 * (*alloc_inode)(struct super_block___364 *);
	void (*destroy_inode)(struct inode___365 *);
	void (*dirty_inode)(struct inode___365 *, int);
	int (*write_inode)(struct inode___365 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___365 *);
	void (*evict_inode)(struct inode___365 *);
	void (*put_super)(struct super_block___364 *);
	int (*sync_fs)(struct super_block___364 *, int);
	int (*freeze_super)(struct super_block___364 *);
	int (*freeze_fs)(struct super_block___364 *);
	int (*thaw_super)(struct super_block___364 *);
	int (*unfreeze_fs)(struct super_block___364 *);
	int (*statfs)(struct dentry___364 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___364 *, int *, char *);
	void (*umount_begin)(struct super_block___364 *);
	int (*show_options)(struct seq_file___309 *, struct dentry___364 *);
	int (*show_devname)(struct seq_file___309 *, struct dentry___364 *);
	int (*show_path)(struct seq_file___309 *, struct dentry___364 *);
	int (*show_stats)(struct seq_file___309 *, struct dentry___364 *);
	ssize_t (*quota_read)(struct super_block___364 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___364 *, int, const char *, size_t, loff_t);
	struct dquot___364 ** (*get_dquots)(struct inode___365 *);
	int (*bdev_try_to_free_page)(struct super_block___364 *, struct page___366 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___364 *, struct shrink_control___133 *);
	long int (*free_cached_objects)(struct super_block___364 *, struct shrink_control___133 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___224)(struct file___365 *, wait_queue_head_t *, struct poll_table_struct___218 *);

struct poll_table_struct___218 {
	poll_queue_proc___224 _qproc;
	__poll_t _key;
};

struct seq_operations___308;

struct seq_file___309 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___308 *op;
	int poll_event;
	const struct file___365 *file;
	void *private;
};

typedef void bio_end_io_t___182(struct bio___182 *);

struct bio_vec___184 {
	struct page___366 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___182;

struct bio___182 {
	struct bio___182 *bi_next;
	struct gendisk___102 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___182 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___182 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___184 *bi_io_vec;
	struct bio_set___182 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___184 bi_inline_vecs[0];
};

struct kernfs_root___358;

struct kernfs_elem_dir___358 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___358 *root;
};

struct kernfs_syscall_ops___358;

struct kernfs_root___358 {
	struct kernfs_node___359 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___358 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___358 {
	struct kernfs_node___359 *target_kn;
};

struct kernfs_ops___358;

struct kernfs_elem_attr___358 {
	const struct kernfs_ops___358 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___359 *notify_next;
};

struct kernfs_node___359 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___359 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___358 dir;
		struct kernfs_elem_symlink___358 symlink;
		struct kernfs_elem_attr___358 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___358;

struct kernfs_ops___358 {
	int (*open)(struct kernfs_open_file___358 *);
	void (*release)(struct kernfs_open_file___358 *);
	int (*seq_show)(struct seq_file___309 *, void *);
	void * (*seq_start)(struct seq_file___309 *, loff_t *);
	void * (*seq_next)(struct seq_file___309 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___309 *, void *);
	ssize_t (*read)(struct kernfs_open_file___358 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___358 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___358 *, struct vm_area_struct___366 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___358 *, struct poll_table_struct___218 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___358 {
	int (*remount_fs)(struct kernfs_root___358 *, int *, char *);
	int (*show_options)(struct seq_file___309 *, struct kernfs_root___358 *);
	int (*mkdir)(struct kernfs_node___359 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___359 *);
	int (*rename)(struct kernfs_node___359 *, struct kernfs_node___359 *, const char *);
	int (*show_path)(struct seq_file___309 *, struct kernfs_node___359 *, struct kernfs_root___358 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___358 {
	struct kernfs_node___359 *kn;
	struct file___365 *file;
	struct seq_file___309 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___353 *vm_ops;
};

struct bin_attribute___328;

struct attribute_group___329 {
	const char *name;
	umode_t (*is_visible)(struct kobject___352 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___352 *, struct bin_attribute___328 *, int);
	struct attribute **attrs;
	struct bin_attribute___328 **bin_attrs;
};

struct bin_attribute___328 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___365 *, struct kobject___352 *, struct bin_attribute___328 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___365 *, struct kobject___352 *, struct bin_attribute___328 *, char *, loff_t, size_t);
	int (*mmap)(struct file___365 *, struct kobject___352 *, struct bin_attribute___328 *, struct vm_area_struct___366 *);
};

struct sysfs_ops___351 {
	ssize_t (*show)(struct kobject___352 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___352 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___351;

struct kset___351 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___352 kobj;
	const struct kset_uevent_ops___351 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___351 {
	void (*release)(struct kobject___352 *);
	const struct sysfs_ops___351 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___28 * (*child_ns_type)(struct kobject___352 *);
	const void * (*namespace)(struct kobject___352 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___351 {
	int (* const filter)(struct kset___351 *, struct kobject___352 *);
	const char * (* const name)(struct kset___351 *, struct kobject___352 *);
	int (* const uevent)(struct kset___351 *, struct kobject___352 *, struct kobj_uevent_env *);
};

struct kobj_attribute___343 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___352 *, struct kobj_attribute___343 *, char *);
	ssize_t (*store)(struct kobject___352 *, struct kobj_attribute___343 *, const char *, size_t);
};

struct dev_pm_ops___332 {
	int (*prepare)(struct device___332 *);
	void (*complete)(struct device___332 *);
	int (*suspend)(struct device___332 *);
	int (*resume)(struct device___332 *);
	int (*freeze)(struct device___332 *);
	int (*thaw)(struct device___332 *);
	int (*poweroff)(struct device___332 *);
	int (*restore)(struct device___332 *);
	int (*suspend_late)(struct device___332 *);
	int (*resume_early)(struct device___332 *);
	int (*freeze_late)(struct device___332 *);
	int (*thaw_early)(struct device___332 *);
	int (*poweroff_late)(struct device___332 *);
	int (*restore_early)(struct device___332 *);
	int (*suspend_noirq)(struct device___332 *);
	int (*resume_noirq)(struct device___332 *);
	int (*freeze_noirq)(struct device___332 *);
	int (*thaw_noirq)(struct device___332 *);
	int (*poweroff_noirq)(struct device___332 *);
	int (*restore_noirq)(struct device___332 *);
	int (*runtime_suspend)(struct device___332 *);
	int (*runtime_resume)(struct device___332 *);
	int (*runtime_idle)(struct device___332 *);
};

struct dev_pm_domain___332 {
	struct dev_pm_ops___332 ops;
	void (*detach)(struct device___332 *, bool);
	int (*activate)(struct device___332 *);
	void (*sync)(struct device___332 *);
	void (*dismiss)(struct device___332 *);
};

struct bus_type___332 {
	const char *name;
	const char *dev_name;
	struct device___332 *dev_root;
	const struct attribute_group___329 **bus_groups;
	const struct attribute_group___329 **dev_groups;
	const struct attribute_group___329 **drv_groups;
	int (*match)(struct device___332 *, struct device_driver___332 *);
	int (*uevent)(struct device___332 *, struct kobj_uevent_env *);
	int (*probe)(struct device___332 *);
	int (*remove)(struct device___332 *);
	void (*shutdown)(struct device___332 *);
	int (*online)(struct device___332 *);
	int (*offline)(struct device___332 *);
	int (*suspend)(struct device___332 *, pm_message_t);
	int (*resume)(struct device___332 *);
	int (*num_vf)(struct device___332 *);
	int (*dma_configure)(struct device___332 *);
	const struct dev_pm_ops___332 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___332 {
	const char *name;
	struct bus_type___332 *bus;
	struct module___296 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___332 *);
	int (*remove)(struct device___332 *);
	void (*shutdown)(struct device___332 *);
	int (*suspend)(struct device___332 *, pm_message_t);
	int (*resume)(struct device___332 *);
	const struct attribute_group___329 **groups;
	const struct dev_pm_ops___332 *pm;
	void (*coredump)(struct device___332 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___332 {
	const char *name;
	const struct attribute_group___329 **groups;
	int (*uevent)(struct device___332 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___332 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___332 *);
	const struct dev_pm_ops___332 *pm;
};

struct class___332 {
	const char *name;
	struct module___296 *owner;
	const struct attribute_group___329 **class_groups;
	const struct attribute_group___329 **dev_groups;
	struct kobject___352 *dev_kobj;
	int (*dev_uevent)(struct device___332 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___332 *, umode_t *);
	void (*class_release)(struct class___332 *);
	void (*dev_release)(struct device___332 *);
	int (*shutdown_pre)(struct device___332 *);
	const struct kobj_ns_type_operations___28 *ns_type;
	const void * (*namespace)(struct device___332 *);
	const struct dev_pm_ops___332 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct device_attribute___44 {
	struct attribute attr;
	ssize_t (*show)(struct device___332 *, struct device_attribute___44 *, char *);
	ssize_t (*store)(struct device___332 *, struct device_attribute___44 *, const char *, size_t);
};

struct dma_map_ops___120 {
	void * (*alloc)(struct device___332 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___332 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___332 *, struct vm_area_struct___366 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___332 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___332 *, struct page___366 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___332 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___332 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___332 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___332 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___332 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___332 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___332 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___332 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___332 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___332 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___332 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___332 *, u64);
	u64 (*get_required_mask)(struct device___332 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___254;

struct fwnode_handle___254 {
	struct fwnode_handle___254 *secondary;
	const struct fwnode_operations___254 *ops;
};

typedef void compound_page_dtor___353(struct page___366 *);

struct fwnode_reference_args___254;

struct fwnode_endpoint___254;

struct fwnode_operations___254 {
	struct fwnode_handle___254 * (*get)(struct fwnode_handle___254 *);
	void (*put)(struct fwnode_handle___254 *);
	bool (*device_is_available)(const struct fwnode_handle___254 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___254 *, const struct device___332 *);
	bool (*property_present)(const struct fwnode_handle___254 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___254 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___254 *, const char *, const char **, size_t);
	struct fwnode_handle___254 * (*get_parent)(const struct fwnode_handle___254 *);
	struct fwnode_handle___254 * (*get_next_child_node)(const struct fwnode_handle___254 *, struct fwnode_handle___254 *);
	struct fwnode_handle___254 * (*get_named_child_node)(const struct fwnode_handle___254 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___254 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___254 *);
	struct fwnode_handle___254 * (*graph_get_next_endpoint)(const struct fwnode_handle___254 *, struct fwnode_handle___254 *);
	struct fwnode_handle___254 * (*graph_get_remote_endpoint)(const struct fwnode_handle___254 *);
	struct fwnode_handle___254 * (*graph_get_port_parent)(struct fwnode_handle___254 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___254 *, struct fwnode_endpoint___254 *);
};

struct fwnode_endpoint___254 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___254 *local_fwnode;
};

struct fwnode_reference_args___254 {
	struct fwnode_handle___254 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

typedef int (*key_restrict_link_func_t___337)(struct key___336 *, const struct key_type *, const union key_payload *, struct key___336 *);

struct key_restriction___336;

struct key___336 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___366 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___336 *restrict_link;
};

struct key_restriction___336 {
	key_restrict_link_func_t___337 check;
	struct key___336 *key;
	struct key_type *keytype;
};

struct seq_operations___308 {
	void * (*start)(struct seq_file___309 *, loff_t *);
	void (*stop)(struct seq_file___309 *, void *);
	void * (*next)(struct seq_file___309 *, void *, loff_t *);
	int (*show)(struct seq_file___309 *, void *);
};

struct bio_integrity_payload___182 {
	struct bio___182 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___184 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___184 bip_inline_vecs[0];
};

struct disk_part_tbl___102 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___102 *last_lookup;
	struct hd_struct___102 *part[0];
};

struct block_device_operations___99 {
	int (*open)(struct block_device___364 *, fmode_t);
	void (*release)(struct gendisk___102 *, fmode_t);
	int (*rw_page)(struct block_device___364 *, sector_t, struct page___366 *, unsigned int);
	int (*ioctl)(struct block_device___364 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___364 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___102 *, unsigned int);
	int (*media_changed)(struct gendisk___102 *);
	void (*unlock_native_capacity)(struct gendisk___102 *);
	int (*revalidate_disk)(struct gendisk___102 *);
	int (*getgeo)(struct block_device___364 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___364 *, long unsigned int);
	int (*report_zones)(struct gendisk___102 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___296 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bdi_writeback_congested___182 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___182 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bsg_ops___98 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___98 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___98 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___98 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___98(struct request___98 *, blk_status_t);

struct request___98 {
	struct request_queue___98 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___35 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___182 *bio;
	struct bio___182 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___184 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___102 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___98 *saved_end_io;
		} flush;
	};
	struct gendisk___102 *rq_disk;
	struct hd_struct___102 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___98 *end_io;
	void *end_io_data;
	struct request___98 *next_rq;
};

struct blk_mq_hw_ctx___35 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___98 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags___4 *tags;
	struct blk_mq_tags___4 *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	unsigned int rh_reserved_nr_expired;
	struct hlist_node cpuhp_dead;
	struct kobject___352 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___364 *debugfs_dir;
	struct dentry___364 *sched_debugfs_dir;
	struct list_head hctx_list;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___98;

struct elevator_mq_ops___98 {
	int (*init_sched)(struct request_queue___98 *, struct elevator_type___98 *);
	void (*exit_sched)(struct elevator_queue___98 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___35 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___35 *, unsigned int);
	bool (*allow_merge)(struct request_queue___98 *, struct request___98 *, struct bio___182 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx___35 *, struct bio___182 *);
	int (*request_merge)(struct request_queue___98 *, struct request___98 **, struct bio___182 *);
	void (*request_merged)(struct request_queue___98 *, struct request___98 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___98 *, struct request___98 *, struct request___98 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___98 *, struct bio___182 *);
	void (*finish_request)(struct request___98 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___35 *, struct list_head *, bool);
	struct request___98 * (*dispatch_request)(struct blk_mq_hw_ctx___35 *);
	bool (*has_work)(struct blk_mq_hw_ctx___35 *);
	void (*completed_request)(struct request___98 *, u64);
	void (*started_request)(struct request___98 *);
	void (*requeue_request)(struct request___98 *);
	struct request___98 * (*former_request)(struct request_queue___98 *, struct request___98 *);
	struct request___98 * (*next_request)(struct request_queue___98 *, struct request___98 *);
	void (*init_icq)(struct io_cq___102 *);
	void (*exit_icq)(struct io_cq___102 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx___35 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___98;

struct elevator_type___98 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___98 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___98 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___296 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___98 {
	struct elevator_type___98 *type;
	void *elevator_data;
	struct kobject___352 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___98 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___98 *, char *);
	ssize_t (*store)(struct elevator_queue___98 *, const char *, size_t);
};

struct blk_mq_queue_data___35;

typedef blk_status_t queue_rq_fn___35(struct blk_mq_hw_ctx___35 *, const struct blk_mq_queue_data___35 *);

typedef void commit_rqs_fn___35(struct blk_mq_hw_ctx___35 *);

typedef bool get_budget_fn___35(struct blk_mq_hw_ctx___35 *);

typedef void put_budget_fn___35(struct blk_mq_hw_ctx___35 *);

typedef enum blk_eh_timer_return timeout_fn___35(struct request___98 *, bool);

typedef int poll_fn___35(struct blk_mq_hw_ctx___35 *);

typedef void complete_fn___35(struct request___98 *);

typedef int init_hctx_fn___35(struct blk_mq_hw_ctx___35 *, void *, unsigned int);

typedef void exit_hctx_fn___35(struct blk_mq_hw_ctx___35 *, unsigned int);

typedef int init_request_fn___35(struct blk_mq_tag_set___35 *, struct request___98 *, unsigned int, unsigned int);

typedef void exit_request_fn___35(struct blk_mq_tag_set___35 *, struct request___98 *, unsigned int);

typedef bool busy_fn___35(struct request_queue___98 *);

typedef int map_queues_fn___35(struct blk_mq_tag_set___35 *);

typedef void cleanup_rq_fn___35(struct request___98 *);

struct blk_mq_ops___35 {
	queue_rq_fn___35 *queue_rq;
	commit_rqs_fn___35 *commit_rqs;
	get_budget_fn___35 *get_budget;
	put_budget_fn___35 *put_budget;
	timeout_fn___35 *timeout;
	poll_fn___35 *poll;
	complete_fn___35 *complete;
	init_hctx_fn___35 *init_hctx;
	exit_hctx_fn___35 *exit_hctx;
	init_request_fn___35 *init_request;
	exit_request_fn___35 *exit_request;
	void (*initialize_rq_fn)(struct request___98 *);
	busy_fn___35 *busy;
	map_queues_fn___35 *map_queues;
	void (*show_rq)(struct seq_file___309 *, struct request___98 *);
	union {
		cleanup_rq_fn___35 *cleanup_rq;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide47;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct blk_mq_tag_set___35 {
	struct blk_mq_queue_map map[6];
	unsigned int nr_maps;
	const struct blk_mq_ops___35 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	struct blk_mq_tags___4 **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct blk_mq_queue_data___35 {
	struct request___98 *rq;
	bool last;
	long unsigned int rh_reserved1;
};

struct Scsi_Host___11;

struct scsi_device___16;

struct scsi_target___16;

struct scsi_host_template___11 {
	struct module___296 *module;
	const char *name;
	const char * (*info)(struct Scsi_Host___11 *);
	int (*ioctl)(struct scsi_device___16 *, int, void *);
	int (*queuecommand)(struct Scsi_Host___11 *, struct scsi_cmnd___2 *);
	int (*eh_abort_handler)(struct scsi_cmnd___2 *);
	int (*eh_device_reset_handler)(struct scsi_cmnd___2 *);
	int (*eh_target_reset_handler)(struct scsi_cmnd___2 *);
	int (*eh_bus_reset_handler)(struct scsi_cmnd___2 *);
	int (*eh_host_reset_handler)(struct scsi_cmnd___2 *);
	int (*slave_alloc)(struct scsi_device___16 *);
	int (*slave_configure)(struct scsi_device___16 *);
	void (*slave_destroy)(struct scsi_device___16 *);
	int (*target_alloc)(struct scsi_target___16 *);
	void (*target_destroy)(struct scsi_target___16 *);
	int (*scan_finished)(struct Scsi_Host___11 *, long unsigned int);
	void (*scan_start)(struct Scsi_Host___11 *);
	int (*change_queue_depth)(struct scsi_device___16 *, int);
	int (*map_queues)(struct Scsi_Host___11 *);
	int (*bios_param)(struct scsi_device___16 *, struct block_device___364 *, sector_t, int *);
	void (*unlock_native_capacity)(struct scsi_device___16 *);
	int (*show_info)(struct seq_file___309 *, struct Scsi_Host___11 *);
	int (*write_info)(struct Scsi_Host___11 *, char *, int);
	enum blk_eh_timer_return (*eh_timed_out)(struct scsi_cmnd___2 *);
	int (*host_reset)(struct Scsi_Host___11 *, int);
	const char *proc_name;
	struct proc_dir_entry *proc_dir;
	int can_queue;
	int this_id;
	short unsigned int sg_tablesize;
	short unsigned int sg_prot_tablesize;
	unsigned int max_sectors;
	long unsigned int dma_boundary;
	short int cmd_per_lun;
	unsigned char present;
	int tag_alloc_policy;
	unsigned int track_queue_depth: 1;
	unsigned int supported_mode: 2;
	unsigned int unchecked_isa_dma: 1;
	unsigned int use_clustering: 1;
	unsigned int emulated: 1;
	unsigned int skip_settle_delay: 1;
	unsigned int no_write_same: 1;
	unsigned int force_blk_mq: 1;
	unsigned int max_host_blocked;
	struct device_attribute___44 **shost_attrs;
	struct device_attribute___44 **sdev_attrs;
	const struct attribute_group___329 **sdev_groups;
	u64 vendor_id;
	unsigned int cmd_size;
	struct scsi_host_cmd_pool *cmd_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct Scsi_Host___11 {
	struct list_head __devices;
	struct list_head __targets;
	struct list_head starved_list;
	spinlock_t default_lock;
	spinlock_t *host_lock;
	struct mutex scan_mutex;
	struct list_head eh_cmd_q;
	struct task_struct___366 *ehandler;
	struct completion *eh_action;
	wait_queue_head_t host_wait;
	struct scsi_host_template___11 *hostt;
	struct scsi_transport_template *transportt;
	struct blk_mq_tag_set___35 tag_set;
	atomic_t host_busy;
	atomic_t host_blocked;
	unsigned int host_failed;
	unsigned int host_eh_scheduled;
	unsigned int host_no;
	int eh_deadline;
	long unsigned int last_reset;
	unsigned int max_channel;
	unsigned int max_id;
	u64 max_lun;
	unsigned int unique_id;
	short unsigned int max_cmd_len;
	int this_id;
	int can_queue;
	short int cmd_per_lun;
	short unsigned int sg_tablesize;
	short unsigned int sg_prot_tablesize;
	unsigned int max_sectors;
	long unsigned int dma_boundary;
	unsigned int nr_hw_queues;
	long unsigned int cmd_serial_number;
	unsigned int active_mode: 2;
	unsigned int unchecked_isa_dma: 1;
	unsigned int use_clustering: 1;
	unsigned int host_self_blocked: 1;
	unsigned int reverse_ordering: 1;
	unsigned int tmf_in_progress: 1;
	unsigned int async_scan: 1;
	unsigned int eh_noresume: 1;
	unsigned int no_write_same: 1;
	unsigned int use_cmd_list: 1;
	unsigned int short_inquiry: 1;
	char work_q_name[20];
	struct workqueue_struct *work_q;
	struct workqueue_struct *tmf_work_q;
	unsigned int no_scsi2_lun_in_cdb: 1;
	unsigned int max_host_blocked;
	unsigned int prot_capabilities;
	unsigned char prot_guard_type;
	long unsigned int base;
	long unsigned int io_port;
	unsigned char n_io_port;
	unsigned char dma_channel;
	unsigned int irq;
	enum scsi_host_state shost_state;
	struct device___332 shost_gendev;
	struct device___332 shost_dev;
	void *shost_data;
	struct device___332 *dma_dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int hostdata[0];
};

struct kernel_param_ops___293 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___293 *);
	int (*get)(char *, const struct kernel_param___293 *);
	void (*free)(void *);
};

struct kparam_array___293;

struct kernel_param___293 {
	const char *name;
	struct module___296 *mod;
	const struct kernel_param_ops___293 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___293 *arr;
	};
};

struct kparam_array___293 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___293 *ops;
	void *elem;
};

struct module_attribute___293 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___293 *, struct module_kobject___293 *, char *);
	ssize_t (*store)(struct module_attribute___293 *, struct module_kobject___293 *, const char *, size_t);
	void (*setup)(struct module___296 *, const char *);
	int (*test)(struct module___296 *);
	void (*free)(struct module___296 *);
};

struct ata_queued_cmd___4;

typedef void (*ata_qc_cb_t___4)(struct ata_queued_cmd___4 *);

struct ata_port___4;

struct ata_device___4;

struct ata_queued_cmd___4 {
	struct ata_port___4 *ap;
	struct ata_device___4 *dev;
	struct scsi_cmnd___2 *scsicmd;
	void (*scsidone)(struct scsi_cmnd___2 *);
	struct ata_taskfile tf;
	u8 cdb[16];
	long unsigned int flags;
	unsigned int tag;
	unsigned int hw_tag;
	unsigned int n_elem;
	unsigned int orig_n_elem;
	int dma_dir;
	unsigned int sect_size;
	unsigned int nbytes;
	unsigned int extrabytes;
	unsigned int curbytes;
	struct scatterlist sgent;
	struct scatterlist *sg;
	struct scatterlist *cursg;
	unsigned int cursg_ofs;
	unsigned int err_mask;
	struct ata_taskfile result_tf;
	ata_qc_cb_t___4 complete_fn;
	void *private_data;
	void *lldd_task;
};

struct ata_link___4;

typedef int (*ata_prereset_fn_t___4)(struct ata_link___4 *, long unsigned int);

struct ata_eh_info___4 {
	struct ata_device___4 *dev;
	u32 serror;
	unsigned int err_mask;
	unsigned int action;
	unsigned int dev_action[2];
	unsigned int flags;
	unsigned int probe_mask;
	char desc[80];
	int desc_len;
};

struct ata_eh_context___4 {
	struct ata_eh_info___4 i;
	int tries[2];
	int cmd_timeout_idx[12];
	unsigned int classes[2];
	unsigned int did_probe_mask;
	unsigned int unloaded_mask;
	unsigned int saved_ncq_enabled;
	u8 saved_xfer_mode[2];
	long unsigned int last_reset;
};

struct ata_device___4 {
	struct ata_link___4 *link;
	unsigned int devno;
	unsigned int horkage;
	long unsigned int flags;
	struct scsi_device___16 *sdev;
	void *private_data;
	union acpi_object *gtf_cache;
	unsigned int gtf_filter;
	struct device___332 tdev;
	u64 n_sectors;
	u64 n_native_sectors;
	unsigned int class;
	long unsigned int unpark_deadline;
	u8 pio_mode;
	u8 dma_mode;
	u8 xfer_mode;
	unsigned int xfer_shift;
	unsigned int multi_count;
	unsigned int max_sectors;
	unsigned int cdb_len;
	long unsigned int pio_mask;
	long unsigned int mwdma_mask;
	long unsigned int udma_mask;
	u16 cylinders;
	u16 heads;
	u16 sectors;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	union {
		u16 id[256];
		u32 gscr[128];
	};
	u8 devslp_timing[8];
	u8 ncq_send_recv_cmds[20];
	u8 ncq_non_data_cmds[64];
	u32 zac_zoned_cap;
	u32 zac_zones_optimal_open;
	u32 zac_zones_optimal_nonseq;
	u32 zac_zones_max_open;
	int spdn_cnt;
	struct ata_ering ering;
	long: 64;
};

struct ata_link___4 {
	struct ata_port___4 *ap;
	int pmp;
	struct device___332 tdev;
	unsigned int active_tag;
	u32 sactive;
	unsigned int flags;
	u32 saved_scontrol;
	unsigned int hw_sata_spd_limit;
	unsigned int sata_spd_limit;
	unsigned int sata_spd;
	enum ata_lpm_policy lpm_policy;
	struct ata_eh_info___4 eh_info;
	struct ata_eh_context___4 eh_context;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ata_device___4 device[2];
	long unsigned int last_lpm_change;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef int (*ata_reset_fn_t___4)(struct ata_link___4 *, unsigned int *, long unsigned int);

typedef void (*ata_postreset_fn_t___4)(struct ata_link___4 *, unsigned int *);

struct ata_port_operations___4;

struct ata_host___4 {
	spinlock_t lock;
	struct device___332 *dev;
	void * const *iomap;
	unsigned int n_ports;
	unsigned int n_tags;
	void *private_data;
	struct ata_port_operations___4 *ops;
	long unsigned int flags;
	struct kref kref;
	struct mutex eh_mutex;
	struct task_struct___366 *eh_owner;
	struct ata_port___4 *simplex_claimed;
	struct ata_port___4 *ports[0];
};

struct ata_port_operations___4 {
	int (*qc_defer)(struct ata_queued_cmd___4 *);
	int (*check_atapi_dma)(struct ata_queued_cmd___4 *);
	void (*qc_prep)(struct ata_queued_cmd___4 *);
	unsigned int (*qc_issue)(struct ata_queued_cmd___4 *);
	bool (*qc_fill_rtf)(struct ata_queued_cmd___4 *);
	int (*cable_detect)(struct ata_port___4 *);
	long unsigned int (*mode_filter)(struct ata_device___4 *, long unsigned int);
	void (*set_piomode)(struct ata_port___4 *, struct ata_device___4 *);
	void (*set_dmamode)(struct ata_port___4 *, struct ata_device___4 *);
	int (*set_mode)(struct ata_link___4 *, struct ata_device___4 **);
	unsigned int (*read_id)(struct ata_device___4 *, struct ata_taskfile *, u16 *);
	void (*dev_config)(struct ata_device___4 *);
	void (*freeze)(struct ata_port___4 *);
	void (*thaw)(struct ata_port___4 *);
	ata_prereset_fn_t___4 prereset;
	ata_reset_fn_t___4 softreset;
	ata_reset_fn_t___4 hardreset;
	ata_postreset_fn_t___4 postreset;
	ata_prereset_fn_t___4 pmp_prereset;
	ata_reset_fn_t___4 pmp_softreset;
	ata_reset_fn_t___4 pmp_hardreset;
	ata_postreset_fn_t___4 pmp_postreset;
	void (*error_handler)(struct ata_port___4 *);
	void (*lost_interrupt)(struct ata_port___4 *);
	void (*post_internal_cmd)(struct ata_queued_cmd___4 *);
	void (*sched_eh)(struct ata_port___4 *);
	void (*end_eh)(struct ata_port___4 *);
	int (*scr_read)(struct ata_link___4 *, unsigned int, u32 *);
	int (*scr_write)(struct ata_link___4 *, unsigned int, u32);
	void (*pmp_attach)(struct ata_port___4 *);
	void (*pmp_detach)(struct ata_port___4 *);
	int (*set_lpm)(struct ata_link___4 *, enum ata_lpm_policy, unsigned int);
	int (*port_suspend)(struct ata_port___4 *, pm_message_t);
	int (*port_resume)(struct ata_port___4 *);
	int (*port_start)(struct ata_port___4 *);
	void (*port_stop)(struct ata_port___4 *);
	void (*host_stop)(struct ata_host___4 *);
	void (*sff_dev_select)(struct ata_port___4 *, unsigned int);
	void (*sff_set_devctl)(struct ata_port___4 *, u8);
	u8 (*sff_check_status)(struct ata_port___4 *);
	u8 (*sff_check_altstatus)(struct ata_port___4 *);
	void (*sff_tf_load)(struct ata_port___4 *, const struct ata_taskfile *);
	void (*sff_tf_read)(struct ata_port___4 *, struct ata_taskfile *);
	void (*sff_exec_command)(struct ata_port___4 *, const struct ata_taskfile *);
	unsigned int (*sff_data_xfer)(struct ata_queued_cmd___4 *, unsigned char *, unsigned int, int);
	void (*sff_irq_on)(struct ata_port___4 *);
	bool (*sff_irq_check)(struct ata_port___4 *);
	void (*sff_irq_clear)(struct ata_port___4 *);
	void (*sff_drain_fifo)(struct ata_queued_cmd___4 *);
	void (*bmdma_setup)(struct ata_queued_cmd___4 *);
	void (*bmdma_start)(struct ata_queued_cmd___4 *);
	void (*bmdma_stop)(struct ata_queued_cmd___4 *);
	u8 (*bmdma_status)(struct ata_port___4 *);
	ssize_t (*em_show)(struct ata_port___4 *, char *);
	ssize_t (*em_store)(struct ata_port___4 *, const char *, size_t);
	ssize_t (*sw_activity_show)(struct ata_device___4 *, char *);
	ssize_t (*sw_activity_store)(struct ata_device___4 *, enum sw_activity);
	ssize_t (*transmit_led_message)(struct ata_port___4 *, u32, ssize_t);
	void (*phy_reset)(struct ata_port___4 *);
	void (*eng_timeout)(struct ata_port___4 *);
	const struct ata_port_operations___4 *inherits;
};

struct ata_port___4 {
	struct Scsi_Host___11 *scsi_host;
	struct ata_port_operations___4 *ops;
	spinlock_t *lock;
	long unsigned int flags;
	unsigned int pflags;
	unsigned int print_id;
	unsigned int local_port_no;
	unsigned int port_no;
	struct ata_ioports ioaddr;
	u8 ctl;
	u8 last_ctl;
	struct ata_link___4 *sff_pio_task_link;
	struct delayed_work sff_pio_task;
	struct ata_bmdma_prd *bmdma_prd;
	dma_addr_t bmdma_prd_dma;
	unsigned int pio_mask;
	unsigned int mwdma_mask;
	unsigned int udma_mask;
	unsigned int cbl;
	struct ata_queued_cmd___4 qcmd[33];
	long unsigned int sas_tag_allocated;
	u64 qc_active;
	int nr_active_links;
	unsigned int sas_last_tag;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ata_link___4 link;
	struct ata_link___4 *slave_link;
	int nr_pmp_links;
	struct ata_link___4 *pmp_link;
	struct ata_link___4 *excl_link;
	struct ata_port_stats stats;
	struct ata_host___4 *host;
	struct device___332 *dev;
	struct device___332 tdev;
	struct mutex scsi_scan_mutex;
	struct delayed_work hotplug_task;
	struct work_struct scsi_rescan_task;
	unsigned int hsm_task_state;
	u32 msg_enable;
	struct list_head eh_done_q;
	wait_queue_head_t eh_wait_q;
	int eh_tries;
	struct completion park_req_pending;
	pm_message_t pm_mesg;
	enum ata_lpm_policy target_lpm_policy;
	struct timer_list fastdrain_timer;
	long unsigned int fastdrain_cnt;
	int em_message_type;
	void *private_data;
	struct ata_acpi_gtm __acpi_init_gtm;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sector_buf[512];
};

struct ata_port_info___4 {
	long unsigned int flags;
	long unsigned int link_flags;
	long unsigned int pio_mask;
	long unsigned int mwdma_mask;
	long unsigned int udma_mask;
	struct ata_port_operations___4 *port_ops;
	void *private_data;
};

struct module___297;

struct file___366;

struct kiocb___366;

struct poll_table_struct___219;

struct vm_area_struct___367;

struct inode___366;

struct file_lock___366;

struct page___367;

struct seq_file___310;

struct file_operations___366 {
	struct module___297 *owner;
	loff_t (*llseek)(struct file___366 *, loff_t, int);
	ssize_t (*read)(struct file___366 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___366 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___366 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___366 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___366 *, bool);
	int (*iterate)(struct file___366 *, struct dir_context *);
	int (*iterate_shared)(struct file___366 *, struct dir_context *);
	__poll_t (*poll)(struct file___366 *, struct poll_table_struct___219 *);
	long int (*unlocked_ioctl)(struct file___366 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___366 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___366 *, struct vm_area_struct___367 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___366 *, struct file___366 *);
	int (*flush)(struct file___366 *, fl_owner_t);
	int (*release)(struct inode___366 *, struct file___366 *);
	int (*fsync)(struct file___366 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___366 *, int);
	int (*lock)(struct file___366 *, int, struct file_lock___366 *);
	ssize_t (*sendpage)(struct file___366 *, struct page___367 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___366 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___366 *, int, struct file_lock___366 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___366 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___366 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___366 *, long int, struct file_lock___366 **, void **);
	long int (*fallocate)(struct file___366 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___310 *, struct file___366 *);
	ssize_t (*copy_file_range)(struct file___366 *, loff_t, struct file___366 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___366 *, loff_t, struct file___366 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___366 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___366 {
	u64 seqnum;
	struct vm_area_struct___367 *vmas[4];
};

struct page_frag___366 {
	struct page___367 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___366;

struct cred___337;

struct bio_list___183;

struct backing_dev_info___183;

struct io_context___103;

struct request_queue___99;

struct vm_struct___272;

struct task_struct___367 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___367 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___366 *mm;
	struct mm_struct___366 *active_mm;
	struct vmacache___366 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___367 *real_parent;
	struct task_struct___367 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___367 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___217 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___217 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___217 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___337 *ptracer_cred;
	const struct cred___337 *real_cred;
	const struct cred___337 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___367 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___183 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___183 *backing_dev_info;
	struct io_context___103 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___366 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___99 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___367 *oom_reaper_list;
	struct vm_struct___272 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___141 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___367 *pgtable_t___366;

struct address_space___365;

struct dev_pagemap___354;

struct page___367 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___365 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___367 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___366 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___366 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___354 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___366;

struct lruvec___366 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___366 *pgdat;
};

struct zone___366 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___366 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___366 {
	struct zone___366 *zone;
	int zone_idx;
};

struct zonelist___366 {
	struct zoneref___366 _zonerefs[25];
};

struct pglist_data___366 {
	struct zone___366 node_zones[3];
	struct zonelist___366 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___367 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___367 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___366 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___367 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___367 *owner;
};

struct secondary_data___367 {
	void *stack;
	struct task_struct___367 *task;
	long int status;
};

struct blocking_notifier_head___366 {
	struct rw_semaphore___367 rwsem;
	struct notifier_block *head;
};

struct kernfs_root___359;

struct kernfs_elem_dir___359 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___359 *root;
};

struct kernfs_node___360;

struct kernfs_syscall_ops___359;

struct kernfs_root___359 {
	struct kernfs_node___360 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___359 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___359 {
	struct kernfs_node___360 *target_kn;
};

struct kernfs_ops___359;

struct kernfs_elem_attr___359 {
	const struct kernfs_ops___359 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___360 *notify_next;
};

struct kernfs_node___360 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___360 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___359 dir;
		struct kernfs_elem_symlink___359 symlink;
		struct kernfs_elem_attr___359 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___359;

struct kernfs_ops___359 {
	int (*open)(struct kernfs_open_file___359 *);
	void (*release)(struct kernfs_open_file___359 *);
	int (*seq_show)(struct seq_file___310 *, void *);
	void * (*seq_start)(struct seq_file___310 *, loff_t *);
	void * (*seq_next)(struct seq_file___310 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___310 *, void *);
	ssize_t (*read)(struct kernfs_open_file___359 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___359 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___359 *, struct vm_area_struct___367 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___359 *, struct poll_table_struct___219 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___359 {
	int (*remount_fs)(struct kernfs_root___359 *, int *, char *);
	int (*show_options)(struct seq_file___310 *, struct kernfs_root___359 *);
	int (*mkdir)(struct kernfs_node___360 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___360 *);
	int (*rename)(struct kernfs_node___360 *, struct kernfs_node___360 *, const char *);
	int (*show_path)(struct seq_file___310 *, struct kernfs_node___360 *, struct kernfs_root___359 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___309;

struct seq_file___310 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___309 *op;
	int poll_event;
	const struct file___366 *file;
	void *private;
};

struct vm_operations_struct___354;

struct kernfs_open_file___359 {
	struct kernfs_node___360 *kn;
	struct file___366 *file;
	struct seq_file___310 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___354 *vm_ops;
};

struct dentry___365;

struct path___366 {
	struct vfsmount *mnt;
	struct dentry___365 *dentry;
};

struct file___366 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___366 f_path;
	struct inode___366 *f_inode;
	const struct file_operations___366 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___217 f_owner;
	const struct cred___337 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___365 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___354;

struct vm_operations_struct___354 {
	void (*open)(struct vm_area_struct___367 *);
	void (*close)(struct vm_area_struct___367 *);
	int (*split)(struct vm_area_struct___367 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___367 *);
	vm_fault_t (*fault)(struct vm_fault___354 *);
	vm_fault_t (*huge_fault)(struct vm_fault___354 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___354 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___367 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___354 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___354 *);
	int (*access)(struct vm_area_struct___367 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___367 *);
	int (*set_policy)(struct vm_area_struct___367 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___367 *, long unsigned int);
	struct page___367 * (*find_special_page)(struct vm_area_struct___367 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___225)(struct file___366 *, wait_queue_head_t *, struct poll_table_struct___219 *);

struct poll_table_struct___219 {
	poll_queue_proc___225 _qproc;
	__poll_t _key;
};

struct vm_area_struct___367 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___367 *vm_next;
	struct vm_area_struct___367 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___366 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___354 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___366 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___353;

struct bin_attribute___329;

struct attribute_group___330 {
	const char *name;
	umode_t (*is_visible)(struct kobject___353 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___353 *, struct bin_attribute___329 *, int);
	struct attribute **attrs;
	struct bin_attribute___329 **bin_attrs;
};

struct kset___352;

struct kobj_type___352;

struct kobject___353 {
	const char *name;
	struct list_head entry;
	struct kobject___353 *parent;
	struct kset___352 *kset;
	struct kobj_type___352 *ktype;
	struct kernfs_node___360 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___329 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___366 *, struct kobject___353 *, struct bin_attribute___329 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___366 *, struct kobject___353 *, struct bin_attribute___329 *, char *, loff_t, size_t);
	int (*mmap)(struct file___366 *, struct kobject___353 *, struct bin_attribute___329 *, struct vm_area_struct___367 *);
};

struct sysfs_ops___352 {
	ssize_t (*show)(struct kobject___353 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___353 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___352;

struct kset___352 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___353 kobj;
	const struct kset_uevent_ops___352 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___352 {
	void (*release)(struct kobject___353 *);
	const struct sysfs_ops___352 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___28 * (*child_ns_type)(struct kobject___353 *);
	const void * (*namespace)(struct kobject___353 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___352 {
	int (* const filter)(struct kset___352 *, struct kobject___353 *);
	const char * (* const name)(struct kset___352 *, struct kobject___353 *);
	int (* const uevent)(struct kset___352 *, struct kobject___353 *, struct kobj_uevent_env *);
};

struct kobj_attribute___344 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___353 *, struct kobj_attribute___344 *, char *);
	ssize_t (*store)(struct kobject___353 *, struct kobj_attribute___344 *, const char *, size_t);
};

struct device___333;

struct dev_pm_ops___333 {
	int (*prepare)(struct device___333 *);
	void (*complete)(struct device___333 *);
	int (*suspend)(struct device___333 *);
	int (*resume)(struct device___333 *);
	int (*freeze)(struct device___333 *);
	int (*thaw)(struct device___333 *);
	int (*poweroff)(struct device___333 *);
	int (*restore)(struct device___333 *);
	int (*suspend_late)(struct device___333 *);
	int (*resume_early)(struct device___333 *);
	int (*freeze_late)(struct device___333 *);
	int (*thaw_early)(struct device___333 *);
	int (*poweroff_late)(struct device___333 *);
	int (*restore_early)(struct device___333 *);
	int (*suspend_noirq)(struct device___333 *);
	int (*resume_noirq)(struct device___333 *);
	int (*freeze_noirq)(struct device___333 *);
	int (*thaw_noirq)(struct device___333 *);
	int (*poweroff_noirq)(struct device___333 *);
	int (*restore_noirq)(struct device___333 *);
	int (*runtime_suspend)(struct device___333 *);
	int (*runtime_resume)(struct device___333 *);
	int (*runtime_idle)(struct device___333 *);
};

struct dev_pm_info___333 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___5 *subsys_data;
	void (*set_latency_tolerance)(struct device___333 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___333;

struct bus_type___333;

struct device_driver___333;

struct dev_pm_domain___333;

struct dma_map_ops___121;

struct fwnode_handle___255;

struct class___333;

struct device___333 {
	struct device___333 *parent;
	struct device_private *p;
	struct kobject___353 kobj;
	const char *init_name;
	const struct device_type___333 *type;
	struct mutex mutex;
	struct bus_type___333 *bus;
	struct device_driver___333 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___333 power;
	struct dev_pm_domain___333 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___121 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___255 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___333 *class;
	const struct attribute_group___330 **groups;
	void (*release)(struct device___333 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___333 {
	struct dev_pm_ops___333 ops;
	void (*detach)(struct device___333 *, bool);
	int (*activate)(struct device___333 *);
	void (*sync)(struct device___333 *);
	void (*dismiss)(struct device___333 *);
};

struct key___337;

struct user_struct___337 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___337 *uid_keyring;
	struct key___337 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___366;

struct mm_struct___366 {
	struct {
		struct vm_area_struct___367 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___366 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___367 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___366 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___367 *owner;
		struct user_namespace___3 *user_ns;
		struct file___366 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___366 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___337 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___337 *session_keyring;
	struct key___337 *process_keyring;
	struct key___337 *thread_keyring;
	struct key___337 *request_key_auth;
	void *security;
	struct user_struct___337 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct bio___183;

struct bio_list___183 {
	struct bio___183 *head;
	struct bio___183 *tail;
};

struct bdi_writeback_congested___183;

struct bdi_writeback___183 {
	struct backing_dev_info___183 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___183 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___157 *memcg_css;
	struct cgroup_subsys_state___157 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___183 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___183 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___333 *dev;
	struct device___333 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___365 *debug_dir;
	struct dentry___365 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___103;

struct io_context___103 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___103 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

typedef blk_qc_t make_request_fn___99(struct request_queue___99 *, struct bio___183 *);

struct request___99;

typedef int dma_drain_needed_fn___99(struct request___99 *);

struct bsg_ops___99;

struct bsg_class_device___99 {
	struct device___333 *class_dev;
	int minor;
	struct request_queue___99 *queue;
	const struct bsg_ops___99 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___183 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___183 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___99;

struct blk_mq_ops___36;

struct blk_mq_hw_ctx___36;

struct blk_mq_tag_set___36;

struct request_queue___99 {
	struct list_head queue_head;
	struct request___99 *last_merge;
	struct elevator_queue___99 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___99 *make_request_fn;
	dma_drain_needed_fn___99 *dma_drain_needed;
	const struct blk_mq_ops___36 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___36 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___183 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___353 kobj;
	struct kobject___353 *mq_kobj;
	struct blk_integrity integrity;
	struct device___333 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	struct bsg_class_device___99 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set___36 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___183 bio_split;
	struct dentry___365 *debugfs_dir;
	struct dentry___365 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___272 {
	struct vm_struct___272 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___367 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bus_type___333 {
	const char *name;
	const char *dev_name;
	struct device___333 *dev_root;
	const struct attribute_group___330 **bus_groups;
	const struct attribute_group___330 **dev_groups;
	const struct attribute_group___330 **drv_groups;
	int (*match)(struct device___333 *, struct device_driver___333 *);
	int (*uevent)(struct device___333 *, struct kobj_uevent_env *);
	int (*probe)(struct device___333 *);
	int (*remove)(struct device___333 *);
	void (*shutdown)(struct device___333 *);
	int (*online)(struct device___333 *);
	int (*offline)(struct device___333 *);
	int (*suspend)(struct device___333 *, pm_message_t);
	int (*resume)(struct device___333 *);
	int (*num_vf)(struct device___333 *);
	int (*dma_configure)(struct device___333 *);
	const struct dev_pm_ops___333 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___333 {
	const char *name;
	struct bus_type___333 *bus;
	struct module___297 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___333 *);
	int (*remove)(struct device___333 *);
	void (*shutdown)(struct device___333 *);
	int (*suspend)(struct device___333 *, pm_message_t);
	int (*resume)(struct device___333 *);
	const struct attribute_group___330 **groups;
	const struct dev_pm_ops___333 *pm;
	void (*coredump)(struct device___333 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___333 {
	const char *name;
	const struct attribute_group___330 **groups;
	int (*uevent)(struct device___333 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___333 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___333 *);
	const struct dev_pm_ops___333 *pm;
};

struct module_kobject___294 {
	struct kobject___353 kobj;
	struct module___297 *mod;
	struct kobject___353 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___294 {
	struct module___297 *mod;
	struct latch_tree_node node;
};

struct module_layout___294 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___294 mtn;
};

struct module_attribute___294;

struct kernel_param___294;

struct module___297 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___294 mkobj;
	struct module_attribute___294 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___353 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___294 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___294 core_layout;
	struct module_layout___294 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct class___333 {
	const char *name;
	struct module___297 *owner;
	const struct attribute_group___330 **class_groups;
	const struct attribute_group___330 **dev_groups;
	struct kobject___353 *dev_kobj;
	int (*dev_uevent)(struct device___333 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___333 *, umode_t *);
	void (*class_release)(struct class___333 *);
	void (*dev_release)(struct device___333 *);
	int (*shutdown_pre)(struct device___333 *);
	const struct kobj_ns_type_operations___28 *ns_type;
	const void * (*namespace)(struct device___333 *);
	const struct dev_pm_ops___333 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct device_attribute___45 {
	struct attribute attr;
	ssize_t (*show)(struct device___333 *, struct device_attribute___45 *, char *);
	ssize_t (*store)(struct device___333 *, struct device_attribute___45 *, const char *, size_t);
};

struct dma_map_ops___121 {
	void * (*alloc)(struct device___333 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___333 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___333 *, struct vm_area_struct___367 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___333 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___333 *, struct page___367 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___333 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___333 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___333 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___333 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___333 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___333 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___333 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___333 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___333 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___333 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___333 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___333 *, u64);
	u64 (*get_required_mask)(struct device___333 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___255;

struct fwnode_handle___255 {
	struct fwnode_handle___255 *secondary;
	const struct fwnode_operations___255 *ops;
};

struct address_space_operations___365;

struct address_space___365 {
	struct inode___366 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___367 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___365 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___354)(struct vm_area_struct___367 *, long unsigned int, const struct page___367 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___354)(struct page___367 *, void *);

struct dev_pagemap___354 {
	dev_page_fault_t___354 page_fault;
	dev_page_free_t___354 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___333 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___366 {
	struct task_struct___367 *task;
	struct core_thread___366 *next;
};

struct core_state___366 {
	atomic_t nr_threads;
	struct core_thread___366 dumper;
	struct completion startup;
};

struct vm_fault___354 {
	struct vm_area_struct___367 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___367 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___367 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___366 prealloc_pte;
};

struct fwnode_reference_args___255;

struct fwnode_endpoint___255;

struct fwnode_operations___255 {
	struct fwnode_handle___255 * (*get)(struct fwnode_handle___255 *);
	void (*put)(struct fwnode_handle___255 *);
	bool (*device_is_available)(const struct fwnode_handle___255 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___255 *, const struct device___333 *);
	bool (*property_present)(const struct fwnode_handle___255 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___255 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___255 *, const char *, const char **, size_t);
	struct fwnode_handle___255 * (*get_parent)(const struct fwnode_handle___255 *);
	struct fwnode_handle___255 * (*get_next_child_node)(const struct fwnode_handle___255 *, struct fwnode_handle___255 *);
	struct fwnode_handle___255 * (*get_named_child_node)(const struct fwnode_handle___255 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___255 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___255 *);
	struct fwnode_handle___255 * (*graph_get_next_endpoint)(const struct fwnode_handle___255 *, struct fwnode_handle___255 *);
	struct fwnode_handle___255 * (*graph_get_remote_endpoint)(const struct fwnode_handle___255 *);
	struct fwnode_handle___255 * (*graph_get_port_parent)(struct fwnode_handle___255 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___255 *, struct fwnode_endpoint___255 *);
};

struct fwnode_endpoint___255 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___255 *local_fwnode;
};

struct fwnode_reference_args___255 {
	struct fwnode_handle___255 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pci_bus___32;

struct pci_slot___32 {
	struct pci_bus___32 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject___353 kobj;
};

struct pci_dev___32;

struct pci_ops___32;

struct pci_bus___32 {
	struct list_head node;
	struct pci_bus___32 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___32 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___32 *ops;
	struct msi_controller___2 *msi;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	int domain_nr;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___333 *bridge;
	struct device___333 dev;
	struct bin_attribute___329 *legacy_io;
	struct bin_attribute___329 *legacy_mem;
	unsigned int is_added: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
};

struct pci_driver___32;

struct pci_dev___32 {
	struct list_head bus_list;
	struct pci_bus___32 *bus;
	struct pci_bus___32 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___32 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u16 aer_cap;
	struct aer_stats *aer_stats;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	long unsigned int *dma_alias_mask;
	struct pci_driver___32 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	unsigned int imm_ready: 1;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int bridge_d3: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int hotplug_user_indicators: 1;
	unsigned int clear_retrain_link: 1;
	unsigned int d3_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	unsigned int ltr_path: 1;
	unsigned int eetlp_prefix_path: 1;
	pci_channel_state_t error_state;
	struct device___333 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int multifunction: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int ats_enabled: 1;
	unsigned int pasid_enabled: 1;
	unsigned int pri_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int reset_fn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int shpc_managed: 1;
	unsigned int is_thunderbolt: 1;
	unsigned int __aer_firmware_first_valid: 1;
	unsigned int __aer_firmware_first: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int irq_managed: 1;
	unsigned int has_secondary_link: 1;
	unsigned int non_compliant_bars: 1;
	unsigned int is_probed: 1;
	unsigned int link_active_reporting: 1;
	unsigned int untrusted: 1;
	unsigned int no_vf_scan: 1;
	unsigned int io_window: 1;
	unsigned int pref_window: 1;
	unsigned int pref_64_window: 1;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	struct bin_attribute___329 *rom_attr;
	int rom_attr_enabled;
	struct bin_attribute___329 *res_attr[17];
	struct bin_attribute___329 *res_attr_wc[17];
	unsigned int broken_cmd_compl: 1;
	const struct attribute_group___330 **msi_irq_groups;
	struct pci_vpd *vpd;
	union {
		struct pci_sriov *sriov;
		struct pci_dev___32 *physfn;
	};
	u16 ats_cap;
	u8 ats_stu;
	atomic_t ats_ref_cnt;
	u32 pri_reqs_alloc;
	u16 pasid_features;
	struct pci_p2pdma *p2pdma;
	phys_addr_t rom;
	size_t romlen;
	char *driver_override;
	long unsigned int priv_flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t pci_dev_extended_size_rh;
	struct pci_dev_extended_rh pci_dev_extended_rh;
};

struct pci_error_handlers___32;

struct pci_driver___32 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___32 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___32 *);
	int (*suspend)(struct pci_dev___32 *, pm_message_t);
	int (*suspend_late)(struct pci_dev___32 *, pm_message_t);
	int (*resume_early)(struct pci_dev___32 *);
	int (*resume)(struct pci_dev___32 *);
	void (*shutdown)(struct pci_dev___32 *);
	int (*sriov_configure)(struct pci_dev___32 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	const struct pci_error_handlers___32 *err_handler;
	const struct attribute_group___330 **groups;
	struct device_driver___333 driver;
	struct pci_dynids dynids;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct pci_ops___32 {
	int (*add_bus)(struct pci_bus___32 *);
	void (*remove_bus)(struct pci_bus___32 *);
	void * (*map_bus)(struct pci_bus___32 *, unsigned int, int);
	int (*read)(struct pci_bus___32 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___32 *, unsigned int, int, int, u32);
};

struct pci_error_handlers___32 {
	pci_ers_result_t (*error_detected)(struct pci_dev___32 *, enum pci_channel_state);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___32 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___32 *);
	void (*reset_prepare)(struct pci_dev___32 *);
	void (*reset_done)(struct pci_dev___32 *);
	void (*resume)(struct pci_dev___32 *);
};

struct dentry_operations___365;

struct super_block___365;

struct dentry___365 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___365 *d_parent;
	struct qstr d_name;
	struct inode___366 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___365 *d_op;
	struct super_block___365 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___365;

struct block_device___365;

struct cdev___85;

struct inode___366 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___365 *i_op;
	struct super_block___365 *i_sb;
	struct address_space___365 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___367 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___183 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___366 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___365 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___365 *i_bdev;
		struct cdev___85 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___365 {
	int (*d_revalidate)(struct dentry___365 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___365 *, unsigned int);
	int (*d_hash)(const struct dentry___365 *, struct qstr *);
	int (*d_compare)(const struct dentry___365 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___365 *);
	int (*d_init)(struct dentry___365 *);
	void (*d_release)(struct dentry___365 *);
	void (*d_prune)(struct dentry___365 *);
	void (*d_iput)(struct dentry___365 *, struct inode___366 *);
	char * (*d_dname)(struct dentry___365 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___366 *);
	int (*d_manage)(const struct path___366 *, bool);
	struct dentry___365 * (*d_real)(struct dentry___365 *, const struct inode___366 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___365;

struct mem_dqinfo___365 {
	struct quota_format_type___365 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___365;

struct quota_info___365 {
	unsigned int flags;
	struct rw_semaphore___367 dqio_sem;
	struct inode___366 *files[3];
	struct mem_dqinfo___365 info[3];
	const struct quota_format_ops___365 *ops[3];
};

struct rcuwait___365 {
	struct task_struct___367 *task;
};

struct percpu_rw_semaphore___365 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___367 rw_sem;
	struct rcuwait___365 writer;
	int readers_block;
};

struct sb_writers___365 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___365 rw_sem[3];
};

struct file_system_type___365;

struct super_operations___365;

struct dquot_operations___365;

struct quotactl_ops___365;

struct super_block___365 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___365 *s_type;
	const struct super_operations___365 *s_op;
	const struct dquot_operations___365 *dq_op;
	const struct quotactl_ops___365 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___365 *s_root;
	struct rw_semaphore___367 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___365 *s_bdev;
	struct backing_dev_info___183 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___365 s_dquot;
	struct sb_writers___365 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___365 *s_d_op;
	int cleancache_poolid;
	struct shrinker___133 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct io_cq___103 {
	struct request_queue___99 *q;
	struct io_context___103 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___366 {
	struct file___366 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___366 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___365 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___366 *ia_file;
};

struct dquot___365 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___365 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___365 {
	int qf_fmt_id;
	const struct quota_format_ops___365 *qf_ops;
	struct module___297 *qf_owner;
	struct quota_format_type___365 *qf_next;
};

struct quota_format_ops___365 {
	int (*check_quota_file)(struct super_block___365 *, int);
	int (*read_file_info)(struct super_block___365 *, int);
	int (*write_file_info)(struct super_block___365 *, int);
	int (*free_file_info)(struct super_block___365 *, int);
	int (*read_dqblk)(struct dquot___365 *);
	int (*commit_dqblk)(struct dquot___365 *);
	int (*release_dqblk)(struct dquot___365 *);
	int (*get_next_id)(struct super_block___365 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___365 {
	int (*write_dquot)(struct dquot___365 *);
	struct dquot___365 * (*alloc_dquot)(struct super_block___365 *, int);
	void (*destroy_dquot)(struct dquot___365 *);
	int (*acquire_dquot)(struct dquot___365 *);
	int (*release_dquot)(struct dquot___365 *);
	int (*mark_dirty)(struct dquot___365 *);
	int (*write_info)(struct super_block___365 *, int);
	qsize_t * (*get_reserved_space)(struct inode___366 *);
	int (*get_projid)(struct inode___366 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___366 *, qsize_t *);
	int (*get_next_id)(struct super_block___365 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___365 {
	int (*quota_on)(struct super_block___365 *, int, int, const struct path___366 *);
	int (*quota_off)(struct super_block___365 *, int);
	int (*quota_enable)(struct super_block___365 *, unsigned int);
	int (*quota_disable)(struct super_block___365 *, unsigned int);
	int (*quota_sync)(struct super_block___365 *, int);
	int (*set_info)(struct super_block___365 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___365 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___365 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___365 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___365 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___365 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___365 {
	int (*writepage)(struct page___367 *, struct writeback_control___3 *);
	int (*readpage)(struct file___366 *, struct page___367 *);
	int (*writepages)(struct address_space___365 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___367 *);
	int (*readpages)(struct file___366 *, struct address_space___365 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___366 *, struct address_space___365 *, loff_t, unsigned int, unsigned int, struct page___367 **, void **);
	int (*write_end)(struct file___366 *, struct address_space___365 *, loff_t, unsigned int, unsigned int, struct page___367 *, void *);
	sector_t (*bmap)(struct address_space___365 *, sector_t);
	void (*invalidatepage)(struct page___367 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___367 *, gfp_t);
	void (*freepage)(struct page___367 *);
	ssize_t (*direct_IO)(struct kiocb___366 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___365 *, struct page___367 *, struct page___367 *, enum migrate_mode);
	bool (*isolate_page)(struct page___367 *, isolate_mode_t);
	void (*putback_page)(struct page___367 *);
	int (*launder_page)(struct page___367 *);
	int (*is_partially_uptodate)(struct page___367 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___367 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___365 *, struct page___367 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___366 *, sector_t *);
	void (*swap_deactivate)(struct file___366 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct hd_struct___103;

struct gendisk___103;

struct block_device___365 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___366 *bd_inode;
	struct super_block___365 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___365 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___103 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___103 *bd_disk;
	struct request_queue___99 *bd_queue;
	struct backing_dev_info___183 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct hd_struct___103 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___333 __dev;
	struct kobject___353 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___103;

struct block_device_operations___100;

struct gendisk___103 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___103 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___103 *part_tbl;
	struct hd_struct___103 part0;
	const struct block_device_operations___100 *fops;
	struct request_queue___99 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___367 lookup_sem;
	struct kobject___353 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___353 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___85 {
	struct kobject___353 kobj;
	struct module___297 *owner;
	const struct file_operations___366 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___365 {
	struct dentry___365 * (*lookup)(struct inode___366 *, struct dentry___365 *, unsigned int);
	const char * (*get_link)(struct dentry___365 *, struct inode___366 *, struct delayed_call *);
	int (*permission)(struct inode___366 *, int);
	struct posix_acl * (*get_acl)(struct inode___366 *, int);
	int (*readlink)(struct dentry___365 *, char *, int);
	int (*create)(struct inode___366 *, struct dentry___365 *, umode_t, bool);
	int (*link)(struct dentry___365 *, struct inode___366 *, struct dentry___365 *);
	int (*unlink)(struct inode___366 *, struct dentry___365 *);
	int (*symlink)(struct inode___366 *, struct dentry___365 *, const char *);
	int (*mkdir)(struct inode___366 *, struct dentry___365 *, umode_t);
	int (*rmdir)(struct inode___366 *, struct dentry___365 *);
	int (*mknod)(struct inode___366 *, struct dentry___365 *, umode_t, dev_t);
	int (*rename)(struct inode___366 *, struct dentry___365 *, struct inode___366 *, struct dentry___365 *, unsigned int);
	int (*setattr)(struct dentry___365 *, struct iattr___365 *);
	int (*getattr)(const struct path___366 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___365 *, char *, size_t);
	int (*fiemap)(struct inode___366 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___366 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___366 *, struct dentry___365 *, struct file___366 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___366 *, struct dentry___365 *, umode_t);
	int (*set_acl)(struct inode___366 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___365 {
	void (*fl_copy_lock)(struct file_lock___366 *, struct file_lock___366 *);
	void (*fl_release_private)(struct file_lock___366 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___365;

struct lock_manager_operations___365;

struct file_lock___366 {
	struct file_lock___366 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___366 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___365 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___365 *fl_ops;
	const struct lock_manager_operations___365 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___365 {
	int (*lm_compare_owner)(struct file_lock___366 *, struct file_lock___366 *);
	long unsigned int (*lm_owner_key)(struct file_lock___366 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___366 *);
	int (*lm_grant)(struct file_lock___366 *, int);
	bool (*lm_break)(struct file_lock___366 *);
	int (*lm_change)(struct file_lock___366 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___366 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___365 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___365 *fa_next;
	struct file___366 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___365 {
	const char *name;
	int fs_flags;
	struct dentry___365 * (*mount)(struct file_system_type___365 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___365 *);
	struct module___297 *owner;
	struct file_system_type___365 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___365 {
	struct inode___366 * (*alloc_inode)(struct super_block___365 *);
	void (*destroy_inode)(struct inode___366 *);
	void (*dirty_inode)(struct inode___366 *, int);
	int (*write_inode)(struct inode___366 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___366 *);
	void (*evict_inode)(struct inode___366 *);
	void (*put_super)(struct super_block___365 *);
	int (*sync_fs)(struct super_block___365 *, int);
	int (*freeze_super)(struct super_block___365 *);
	int (*freeze_fs)(struct super_block___365 *);
	int (*thaw_super)(struct super_block___365 *);
	int (*unfreeze_fs)(struct super_block___365 *);
	int (*statfs)(struct dentry___365 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___365 *, int *, char *);
	void (*umount_begin)(struct super_block___365 *);
	int (*show_options)(struct seq_file___310 *, struct dentry___365 *);
	int (*show_devname)(struct seq_file___310 *, struct dentry___365 *);
	int (*show_path)(struct seq_file___310 *, struct dentry___365 *);
	int (*show_stats)(struct seq_file___310 *, struct dentry___365 *);
	ssize_t (*quota_read)(struct super_block___365 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___365 *, int, const char *, size_t, loff_t);
	struct dquot___365 ** (*get_dquots)(struct inode___366 *);
	int (*bdev_try_to_free_page)(struct super_block___365 *, struct page___367 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___365 *, struct shrink_control___133 *);
	long int (*free_cached_objects)(struct super_block___365 *, struct shrink_control___133 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___183(struct bio___183 *);

struct bio_vec___185 {
	struct page___367 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___183;

struct bio___183 {
	struct bio___183 *bi_next;
	struct gendisk___103 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___183 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___183 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___185 *bi_io_vec;
	struct bio_set___183 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___185 bi_inline_vecs[0];
};

typedef void compound_page_dtor___354(struct page___367 *);

struct kernel_param_ops___294 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___294 *);
	int (*get)(char *, const struct kernel_param___294 *);
	void (*free)(void *);
};

struct kparam_array___294;

struct kernel_param___294 {
	const char *name;
	struct module___297 *mod;
	const struct kernel_param_ops___294 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___294 *arr;
	};
};

struct kparam_array___294 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___294 *ops;
	void *elem;
};

struct module_attribute___294 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___294 *, struct module_kobject___294 *, char *);
	ssize_t (*store)(struct module_attribute___294 *, struct module_kobject___294 *, const char *, size_t);
	void (*setup)(struct module___297 *, const char *);
	int (*test)(struct module___297 *);
	void (*free)(struct module___297 *);
};

typedef int (*key_restrict_link_func_t___338)(struct key___337 *, const struct key_type *, const union key_payload *, struct key___337 *);

struct key_restriction___337;

struct key___337 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___367 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___337 *restrict_link;
};

struct key_restriction___337 {
	key_restrict_link_func_t___338 check;
	struct key___337 *key;
	struct key_type *keytype;
};

struct seq_operations___309 {
	void * (*start)(struct seq_file___310 *, loff_t *);
	void (*stop)(struct seq_file___310 *, void *);
	void * (*next)(struct seq_file___310 *, void *, loff_t *);
	int (*show)(struct seq_file___310 *, void *);
};

struct bio_integrity_payload___183 {
	struct bio___183 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___185 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___185 bip_inline_vecs[0];
};

struct disk_part_tbl___103 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___103 *last_lookup;
	struct hd_struct___103 *part[0];
};

struct block_device_operations___100 {
	int (*open)(struct block_device___365 *, fmode_t);
	void (*release)(struct gendisk___103 *, fmode_t);
	int (*rw_page)(struct block_device___365 *, sector_t, struct page___367 *, unsigned int);
	int (*ioctl)(struct block_device___365 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___365 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___103 *, unsigned int);
	int (*media_changed)(struct gendisk___103 *);
	void (*unlock_native_capacity)(struct gendisk___103 *);
	int (*revalidate_disk)(struct gendisk___103 *);
	int (*getgeo)(struct block_device___365 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___365 *, long unsigned int);
	int (*report_zones)(struct gendisk___103 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___297 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bdi_writeback_congested___183 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___183 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bsg_ops___99 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___99 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___99 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___99 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___99(struct request___99 *, blk_status_t);

struct request___99 {
	struct request_queue___99 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___36 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___183 *bio;
	struct bio___183 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___185 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___103 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___99 *saved_end_io;
		} flush;
	};
	struct gendisk___103 *rq_disk;
	struct hd_struct___103 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___99 *end_io;
	void *end_io_data;
	struct request___99 *next_rq;
};

struct blk_mq_hw_ctx___36 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___99 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags___4 *tags;
	struct blk_mq_tags___4 *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	unsigned int rh_reserved_nr_expired;
	struct hlist_node cpuhp_dead;
	struct kobject___353 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___365 *debugfs_dir;
	struct dentry___365 *sched_debugfs_dir;
	struct list_head hctx_list;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___99;

struct elevator_mq_ops___99 {
	int (*init_sched)(struct request_queue___99 *, struct elevator_type___99 *);
	void (*exit_sched)(struct elevator_queue___99 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___36 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___36 *, unsigned int);
	bool (*allow_merge)(struct request_queue___99 *, struct request___99 *, struct bio___183 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx___36 *, struct bio___183 *);
	int (*request_merge)(struct request_queue___99 *, struct request___99 **, struct bio___183 *);
	void (*request_merged)(struct request_queue___99 *, struct request___99 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___99 *, struct request___99 *, struct request___99 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___99 *, struct bio___183 *);
	void (*finish_request)(struct request___99 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___36 *, struct list_head *, bool);
	struct request___99 * (*dispatch_request)(struct blk_mq_hw_ctx___36 *);
	bool (*has_work)(struct blk_mq_hw_ctx___36 *);
	void (*completed_request)(struct request___99 *, u64);
	void (*started_request)(struct request___99 *);
	void (*requeue_request)(struct request___99 *);
	struct request___99 * (*former_request)(struct request_queue___99 *, struct request___99 *);
	struct request___99 * (*next_request)(struct request_queue___99 *, struct request___99 *);
	void (*init_icq)(struct io_cq___103 *);
	void (*exit_icq)(struct io_cq___103 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx___36 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___99;

struct elevator_type___99 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___99 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___99 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___297 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___99 {
	struct elevator_type___99 *type;
	void *elevator_data;
	struct kobject___353 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___99 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___99 *, char *);
	ssize_t (*store)(struct elevator_queue___99 *, const char *, size_t);
};

struct blk_mq_queue_data___36;

typedef blk_status_t queue_rq_fn___36(struct blk_mq_hw_ctx___36 *, const struct blk_mq_queue_data___36 *);

typedef void commit_rqs_fn___36(struct blk_mq_hw_ctx___36 *);

typedef bool get_budget_fn___36(struct blk_mq_hw_ctx___36 *);

typedef void put_budget_fn___36(struct blk_mq_hw_ctx___36 *);

typedef enum blk_eh_timer_return timeout_fn___36(struct request___99 *, bool);

typedef int poll_fn___36(struct blk_mq_hw_ctx___36 *);

typedef void complete_fn___36(struct request___99 *);

typedef int init_hctx_fn___36(struct blk_mq_hw_ctx___36 *, void *, unsigned int);

typedef void exit_hctx_fn___36(struct blk_mq_hw_ctx___36 *, unsigned int);

typedef int init_request_fn___36(struct blk_mq_tag_set___36 *, struct request___99 *, unsigned int, unsigned int);

typedef void exit_request_fn___36(struct blk_mq_tag_set___36 *, struct request___99 *, unsigned int);

typedef bool busy_fn___36(struct request_queue___99 *);

typedef int map_queues_fn___36(struct blk_mq_tag_set___36 *);

typedef void cleanup_rq_fn___36(struct request___99 *);

struct blk_mq_ops___36 {
	queue_rq_fn___36 *queue_rq;
	commit_rqs_fn___36 *commit_rqs;
	get_budget_fn___36 *get_budget;
	put_budget_fn___36 *put_budget;
	timeout_fn___36 *timeout;
	poll_fn___36 *poll;
	complete_fn___36 *complete;
	init_hctx_fn___36 *init_hctx;
	exit_hctx_fn___36 *exit_hctx;
	init_request_fn___36 *init_request;
	exit_request_fn___36 *exit_request;
	void (*initialize_rq_fn)(struct request___99 *);
	busy_fn___36 *busy;
	map_queues_fn___36 *map_queues;
	void (*show_rq)(struct seq_file___310 *, struct request___99 *);
	union {
		cleanup_rq_fn___36 *cleanup_rq;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide47;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct blk_mq_tag_set___36 {
	struct blk_mq_queue_map map[6];
	unsigned int nr_maps;
	const struct blk_mq_ops___36 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	struct blk_mq_tags___4 **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct blk_mq_queue_data___36 {
	struct request___99 *rq;
	bool last;
	long unsigned int rh_reserved1;
};

struct Scsi_Host___12;

struct scsi_host_template___12 {
	struct module___297 *module;
	const char *name;
	const char * (*info)(struct Scsi_Host___12 *);
	int (*ioctl)(struct scsi_device___16 *, int, void *);
	int (*queuecommand)(struct Scsi_Host___12 *, struct scsi_cmnd___2 *);
	int (*eh_abort_handler)(struct scsi_cmnd___2 *);
	int (*eh_device_reset_handler)(struct scsi_cmnd___2 *);
	int (*eh_target_reset_handler)(struct scsi_cmnd___2 *);
	int (*eh_bus_reset_handler)(struct scsi_cmnd___2 *);
	int (*eh_host_reset_handler)(struct scsi_cmnd___2 *);
	int (*slave_alloc)(struct scsi_device___16 *);
	int (*slave_configure)(struct scsi_device___16 *);
	void (*slave_destroy)(struct scsi_device___16 *);
	int (*target_alloc)(struct scsi_target___16 *);
	void (*target_destroy)(struct scsi_target___16 *);
	int (*scan_finished)(struct Scsi_Host___12 *, long unsigned int);
	void (*scan_start)(struct Scsi_Host___12 *);
	int (*change_queue_depth)(struct scsi_device___16 *, int);
	int (*map_queues)(struct Scsi_Host___12 *);
	int (*bios_param)(struct scsi_device___16 *, struct block_device___365 *, sector_t, int *);
	void (*unlock_native_capacity)(struct scsi_device___16 *);
	int (*show_info)(struct seq_file___310 *, struct Scsi_Host___12 *);
	int (*write_info)(struct Scsi_Host___12 *, char *, int);
	enum blk_eh_timer_return (*eh_timed_out)(struct scsi_cmnd___2 *);
	int (*host_reset)(struct Scsi_Host___12 *, int);
	const char *proc_name;
	struct proc_dir_entry *proc_dir;
	int can_queue;
	int this_id;
	short unsigned int sg_tablesize;
	short unsigned int sg_prot_tablesize;
	unsigned int max_sectors;
	long unsigned int dma_boundary;
	short int cmd_per_lun;
	unsigned char present;
	int tag_alloc_policy;
	unsigned int track_queue_depth: 1;
	unsigned int supported_mode: 2;
	unsigned int unchecked_isa_dma: 1;
	unsigned int use_clustering: 1;
	unsigned int emulated: 1;
	unsigned int skip_settle_delay: 1;
	unsigned int no_write_same: 1;
	unsigned int force_blk_mq: 1;
	unsigned int max_host_blocked;
	struct device_attribute___45 **shost_attrs;
	struct device_attribute___45 **sdev_attrs;
	const struct attribute_group___330 **sdev_groups;
	u64 vendor_id;
	unsigned int cmd_size;
	struct scsi_host_cmd_pool *cmd_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct Scsi_Host___12 {
	struct list_head __devices;
	struct list_head __targets;
	struct list_head starved_list;
	spinlock_t default_lock;
	spinlock_t *host_lock;
	struct mutex scan_mutex;
	struct list_head eh_cmd_q;
	struct task_struct___367 *ehandler;
	struct completion *eh_action;
	wait_queue_head_t host_wait;
	struct scsi_host_template___12 *hostt;
	struct scsi_transport_template *transportt;
	struct blk_mq_tag_set___36 tag_set;
	atomic_t host_busy;
	atomic_t host_blocked;
	unsigned int host_failed;
	unsigned int host_eh_scheduled;
	unsigned int host_no;
	int eh_deadline;
	long unsigned int last_reset;
	unsigned int max_channel;
	unsigned int max_id;
	u64 max_lun;
	unsigned int unique_id;
	short unsigned int max_cmd_len;
	int this_id;
	int can_queue;
	short int cmd_per_lun;
	short unsigned int sg_tablesize;
	short unsigned int sg_prot_tablesize;
	unsigned int max_sectors;
	long unsigned int dma_boundary;
	unsigned int nr_hw_queues;
	long unsigned int cmd_serial_number;
	unsigned int active_mode: 2;
	unsigned int unchecked_isa_dma: 1;
	unsigned int use_clustering: 1;
	unsigned int host_self_blocked: 1;
	unsigned int reverse_ordering: 1;
	unsigned int tmf_in_progress: 1;
	unsigned int async_scan: 1;
	unsigned int eh_noresume: 1;
	unsigned int no_write_same: 1;
	unsigned int use_cmd_list: 1;
	unsigned int short_inquiry: 1;
	char work_q_name[20];
	struct workqueue_struct *work_q;
	struct workqueue_struct *tmf_work_q;
	unsigned int no_scsi2_lun_in_cdb: 1;
	unsigned int max_host_blocked;
	unsigned int prot_capabilities;
	unsigned char prot_guard_type;
	long unsigned int base;
	long unsigned int io_port;
	unsigned char n_io_port;
	unsigned char dma_channel;
	unsigned int irq;
	enum scsi_host_state shost_state;
	struct device___333 shost_gendev;
	struct device___333 shost_dev;
	void *shost_data;
	struct device___333 *dma_dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int hostdata[0];
};

enum hsm_task_states {
	HSM_ST_IDLE = 0,
	HSM_ST_FIRST = 1,
	HSM_ST = 2,
	HSM_ST_LAST = 3,
	HSM_ST_ERR = 4,
};

struct ata_queued_cmd___5;

typedef void (*ata_qc_cb_t___5)(struct ata_queued_cmd___5 *);

struct ata_port___5;

struct ata_device___5;

struct ata_queued_cmd___5 {
	struct ata_port___5 *ap;
	struct ata_device___5 *dev;
	struct scsi_cmnd___2 *scsicmd;
	void (*scsidone)(struct scsi_cmnd___2 *);
	struct ata_taskfile tf;
	u8 cdb[16];
	long unsigned int flags;
	unsigned int tag;
	unsigned int hw_tag;
	unsigned int n_elem;
	unsigned int orig_n_elem;
	int dma_dir;
	unsigned int sect_size;
	unsigned int nbytes;
	unsigned int extrabytes;
	unsigned int curbytes;
	struct scatterlist sgent;
	struct scatterlist *sg;
	struct scatterlist *cursg;
	unsigned int cursg_ofs;
	unsigned int err_mask;
	struct ata_taskfile result_tf;
	ata_qc_cb_t___5 complete_fn;
	void *private_data;
	void *lldd_task;
};

struct ata_link___5;

typedef int (*ata_prereset_fn_t___5)(struct ata_link___5 *, long unsigned int);

struct ata_eh_info___5 {
	struct ata_device___5 *dev;
	u32 serror;
	unsigned int err_mask;
	unsigned int action;
	unsigned int dev_action[2];
	unsigned int flags;
	unsigned int probe_mask;
	char desc[80];
	int desc_len;
};

struct ata_eh_context___5 {
	struct ata_eh_info___5 i;
	int tries[2];
	int cmd_timeout_idx[12];
	unsigned int classes[2];
	unsigned int did_probe_mask;
	unsigned int unloaded_mask;
	unsigned int saved_ncq_enabled;
	u8 saved_xfer_mode[2];
	long unsigned int last_reset;
};

struct ata_device___5 {
	struct ata_link___5 *link;
	unsigned int devno;
	unsigned int horkage;
	long unsigned int flags;
	struct scsi_device___16 *sdev;
	void *private_data;
	union acpi_object *gtf_cache;
	unsigned int gtf_filter;
	struct device___333 tdev;
	u64 n_sectors;
	u64 n_native_sectors;
	unsigned int class;
	long unsigned int unpark_deadline;
	u8 pio_mode;
	u8 dma_mode;
	u8 xfer_mode;
	unsigned int xfer_shift;
	unsigned int multi_count;
	unsigned int max_sectors;
	unsigned int cdb_len;
	long unsigned int pio_mask;
	long unsigned int mwdma_mask;
	long unsigned int udma_mask;
	u16 cylinders;
	u16 heads;
	u16 sectors;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	union {
		u16 id[256];
		u32 gscr[128];
	};
	u8 devslp_timing[8];
	u8 ncq_send_recv_cmds[20];
	u8 ncq_non_data_cmds[64];
	u32 zac_zoned_cap;
	u32 zac_zones_optimal_open;
	u32 zac_zones_optimal_nonseq;
	u32 zac_zones_max_open;
	int spdn_cnt;
	struct ata_ering ering;
	long: 64;
};

struct ata_link___5 {
	struct ata_port___5 *ap;
	int pmp;
	struct device___333 tdev;
	unsigned int active_tag;
	u32 sactive;
	unsigned int flags;
	u32 saved_scontrol;
	unsigned int hw_sata_spd_limit;
	unsigned int sata_spd_limit;
	unsigned int sata_spd;
	enum ata_lpm_policy lpm_policy;
	struct ata_eh_info___5 eh_info;
	struct ata_eh_context___5 eh_context;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ata_device___5 device[2];
	long unsigned int last_lpm_change;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef int (*ata_reset_fn_t___5)(struct ata_link___5 *, unsigned int *, long unsigned int);

typedef void (*ata_postreset_fn_t___5)(struct ata_link___5 *, unsigned int *);

struct ata_port_operations___5;

struct ata_host___5 {
	spinlock_t lock;
	struct device___333 *dev;
	void * const *iomap;
	unsigned int n_ports;
	unsigned int n_tags;
	void *private_data;
	struct ata_port_operations___5 *ops;
	long unsigned int flags;
	struct kref kref;
	struct mutex eh_mutex;
	struct task_struct___367 *eh_owner;
	struct ata_port___5 *simplex_claimed;
	struct ata_port___5 *ports[0];
};

struct ata_port_operations___5 {
	int (*qc_defer)(struct ata_queued_cmd___5 *);
	int (*check_atapi_dma)(struct ata_queued_cmd___5 *);
	void (*qc_prep)(struct ata_queued_cmd___5 *);
	unsigned int (*qc_issue)(struct ata_queued_cmd___5 *);
	bool (*qc_fill_rtf)(struct ata_queued_cmd___5 *);
	int (*cable_detect)(struct ata_port___5 *);
	long unsigned int (*mode_filter)(struct ata_device___5 *, long unsigned int);
	void (*set_piomode)(struct ata_port___5 *, struct ata_device___5 *);
	void (*set_dmamode)(struct ata_port___5 *, struct ata_device___5 *);
	int (*set_mode)(struct ata_link___5 *, struct ata_device___5 **);
	unsigned int (*read_id)(struct ata_device___5 *, struct ata_taskfile *, u16 *);
	void (*dev_config)(struct ata_device___5 *);
	void (*freeze)(struct ata_port___5 *);
	void (*thaw)(struct ata_port___5 *);
	ata_prereset_fn_t___5 prereset;
	ata_reset_fn_t___5 softreset;
	ata_reset_fn_t___5 hardreset;
	ata_postreset_fn_t___5 postreset;
	ata_prereset_fn_t___5 pmp_prereset;
	ata_reset_fn_t___5 pmp_softreset;
	ata_reset_fn_t___5 pmp_hardreset;
	ata_postreset_fn_t___5 pmp_postreset;
	void (*error_handler)(struct ata_port___5 *);
	void (*lost_interrupt)(struct ata_port___5 *);
	void (*post_internal_cmd)(struct ata_queued_cmd___5 *);
	void (*sched_eh)(struct ata_port___5 *);
	void (*end_eh)(struct ata_port___5 *);
	int (*scr_read)(struct ata_link___5 *, unsigned int, u32 *);
	int (*scr_write)(struct ata_link___5 *, unsigned int, u32);
	void (*pmp_attach)(struct ata_port___5 *);
	void (*pmp_detach)(struct ata_port___5 *);
	int (*set_lpm)(struct ata_link___5 *, enum ata_lpm_policy, unsigned int);
	int (*port_suspend)(struct ata_port___5 *, pm_message_t);
	int (*port_resume)(struct ata_port___5 *);
	int (*port_start)(struct ata_port___5 *);
	void (*port_stop)(struct ata_port___5 *);
	void (*host_stop)(struct ata_host___5 *);
	void (*sff_dev_select)(struct ata_port___5 *, unsigned int);
	void (*sff_set_devctl)(struct ata_port___5 *, u8);
	u8 (*sff_check_status)(struct ata_port___5 *);
	u8 (*sff_check_altstatus)(struct ata_port___5 *);
	void (*sff_tf_load)(struct ata_port___5 *, const struct ata_taskfile *);
	void (*sff_tf_read)(struct ata_port___5 *, struct ata_taskfile *);
	void (*sff_exec_command)(struct ata_port___5 *, const struct ata_taskfile *);
	unsigned int (*sff_data_xfer)(struct ata_queued_cmd___5 *, unsigned char *, unsigned int, int);
	void (*sff_irq_on)(struct ata_port___5 *);
	bool (*sff_irq_check)(struct ata_port___5 *);
	void (*sff_irq_clear)(struct ata_port___5 *);
	void (*sff_drain_fifo)(struct ata_queued_cmd___5 *);
	void (*bmdma_setup)(struct ata_queued_cmd___5 *);
	void (*bmdma_start)(struct ata_queued_cmd___5 *);
	void (*bmdma_stop)(struct ata_queued_cmd___5 *);
	u8 (*bmdma_status)(struct ata_port___5 *);
	ssize_t (*em_show)(struct ata_port___5 *, char *);
	ssize_t (*em_store)(struct ata_port___5 *, const char *, size_t);
	ssize_t (*sw_activity_show)(struct ata_device___5 *, char *);
	ssize_t (*sw_activity_store)(struct ata_device___5 *, enum sw_activity);
	ssize_t (*transmit_led_message)(struct ata_port___5 *, u32, ssize_t);
	void (*phy_reset)(struct ata_port___5 *);
	void (*eng_timeout)(struct ata_port___5 *);
	const struct ata_port_operations___5 *inherits;
};

struct ata_port___5 {
	struct Scsi_Host___12 *scsi_host;
	struct ata_port_operations___5 *ops;
	spinlock_t *lock;
	long unsigned int flags;
	unsigned int pflags;
	unsigned int print_id;
	unsigned int local_port_no;
	unsigned int port_no;
	struct ata_ioports ioaddr;
	u8 ctl;
	u8 last_ctl;
	struct ata_link___5 *sff_pio_task_link;
	struct delayed_work sff_pio_task;
	struct ata_bmdma_prd *bmdma_prd;
	dma_addr_t bmdma_prd_dma;
	unsigned int pio_mask;
	unsigned int mwdma_mask;
	unsigned int udma_mask;
	unsigned int cbl;
	struct ata_queued_cmd___5 qcmd[33];
	long unsigned int sas_tag_allocated;
	u64 qc_active;
	int nr_active_links;
	unsigned int sas_last_tag;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ata_link___5 link;
	struct ata_link___5 *slave_link;
	int nr_pmp_links;
	struct ata_link___5 *pmp_link;
	struct ata_link___5 *excl_link;
	struct ata_port_stats stats;
	struct ata_host___5 *host;
	struct device___333 *dev;
	struct device___333 tdev;
	struct mutex scsi_scan_mutex;
	struct delayed_work hotplug_task;
	struct work_struct scsi_rescan_task;
	unsigned int hsm_task_state;
	u32 msg_enable;
	struct list_head eh_done_q;
	wait_queue_head_t eh_wait_q;
	int eh_tries;
	struct completion park_req_pending;
	pm_message_t pm_mesg;
	enum ata_lpm_policy target_lpm_policy;
	struct timer_list fastdrain_timer;
	long unsigned int fastdrain_cnt;
	int em_message_type;
	void *private_data;
	struct ata_acpi_gtm __acpi_init_gtm;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sector_buf[512];
};

struct ata_port_info___5 {
	long unsigned int flags;
	long unsigned int link_flags;
	long unsigned int pio_mask;
	long unsigned int mwdma_mask;
	long unsigned int udma_mask;
	struct ata_port_operations___5 *port_ops;
	void *private_data;
};

struct module___298;

struct file___367;

struct kiocb___367;

struct poll_table_struct___220;

struct vm_area_struct___368;

struct inode___367;

struct file_lock___367;

struct page___368;

struct seq_file___311;

struct file_operations___367 {
	struct module___298 *owner;
	loff_t (*llseek)(struct file___367 *, loff_t, int);
	ssize_t (*read)(struct file___367 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___367 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___367 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___367 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___367 *, bool);
	int (*iterate)(struct file___367 *, struct dir_context *);
	int (*iterate_shared)(struct file___367 *, struct dir_context *);
	__poll_t (*poll)(struct file___367 *, struct poll_table_struct___220 *);
	long int (*unlocked_ioctl)(struct file___367 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___367 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___367 *, struct vm_area_struct___368 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___367 *, struct file___367 *);
	int (*flush)(struct file___367 *, fl_owner_t);
	int (*release)(struct inode___367 *, struct file___367 *);
	int (*fsync)(struct file___367 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___367 *, int);
	int (*lock)(struct file___367 *, int, struct file_lock___367 *);
	ssize_t (*sendpage)(struct file___367 *, struct page___368 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___367 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___367 *, int, struct file_lock___367 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___367 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___367 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___367 *, long int, struct file_lock___367 **, void **);
	long int (*fallocate)(struct file___367 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___311 *, struct file___367 *);
	ssize_t (*copy_file_range)(struct file___367 *, loff_t, struct file___367 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___367 *, loff_t, struct file___367 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___367 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___367 {
	u64 seqnum;
	struct vm_area_struct___368 *vmas[4];
};

struct page_frag___367 {
	struct page___368 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___367;

struct cred___338;

struct bio_list___184;

struct backing_dev_info___184;

struct io_context___104;

struct request_queue___100;

struct vm_struct___273;

struct task_struct___368 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___368 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___367 *mm;
	struct mm_struct___367 *active_mm;
	struct vmacache___367 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___368 *real_parent;
	struct task_struct___368 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___368 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___217 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___217 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___217 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___338 *ptracer_cred;
	const struct cred___338 *real_cred;
	const struct cred___338 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___368 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___184 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___184 *backing_dev_info;
	struct io_context___104 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___367 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___100 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___368 *oom_reaper_list;
	struct vm_struct___273 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___141 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct secondary_data___368 {
	void *stack;
	struct task_struct___368 *task;
	long int status;
};

typedef struct page___368 *pgtable_t___367;

struct address_space___366;

struct dev_pagemap___355;

struct page___368 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___366 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___368 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___367 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___367 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___355 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___367;

struct lruvec___367 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___367 *pgdat;
};

struct zone___367 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___367 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___367 {
	struct zone___367 *zone;
	int zone_idx;
};

struct zonelist___367 {
	struct zoneref___367 _zonerefs[25];
};

struct pglist_data___367 {
	struct zone___367 node_zones[3];
	struct zonelist___367 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___368 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___368 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___367 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___368 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___368 *owner;
};

struct blocking_notifier_head___367 {
	struct rw_semaphore___368 rwsem;
	struct notifier_block *head;
};

struct kernfs_root___360;

struct kernfs_elem_dir___360 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___360 *root;
};

struct kernfs_node___361;

struct kernfs_syscall_ops___360;

struct kernfs_root___360 {
	struct kernfs_node___361 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___360 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___360 {
	struct kernfs_node___361 *target_kn;
};

struct kernfs_ops___360;

struct kernfs_elem_attr___360 {
	const struct kernfs_ops___360 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___361 *notify_next;
};

struct kernfs_node___361 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___361 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___360 dir;
		struct kernfs_elem_symlink___360 symlink;
		struct kernfs_elem_attr___360 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___360;

struct kernfs_ops___360 {
	int (*open)(struct kernfs_open_file___360 *);
	void (*release)(struct kernfs_open_file___360 *);
	int (*seq_show)(struct seq_file___311 *, void *);
	void * (*seq_start)(struct seq_file___311 *, loff_t *);
	void * (*seq_next)(struct seq_file___311 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___311 *, void *);
	ssize_t (*read)(struct kernfs_open_file___360 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___360 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___360 *, struct vm_area_struct___368 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___360 *, struct poll_table_struct___220 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___360 {
	int (*remount_fs)(struct kernfs_root___360 *, int *, char *);
	int (*show_options)(struct seq_file___311 *, struct kernfs_root___360 *);
	int (*mkdir)(struct kernfs_node___361 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___361 *);
	int (*rename)(struct kernfs_node___361 *, struct kernfs_node___361 *, const char *);
	int (*show_path)(struct seq_file___311 *, struct kernfs_node___361 *, struct kernfs_root___360 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___310;

struct seq_file___311 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___310 *op;
	int poll_event;
	const struct file___367 *file;
	void *private;
};

struct vm_operations_struct___355;

struct kernfs_open_file___360 {
	struct kernfs_node___361 *kn;
	struct file___367 *file;
	struct seq_file___311 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___355 *vm_ops;
};

struct dentry___366;

struct path___367 {
	struct vfsmount *mnt;
	struct dentry___366 *dentry;
};

struct file___367 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___367 f_path;
	struct inode___367 *f_inode;
	const struct file_operations___367 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___217 f_owner;
	const struct cred___338 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___366 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___355;

struct vm_operations_struct___355 {
	void (*open)(struct vm_area_struct___368 *);
	void (*close)(struct vm_area_struct___368 *);
	int (*split)(struct vm_area_struct___368 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___368 *);
	vm_fault_t (*fault)(struct vm_fault___355 *);
	vm_fault_t (*huge_fault)(struct vm_fault___355 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___355 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___368 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___355 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___355 *);
	int (*access)(struct vm_area_struct___368 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___368 *);
	int (*set_policy)(struct vm_area_struct___368 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___368 *, long unsigned int);
	struct page___368 * (*find_special_page)(struct vm_area_struct___368 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___226)(struct file___367 *, wait_queue_head_t *, struct poll_table_struct___220 *);

struct poll_table_struct___220 {
	poll_queue_proc___226 _qproc;
	__poll_t _key;
};

struct vm_area_struct___368 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___368 *vm_next;
	struct vm_area_struct___368 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___367 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___355 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___367 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___354;

struct bin_attribute___330;

struct attribute_group___331 {
	const char *name;
	umode_t (*is_visible)(struct kobject___354 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___354 *, struct bin_attribute___330 *, int);
	struct attribute **attrs;
	struct bin_attribute___330 **bin_attrs;
};

struct kset___353;

struct kobj_type___353;

struct kobject___354 {
	const char *name;
	struct list_head entry;
	struct kobject___354 *parent;
	struct kset___353 *kset;
	struct kobj_type___353 *ktype;
	struct kernfs_node___361 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___330 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___367 *, struct kobject___354 *, struct bin_attribute___330 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___367 *, struct kobject___354 *, struct bin_attribute___330 *, char *, loff_t, size_t);
	int (*mmap)(struct file___367 *, struct kobject___354 *, struct bin_attribute___330 *, struct vm_area_struct___368 *);
};

struct sysfs_ops___353 {
	ssize_t (*show)(struct kobject___354 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___354 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___353;

struct kset___353 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___354 kobj;
	const struct kset_uevent_ops___353 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___353 {
	void (*release)(struct kobject___354 *);
	const struct sysfs_ops___353 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___28 * (*child_ns_type)(struct kobject___354 *);
	const void * (*namespace)(struct kobject___354 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___353 {
	int (* const filter)(struct kset___353 *, struct kobject___354 *);
	const char * (* const name)(struct kset___353 *, struct kobject___354 *);
	int (* const uevent)(struct kset___353 *, struct kobject___354 *, struct kobj_uevent_env *);
};

struct kobj_attribute___345 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___354 *, struct kobj_attribute___345 *, char *);
	ssize_t (*store)(struct kobject___354 *, struct kobj_attribute___345 *, const char *, size_t);
};

struct device___334;

struct dev_pm_ops___334 {
	int (*prepare)(struct device___334 *);
	void (*complete)(struct device___334 *);
	int (*suspend)(struct device___334 *);
	int (*resume)(struct device___334 *);
	int (*freeze)(struct device___334 *);
	int (*thaw)(struct device___334 *);
	int (*poweroff)(struct device___334 *);
	int (*restore)(struct device___334 *);
	int (*suspend_late)(struct device___334 *);
	int (*resume_early)(struct device___334 *);
	int (*freeze_late)(struct device___334 *);
	int (*thaw_early)(struct device___334 *);
	int (*poweroff_late)(struct device___334 *);
	int (*restore_early)(struct device___334 *);
	int (*suspend_noirq)(struct device___334 *);
	int (*resume_noirq)(struct device___334 *);
	int (*freeze_noirq)(struct device___334 *);
	int (*thaw_noirq)(struct device___334 *);
	int (*poweroff_noirq)(struct device___334 *);
	int (*restore_noirq)(struct device___334 *);
	int (*runtime_suspend)(struct device___334 *);
	int (*runtime_resume)(struct device___334 *);
	int (*runtime_idle)(struct device___334 *);
};

struct dev_pm_info___334 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___5 *subsys_data;
	void (*set_latency_tolerance)(struct device___334 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___334;

struct bus_type___334;

struct device_driver___334;

struct dev_pm_domain___334;

struct dma_map_ops___122;

struct fwnode_handle___256;

struct class___334;

struct device___334 {
	struct device___334 *parent;
	struct device_private *p;
	struct kobject___354 kobj;
	const char *init_name;
	const struct device_type___334 *type;
	struct mutex mutex;
	struct bus_type___334 *bus;
	struct device_driver___334 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___334 power;
	struct dev_pm_domain___334 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___122 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___256 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___334 *class;
	const struct attribute_group___331 **groups;
	void (*release)(struct device___334 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___334 {
	struct dev_pm_ops___334 ops;
	void (*detach)(struct device___334 *, bool);
	int (*activate)(struct device___334 *);
	void (*sync)(struct device___334 *);
	void (*dismiss)(struct device___334 *);
};

struct key___338;

struct user_struct___338 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___338 *uid_keyring;
	struct key___338 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___367;

struct mm_struct___367 {
	struct {
		struct vm_area_struct___368 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___367 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___368 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___367 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___368 *owner;
		struct user_namespace___3 *user_ns;
		struct file___367 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___367 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___338 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___338 *session_keyring;
	struct key___338 *process_keyring;
	struct key___338 *thread_keyring;
	struct key___338 *request_key_auth;
	void *security;
	struct user_struct___338 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct bio___184;

struct bio_list___184 {
	struct bio___184 *head;
	struct bio___184 *tail;
};

struct bdi_writeback_congested___184;

struct bdi_writeback___184 {
	struct backing_dev_info___184 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___184 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___157 *memcg_css;
	struct cgroup_subsys_state___157 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___184 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___184 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___334 *dev;
	struct device___334 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___366 *debug_dir;
	struct dentry___366 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___104;

struct io_context___104 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___104 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

typedef blk_qc_t make_request_fn___100(struct request_queue___100 *, struct bio___184 *);

struct request___100;

typedef int dma_drain_needed_fn___100(struct request___100 *);

struct bsg_ops___100;

struct bsg_class_device___100 {
	struct device___334 *class_dev;
	int minor;
	struct request_queue___100 *queue;
	const struct bsg_ops___100 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___184 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___184 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___100;

struct blk_mq_ops___37;

struct blk_mq_hw_ctx___37;

struct blk_mq_tag_set___37;

struct request_queue___100 {
	struct list_head queue_head;
	struct request___100 *last_merge;
	struct elevator_queue___100 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___100 *make_request_fn;
	dma_drain_needed_fn___100 *dma_drain_needed;
	const struct blk_mq_ops___37 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___37 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___184 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___354 kobj;
	struct kobject___354 *mq_kobj;
	struct blk_integrity integrity;
	struct device___334 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	struct bsg_class_device___100 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set___37 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___184 bio_split;
	struct dentry___366 *debugfs_dir;
	struct dentry___366 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___273 {
	struct vm_struct___273 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___368 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bus_type___334 {
	const char *name;
	const char *dev_name;
	struct device___334 *dev_root;
	const struct attribute_group___331 **bus_groups;
	const struct attribute_group___331 **dev_groups;
	const struct attribute_group___331 **drv_groups;
	int (*match)(struct device___334 *, struct device_driver___334 *);
	int (*uevent)(struct device___334 *, struct kobj_uevent_env *);
	int (*probe)(struct device___334 *);
	int (*remove)(struct device___334 *);
	void (*shutdown)(struct device___334 *);
	int (*online)(struct device___334 *);
	int (*offline)(struct device___334 *);
	int (*suspend)(struct device___334 *, pm_message_t);
	int (*resume)(struct device___334 *);
	int (*num_vf)(struct device___334 *);
	int (*dma_configure)(struct device___334 *);
	const struct dev_pm_ops___334 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___334 {
	const char *name;
	struct bus_type___334 *bus;
	struct module___298 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___334 *);
	int (*remove)(struct device___334 *);
	void (*shutdown)(struct device___334 *);
	int (*suspend)(struct device___334 *, pm_message_t);
	int (*resume)(struct device___334 *);
	const struct attribute_group___331 **groups;
	const struct dev_pm_ops___334 *pm;
	void (*coredump)(struct device___334 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___334 {
	const char *name;
	const struct attribute_group___331 **groups;
	int (*uevent)(struct device___334 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___334 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___334 *);
	const struct dev_pm_ops___334 *pm;
};

struct module_kobject___295 {
	struct kobject___354 kobj;
	struct module___298 *mod;
	struct kobject___354 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___295 {
	struct module___298 *mod;
	struct latch_tree_node node;
};

struct module_layout___295 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___295 mtn;
};

struct module_attribute___295;

struct kernel_param___295;

struct module___298 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___295 mkobj;
	struct module_attribute___295 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___354 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___295 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___295 core_layout;
	struct module_layout___295 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide46;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide47;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct class___334 {
	const char *name;
	struct module___298 *owner;
	const struct attribute_group___331 **class_groups;
	const struct attribute_group___331 **dev_groups;
	struct kobject___354 *dev_kobj;
	int (*dev_uevent)(struct device___334 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___334 *, umode_t *);
	void (*class_release)(struct class___334 *);
	void (*dev_release)(struct device___334 *);
	int (*shutdown_pre)(struct device___334 *);
	const struct kobj_ns_type_operations___28 *ns_type;
	const void * (*namespace)(struct device___334 *);
	const struct dev_pm_ops___334 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct device_attribute___46 {
	struct attribute attr;
	ssize_t (*show)(struct device___334 *, struct device_attribute___46 *, char *);
	ssize_t (*store)(struct device___334 *, struct device_attribute___46 *, const char *, size_t);
};

struct dma_map_ops___122 {
	void * (*alloc)(struct device___334 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___334 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___334 *, struct vm_area_struct___368 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___334 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___334 *, struct page___368 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___334 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___334 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___334 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___334 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___334 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___334 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___334 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___334 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___334 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___334 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___334 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___334 *, u64);
	u64 (*get_required_mask)(struct device___334 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___256;

struct fwnode_handle___256 {
	struct fwnode_handle___256 *secondary;
	const struct fwnode_operations___256 *ops;
};

struct address_space_operations___366;

struct address_space___366 {
	struct inode___367 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___368 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___366 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___355)(struct vm_area_struct___368 *, long unsigned int, const struct page___368 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___355)(struct page___368 *, void *);

struct dev_pagemap___355 {
	dev_page_fault_t___355 page_fault;
	dev_page_free_t___355 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___334 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___367 {
	struct task_struct___368 *task;
	struct core_thread___367 *next;
};

struct core_state___367 {
	atomic_t nr_threads;
	struct core_thread___367 dumper;
	struct completion startup;
};

struct vm_fault___355 {
	struct vm_area_struct___368 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___368 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___368 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___367 prealloc_pte;
};

struct dentry_operations___366;

struct super_block___366;

struct dentry___366 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___366 *d_parent;
	struct qstr d_name;
	struct inode___367 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___366 *d_op;
	struct super_block___366 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___366;

struct block_device___366;

struct cdev___86;

struct inode___367 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___366 *i_op;
	struct super_block___366 *i_sb;
	struct address_space___366 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___368 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___184 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___367 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___366 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___366 *i_bdev;
		struct cdev___86 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___366 {
	int (*d_revalidate)(struct dentry___366 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___366 *, unsigned int);
	int (*d_hash)(const struct dentry___366 *, struct qstr *);
	int (*d_compare)(const struct dentry___366 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___366 *);
	int (*d_init)(struct dentry___366 *);
	void (*d_release)(struct dentry___366 *);
	void (*d_prune)(struct dentry___366 *);
	void (*d_iput)(struct dentry___366 *, struct inode___367 *);
	char * (*d_dname)(struct dentry___366 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___367 *);
	int (*d_manage)(const struct path___367 *, bool);
	struct dentry___366 * (*d_real)(struct dentry___366 *, const struct inode___367 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___366;

struct mem_dqinfo___366 {
	struct quota_format_type___366 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___366;

struct quota_info___366 {
	unsigned int flags;
	struct rw_semaphore___368 dqio_sem;
	struct inode___367 *files[3];
	struct mem_dqinfo___366 info[3];
	const struct quota_format_ops___366 *ops[3];
};

struct rcuwait___366 {
	struct task_struct___368 *task;
};

struct percpu_rw_semaphore___366 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___368 rw_sem;
	struct rcuwait___366 writer;
	int readers_block;
};

struct sb_writers___366 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___366 rw_sem[3];
};

struct file_system_type___366;

struct super_operations___366;

struct dquot_operations___366;

struct quotactl_ops___366;

struct super_block___366 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___366 *s_type;
	const struct super_operations___366 *s_op;
	const struct dquot_operations___366 *dq_op;
	const struct quotactl_ops___366 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___366 *s_root;
	struct rw_semaphore___368 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___366 *s_bdev;
	struct backing_dev_info___184 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___366 s_dquot;
	struct sb_writers___366 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___366 *s_d_op;
	int cleancache_poolid;
	struct shrinker___133 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct io_cq___104 {
	struct request_queue___100 *q;
	struct io_context___104 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___367 {
	struct file___367 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___367 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___366 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___367 *ia_file;
};

struct dquot___366 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___366 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___366 {
	int qf_fmt_id;
	const struct quota_format_ops___366 *qf_ops;
	struct module___298 *qf_owner;
	struct quota_format_type___366 *qf_next;
};

struct quota_format_ops___366 {
	int (*check_quota_file)(struct super_block___366 *, int);
	int (*read_file_info)(struct super_block___366 *, int);
	int (*write_file_info)(struct super_block___366 *, int);
	int (*free_file_info)(struct super_block___366 *, int);
	int (*read_dqblk)(struct dquot___366 *);
	int (*commit_dqblk)(struct dquot___366 *);
	int (*release_dqblk)(struct dquot___366 *);
	int (*get_next_id)(struct super_block___366 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___366 {
	int (*write_dquot)(struct dquot___366 *);
	struct dquot___366 * (*alloc_dquot)(struct super_block___366 *, int);
	void (*destroy_dquot)(struct dquot___366 *);
	int (*acquire_dquot)(struct dquot___366 *);
	int (*release_dquot)(struct dquot___366 *);
	int (*mark_dirty)(struct dquot___366 *);
	int (*write_info)(struct super_block___366 *, int);
	qsize_t * (*get_reserved_space)(struct inode___367 *);
	int (*get_projid)(struct inode___367 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___367 *, qsize_t *);
	int (*get_next_id)(struct super_block___366 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___366 {
	int (*quota_on)(struct super_block___366 *, int, int, const struct path___367 *);
	int (*quota_off)(struct super_block___366 *, int);
	int (*quota_enable)(struct super_block___366 *, unsigned int);
	int (*quota_disable)(struct super_block___366 *, unsigned int);
	int (*quota_sync)(struct super_block___366 *, int);
	int (*set_info)(struct super_block___366 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___366 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___366 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___366 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___366 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___366 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___366 {
	int (*writepage)(struct page___368 *, struct writeback_control___3 *);
	int (*readpage)(struct file___367 *, struct page___368 *);
	int (*writepages)(struct address_space___366 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___368 *);
	int (*readpages)(struct file___367 *, struct address_space___366 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___367 *, struct address_space___366 *, loff_t, unsigned int, unsigned int, struct page___368 **, void **);
	int (*write_end)(struct file___367 *, struct address_space___366 *, loff_t, unsigned int, unsigned int, struct page___368 *, void *);
	sector_t (*bmap)(struct address_space___366 *, sector_t);
	void (*invalidatepage)(struct page___368 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___368 *, gfp_t);
	void (*freepage)(struct page___368 *);
	ssize_t (*direct_IO)(struct kiocb___367 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___366 *, struct page___368 *, struct page___368 *, enum migrate_mode);
	bool (*isolate_page)(struct page___368 *, isolate_mode_t);
	void (*putback_page)(struct page___368 *);
	int (*launder_page)(struct page___368 *);
	int (*is_partially_uptodate)(struct page___368 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___368 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___366 *, struct page___368 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___367 *, sector_t *);
	void (*swap_deactivate)(struct file___367 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct hd_struct___104;

struct gendisk___104;

struct block_device___366 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___367 *bd_inode;
	struct super_block___366 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___366 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___104 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___104 *bd_disk;
	struct request_queue___100 *bd_queue;
	struct backing_dev_info___184 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct hd_struct___104 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___334 __dev;
	struct kobject___354 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___104;

struct block_device_operations___101;

struct gendisk___104 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___104 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___104 *part_tbl;
	struct hd_struct___104 part0;
	const struct block_device_operations___101 *fops;
	struct request_queue___100 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___368 lookup_sem;
	struct kobject___354 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___354 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___86 {
	struct kobject___354 kobj;
	struct module___298 *owner;
	const struct file_operations___367 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___366 {
	struct dentry___366 * (*lookup)(struct inode___367 *, struct dentry___366 *, unsigned int);
	const char * (*get_link)(struct dentry___366 *, struct inode___367 *, struct delayed_call *);
	int (*permission)(struct inode___367 *, int);
	struct posix_acl * (*get_acl)(struct inode___367 *, int);
	int (*readlink)(struct dentry___366 *, char *, int);
	int (*create)(struct inode___367 *, struct dentry___366 *, umode_t, bool);
	int (*link)(struct dentry___366 *, struct inode___367 *, struct dentry___366 *);
	int (*unlink)(struct inode___367 *, struct dentry___366 *);
	int (*symlink)(struct inode___367 *, struct dentry___366 *, const char *);
	int (*mkdir)(struct inode___367 *, struct dentry___366 *, umode_t);
	int (*rmdir)(struct inode___367 *, struct dentry___366 *);
	int (*mknod)(struct inode___367 *, struct dentry___366 *, umode_t, dev_t);
	int (*rename)(struct inode___367 *, struct dentry___366 *, struct inode___367 *, struct dentry___366 *, unsigned int);
	int (*setattr)(struct dentry___366 *, struct iattr___366 *);
	int (*getattr)(const struct path___367 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___366 *, char *, size_t);
	int (*fiemap)(struct inode___367 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___367 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___367 *, struct dentry___366 *, struct file___367 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___367 *, struct dentry___366 *, umode_t);
	int (*set_acl)(struct inode___367 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___366 {
	void (*fl_copy_lock)(struct file_lock___367 *, struct file_lock___367 *);
	void (*fl_release_private)(struct file_lock___367 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___366;

struct lock_manager_operations___366;

struct file_lock___367 {
	struct file_lock___367 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___367 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___366 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___366 *fl_ops;
	const struct lock_manager_operations___366 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___366 {
	int (*lm_compare_owner)(struct file_lock___367 *, struct file_lock___367 *);
	long unsigned int (*lm_owner_key)(struct file_lock___367 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___367 *);
	int (*lm_grant)(struct file_lock___367 *, int);
	bool (*lm_break)(struct file_lock___367 *);
	int (*lm_change)(struct file_lock___367 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___367 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___366 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___366 *fa_next;
	struct file___367 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___366 {
	const char *name;
	int fs_flags;
	struct dentry___366 * (*mount)(struct file_system_type___366 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___366 *);
	struct module___298 *owner;
	struct file_system_type___366 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___366 {
	struct inode___367 * (*alloc_inode)(struct super_block___366 *);
	void (*destroy_inode)(struct inode___367 *);
	void (*dirty_inode)(struct inode___367 *, int);
	int (*write_inode)(struct inode___367 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___367 *);
	void (*evict_inode)(struct inode___367 *);
	void (*put_super)(struct super_block___366 *);
	int (*sync_fs)(struct super_block___366 *, int);
	int (*freeze_super)(struct super_block___366 *);
	int (*freeze_fs)(struct super_block___366 *);
	int (*thaw_super)(struct super_block___366 *);
	int (*unfreeze_fs)(struct super_block___366 *);
	int (*statfs)(struct dentry___366 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___366 *, int *, char *);
	void (*umount_begin)(struct super_block___366 *);
	int (*show_options)(struct seq_file___311 *, struct dentry___366 *);
	int (*show_devname)(struct seq_file___311 *, struct dentry___366 *);
	int (*show_path)(struct seq_file___311 *, struct dentry___366 *);
	int (*show_stats)(struct seq_file___311 *, struct dentry___366 *);
	ssize_t (*quota_read)(struct super_block___366 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___366 *, int, const char *, size_t, loff_t);
	struct dquot___366 ** (*get_dquots)(struct inode___367 *);
	int (*bdev_try_to_free_page)(struct super_block___366 *, struct page___368 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___366 *, struct shrink_control___133 *);
	long int (*free_cached_objects)(struct super_block___366 *, struct shrink_control___133 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___184(struct bio___184 *);

struct bio_vec___186 {
	struct page___368 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___184;

struct bio___184 {
	struct bio___184 *bi_next;
	struct gendisk___104 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___184 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___184 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___186 *bi_io_vec;
	struct bio_set___184 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___186 bi_inline_vecs[0];
};

typedef void compound_page_dtor___355(struct page___368 *);

struct fwnode_reference_args___256;

struct fwnode_endpoint___256;

struct fwnode_operations___256 {
	struct fwnode_handle___256 * (*get)(struct fwnode_handle___256 *);
	void (*put)(struct fwnode_handle___256 *);
	bool (*device_is_available)(const struct fwnode_handle___256 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___256 *, const struct device___334 *);
	bool (*property_present)(const struct fwnode_handle___256 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___256 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___256 *, const char *, const char **, size_t);
	struct fwnode_handle___256 * (*get_parent)(const struct fwnode_handle___256 *);
	struct fwnode_handle___256 * (*get_next_child_node)(const struct fwnode_handle___256 *, struct fwnode_handle___256 *);
	struct fwnode_handle___256 * (*get_named_child_node)(const struct fwnode_handle___256 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___256 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___256 *);
	struct fwnode_handle___256 * (*graph_get_next_endpoint)(const struct fwnode_handle___256 *, struct fwnode_handle___256 *);
	struct fwnode_handle___256 * (*graph_get_remote_endpoint)(const struct fwnode_handle___256 *);
	struct fwnode_handle___256 * (*graph_get_port_parent)(struct fwnode_handle___256 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___256 *, struct fwnode_endpoint___256 *);
};

struct fwnode_endpoint___256 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___256 *local_fwnode;
};

struct fwnode_reference_args___256 {
	struct fwnode_handle___256 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

typedef int (*key_restrict_link_func_t___339)(struct key___338 *, const struct key_type *, const union key_payload *, struct key___338 *);

struct key_restriction___338;

struct key___338 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___368 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___338 *restrict_link;
};

struct key_restriction___338 {
	key_restrict_link_func_t___339 check;
	struct key___338 *key;
	struct key_type *keytype;
};

struct seq_operations___310 {
	void * (*start)(struct seq_file___311 *, loff_t *);
	void (*stop)(struct seq_file___311 *, void *);
	void * (*next)(struct seq_file___311 *, void *, loff_t *);
	int (*show)(struct seq_file___311 *, void *);
};

struct bio_integrity_payload___184 {
	struct bio___184 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___186 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___186 bip_inline_vecs[0];
};

struct disk_part_tbl___104 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___104 *last_lookup;
	struct hd_struct___104 *part[0];
};

struct block_device_operations___101 {
	int (*open)(struct block_device___366 *, fmode_t);
	void (*release)(struct gendisk___104 *, fmode_t);
	int (*rw_page)(struct block_device___366 *, sector_t, struct page___368 *, unsigned int);
	int (*ioctl)(struct block_device___366 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___366 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___104 *, unsigned int);
	int (*media_changed)(struct gendisk___104 *);
	void (*unlock_native_capacity)(struct gendisk___104 *);
	int (*revalidate_disk)(struct gendisk___104 *);
	int (*getgeo)(struct block_device___366 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___366 *, long unsigned int);
	int (*report_zones)(struct gendisk___104 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___298 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bdi_writeback_congested___184 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___184 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bsg_ops___100 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___100 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___100 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___100 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___100(struct request___100 *, blk_status_t);

struct request___100 {
	struct request_queue___100 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___37 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___184 *bio;
	struct bio___184 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___186 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___104 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___100 *saved_end_io;
		} flush;
	};
	struct gendisk___104 *rq_disk;
	struct hd_struct___104 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___100 *end_io;
	void *end_io_data;
	struct request___100 *next_rq;
};

struct blk_mq_hw_ctx___37 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___100 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags___4 *tags;
	struct blk_mq_tags___4 *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	unsigned int rh_reserved_nr_expired;
	struct hlist_node cpuhp_dead;
	struct kobject___354 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___366 *debugfs_dir;
	struct dentry___366 *sched_debugfs_dir;
	struct list_head hctx_list;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___100;

struct elevator_mq_ops___100 {
	int (*init_sched)(struct request_queue___100 *, struct elevator_type___100 *);
	void (*exit_sched)(struct elevator_queue___100 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___37 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___37 *, unsigned int);
	bool (*allow_merge)(struct request_queue___100 *, struct request___100 *, struct bio___184 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx___37 *, struct bio___184 *);
	int (*request_merge)(struct request_queue___100 *, struct request___100 **, struct bio___184 *);
	void (*request_merged)(struct request_queue___100 *, struct request___100 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___100 *, struct request___100 *, struct request___100 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___100 *, struct bio___184 *);
	void (*finish_request)(struct request___100 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___37 *, struct list_head *, bool);
	struct request___100 * (*dispatch_request)(struct blk_mq_hw_ctx___37 *);
	bool (*has_work)(struct blk_mq_hw_ctx___37 *);
	void (*completed_request)(struct request___100 *, u64);
	void (*started_request)(struct request___100 *);
	void (*requeue_request)(struct request___100 *);
	struct request___100 * (*former_request)(struct request_queue___100 *, struct request___100 *);
	struct request___100 * (*next_request)(struct request_queue___100 *, struct request___100 *);
	void (*init_icq)(struct io_cq___104 *);
	void (*exit_icq)(struct io_cq___104 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx___37 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___100;

struct elevator_type___100 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___100 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___100 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___298 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___100 {
	struct elevator_type___100 *type;
	void *elevator_data;
	struct kobject___354 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___100 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___100 *, char *);
	ssize_t (*store)(struct elevator_queue___100 *, const char *, size_t);
};

struct blk_mq_queue_data___37;

typedef blk_status_t queue_rq_fn___37(struct blk_mq_hw_ctx___37 *, const struct blk_mq_queue_data___37 *);

typedef void commit_rqs_fn___37(struct blk_mq_hw_ctx___37 *);

typedef bool get_budget_fn___37(struct blk_mq_hw_ctx___37 *);

typedef void put_budget_fn___37(struct blk_mq_hw_ctx___37 *);

typedef enum blk_eh_timer_return timeout_fn___37(struct request___100 *, bool);

typedef int poll_fn___37(struct blk_mq_hw_ctx___37 *);

typedef void complete_fn___37(struct request___100 *);

typedef int init_hctx_fn___37(struct blk_mq_hw_ctx___37 *, void *, unsigned int);

typedef void exit_hctx_fn___37(struct blk_mq_hw_ctx___37 *, unsigned int);

typedef int init_request_fn___37(struct blk_mq_tag_set___37 *, struct request___100 *, unsigned int, unsigned int);

typedef void exit_request_fn___37(struct blk_mq_tag_set___37 *, struct request___100 *, unsigned int);

typedef bool busy_fn___37(struct request_queue___100 *);

typedef int map_queues_fn___37(struct blk_mq_tag_set___37 *);

typedef void cleanup_rq_fn___37(struct request___100 *);

struct blk_mq_ops___37 {
	queue_rq_fn___37 *queue_rq;
	commit_rqs_fn___37 *commit_rqs;
	get_budget_fn___37 *get_budget;
	put_budget_fn___37 *put_budget;
	timeout_fn___37 *timeout;
	poll_fn___37 *poll;
	complete_fn___37 *complete;
	init_hctx_fn___37 *init_hctx;
	exit_hctx_fn___37 *exit_hctx;
	init_request_fn___37 *init_request;
	exit_request_fn___37 *exit_request;
	void (*initialize_rq_fn)(struct request___100 *);
	busy_fn___37 *busy;
	map_queues_fn___37 *map_queues;
	void (*show_rq)(struct seq_file___311 *, struct request___100 *);
	union {
		cleanup_rq_fn___37 *cleanup_rq;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide45;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct blk_mq_tag_set___37 {
	struct blk_mq_queue_map map[6];
	unsigned int nr_maps;
	const struct blk_mq_ops___37 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	struct blk_mq_tags___4 **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct blk_mq_queue_data___37 {
	struct request___100 *rq;
	bool last;
	long unsigned int rh_reserved1;
};

struct Scsi_Host___13;

struct scsi_host_template___13 {
	struct module___298 *module;
	const char *name;
	const char * (*info)(struct Scsi_Host___13 *);
	int (*ioctl)(struct scsi_device___16 *, int, void *);
	int (*queuecommand)(struct Scsi_Host___13 *, struct scsi_cmnd___2 *);
	int (*eh_abort_handler)(struct scsi_cmnd___2 *);
	int (*eh_device_reset_handler)(struct scsi_cmnd___2 *);
	int (*eh_target_reset_handler)(struct scsi_cmnd___2 *);
	int (*eh_bus_reset_handler)(struct scsi_cmnd___2 *);
	int (*eh_host_reset_handler)(struct scsi_cmnd___2 *);
	int (*slave_alloc)(struct scsi_device___16 *);
	int (*slave_configure)(struct scsi_device___16 *);
	void (*slave_destroy)(struct scsi_device___16 *);
	int (*target_alloc)(struct scsi_target___16 *);
	void (*target_destroy)(struct scsi_target___16 *);
	int (*scan_finished)(struct Scsi_Host___13 *, long unsigned int);
	void (*scan_start)(struct Scsi_Host___13 *);
	int (*change_queue_depth)(struct scsi_device___16 *, int);
	int (*map_queues)(struct Scsi_Host___13 *);
	int (*bios_param)(struct scsi_device___16 *, struct block_device___366 *, sector_t, int *);
	void (*unlock_native_capacity)(struct scsi_device___16 *);
	int (*show_info)(struct seq_file___311 *, struct Scsi_Host___13 *);
	int (*write_info)(struct Scsi_Host___13 *, char *, int);
	enum blk_eh_timer_return (*eh_timed_out)(struct scsi_cmnd___2 *);
	int (*host_reset)(struct Scsi_Host___13 *, int);
	const char *proc_name;
	struct proc_dir_entry *proc_dir;
	int can_queue;
	int this_id;
	short unsigned int sg_tablesize;
	short unsigned int sg_prot_tablesize;
	unsigned int max_sectors;
	long unsigned int dma_boundary;
	short int cmd_per_lun;
	unsigned char present;
	int tag_alloc_policy;
	unsigned int track_queue_depth: 1;
	unsigned int supported_mode: 2;
	unsigned int unchecked_isa_dma: 1;
	unsigned int use_clustering: 1;
	unsigned int emulated: 1;
	unsigned int skip_settle_delay: 1;
	unsigned int no_write_same: 1;
	unsigned int force_blk_mq: 1;
	unsigned int max_host_blocked;
	struct device_attribute___46 **shost_attrs;
	struct device_attribute___46 **sdev_attrs;
	const struct attribute_group___331 **sdev_groups;
	u64 vendor_id;
	unsigned int cmd_size;
	struct scsi_host_cmd_pool *cmd_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct Scsi_Host___13 {
	struct list_head __devices;
	struct list_head __targets;
	struct list_head starved_list;
	spinlock_t default_lock;
	spinlock_t *host_lock;
	struct mutex scan_mutex;
	struct list_head eh_cmd_q;
	struct task_struct___368 *ehandler;
	struct completion *eh_action;
	wait_queue_head_t host_wait;
	struct scsi_host_template___13 *hostt;
	struct scsi_transport_template *transportt;
	struct blk_mq_tag_set___37 tag_set;
	atomic_t host_busy;
	atomic_t host_blocked;
	unsigned int host_failed;
	unsigned int host_eh_scheduled;
	unsigned int host_no;
	int eh_deadline;
	long unsigned int last_reset;
	unsigned int max_channel;
	unsigned int max_id;
	u64 max_lun;
	unsigned int unique_id;
	short unsigned int max_cmd_len;
	int this_id;
	int can_queue;
	short int cmd_per_lun;
	short unsigned int sg_tablesize;
	short unsigned int sg_prot_tablesize;
	unsigned int max_sectors;
	long unsigned int dma_boundary;
	unsigned int nr_hw_queues;
	long unsigned int cmd_serial_number;
	unsigned int active_mode: 2;
	unsigned int unchecked_isa_dma: 1;
	unsigned int use_clustering: 1;
	unsigned int host_self_blocked: 1;
	unsigned int reverse_ordering: 1;
	unsigned int tmf_in_progress: 1;
	unsigned int async_scan: 1;
	unsigned int eh_noresume: 1;
	unsigned int no_write_same: 1;
	unsigned int use_cmd_list: 1;
	unsigned int short_inquiry: 1;
	char work_q_name[20];
	struct workqueue_struct *work_q;
	struct workqueue_struct *tmf_work_q;
	unsigned int no_scsi2_lun_in_cdb: 1;
	unsigned int max_host_blocked;
	unsigned int prot_capabilities;
	unsigned char prot_guard_type;
	long unsigned int base;
	long unsigned int io_port;
	unsigned char n_io_port;
	unsigned char dma_channel;
	unsigned int irq;
	enum scsi_host_state shost_state;
	struct device___334 shost_gendev;
	struct device___334 shost_dev;
	void *shost_data;
	struct device___334 *dma_dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int hostdata[0];
};

struct kernel_param_ops___295 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___295 *);
	int (*get)(char *, const struct kernel_param___295 *);
	void (*free)(void *);
};

struct kparam_array___295;

struct kernel_param___295 {
	const char *name;
	struct module___298 *mod;
	const struct kernel_param_ops___295 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___295 *arr;
	};
};

struct kparam_array___295 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___295 *ops;
	void *elem;
};

struct module_attribute___295 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___295 *, struct module_kobject___295 *, char *);
	ssize_t (*store)(struct module_attribute___295 *, struct module_kobject___295 *, const char *, size_t);
	void (*setup)(struct module___298 *, const char *);
	int (*test)(struct module___298 *);
	void (*free)(struct module___298 *);
};

struct ata_queued_cmd___6;

typedef void (*ata_qc_cb_t___6)(struct ata_queued_cmd___6 *);

struct ata_port___6;

struct ata_device___6;

struct ata_queued_cmd___6 {
	struct ata_port___6 *ap;
	struct ata_device___6 *dev;
	struct scsi_cmnd___2 *scsicmd;
	void (*scsidone)(struct scsi_cmnd___2 *);
	struct ata_taskfile tf;
	u8 cdb[16];
	long unsigned int flags;
	unsigned int tag;
	unsigned int hw_tag;
	unsigned int n_elem;
	unsigned int orig_n_elem;
	int dma_dir;
	unsigned int sect_size;
	unsigned int nbytes;
	unsigned int extrabytes;
	unsigned int curbytes;
	struct scatterlist sgent;
	struct scatterlist *sg;
	struct scatterlist *cursg;
	unsigned int cursg_ofs;
	unsigned int err_mask;
	struct ata_taskfile result_tf;
	ata_qc_cb_t___6 complete_fn;
	void *private_data;
	void *lldd_task;
};

struct ata_link___6;

typedef int (*ata_prereset_fn_t___6)(struct ata_link___6 *, long unsigned int);

struct ata_eh_info___6 {
	struct ata_device___6 *dev;
	u32 serror;
	unsigned int err_mask;
	unsigned int action;
	unsigned int dev_action[2];
	unsigned int flags;
	unsigned int probe_mask;
	char desc[80];
	int desc_len;
};

struct ata_eh_context___6 {
	struct ata_eh_info___6 i;
	int tries[2];
	int cmd_timeout_idx[12];
	unsigned int classes[2];
	unsigned int did_probe_mask;
	unsigned int unloaded_mask;
	unsigned int saved_ncq_enabled;
	u8 saved_xfer_mode[2];
	long unsigned int last_reset;
};

struct ata_device___6 {
	struct ata_link___6 *link;
	unsigned int devno;
	unsigned int horkage;
	long unsigned int flags;
	struct scsi_device___16 *sdev;
	void *private_data;
	union acpi_object *gtf_cache;
	unsigned int gtf_filter;
	struct device___334 tdev;
	u64 n_sectors;
	u64 n_native_sectors;
	unsigned int class;
	long unsigned int unpark_deadline;
	u8 pio_mode;
	u8 dma_mode;
	u8 xfer_mode;
	unsigned int xfer_shift;
	unsigned int multi_count;
	unsigned int max_sectors;
	unsigned int cdb_len;
	long unsigned int pio_mask;
	long unsigned int mwdma_mask;
	long unsigned int udma_mask;
	u16 cylinders;
	u16 heads;
	u16 sectors;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	union {
		u16 id[256];
		u32 gscr[128];
	};
	u8 devslp_timing[8];
	u8 ncq_send_recv_cmds[20];
	u8 ncq_non_data_cmds[64];
	u32 zac_zoned_cap;
	u32 zac_zones_optimal_open;
	u32 zac_zones_optimal_nonseq;
	u32 zac_zones_max_open;
	int spdn_cnt;
	struct ata_ering ering;
	long: 64;
};

struct ata_link___6 {
	struct ata_port___6 *ap;
	int pmp;
	struct device___334 tdev;
	unsigned int active_tag;
	u32 sactive;
	unsigned int flags;
	u32 saved_scontrol;
	unsigned int hw_sata_spd_limit;
	unsigned int sata_spd_limit;
	unsigned int sata_spd;
	enum ata_lpm_policy lpm_policy;
	struct ata_eh_info___6 eh_info;
	struct ata_eh_context___6 eh_context;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ata_device___6 device[2];
	long unsigned int last_lpm_change;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef int (*ata_reset_fn_t___6)(struct ata_link___6 *, unsigned int *, long unsigned int);

typedef void (*ata_postreset_fn_t___6)(struct ata_link___6 *, unsigned int *);

struct ata_port_operations___6;

struct ata_host___6 {
	spinlock_t lock;
	struct device___334 *dev;
	void * const *iomap;
	unsigned int n_ports;
	unsigned int n_tags;
	void *private_data;
	struct ata_port_operations___6 *ops;
	long unsigned int flags;
	struct kref kref;
	struct mutex eh_mutex;
	struct task_struct___368 *eh_owner;
	struct ata_port___6 *simplex_claimed;
	struct ata_port___6 *ports[0];
};

struct ata_port_operations___6 {
	int (*qc_defer)(struct ata_queued_cmd___6 *);
	int (*check_atapi_dma)(struct ata_queued_cmd___6 *);
	void (*qc_prep)(struct ata_queued_cmd___6 *);
	unsigned int (*qc_issue)(struct ata_queued_cmd___6 *);
	bool (*qc_fill_rtf)(struct ata_queued_cmd___6 *);
	int (*cable_detect)(struct ata_port___6 *);
	long unsigned int (*mode_filter)(struct ata_device___6 *, long unsigned int);
	void (*set_piomode)(struct ata_port___6 *, struct ata_device___6 *);
	void (*set_dmamode)(struct ata_port___6 *, struct ata_device___6 *);
	int (*set_mode)(struct ata_link___6 *, struct ata_device___6 **);
	unsigned int (*read_id)(struct ata_device___6 *, struct ata_taskfile *, u16 *);
	void (*dev_config)(struct ata_device___6 *);
	void (*freeze)(struct ata_port___6 *);
	void (*thaw)(struct ata_port___6 *);
	ata_prereset_fn_t___6 prereset;
	ata_reset_fn_t___6 softreset;
	ata_reset_fn_t___6 hardreset;
	ata_postreset_fn_t___6 postreset;
	ata_prereset_fn_t___6 pmp_prereset;
	ata_reset_fn_t___6 pmp_softreset;
	ata_reset_fn_t___6 pmp_hardreset;
	ata_postreset_fn_t___6 pmp_postreset;
	void (*error_handler)(struct ata_port___6 *);
	void (*lost_interrupt)(struct ata_port___6 *);
	void (*post_internal_cmd)(struct ata_queued_cmd___6 *);
	void (*sched_eh)(struct ata_port___6 *);
	void (*end_eh)(struct ata_port___6 *);
	int (*scr_read)(struct ata_link___6 *, unsigned int, u32 *);
	int (*scr_write)(struct ata_link___6 *, unsigned int, u32);
	void (*pmp_attach)(struct ata_port___6 *);
	void (*pmp_detach)(struct ata_port___6 *);
	int (*set_lpm)(struct ata_link___6 *, enum ata_lpm_policy, unsigned int);
	int (*port_suspend)(struct ata_port___6 *, pm_message_t);
	int (*port_resume)(struct ata_port___6 *);
	int (*port_start)(struct ata_port___6 *);
	void (*port_stop)(struct ata_port___6 *);
	void (*host_stop)(struct ata_host___6 *);
	void (*sff_dev_select)(struct ata_port___6 *, unsigned int);
	void (*sff_set_devctl)(struct ata_port___6 *, u8);
	u8 (*sff_check_status)(struct ata_port___6 *);
	u8 (*sff_check_altstatus)(struct ata_port___6 *);
	void (*sff_tf_load)(struct ata_port___6 *, const struct ata_taskfile *);
	void (*sff_tf_read)(struct ata_port___6 *, struct ata_taskfile *);
	void (*sff_exec_command)(struct ata_port___6 *, const struct ata_taskfile *);
	unsigned int (*sff_data_xfer)(struct ata_queued_cmd___6 *, unsigned char *, unsigned int, int);
	void (*sff_irq_on)(struct ata_port___6 *);
	bool (*sff_irq_check)(struct ata_port___6 *);
	void (*sff_irq_clear)(struct ata_port___6 *);
	void (*sff_drain_fifo)(struct ata_queued_cmd___6 *);
	void (*bmdma_setup)(struct ata_queued_cmd___6 *);
	void (*bmdma_start)(struct ata_queued_cmd___6 *);
	void (*bmdma_stop)(struct ata_queued_cmd___6 *);
	u8 (*bmdma_status)(struct ata_port___6 *);
	ssize_t (*em_show)(struct ata_port___6 *, char *);
	ssize_t (*em_store)(struct ata_port___6 *, const char *, size_t);
	ssize_t (*sw_activity_show)(struct ata_device___6 *, char *);
	ssize_t (*sw_activity_store)(struct ata_device___6 *, enum sw_activity);
	ssize_t (*transmit_led_message)(struct ata_port___6 *, u32, ssize_t);
	void (*phy_reset)(struct ata_port___6 *);
	void (*eng_timeout)(struct ata_port___6 *);
	const struct ata_port_operations___6 *inherits;
};

struct ata_port___6 {
	struct Scsi_Host___13 *scsi_host;
	struct ata_port_operations___6 *ops;
	spinlock_t *lock;
	long unsigned int flags;
	unsigned int pflags;
	unsigned int print_id;
	unsigned int local_port_no;
	unsigned int port_no;
	struct ata_ioports ioaddr;
	u8 ctl;
	u8 last_ctl;
	struct ata_link___6 *sff_pio_task_link;
	struct delayed_work sff_pio_task;
	struct ata_bmdma_prd *bmdma_prd;
	dma_addr_t bmdma_prd_dma;
	unsigned int pio_mask;
	unsigned int mwdma_mask;
	unsigned int udma_mask;
	unsigned int cbl;
	struct ata_queued_cmd___6 qcmd[33];
	long unsigned int sas_tag_allocated;
	u64 qc_active;
	int nr_active_links;
	unsigned int sas_last_tag;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ata_link___6 link;
	struct ata_link___6 *slave_link;
	int nr_pmp_links;
	struct ata_link___6 *pmp_link;
	struct ata_link___6 *excl_link;
	struct ata_port_stats stats;
	struct ata_host___6 *host;
	struct device___334 *dev;
	struct device___334 tdev;
	struct mutex scsi_scan_mutex;
	struct delayed_work hotplug_task;
	struct work_struct scsi_rescan_task;
	unsigned int hsm_task_state;
	u32 msg_enable;
	struct list_head eh_done_q;
	wait_queue_head_t eh_wait_q;
	int eh_tries;
	struct completion park_req_pending;
	pm_message_t pm_mesg;
	enum ata_lpm_policy target_lpm_policy;
	struct timer_list fastdrain_timer;
	long unsigned int fastdrain_cnt;
	int em_message_type;
	void *private_data;
	struct ata_acpi_gtm __acpi_init_gtm;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sector_buf[512];
};

struct ata_port_info___6 {
	long unsigned int flags;
	long unsigned int link_flags;
	long unsigned int pio_mask;
	long unsigned int mwdma_mask;
	long unsigned int udma_mask;
	struct ata_port_operations___6 *port_ops;
	void *private_data;
};

struct module___299;

struct file___368;

struct kiocb___368;

struct poll_table_struct___221;

struct vm_area_struct___369;

struct inode___368;

struct file_lock___368;

struct page___369;

struct seq_file___312;

struct file_operations___368 {
	struct module___299 *owner;
	loff_t (*llseek)(struct file___368 *, loff_t, int);
	ssize_t (*read)(struct file___368 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___368 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___368 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___368 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___368 *, bool);
	int (*iterate)(struct file___368 *, struct dir_context *);
	int (*iterate_shared)(struct file___368 *, struct dir_context *);
	__poll_t (*poll)(struct file___368 *, struct poll_table_struct___221 *);
	long int (*unlocked_ioctl)(struct file___368 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___368 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___368 *, struct vm_area_struct___369 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___368 *, struct file___368 *);
	int (*flush)(struct file___368 *, fl_owner_t);
	int (*release)(struct inode___368 *, struct file___368 *);
	int (*fsync)(struct file___368 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___368 *, int);
	int (*lock)(struct file___368 *, int, struct file_lock___368 *);
	ssize_t (*sendpage)(struct file___368 *, struct page___369 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___368 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___368 *, int, struct file_lock___368 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___368 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___368 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___368 *, long int, struct file_lock___368 **, void **);
	long int (*fallocate)(struct file___368 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___312 *, struct file___368 *);
	ssize_t (*copy_file_range)(struct file___368 *, loff_t, struct file___368 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___368 *, loff_t, struct file___368 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___368 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___368 {
	u64 seqnum;
	struct vm_area_struct___369 *vmas[4];
};

struct page_frag___368 {
	struct page___369 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___368;

struct cred___339;

struct bio_list___185;

struct backing_dev_info___185;

struct io_context___105;

struct request_queue___101;

struct vm_struct___274;

struct task_struct___369 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___369 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___368 *mm;
	struct mm_struct___368 *active_mm;
	struct vmacache___368 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___369 *real_parent;
	struct task_struct___369 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___369 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___217 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___217 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___217 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___339 *ptracer_cred;
	const struct cred___339 *real_cred;
	const struct cred___339 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___369 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___185 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___185 *backing_dev_info;
	struct io_context___105 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___368 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___101 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___369 *oom_reaper_list;
	struct vm_struct___274 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___141 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___369 *pgtable_t___368;

struct address_space___367;

struct dev_pagemap___356;

struct page___369 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___367 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___369 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___368 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___368 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___356 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___368;

struct lruvec___368 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___368 *pgdat;
};

struct zone___368 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___368 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___368 {
	struct zone___368 *zone;
	int zone_idx;
};

struct zonelist___368 {
	struct zoneref___368 _zonerefs[25];
};

struct pglist_data___368 {
	struct zone___368 node_zones[3];
	struct zonelist___368 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___369 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___369 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___368 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___369 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___369 *owner;
};

struct secondary_data___369 {
	void *stack;
	struct task_struct___369 *task;
	long int status;
};

struct blocking_notifier_head___368 {
	struct rw_semaphore___369 rwsem;
	struct notifier_block *head;
};

struct dentry___367;

struct path___368 {
	struct vfsmount *mnt;
	struct dentry___367 *dentry;
};

struct file___368 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___368 f_path;
	struct inode___368 *f_inode;
	const struct file_operations___368 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___217 f_owner;
	const struct cred___339 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___367 *f_mapping;
	errseq_t f_wb_err;
};

struct key___339;

struct user_struct___339;

struct cred___339 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___339 *session_keyring;
	struct key___339 *process_keyring;
	struct key___339 *thread_keyring;
	struct key___339 *request_key_auth;
	void *security;
	struct user_struct___339 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___361;

struct kernfs_elem_dir___361 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___361 *root;
};

struct kernfs_node___362;

struct kernfs_syscall_ops___361;

struct kernfs_root___361 {
	struct kernfs_node___362 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___361 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___361 {
	struct kernfs_node___362 *target_kn;
};

struct kernfs_ops___361;

struct kernfs_elem_attr___361 {
	const struct kernfs_ops___361 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___362 *notify_next;
};

struct kernfs_node___362 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___362 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___361 dir;
		struct kernfs_elem_symlink___361 symlink;
		struct kernfs_elem_attr___361 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___361;

struct kernfs_ops___361 {
	int (*open)(struct kernfs_open_file___361 *);
	void (*release)(struct kernfs_open_file___361 *);
	int (*seq_show)(struct seq_file___312 *, void *);
	void * (*seq_start)(struct seq_file___312 *, loff_t *);
	void * (*seq_next)(struct seq_file___312 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___312 *, void *);
	ssize_t (*read)(struct kernfs_open_file___361 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___361 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___361 *, struct vm_area_struct___369 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___361 *, struct poll_table_struct___221 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___361 {
	int (*remount_fs)(struct kernfs_root___361 *, int *, char *);
	int (*show_options)(struct seq_file___312 *, struct kernfs_root___361 *);
	int (*mkdir)(struct kernfs_node___362 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___362 *);
	int (*rename)(struct kernfs_node___362 *, struct kernfs_node___362 *, const char *);
	int (*show_path)(struct seq_file___312 *, struct kernfs_node___362 *, struct kernfs_root___361 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___311;

struct seq_file___312 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___311 *op;
	int poll_event;
	const struct file___368 *file;
	void *private;
};

struct vm_operations_struct___356;

struct kernfs_open_file___361 {
	struct kernfs_node___362 *kn;
	struct file___368 *file;
	struct seq_file___312 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___356 *vm_ops;
};

struct vm_fault___356;

struct vm_operations_struct___356 {
	void (*open)(struct vm_area_struct___369 *);
	void (*close)(struct vm_area_struct___369 *);
	int (*split)(struct vm_area_struct___369 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___369 *);
	vm_fault_t (*fault)(struct vm_fault___356 *);
	vm_fault_t (*huge_fault)(struct vm_fault___356 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___356 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___369 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___356 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___356 *);
	int (*access)(struct vm_area_struct___369 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___369 *);
	int (*set_policy)(struct vm_area_struct___369 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___369 *, long unsigned int);
	struct page___369 * (*find_special_page)(struct vm_area_struct___369 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___227)(struct file___368 *, wait_queue_head_t *, struct poll_table_struct___221 *);

struct poll_table_struct___221 {
	poll_queue_proc___227 _qproc;
	__poll_t _key;
};

struct vm_area_struct___369 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___369 *vm_next;
	struct vm_area_struct___369 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___368 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___356 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___368 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___355;

struct bin_attribute___331;

struct attribute_group___332 {
	const char *name;
	umode_t (*is_visible)(struct kobject___355 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___355 *, struct bin_attribute___331 *, int);
	struct attribute **attrs;
	struct bin_attribute___331 **bin_attrs;
};

struct kset___354;

struct kobj_type___354;

struct kobject___355 {
	const char *name;
	struct list_head entry;
	struct kobject___355 *parent;
	struct kset___354 *kset;
	struct kobj_type___354 *ktype;
	struct kernfs_node___362 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___331 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___368 *, struct kobject___355 *, struct bin_attribute___331 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___368 *, struct kobject___355 *, struct bin_attribute___331 *, char *, loff_t, size_t);
	int (*mmap)(struct file___368 *, struct kobject___355 *, struct bin_attribute___331 *, struct vm_area_struct___369 *);
};

struct sysfs_ops___354 {
	ssize_t (*show)(struct kobject___355 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___355 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___354;

struct kset___354 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___355 kobj;
	const struct kset_uevent_ops___354 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___354 {
	void (*release)(struct kobject___355 *);
	const struct sysfs_ops___354 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___28 * (*child_ns_type)(struct kobject___355 *);
	const void * (*namespace)(struct kobject___355 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___354 {
	int (* const filter)(struct kset___354 *, struct kobject___355 *);
	const char * (* const name)(struct kset___354 *, struct kobject___355 *);
	int (* const uevent)(struct kset___354 *, struct kobject___355 *, struct kobj_uevent_env *);
};

struct kobj_attribute___346 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___355 *, struct kobj_attribute___346 *, char *);
	ssize_t (*store)(struct kobject___355 *, struct kobj_attribute___346 *, const char *, size_t);
};

struct kernel_param___296;

struct kernel_param_ops___296 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___296 *);
	int (*get)(char *, const struct kernel_param___296 *);
	void (*free)(void *);
};

struct kparam_array___296;

struct kernel_param___296 {
	const char *name;
	struct module___299 *mod;
	const struct kernel_param_ops___296 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___296 *arr;
	};
};

struct kparam_array___296 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___296 *ops;
	void *elem;
};

struct module_kobject___296 {
	struct kobject___355 kobj;
	struct module___299 *mod;
	struct kobject___355 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___296 {
	struct module___299 *mod;
	struct latch_tree_node node;
};

struct module_layout___296 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___296 mtn;
};

struct module_attribute___296;

struct module___299 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___296 mkobj;
	struct module_attribute___296 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___355 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___296 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___296 core_layout;
	struct module_layout___296 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___296 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___296 *, struct module_kobject___296 *, char *);
	ssize_t (*store)(struct module_attribute___296 *, struct module_kobject___296 *, const char *, size_t);
	void (*setup)(struct module___299 *, const char *);
	int (*test)(struct module___299 *);
	void (*free)(struct module___299 *);
};

struct device___335;

struct dev_pm_ops___335 {
	int (*prepare)(struct device___335 *);
	void (*complete)(struct device___335 *);
	int (*suspend)(struct device___335 *);
	int (*resume)(struct device___335 *);
	int (*freeze)(struct device___335 *);
	int (*thaw)(struct device___335 *);
	int (*poweroff)(struct device___335 *);
	int (*restore)(struct device___335 *);
	int (*suspend_late)(struct device___335 *);
	int (*resume_early)(struct device___335 *);
	int (*freeze_late)(struct device___335 *);
	int (*thaw_early)(struct device___335 *);
	int (*poweroff_late)(struct device___335 *);
	int (*restore_early)(struct device___335 *);
	int (*suspend_noirq)(struct device___335 *);
	int (*resume_noirq)(struct device___335 *);
	int (*freeze_noirq)(struct device___335 *);
	int (*thaw_noirq)(struct device___335 *);
	int (*poweroff_noirq)(struct device___335 *);
	int (*restore_noirq)(struct device___335 *);
	int (*runtime_suspend)(struct device___335 *);
	int (*runtime_resume)(struct device___335 *);
	int (*runtime_idle)(struct device___335 *);
};

struct dev_pm_info___335 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___5 *subsys_data;
	void (*set_latency_tolerance)(struct device___335 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___335;

struct bus_type___335;

struct device_driver___335;

struct dev_pm_domain___335;

struct dma_map_ops___123;

struct fwnode_handle___257;

struct class___335;

struct device___335 {
	struct device___335 *parent;
	struct device_private *p;
	struct kobject___355 kobj;
	const char *init_name;
	const struct device_type___335 *type;
	struct mutex mutex;
	struct bus_type___335 *bus;
	struct device_driver___335 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___335 power;
	struct dev_pm_domain___335 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___123 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___257 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___335 *class;
	const struct attribute_group___332 **groups;
	void (*release)(struct device___335 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___335 {
	struct dev_pm_ops___335 ops;
	void (*detach)(struct device___335 *, bool);
	int (*activate)(struct device___335 *);
	void (*sync)(struct device___335 *);
	void (*dismiss)(struct device___335 *);
};

struct user_struct___339 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___339 *uid_keyring;
	struct key___339 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___368;

struct mm_struct___368 {
	struct {
		struct vm_area_struct___369 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___368 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___369 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___368 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___369 *owner;
		struct user_namespace___3 *user_ns;
		struct file___368 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___368 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct bio___185;

struct bio_list___185 {
	struct bio___185 *head;
	struct bio___185 *tail;
};

struct bdi_writeback_congested___185;

struct bdi_writeback___185 {
	struct backing_dev_info___185 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___185 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___157 *memcg_css;
	struct cgroup_subsys_state___157 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___185 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___185 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___335 *dev;
	struct device___335 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___367 *debug_dir;
	struct dentry___367 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___105;

struct io_context___105 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___105 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

typedef blk_qc_t make_request_fn___101(struct request_queue___101 *, struct bio___185 *);

struct request___101;

typedef int dma_drain_needed_fn___101(struct request___101 *);

struct bsg_ops___101;

struct bsg_class_device___101 {
	struct device___335 *class_dev;
	int minor;
	struct request_queue___101 *queue;
	const struct bsg_ops___101 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___185 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___185 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___101;

struct blk_mq_ops___38;

struct blk_mq_hw_ctx___38;

struct blk_mq_tag_set___38;

struct request_queue___101 {
	struct list_head queue_head;
	struct request___101 *last_merge;
	struct elevator_queue___101 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___101 *make_request_fn;
	dma_drain_needed_fn___101 *dma_drain_needed;
	const struct blk_mq_ops___38 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___38 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___185 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___355 kobj;
	struct kobject___355 *mq_kobj;
	struct blk_integrity integrity;
	struct device___335 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	struct bsg_class_device___101 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set___38 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___185 bio_split;
	struct dentry___367 *debugfs_dir;
	struct dentry___367 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___274 {
	struct vm_struct___274 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___369 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bus_type___335 {
	const char *name;
	const char *dev_name;
	struct device___335 *dev_root;
	const struct attribute_group___332 **bus_groups;
	const struct attribute_group___332 **dev_groups;
	const struct attribute_group___332 **drv_groups;
	int (*match)(struct device___335 *, struct device_driver___335 *);
	int (*uevent)(struct device___335 *, struct kobj_uevent_env *);
	int (*probe)(struct device___335 *);
	int (*remove)(struct device___335 *);
	void (*shutdown)(struct device___335 *);
	int (*online)(struct device___335 *);
	int (*offline)(struct device___335 *);
	int (*suspend)(struct device___335 *, pm_message_t);
	int (*resume)(struct device___335 *);
	int (*num_vf)(struct device___335 *);
	int (*dma_configure)(struct device___335 *);
	const struct dev_pm_ops___335 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___335 {
	const char *name;
	struct bus_type___335 *bus;
	struct module___299 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___335 *);
	int (*remove)(struct device___335 *);
	void (*shutdown)(struct device___335 *);
	int (*suspend)(struct device___335 *, pm_message_t);
	int (*resume)(struct device___335 *);
	const struct attribute_group___332 **groups;
	const struct dev_pm_ops___335 *pm;
	void (*coredump)(struct device___335 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___335 {
	const char *name;
	const struct attribute_group___332 **groups;
	int (*uevent)(struct device___335 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___335 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___335 *);
	const struct dev_pm_ops___335 *pm;
};

struct class___335 {
	const char *name;
	struct module___299 *owner;
	const struct attribute_group___332 **class_groups;
	const struct attribute_group___332 **dev_groups;
	struct kobject___355 *dev_kobj;
	int (*dev_uevent)(struct device___335 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___335 *, umode_t *);
	void (*class_release)(struct class___335 *);
	void (*dev_release)(struct device___335 *);
	int (*shutdown_pre)(struct device___335 *);
	const struct kobj_ns_type_operations___28 *ns_type;
	const void * (*namespace)(struct device___335 *);
	const struct dev_pm_ops___335 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct device_attribute___47 {
	struct attribute attr;
	ssize_t (*show)(struct device___335 *, struct device_attribute___47 *, char *);
	ssize_t (*store)(struct device___335 *, struct device_attribute___47 *, const char *, size_t);
};

struct dma_map_ops___123 {
	void * (*alloc)(struct device___335 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___335 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___335 *, struct vm_area_struct___369 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___335 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___335 *, struct page___369 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___335 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___335 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___335 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___335 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___335 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___335 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___335 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___335 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___335 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___335 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___335 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___335 *, u64);
	u64 (*get_required_mask)(struct device___335 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___257;

struct fwnode_handle___257 {
	struct fwnode_handle___257 *secondary;
	const struct fwnode_operations___257 *ops;
};

struct fwnode_reference_args___257;

struct fwnode_endpoint___257;

struct fwnode_operations___257 {
	struct fwnode_handle___257 * (*get)(struct fwnode_handle___257 *);
	void (*put)(struct fwnode_handle___257 *);
	bool (*device_is_available)(const struct fwnode_handle___257 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___257 *, const struct device___335 *);
	bool (*property_present)(const struct fwnode_handle___257 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___257 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___257 *, const char *, const char **, size_t);
	struct fwnode_handle___257 * (*get_parent)(const struct fwnode_handle___257 *);
	struct fwnode_handle___257 * (*get_next_child_node)(const struct fwnode_handle___257 *, struct fwnode_handle___257 *);
	struct fwnode_handle___257 * (*get_named_child_node)(const struct fwnode_handle___257 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___257 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___257 *);
	struct fwnode_handle___257 * (*graph_get_next_endpoint)(const struct fwnode_handle___257 *, struct fwnode_handle___257 *);
	struct fwnode_handle___257 * (*graph_get_remote_endpoint)(const struct fwnode_handle___257 *);
	struct fwnode_handle___257 * (*graph_get_port_parent)(struct fwnode_handle___257 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___257 *, struct fwnode_endpoint___257 *);
};

struct fwnode_endpoint___257 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___257 *local_fwnode;
};

struct fwnode_reference_args___257 {
	struct fwnode_handle___257 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct dentry_operations___367;

struct super_block___367;

struct dentry___367 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___367 *d_parent;
	struct qstr d_name;
	struct inode___368 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___367 *d_op;
	struct super_block___367 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___367;

struct address_space___367 {
	struct inode___368 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___369 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___367 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___367;

struct block_device___367;

struct cdev___87;

struct inode___368 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___367 *i_op;
	struct super_block___367 *i_sb;
	struct address_space___367 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___369 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___185 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___368 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___367 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___367 *i_bdev;
		struct cdev___87 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___367 {
	int (*d_revalidate)(struct dentry___367 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___367 *, unsigned int);
	int (*d_hash)(const struct dentry___367 *, struct qstr *);
	int (*d_compare)(const struct dentry___367 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___367 *);
	int (*d_init)(struct dentry___367 *);
	void (*d_release)(struct dentry___367 *);
	void (*d_prune)(struct dentry___367 *);
	void (*d_iput)(struct dentry___367 *, struct inode___368 *);
	char * (*d_dname)(struct dentry___367 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___368 *);
	int (*d_manage)(const struct path___368 *, bool);
	struct dentry___367 * (*d_real)(struct dentry___367 *, const struct inode___368 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___367;

struct mem_dqinfo___367 {
	struct quota_format_type___367 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___367;

struct quota_info___367 {
	unsigned int flags;
	struct rw_semaphore___369 dqio_sem;
	struct inode___368 *files[3];
	struct mem_dqinfo___367 info[3];
	const struct quota_format_ops___367 *ops[3];
};

struct rcuwait___367 {
	struct task_struct___369 *task;
};

struct percpu_rw_semaphore___367 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___369 rw_sem;
	struct rcuwait___367 writer;
	int readers_block;
};

struct sb_writers___367 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___367 rw_sem[3];
};

struct file_system_type___367;

struct super_operations___367;

struct dquot_operations___367;

struct quotactl_ops___367;

struct super_block___367 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___367 *s_type;
	const struct super_operations___367 *s_op;
	const struct dquot_operations___367 *dq_op;
	const struct quotactl_ops___367 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___367 *s_root;
	struct rw_semaphore___369 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___367 *s_bdev;
	struct backing_dev_info___185 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___367 s_dquot;
	struct sb_writers___367 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___367 *s_d_op;
	int cleancache_poolid;
	struct shrinker___133 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

typedef int (*dev_page_fault_t___356)(struct vm_area_struct___369 *, long unsigned int, const struct page___369 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___356)(struct page___369 *, void *);

struct dev_pagemap___356 {
	dev_page_fault_t___356 page_fault;
	dev_page_free_t___356 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___335 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___368 {
	struct task_struct___369 *task;
	struct core_thread___368 *next;
};

struct core_state___368 {
	atomic_t nr_threads;
	struct core_thread___368 dumper;
	struct completion startup;
};

struct vm_fault___356 {
	struct vm_area_struct___369 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___369 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___369 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___368 prealloc_pte;
};

struct io_cq___105 {
	struct request_queue___101 *q;
	struct io_context___105 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___368 {
	struct file___368 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___368 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___367 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___368 *ia_file;
};

struct dquot___367 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___367 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___367 {
	int qf_fmt_id;
	const struct quota_format_ops___367 *qf_ops;
	struct module___299 *qf_owner;
	struct quota_format_type___367 *qf_next;
};

struct quota_format_ops___367 {
	int (*check_quota_file)(struct super_block___367 *, int);
	int (*read_file_info)(struct super_block___367 *, int);
	int (*write_file_info)(struct super_block___367 *, int);
	int (*free_file_info)(struct super_block___367 *, int);
	int (*read_dqblk)(struct dquot___367 *);
	int (*commit_dqblk)(struct dquot___367 *);
	int (*release_dqblk)(struct dquot___367 *);
	int (*get_next_id)(struct super_block___367 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___367 {
	int (*write_dquot)(struct dquot___367 *);
	struct dquot___367 * (*alloc_dquot)(struct super_block___367 *, int);
	void (*destroy_dquot)(struct dquot___367 *);
	int (*acquire_dquot)(struct dquot___367 *);
	int (*release_dquot)(struct dquot___367 *);
	int (*mark_dirty)(struct dquot___367 *);
	int (*write_info)(struct super_block___367 *, int);
	qsize_t * (*get_reserved_space)(struct inode___368 *);
	int (*get_projid)(struct inode___368 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___368 *, qsize_t *);
	int (*get_next_id)(struct super_block___367 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___367 {
	int (*quota_on)(struct super_block___367 *, int, int, const struct path___368 *);
	int (*quota_off)(struct super_block___367 *, int);
	int (*quota_enable)(struct super_block___367 *, unsigned int);
	int (*quota_disable)(struct super_block___367 *, unsigned int);
	int (*quota_sync)(struct super_block___367 *, int);
	int (*set_info)(struct super_block___367 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___367 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___367 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___367 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___367 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___367 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___367 {
	int (*writepage)(struct page___369 *, struct writeback_control___3 *);
	int (*readpage)(struct file___368 *, struct page___369 *);
	int (*writepages)(struct address_space___367 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___369 *);
	int (*readpages)(struct file___368 *, struct address_space___367 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___368 *, struct address_space___367 *, loff_t, unsigned int, unsigned int, struct page___369 **, void **);
	int (*write_end)(struct file___368 *, struct address_space___367 *, loff_t, unsigned int, unsigned int, struct page___369 *, void *);
	sector_t (*bmap)(struct address_space___367 *, sector_t);
	void (*invalidatepage)(struct page___369 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___369 *, gfp_t);
	void (*freepage)(struct page___369 *);
	ssize_t (*direct_IO)(struct kiocb___368 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___367 *, struct page___369 *, struct page___369 *, enum migrate_mode);
	bool (*isolate_page)(struct page___369 *, isolate_mode_t);
	void (*putback_page)(struct page___369 *);
	int (*launder_page)(struct page___369 *);
	int (*is_partially_uptodate)(struct page___369 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___369 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___367 *, struct page___369 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___368 *, sector_t *);
	void (*swap_deactivate)(struct file___368 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct hd_struct___105;

struct gendisk___105;

struct block_device___367 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___368 *bd_inode;
	struct super_block___367 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___367 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___105 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___105 *bd_disk;
	struct request_queue___101 *bd_queue;
	struct backing_dev_info___185 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct hd_struct___105 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___335 __dev;
	struct kobject___355 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___105;

struct block_device_operations___102;

struct gendisk___105 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___105 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___105 *part_tbl;
	struct hd_struct___105 part0;
	const struct block_device_operations___102 *fops;
	struct request_queue___101 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___369 lookup_sem;
	struct kobject___355 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___355 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___87 {
	struct kobject___355 kobj;
	struct module___299 *owner;
	const struct file_operations___368 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___367 {
	struct dentry___367 * (*lookup)(struct inode___368 *, struct dentry___367 *, unsigned int);
	const char * (*get_link)(struct dentry___367 *, struct inode___368 *, struct delayed_call *);
	int (*permission)(struct inode___368 *, int);
	struct posix_acl * (*get_acl)(struct inode___368 *, int);
	int (*readlink)(struct dentry___367 *, char *, int);
	int (*create)(struct inode___368 *, struct dentry___367 *, umode_t, bool);
	int (*link)(struct dentry___367 *, struct inode___368 *, struct dentry___367 *);
	int (*unlink)(struct inode___368 *, struct dentry___367 *);
	int (*symlink)(struct inode___368 *, struct dentry___367 *, const char *);
	int (*mkdir)(struct inode___368 *, struct dentry___367 *, umode_t);
	int (*rmdir)(struct inode___368 *, struct dentry___367 *);
	int (*mknod)(struct inode___368 *, struct dentry___367 *, umode_t, dev_t);
	int (*rename)(struct inode___368 *, struct dentry___367 *, struct inode___368 *, struct dentry___367 *, unsigned int);
	int (*setattr)(struct dentry___367 *, struct iattr___367 *);
	int (*getattr)(const struct path___368 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___367 *, char *, size_t);
	int (*fiemap)(struct inode___368 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___368 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___368 *, struct dentry___367 *, struct file___368 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___368 *, struct dentry___367 *, umode_t);
	int (*set_acl)(struct inode___368 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___367 {
	void (*fl_copy_lock)(struct file_lock___368 *, struct file_lock___368 *);
	void (*fl_release_private)(struct file_lock___368 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___367;

struct lock_manager_operations___367;

struct file_lock___368 {
	struct file_lock___368 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___368 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___367 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___367 *fl_ops;
	const struct lock_manager_operations___367 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___367 {
	int (*lm_compare_owner)(struct file_lock___368 *, struct file_lock___368 *);
	long unsigned int (*lm_owner_key)(struct file_lock___368 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___368 *);
	int (*lm_grant)(struct file_lock___368 *, int);
	bool (*lm_break)(struct file_lock___368 *);
	int (*lm_change)(struct file_lock___368 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___368 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___367 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___367 *fa_next;
	struct file___368 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___367 {
	const char *name;
	int fs_flags;
	struct dentry___367 * (*mount)(struct file_system_type___367 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___367 *);
	struct module___299 *owner;
	struct file_system_type___367 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___367 {
	struct inode___368 * (*alloc_inode)(struct super_block___367 *);
	void (*destroy_inode)(struct inode___368 *);
	void (*dirty_inode)(struct inode___368 *, int);
	int (*write_inode)(struct inode___368 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___368 *);
	void (*evict_inode)(struct inode___368 *);
	void (*put_super)(struct super_block___367 *);
	int (*sync_fs)(struct super_block___367 *, int);
	int (*freeze_super)(struct super_block___367 *);
	int (*freeze_fs)(struct super_block___367 *);
	int (*thaw_super)(struct super_block___367 *);
	int (*unfreeze_fs)(struct super_block___367 *);
	int (*statfs)(struct dentry___367 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___367 *, int *, char *);
	void (*umount_begin)(struct super_block___367 *);
	int (*show_options)(struct seq_file___312 *, struct dentry___367 *);
	int (*show_devname)(struct seq_file___312 *, struct dentry___367 *);
	int (*show_path)(struct seq_file___312 *, struct dentry___367 *);
	int (*show_stats)(struct seq_file___312 *, struct dentry___367 *);
	ssize_t (*quota_read)(struct super_block___367 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___367 *, int, const char *, size_t, loff_t);
	struct dquot___367 ** (*get_dquots)(struct inode___368 *);
	int (*bdev_try_to_free_page)(struct super_block___367 *, struct page___369 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___367 *, struct shrink_control___133 *);
	long int (*free_cached_objects)(struct super_block___367 *, struct shrink_control___133 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___185(struct bio___185 *);

struct bio_vec___187 {
	struct page___369 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___185;

struct bio___185 {
	struct bio___185 *bi_next;
	struct gendisk___105 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___185 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___185 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___187 *bi_io_vec;
	struct bio_set___185 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___187 bi_inline_vecs[0];
};

struct acpi_device___16;

struct acpi_hotplug_profile___16 {
	struct kobject___355 kobj;
	int (*scan_dependent)(struct acpi_device___16 *);
	void (*notify_online)(struct acpi_device___16 *);
	bool enabled: 1;
	bool demand_offline: 1;
};

struct acpi_device_wakeup_context___16 {
	void (*func)(struct acpi_device_wakeup_context___16 *);
	struct device___335 *dev;
};

struct acpi_device_wakeup___16 {
	acpi_handle gpe_device;
	u64 gpe_number;
	u64 sleep_state;
	struct list_head resources;
	struct acpi_device_wakeup_flags flags;
	struct acpi_device_wakeup_context___16 context;
	struct wakeup_source___8 *ws;
	int prepare_count;
	int enable_count;
};

struct acpi_scan_handler___16;

struct acpi_hotplug_context___16;

struct acpi_driver___16;

struct acpi_device___16 {
	int device_type;
	acpi_handle handle;
	struct fwnode_handle___257 fwnode;
	struct acpi_device___16 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup___16 wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_device_data data;
	struct acpi_scan_handler___16 *handler;
	struct acpi_hotplug_context___16 *hp;
	struct acpi_driver___16 *driver;
	const struct acpi_gpio_mapping *driver_gpios;
	void *driver_data;
	struct device___335 dev;
	unsigned int physical_node_count;
	unsigned int dep_unmet;
	struct list_head physical_node_list;
	struct mutex physical_node_lock;
	void (*remove)(struct acpi_device___16 *);
};

struct acpi_scan_handler___16 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	bool (*match)(const char *, const struct acpi_device_id **);
	int (*attach)(struct acpi_device___16 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___16 *);
	void (*bind)(struct device___335 *);
	void (*unbind)(struct device___335 *);
	struct acpi_hotplug_profile___16 hotplug;
};

struct acpi_hotplug_context___16 {
	struct acpi_device___16 *self;
	int (*notify)(struct acpi_device___16 *, u32);
	void (*uevent)(struct acpi_device___16 *, u32);
	void (*fixup)(struct acpi_device___16 *);
};

typedef int (*acpi_op_add___16)(struct acpi_device___16 *);

typedef int (*acpi_op_remove___16)(struct acpi_device___16 *);

typedef void (*acpi_op_notify___16)(struct acpi_device___16 *, u32);

struct acpi_device_ops___16 {
	acpi_op_add___16 add;
	acpi_op_remove___16 remove;
	acpi_op_notify___16 notify;
};

struct acpi_driver___16 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___16 ops;
	struct device_driver___335 drv;
	struct module___299 *owner;
};

typedef int (*key_restrict_link_func_t___340)(struct key___339 *, const struct key_type *, const union key_payload *, struct key___339 *);

struct key_restriction___339;

struct key___339 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___369 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___339 *restrict_link;
};

struct key_restriction___339 {
	key_restrict_link_func_t___340 check;
	struct key___339 *key;
	struct key_type *keytype;
};

struct seq_operations___311 {
	void * (*start)(struct seq_file___312 *, loff_t *);
	void (*stop)(struct seq_file___312 *, void *);
	void * (*next)(struct seq_file___312 *, void *, loff_t *);
	int (*show)(struct seq_file___312 *, void *);
};

typedef void compound_page_dtor___356(struct page___369 *);

struct bio_integrity_payload___185 {
	struct bio___185 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___187 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___187 bip_inline_vecs[0];
};

struct disk_part_tbl___105 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___105 *last_lookup;
	struct hd_struct___105 *part[0];
};

struct block_device_operations___102 {
	int (*open)(struct block_device___367 *, fmode_t);
	void (*release)(struct gendisk___105 *, fmode_t);
	int (*rw_page)(struct block_device___367 *, sector_t, struct page___369 *, unsigned int);
	int (*ioctl)(struct block_device___367 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___367 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___105 *, unsigned int);
	int (*media_changed)(struct gendisk___105 *);
	void (*unlock_native_capacity)(struct gendisk___105 *);
	int (*revalidate_disk)(struct gendisk___105 *);
	int (*getgeo)(struct block_device___367 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___367 *, long unsigned int);
	int (*report_zones)(struct gendisk___105 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___299 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bdi_writeback_congested___185 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___185 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bsg_ops___101 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___101 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___101 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___101 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___101(struct request___101 *, blk_status_t);

struct request___101 {
	struct request_queue___101 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___38 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___185 *bio;
	struct bio___185 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___187 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___105 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___101 *saved_end_io;
		} flush;
	};
	struct gendisk___105 *rq_disk;
	struct hd_struct___105 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___101 *end_io;
	void *end_io_data;
	struct request___101 *next_rq;
};

struct blk_mq_hw_ctx___38 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___101 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags___4 *tags;
	struct blk_mq_tags___4 *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	unsigned int rh_reserved_nr_expired;
	struct hlist_node cpuhp_dead;
	struct kobject___355 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___367 *debugfs_dir;
	struct dentry___367 *sched_debugfs_dir;
	struct list_head hctx_list;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___101;

struct elevator_mq_ops___101 {
	int (*init_sched)(struct request_queue___101 *, struct elevator_type___101 *);
	void (*exit_sched)(struct elevator_queue___101 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___38 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___38 *, unsigned int);
	bool (*allow_merge)(struct request_queue___101 *, struct request___101 *, struct bio___185 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx___38 *, struct bio___185 *);
	int (*request_merge)(struct request_queue___101 *, struct request___101 **, struct bio___185 *);
	void (*request_merged)(struct request_queue___101 *, struct request___101 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___101 *, struct request___101 *, struct request___101 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___101 *, struct bio___185 *);
	void (*finish_request)(struct request___101 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___38 *, struct list_head *, bool);
	struct request___101 * (*dispatch_request)(struct blk_mq_hw_ctx___38 *);
	bool (*has_work)(struct blk_mq_hw_ctx___38 *);
	void (*completed_request)(struct request___101 *, u64);
	void (*started_request)(struct request___101 *);
	void (*requeue_request)(struct request___101 *);
	struct request___101 * (*former_request)(struct request_queue___101 *, struct request___101 *);
	struct request___101 * (*next_request)(struct request_queue___101 *, struct request___101 *);
	void (*init_icq)(struct io_cq___105 *);
	void (*exit_icq)(struct io_cq___105 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx___38 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___101;

struct elevator_type___101 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___101 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___101 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___299 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___101 {
	struct elevator_type___101 *type;
	void *elevator_data;
	struct kobject___355 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___101 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___101 *, char *);
	ssize_t (*store)(struct elevator_queue___101 *, const char *, size_t);
};

struct blk_mq_queue_data___38;

typedef blk_status_t queue_rq_fn___38(struct blk_mq_hw_ctx___38 *, const struct blk_mq_queue_data___38 *);

typedef void commit_rqs_fn___38(struct blk_mq_hw_ctx___38 *);

typedef bool get_budget_fn___38(struct blk_mq_hw_ctx___38 *);

typedef void put_budget_fn___38(struct blk_mq_hw_ctx___38 *);

typedef enum blk_eh_timer_return timeout_fn___38(struct request___101 *, bool);

typedef int poll_fn___38(struct blk_mq_hw_ctx___38 *);

typedef void complete_fn___38(struct request___101 *);

typedef int init_hctx_fn___38(struct blk_mq_hw_ctx___38 *, void *, unsigned int);

typedef void exit_hctx_fn___38(struct blk_mq_hw_ctx___38 *, unsigned int);

typedef int init_request_fn___38(struct blk_mq_tag_set___38 *, struct request___101 *, unsigned int, unsigned int);

typedef void exit_request_fn___38(struct blk_mq_tag_set___38 *, struct request___101 *, unsigned int);

typedef bool busy_fn___38(struct request_queue___101 *);

typedef int map_queues_fn___38(struct blk_mq_tag_set___38 *);

typedef void cleanup_rq_fn___38(struct request___101 *);

struct blk_mq_ops___38 {
	queue_rq_fn___38 *queue_rq;
	commit_rqs_fn___38 *commit_rqs;
	get_budget_fn___38 *get_budget;
	put_budget_fn___38 *put_budget;
	timeout_fn___38 *timeout;
	poll_fn___38 *poll;
	complete_fn___38 *complete;
	init_hctx_fn___38 *init_hctx;
	exit_hctx_fn___38 *exit_hctx;
	init_request_fn___38 *init_request;
	exit_request_fn___38 *exit_request;
	void (*initialize_rq_fn)(struct request___101 *);
	busy_fn___38 *busy;
	map_queues_fn___38 *map_queues;
	void (*show_rq)(struct seq_file___312 *, struct request___101 *);
	union {
		cleanup_rq_fn___38 *cleanup_rq;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide47;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct blk_mq_tag_set___38 {
	struct blk_mq_queue_map map[6];
	unsigned int nr_maps;
	const struct blk_mq_ops___38 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	struct blk_mq_tags___4 **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct blk_mq_queue_data___38 {
	struct request___101 *rq;
	bool last;
	long unsigned int rh_reserved1;
};

struct Scsi_Host___14;

struct scsi_device___17;

struct scsi_target___17;

struct scsi_host_template___14 {
	struct module___299 *module;
	const char *name;
	const char * (*info)(struct Scsi_Host___14 *);
	int (*ioctl)(struct scsi_device___17 *, int, void *);
	int (*queuecommand)(struct Scsi_Host___14 *, struct scsi_cmnd___2 *);
	int (*eh_abort_handler)(struct scsi_cmnd___2 *);
	int (*eh_device_reset_handler)(struct scsi_cmnd___2 *);
	int (*eh_target_reset_handler)(struct scsi_cmnd___2 *);
	int (*eh_bus_reset_handler)(struct scsi_cmnd___2 *);
	int (*eh_host_reset_handler)(struct scsi_cmnd___2 *);
	int (*slave_alloc)(struct scsi_device___17 *);
	int (*slave_configure)(struct scsi_device___17 *);
	void (*slave_destroy)(struct scsi_device___17 *);
	int (*target_alloc)(struct scsi_target___17 *);
	void (*target_destroy)(struct scsi_target___17 *);
	int (*scan_finished)(struct Scsi_Host___14 *, long unsigned int);
	void (*scan_start)(struct Scsi_Host___14 *);
	int (*change_queue_depth)(struct scsi_device___17 *, int);
	int (*map_queues)(struct Scsi_Host___14 *);
	int (*bios_param)(struct scsi_device___17 *, struct block_device___367 *, sector_t, int *);
	void (*unlock_native_capacity)(struct scsi_device___17 *);
	int (*show_info)(struct seq_file___312 *, struct Scsi_Host___14 *);
	int (*write_info)(struct Scsi_Host___14 *, char *, int);
	enum blk_eh_timer_return (*eh_timed_out)(struct scsi_cmnd___2 *);
	int (*host_reset)(struct Scsi_Host___14 *, int);
	const char *proc_name;
	struct proc_dir_entry *proc_dir;
	int can_queue;
	int this_id;
	short unsigned int sg_tablesize;
	short unsigned int sg_prot_tablesize;
	unsigned int max_sectors;
	long unsigned int dma_boundary;
	short int cmd_per_lun;
	unsigned char present;
	int tag_alloc_policy;
	unsigned int track_queue_depth: 1;
	unsigned int supported_mode: 2;
	unsigned int unchecked_isa_dma: 1;
	unsigned int use_clustering: 1;
	unsigned int emulated: 1;
	unsigned int skip_settle_delay: 1;
	unsigned int no_write_same: 1;
	unsigned int force_blk_mq: 1;
	unsigned int max_host_blocked;
	struct device_attribute___47 **shost_attrs;
	struct device_attribute___47 **sdev_attrs;
	const struct attribute_group___332 **sdev_groups;
	u64 vendor_id;
	unsigned int cmd_size;
	struct scsi_host_cmd_pool *cmd_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct Scsi_Host___14 {
	struct list_head __devices;
	struct list_head __targets;
	struct list_head starved_list;
	spinlock_t default_lock;
	spinlock_t *host_lock;
	struct mutex scan_mutex;
	struct list_head eh_cmd_q;
	struct task_struct___369 *ehandler;
	struct completion *eh_action;
	wait_queue_head_t host_wait;
	struct scsi_host_template___14 *hostt;
	struct scsi_transport_template *transportt;
	struct blk_mq_tag_set___38 tag_set;
	atomic_t host_busy;
	atomic_t host_blocked;
	unsigned int host_failed;
	unsigned int host_eh_scheduled;
	unsigned int host_no;
	int eh_deadline;
	long unsigned int last_reset;
	unsigned int max_channel;
	unsigned int max_id;
	u64 max_lun;
	unsigned int unique_id;
	short unsigned int max_cmd_len;
	int this_id;
	int can_queue;
	short int cmd_per_lun;
	short unsigned int sg_tablesize;
	short unsigned int sg_prot_tablesize;
	unsigned int max_sectors;
	long unsigned int dma_boundary;
	unsigned int nr_hw_queues;
	long unsigned int cmd_serial_number;
	unsigned int active_mode: 2;
	unsigned int unchecked_isa_dma: 1;
	unsigned int use_clustering: 1;
	unsigned int host_self_blocked: 1;
	unsigned int reverse_ordering: 1;
	unsigned int tmf_in_progress: 1;
	unsigned int async_scan: 1;
	unsigned int eh_noresume: 1;
	unsigned int no_write_same: 1;
	unsigned int use_cmd_list: 1;
	unsigned int short_inquiry: 1;
	char work_q_name[20];
	struct workqueue_struct *work_q;
	struct workqueue_struct *tmf_work_q;
	unsigned int no_scsi2_lun_in_cdb: 1;
	unsigned int max_host_blocked;
	unsigned int prot_capabilities;
	unsigned char prot_guard_type;
	long unsigned int base;
	long unsigned int io_port;
	unsigned char n_io_port;
	unsigned char dma_channel;
	unsigned int irq;
	enum scsi_host_state shost_state;
	struct device___335 shost_gendev;
	struct device___335 shost_dev;
	void *shost_data;
	struct device___335 *dma_dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int hostdata[0];
};

struct scsi_device___17 {
	struct Scsi_Host___14 *host;
	struct request_queue___101 *request_queue;
	struct list_head siblings;
	struct list_head same_target_siblings;
	atomic_t device_busy;
	atomic_t device_blocked;
	spinlock_t list_lock;
	struct list_head cmd_list;
	struct list_head starved_entry;
	short unsigned int queue_depth;
	short unsigned int max_queue_depth;
	short unsigned int last_queue_full_depth;
	short unsigned int last_queue_full_count;
	long unsigned int last_queue_full_time;
	long unsigned int queue_ramp_up_period;
	long unsigned int last_queue_ramp_up;
	unsigned int id;
	unsigned int channel;
	u64 lun;
	unsigned int manufacturer;
	unsigned int sector_size;
	void *hostdata;
	unsigned char type;
	char scsi_level;
	char inq_periph_qual;
	struct mutex inquiry_mutex;
	unsigned char inquiry_len;
	unsigned char *inquiry;
	const char *vendor;
	const char *model;
	const char *rev;
	struct scsi_vpd *vpd_pg83;
	struct scsi_vpd *vpd_pg80;
	unsigned char current_tag;
	struct scsi_target___17 *sdev_target;
	blist_flags_t sdev_bflags;
	unsigned int eh_timeout;
	unsigned int removable: 1;
	unsigned int changed: 1;
	unsigned int busy: 1;
	unsigned int lockable: 1;
	unsigned int locked: 1;
	unsigned int borken: 1;
	unsigned int disconnect: 1;
	unsigned int soft_reset: 1;
	unsigned int sdtr: 1;
	unsigned int wdtr: 1;
	unsigned int ppr: 1;
	unsigned int tagged_supported: 1;
	unsigned int simple_tags: 1;
	unsigned int was_reset: 1;
	unsigned int expecting_cc_ua: 1;
	unsigned int use_10_for_rw: 1;
	unsigned int use_10_for_ms: 1;
	unsigned int no_report_opcodes: 1;
	unsigned int no_write_same: 1;
	unsigned int use_16_for_rw: 1;
	unsigned int skip_ms_page_8: 1;
	unsigned int skip_ms_page_3f: 1;
	unsigned int skip_vpd_pages: 1;
	unsigned int try_vpd_pages: 1;
	unsigned int use_192_bytes_for_3f: 1;
	unsigned int no_start_on_add: 1;
	unsigned int allow_restart: 1;
	unsigned int manage_start_stop: 1;
	unsigned int start_stop_pwr_cond: 1;
	unsigned int no_uld_attach: 1;
	unsigned int select_no_atn: 1;
	unsigned int fix_capacity: 1;
	unsigned int guess_capacity: 1;
	unsigned int retry_hwerror: 1;
	unsigned int last_sector_bug: 1;
	unsigned int no_read_disc_info: 1;
	unsigned int no_read_capacity_16: 1;
	unsigned int try_rc_10_first: 1;
	unsigned int security_supported: 1;
	unsigned int is_visible: 1;
	unsigned int wce_default_on: 1;
	unsigned int no_dif: 1;
	unsigned int broken_fua: 1;
	unsigned int lun_in_cdb: 1;
	unsigned int unmap_limit_for_ws: 1;
	atomic_t disk_events_disable_depth;
	long unsigned int supported_events[1];
	long unsigned int pending_events[1];
	struct list_head event_list;
	struct work_struct event_work;
	unsigned int max_device_blocked;
	atomic_t iorequest_cnt;
	atomic_t iodone_cnt;
	atomic_t ioerr_cnt;
	struct device___335 sdev_gendev;
	struct device___335 sdev_dev;
	struct execute_work ew;
	struct work_struct requeue_work;
	struct scsi_device_handler *handler;
	void *handler_data;
	unsigned char access_state;
	struct mutex state_mutex;
	enum scsi_device_state sdev_state;
	struct task_struct___369 *quiesced_by;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int sdev_data[0];
};

struct scsi_target___17 {
	struct scsi_device___17 *starget_sdev_user;
	struct list_head siblings;
	struct list_head devices;
	struct device___335 dev;
	struct kref reap_ref;
	unsigned int channel;
	unsigned int id;
	unsigned int create: 1;
	unsigned int single_lun: 1;
	unsigned int pdt_1f_for_no_lun: 1;
	unsigned int no_report_luns: 1;
	unsigned int expecting_lun_change: 1;
	atomic_t target_busy;
	atomic_t target_blocked;
	unsigned int can_queue;
	unsigned int max_target_blocked;
	char scsi_level;
	enum scsi_target_state state;
	void *hostdata;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int starget_data[0];
};

struct ata_queued_cmd___7;

typedef void (*ata_qc_cb_t___7)(struct ata_queued_cmd___7 *);

struct ata_port___7;

struct ata_device___7;

struct ata_queued_cmd___7 {
	struct ata_port___7 *ap;
	struct ata_device___7 *dev;
	struct scsi_cmnd___2 *scsicmd;
	void (*scsidone)(struct scsi_cmnd___2 *);
	struct ata_taskfile tf;
	u8 cdb[16];
	long unsigned int flags;
	unsigned int tag;
	unsigned int hw_tag;
	unsigned int n_elem;
	unsigned int orig_n_elem;
	int dma_dir;
	unsigned int sect_size;
	unsigned int nbytes;
	unsigned int extrabytes;
	unsigned int curbytes;
	struct scatterlist sgent;
	struct scatterlist *sg;
	struct scatterlist *cursg;
	unsigned int cursg_ofs;
	unsigned int err_mask;
	struct ata_taskfile result_tf;
	ata_qc_cb_t___7 complete_fn;
	void *private_data;
	void *lldd_task;
};

struct ata_link___7;

typedef int (*ata_prereset_fn_t___7)(struct ata_link___7 *, long unsigned int);

struct ata_eh_info___7 {
	struct ata_device___7 *dev;
	u32 serror;
	unsigned int err_mask;
	unsigned int action;
	unsigned int dev_action[2];
	unsigned int flags;
	unsigned int probe_mask;
	char desc[80];
	int desc_len;
};

struct ata_eh_context___7 {
	struct ata_eh_info___7 i;
	int tries[2];
	int cmd_timeout_idx[12];
	unsigned int classes[2];
	unsigned int did_probe_mask;
	unsigned int unloaded_mask;
	unsigned int saved_ncq_enabled;
	u8 saved_xfer_mode[2];
	long unsigned int last_reset;
};

struct ata_device___7 {
	struct ata_link___7 *link;
	unsigned int devno;
	unsigned int horkage;
	long unsigned int flags;
	struct scsi_device___17 *sdev;
	void *private_data;
	union acpi_object *gtf_cache;
	unsigned int gtf_filter;
	struct device___335 tdev;
	u64 n_sectors;
	u64 n_native_sectors;
	unsigned int class;
	long unsigned int unpark_deadline;
	u8 pio_mode;
	u8 dma_mode;
	u8 xfer_mode;
	unsigned int xfer_shift;
	unsigned int multi_count;
	unsigned int max_sectors;
	unsigned int cdb_len;
	long unsigned int pio_mask;
	long unsigned int mwdma_mask;
	long unsigned int udma_mask;
	u16 cylinders;
	u16 heads;
	u16 sectors;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	union {
		u16 id[256];
		u32 gscr[128];
	};
	u8 devslp_timing[8];
	u8 ncq_send_recv_cmds[20];
	u8 ncq_non_data_cmds[64];
	u32 zac_zoned_cap;
	u32 zac_zones_optimal_open;
	u32 zac_zones_optimal_nonseq;
	u32 zac_zones_max_open;
	int spdn_cnt;
	struct ata_ering ering;
	long: 64;
};

struct ata_link___7 {
	struct ata_port___7 *ap;
	int pmp;
	struct device___335 tdev;
	unsigned int active_tag;
	u32 sactive;
	unsigned int flags;
	u32 saved_scontrol;
	unsigned int hw_sata_spd_limit;
	unsigned int sata_spd_limit;
	unsigned int sata_spd;
	enum ata_lpm_policy lpm_policy;
	struct ata_eh_info___7 eh_info;
	struct ata_eh_context___7 eh_context;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ata_device___7 device[2];
	long unsigned int last_lpm_change;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef int (*ata_reset_fn_t___7)(struct ata_link___7 *, unsigned int *, long unsigned int);

typedef void (*ata_postreset_fn_t___7)(struct ata_link___7 *, unsigned int *);

struct ata_port_operations___7;

struct ata_host___7 {
	spinlock_t lock;
	struct device___335 *dev;
	void * const *iomap;
	unsigned int n_ports;
	unsigned int n_tags;
	void *private_data;
	struct ata_port_operations___7 *ops;
	long unsigned int flags;
	struct kref kref;
	struct mutex eh_mutex;
	struct task_struct___369 *eh_owner;
	struct ata_port___7 *simplex_claimed;
	struct ata_port___7 *ports[0];
};

struct ata_port_operations___7 {
	int (*qc_defer)(struct ata_queued_cmd___7 *);
	int (*check_atapi_dma)(struct ata_queued_cmd___7 *);
	void (*qc_prep)(struct ata_queued_cmd___7 *);
	unsigned int (*qc_issue)(struct ata_queued_cmd___7 *);
	bool (*qc_fill_rtf)(struct ata_queued_cmd___7 *);
	int (*cable_detect)(struct ata_port___7 *);
	long unsigned int (*mode_filter)(struct ata_device___7 *, long unsigned int);
	void (*set_piomode)(struct ata_port___7 *, struct ata_device___7 *);
	void (*set_dmamode)(struct ata_port___7 *, struct ata_device___7 *);
	int (*set_mode)(struct ata_link___7 *, struct ata_device___7 **);
	unsigned int (*read_id)(struct ata_device___7 *, struct ata_taskfile *, u16 *);
	void (*dev_config)(struct ata_device___7 *);
	void (*freeze)(struct ata_port___7 *);
	void (*thaw)(struct ata_port___7 *);
	ata_prereset_fn_t___7 prereset;
	ata_reset_fn_t___7 softreset;
	ata_reset_fn_t___7 hardreset;
	ata_postreset_fn_t___7 postreset;
	ata_prereset_fn_t___7 pmp_prereset;
	ata_reset_fn_t___7 pmp_softreset;
	ata_reset_fn_t___7 pmp_hardreset;
	ata_postreset_fn_t___7 pmp_postreset;
	void (*error_handler)(struct ata_port___7 *);
	void (*lost_interrupt)(struct ata_port___7 *);
	void (*post_internal_cmd)(struct ata_queued_cmd___7 *);
	void (*sched_eh)(struct ata_port___7 *);
	void (*end_eh)(struct ata_port___7 *);
	int (*scr_read)(struct ata_link___7 *, unsigned int, u32 *);
	int (*scr_write)(struct ata_link___7 *, unsigned int, u32);
	void (*pmp_attach)(struct ata_port___7 *);
	void (*pmp_detach)(struct ata_port___7 *);
	int (*set_lpm)(struct ata_link___7 *, enum ata_lpm_policy, unsigned int);
	int (*port_suspend)(struct ata_port___7 *, pm_message_t);
	int (*port_resume)(struct ata_port___7 *);
	int (*port_start)(struct ata_port___7 *);
	void (*port_stop)(struct ata_port___7 *);
	void (*host_stop)(struct ata_host___7 *);
	void (*sff_dev_select)(struct ata_port___7 *, unsigned int);
	void (*sff_set_devctl)(struct ata_port___7 *, u8);
	u8 (*sff_check_status)(struct ata_port___7 *);
	u8 (*sff_check_altstatus)(struct ata_port___7 *);
	void (*sff_tf_load)(struct ata_port___7 *, const struct ata_taskfile *);
	void (*sff_tf_read)(struct ata_port___7 *, struct ata_taskfile *);
	void (*sff_exec_command)(struct ata_port___7 *, const struct ata_taskfile *);
	unsigned int (*sff_data_xfer)(struct ata_queued_cmd___7 *, unsigned char *, unsigned int, int);
	void (*sff_irq_on)(struct ata_port___7 *);
	bool (*sff_irq_check)(struct ata_port___7 *);
	void (*sff_irq_clear)(struct ata_port___7 *);
	void (*sff_drain_fifo)(struct ata_queued_cmd___7 *);
	void (*bmdma_setup)(struct ata_queued_cmd___7 *);
	void (*bmdma_start)(struct ata_queued_cmd___7 *);
	void (*bmdma_stop)(struct ata_queued_cmd___7 *);
	u8 (*bmdma_status)(struct ata_port___7 *);
	ssize_t (*em_show)(struct ata_port___7 *, char *);
	ssize_t (*em_store)(struct ata_port___7 *, const char *, size_t);
	ssize_t (*sw_activity_show)(struct ata_device___7 *, char *);
	ssize_t (*sw_activity_store)(struct ata_device___7 *, enum sw_activity);
	ssize_t (*transmit_led_message)(struct ata_port___7 *, u32, ssize_t);
	void (*phy_reset)(struct ata_port___7 *);
	void (*eng_timeout)(struct ata_port___7 *);
	const struct ata_port_operations___7 *inherits;
};

struct ata_port___7 {
	struct Scsi_Host___14 *scsi_host;
	struct ata_port_operations___7 *ops;
	spinlock_t *lock;
	long unsigned int flags;
	unsigned int pflags;
	unsigned int print_id;
	unsigned int local_port_no;
	unsigned int port_no;
	struct ata_ioports ioaddr;
	u8 ctl;
	u8 last_ctl;
	struct ata_link___7 *sff_pio_task_link;
	struct delayed_work sff_pio_task;
	struct ata_bmdma_prd *bmdma_prd;
	dma_addr_t bmdma_prd_dma;
	unsigned int pio_mask;
	unsigned int mwdma_mask;
	unsigned int udma_mask;
	unsigned int cbl;
	struct ata_queued_cmd___7 qcmd[33];
	long unsigned int sas_tag_allocated;
	u64 qc_active;
	int nr_active_links;
	unsigned int sas_last_tag;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ata_link___7 link;
	struct ata_link___7 *slave_link;
	int nr_pmp_links;
	struct ata_link___7 *pmp_link;
	struct ata_link___7 *excl_link;
	struct ata_port_stats stats;
	struct ata_host___7 *host;
	struct device___335 *dev;
	struct device___335 tdev;
	struct mutex scsi_scan_mutex;
	struct delayed_work hotplug_task;
	struct work_struct scsi_rescan_task;
	unsigned int hsm_task_state;
	u32 msg_enable;
	struct list_head eh_done_q;
	wait_queue_head_t eh_wait_q;
	int eh_tries;
	struct completion park_req_pending;
	pm_message_t pm_mesg;
	enum ata_lpm_policy target_lpm_policy;
	struct timer_list fastdrain_timer;
	long unsigned int fastdrain_cnt;
	int em_message_type;
	void *private_data;
	struct ata_acpi_gtm __acpi_init_gtm;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sector_buf[512];
};

struct ata_port_info___7 {
	long unsigned int flags;
	long unsigned int link_flags;
	long unsigned int pio_mask;
	long unsigned int mwdma_mask;
	long unsigned int udma_mask;
	struct ata_port_operations___7 *port_ops;
	void *private_data;
};

struct ata_acpi_gtf {
	u8 tf[7];
};

struct ata_acpi_hotplug_context {
	struct acpi_hotplug_context___16 hp;
	union {
		struct ata_port___7 *ap;
		struct ata_device___7 *dev;
	} data;
};

struct module___300;

struct file___369;

struct kiocb___369;

struct poll_table_struct___222;

struct vm_area_struct___370;

struct inode___369;

struct file_lock___369;

struct page___370;

struct seq_file___313;

struct file_operations___369 {
	struct module___300 *owner;
	loff_t (*llseek)(struct file___369 *, loff_t, int);
	ssize_t (*read)(struct file___369 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___369 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___369 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___369 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___369 *, bool);
	int (*iterate)(struct file___369 *, struct dir_context *);
	int (*iterate_shared)(struct file___369 *, struct dir_context *);
	__poll_t (*poll)(struct file___369 *, struct poll_table_struct___222 *);
	long int (*unlocked_ioctl)(struct file___369 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___369 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___369 *, struct vm_area_struct___370 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___369 *, struct file___369 *);
	int (*flush)(struct file___369 *, fl_owner_t);
	int (*release)(struct inode___369 *, struct file___369 *);
	int (*fsync)(struct file___369 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___369 *, int);
	int (*lock)(struct file___369 *, int, struct file_lock___369 *);
	ssize_t (*sendpage)(struct file___369 *, struct page___370 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___369 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___369 *, int, struct file_lock___369 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___369 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___369 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___369 *, long int, struct file_lock___369 **, void **);
	long int (*fallocate)(struct file___369 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___313 *, struct file___369 *);
	ssize_t (*copy_file_range)(struct file___369 *, loff_t, struct file___369 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___369 *, loff_t, struct file___369 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___369 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___369 {
	u64 seqnum;
	struct vm_area_struct___370 *vmas[4];
};

struct page_frag___369 {
	struct page___370 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___369;

struct cred___340;

struct bio_list___186;

struct backing_dev_info___186;

struct io_context___106;

struct request_queue___102;

struct vm_struct___275;

struct task_struct___370 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___370 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___369 *mm;
	struct mm_struct___369 *active_mm;
	struct vmacache___369 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___370 *real_parent;
	struct task_struct___370 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___370 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___217 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___217 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___217 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___340 *ptracer_cred;
	const struct cred___340 *real_cred;
	const struct cred___340 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___370 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___186 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___186 *backing_dev_info;
	struct io_context___106 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___369 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___102 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___370 *oom_reaper_list;
	struct vm_struct___275 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___141 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___370 *pgtable_t___369;

struct address_space___368;

struct dev_pagemap___357;

struct page___370 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___368 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___370 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___369 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___369 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___357 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___369;

struct lruvec___369 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___369 *pgdat;
};

struct zone___369 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___369 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___369 {
	struct zone___369 *zone;
	int zone_idx;
};

struct zonelist___369 {
	struct zoneref___369 _zonerefs[25];
};

struct pglist_data___369 {
	struct zone___369 node_zones[3];
	struct zonelist___369 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___370 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___370 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___369 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___370 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___370 *owner;
};

struct secondary_data___370 {
	void *stack;
	struct task_struct___370 *task;
	long int status;
};

struct blocking_notifier_head___369 {
	struct rw_semaphore___370 rwsem;
	struct notifier_block *head;
};

struct dentry___368;

struct path___369 {
	struct vfsmount *mnt;
	struct dentry___368 *dentry;
};

struct file___369 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___369 f_path;
	struct inode___369 *f_inode;
	const struct file_operations___369 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___217 f_owner;
	const struct cred___340 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___368 *f_mapping;
	errseq_t f_wb_err;
};

struct key___340;

struct user_struct___340;

struct cred___340 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___340 *session_keyring;
	struct key___340 *process_keyring;
	struct key___340 *thread_keyring;
	struct key___340 *request_key_auth;
	void *security;
	struct user_struct___340 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___362;

struct kernfs_elem_dir___362 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___362 *root;
};

struct kernfs_node___363;

struct kernfs_syscall_ops___362;

struct kernfs_root___362 {
	struct kernfs_node___363 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___362 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___362 {
	struct kernfs_node___363 *target_kn;
};

struct kernfs_ops___362;

struct kernfs_elem_attr___362 {
	const struct kernfs_ops___362 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___363 *notify_next;
};

struct kernfs_node___363 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___363 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___362 dir;
		struct kernfs_elem_symlink___362 symlink;
		struct kernfs_elem_attr___362 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___362;

struct kernfs_ops___362 {
	int (*open)(struct kernfs_open_file___362 *);
	void (*release)(struct kernfs_open_file___362 *);
	int (*seq_show)(struct seq_file___313 *, void *);
	void * (*seq_start)(struct seq_file___313 *, loff_t *);
	void * (*seq_next)(struct seq_file___313 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___313 *, void *);
	ssize_t (*read)(struct kernfs_open_file___362 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___362 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___362 *, struct vm_area_struct___370 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___362 *, struct poll_table_struct___222 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___362 {
	int (*remount_fs)(struct kernfs_root___362 *, int *, char *);
	int (*show_options)(struct seq_file___313 *, struct kernfs_root___362 *);
	int (*mkdir)(struct kernfs_node___363 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___363 *);
	int (*rename)(struct kernfs_node___363 *, struct kernfs_node___363 *, const char *);
	int (*show_path)(struct seq_file___313 *, struct kernfs_node___363 *, struct kernfs_root___362 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___312;

struct seq_file___313 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___312 *op;
	int poll_event;
	const struct file___369 *file;
	void *private;
};

struct vm_operations_struct___357;

struct kernfs_open_file___362 {
	struct kernfs_node___363 *kn;
	struct file___369 *file;
	struct seq_file___313 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___357 *vm_ops;
};

struct vm_fault___357;

struct vm_operations_struct___357 {
	void (*open)(struct vm_area_struct___370 *);
	void (*close)(struct vm_area_struct___370 *);
	int (*split)(struct vm_area_struct___370 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___370 *);
	vm_fault_t (*fault)(struct vm_fault___357 *);
	vm_fault_t (*huge_fault)(struct vm_fault___357 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___357 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___370 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___357 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___357 *);
	int (*access)(struct vm_area_struct___370 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___370 *);
	int (*set_policy)(struct vm_area_struct___370 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___370 *, long unsigned int);
	struct page___370 * (*find_special_page)(struct vm_area_struct___370 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___228)(struct file___369 *, wait_queue_head_t *, struct poll_table_struct___222 *);

struct poll_table_struct___222 {
	poll_queue_proc___228 _qproc;
	__poll_t _key;
};

struct vm_area_struct___370 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___370 *vm_next;
	struct vm_area_struct___370 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___369 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___357 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___369 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___356;

struct bin_attribute___332;

struct attribute_group___333 {
	const char *name;
	umode_t (*is_visible)(struct kobject___356 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___356 *, struct bin_attribute___332 *, int);
	struct attribute **attrs;
	struct bin_attribute___332 **bin_attrs;
};

struct kset___355;

struct kobj_type___355;

struct kobject___356 {
	const char *name;
	struct list_head entry;
	struct kobject___356 *parent;
	struct kset___355 *kset;
	struct kobj_type___355 *ktype;
	struct kernfs_node___363 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___332 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___369 *, struct kobject___356 *, struct bin_attribute___332 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___369 *, struct kobject___356 *, struct bin_attribute___332 *, char *, loff_t, size_t);
	int (*mmap)(struct file___369 *, struct kobject___356 *, struct bin_attribute___332 *, struct vm_area_struct___370 *);
};

struct sysfs_ops___355 {
	ssize_t (*show)(struct kobject___356 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___356 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___355;

struct kset___355 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___356 kobj;
	const struct kset_uevent_ops___355 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___355 {
	void (*release)(struct kobject___356 *);
	const struct sysfs_ops___355 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___28 * (*child_ns_type)(struct kobject___356 *);
	const void * (*namespace)(struct kobject___356 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___355 {
	int (* const filter)(struct kset___355 *, struct kobject___356 *);
	const char * (* const name)(struct kset___355 *, struct kobject___356 *);
	int (* const uevent)(struct kset___355 *, struct kobject___356 *, struct kobj_uevent_env *);
};

struct kobj_attribute___347 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___356 *, struct kobj_attribute___347 *, char *);
	ssize_t (*store)(struct kobject___356 *, struct kobj_attribute___347 *, const char *, size_t);
};

struct kernel_param___297;

struct kernel_param_ops___297 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___297 *);
	int (*get)(char *, const struct kernel_param___297 *);
	void (*free)(void *);
};

struct kparam_array___297;

struct kernel_param___297 {
	const char *name;
	struct module___300 *mod;
	const struct kernel_param_ops___297 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___297 *arr;
	};
};

struct kparam_array___297 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___297 *ops;
	void *elem;
};

struct module_kobject___297 {
	struct kobject___356 kobj;
	struct module___300 *mod;
	struct kobject___356 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___297 {
	struct module___300 *mod;
	struct latch_tree_node node;
};

struct module_layout___297 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___297 mtn;
};

struct module_attribute___297;

struct module___300 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___297 mkobj;
	struct module_attribute___297 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___356 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___297 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___297 core_layout;
	struct module_layout___297 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___297 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___297 *, struct module_kobject___297 *, char *);
	ssize_t (*store)(struct module_attribute___297 *, struct module_kobject___297 *, const char *, size_t);
	void (*setup)(struct module___300 *, const char *);
	int (*test)(struct module___300 *);
	void (*free)(struct module___300 *);
};

struct module_version_attribute___10 {
	struct module_attribute___297 mattr;
	const char *module_name;
	const char *version;
};

struct device___336;

struct dev_pm_ops___336 {
	int (*prepare)(struct device___336 *);
	void (*complete)(struct device___336 *);
	int (*suspend)(struct device___336 *);
	int (*resume)(struct device___336 *);
	int (*freeze)(struct device___336 *);
	int (*thaw)(struct device___336 *);
	int (*poweroff)(struct device___336 *);
	int (*restore)(struct device___336 *);
	int (*suspend_late)(struct device___336 *);
	int (*resume_early)(struct device___336 *);
	int (*freeze_late)(struct device___336 *);
	int (*thaw_early)(struct device___336 *);
	int (*poweroff_late)(struct device___336 *);
	int (*restore_early)(struct device___336 *);
	int (*suspend_noirq)(struct device___336 *);
	int (*resume_noirq)(struct device___336 *);
	int (*freeze_noirq)(struct device___336 *);
	int (*thaw_noirq)(struct device___336 *);
	int (*poweroff_noirq)(struct device___336 *);
	int (*restore_noirq)(struct device___336 *);
	int (*runtime_suspend)(struct device___336 *);
	int (*runtime_resume)(struct device___336 *);
	int (*runtime_idle)(struct device___336 *);
};

struct dev_pm_info___336 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___5 *subsys_data;
	void (*set_latency_tolerance)(struct device___336 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___336;

struct bus_type___336;

struct device_driver___336;

struct dev_pm_domain___336;

struct dma_map_ops___124;

struct device_node___81;

struct fwnode_handle___258;

struct class___336;

struct device___336 {
	struct device___336 *parent;
	struct device_private *p;
	struct kobject___356 kobj;
	const char *init_name;
	const struct device_type___336 *type;
	struct mutex mutex;
	struct bus_type___336 *bus;
	struct device_driver___336 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___336 power;
	struct dev_pm_domain___336 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___124 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___81 *of_node;
	struct fwnode_handle___258 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___336 *class;
	const struct attribute_group___333 **groups;
	void (*release)(struct device___336 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___336 {
	struct dev_pm_ops___336 ops;
	void (*detach)(struct device___336 *, bool);
	int (*activate)(struct device___336 *);
	void (*sync)(struct device___336 *);
	void (*dismiss)(struct device___336 *);
};

struct user_struct___340 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___340 *uid_keyring;
	struct key___340 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___369;

struct mm_struct___369 {
	struct {
		struct vm_area_struct___370 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___369 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___370 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___369 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___370 *owner;
		struct user_namespace___3 *user_ns;
		struct file___369 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___369 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct bio___186;

struct bio_list___186 {
	struct bio___186 *head;
	struct bio___186 *tail;
};

struct bdi_writeback_congested___186;

struct bdi_writeback___186 {
	struct backing_dev_info___186 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___186 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___157 *memcg_css;
	struct cgroup_subsys_state___157 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___186 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___186 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___336 *dev;
	struct device___336 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___368 *debug_dir;
	struct dentry___368 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___106;

struct io_context___106 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___106 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

typedef blk_qc_t make_request_fn___102(struct request_queue___102 *, struct bio___186 *);

struct request___102;

typedef int dma_drain_needed_fn___102(struct request___102 *);

struct bsg_ops___102;

struct bsg_class_device___102 {
	struct device___336 *class_dev;
	int minor;
	struct request_queue___102 *queue;
	const struct bsg_ops___102 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___186 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___186 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___102;

struct blk_mq_ops___39;

struct blk_mq_hw_ctx___39;

struct blk_mq_tag_set___39;

struct request_queue___102 {
	struct list_head queue_head;
	struct request___102 *last_merge;
	struct elevator_queue___102 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___102 *make_request_fn;
	dma_drain_needed_fn___102 *dma_drain_needed;
	const struct blk_mq_ops___39 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___39 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___186 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___356 kobj;
	struct kobject___356 *mq_kobj;
	struct blk_integrity integrity;
	struct device___336 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	struct bsg_class_device___102 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set___39 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___186 bio_split;
	struct dentry___368 *debugfs_dir;
	struct dentry___368 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___275 {
	struct vm_struct___275 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___370 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bus_type___336 {
	const char *name;
	const char *dev_name;
	struct device___336 *dev_root;
	const struct attribute_group___333 **bus_groups;
	const struct attribute_group___333 **dev_groups;
	const struct attribute_group___333 **drv_groups;
	int (*match)(struct device___336 *, struct device_driver___336 *);
	int (*uevent)(struct device___336 *, struct kobj_uevent_env *);
	int (*probe)(struct device___336 *);
	int (*remove)(struct device___336 *);
	void (*shutdown)(struct device___336 *);
	int (*online)(struct device___336 *);
	int (*offline)(struct device___336 *);
	int (*suspend)(struct device___336 *, pm_message_t);
	int (*resume)(struct device___336 *);
	int (*num_vf)(struct device___336 *);
	int (*dma_configure)(struct device___336 *);
	const struct dev_pm_ops___336 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___336 {
	const char *name;
	struct bus_type___336 *bus;
	struct module___300 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___336 *);
	int (*remove)(struct device___336 *);
	void (*shutdown)(struct device___336 *);
	int (*suspend)(struct device___336 *, pm_message_t);
	int (*resume)(struct device___336 *);
	const struct attribute_group___333 **groups;
	const struct dev_pm_ops___336 *pm;
	void (*coredump)(struct device___336 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___336 {
	const char *name;
	const struct attribute_group___333 **groups;
	int (*uevent)(struct device___336 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___336 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___336 *);
	const struct dev_pm_ops___336 *pm;
};

struct class___336 {
	const char *name;
	struct module___300 *owner;
	const struct attribute_group___333 **class_groups;
	const struct attribute_group___333 **dev_groups;
	struct kobject___356 *dev_kobj;
	int (*dev_uevent)(struct device___336 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___336 *, umode_t *);
	void (*class_release)(struct class___336 *);
	void (*dev_release)(struct device___336 *);
	int (*shutdown_pre)(struct device___336 *);
	const struct kobj_ns_type_operations___28 *ns_type;
	const void * (*namespace)(struct device___336 *);
	const struct dev_pm_ops___336 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct device_attribute___48 {
	struct attribute attr;
	ssize_t (*show)(struct device___336 *, struct device_attribute___48 *, char *);
	ssize_t (*store)(struct device___336 *, struct device_attribute___48 *, const char *, size_t);
};

struct dma_map_ops___124 {
	void * (*alloc)(struct device___336 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___336 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___336 *, struct vm_area_struct___370 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___336 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___336 *, struct page___370 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___336 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___336 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___336 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___336 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___336 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___336 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___336 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___336 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___336 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___336 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___336 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___336 *, u64);
	u64 (*get_required_mask)(struct device___336 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___258;

struct fwnode_handle___258 {
	struct fwnode_handle___258 *secondary;
	const struct fwnode_operations___258 *ops;
};

struct property___77;

struct device_node___81 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___258 fwnode;
	struct property___77 *properties;
	struct property___77 *deadprops;
	struct device_node___81 *parent;
	struct device_node___81 *child;
	struct device_node___81 *sibling;
	struct kobject___356 kobj;
	long unsigned int _flags;
	void *data;
};

struct address_space_operations___368;

struct address_space___368 {
	struct inode___369 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___370 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___368 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___357)(struct vm_area_struct___370 *, long unsigned int, const struct page___370 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___357)(struct page___370 *, void *);

struct dev_pagemap___357 {
	dev_page_fault_t___357 page_fault;
	dev_page_free_t___357 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___336 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___369 {
	struct task_struct___370 *task;
	struct core_thread___369 *next;
};

struct core_state___369 {
	atomic_t nr_threads;
	struct core_thread___369 dumper;
	struct completion startup;
};

struct vm_fault___357 {
	struct vm_area_struct___370 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___370 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___370 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___369 prealloc_pte;
};

struct fwnode_reference_args___258;

struct fwnode_endpoint___258;

struct fwnode_operations___258 {
	struct fwnode_handle___258 * (*get)(struct fwnode_handle___258 *);
	void (*put)(struct fwnode_handle___258 *);
	bool (*device_is_available)(const struct fwnode_handle___258 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___258 *, const struct device___336 *);
	bool (*property_present)(const struct fwnode_handle___258 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___258 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___258 *, const char *, const char **, size_t);
	struct fwnode_handle___258 * (*get_parent)(const struct fwnode_handle___258 *);
	struct fwnode_handle___258 * (*get_next_child_node)(const struct fwnode_handle___258 *, struct fwnode_handle___258 *);
	struct fwnode_handle___258 * (*get_named_child_node)(const struct fwnode_handle___258 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___258 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___258 *);
	struct fwnode_handle___258 * (*graph_get_next_endpoint)(const struct fwnode_handle___258 *, struct fwnode_handle___258 *);
	struct fwnode_handle___258 * (*graph_get_remote_endpoint)(const struct fwnode_handle___258 *);
	struct fwnode_handle___258 * (*graph_get_port_parent)(struct fwnode_handle___258 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___258 *, struct fwnode_endpoint___258 *);
};

struct fwnode_endpoint___258 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___258 *local_fwnode;
};

struct fwnode_reference_args___258 {
	struct fwnode_handle___258 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pci_bus___33;

struct pci_slot___33 {
	struct pci_bus___33 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject___356 kobj;
};

struct pci_dev___33;

struct pci_ops___33;

struct msi_controller___13;

struct pci_bus___33 {
	struct list_head node;
	struct pci_bus___33 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___33 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___33 *ops;
	struct msi_controller___13 *msi;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	int domain_nr;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___336 *bridge;
	struct device___336 dev;
	struct bin_attribute___332 *legacy_io;
	struct bin_attribute___332 *legacy_mem;
	unsigned int is_added: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
};

struct pci_driver___33;

struct pci_dev___33 {
	struct list_head bus_list;
	struct pci_bus___33 *bus;
	struct pci_bus___33 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___33 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u16 aer_cap;
	struct aer_stats *aer_stats;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	long unsigned int *dma_alias_mask;
	struct pci_driver___33 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	unsigned int imm_ready: 1;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int bridge_d3: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int hotplug_user_indicators: 1;
	unsigned int clear_retrain_link: 1;
	unsigned int d3_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	unsigned int ltr_path: 1;
	unsigned int eetlp_prefix_path: 1;
	pci_channel_state_t error_state;
	struct device___336 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int multifunction: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int ats_enabled: 1;
	unsigned int pasid_enabled: 1;
	unsigned int pri_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int reset_fn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int shpc_managed: 1;
	unsigned int is_thunderbolt: 1;
	unsigned int __aer_firmware_first_valid: 1;
	unsigned int __aer_firmware_first: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int irq_managed: 1;
	unsigned int has_secondary_link: 1;
	unsigned int non_compliant_bars: 1;
	unsigned int is_probed: 1;
	unsigned int link_active_reporting: 1;
	unsigned int untrusted: 1;
	unsigned int no_vf_scan: 1;
	unsigned int io_window: 1;
	unsigned int pref_window: 1;
	unsigned int pref_64_window: 1;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	struct bin_attribute___332 *rom_attr;
	int rom_attr_enabled;
	struct bin_attribute___332 *res_attr[17];
	struct bin_attribute___332 *res_attr_wc[17];
	unsigned int broken_cmd_compl: 1;
	const struct attribute_group___333 **msi_irq_groups;
	struct pci_vpd *vpd;
	union {
		struct pci_sriov *sriov;
		struct pci_dev___33 *physfn;
	};
	u16 ats_cap;
	u8 ats_stu;
	atomic_t ats_ref_cnt;
	u32 pri_reqs_alloc;
	u16 pasid_features;
	struct pci_p2pdma *p2pdma;
	phys_addr_t rom;
	size_t romlen;
	char *driver_override;
	long unsigned int priv_flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t pci_dev_extended_size_rh;
	struct pci_dev_extended_rh pci_dev_extended_rh;
};

struct pci_error_handlers___33;

struct pci_driver___33 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___33 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___33 *);
	int (*suspend)(struct pci_dev___33 *, pm_message_t);
	int (*suspend_late)(struct pci_dev___33 *, pm_message_t);
	int (*resume_early)(struct pci_dev___33 *);
	int (*resume)(struct pci_dev___33 *);
	void (*shutdown)(struct pci_dev___33 *);
	int (*sriov_configure)(struct pci_dev___33 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	const struct pci_error_handlers___33 *err_handler;
	const struct attribute_group___333 **groups;
	struct device_driver___336 driver;
	struct pci_dynids dynids;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct pci_ops___33 {
	int (*add_bus)(struct pci_bus___33 *);
	void (*remove_bus)(struct pci_bus___33 *);
	void * (*map_bus)(struct pci_bus___33 *, unsigned int, int);
	int (*read)(struct pci_bus___33 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___33 *, unsigned int, int, int, u32);
};

struct msi_desc___16;

struct msi_controller___13 {
	struct module___300 *owner;
	struct device___336 *dev;
	struct device_node___81 *of_node;
	struct list_head list;
	int (*setup_irq)(struct msi_controller___13 *, struct pci_dev___33 *, struct msi_desc___16 *);
	int (*setup_irqs)(struct msi_controller___13 *, struct pci_dev___33 *, int, int);
	void (*teardown_irq)(struct msi_controller___13 *, unsigned int);
};

struct pci_error_handlers___33 {
	pci_ers_result_t (*error_detected)(struct pci_dev___33 *, enum pci_channel_state);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___33 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___33 *);
	void (*reset_prepare)(struct pci_dev___33 *);
	void (*reset_done)(struct pci_dev___33 *);
	void (*resume)(struct pci_dev___33 *);
};

struct dentry_operations___368;

struct super_block___368;

struct dentry___368 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___368 *d_parent;
	struct qstr d_name;
	struct inode___369 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___368 *d_op;
	struct super_block___368 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___368;

struct block_device___368;

struct cdev___88;

struct inode___369 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___368 *i_op;
	struct super_block___368 *i_sb;
	struct address_space___368 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___370 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___186 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___369 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___368 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___368 *i_bdev;
		struct cdev___88 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___368 {
	int (*d_revalidate)(struct dentry___368 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___368 *, unsigned int);
	int (*d_hash)(const struct dentry___368 *, struct qstr *);
	int (*d_compare)(const struct dentry___368 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___368 *);
	int (*d_init)(struct dentry___368 *);
	void (*d_release)(struct dentry___368 *);
	void (*d_prune)(struct dentry___368 *);
	void (*d_iput)(struct dentry___368 *, struct inode___369 *);
	char * (*d_dname)(struct dentry___368 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___369 *);
	int (*d_manage)(const struct path___369 *, bool);
	struct dentry___368 * (*d_real)(struct dentry___368 *, const struct inode___369 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___368;

struct mem_dqinfo___368 {
	struct quota_format_type___368 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___368;

struct quota_info___368 {
	unsigned int flags;
	struct rw_semaphore___370 dqio_sem;
	struct inode___369 *files[3];
	struct mem_dqinfo___368 info[3];
	const struct quota_format_ops___368 *ops[3];
};

struct rcuwait___368 {
	struct task_struct___370 *task;
};

struct percpu_rw_semaphore___368 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___370 rw_sem;
	struct rcuwait___368 writer;
	int readers_block;
};

struct sb_writers___368 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___368 rw_sem[3];
};

struct file_system_type___368;

struct super_operations___368;

struct dquot_operations___368;

struct quotactl_ops___368;

struct super_block___368 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___368 *s_type;
	const struct super_operations___368 *s_op;
	const struct dquot_operations___368 *dq_op;
	const struct quotactl_ops___368 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___368 *s_root;
	struct rw_semaphore___370 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___368 *s_bdev;
	struct backing_dev_info___186 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___368 s_dquot;
	struct sb_writers___368 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___368 *s_d_op;
	int cleancache_poolid;
	struct shrinker___133 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct io_cq___106 {
	struct request_queue___102 *q;
	struct io_context___106 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___369 {
	struct file___369 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___369 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___368 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___369 *ia_file;
};

struct dquot___368 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___368 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___368 {
	int qf_fmt_id;
	const struct quota_format_ops___368 *qf_ops;
	struct module___300 *qf_owner;
	struct quota_format_type___368 *qf_next;
};

struct quota_format_ops___368 {
	int (*check_quota_file)(struct super_block___368 *, int);
	int (*read_file_info)(struct super_block___368 *, int);
	int (*write_file_info)(struct super_block___368 *, int);
	int (*free_file_info)(struct super_block___368 *, int);
	int (*read_dqblk)(struct dquot___368 *);
	int (*commit_dqblk)(struct dquot___368 *);
	int (*release_dqblk)(struct dquot___368 *);
	int (*get_next_id)(struct super_block___368 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___368 {
	int (*write_dquot)(struct dquot___368 *);
	struct dquot___368 * (*alloc_dquot)(struct super_block___368 *, int);
	void (*destroy_dquot)(struct dquot___368 *);
	int (*acquire_dquot)(struct dquot___368 *);
	int (*release_dquot)(struct dquot___368 *);
	int (*mark_dirty)(struct dquot___368 *);
	int (*write_info)(struct super_block___368 *, int);
	qsize_t * (*get_reserved_space)(struct inode___369 *);
	int (*get_projid)(struct inode___369 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___369 *, qsize_t *);
	int (*get_next_id)(struct super_block___368 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___368 {
	int (*quota_on)(struct super_block___368 *, int, int, const struct path___369 *);
	int (*quota_off)(struct super_block___368 *, int);
	int (*quota_enable)(struct super_block___368 *, unsigned int);
	int (*quota_disable)(struct super_block___368 *, unsigned int);
	int (*quota_sync)(struct super_block___368 *, int);
	int (*set_info)(struct super_block___368 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___368 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___368 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___368 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___368 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___368 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___368 {
	int (*writepage)(struct page___370 *, struct writeback_control___3 *);
	int (*readpage)(struct file___369 *, struct page___370 *);
	int (*writepages)(struct address_space___368 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___370 *);
	int (*readpages)(struct file___369 *, struct address_space___368 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___369 *, struct address_space___368 *, loff_t, unsigned int, unsigned int, struct page___370 **, void **);
	int (*write_end)(struct file___369 *, struct address_space___368 *, loff_t, unsigned int, unsigned int, struct page___370 *, void *);
	sector_t (*bmap)(struct address_space___368 *, sector_t);
	void (*invalidatepage)(struct page___370 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___370 *, gfp_t);
	void (*freepage)(struct page___370 *);
	ssize_t (*direct_IO)(struct kiocb___369 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___368 *, struct page___370 *, struct page___370 *, enum migrate_mode);
	bool (*isolate_page)(struct page___370 *, isolate_mode_t);
	void (*putback_page)(struct page___370 *);
	int (*launder_page)(struct page___370 *);
	int (*is_partially_uptodate)(struct page___370 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___370 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___368 *, struct page___370 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___369 *, sector_t *);
	void (*swap_deactivate)(struct file___369 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct hd_struct___106;

struct gendisk___106;

struct block_device___368 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___369 *bd_inode;
	struct super_block___368 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___368 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___106 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___106 *bd_disk;
	struct request_queue___102 *bd_queue;
	struct backing_dev_info___186 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct hd_struct___106 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___336 __dev;
	struct kobject___356 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___106;

struct block_device_operations___103;

struct gendisk___106 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___106 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___106 *part_tbl;
	struct hd_struct___106 part0;
	const struct block_device_operations___103 *fops;
	struct request_queue___102 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___370 lookup_sem;
	struct kobject___356 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___356 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___88 {
	struct kobject___356 kobj;
	struct module___300 *owner;
	const struct file_operations___369 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___368 {
	struct dentry___368 * (*lookup)(struct inode___369 *, struct dentry___368 *, unsigned int);
	const char * (*get_link)(struct dentry___368 *, struct inode___369 *, struct delayed_call *);
	int (*permission)(struct inode___369 *, int);
	struct posix_acl * (*get_acl)(struct inode___369 *, int);
	int (*readlink)(struct dentry___368 *, char *, int);
	int (*create)(struct inode___369 *, struct dentry___368 *, umode_t, bool);
	int (*link)(struct dentry___368 *, struct inode___369 *, struct dentry___368 *);
	int (*unlink)(struct inode___369 *, struct dentry___368 *);
	int (*symlink)(struct inode___369 *, struct dentry___368 *, const char *);
	int (*mkdir)(struct inode___369 *, struct dentry___368 *, umode_t);
	int (*rmdir)(struct inode___369 *, struct dentry___368 *);
	int (*mknod)(struct inode___369 *, struct dentry___368 *, umode_t, dev_t);
	int (*rename)(struct inode___369 *, struct dentry___368 *, struct inode___369 *, struct dentry___368 *, unsigned int);
	int (*setattr)(struct dentry___368 *, struct iattr___368 *);
	int (*getattr)(const struct path___369 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___368 *, char *, size_t);
	int (*fiemap)(struct inode___369 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___369 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___369 *, struct dentry___368 *, struct file___369 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___369 *, struct dentry___368 *, umode_t);
	int (*set_acl)(struct inode___369 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___368 {
	void (*fl_copy_lock)(struct file_lock___369 *, struct file_lock___369 *);
	void (*fl_release_private)(struct file_lock___369 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___368;

struct lock_manager_operations___368;

struct file_lock___369 {
	struct file_lock___369 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___369 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___368 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___368 *fl_ops;
	const struct lock_manager_operations___368 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___368 {
	int (*lm_compare_owner)(struct file_lock___369 *, struct file_lock___369 *);
	long unsigned int (*lm_owner_key)(struct file_lock___369 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___369 *);
	int (*lm_grant)(struct file_lock___369 *, int);
	bool (*lm_break)(struct file_lock___369 *);
	int (*lm_change)(struct file_lock___369 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___369 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___368 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___368 *fa_next;
	struct file___369 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___368 {
	const char *name;
	int fs_flags;
	struct dentry___368 * (*mount)(struct file_system_type___368 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___368 *);
	struct module___300 *owner;
	struct file_system_type___368 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___368 {
	struct inode___369 * (*alloc_inode)(struct super_block___368 *);
	void (*destroy_inode)(struct inode___369 *);
	void (*dirty_inode)(struct inode___369 *, int);
	int (*write_inode)(struct inode___369 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___369 *);
	void (*evict_inode)(struct inode___369 *);
	void (*put_super)(struct super_block___368 *);
	int (*sync_fs)(struct super_block___368 *, int);
	int (*freeze_super)(struct super_block___368 *);
	int (*freeze_fs)(struct super_block___368 *);
	int (*thaw_super)(struct super_block___368 *);
	int (*unfreeze_fs)(struct super_block___368 *);
	int (*statfs)(struct dentry___368 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___368 *, int *, char *);
	void (*umount_begin)(struct super_block___368 *);
	int (*show_options)(struct seq_file___313 *, struct dentry___368 *);
	int (*show_devname)(struct seq_file___313 *, struct dentry___368 *);
	int (*show_path)(struct seq_file___313 *, struct dentry___368 *);
	int (*show_stats)(struct seq_file___313 *, struct dentry___368 *);
	ssize_t (*quota_read)(struct super_block___368 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___368 *, int, const char *, size_t, loff_t);
	struct dquot___368 ** (*get_dquots)(struct inode___369 *);
	int (*bdev_try_to_free_page)(struct super_block___368 *, struct page___370 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___368 *, struct shrink_control___133 *);
	long int (*free_cached_objects)(struct super_block___368 *, struct shrink_control___133 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___186(struct bio___186 *);

struct bio_vec___188 {
	struct page___370 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___186;

struct bio___186 {
	struct bio___186 *bi_next;
	struct gendisk___106 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___186 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___186 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___188 *bi_io_vec;
	struct bio_set___186 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___188 bi_inline_vecs[0];
};

typedef void compound_page_dtor___357(struct page___370 *);

struct bio_integrity_payload___186 {
	struct bio___186 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___188 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___188 bip_inline_vecs[0];
};

struct disk_part_tbl___106 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___106 *last_lookup;
	struct hd_struct___106 *part[0];
};

struct block_device_operations___103 {
	int (*open)(struct block_device___368 *, fmode_t);
	void (*release)(struct gendisk___106 *, fmode_t);
	int (*rw_page)(struct block_device___368 *, sector_t, struct page___370 *, unsigned int);
	int (*ioctl)(struct block_device___368 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___368 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___106 *, unsigned int);
	int (*media_changed)(struct gendisk___106 *);
	void (*unlock_native_capacity)(struct gendisk___106 *);
	int (*revalidate_disk)(struct gendisk___106 *);
	int (*getgeo)(struct block_device___368 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___368 *, long unsigned int);
	int (*report_zones)(struct gendisk___106 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___300 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bdi_writeback_congested___186 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___186 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bsg_ops___102 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___102 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___102 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___102 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___102(struct request___102 *, blk_status_t);

struct request___102 {
	struct request_queue___102 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___39 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___186 *bio;
	struct bio___186 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___188 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___106 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___102 *saved_end_io;
		} flush;
	};
	struct gendisk___106 *rq_disk;
	struct hd_struct___106 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___102 *end_io;
	void *end_io_data;
	struct request___102 *next_rq;
};

struct blk_mq_hw_ctx___39 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___102 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags___4 *tags;
	struct blk_mq_tags___4 *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	unsigned int rh_reserved_nr_expired;
	struct hlist_node cpuhp_dead;
	struct kobject___356 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___368 *debugfs_dir;
	struct dentry___368 *sched_debugfs_dir;
	struct list_head hctx_list;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___102;

struct elevator_mq_ops___102 {
	int (*init_sched)(struct request_queue___102 *, struct elevator_type___102 *);
	void (*exit_sched)(struct elevator_queue___102 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___39 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___39 *, unsigned int);
	bool (*allow_merge)(struct request_queue___102 *, struct request___102 *, struct bio___186 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx___39 *, struct bio___186 *);
	int (*request_merge)(struct request_queue___102 *, struct request___102 **, struct bio___186 *);
	void (*request_merged)(struct request_queue___102 *, struct request___102 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___102 *, struct request___102 *, struct request___102 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___102 *, struct bio___186 *);
	void (*finish_request)(struct request___102 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___39 *, struct list_head *, bool);
	struct request___102 * (*dispatch_request)(struct blk_mq_hw_ctx___39 *);
	bool (*has_work)(struct blk_mq_hw_ctx___39 *);
	void (*completed_request)(struct request___102 *, u64);
	void (*started_request)(struct request___102 *);
	void (*requeue_request)(struct request___102 *);
	struct request___102 * (*former_request)(struct request_queue___102 *, struct request___102 *);
	struct request___102 * (*next_request)(struct request_queue___102 *, struct request___102 *);
	void (*init_icq)(struct io_cq___106 *);
	void (*exit_icq)(struct io_cq___106 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx___39 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___102;

struct elevator_type___102 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___102 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___102 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___300 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___102 {
	struct elevator_type___102 *type;
	void *elevator_data;
	struct kobject___356 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___102 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___102 *, char *);
	ssize_t (*store)(struct elevator_queue___102 *, const char *, size_t);
};

struct blk_mq_queue_data___39;

typedef blk_status_t queue_rq_fn___39(struct blk_mq_hw_ctx___39 *, const struct blk_mq_queue_data___39 *);

typedef void commit_rqs_fn___39(struct blk_mq_hw_ctx___39 *);

typedef bool get_budget_fn___39(struct blk_mq_hw_ctx___39 *);

typedef void put_budget_fn___39(struct blk_mq_hw_ctx___39 *);

typedef enum blk_eh_timer_return timeout_fn___39(struct request___102 *, bool);

typedef int poll_fn___39(struct blk_mq_hw_ctx___39 *);

typedef void complete_fn___39(struct request___102 *);

typedef int init_hctx_fn___39(struct blk_mq_hw_ctx___39 *, void *, unsigned int);

typedef void exit_hctx_fn___39(struct blk_mq_hw_ctx___39 *, unsigned int);

typedef int init_request_fn___39(struct blk_mq_tag_set___39 *, struct request___102 *, unsigned int, unsigned int);

typedef void exit_request_fn___39(struct blk_mq_tag_set___39 *, struct request___102 *, unsigned int);

typedef bool busy_fn___39(struct request_queue___102 *);

typedef int map_queues_fn___39(struct blk_mq_tag_set___39 *);

typedef void cleanup_rq_fn___39(struct request___102 *);

struct blk_mq_ops___39 {
	queue_rq_fn___39 *queue_rq;
	commit_rqs_fn___39 *commit_rqs;
	get_budget_fn___39 *get_budget;
	put_budget_fn___39 *put_budget;
	timeout_fn___39 *timeout;
	poll_fn___39 *poll;
	complete_fn___39 *complete;
	init_hctx_fn___39 *init_hctx;
	exit_hctx_fn___39 *exit_hctx;
	init_request_fn___39 *init_request;
	exit_request_fn___39 *exit_request;
	void (*initialize_rq_fn)(struct request___102 *);
	busy_fn___39 *busy;
	map_queues_fn___39 *map_queues;
	void (*show_rq)(struct seq_file___313 *, struct request___102 *);
	union {
		cleanup_rq_fn___39 *cleanup_rq;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide47;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct blk_mq_tag_set___39 {
	struct blk_mq_queue_map map[6];
	unsigned int nr_maps;
	const struct blk_mq_ops___39 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	struct blk_mq_tags___4 **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct msi_desc___16 {
	struct list_head list;
	unsigned int irq;
	unsigned int nvec_used;
	struct device___336 *dev;
	struct msi_msg msg;
	struct irq_affinity_desc *affinity;
	const void *iommu_cookie;
	union {
		struct {
			u32 masked;
			struct {
				u8 is_msix: 1;
				u8 multiple: 3;
				u8 multi_cap: 3;
				u8 maskbit: 1;
				u8 is_64: 1;
				u16 entry_nr;
				unsigned int default_irq;
			} msi_attrib;
			union {
				u8 mask_pos;
				void *mask_base;
			};
		};
		struct platform_msi_desc platform;
		struct fsl_mc_msi_desc fsl_mc;
	};
};

typedef int (*key_restrict_link_func_t___341)(struct key___340 *, const struct key_type *, const union key_payload *, struct key___340 *);

struct key_restriction___340;

struct key___340 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___370 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___340 *restrict_link;
};

struct key_restriction___340 {
	key_restrict_link_func_t___341 check;
	struct key___340 *key;
	struct key_type *keytype;
};

struct seq_operations___312 {
	void * (*start)(struct seq_file___313 *, loff_t *);
	void (*stop)(struct seq_file___313 *, void *);
	void * (*next)(struct seq_file___313 *, void *, loff_t *);
	int (*show)(struct seq_file___313 *, void *);
};

struct blk_mq_queue_data___39 {
	struct request___102 *rq;
	bool last;
	long unsigned int rh_reserved1;
};

struct Scsi_Host___15;

struct scsi_cmnd___11;

struct scsi_host_template___15 {
	struct module___300 *module;
	const char *name;
	const char * (*info)(struct Scsi_Host___15 *);
	int (*ioctl)(struct scsi_device___16 *, int, void *);
	int (*queuecommand)(struct Scsi_Host___15 *, struct scsi_cmnd___11 *);
	int (*eh_abort_handler)(struct scsi_cmnd___11 *);
	int (*eh_device_reset_handler)(struct scsi_cmnd___11 *);
	int (*eh_target_reset_handler)(struct scsi_cmnd___11 *);
	int (*eh_bus_reset_handler)(struct scsi_cmnd___11 *);
	int (*eh_host_reset_handler)(struct scsi_cmnd___11 *);
	int (*slave_alloc)(struct scsi_device___16 *);
	int (*slave_configure)(struct scsi_device___16 *);
	void (*slave_destroy)(struct scsi_device___16 *);
	int (*target_alloc)(struct scsi_target___16 *);
	void (*target_destroy)(struct scsi_target___16 *);
	int (*scan_finished)(struct Scsi_Host___15 *, long unsigned int);
	void (*scan_start)(struct Scsi_Host___15 *);
	int (*change_queue_depth)(struct scsi_device___16 *, int);
	int (*map_queues)(struct Scsi_Host___15 *);
	int (*bios_param)(struct scsi_device___16 *, struct block_device___368 *, sector_t, int *);
	void (*unlock_native_capacity)(struct scsi_device___16 *);
	int (*show_info)(struct seq_file___313 *, struct Scsi_Host___15 *);
	int (*write_info)(struct Scsi_Host___15 *, char *, int);
	enum blk_eh_timer_return (*eh_timed_out)(struct scsi_cmnd___11 *);
	int (*host_reset)(struct Scsi_Host___15 *, int);
	const char *proc_name;
	struct proc_dir_entry *proc_dir;
	int can_queue;
	int this_id;
	short unsigned int sg_tablesize;
	short unsigned int sg_prot_tablesize;
	unsigned int max_sectors;
	long unsigned int dma_boundary;
	short int cmd_per_lun;
	unsigned char present;
	int tag_alloc_policy;
	unsigned int track_queue_depth: 1;
	unsigned int supported_mode: 2;
	unsigned int unchecked_isa_dma: 1;
	unsigned int use_clustering: 1;
	unsigned int emulated: 1;
	unsigned int skip_settle_delay: 1;
	unsigned int no_write_same: 1;
	unsigned int force_blk_mq: 1;
	unsigned int max_host_blocked;
	struct device_attribute___48 **shost_attrs;
	struct device_attribute___48 **sdev_attrs;
	const struct attribute_group___333 **sdev_groups;
	u64 vendor_id;
	unsigned int cmd_size;
	struct scsi_host_cmd_pool *cmd_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct Scsi_Host___15 {
	struct list_head __devices;
	struct list_head __targets;
	struct list_head starved_list;
	spinlock_t default_lock;
	spinlock_t *host_lock;
	struct mutex scan_mutex;
	struct list_head eh_cmd_q;
	struct task_struct___370 *ehandler;
	struct completion *eh_action;
	wait_queue_head_t host_wait;
	struct scsi_host_template___15 *hostt;
	struct scsi_transport_template *transportt;
	struct blk_mq_tag_set___39 tag_set;
	atomic_t host_busy;
	atomic_t host_blocked;
	unsigned int host_failed;
	unsigned int host_eh_scheduled;
	unsigned int host_no;
	int eh_deadline;
	long unsigned int last_reset;
	unsigned int max_channel;
	unsigned int max_id;
	u64 max_lun;
	unsigned int unique_id;
	short unsigned int max_cmd_len;
	int this_id;
	int can_queue;
	short int cmd_per_lun;
	short unsigned int sg_tablesize;
	short unsigned int sg_prot_tablesize;
	unsigned int max_sectors;
	long unsigned int dma_boundary;
	unsigned int nr_hw_queues;
	long unsigned int cmd_serial_number;
	unsigned int active_mode: 2;
	unsigned int unchecked_isa_dma: 1;
	unsigned int use_clustering: 1;
	unsigned int host_self_blocked: 1;
	unsigned int reverse_ordering: 1;
	unsigned int tmf_in_progress: 1;
	unsigned int async_scan: 1;
	unsigned int eh_noresume: 1;
	unsigned int no_write_same: 1;
	unsigned int use_cmd_list: 1;
	unsigned int short_inquiry: 1;
	char work_q_name[20];
	struct workqueue_struct *work_q;
	struct workqueue_struct *tmf_work_q;
	unsigned int no_scsi2_lun_in_cdb: 1;
	unsigned int max_host_blocked;
	unsigned int prot_capabilities;
	unsigned char prot_guard_type;
	long unsigned int base;
	long unsigned int io_port;
	unsigned char n_io_port;
	unsigned char dma_channel;
	unsigned int irq;
	enum scsi_host_state shost_state;
	struct device___336 shost_gendev;
	struct device___336 shost_dev;
	void *shost_data;
	struct device___336 *dma_dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int hostdata[0];
};

struct scsi_device___16 {
	struct Scsi_Host___15 *host;
	struct request_queue___102 *request_queue;
	struct list_head siblings;
	struct list_head same_target_siblings;
	atomic_t device_busy;
	atomic_t device_blocked;
	spinlock_t list_lock;
	struct list_head cmd_list;
	struct list_head starved_entry;
	short unsigned int queue_depth;
	short unsigned int max_queue_depth;
	short unsigned int last_queue_full_depth;
	short unsigned int last_queue_full_count;
	long unsigned int last_queue_full_time;
	long unsigned int queue_ramp_up_period;
	long unsigned int last_queue_ramp_up;
	unsigned int id;
	unsigned int channel;
	u64 lun;
	unsigned int manufacturer;
	unsigned int sector_size;
	void *hostdata;
	unsigned char type;
	char scsi_level;
	char inq_periph_qual;
	struct mutex inquiry_mutex;
	unsigned char inquiry_len;
	unsigned char *inquiry;
	const char *vendor;
	const char *model;
	const char *rev;
	struct scsi_vpd *vpd_pg83;
	struct scsi_vpd *vpd_pg80;
	unsigned char current_tag;
	struct scsi_target___16 *sdev_target;
	blist_flags_t sdev_bflags;
	unsigned int eh_timeout;
	unsigned int removable: 1;
	unsigned int changed: 1;
	unsigned int busy: 1;
	unsigned int lockable: 1;
	unsigned int locked: 1;
	unsigned int borken: 1;
	unsigned int disconnect: 1;
	unsigned int soft_reset: 1;
	unsigned int sdtr: 1;
	unsigned int wdtr: 1;
	unsigned int ppr: 1;
	unsigned int tagged_supported: 1;
	unsigned int simple_tags: 1;
	unsigned int was_reset: 1;
	unsigned int expecting_cc_ua: 1;
	unsigned int use_10_for_rw: 1;
	unsigned int use_10_for_ms: 1;
	unsigned int no_report_opcodes: 1;
	unsigned int no_write_same: 1;
	unsigned int use_16_for_rw: 1;
	unsigned int skip_ms_page_8: 1;
	unsigned int skip_ms_page_3f: 1;
	unsigned int skip_vpd_pages: 1;
	unsigned int try_vpd_pages: 1;
	unsigned int use_192_bytes_for_3f: 1;
	unsigned int no_start_on_add: 1;
	unsigned int allow_restart: 1;
	unsigned int manage_start_stop: 1;
	unsigned int start_stop_pwr_cond: 1;
	unsigned int no_uld_attach: 1;
	unsigned int select_no_atn: 1;
	unsigned int fix_capacity: 1;
	unsigned int guess_capacity: 1;
	unsigned int retry_hwerror: 1;
	unsigned int last_sector_bug: 1;
	unsigned int no_read_disc_info: 1;
	unsigned int no_read_capacity_16: 1;
	unsigned int try_rc_10_first: 1;
	unsigned int security_supported: 1;
	unsigned int is_visible: 1;
	unsigned int wce_default_on: 1;
	unsigned int no_dif: 1;
	unsigned int broken_fua: 1;
	unsigned int lun_in_cdb: 1;
	unsigned int unmap_limit_for_ws: 1;
	atomic_t disk_events_disable_depth;
	long unsigned int supported_events[1];
	long unsigned int pending_events[1];
	struct list_head event_list;
	struct work_struct event_work;
	unsigned int max_device_blocked;
	atomic_t iorequest_cnt;
	atomic_t iodone_cnt;
	atomic_t ioerr_cnt;
	struct device___336 sdev_gendev;
	struct device___336 sdev_dev;
	struct execute_work ew;
	struct work_struct requeue_work;
	struct scsi_device_handler *handler;
	void *handler_data;
	unsigned char access_state;
	struct mutex state_mutex;
	enum scsi_device_state sdev_state;
	struct task_struct___370 *quiesced_by;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int sdev_data[0];
};

struct scsi_cmnd___11 {
	struct scsi_request req;
	struct scsi_device___16 *device;
	struct list_head list;
	struct list_head eh_entry;
	struct delayed_work abort_work;
	struct callback_head rcu;
	int eh_eflags;
	long unsigned int serial_number;
	long unsigned int jiffies_at_alloc;
	int retries;
	int allowed;
	unsigned char prot_op;
	unsigned char prot_type;
	unsigned char prot_flags;
	short unsigned int cmd_len;
	enum dma_data_direction sc_data_direction;
	unsigned char *cmnd;
	struct scsi_data_buffer sdb;
	struct scsi_data_buffer *prot_sdb;
	unsigned int underflow;
	unsigned int transfersize;
	struct request___102 *request;
	unsigned char *sense_buffer;
	void (*scsi_done)(struct scsi_cmnd___11 *);
	struct scsi_pointer SCp;
	unsigned char *host_scribble;
	int result;
	int flags;
	long unsigned int state;
	unsigned char tag;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct scsi_target___16 {
	struct scsi_device___16 *starget_sdev_user;
	struct list_head siblings;
	struct list_head devices;
	struct device___336 dev;
	struct kref reap_ref;
	unsigned int channel;
	unsigned int id;
	unsigned int create: 1;
	unsigned int single_lun: 1;
	unsigned int pdt_1f_for_no_lun: 1;
	unsigned int no_report_luns: 1;
	unsigned int expecting_lun_change: 1;
	atomic_t target_busy;
	atomic_t target_blocked;
	unsigned int can_queue;
	unsigned int max_target_blocked;
	char scsi_level;
	enum scsi_target_state state;
	void *hostdata;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int starget_data[0];
};

struct ata_queued_cmd___8;

typedef void (*ata_qc_cb_t___8)(struct ata_queued_cmd___8 *);

struct ata_port___8;

struct ata_device___8;

struct ata_queued_cmd___8 {
	struct ata_port___8 *ap;
	struct ata_device___8 *dev;
	struct scsi_cmnd___11 *scsicmd;
	void (*scsidone)(struct scsi_cmnd___11 *);
	struct ata_taskfile tf;
	u8 cdb[16];
	long unsigned int flags;
	unsigned int tag;
	unsigned int hw_tag;
	unsigned int n_elem;
	unsigned int orig_n_elem;
	int dma_dir;
	unsigned int sect_size;
	unsigned int nbytes;
	unsigned int extrabytes;
	unsigned int curbytes;
	struct scatterlist sgent;
	struct scatterlist *sg;
	struct scatterlist *cursg;
	unsigned int cursg_ofs;
	unsigned int err_mask;
	struct ata_taskfile result_tf;
	ata_qc_cb_t___8 complete_fn;
	void *private_data;
	void *lldd_task;
};

struct ata_link___8;

typedef int (*ata_prereset_fn_t___8)(struct ata_link___8 *, long unsigned int);

struct ata_eh_info___8 {
	struct ata_device___8 *dev;
	u32 serror;
	unsigned int err_mask;
	unsigned int action;
	unsigned int dev_action[2];
	unsigned int flags;
	unsigned int probe_mask;
	char desc[80];
	int desc_len;
};

struct ata_eh_context___8 {
	struct ata_eh_info___8 i;
	int tries[2];
	int cmd_timeout_idx[12];
	unsigned int classes[2];
	unsigned int did_probe_mask;
	unsigned int unloaded_mask;
	unsigned int saved_ncq_enabled;
	u8 saved_xfer_mode[2];
	long unsigned int last_reset;
};

struct ata_device___8 {
	struct ata_link___8 *link;
	unsigned int devno;
	unsigned int horkage;
	long unsigned int flags;
	struct scsi_device___16 *sdev;
	void *private_data;
	union acpi_object *gtf_cache;
	unsigned int gtf_filter;
	struct device___336 tdev;
	u64 n_sectors;
	u64 n_native_sectors;
	unsigned int class;
	long unsigned int unpark_deadline;
	u8 pio_mode;
	u8 dma_mode;
	u8 xfer_mode;
	unsigned int xfer_shift;
	unsigned int multi_count;
	unsigned int max_sectors;
	unsigned int cdb_len;
	long unsigned int pio_mask;
	long unsigned int mwdma_mask;
	long unsigned int udma_mask;
	u16 cylinders;
	u16 heads;
	u16 sectors;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	union {
		u16 id[256];
		u32 gscr[128];
	};
	u8 devslp_timing[8];
	u8 ncq_send_recv_cmds[20];
	u8 ncq_non_data_cmds[64];
	u32 zac_zoned_cap;
	u32 zac_zones_optimal_open;
	u32 zac_zones_optimal_nonseq;
	u32 zac_zones_max_open;
	int spdn_cnt;
	struct ata_ering ering;
	long: 64;
};

struct ata_link___8 {
	struct ata_port___8 *ap;
	int pmp;
	struct device___336 tdev;
	unsigned int active_tag;
	u32 sactive;
	unsigned int flags;
	u32 saved_scontrol;
	unsigned int hw_sata_spd_limit;
	unsigned int sata_spd_limit;
	unsigned int sata_spd;
	enum ata_lpm_policy lpm_policy;
	struct ata_eh_info___8 eh_info;
	struct ata_eh_context___8 eh_context;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ata_device___8 device[2];
	long unsigned int last_lpm_change;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef int (*ata_reset_fn_t___8)(struct ata_link___8 *, unsigned int *, long unsigned int);

typedef void (*ata_postreset_fn_t___8)(struct ata_link___8 *, unsigned int *);

struct ata_port_operations___8;

struct ata_host___8 {
	spinlock_t lock;
	struct device___336 *dev;
	void * const *iomap;
	unsigned int n_ports;
	unsigned int n_tags;
	void *private_data;
	struct ata_port_operations___8 *ops;
	long unsigned int flags;
	struct kref kref;
	struct mutex eh_mutex;
	struct task_struct___370 *eh_owner;
	struct ata_port___8 *simplex_claimed;
	struct ata_port___8 *ports[0];
};

struct ata_port_operations___8 {
	int (*qc_defer)(struct ata_queued_cmd___8 *);
	int (*check_atapi_dma)(struct ata_queued_cmd___8 *);
	void (*qc_prep)(struct ata_queued_cmd___8 *);
	unsigned int (*qc_issue)(struct ata_queued_cmd___8 *);
	bool (*qc_fill_rtf)(struct ata_queued_cmd___8 *);
	int (*cable_detect)(struct ata_port___8 *);
	long unsigned int (*mode_filter)(struct ata_device___8 *, long unsigned int);
	void (*set_piomode)(struct ata_port___8 *, struct ata_device___8 *);
	void (*set_dmamode)(struct ata_port___8 *, struct ata_device___8 *);
	int (*set_mode)(struct ata_link___8 *, struct ata_device___8 **);
	unsigned int (*read_id)(struct ata_device___8 *, struct ata_taskfile *, u16 *);
	void (*dev_config)(struct ata_device___8 *);
	void (*freeze)(struct ata_port___8 *);
	void (*thaw)(struct ata_port___8 *);
	ata_prereset_fn_t___8 prereset;
	ata_reset_fn_t___8 softreset;
	ata_reset_fn_t___8 hardreset;
	ata_postreset_fn_t___8 postreset;
	ata_prereset_fn_t___8 pmp_prereset;
	ata_reset_fn_t___8 pmp_softreset;
	ata_reset_fn_t___8 pmp_hardreset;
	ata_postreset_fn_t___8 pmp_postreset;
	void (*error_handler)(struct ata_port___8 *);
	void (*lost_interrupt)(struct ata_port___8 *);
	void (*post_internal_cmd)(struct ata_queued_cmd___8 *);
	void (*sched_eh)(struct ata_port___8 *);
	void (*end_eh)(struct ata_port___8 *);
	int (*scr_read)(struct ata_link___8 *, unsigned int, u32 *);
	int (*scr_write)(struct ata_link___8 *, unsigned int, u32);
	void (*pmp_attach)(struct ata_port___8 *);
	void (*pmp_detach)(struct ata_port___8 *);
	int (*set_lpm)(struct ata_link___8 *, enum ata_lpm_policy, unsigned int);
	int (*port_suspend)(struct ata_port___8 *, pm_message_t);
	int (*port_resume)(struct ata_port___8 *);
	int (*port_start)(struct ata_port___8 *);
	void (*port_stop)(struct ata_port___8 *);
	void (*host_stop)(struct ata_host___8 *);
	void (*sff_dev_select)(struct ata_port___8 *, unsigned int);
	void (*sff_set_devctl)(struct ata_port___8 *, u8);
	u8 (*sff_check_status)(struct ata_port___8 *);
	u8 (*sff_check_altstatus)(struct ata_port___8 *);
	void (*sff_tf_load)(struct ata_port___8 *, const struct ata_taskfile *);
	void (*sff_tf_read)(struct ata_port___8 *, struct ata_taskfile *);
	void (*sff_exec_command)(struct ata_port___8 *, const struct ata_taskfile *);
	unsigned int (*sff_data_xfer)(struct ata_queued_cmd___8 *, unsigned char *, unsigned int, int);
	void (*sff_irq_on)(struct ata_port___8 *);
	bool (*sff_irq_check)(struct ata_port___8 *);
	void (*sff_irq_clear)(struct ata_port___8 *);
	void (*sff_drain_fifo)(struct ata_queued_cmd___8 *);
	void (*bmdma_setup)(struct ata_queued_cmd___8 *);
	void (*bmdma_start)(struct ata_queued_cmd___8 *);
	void (*bmdma_stop)(struct ata_queued_cmd___8 *);
	u8 (*bmdma_status)(struct ata_port___8 *);
	ssize_t (*em_show)(struct ata_port___8 *, char *);
	ssize_t (*em_store)(struct ata_port___8 *, const char *, size_t);
	ssize_t (*sw_activity_show)(struct ata_device___8 *, char *);
	ssize_t (*sw_activity_store)(struct ata_device___8 *, enum sw_activity);
	ssize_t (*transmit_led_message)(struct ata_port___8 *, u32, ssize_t);
	void (*phy_reset)(struct ata_port___8 *);
	void (*eng_timeout)(struct ata_port___8 *);
	const struct ata_port_operations___8 *inherits;
};

struct ata_port___8 {
	struct Scsi_Host___15 *scsi_host;
	struct ata_port_operations___8 *ops;
	spinlock_t *lock;
	long unsigned int flags;
	unsigned int pflags;
	unsigned int print_id;
	unsigned int local_port_no;
	unsigned int port_no;
	struct ata_ioports ioaddr;
	u8 ctl;
	u8 last_ctl;
	struct ata_link___8 *sff_pio_task_link;
	struct delayed_work sff_pio_task;
	struct ata_bmdma_prd *bmdma_prd;
	dma_addr_t bmdma_prd_dma;
	unsigned int pio_mask;
	unsigned int mwdma_mask;
	unsigned int udma_mask;
	unsigned int cbl;
	struct ata_queued_cmd___8 qcmd[33];
	long unsigned int sas_tag_allocated;
	u64 qc_active;
	int nr_active_links;
	unsigned int sas_last_tag;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ata_link___8 link;
	struct ata_link___8 *slave_link;
	int nr_pmp_links;
	struct ata_link___8 *pmp_link;
	struct ata_link___8 *excl_link;
	struct ata_port_stats stats;
	struct ata_host___8 *host;
	struct device___336 *dev;
	struct device___336 tdev;
	struct mutex scsi_scan_mutex;
	struct delayed_work hotplug_task;
	struct work_struct scsi_rescan_task;
	unsigned int hsm_task_state;
	u32 msg_enable;
	struct list_head eh_done_q;
	wait_queue_head_t eh_wait_q;
	int eh_tries;
	struct completion park_req_pending;
	pm_message_t pm_mesg;
	enum ata_lpm_policy target_lpm_policy;
	struct timer_list fastdrain_timer;
	long unsigned int fastdrain_cnt;
	int em_message_type;
	void *private_data;
	struct ata_acpi_gtm __acpi_init_gtm;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sector_buf[512];
};

struct ata_port_info___8 {
	long unsigned int flags;
	long unsigned int link_flags;
	long unsigned int pio_mask;
	long unsigned int mwdma_mask;
	long unsigned int udma_mask;
	struct ata_port_operations___8 *port_ops;
	void *private_data;
};

struct property___77 {
	char *name;
	int length;
	void *value;
	struct property___77 *next;
	long unsigned int _flags;
	struct bin_attribute___332 attr;
};

struct phy___6;

struct phy_ops___5 {
	int (*init)(struct phy___6 *);
	int (*exit)(struct phy___6 *);
	int (*power_on)(struct phy___6 *);
	int (*power_off)(struct phy___6 *);
	int (*set_mode)(struct phy___6 *, enum phy_mode);
	int (*reset)(struct phy___6 *);
	int (*calibrate)(struct phy___6 *);
	struct module___300 *owner;
};

struct phy___6 {
	struct device___336 dev;
	int id;
	const struct phy_ops___5 *ops;
	struct mutex mutex;
	int init_count;
	int power_count;
	struct phy_attrs attrs;
	struct regulator *pwr;
};

enum {
	AHCI_MAX_PORTS = 32,
	AHCI_MAX_CLKS = 5,
	AHCI_MAX_SG = 168,
	AHCI_DMA_BOUNDARY = 4294967295,
	AHCI_MAX_CMDS = 32,
	AHCI_CMD_SZ = 32,
	AHCI_CMD_SLOT_SZ = 1024,
	AHCI_RX_FIS_SZ = 256,
	AHCI_CMD_TBL_CDB = 64,
	AHCI_CMD_TBL_HDR_SZ = 128,
	AHCI_CMD_TBL_SZ = 2816,
	AHCI_CMD_TBL_AR_SZ = 90112,
	AHCI_PORT_PRIV_DMA_SZ = 91392,
	AHCI_PORT_PRIV_FBS_DMA_SZ = 95232,
	AHCI_IRQ_ON_SG = 2147483648,
	AHCI_CMD_ATAPI = 32,
	AHCI_CMD_WRITE = 64,
	AHCI_CMD_PREFETCH = 128,
	AHCI_CMD_RESET = 256,
	AHCI_CMD_CLR_BUSY = 1024,
	RX_FIS_PIO_SETUP = 32,
	RX_FIS_D2H_REG = 64,
	RX_FIS_SDB = 88,
	RX_FIS_UNK = 96,
	HOST_CAP = 0,
	HOST_CTL = 4,
	HOST_IRQ_STAT = 8,
	HOST_PORTS_IMPL = 12,
	HOST_VERSION = 16,
	HOST_EM_LOC = 28,
	HOST_EM_CTL = 32,
	HOST_CAP2 = 36,
	HOST_RESET = 1,
	HOST_IRQ_EN = 2,
	HOST_MRSM = 4,
	HOST_AHCI_EN = 2147483648,
	HOST_CAP_SXS = 32,
	HOST_CAP_EMS = 64,
	HOST_CAP_CCC = 128,
	HOST_CAP_PART = 8192,
	HOST_CAP_SSC = 16384,
	HOST_CAP_PIO_MULTI = 32768,
	HOST_CAP_FBS = 65536,
	HOST_CAP_PMP = 131072,
	HOST_CAP_ONLY = 262144,
	HOST_CAP_CLO = 16777216,
	HOST_CAP_LED = 33554432,
	HOST_CAP_ALPM = 67108864,
	HOST_CAP_SSS = 134217728,
	HOST_CAP_MPS = 268435456,
	HOST_CAP_SNTF = 536870912,
	HOST_CAP_NCQ = 1073741824,
	HOST_CAP_64 = 2147483648,
	HOST_CAP2_BOH = 1,
	HOST_CAP2_NVMHCI = 2,
	HOST_CAP2_APST = 4,
	HOST_CAP2_SDS = 8,
	HOST_CAP2_SADM = 16,
	HOST_CAP2_DESO = 32,
	PORT_LST_ADDR = 0,
	PORT_LST_ADDR_HI = 4,
	PORT_FIS_ADDR = 8,
	PORT_FIS_ADDR_HI = 12,
	PORT_IRQ_STAT = 16,
	PORT_IRQ_MASK = 20,
	PORT_CMD = 24,
	PORT_TFDATA = 32,
	PORT_SIG = 36,
	PORT_CMD_ISSUE = 56,
	PORT_SCR_STAT = 40,
	PORT_SCR_CTL = 44,
	PORT_SCR_ERR = 48,
	PORT_SCR_ACT = 52,
	PORT_SCR_NTF = 60,
	PORT_FBS = 64,
	PORT_DEVSLP = 68,
	PORT_IRQ_COLD_PRES = 2147483648,
	PORT_IRQ_TF_ERR = 1073741824,
	PORT_IRQ_HBUS_ERR = 536870912,
	PORT_IRQ_HBUS_DATA_ERR = 268435456,
	PORT_IRQ_IF_ERR = 134217728,
	PORT_IRQ_IF_NONFATAL = 67108864,
	PORT_IRQ_OVERFLOW = 16777216,
	PORT_IRQ_BAD_PMP = 8388608,
	PORT_IRQ_PHYRDY = 4194304,
	PORT_IRQ_DEV_ILCK = 128,
	PORT_IRQ_CONNECT = 64,
	PORT_IRQ_SG_DONE = 32,
	PORT_IRQ_UNK_FIS = 16,
	PORT_IRQ_SDB_FIS = 8,
	PORT_IRQ_DMAS_FIS = 4,
	PORT_IRQ_PIOS_FIS = 2,
	PORT_IRQ_D2H_REG_FIS = 1,
	PORT_IRQ_FREEZE = 683671632,
	PORT_IRQ_ERROR = 2025848912,
	DEF_PORT_IRQ = 2025848959,
	PORT_CMD_ASP = 134217728,
	PORT_CMD_ALPE = 67108864,
	PORT_CMD_ATAPI = 16777216,
	PORT_CMD_FBSCP = 4194304,
	PORT_CMD_ESP = 2097152,
	PORT_CMD_HPCP = 262144,
	PORT_CMD_PMP = 131072,
	PORT_CMD_LIST_ON = 32768,
	PORT_CMD_FIS_ON = 16384,
	PORT_CMD_FIS_RX = 16,
	PORT_CMD_CLO = 8,
	PORT_CMD_POWER_ON = 4,
	PORT_CMD_SPIN_UP = 2,
	PORT_CMD_START = 1,
	PORT_CMD_ICC_MASK = 4026531840,
	PORT_CMD_ICC_ACTIVE = 268435456,
	PORT_CMD_ICC_PARTIAL = 536870912,
	PORT_CMD_ICC_SLUMBER = 1610612736,
	PORT_FBS_DWE_OFFSET = 16,
	PORT_FBS_ADO_OFFSET = 12,
	PORT_FBS_DEV_OFFSET = 8,
	PORT_FBS_DEV_MASK = 3840,
	PORT_FBS_SDE = 4,
	PORT_FBS_DEC = 2,
	PORT_FBS_EN = 1,
	PORT_DEVSLP_DM_OFFSET = 25,
	PORT_DEVSLP_DM_MASK = 503316480,
	PORT_DEVSLP_DITO_OFFSET = 15,
	PORT_DEVSLP_MDAT_OFFSET = 10,
	PORT_DEVSLP_DETO_OFFSET = 2,
	PORT_DEVSLP_DSP = 2,
	PORT_DEVSLP_ADSE = 1,
	AHCI_HFLAG_NO_NCQ = 1,
	AHCI_HFLAG_IGN_IRQ_IF_ERR = 2,
	AHCI_HFLAG_IGN_SERR_INTERNAL = 4,
	AHCI_HFLAG_32BIT_ONLY = 8,
	AHCI_HFLAG_MV_PATA = 16,
	AHCI_HFLAG_NO_MSI = 32,
	AHCI_HFLAG_NO_PMP = 64,
	AHCI_HFLAG_SECT255 = 256,
	AHCI_HFLAG_YES_NCQ = 512,
	AHCI_HFLAG_NO_SUSPEND = 1024,
	AHCI_HFLAG_SRST_TOUT_IS_OFFLINE = 2048,
	AHCI_HFLAG_NO_SNTF = 4096,
	AHCI_HFLAG_NO_FPDMA_AA = 8192,
	AHCI_HFLAG_YES_FBS = 16384,
	AHCI_HFLAG_DELAY_ENGINE = 32768,
	AHCI_HFLAG_NO_DEVSLP = 131072,
	AHCI_HFLAG_NO_FBS = 262144,
	AHCI_HFLAG_MULTI_MSI = 1048576,
	AHCI_HFLAG_WAKE_BEFORE_STOP = 4194304,
	AHCI_HFLAG_YES_ALPM = 8388608,
	AHCI_HFLAG_NO_WRITE_TO_RO = 16777216,
	AHCI_HFLAG_IS_MOBILE = 33554432,
	AHCI_FLAG_COMMON = 393346,
	ICH_MAP = 144,
	EM_MAX_SLOTS = 8,
	EM_MAX_RETRY = 5,
	EM_CTL_RST = 512,
	EM_CTL_TM = 256,
	EM_CTL_MR = 1,
	EM_CTL_ALHD = 67108864,
	EM_CTL_XMT = 33554432,
	EM_CTL_SMB = 16777216,
	EM_CTL_SGPIO = 524288,
	EM_CTL_SES = 262144,
	EM_CTL_SAFTE = 131072,
	EM_CTL_LED = 65536,
	EM_MSG_TYPE_LED = 1,
	EM_MSG_TYPE_SAFTE = 2,
	EM_MSG_TYPE_SES2 = 4,
	EM_MSG_TYPE_SGPIO = 8,
};

struct ahci_cmd_hdr {
	__le32 opts;
	__le32 status;
	__le32 tbl_addr;
	__le32 tbl_addr_hi;
	__le32 reserved[4];
};

struct ahci_em_priv {
	enum sw_activity blink_policy;
	struct timer_list timer;
	long unsigned int saved_activity;
	long unsigned int activity;
	long unsigned int led_state;
	struct ata_link___8 *link;
};

struct ahci_port_priv {
	struct ata_link___8 *active_link;
	struct ahci_cmd_hdr *cmd_slot;
	dma_addr_t cmd_slot_dma;
	void *cmd_tbl;
	dma_addr_t cmd_tbl_dma;
	void *rx_fis;
	dma_addr_t rx_fis_dma;
	unsigned int ncq_saw_d2h: 1;
	unsigned int ncq_saw_dmas: 1;
	unsigned int ncq_saw_sdb: 1;
	spinlock_t lock;
	u32 intr_mask;
	bool fbs_supported;
	bool fbs_enabled;
	int fbs_last_dev;
	struct ahci_em_priv em_priv[8];
	char *irq_desc;
};

struct ahci_host_priv {
	unsigned int flags;
	u32 force_port_map;
	u32 mask_port_map;
	void *mmio;
	u32 cap;
	u32 cap2;
	u32 version;
	u32 port_map;
	u32 saved_cap;
	u32 saved_cap2;
	u32 saved_port_map;
	u32 em_loc;
	u32 em_buf_sz;
	u32 em_msg_type;
	bool got_runtime_pm;
	struct clk *clks[5];
	struct regulator **target_pwrs;
	struct phy___6 **phys;
	unsigned int nports;
	void *plat_data;
	unsigned int irq;
	void (*start_engine)(struct ata_port___8 *);
	int (*stop_engine)(struct ata_port___8 *);
	irqreturn_t (*irq_handler)(int, void *);
	int (*get_irq_vector)(struct ata_host___8 *, int);
};

enum {
	AHCI_PCI_BAR_STA2X11 = 0,
	AHCI_PCI_BAR_CAVIUM = 0,
	AHCI_PCI_BAR_ENMOTUS = 2,
	AHCI_PCI_BAR_CAVIUM_GEN5 = 4,
	AHCI_PCI_BAR_STANDARD = 5,
};

enum board_ids {
	board_ahci = 0,
	board_ahci_ign_iferr = 1,
	board_ahci_mobile = 2,
	board_ahci_nomsi = 3,
	board_ahci_noncq = 4,
	board_ahci_nosntf = 5,
	board_ahci_yes_fbs = 6,
	board_ahci_avn = 7,
	board_ahci_mcp65 = 8,
	board_ahci_mcp77 = 9,
	board_ahci_mcp89 = 10,
	board_ahci_mv = 11,
	board_ahci_sb600 = 12,
	board_ahci_sb700 = 13,
	board_ahci_vt8251 = 14,
	board_ahci_mcp_linux = 8,
	board_ahci_mcp67 = 8,
	board_ahci_mcp73 = 8,
	board_ahci_mcp79 = 9,
};

struct module___301;

struct file___370;

struct kiocb___370;

struct poll_table_struct___223;

struct vm_area_struct___371;

struct inode___370;

struct file_lock___370;

struct page___371;

struct seq_file___314;

struct file_operations___370 {
	struct module___301 *owner;
	loff_t (*llseek)(struct file___370 *, loff_t, int);
	ssize_t (*read)(struct file___370 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___370 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___370 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___370 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___370 *, bool);
	int (*iterate)(struct file___370 *, struct dir_context *);
	int (*iterate_shared)(struct file___370 *, struct dir_context *);
	__poll_t (*poll)(struct file___370 *, struct poll_table_struct___223 *);
	long int (*unlocked_ioctl)(struct file___370 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___370 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___370 *, struct vm_area_struct___371 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___370 *, struct file___370 *);
	int (*flush)(struct file___370 *, fl_owner_t);
	int (*release)(struct inode___370 *, struct file___370 *);
	int (*fsync)(struct file___370 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___370 *, int);
	int (*lock)(struct file___370 *, int, struct file_lock___370 *);
	ssize_t (*sendpage)(struct file___370 *, struct page___371 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___370 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___370 *, int, struct file_lock___370 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___370 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___370 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___370 *, long int, struct file_lock___370 **, void **);
	long int (*fallocate)(struct file___370 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___314 *, struct file___370 *);
	ssize_t (*copy_file_range)(struct file___370 *, loff_t, struct file___370 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___370 *, loff_t, struct file___370 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___370 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___370 {
	u64 seqnum;
	struct vm_area_struct___371 *vmas[4];
};

struct page_frag___370 {
	struct page___371 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___370;

struct cred___341;

struct bio_list___187;

struct backing_dev_info___187;

struct io_context___107;

struct request_queue___103;

struct vm_struct___276;

struct task_struct___371 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___371 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___370 *mm;
	struct mm_struct___370 *active_mm;
	struct vmacache___370 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___371 *real_parent;
	struct task_struct___371 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___371 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___217 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___217 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___217 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___341 *ptracer_cred;
	const struct cred___341 *real_cred;
	const struct cred___341 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___371 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___187 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___187 *backing_dev_info;
	struct io_context___107 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___370 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___103 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___371 *oom_reaper_list;
	struct vm_struct___276 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___141 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___371 *pgtable_t___370;

struct address_space___369;

struct dev_pagemap___358;

struct page___371 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___369 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___371 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___370 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___370 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___358 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___370;

struct lruvec___370 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___370 *pgdat;
};

struct zone___370 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___370 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___370 {
	struct zone___370 *zone;
	int zone_idx;
};

struct zonelist___370 {
	struct zoneref___370 _zonerefs[25];
};

struct pglist_data___370 {
	struct zone___370 node_zones[3];
	struct zonelist___370 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___371 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___371 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___370 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___371 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___371 *owner;
};

struct secondary_data___371 {
	void *stack;
	struct task_struct___371 *task;
	long int status;
};

struct blocking_notifier_head___370 {
	struct rw_semaphore___371 rwsem;
	struct notifier_block *head;
};

struct dentry___369;

struct path___370 {
	struct vfsmount *mnt;
	struct dentry___369 *dentry;
};

struct file___370 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___370 f_path;
	struct inode___370 *f_inode;
	const struct file_operations___370 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___217 f_owner;
	const struct cred___341 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___369 *f_mapping;
	errseq_t f_wb_err;
};

struct key___341;

struct user_struct___341;

struct cred___341 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___341 *session_keyring;
	struct key___341 *process_keyring;
	struct key___341 *thread_keyring;
	struct key___341 *request_key_auth;
	void *security;
	struct user_struct___341 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___363;

struct kernfs_elem_dir___363 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___363 *root;
};

struct kernfs_node___364;

struct kernfs_syscall_ops___363;

struct kernfs_root___363 {
	struct kernfs_node___364 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___363 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___363 {
	struct kernfs_node___364 *target_kn;
};

struct kernfs_ops___363;

struct kernfs_elem_attr___363 {
	const struct kernfs_ops___363 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___364 *notify_next;
};

struct kernfs_node___364 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___364 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___363 dir;
		struct kernfs_elem_symlink___363 symlink;
		struct kernfs_elem_attr___363 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___363;

struct kernfs_ops___363 {
	int (*open)(struct kernfs_open_file___363 *);
	void (*release)(struct kernfs_open_file___363 *);
	int (*seq_show)(struct seq_file___314 *, void *);
	void * (*seq_start)(struct seq_file___314 *, loff_t *);
	void * (*seq_next)(struct seq_file___314 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___314 *, void *);
	ssize_t (*read)(struct kernfs_open_file___363 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___363 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___363 *, struct vm_area_struct___371 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___363 *, struct poll_table_struct___223 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___363 {
	int (*remount_fs)(struct kernfs_root___363 *, int *, char *);
	int (*show_options)(struct seq_file___314 *, struct kernfs_root___363 *);
	int (*mkdir)(struct kernfs_node___364 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___364 *);
	int (*rename)(struct kernfs_node___364 *, struct kernfs_node___364 *, const char *);
	int (*show_path)(struct seq_file___314 *, struct kernfs_node___364 *, struct kernfs_root___363 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___313;

struct seq_file___314 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___313 *op;
	int poll_event;
	const struct file___370 *file;
	void *private;
};

struct vm_operations_struct___358;

struct kernfs_open_file___363 {
	struct kernfs_node___364 *kn;
	struct file___370 *file;
	struct seq_file___314 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___358 *vm_ops;
};

struct vm_fault___358;

struct vm_operations_struct___358 {
	void (*open)(struct vm_area_struct___371 *);
	void (*close)(struct vm_area_struct___371 *);
	int (*split)(struct vm_area_struct___371 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___371 *);
	vm_fault_t (*fault)(struct vm_fault___358 *);
	vm_fault_t (*huge_fault)(struct vm_fault___358 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___358 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___371 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___358 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___358 *);
	int (*access)(struct vm_area_struct___371 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___371 *);
	int (*set_policy)(struct vm_area_struct___371 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___371 *, long unsigned int);
	struct page___371 * (*find_special_page)(struct vm_area_struct___371 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___229)(struct file___370 *, wait_queue_head_t *, struct poll_table_struct___223 *);

struct poll_table_struct___223 {
	poll_queue_proc___229 _qproc;
	__poll_t _key;
};

struct vm_area_struct___371 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___371 *vm_next;
	struct vm_area_struct___371 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___370 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___358 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___370 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___357;

struct bin_attribute___333;

struct attribute_group___334 {
	const char *name;
	umode_t (*is_visible)(struct kobject___357 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___357 *, struct bin_attribute___333 *, int);
	struct attribute **attrs;
	struct bin_attribute___333 **bin_attrs;
};

struct kset___356;

struct kobj_type___356;

struct kobject___357 {
	const char *name;
	struct list_head entry;
	struct kobject___357 *parent;
	struct kset___356 *kset;
	struct kobj_type___356 *ktype;
	struct kernfs_node___364 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___333 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___370 *, struct kobject___357 *, struct bin_attribute___333 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___370 *, struct kobject___357 *, struct bin_attribute___333 *, char *, loff_t, size_t);
	int (*mmap)(struct file___370 *, struct kobject___357 *, struct bin_attribute___333 *, struct vm_area_struct___371 *);
};

struct sysfs_ops___356 {
	ssize_t (*show)(struct kobject___357 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___357 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___356;

struct kset___356 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___357 kobj;
	const struct kset_uevent_ops___356 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___356 {
	void (*release)(struct kobject___357 *);
	const struct sysfs_ops___356 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___28 * (*child_ns_type)(struct kobject___357 *);
	const void * (*namespace)(struct kobject___357 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___356 {
	int (* const filter)(struct kset___356 *, struct kobject___357 *);
	const char * (* const name)(struct kset___356 *, struct kobject___357 *);
	int (* const uevent)(struct kset___356 *, struct kobject___357 *, struct kobj_uevent_env *);
};

struct kobj_attribute___348 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___357 *, struct kobj_attribute___348 *, char *);
	ssize_t (*store)(struct kobject___357 *, struct kobj_attribute___348 *, const char *, size_t);
};

struct kernel_param___298;

struct kernel_param_ops___298 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___298 *);
	int (*get)(char *, const struct kernel_param___298 *);
	void (*free)(void *);
};

struct kparam_array___298;

struct kernel_param___298 {
	const char *name;
	struct module___301 *mod;
	const struct kernel_param_ops___298 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___298 *arr;
	};
};

struct kparam_array___298 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___298 *ops;
	void *elem;
};

struct module_kobject___298 {
	struct kobject___357 kobj;
	struct module___301 *mod;
	struct kobject___357 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___298 {
	struct module___301 *mod;
	struct latch_tree_node node;
};

struct module_layout___298 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___298 mtn;
};

struct module_attribute___298;

struct module___301 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___298 mkobj;
	struct module_attribute___298 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___357 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___298 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___298 core_layout;
	struct module_layout___298 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___298 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___298 *, struct module_kobject___298 *, char *);
	ssize_t (*store)(struct module_attribute___298 *, struct module_kobject___298 *, const char *, size_t);
	void (*setup)(struct module___301 *, const char *);
	int (*test)(struct module___301 *);
	void (*free)(struct module___301 *);
};

struct user_struct___341 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___341 *uid_keyring;
	struct key___341 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___370;

struct mm_struct___370 {
	struct {
		struct vm_area_struct___371 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___370 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___371 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___370 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___371 *owner;
		struct user_namespace___3 *user_ns;
		struct file___370 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___370 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct bio___187;

struct bio_list___187 {
	struct bio___187 *head;
	struct bio___187 *tail;
};

struct bdi_writeback_congested___187;

struct bdi_writeback___187 {
	struct backing_dev_info___187 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___187 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___157 *memcg_css;
	struct cgroup_subsys_state___157 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___337;

struct backing_dev_info___187 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___187 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___337 *dev;
	struct device___337 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___369 *debug_dir;
	struct dentry___369 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___107;

struct io_context___107 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___107 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

typedef blk_qc_t make_request_fn___103(struct request_queue___103 *, struct bio___187 *);

struct request___103;

typedef int dma_drain_needed_fn___103(struct request___103 *);

struct bsg_ops___103;

struct bsg_class_device___103 {
	struct device___337 *class_dev;
	int minor;
	struct request_queue___103 *queue;
	const struct bsg_ops___103 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___187 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___187 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___103;

struct blk_mq_ops___40;

struct blk_mq_hw_ctx___40;

struct blk_mq_tag_set___40;

struct request_queue___103 {
	struct list_head queue_head;
	struct request___103 *last_merge;
	struct elevator_queue___103 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___103 *make_request_fn;
	dma_drain_needed_fn___103 *dma_drain_needed;
	const struct blk_mq_ops___40 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___40 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___187 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___357 kobj;
	struct kobject___357 *mq_kobj;
	struct blk_integrity integrity;
	struct device___337 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	struct bsg_class_device___103 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set___40 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___187 bio_split;
	struct dentry___369 *debugfs_dir;
	struct dentry___369 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___276 {
	struct vm_struct___276 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___371 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bio_vec___189 {
	struct page___371 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

typedef void bio_end_io_t___187(struct bio___187 *);

struct gendisk___107;

struct bio_integrity_payload___187;

struct bio___187 {
	struct bio___187 *bi_next;
	struct gendisk___107 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___187 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___187 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___189 *bi_io_vec;
	struct bio_set___187 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___189 bi_inline_vecs[0];
};

struct bio_integrity_payload___187 {
	struct bio___187 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___189 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___189 bip_inline_vecs[0];
};

struct dev_pm_info___337 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___5 *subsys_data;
	void (*set_latency_tolerance)(struct device___337 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___337;

struct bus_type___337;

struct device_driver___337;

struct dev_pm_domain___337;

struct dma_map_ops___125;

struct device_node___82;

struct fwnode_handle___259;

struct class___337;

struct device___337 {
	struct device___337 *parent;
	struct device_private *p;
	struct kobject___357 kobj;
	const char *init_name;
	const struct device_type___337 *type;
	struct mutex mutex;
	struct bus_type___337 *bus;
	struct device_driver___337 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___337 power;
	struct dev_pm_domain___337 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___125 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___82 *of_node;
	struct fwnode_handle___259 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___337 *class;
	const struct attribute_group___334 **groups;
	void (*release)(struct device___337 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___107 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___337 __dev;
	struct kobject___357 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___107;

struct block_device_operations___104;

struct gendisk___107 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___107 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___107 *part_tbl;
	struct hd_struct___107 part0;
	const struct block_device_operations___104 *fops;
	struct request_queue___103 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___371 lookup_sem;
	struct kobject___357 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___357 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_ops___337;

struct device_type___337 {
	const char *name;
	const struct attribute_group___334 **groups;
	int (*uevent)(struct device___337 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___337 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___337 *);
	const struct dev_pm_ops___337 *pm;
};

struct class___337 {
	const char *name;
	struct module___301 *owner;
	const struct attribute_group___334 **class_groups;
	const struct attribute_group___334 **dev_groups;
	struct kobject___357 *dev_kobj;
	int (*dev_uevent)(struct device___337 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___337 *, umode_t *);
	void (*class_release)(struct class___337 *);
	void (*dev_release)(struct device___337 *);
	int (*shutdown_pre)(struct device___337 *);
	const struct kobj_ns_type_operations___28 *ns_type;
	const void * (*namespace)(struct device___337 *);
	const struct dev_pm_ops___337 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dev_pm_ops___337 {
	int (*prepare)(struct device___337 *);
	void (*complete)(struct device___337 *);
	int (*suspend)(struct device___337 *);
	int (*resume)(struct device___337 *);
	int (*freeze)(struct device___337 *);
	int (*thaw)(struct device___337 *);
	int (*poweroff)(struct device___337 *);
	int (*restore)(struct device___337 *);
	int (*suspend_late)(struct device___337 *);
	int (*resume_early)(struct device___337 *);
	int (*freeze_late)(struct device___337 *);
	int (*thaw_early)(struct device___337 *);
	int (*poweroff_late)(struct device___337 *);
	int (*restore_early)(struct device___337 *);
	int (*suspend_noirq)(struct device___337 *);
	int (*resume_noirq)(struct device___337 *);
	int (*freeze_noirq)(struct device___337 *);
	int (*thaw_noirq)(struct device___337 *);
	int (*poweroff_noirq)(struct device___337 *);
	int (*restore_noirq)(struct device___337 *);
	int (*runtime_suspend)(struct device___337 *);
	int (*runtime_resume)(struct device___337 *);
	int (*runtime_idle)(struct device___337 *);
};

struct dev_pm_domain___337 {
	struct dev_pm_ops___337 ops;
	void (*detach)(struct device___337 *, bool);
	int (*activate)(struct device___337 *);
	void (*sync)(struct device___337 *);
	void (*dismiss)(struct device___337 *);
};

struct bus_type___337 {
	const char *name;
	const char *dev_name;
	struct device___337 *dev_root;
	const struct attribute_group___334 **bus_groups;
	const struct attribute_group___334 **dev_groups;
	const struct attribute_group___334 **drv_groups;
	int (*match)(struct device___337 *, struct device_driver___337 *);
	int (*uevent)(struct device___337 *, struct kobj_uevent_env *);
	int (*probe)(struct device___337 *);
	int (*remove)(struct device___337 *);
	void (*shutdown)(struct device___337 *);
	int (*online)(struct device___337 *);
	int (*offline)(struct device___337 *);
	int (*suspend)(struct device___337 *, pm_message_t);
	int (*resume)(struct device___337 *);
	int (*num_vf)(struct device___337 *);
	int (*dma_configure)(struct device___337 *);
	const struct dev_pm_ops___337 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___337 {
	const char *name;
	struct bus_type___337 *bus;
	struct module___301 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___337 *);
	int (*remove)(struct device___337 *);
	void (*shutdown)(struct device___337 *);
	int (*suspend)(struct device___337 *, pm_message_t);
	int (*resume)(struct device___337 *);
	const struct attribute_group___334 **groups;
	const struct dev_pm_ops___337 *pm;
	void (*coredump)(struct device___337 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_attribute___49 {
	struct attribute attr;
	ssize_t (*show)(struct device___337 *, struct device_attribute___49 *, char *);
	ssize_t (*store)(struct device___337 *, struct device_attribute___49 *, const char *, size_t);
};

struct dma_map_ops___125 {
	void * (*alloc)(struct device___337 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___337 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___337 *, struct vm_area_struct___371 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___337 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___337 *, struct page___371 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___337 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___337 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___337 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___337 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___337 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___337 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide42;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___337 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___337 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___337 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___337 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___337 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___337 *, u64);
	u64 (*get_required_mask)(struct device___337 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___259;

struct fwnode_handle___259 {
	struct fwnode_handle___259 *secondary;
	const struct fwnode_operations___259 *ops;
};

struct property___78;

struct device_node___82 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___259 fwnode;
	struct property___78 *properties;
	struct property___78 *deadprops;
	struct device_node___82 *parent;
	struct device_node___82 *child;
	struct device_node___82 *sibling;
	struct kobject___357 kobj;
	long unsigned int _flags;
	void *data;
};

struct dentry_operations___369;

struct super_block___369;

struct dentry___369 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___369 *d_parent;
	struct qstr d_name;
	struct inode___370 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___369 *d_op;
	struct super_block___369 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___369;

struct address_space___369 {
	struct inode___370 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___371 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___369 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___369;

struct block_device___369;

struct cdev___89;

struct inode___370 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___369 *i_op;
	struct super_block___369 *i_sb;
	struct address_space___369 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___371 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___187 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___370 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___369 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___369 *i_bdev;
		struct cdev___89 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___369 {
	int (*d_revalidate)(struct dentry___369 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___369 *, unsigned int);
	int (*d_hash)(const struct dentry___369 *, struct qstr *);
	int (*d_compare)(const struct dentry___369 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___369 *);
	int (*d_init)(struct dentry___369 *);
	void (*d_release)(struct dentry___369 *);
	void (*d_prune)(struct dentry___369 *);
	void (*d_iput)(struct dentry___369 *, struct inode___370 *);
	char * (*d_dname)(struct dentry___369 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___370 *);
	int (*d_manage)(const struct path___370 *, bool);
	struct dentry___369 * (*d_real)(struct dentry___369 *, const struct inode___370 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___369;

struct mem_dqinfo___369 {
	struct quota_format_type___369 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___369;

struct quota_info___369 {
	unsigned int flags;
	struct rw_semaphore___371 dqio_sem;
	struct inode___370 *files[3];
	struct mem_dqinfo___369 info[3];
	const struct quota_format_ops___369 *ops[3];
};

struct rcuwait___369 {
	struct task_struct___371 *task;
};

struct percpu_rw_semaphore___369 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___371 rw_sem;
	struct rcuwait___369 writer;
	int readers_block;
};

struct sb_writers___369 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___369 rw_sem[3];
};

struct file_system_type___369;

struct super_operations___369;

struct dquot_operations___369;

struct quotactl_ops___369;

struct super_block___369 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___369 *s_type;
	const struct super_operations___369 *s_op;
	const struct dquot_operations___369 *dq_op;
	const struct quotactl_ops___369 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___369 *s_root;
	struct rw_semaphore___371 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___369 *s_bdev;
	struct backing_dev_info___187 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___369 s_dquot;
	struct sb_writers___369 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___369 *s_d_op;
	int cleancache_poolid;
	struct shrinker___133 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

typedef int (*dev_page_fault_t___358)(struct vm_area_struct___371 *, long unsigned int, const struct page___371 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___358)(struct page___371 *, void *);

struct dev_pagemap___358 {
	dev_page_fault_t___358 page_fault;
	dev_page_free_t___358 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___337 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___370 {
	struct task_struct___371 *task;
	struct core_thread___370 *next;
};

struct core_state___370 {
	atomic_t nr_threads;
	struct core_thread___370 dumper;
	struct completion startup;
};

struct vm_fault___358 {
	struct vm_area_struct___371 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___371 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___371 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___370 prealloc_pte;
};

struct io_cq___107 {
	struct request_queue___103 *q;
	struct io_context___107 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___370 {
	struct file___370 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___370 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___369 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___370 *ia_file;
};

struct dquot___369 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___369 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___369 {
	int qf_fmt_id;
	const struct quota_format_ops___369 *qf_ops;
	struct module___301 *qf_owner;
	struct quota_format_type___369 *qf_next;
};

struct quota_format_ops___369 {
	int (*check_quota_file)(struct super_block___369 *, int);
	int (*read_file_info)(struct super_block___369 *, int);
	int (*write_file_info)(struct super_block___369 *, int);
	int (*free_file_info)(struct super_block___369 *, int);
	int (*read_dqblk)(struct dquot___369 *);
	int (*commit_dqblk)(struct dquot___369 *);
	int (*release_dqblk)(struct dquot___369 *);
	int (*get_next_id)(struct super_block___369 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___369 {
	int (*write_dquot)(struct dquot___369 *);
	struct dquot___369 * (*alloc_dquot)(struct super_block___369 *, int);
	void (*destroy_dquot)(struct dquot___369 *);
	int (*acquire_dquot)(struct dquot___369 *);
	int (*release_dquot)(struct dquot___369 *);
	int (*mark_dirty)(struct dquot___369 *);
	int (*write_info)(struct super_block___369 *, int);
	qsize_t * (*get_reserved_space)(struct inode___370 *);
	int (*get_projid)(struct inode___370 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___370 *, qsize_t *);
	int (*get_next_id)(struct super_block___369 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___369 {
	int (*quota_on)(struct super_block___369 *, int, int, const struct path___370 *);
	int (*quota_off)(struct super_block___369 *, int);
	int (*quota_enable)(struct super_block___369 *, unsigned int);
	int (*quota_disable)(struct super_block___369 *, unsigned int);
	int (*quota_sync)(struct super_block___369 *, int);
	int (*set_info)(struct super_block___369 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___369 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___369 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___369 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___369 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___369 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___369 {
	int (*writepage)(struct page___371 *, struct writeback_control___3 *);
	int (*readpage)(struct file___370 *, struct page___371 *);
	int (*writepages)(struct address_space___369 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___371 *);
	int (*readpages)(struct file___370 *, struct address_space___369 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___370 *, struct address_space___369 *, loff_t, unsigned int, unsigned int, struct page___371 **, void **);
	int (*write_end)(struct file___370 *, struct address_space___369 *, loff_t, unsigned int, unsigned int, struct page___371 *, void *);
	sector_t (*bmap)(struct address_space___369 *, sector_t);
	void (*invalidatepage)(struct page___371 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___371 *, gfp_t);
	void (*freepage)(struct page___371 *);
	ssize_t (*direct_IO)(struct kiocb___370 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___369 *, struct page___371 *, struct page___371 *, enum migrate_mode);
	bool (*isolate_page)(struct page___371 *, isolate_mode_t);
	void (*putback_page)(struct page___371 *);
	int (*launder_page)(struct page___371 *);
	int (*is_partially_uptodate)(struct page___371 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___371 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___369 *, struct page___371 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___370 *, sector_t *);
	void (*swap_deactivate)(struct file___370 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___369 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___370 *bd_inode;
	struct super_block___369 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___369 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___107 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___107 *bd_disk;
	struct request_queue___103 *bd_queue;
	struct backing_dev_info___187 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___89 {
	struct kobject___357 kobj;
	struct module___301 *owner;
	const struct file_operations___370 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___369 {
	struct dentry___369 * (*lookup)(struct inode___370 *, struct dentry___369 *, unsigned int);
	const char * (*get_link)(struct dentry___369 *, struct inode___370 *, struct delayed_call *);
	int (*permission)(struct inode___370 *, int);
	struct posix_acl * (*get_acl)(struct inode___370 *, int);
	int (*readlink)(struct dentry___369 *, char *, int);
	int (*create)(struct inode___370 *, struct dentry___369 *, umode_t, bool);
	int (*link)(struct dentry___369 *, struct inode___370 *, struct dentry___369 *);
	int (*unlink)(struct inode___370 *, struct dentry___369 *);
	int (*symlink)(struct inode___370 *, struct dentry___369 *, const char *);
	int (*mkdir)(struct inode___370 *, struct dentry___369 *, umode_t);
	int (*rmdir)(struct inode___370 *, struct dentry___369 *);
	int (*mknod)(struct inode___370 *, struct dentry___369 *, umode_t, dev_t);
	int (*rename)(struct inode___370 *, struct dentry___369 *, struct inode___370 *, struct dentry___369 *, unsigned int);
	int (*setattr)(struct dentry___369 *, struct iattr___369 *);
	int (*getattr)(const struct path___370 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___369 *, char *, size_t);
	int (*fiemap)(struct inode___370 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___370 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___370 *, struct dentry___369 *, struct file___370 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___370 *, struct dentry___369 *, umode_t);
	int (*set_acl)(struct inode___370 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___369 {
	void (*fl_copy_lock)(struct file_lock___370 *, struct file_lock___370 *);
	void (*fl_release_private)(struct file_lock___370 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___369;

struct lock_manager_operations___369;

struct file_lock___370 {
	struct file_lock___370 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___370 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___369 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___369 *fl_ops;
	const struct lock_manager_operations___369 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___369 {
	int (*lm_compare_owner)(struct file_lock___370 *, struct file_lock___370 *);
	long unsigned int (*lm_owner_key)(struct file_lock___370 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___370 *);
	int (*lm_grant)(struct file_lock___370 *, int);
	bool (*lm_break)(struct file_lock___370 *);
	int (*lm_change)(struct file_lock___370 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___370 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___369 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___369 *fa_next;
	struct file___370 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___369 {
	const char *name;
	int fs_flags;
	struct dentry___369 * (*mount)(struct file_system_type___369 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___369 *);
	struct module___301 *owner;
	struct file_system_type___369 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___369 {
	struct inode___370 * (*alloc_inode)(struct super_block___369 *);
	void (*destroy_inode)(struct inode___370 *);
	void (*dirty_inode)(struct inode___370 *, int);
	int (*write_inode)(struct inode___370 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___370 *);
	void (*evict_inode)(struct inode___370 *);
	void (*put_super)(struct super_block___369 *);
	int (*sync_fs)(struct super_block___369 *, int);
	int (*freeze_super)(struct super_block___369 *);
	int (*freeze_fs)(struct super_block___369 *);
	int (*thaw_super)(struct super_block___369 *);
	int (*unfreeze_fs)(struct super_block___369 *);
	int (*statfs)(struct dentry___369 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___369 *, int *, char *);
	void (*umount_begin)(struct super_block___369 *);
	int (*show_options)(struct seq_file___314 *, struct dentry___369 *);
	int (*show_devname)(struct seq_file___314 *, struct dentry___369 *);
	int (*show_path)(struct seq_file___314 *, struct dentry___369 *);
	int (*show_stats)(struct seq_file___314 *, struct dentry___369 *);
	ssize_t (*quota_read)(struct super_block___369 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___369 *, int, const char *, size_t, loff_t);
	struct dquot___369 ** (*get_dquots)(struct inode___370 *);
	int (*bdev_try_to_free_page)(struct super_block___369 *, struct page___371 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___369 *, struct shrink_control___133 *);
	long int (*free_cached_objects)(struct super_block___369 *, struct shrink_control___133 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___107 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___107 *last_lookup;
	struct hd_struct___107 *part[0];
};

struct block_device_operations___104 {
	int (*open)(struct block_device___369 *, fmode_t);
	void (*release)(struct gendisk___107 *, fmode_t);
	int (*rw_page)(struct block_device___369 *, sector_t, struct page___371 *, unsigned int);
	int (*ioctl)(struct block_device___369 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___369 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___107 *, unsigned int);
	int (*media_changed)(struct gendisk___107 *);
	void (*unlock_native_capacity)(struct gendisk___107 *);
	int (*revalidate_disk)(struct gendisk___107 *);
	int (*getgeo)(struct block_device___369 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___369 *, long unsigned int);
	int (*report_zones)(struct gendisk___107 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___301 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___358(struct page___371 *);

struct bdi_writeback_congested___187 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___187 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bsg_ops___103 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___103 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___103 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___103 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___103(struct request___103 *, blk_status_t);

struct request___103 {
	struct request_queue___103 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___40 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___187 *bio;
	struct bio___187 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___189 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___107 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___103 *saved_end_io;
		} flush;
	};
	struct gendisk___107 *rq_disk;
	struct hd_struct___107 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___103 *end_io;
	void *end_io_data;
	struct request___103 *next_rq;
};

struct fwnode_reference_args___259;

struct fwnode_endpoint___259;

struct fwnode_operations___259 {
	struct fwnode_handle___259 * (*get)(struct fwnode_handle___259 *);
	void (*put)(struct fwnode_handle___259 *);
	bool (*device_is_available)(const struct fwnode_handle___259 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___259 *, const struct device___337 *);
	bool (*property_present)(const struct fwnode_handle___259 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___259 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___259 *, const char *, const char **, size_t);
	struct fwnode_handle___259 * (*get_parent)(const struct fwnode_handle___259 *);
	struct fwnode_handle___259 * (*get_next_child_node)(const struct fwnode_handle___259 *, struct fwnode_handle___259 *);
	struct fwnode_handle___259 * (*get_named_child_node)(const struct fwnode_handle___259 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___259 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___259 *);
	struct fwnode_handle___259 * (*graph_get_next_endpoint)(const struct fwnode_handle___259 *, struct fwnode_handle___259 *);
	struct fwnode_handle___259 * (*graph_get_remote_endpoint)(const struct fwnode_handle___259 *);
	struct fwnode_handle___259 * (*graph_get_port_parent)(struct fwnode_handle___259 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___259 *, struct fwnode_endpoint___259 *);
};

struct fwnode_endpoint___259 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___259 *local_fwnode;
};

struct fwnode_reference_args___259 {
	struct fwnode_handle___259 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct blk_mq_hw_ctx___40 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___103 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags___4 *tags;
	struct blk_mq_tags___4 *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	unsigned int rh_reserved_nr_expired;
	struct hlist_node cpuhp_dead;
	struct kobject___357 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___369 *debugfs_dir;
	struct dentry___369 *sched_debugfs_dir;
	struct list_head hctx_list;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___103;

struct elevator_mq_ops___103 {
	int (*init_sched)(struct request_queue___103 *, struct elevator_type___103 *);
	void (*exit_sched)(struct elevator_queue___103 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___40 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___40 *, unsigned int);
	bool (*allow_merge)(struct request_queue___103 *, struct request___103 *, struct bio___187 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx___40 *, struct bio___187 *);
	int (*request_merge)(struct request_queue___103 *, struct request___103 **, struct bio___187 *);
	void (*request_merged)(struct request_queue___103 *, struct request___103 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___103 *, struct request___103 *, struct request___103 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___103 *, struct bio___187 *);
	void (*finish_request)(struct request___103 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___40 *, struct list_head *, bool);
	struct request___103 * (*dispatch_request)(struct blk_mq_hw_ctx___40 *);
	bool (*has_work)(struct blk_mq_hw_ctx___40 *);
	void (*completed_request)(struct request___103 *, u64);
	void (*started_request)(struct request___103 *);
	void (*requeue_request)(struct request___103 *);
	struct request___103 * (*former_request)(struct request_queue___103 *, struct request___103 *);
	struct request___103 * (*next_request)(struct request_queue___103 *, struct request___103 *);
	void (*init_icq)(struct io_cq___107 *);
	void (*exit_icq)(struct io_cq___107 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx___40 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___103;

struct elevator_type___103 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___103 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___103 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___301 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___103 {
	struct elevator_type___103 *type;
	void *elevator_data;
	struct kobject___357 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___103 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___103 *, char *);
	ssize_t (*store)(struct elevator_queue___103 *, const char *, size_t);
};

struct blk_mq_queue_data___40;

typedef blk_status_t queue_rq_fn___40(struct blk_mq_hw_ctx___40 *, const struct blk_mq_queue_data___40 *);

typedef void commit_rqs_fn___40(struct blk_mq_hw_ctx___40 *);

typedef bool get_budget_fn___40(struct blk_mq_hw_ctx___40 *);

typedef void put_budget_fn___40(struct blk_mq_hw_ctx___40 *);

typedef enum blk_eh_timer_return timeout_fn___40(struct request___103 *, bool);

typedef int poll_fn___40(struct blk_mq_hw_ctx___40 *);

typedef void complete_fn___40(struct request___103 *);

typedef int init_hctx_fn___40(struct blk_mq_hw_ctx___40 *, void *, unsigned int);

typedef void exit_hctx_fn___40(struct blk_mq_hw_ctx___40 *, unsigned int);

typedef int init_request_fn___40(struct blk_mq_tag_set___40 *, struct request___103 *, unsigned int, unsigned int);

typedef void exit_request_fn___40(struct blk_mq_tag_set___40 *, struct request___103 *, unsigned int);

typedef bool busy_fn___40(struct request_queue___103 *);

typedef int map_queues_fn___40(struct blk_mq_tag_set___40 *);

typedef void cleanup_rq_fn___40(struct request___103 *);

struct blk_mq_ops___40 {
	queue_rq_fn___40 *queue_rq;
	commit_rqs_fn___40 *commit_rqs;
	get_budget_fn___40 *get_budget;
	put_budget_fn___40 *put_budget;
	timeout_fn___40 *timeout;
	poll_fn___40 *poll;
	complete_fn___40 *complete;
	init_hctx_fn___40 *init_hctx;
	exit_hctx_fn___40 *exit_hctx;
	init_request_fn___40 *init_request;
	exit_request_fn___40 *exit_request;
	void (*initialize_rq_fn)(struct request___103 *);
	busy_fn___40 *busy;
	map_queues_fn___40 *map_queues;
	void (*show_rq)(struct seq_file___314 *, struct request___103 *);
	union {
		cleanup_rq_fn___40 *cleanup_rq;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide47;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct blk_mq_tag_set___40 {
	struct blk_mq_queue_map map[6];
	unsigned int nr_maps;
	const struct blk_mq_ops___40 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	struct blk_mq_tags___4 **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef int (*key_restrict_link_func_t___342)(struct key___341 *, const struct key_type *, const union key_payload *, struct key___341 *);

struct key_restriction___341;

struct key___341 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___371 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___341 *restrict_link;
};

struct key_restriction___341 {
	key_restrict_link_func_t___342 check;
	struct key___341 *key;
	struct key_type *keytype;
};

struct seq_operations___313 {
	void * (*start)(struct seq_file___314 *, loff_t *);
	void (*stop)(struct seq_file___314 *, void *);
	void * (*next)(struct seq_file___314 *, void *, loff_t *);
	int (*show)(struct seq_file___314 *, void *);
};

struct blk_mq_queue_data___40 {
	struct request___103 *rq;
	bool last;
	long unsigned int rh_reserved1;
};

struct Scsi_Host___16;

struct scsi_device___18;

struct scsi_cmnd___12;

struct scsi_target___18;

struct scsi_host_template___16 {
	struct module___301 *module;
	const char *name;
	const char * (*info)(struct Scsi_Host___16 *);
	int (*ioctl)(struct scsi_device___18 *, int, void *);
	int (*queuecommand)(struct Scsi_Host___16 *, struct scsi_cmnd___12 *);
	int (*eh_abort_handler)(struct scsi_cmnd___12 *);
	int (*eh_device_reset_handler)(struct scsi_cmnd___12 *);
	int (*eh_target_reset_handler)(struct scsi_cmnd___12 *);
	int (*eh_bus_reset_handler)(struct scsi_cmnd___12 *);
	int (*eh_host_reset_handler)(struct scsi_cmnd___12 *);
	int (*slave_alloc)(struct scsi_device___18 *);
	int (*slave_configure)(struct scsi_device___18 *);
	void (*slave_destroy)(struct scsi_device___18 *);
	int (*target_alloc)(struct scsi_target___18 *);
	void (*target_destroy)(struct scsi_target___18 *);
	int (*scan_finished)(struct Scsi_Host___16 *, long unsigned int);
	void (*scan_start)(struct Scsi_Host___16 *);
	int (*change_queue_depth)(struct scsi_device___18 *, int);
	int (*map_queues)(struct Scsi_Host___16 *);
	int (*bios_param)(struct scsi_device___18 *, struct block_device___369 *, sector_t, int *);
	void (*unlock_native_capacity)(struct scsi_device___18 *);
	int (*show_info)(struct seq_file___314 *, struct Scsi_Host___16 *);
	int (*write_info)(struct Scsi_Host___16 *, char *, int);
	enum blk_eh_timer_return (*eh_timed_out)(struct scsi_cmnd___12 *);
	int (*host_reset)(struct Scsi_Host___16 *, int);
	const char *proc_name;
	struct proc_dir_entry *proc_dir;
	int can_queue;
	int this_id;
	short unsigned int sg_tablesize;
	short unsigned int sg_prot_tablesize;
	unsigned int max_sectors;
	long unsigned int dma_boundary;
	short int cmd_per_lun;
	unsigned char present;
	int tag_alloc_policy;
	unsigned int track_queue_depth: 1;
	unsigned int supported_mode: 2;
	unsigned int unchecked_isa_dma: 1;
	unsigned int use_clustering: 1;
	unsigned int emulated: 1;
	unsigned int skip_settle_delay: 1;
	unsigned int no_write_same: 1;
	unsigned int force_blk_mq: 1;
	unsigned int max_host_blocked;
	struct device_attribute___49 **shost_attrs;
	struct device_attribute___49 **sdev_attrs;
	const struct attribute_group___334 **sdev_groups;
	u64 vendor_id;
	unsigned int cmd_size;
	struct scsi_host_cmd_pool *cmd_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct Scsi_Host___16 {
	struct list_head __devices;
	struct list_head __targets;
	struct list_head starved_list;
	spinlock_t default_lock;
	spinlock_t *host_lock;
	struct mutex scan_mutex;
	struct list_head eh_cmd_q;
	struct task_struct___371 *ehandler;
	struct completion *eh_action;
	wait_queue_head_t host_wait;
	struct scsi_host_template___16 *hostt;
	struct scsi_transport_template *transportt;
	struct blk_mq_tag_set___40 tag_set;
	atomic_t host_busy;
	atomic_t host_blocked;
	unsigned int host_failed;
	unsigned int host_eh_scheduled;
	unsigned int host_no;
	int eh_deadline;
	long unsigned int last_reset;
	unsigned int max_channel;
	unsigned int max_id;
	u64 max_lun;
	unsigned int unique_id;
	short unsigned int max_cmd_len;
	int this_id;
	int can_queue;
	short int cmd_per_lun;
	short unsigned int sg_tablesize;
	short unsigned int sg_prot_tablesize;
	unsigned int max_sectors;
	long unsigned int dma_boundary;
	unsigned int nr_hw_queues;
	long unsigned int cmd_serial_number;
	unsigned int active_mode: 2;
	unsigned int unchecked_isa_dma: 1;
	unsigned int use_clustering: 1;
	unsigned int host_self_blocked: 1;
	unsigned int reverse_ordering: 1;
	unsigned int tmf_in_progress: 1;
	unsigned int async_scan: 1;
	unsigned int eh_noresume: 1;
	unsigned int no_write_same: 1;
	unsigned int use_cmd_list: 1;
	unsigned int short_inquiry: 1;
	char work_q_name[20];
	struct workqueue_struct *work_q;
	struct workqueue_struct *tmf_work_q;
	unsigned int no_scsi2_lun_in_cdb: 1;
	unsigned int max_host_blocked;
	unsigned int prot_capabilities;
	unsigned char prot_guard_type;
	long unsigned int base;
	long unsigned int io_port;
	unsigned char n_io_port;
	unsigned char dma_channel;
	unsigned int irq;
	enum scsi_host_state shost_state;
	struct device___337 shost_gendev;
	struct device___337 shost_dev;
	void *shost_data;
	struct device___337 *dma_dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int hostdata[0];
};

struct scsi_device___18 {
	struct Scsi_Host___16 *host;
	struct request_queue___103 *request_queue;
	struct list_head siblings;
	struct list_head same_target_siblings;
	atomic_t device_busy;
	atomic_t device_blocked;
	spinlock_t list_lock;
	struct list_head cmd_list;
	struct list_head starved_entry;
	short unsigned int queue_depth;
	short unsigned int max_queue_depth;
	short unsigned int last_queue_full_depth;
	short unsigned int last_queue_full_count;
	long unsigned int last_queue_full_time;
	long unsigned int queue_ramp_up_period;
	long unsigned int last_queue_ramp_up;
	unsigned int id;
	unsigned int channel;
	u64 lun;
	unsigned int manufacturer;
	unsigned int sector_size;
	void *hostdata;
	unsigned char type;
	char scsi_level;
	char inq_periph_qual;
	struct mutex inquiry_mutex;
	unsigned char inquiry_len;
	unsigned char *inquiry;
	const char *vendor;
	const char *model;
	const char *rev;
	struct scsi_vpd *vpd_pg83;
	struct scsi_vpd *vpd_pg80;
	unsigned char current_tag;
	struct scsi_target___18 *sdev_target;
	blist_flags_t sdev_bflags;
	unsigned int eh_timeout;
	unsigned int removable: 1;
	unsigned int changed: 1;
	unsigned int busy: 1;
	unsigned int lockable: 1;
	unsigned int locked: 1;
	unsigned int borken: 1;
	unsigned int disconnect: 1;
	unsigned int soft_reset: 1;
	unsigned int sdtr: 1;
	unsigned int wdtr: 1;
	unsigned int ppr: 1;
	unsigned int tagged_supported: 1;
	unsigned int simple_tags: 1;
	unsigned int was_reset: 1;
	unsigned int expecting_cc_ua: 1;
	unsigned int use_10_for_rw: 1;
	unsigned int use_10_for_ms: 1;
	unsigned int no_report_opcodes: 1;
	unsigned int no_write_same: 1;
	unsigned int use_16_for_rw: 1;
	unsigned int skip_ms_page_8: 1;
	unsigned int skip_ms_page_3f: 1;
	unsigned int skip_vpd_pages: 1;
	unsigned int try_vpd_pages: 1;
	unsigned int use_192_bytes_for_3f: 1;
	unsigned int no_start_on_add: 1;
	unsigned int allow_restart: 1;
	unsigned int manage_start_stop: 1;
	unsigned int start_stop_pwr_cond: 1;
	unsigned int no_uld_attach: 1;
	unsigned int select_no_atn: 1;
	unsigned int fix_capacity: 1;
	unsigned int guess_capacity: 1;
	unsigned int retry_hwerror: 1;
	unsigned int last_sector_bug: 1;
	unsigned int no_read_disc_info: 1;
	unsigned int no_read_capacity_16: 1;
	unsigned int try_rc_10_first: 1;
	unsigned int security_supported: 1;
	unsigned int is_visible: 1;
	unsigned int wce_default_on: 1;
	unsigned int no_dif: 1;
	unsigned int broken_fua: 1;
	unsigned int lun_in_cdb: 1;
	unsigned int unmap_limit_for_ws: 1;
	atomic_t disk_events_disable_depth;
	long unsigned int supported_events[1];
	long unsigned int pending_events[1];
	struct list_head event_list;
	struct work_struct event_work;
	unsigned int max_device_blocked;
	atomic_t iorequest_cnt;
	atomic_t iodone_cnt;
	atomic_t ioerr_cnt;
	struct device___337 sdev_gendev;
	struct device___337 sdev_dev;
	struct execute_work ew;
	struct work_struct requeue_work;
	struct scsi_device_handler *handler;
	void *handler_data;
	unsigned char access_state;
	struct mutex state_mutex;
	enum scsi_device_state sdev_state;
	struct task_struct___371 *quiesced_by;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int sdev_data[0];
};

struct scsi_cmnd___12 {
	struct scsi_request req;
	struct scsi_device___18 *device;
	struct list_head list;
	struct list_head eh_entry;
	struct delayed_work abort_work;
	struct callback_head rcu;
	int eh_eflags;
	long unsigned int serial_number;
	long unsigned int jiffies_at_alloc;
	int retries;
	int allowed;
	unsigned char prot_op;
	unsigned char prot_type;
	unsigned char prot_flags;
	short unsigned int cmd_len;
	enum dma_data_direction sc_data_direction;
	unsigned char *cmnd;
	struct scsi_data_buffer sdb;
	struct scsi_data_buffer *prot_sdb;
	unsigned int underflow;
	unsigned int transfersize;
	struct request___103 *request;
	unsigned char *sense_buffer;
	void (*scsi_done)(struct scsi_cmnd___12 *);
	struct scsi_pointer SCp;
	unsigned char *host_scribble;
	int result;
	int flags;
	long unsigned int state;
	unsigned char tag;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct scsi_target___18 {
	struct scsi_device___18 *starget_sdev_user;
	struct list_head siblings;
	struct list_head devices;
	struct device___337 dev;
	struct kref reap_ref;
	unsigned int channel;
	unsigned int id;
	unsigned int create: 1;
	unsigned int single_lun: 1;
	unsigned int pdt_1f_for_no_lun: 1;
	unsigned int no_report_luns: 1;
	unsigned int expecting_lun_change: 1;
	atomic_t target_busy;
	atomic_t target_blocked;
	unsigned int can_queue;
	unsigned int max_target_blocked;
	char scsi_level;
	enum scsi_target_state state;
	void *hostdata;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int starget_data[0];
};

struct pci_dev___34;

struct pci_ops___34;

struct pci_bus___34 {
	struct list_head node;
	struct pci_bus___34 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___34 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___34 *ops;
	struct msi_controller___2 *msi;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	int domain_nr;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___337 *bridge;
	struct device___337 dev;
	struct bin_attribute___333 *legacy_io;
	struct bin_attribute___333 *legacy_mem;
	unsigned int is_added: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
};

struct ata_queued_cmd___9;

typedef void (*ata_qc_cb_t___9)(struct ata_queued_cmd___9 *);

struct ata_port___9;

struct ata_device___9;

struct ata_queued_cmd___9 {
	struct ata_port___9 *ap;
	struct ata_device___9 *dev;
	struct scsi_cmnd___12 *scsicmd;
	void (*scsidone)(struct scsi_cmnd___12 *);
	struct ata_taskfile tf;
	u8 cdb[16];
	long unsigned int flags;
	unsigned int tag;
	unsigned int hw_tag;
	unsigned int n_elem;
	unsigned int orig_n_elem;
	int dma_dir;
	unsigned int sect_size;
	unsigned int nbytes;
	unsigned int extrabytes;
	unsigned int curbytes;
	struct scatterlist sgent;
	struct scatterlist *sg;
	struct scatterlist *cursg;
	unsigned int cursg_ofs;
	unsigned int err_mask;
	struct ata_taskfile result_tf;
	ata_qc_cb_t___9 complete_fn;
	void *private_data;
	void *lldd_task;
};

struct ata_link___9;

typedef int (*ata_prereset_fn_t___9)(struct ata_link___9 *, long unsigned int);

struct ata_eh_info___9 {
	struct ata_device___9 *dev;
	u32 serror;
	unsigned int err_mask;
	unsigned int action;
	unsigned int dev_action[2];
	unsigned int flags;
	unsigned int probe_mask;
	char desc[80];
	int desc_len;
};

struct ata_eh_context___9 {
	struct ata_eh_info___9 i;
	int tries[2];
	int cmd_timeout_idx[12];
	unsigned int classes[2];
	unsigned int did_probe_mask;
	unsigned int unloaded_mask;
	unsigned int saved_ncq_enabled;
	u8 saved_xfer_mode[2];
	long unsigned int last_reset;
};

struct ata_device___9 {
	struct ata_link___9 *link;
	unsigned int devno;
	unsigned int horkage;
	long unsigned int flags;
	struct scsi_device___18 *sdev;
	void *private_data;
	union acpi_object *gtf_cache;
	unsigned int gtf_filter;
	struct device___337 tdev;
	u64 n_sectors;
	u64 n_native_sectors;
	unsigned int class;
	long unsigned int unpark_deadline;
	u8 pio_mode;
	u8 dma_mode;
	u8 xfer_mode;
	unsigned int xfer_shift;
	unsigned int multi_count;
	unsigned int max_sectors;
	unsigned int cdb_len;
	long unsigned int pio_mask;
	long unsigned int mwdma_mask;
	long unsigned int udma_mask;
	u16 cylinders;
	u16 heads;
	u16 sectors;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	union {
		u16 id[256];
		u32 gscr[128];
	};
	u8 devslp_timing[8];
	u8 ncq_send_recv_cmds[20];
	u8 ncq_non_data_cmds[64];
	u32 zac_zoned_cap;
	u32 zac_zones_optimal_open;
	u32 zac_zones_optimal_nonseq;
	u32 zac_zones_max_open;
	int spdn_cnt;
	struct ata_ering ering;
	long: 64;
};

struct ata_link___9 {
	struct ata_port___9 *ap;
	int pmp;
	struct device___337 tdev;
	unsigned int active_tag;
	u32 sactive;
	unsigned int flags;
	u32 saved_scontrol;
	unsigned int hw_sata_spd_limit;
	unsigned int sata_spd_limit;
	unsigned int sata_spd;
	enum ata_lpm_policy lpm_policy;
	struct ata_eh_info___9 eh_info;
	struct ata_eh_context___9 eh_context;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ata_device___9 device[2];
	long unsigned int last_lpm_change;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef int (*ata_reset_fn_t___9)(struct ata_link___9 *, unsigned int *, long unsigned int);

typedef void (*ata_postreset_fn_t___9)(struct ata_link___9 *, unsigned int *);

struct ata_port_operations___9;

struct ata_host___9 {
	spinlock_t lock;
	struct device___337 *dev;
	void * const *iomap;
	unsigned int n_ports;
	unsigned int n_tags;
	void *private_data;
	struct ata_port_operations___9 *ops;
	long unsigned int flags;
	struct kref kref;
	struct mutex eh_mutex;
	struct task_struct___371 *eh_owner;
	struct ata_port___9 *simplex_claimed;
	struct ata_port___9 *ports[0];
};

struct ata_port_operations___9 {
	int (*qc_defer)(struct ata_queued_cmd___9 *);
	int (*check_atapi_dma)(struct ata_queued_cmd___9 *);
	void (*qc_prep)(struct ata_queued_cmd___9 *);
	unsigned int (*qc_issue)(struct ata_queued_cmd___9 *);
	bool (*qc_fill_rtf)(struct ata_queued_cmd___9 *);
	int (*cable_detect)(struct ata_port___9 *);
	long unsigned int (*mode_filter)(struct ata_device___9 *, long unsigned int);
	void (*set_piomode)(struct ata_port___9 *, struct ata_device___9 *);
	void (*set_dmamode)(struct ata_port___9 *, struct ata_device___9 *);
	int (*set_mode)(struct ata_link___9 *, struct ata_device___9 **);
	unsigned int (*read_id)(struct ata_device___9 *, struct ata_taskfile *, u16 *);
	void (*dev_config)(struct ata_device___9 *);
	void (*freeze)(struct ata_port___9 *);
	void (*thaw)(struct ata_port___9 *);
	ata_prereset_fn_t___9 prereset;
	ata_reset_fn_t___9 softreset;
	ata_reset_fn_t___9 hardreset;
	ata_postreset_fn_t___9 postreset;
	ata_prereset_fn_t___9 pmp_prereset;
	ata_reset_fn_t___9 pmp_softreset;
	ata_reset_fn_t___9 pmp_hardreset;
	ata_postreset_fn_t___9 pmp_postreset;
	void (*error_handler)(struct ata_port___9 *);
	void (*lost_interrupt)(struct ata_port___9 *);
	void (*post_internal_cmd)(struct ata_queued_cmd___9 *);
	void (*sched_eh)(struct ata_port___9 *);
	void (*end_eh)(struct ata_port___9 *);
	int (*scr_read)(struct ata_link___9 *, unsigned int, u32 *);
	int (*scr_write)(struct ata_link___9 *, unsigned int, u32);
	void (*pmp_attach)(struct ata_port___9 *);
	void (*pmp_detach)(struct ata_port___9 *);
	int (*set_lpm)(struct ata_link___9 *, enum ata_lpm_policy, unsigned int);
	int (*port_suspend)(struct ata_port___9 *, pm_message_t);
	int (*port_resume)(struct ata_port___9 *);
	int (*port_start)(struct ata_port___9 *);
	void (*port_stop)(struct ata_port___9 *);
	void (*host_stop)(struct ata_host___9 *);
	void (*sff_dev_select)(struct ata_port___9 *, unsigned int);
	void (*sff_set_devctl)(struct ata_port___9 *, u8);
	u8 (*sff_check_status)(struct ata_port___9 *);
	u8 (*sff_check_altstatus)(struct ata_port___9 *);
	void (*sff_tf_load)(struct ata_port___9 *, const struct ata_taskfile *);
	void (*sff_tf_read)(struct ata_port___9 *, struct ata_taskfile *);
	void (*sff_exec_command)(struct ata_port___9 *, const struct ata_taskfile *);
	unsigned int (*sff_data_xfer)(struct ata_queued_cmd___9 *, unsigned char *, unsigned int, int);
	void (*sff_irq_on)(struct ata_port___9 *);
	bool (*sff_irq_check)(struct ata_port___9 *);
	void (*sff_irq_clear)(struct ata_port___9 *);
	void (*sff_drain_fifo)(struct ata_queued_cmd___9 *);
	void (*bmdma_setup)(struct ata_queued_cmd___9 *);
	void (*bmdma_start)(struct ata_queued_cmd___9 *);
	void (*bmdma_stop)(struct ata_queued_cmd___9 *);
	u8 (*bmdma_status)(struct ata_port___9 *);
	ssize_t (*em_show)(struct ata_port___9 *, char *);
	ssize_t (*em_store)(struct ata_port___9 *, const char *, size_t);
	ssize_t (*sw_activity_show)(struct ata_device___9 *, char *);
	ssize_t (*sw_activity_store)(struct ata_device___9 *, enum sw_activity);
	ssize_t (*transmit_led_message)(struct ata_port___9 *, u32, ssize_t);
	void (*phy_reset)(struct ata_port___9 *);
	void (*eng_timeout)(struct ata_port___9 *);
	const struct ata_port_operations___9 *inherits;
};

struct ata_port___9 {
	struct Scsi_Host___16 *scsi_host;
	struct ata_port_operations___9 *ops;
	spinlock_t *lock;
	long unsigned int flags;
	unsigned int pflags;
	unsigned int print_id;
	unsigned int local_port_no;
	unsigned int port_no;
	struct ata_ioports ioaddr;
	u8 ctl;
	u8 last_ctl;
	struct ata_link___9 *sff_pio_task_link;
	struct delayed_work sff_pio_task;
	struct ata_bmdma_prd *bmdma_prd;
	dma_addr_t bmdma_prd_dma;
	unsigned int pio_mask;
	unsigned int mwdma_mask;
	unsigned int udma_mask;
	unsigned int cbl;
	struct ata_queued_cmd___9 qcmd[33];
	long unsigned int sas_tag_allocated;
	u64 qc_active;
	int nr_active_links;
	unsigned int sas_last_tag;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ata_link___9 link;
	struct ata_link___9 *slave_link;
	int nr_pmp_links;
	struct ata_link___9 *pmp_link;
	struct ata_link___9 *excl_link;
	struct ata_port_stats stats;
	struct ata_host___9 *host;
	struct device___337 *dev;
	struct device___337 tdev;
	struct mutex scsi_scan_mutex;
	struct delayed_work hotplug_task;
	struct work_struct scsi_rescan_task;
	unsigned int hsm_task_state;
	u32 msg_enable;
	struct list_head eh_done_q;
	wait_queue_head_t eh_wait_q;
	int eh_tries;
	struct completion park_req_pending;
	pm_message_t pm_mesg;
	enum ata_lpm_policy target_lpm_policy;
	struct timer_list fastdrain_timer;
	long unsigned int fastdrain_cnt;
	int em_message_type;
	void *private_data;
	struct ata_acpi_gtm __acpi_init_gtm;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sector_buf[512];
};

struct ata_port_info___9 {
	long unsigned int flags;
	long unsigned int link_flags;
	long unsigned int pio_mask;
	long unsigned int mwdma_mask;
	long unsigned int udma_mask;
	struct ata_port_operations___9 *port_ops;
	void *private_data;
};

struct pci_slot___34 {
	struct pci_bus___34 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject___357 kobj;
};

struct pci_driver___34;

struct pci_dev___34 {
	struct list_head bus_list;
	struct pci_bus___34 *bus;
	struct pci_bus___34 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___34 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u16 aer_cap;
	struct aer_stats *aer_stats;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	long unsigned int *dma_alias_mask;
	struct pci_driver___34 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	unsigned int imm_ready: 1;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int bridge_d3: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int hotplug_user_indicators: 1;
	unsigned int clear_retrain_link: 1;
	unsigned int d3_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	unsigned int ltr_path: 1;
	unsigned int eetlp_prefix_path: 1;
	pci_channel_state_t error_state;
	struct device___337 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int multifunction: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int ats_enabled: 1;
	unsigned int pasid_enabled: 1;
	unsigned int pri_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int reset_fn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int shpc_managed: 1;
	unsigned int is_thunderbolt: 1;
	unsigned int __aer_firmware_first_valid: 1;
	unsigned int __aer_firmware_first: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int irq_managed: 1;
	unsigned int has_secondary_link: 1;
	unsigned int non_compliant_bars: 1;
	unsigned int is_probed: 1;
	unsigned int link_active_reporting: 1;
	unsigned int untrusted: 1;
	unsigned int no_vf_scan: 1;
	unsigned int io_window: 1;
	unsigned int pref_window: 1;
	unsigned int pref_64_window: 1;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	struct bin_attribute___333 *rom_attr;
	int rom_attr_enabled;
	struct bin_attribute___333 *res_attr[17];
	struct bin_attribute___333 *res_attr_wc[17];
	unsigned int broken_cmd_compl: 1;
	const struct attribute_group___334 **msi_irq_groups;
	struct pci_vpd *vpd;
	union {
		struct pci_sriov *sriov;
		struct pci_dev___34 *physfn;
	};
	u16 ats_cap;
	u8 ats_stu;
	atomic_t ats_ref_cnt;
	u32 pri_reqs_alloc;
	u16 pasid_features;
	struct pci_p2pdma *p2pdma;
	phys_addr_t rom;
	size_t romlen;
	char *driver_override;
	long unsigned int priv_flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t pci_dev_extended_size_rh;
	struct pci_dev_extended_rh pci_dev_extended_rh;
};

struct pci_error_handlers___34;

struct pci_driver___34 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___34 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___34 *);
	int (*suspend)(struct pci_dev___34 *, pm_message_t);
	int (*suspend_late)(struct pci_dev___34 *, pm_message_t);
	int (*resume_early)(struct pci_dev___34 *);
	int (*resume)(struct pci_dev___34 *);
	void (*shutdown)(struct pci_dev___34 *);
	int (*sriov_configure)(struct pci_dev___34 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	const struct pci_error_handlers___34 *err_handler;
	const struct attribute_group___334 **groups;
	struct device_driver___337 driver;
	struct pci_dynids dynids;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct pci_ops___34 {
	int (*add_bus)(struct pci_bus___34 *);
	void (*remove_bus)(struct pci_bus___34 *);
	void * (*map_bus)(struct pci_bus___34 *, unsigned int, int);
	int (*read)(struct pci_bus___34 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___34 *, unsigned int, int, int, u32);
};

struct pci_error_handlers___34 {
	pci_ers_result_t (*error_detected)(struct pci_dev___34 *, enum pci_channel_state);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___34 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___34 *);
	void (*reset_prepare)(struct pci_dev___34 *);
	void (*reset_done)(struct pci_dev___34 *);
	void (*resume)(struct pci_dev___34 *);
};

struct property___78 {
	char *name;
	int length;
	void *value;
	struct property___78 *next;
	long unsigned int _flags;
	struct bin_attribute___333 attr;
};

struct phy___7;

struct phy_ops___6 {
	int (*init)(struct phy___7 *);
	int (*exit)(struct phy___7 *);
	int (*power_on)(struct phy___7 *);
	int (*power_off)(struct phy___7 *);
	int (*set_mode)(struct phy___7 *, enum phy_mode);
	int (*reset)(struct phy___7 *);
	int (*calibrate)(struct phy___7 *);
	struct module___301 *owner;
};

struct phy___7 {
	struct device___337 dev;
	int id;
	const struct phy_ops___6 *ops;
	struct mutex mutex;
	int init_count;
	int power_count;
	struct phy_attrs attrs;
	struct regulator *pwr;
};

struct ahci_sg {
	__le32 addr;
	__le32 addr_hi;
	__le32 reserved;
	__le32 flags_size;
};

struct ahci_em_priv___2 {
	enum sw_activity blink_policy;
	struct timer_list timer;
	long unsigned int saved_activity;
	long unsigned int activity;
	long unsigned int led_state;
	struct ata_link___9 *link;
};

struct ahci_port_priv___2 {
	struct ata_link___9 *active_link;
	struct ahci_cmd_hdr *cmd_slot;
	dma_addr_t cmd_slot_dma;
	void *cmd_tbl;
	dma_addr_t cmd_tbl_dma;
	void *rx_fis;
	dma_addr_t rx_fis_dma;
	unsigned int ncq_saw_d2h: 1;
	unsigned int ncq_saw_dmas: 1;
	unsigned int ncq_saw_sdb: 1;
	spinlock_t lock;
	u32 intr_mask;
	bool fbs_supported;
	bool fbs_enabled;
	int fbs_last_dev;
	struct ahci_em_priv___2 em_priv[8];
	char *irq_desc;
};

struct ahci_host_priv___2 {
	unsigned int flags;
	u32 force_port_map;
	u32 mask_port_map;
	void *mmio;
	u32 cap;
	u32 cap2;
	u32 version;
	u32 port_map;
	u32 saved_cap;
	u32 saved_cap2;
	u32 saved_port_map;
	u32 em_loc;
	u32 em_buf_sz;
	u32 em_msg_type;
	bool got_runtime_pm;
	struct clk *clks[5];
	struct regulator **target_pwrs;
	struct phy___7 **phys;
	unsigned int nports;
	void *plat_data;
	unsigned int irq;
	void (*start_engine)(struct ata_port___9 *);
	int (*stop_engine)(struct ata_port___9 *);
	irqreturn_t (*irq_handler)(int, void *);
	int (*get_irq_vector)(struct ata_host___9 *, int);
};

enum {
	PIIX_IOCFG = 84,
	ICH5_PMR = 144,
	ICH5_PCS = 146,
	PIIX_SIDPR_BAR = 5,
	PIIX_SIDPR_LEN = 16,
	PIIX_SIDPR_IDX = 0,
	PIIX_SIDPR_DATA = 4,
	PIIX_FLAG_CHECKINTR = 268435456,
	PIIX_FLAG_SIDPR = 536870912,
	PIIX_PATA_FLAGS = 1,
	PIIX_SATA_FLAGS = 268435458,
	PIIX_FLAG_PIO16 = 1073741824,
	PIIX_80C_PRI = 48,
	PIIX_80C_SEC = 192,
	P0 = 0,
	P1 = 1,
	P2 = 2,
	P3 = 3,
	IDE = 4294967295,
	NA = 4294967294,
	RV = 4294967293,
	PIIX_AHCI_DEVICE = 6,
	PIIX_HOST_BROKEN_SUSPEND = 16777216,
};

enum piix_controller_ids {
	piix_pata_mwdma = 0,
	piix_pata_33 = 1,
	ich_pata_33 = 2,
	ich_pata_66 = 3,
	ich_pata_100 = 4,
	ich_pata_100_nomwdma1 = 5,
	ich5_sata = 6,
	ich6_sata = 7,
	ich6m_sata = 8,
	ich8_sata = 9,
	ich8_2port_sata = 10,
	ich8m_apple_sata = 11,
	tolapai_sata = 12,
	piix_pata_vmw = 13,
	ich8_sata_snb = 14,
	ich8_2port_sata_snb = 15,
	ich8_2port_sata_byt = 16,
};

struct piix_map_db {
	const u32 mask;
	const u16 port_enable;
	const int map[0];
};

struct piix_host_priv {
	const int *map;
	u32 saved_iocfg;
	void *sidpr;
};

struct ich_laptop {
	u16 device;
	u16 subvendor;
	u16 subdevice;
};

struct module___302;

struct file___371;

struct kiocb___371;

struct poll_table_struct___224;

struct vm_area_struct___372;

struct inode___371;

struct file_lock___371;

struct page___372;

struct seq_file___315;

struct file_operations___371 {
	struct module___302 *owner;
	loff_t (*llseek)(struct file___371 *, loff_t, int);
	ssize_t (*read)(struct file___371 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___371 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___371 *, struct iov_iter___156 *);
	ssize_t (*write_iter)(struct kiocb___371 *, struct iov_iter___156 *);
	int (*iopoll)(struct kiocb___371 *, bool);
	int (*iterate)(struct file___371 *, struct dir_context *);
	int (*iterate_shared)(struct file___371 *, struct dir_context *);
	__poll_t (*poll)(struct file___371 *, struct poll_table_struct___224 *);
	long int (*unlocked_ioctl)(struct file___371 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___371 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___371 *, struct vm_area_struct___372 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___371 *, struct file___371 *);
	int (*flush)(struct file___371 *, fl_owner_t);
	int (*release)(struct inode___371 *, struct file___371 *);
	int (*fsync)(struct file___371 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___371 *, int);
	int (*lock)(struct file___371 *, int, struct file_lock___371 *);
	ssize_t (*sendpage)(struct file___371 *, struct page___372 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___371 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___371 *, int, struct file_lock___371 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___371 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___371 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___371 *, long int, struct file_lock___371 **, void **);
	long int (*fallocate)(struct file___371 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___315 *, struct file___371 *);
	ssize_t (*copy_file_range)(struct file___371 *, loff_t, struct file___371 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___371 *, loff_t, struct file___371 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___371 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct perf_event___142;

struct debug_info___142 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___142 *hbp_break[16];
	struct perf_event___142 *hbp_watch[16];
};

struct task_struct___372;

struct hw_perf_event___142 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___372 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___142)(struct perf_event___142 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___142;

struct perf_event_context___142;

struct fasync_struct___370;

struct pid_namespace___218;

struct trace_event_call___135;

struct perf_cgroup___142;

struct perf_event___142 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___142 *group_leader;
	struct pmu___142 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___142 hw;
	struct perf_event_context___142 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___142 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___372 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___370 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___142 *);
	struct callback_head callback_head;
	struct pid_namespace___218 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___142 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___142 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___135 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___142 *cgrp;
	struct list_head sb_list;
};

struct thread_struct___142 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___142 debug;
	long: 64;
};

struct vmacache___371 {
	u64 seqnum;
	struct vm_area_struct___372 *vmas[4];
};

struct page_frag___371 {
	struct page___372 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___371;

struct pid___218;

struct cred___342;

struct nsproxy___277;

struct signal_struct___256;

struct css_set___232;

struct vm_struct___277;

struct task_struct___372 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___372 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___371 *mm;
	struct mm_struct___371 *active_mm;
	struct vmacache___371 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___372 *real_parent;
	struct task_struct___372 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___372 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___218 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___218 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___218 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___342 *ptracer_cred;
	const struct cred___342 *real_cred;
	const struct cred___342 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___277 *nsproxy;
	struct signal_struct___256 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___372 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___107 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___232 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___142 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___371 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___372 *oom_reaper_list;
	struct vm_struct___277 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___142 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___372 *pgtable_t___371;

struct address_space___370;

struct dev_pagemap___359;

struct page___372 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___370 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___372 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___371 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___371 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___359 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___371;

struct lruvec___371 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___371 *pgdat;
};

struct zone___371 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___371 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___371 {
	struct zone___371 *zone;
	int zone_idx;
};

struct zonelist___371 {
	struct zoneref___371 _zonerefs[25];
};

struct pglist_data___371 {
	struct zone___371 node_zones[3];
	struct zonelist___371 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___372 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___372 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___371 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___372 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___372 *owner;
};

struct secondary_data___372 {
	void *stack;
	struct task_struct___372 *task;
	long int status;
};

struct blocking_notifier_head___371 {
	struct rw_semaphore___372 rwsem;
	struct notifier_block *head;
};

struct key___342;

struct ucounts___247;

struct user_namespace___247 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___247 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___9 ns;
	long unsigned int flags;
	struct key___342 *persistent_keyring_register;
	struct rw_semaphore___372 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___247 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_root___364;

struct kernfs_elem_dir___364 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___364 *root;
};

struct kernfs_node___365;

struct kernfs_syscall_ops___364;

struct kernfs_root___364 {
	struct kernfs_node___365 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___364 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___364 {
	struct kernfs_node___365 *target_kn;
};

struct kernfs_ops___364;

struct kernfs_elem_attr___364 {
	const struct kernfs_ops___364 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___365 *notify_next;
};

struct kernfs_node___365 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___365 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___364 dir;
		struct kernfs_elem_symlink___364 symlink;
		struct kernfs_elem_attr___364 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___364;

struct kernfs_ops___364 {
	int (*open)(struct kernfs_open_file___364 *);
	void (*release)(struct kernfs_open_file___364 *);
	int (*seq_show)(struct seq_file___315 *, void *);
	void * (*seq_start)(struct seq_file___315 *, loff_t *);
	void * (*seq_next)(struct seq_file___315 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___315 *, void *);
	ssize_t (*read)(struct kernfs_open_file___364 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___364 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___364 *, struct vm_area_struct___372 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___364 *, struct poll_table_struct___224 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___364 {
	int (*remount_fs)(struct kernfs_root___364 *, int *, char *);
	int (*show_options)(struct seq_file___315 *, struct kernfs_root___364 *);
	int (*mkdir)(struct kernfs_node___365 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___365 *);
	int (*rename)(struct kernfs_node___365 *, struct kernfs_node___365 *, const char *);
	int (*show_path)(struct seq_file___315 *, struct kernfs_node___365 *, struct kernfs_root___364 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___314;

struct seq_file___315 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___314 *op;
	int poll_event;
	const struct file___371 *file;
	void *private;
};

struct vm_operations_struct___359;

struct kernfs_open_file___364 {
	struct kernfs_node___365 *kn;
	struct file___371 *file;
	struct seq_file___315 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___359 *vm_ops;
};

struct dentry___370;

struct path___371 {
	struct vfsmount *mnt;
	struct dentry___370 *dentry;
};

struct fown_struct___218 {
	rwlock_t lock;
	struct pid___218 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___371 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___371 f_path;
	struct inode___371 *f_inode;
	const struct file_operations___371 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___218 f_owner;
	const struct cred___342 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___370 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___359;

struct vm_operations_struct___359 {
	void (*open)(struct vm_area_struct___372 *);
	void (*close)(struct vm_area_struct___372 *);
	int (*split)(struct vm_area_struct___372 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___372 *);
	vm_fault_t (*fault)(struct vm_fault___359 *);
	vm_fault_t (*huge_fault)(struct vm_fault___359 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___359 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___372 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___359 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___359 *);
	int (*access)(struct vm_area_struct___372 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___372 *);
	int (*set_policy)(struct vm_area_struct___372 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___372 *, long unsigned int);
	struct page___372 * (*find_special_page)(struct vm_area_struct___372 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___230)(struct file___371 *, wait_queue_head_t *, struct poll_table_struct___224 *);

struct poll_table_struct___224 {
	poll_queue_proc___230 _qproc;
	__poll_t _key;
};

struct vm_area_struct___372 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___372 *vm_next;
	struct vm_area_struct___372 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___371 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___359 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___371 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___358;

struct bin_attribute___334;

struct attribute_group___335 {
	const char *name;
	umode_t (*is_visible)(struct kobject___358 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___358 *, struct bin_attribute___334 *, int);
	struct attribute **attrs;
	struct bin_attribute___334 **bin_attrs;
};

struct kset___357;

struct kobj_type___357;

struct kobject___358 {
	const char *name;
	struct list_head entry;
	struct kobject___358 *parent;
	struct kset___357 *kset;
	struct kobj_type___357 *ktype;
	struct kernfs_node___365 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___334 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___371 *, struct kobject___358 *, struct bin_attribute___334 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___371 *, struct kobject___358 *, struct bin_attribute___334 *, char *, loff_t, size_t);
	int (*mmap)(struct file___371 *, struct kobject___358 *, struct bin_attribute___334 *, struct vm_area_struct___372 *);
};

struct sysfs_ops___357 {
	ssize_t (*show)(struct kobject___358 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___358 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___357;

struct kset___357 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___358 kobj;
	const struct kset_uevent_ops___357 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___357 {
	void (*release)(struct kobject___358 *);
	const struct sysfs_ops___357 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___28 * (*child_ns_type)(struct kobject___358 *);
	const void * (*namespace)(struct kobject___358 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___357 {
	int (* const filter)(struct kset___357 *, struct kobject___358 *);
	const char * (* const name)(struct kset___357 *, struct kobject___358 *);
	int (* const uevent)(struct kset___357 *, struct kobject___358 *, struct kobj_uevent_env *);
};

struct kobj_attribute___349 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___358 *, struct kobj_attribute___349 *, char *);
	ssize_t (*store)(struct kobject___358 *, struct kobj_attribute___349 *, const char *, size_t);
};

struct device___338;

struct dev_pm_ops___338 {
	int (*prepare)(struct device___338 *);
	void (*complete)(struct device___338 *);
	int (*suspend)(struct device___338 *);
	int (*resume)(struct device___338 *);
	int (*freeze)(struct device___338 *);
	int (*thaw)(struct device___338 *);
	int (*poweroff)(struct device___338 *);
	int (*restore)(struct device___338 *);
	int (*suspend_late)(struct device___338 *);
	int (*resume_early)(struct device___338 *);
	int (*freeze_late)(struct device___338 *);
	int (*thaw_early)(struct device___338 *);
	int (*poweroff_late)(struct device___338 *);
	int (*restore_early)(struct device___338 *);
	int (*suspend_noirq)(struct device___338 *);
	int (*resume_noirq)(struct device___338 *);
	int (*freeze_noirq)(struct device___338 *);
	int (*thaw_noirq)(struct device___338 *);
	int (*poweroff_noirq)(struct device___338 *);
	int (*restore_noirq)(struct device___338 *);
	int (*runtime_suspend)(struct device___338 *);
	int (*runtime_resume)(struct device___338 *);
	int (*runtime_idle)(struct device___338 *);
};

struct pm_subsys_data___6;

struct dev_pm_info___338 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___6 *subsys_data;
	void (*set_latency_tolerance)(struct device___338 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___338;

struct bus_type___338;

struct device_driver___338;

struct dev_pm_domain___338;

struct irq_domain___27;

struct dma_map_ops___126;

struct device_node___83;

struct fwnode_handle___260;

struct class___338;

struct device___338 {
	struct device___338 *parent;
	struct device_private *p;
	struct kobject___358 kobj;
	const char *init_name;
	const struct device_type___338 *type;
	struct mutex mutex;
	struct bus_type___338 *bus;
	struct device_driver___338 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___338 power;
	struct dev_pm_domain___338 *pm_domain;
	struct irq_domain___27 *msi_domain;
	struct dev_pin_info___4 *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___126 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___83 *of_node;
	struct fwnode_handle___260 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___338 *class;
	const struct attribute_group___335 **groups;
	void (*release)(struct device___338 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct pm_domain_data___6;

struct pm_subsys_data___6 {
	spinlock_t lock;
	unsigned int refcount;
	struct list_head clock_list;
	struct pm_domain_data___6 *domain_data;
};

struct pm_domain_data___6 {
	struct list_head list_node;
	struct device___338 *dev;
};

struct dev_pm_domain___338 {
	struct dev_pm_ops___338 ops;
	void (*detach)(struct device___338 *, bool);
	int (*activate)(struct device___338 *);
	void (*sync)(struct device___338 *);
	void (*dismiss)(struct device___338 *);
};

struct upid___218 {
	int nr;
	struct pid_namespace___218 *ns;
};

struct pid_namespace___218 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___372 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___218 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___370 *proc_self;
	struct dentry___370 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___247 *user_ns;
	struct ucounts___247 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___9 ns;
};

struct pid___218 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___218 numbers[1];
};

struct user_struct___342 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___342 *uid_keyring;
	struct key___342 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___371;

struct mm_struct___371 {
	struct {
		struct vm_area_struct___372 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___371 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___372 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___371 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___372 *owner;
		struct user_namespace___247 *user_ns;
		struct file___371 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___371 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___342 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___342 *session_keyring;
	struct key___342 *process_keyring;
	struct key___342 *thread_keyring;
	struct key___342 *request_key_auth;
	void *security;
	struct user_struct___342 *user;
	struct user_namespace___247 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___232;

struct nsproxy___277 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___218 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___232 *cgroup_ns;
};

struct signal_struct___256 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___372 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___372 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___218 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___218 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___371 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___218 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___232;

struct cgroup___232;

struct css_set___232 {
	struct cgroup_subsys_state___232 *subsys[13];
	refcount_t refcount;
	struct css_set___232 *dom_cset;
	struct cgroup___232 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___232 *mg_src_cgrp;
	struct cgroup___232 *mg_dst_cgrp;
	struct css_set___232 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___142 {
	struct pmu___142 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___372 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___142 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___277 {
	struct vm_struct___277 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___372 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___268 {
	struct task_struct___372 task;
	long unsigned int stack[8192];
};

struct bus_type___338 {
	const char *name;
	const char *dev_name;
	struct device___338 *dev_root;
	const struct attribute_group___335 **bus_groups;
	const struct attribute_group___335 **dev_groups;
	const struct attribute_group___335 **drv_groups;
	int (*match)(struct device___338 *, struct device_driver___338 *);
	int (*uevent)(struct device___338 *, struct kobj_uevent_env *);
	int (*probe)(struct device___338 *);
	int (*remove)(struct device___338 *);
	void (*shutdown)(struct device___338 *);
	int (*online)(struct device___338 *);
	int (*offline)(struct device___338 *);
	int (*suspend)(struct device___338 *, pm_message_t);
	int (*resume)(struct device___338 *);
	int (*num_vf)(struct device___338 *);
	int (*dma_configure)(struct device___338 *);
	const struct dev_pm_ops___338 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___338 {
	const char *name;
	struct bus_type___338 *bus;
	struct module___302 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___338 *);
	int (*remove)(struct device___338 *);
	void (*shutdown)(struct device___338 *);
	int (*suspend)(struct device___338 *, pm_message_t);
	int (*resume)(struct device___338 *);
	const struct attribute_group___335 **groups;
	const struct dev_pm_ops___338 *pm;
	void (*coredump)(struct device___338 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___338 {
	const char *name;
	const struct attribute_group___335 **groups;
	int (*uevent)(struct device___338 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___338 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___338 *);
	const struct dev_pm_ops___338 *pm;
};

struct module_kobject___299 {
	struct kobject___358 kobj;
	struct module___302 *mod;
	struct kobject___358 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___299 {
	struct module___302 *mod;
	struct latch_tree_node node;
};

struct module_layout___299 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___299 mtn;
};

struct module_attribute___299;

struct kernel_param___299;

struct module___302 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___299 mkobj;
	struct module_attribute___299 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___358 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___299 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___299 core_layout;
	struct module_layout___299 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___135 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide21;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct class___338 {
	const char *name;
	struct module___302 *owner;
	const struct attribute_group___335 **class_groups;
	const struct attribute_group___335 **dev_groups;
	struct kobject___358 *dev_kobj;
	int (*dev_uevent)(struct device___338 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___338 *, umode_t *);
	void (*class_release)(struct class___338 *);
	void (*dev_release)(struct device___338 *);
	int (*shutdown_pre)(struct device___338 *);
	const struct kobj_ns_type_operations___28 *ns_type;
	const void * (*namespace)(struct device___338 *);
	const struct dev_pm_ops___338 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct device_attribute___50 {
	struct attribute attr;
	ssize_t (*show)(struct device___338 *, struct device_attribute___50 *, char *);
	ssize_t (*store)(struct device___338 *, struct device_attribute___50 *, const char *, size_t);
};

typedef void (*dr_release_t___22)(struct device___338 *, void *);

struct irq_domain_ops___27;

struct irq_domain_chip_generic___15;

struct irq_domain___27 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___27 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___260 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___15 *gc;
	struct irq_domain___27 *parent;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_direct_max_irq;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_tree_mutex;
	unsigned int linear_revmap[0];
};

struct dma_map_ops___126 {
	void * (*alloc)(struct device___338 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___338 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___338 *, struct vm_area_struct___372 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___338 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___338 *, struct page___372 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___338 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___338 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___338 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___338 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___338 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___338 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___338 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___338 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___338 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___338 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___338 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___338 *, u64);
	u64 (*get_required_mask)(struct device___338 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___260;

struct fwnode_handle___260 {
	struct fwnode_handle___260 *secondary;
	const struct fwnode_operations___260 *ops;
};

struct property___79;

struct device_node___83 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___260 fwnode;
	struct property___79 *properties;
	struct property___79 *deadprops;
	struct device_node___83 *parent;
	struct device_node___83 *child;
	struct device_node___83 *sibling;
	struct kobject___358 kobj;
	long unsigned int _flags;
	void *data;
};

struct address_space_operations___370;

struct address_space___370 {
	struct inode___371 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___372 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___370 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___359)(struct vm_area_struct___372 *, long unsigned int, const struct page___372 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___359)(struct page___372 *, void *);

struct dev_pagemap___359 {
	dev_page_fault_t___359 page_fault;
	dev_page_free_t___359 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___338 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___371 {
	struct task_struct___372 *task;
	struct core_thread___371 *next;
};

struct core_state___371 {
	atomic_t nr_threads;
	struct core_thread___371 dumper;
	struct completion startup;
};

struct vm_fault___359 {
	struct vm_area_struct___372 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___372 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___372 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___371 prealloc_pte;
};

struct dentry_operations___370;

struct super_block___370;

struct dentry___370 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___370 *d_parent;
	struct qstr d_name;
	struct inode___371 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___370 *d_op;
	struct super_block___370 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___370;

struct block_device___370;

struct cdev___90;

struct inode___371 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___370 *i_op;
	struct super_block___370 *i_sb;
	struct address_space___370 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___372 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___371 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___370 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___370 *i_bdev;
		struct cdev___90 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___370 {
	int (*d_revalidate)(struct dentry___370 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___370 *, unsigned int);
	int (*d_hash)(const struct dentry___370 *, struct qstr *);
	int (*d_compare)(const struct dentry___370 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___370 *);
	int (*d_init)(struct dentry___370 *);
	void (*d_release)(struct dentry___370 *);
	void (*d_prune)(struct dentry___370 *);
	void (*d_iput)(struct dentry___370 *, struct inode___371 *);
	char * (*d_dname)(struct dentry___370 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___371 *);
	int (*d_manage)(const struct path___371 *, bool);
	struct dentry___370 * (*d_real)(struct dentry___370 *, const struct inode___371 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___370;

struct mem_dqinfo___370 {
	struct quota_format_type___370 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___370;

struct quota_info___370 {
	unsigned int flags;
	struct rw_semaphore___372 dqio_sem;
	struct inode___371 *files[3];
	struct mem_dqinfo___370 info[3];
	const struct quota_format_ops___370 *ops[3];
};

struct rcuwait___370 {
	struct task_struct___372 *task;
};

struct percpu_rw_semaphore___370 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___372 rw_sem;
	struct rcuwait___370 writer;
	int readers_block;
};

struct sb_writers___370 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___370 rw_sem[3];
};

struct file_system_type___370;

struct super_operations___370;

struct dquot_operations___370;

struct quotactl_ops___370;

struct super_block___370 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___370 *s_type;
	const struct super_operations___370 *s_op;
	const struct dquot_operations___370 *dq_op;
	const struct quotactl_ops___370 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___370 *s_root;
	struct rw_semaphore___372 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___370 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___370 s_dquot;
	struct sb_writers___370 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___370 *s_d_op;
	int cleancache_poolid;
	struct shrinker___133 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___247 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___371 {
	struct file___371 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___371 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___370 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___371 *ia_file;
};

struct dquot___370 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___370 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___370 {
	int qf_fmt_id;
	const struct quota_format_ops___370 *qf_ops;
	struct module___302 *qf_owner;
	struct quota_format_type___370 *qf_next;
};

struct quota_format_ops___370 {
	int (*check_quota_file)(struct super_block___370 *, int);
	int (*read_file_info)(struct super_block___370 *, int);
	int (*write_file_info)(struct super_block___370 *, int);
	int (*free_file_info)(struct super_block___370 *, int);
	int (*read_dqblk)(struct dquot___370 *);
	int (*commit_dqblk)(struct dquot___370 *);
	int (*release_dqblk)(struct dquot___370 *);
	int (*get_next_id)(struct super_block___370 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___370 {
	int (*write_dquot)(struct dquot___370 *);
	struct dquot___370 * (*alloc_dquot)(struct super_block___370 *, int);
	void (*destroy_dquot)(struct dquot___370 *);
	int (*acquire_dquot)(struct dquot___370 *);
	int (*release_dquot)(struct dquot___370 *);
	int (*mark_dirty)(struct dquot___370 *);
	int (*write_info)(struct super_block___370 *, int);
	qsize_t * (*get_reserved_space)(struct inode___371 *);
	int (*get_projid)(struct inode___371 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___371 *, qsize_t *);
	int (*get_next_id)(struct super_block___370 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___370 {
	int (*quota_on)(struct super_block___370 *, int, int, const struct path___371 *);
	int (*quota_off)(struct super_block___370 *, int);
	int (*quota_enable)(struct super_block___370 *, unsigned int);
	int (*quota_disable)(struct super_block___370 *, unsigned int);
	int (*quota_sync)(struct super_block___370 *, int);
	int (*set_info)(struct super_block___370 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___370 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___370 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___370 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___370 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___370 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___370 {
	int (*writepage)(struct page___372 *, struct writeback_control___3 *);
	int (*readpage)(struct file___371 *, struct page___372 *);
	int (*writepages)(struct address_space___370 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___372 *);
	int (*readpages)(struct file___371 *, struct address_space___370 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___371 *, struct address_space___370 *, loff_t, unsigned int, unsigned int, struct page___372 **, void **);
	int (*write_end)(struct file___371 *, struct address_space___370 *, loff_t, unsigned int, unsigned int, struct page___372 *, void *);
	sector_t (*bmap)(struct address_space___370 *, sector_t);
	void (*invalidatepage)(struct page___372 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___372 *, gfp_t);
	void (*freepage)(struct page___372 *);
	ssize_t (*direct_IO)(struct kiocb___371 *, struct iov_iter___156 *);
	int (*migratepage)(struct address_space___370 *, struct page___372 *, struct page___372 *, enum migrate_mode);
	bool (*isolate_page)(struct page___372 *, isolate_mode_t);
	void (*putback_page)(struct page___372 *);
	int (*launder_page)(struct page___372 *);
	int (*is_partially_uptodate)(struct page___372 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___372 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___370 *, struct page___372 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___371 *, sector_t *);
	void (*swap_deactivate)(struct file___371 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___370 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___371 *bd_inode;
	struct super_block___370 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___370 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___90 {
	struct kobject___358 kobj;
	struct module___302 *owner;
	const struct file_operations___371 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___370 {
	struct dentry___370 * (*lookup)(struct inode___371 *, struct dentry___370 *, unsigned int);
	const char * (*get_link)(struct dentry___370 *, struct inode___371 *, struct delayed_call *);
	int (*permission)(struct inode___371 *, int);
	struct posix_acl * (*get_acl)(struct inode___371 *, int);
	int (*readlink)(struct dentry___370 *, char *, int);
	int (*create)(struct inode___371 *, struct dentry___370 *, umode_t, bool);
	int (*link)(struct dentry___370 *, struct inode___371 *, struct dentry___370 *);
	int (*unlink)(struct inode___371 *, struct dentry___370 *);
	int (*symlink)(struct inode___371 *, struct dentry___370 *, const char *);
	int (*mkdir)(struct inode___371 *, struct dentry___370 *, umode_t);
	int (*rmdir)(struct inode___371 *, struct dentry___370 *);
	int (*mknod)(struct inode___371 *, struct dentry___370 *, umode_t, dev_t);
	int (*rename)(struct inode___371 *, struct dentry___370 *, struct inode___371 *, struct dentry___370 *, unsigned int);
	int (*setattr)(struct dentry___370 *, struct iattr___370 *);
	int (*getattr)(const struct path___371 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___370 *, char *, size_t);
	int (*fiemap)(struct inode___371 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___371 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___371 *, struct dentry___370 *, struct file___371 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___371 *, struct dentry___370 *, umode_t);
	int (*set_acl)(struct inode___371 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___370 {
	void (*fl_copy_lock)(struct file_lock___371 *, struct file_lock___371 *);
	void (*fl_release_private)(struct file_lock___371 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___370;

struct file_lock___371 {
	struct file_lock___371 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___371 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___370 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___370 *fl_ops;
	const struct lock_manager_operations___370 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___370 {
	int (*lm_compare_owner)(struct file_lock___371 *, struct file_lock___371 *);
	long unsigned int (*lm_owner_key)(struct file_lock___371 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___371 *);
	int (*lm_grant)(struct file_lock___371 *, int);
	bool (*lm_break)(struct file_lock___371 *);
	int (*lm_change)(struct file_lock___371 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___371 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___370 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___370 *fa_next;
	struct file___371 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___370 {
	const char *name;
	int fs_flags;
	struct dentry___370 * (*mount)(struct file_system_type___370 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___370 *);
	struct module___302 *owner;
	struct file_system_type___370 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___370 {
	struct inode___371 * (*alloc_inode)(struct super_block___370 *);
	void (*destroy_inode)(struct inode___371 *);
	void (*dirty_inode)(struct inode___371 *, int);
	int (*write_inode)(struct inode___371 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___371 *);
	void (*evict_inode)(struct inode___371 *);
	void (*put_super)(struct super_block___370 *);
	int (*sync_fs)(struct super_block___370 *, int);
	int (*freeze_super)(struct super_block___370 *);
	int (*freeze_fs)(struct super_block___370 *);
	int (*thaw_super)(struct super_block___370 *);
	int (*unfreeze_fs)(struct super_block___370 *);
	int (*statfs)(struct dentry___370 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___370 *, int *, char *);
	void (*umount_begin)(struct super_block___370 *);
	int (*show_options)(struct seq_file___315 *, struct dentry___370 *);
	int (*show_devname)(struct seq_file___315 *, struct dentry___370 *);
	int (*show_path)(struct seq_file___315 *, struct dentry___370 *);
	int (*show_stats)(struct seq_file___315 *, struct dentry___370 *);
	ssize_t (*quota_read)(struct super_block___370 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___370 *, int, const char *, size_t, loff_t);
	struct dquot___370 ** (*get_dquots)(struct inode___371 *);
	int (*bdev_try_to_free_page)(struct super_block___370 *, struct page___372 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___370 *, struct shrink_control___133 *);
	long int (*free_cached_objects)(struct super_block___370 *, struct shrink_control___133 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___359(struct page___372 *);

struct fwnode_reference_args___260;

struct fwnode_endpoint___260;

struct fwnode_operations___260 {
	struct fwnode_handle___260 * (*get)(struct fwnode_handle___260 *);
	void (*put)(struct fwnode_handle___260 *);
	bool (*device_is_available)(const struct fwnode_handle___260 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___260 *, const struct device___338 *);
	bool (*property_present)(const struct fwnode_handle___260 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___260 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___260 *, const char *, const char **, size_t);
	struct fwnode_handle___260 * (*get_parent)(const struct fwnode_handle___260 *);
	struct fwnode_handle___260 * (*get_next_child_node)(const struct fwnode_handle___260 *, struct fwnode_handle___260 *);
	struct fwnode_handle___260 * (*get_named_child_node)(const struct fwnode_handle___260 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___260 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___260 *);
	struct fwnode_handle___260 * (*graph_get_next_endpoint)(const struct fwnode_handle___260 *, struct fwnode_handle___260 *);
	struct fwnode_handle___260 * (*graph_get_remote_endpoint)(const struct fwnode_handle___260 *);
	struct fwnode_handle___260 * (*graph_get_port_parent)(struct fwnode_handle___260 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___260 *, struct fwnode_endpoint___260 *);
};

struct fwnode_endpoint___260 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___260 *local_fwnode;
};

struct fwnode_reference_args___260 {
	struct fwnode_handle___260 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct dma_router___7 {
	struct device___338 *dev;
	void (*route_free)(struct device___338 *, void *);
};

struct dma_device___7;

struct dma_chan_dev___7;

struct dma_chan___8 {
	struct dma_device___7 *device;
	dma_cookie_t cookie;
	dma_cookie_t completed_cookie;
	int chan_id;
	struct dma_chan_dev___7 *dev;
	struct list_head device_node;
	struct dma_chan_percpu *local;
	int client_count;
	int table_count;
	struct dma_router___7 *router;
	void *route_data;
	void *private;
};

typedef bool (*dma_filter_fn___7)(struct dma_chan___8 *, void *);

struct dma_filter___7 {
	dma_filter_fn___7 fn;
	int mapcnt;
	const struct dma_slave_map *map;
};

struct dma_async_tx_descriptor___7;

struct dma_device___7 {
	unsigned int chancnt;
	unsigned int privatecnt;
	struct list_head channels;
	struct list_head global_node;
	struct dma_filter___7 filter;
	dma_cap_mask_t cap_mask;
	short unsigned int max_xor;
	short unsigned int max_pq;
	enum dmaengine_alignment copy_align;
	enum dmaengine_alignment xor_align;
	enum dmaengine_alignment pq_align;
	enum dmaengine_alignment fill_align;
	int dev_id;
	struct device___338 *dev;
	u32 src_addr_widths;
	u32 dst_addr_widths;
	u32 directions;
	u32 max_burst;
	bool descriptor_reuse;
	enum dma_residue_granularity residue_granularity;
	int (*device_alloc_chan_resources)(struct dma_chan___8 *);
	void (*device_free_chan_resources)(struct dma_chan___8 *);
	struct dma_async_tx_descriptor___7 * (*device_prep_dma_memcpy)(struct dma_chan___8 *, dma_addr_t, dma_addr_t, size_t, long unsigned int);
	struct dma_async_tx_descriptor___7 * (*device_prep_dma_xor)(struct dma_chan___8 *, dma_addr_t, dma_addr_t *, unsigned int, size_t, long unsigned int);
	struct dma_async_tx_descriptor___7 * (*device_prep_dma_xor_val)(struct dma_chan___8 *, dma_addr_t *, unsigned int, size_t, enum sum_check_flags *, long unsigned int);
	struct dma_async_tx_descriptor___7 * (*device_prep_dma_pq)(struct dma_chan___8 *, dma_addr_t *, dma_addr_t *, unsigned int, const unsigned char *, size_t, long unsigned int);
	struct dma_async_tx_descriptor___7 * (*device_prep_dma_pq_val)(struct dma_chan___8 *, dma_addr_t *, dma_addr_t *, unsigned int, const unsigned char *, size_t, enum sum_check_flags *, long unsigned int);
	struct dma_async_tx_descriptor___7 * (*device_prep_dma_memset)(struct dma_chan___8 *, dma_addr_t, int, size_t, long unsigned int);
	struct dma_async_tx_descriptor___7 * (*device_prep_dma_memset_sg)(struct dma_chan___8 *, struct scatterlist *, unsigned int, int, long unsigned int);
	struct dma_async_tx_descriptor___7 * (*device_prep_dma_interrupt)(struct dma_chan___8 *, long unsigned int);
	struct dma_async_tx_descriptor___7 * (*device_prep_slave_sg)(struct dma_chan___8 *, struct scatterlist *, unsigned int, enum dma_transfer_direction, long unsigned int, void *);
	struct dma_async_tx_descriptor___7 * (*device_prep_dma_cyclic)(struct dma_chan___8 *, dma_addr_t, size_t, size_t, enum dma_transfer_direction, long unsigned int);
	struct dma_async_tx_descriptor___7 * (*device_prep_interleaved_dma)(struct dma_chan___8 *, struct dma_interleaved_template *, long unsigned int);
	struct dma_async_tx_descriptor___7 * (*device_prep_dma_imm_data)(struct dma_chan___8 *, dma_addr_t, u64, long unsigned int);
	int (*device_config)(struct dma_chan___8 *, struct dma_slave_config *);
	int (*device_pause)(struct dma_chan___8 *);
	int (*device_resume)(struct dma_chan___8 *);
	int (*device_terminate_all)(struct dma_chan___8 *);
	void (*device_synchronize)(struct dma_chan___8 *);
	enum dma_status (*device_tx_status)(struct dma_chan___8 *, dma_cookie_t, struct dma_tx_state *);
	void (*device_issue_pending)(struct dma_chan___8 *);
};

struct dma_chan_dev___7 {
	struct dma_chan___8 *chan;
	struct device___338 device;
	int dev_id;
	atomic_t *idr_ref;
};

struct dmaengine_unmap_data___7 {
	u8 map_cnt;
	u8 to_cnt;
	u8 from_cnt;
	u8 bidi_cnt;
	struct device___338 *dev;
	struct kref kref;
	size_t len;
	dma_addr_t addr[0];
};

struct dma_async_tx_descriptor___7 {
	dma_cookie_t cookie;
	enum dma_ctrl_flags flags;
	dma_addr_t phys;
	struct dma_chan___8 *chan;
	dma_cookie_t (*tx_submit)(struct dma_async_tx_descriptor___7 *);
	int (*desc_free)(struct dma_async_tx_descriptor___7 *);
	dma_async_tx_callback callback;
	dma_async_tx_callback_result callback_result;
	void *callback_param;
	struct dmaengine_unmap_data___7 *unmap;
};

struct node___207 {
	struct device___338 dev;
};

struct spi_device_id {
	char name[32];
	kernel_ulong_t driver_data;
};

struct property___79 {
	char *name;
	int length;
	void *value;
	struct property___79 *next;
	long unsigned int _flags;
	struct bin_attribute___334 attr;
};

struct of_reconfig_data {
	struct device_node___83 *dn;
	struct property___79 *prop;
	struct property___79 *old_prop;
};

enum of_reconfig_change {
	OF_RECONFIG_NO_CHANGE = 0,
	OF_RECONFIG_CHANGE_ADD = 1,
	OF_RECONFIG_CHANGE_REMOVE = 2,
};

struct irq_desc___20;

typedef void (*irq_flow_handler_t___20)(struct irq_desc___20 *);

struct irq_chip___27;

struct irq_data___27 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___11 *common;
	struct irq_chip___27 *chip;
	struct irq_domain___27 *domain;
	struct irq_data___27 *parent_data;
	void *chip_data;
};

struct irqaction___17;

struct irq_desc___20 {
	struct irq_common_data___11 irq_common_data;
	struct irq_data___27 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___20 handle_irq;
	struct irqaction___17 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int irq_count;
	unsigned int tot_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___358 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___302 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip___27 {
	struct device___338 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___27 *);
	void (*irq_shutdown)(struct irq_data___27 *);
	void (*irq_enable)(struct irq_data___27 *);
	void (*irq_disable)(struct irq_data___27 *);
	void (*irq_ack)(struct irq_data___27 *);
	void (*irq_mask)(struct irq_data___27 *);
	void (*irq_mask_ack)(struct irq_data___27 *);
	void (*irq_unmask)(struct irq_data___27 *);
	void (*irq_eoi)(struct irq_data___27 *);
	int (*irq_set_affinity)(struct irq_data___27 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___27 *);
	int (*irq_set_type)(struct irq_data___27 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___27 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___27 *);
	void (*irq_bus_sync_unlock)(struct irq_data___27 *);
	void (*irq_cpu_online)(struct irq_data___27 *);
	void (*irq_cpu_offline)(struct irq_data___27 *);
	void (*irq_suspend)(struct irq_data___27 *);
	void (*irq_resume)(struct irq_data___27 *);
	void (*irq_pm_shutdown)(struct irq_data___27 *);
	void (*irq_calc_mask)(struct irq_data___27 *);
	void (*irq_print_chip)(struct irq_data___27 *, struct seq_file___315 *);
	int (*irq_request_resources)(struct irq_data___27 *);
	void (*irq_release_resources)(struct irq_data___27 *);
	void (*irq_compose_msi_msg)(struct irq_data___27 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___27 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___27 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___27 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___27 *, void *);
	void (*ipi_send_single)(struct irq_data___27 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___27 *, const struct cpumask *);
	long unsigned int flags;
};

struct irqaction___17 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___17 *next;
	irq_handler_t thread_fn;
	struct task_struct___372 *thread;
	struct irqaction___17 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip_type___16 {
	struct irq_chip___27 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___20 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___16 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___16 *);
	void (*resume)(struct irq_chip_generic___16 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___27 *domain;
	struct list_head list;
	struct irq_chip_type___16 chip_types[0];
};

struct irq_domain_chip_generic___15 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___16 *gc[0];
};

struct irq_fwspec___27 {
	struct fwnode_handle___260 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___27 {
	int (*match)(struct irq_domain___27 *, struct device_node___83 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___27 *, struct irq_fwspec___27 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___27 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___27 *, unsigned int);
	int (*xlate)(struct irq_domain___27 *, struct device_node___83 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___27 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___27 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___27 *, struct irq_data___27 *, bool);
	void (*deactivate)(struct irq_domain___27 *, struct irq_data___27 *);
	int (*translate)(struct irq_domain___27 *, struct irq_fwspec___27 *, long unsigned int *, unsigned int *);
};

struct kthread_work___232;

typedef void (*kthread_work_func_t___232)(struct kthread_work___232 *);

struct kthread_worker___232;

struct kthread_work___232 {
	struct list_head node;
	kthread_work_func_t___232 func;
	struct kthread_worker___232 *worker;
	int canceling;
};

struct kthread_worker___232 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___372 *task;
	struct kthread_work___232 *current_work;
};

struct kthread_delayed_work___232 {
	struct kthread_work___232 work;
	struct timer_list timer;
};

struct spi_controller___2;

struct spi_device___2 {
	struct device___338 dev;
	struct spi_controller___2 *controller;
	struct spi_controller___2 *master;
	u32 max_speed_hz;
	u8 chip_select;
	u8 bits_per_word;
	u16 mode;
	int irq;
	void *controller_state;
	void *controller_data;
	char modalias[32];
	const char *driver_override;
	int cs_gpio;
	struct gpio_desc *cs_gpiod;
	uint8_t word_delay_usecs;
	struct spi_statistics statistics;
};

struct spi_message___2;

struct spi_controller_mem_ops___2;

struct spi_controller___2 {
	struct device___338 dev;
	struct list_head list;
	s16 bus_num;
	u16 num_chipselect;
	u16 dma_alignment;
	u16 mode_bits;
	u32 bits_per_word_mask;
	u32 min_speed_hz;
	u32 max_speed_hz;
	u16 flags;
	bool slave;
	size_t (*max_transfer_size)(struct spi_device___2 *);
	size_t (*max_message_size)(struct spi_device___2 *);
	struct mutex io_mutex;
	spinlock_t bus_lock_spinlock;
	struct mutex bus_lock_mutex;
	bool bus_lock_flag;
	int (*setup)(struct spi_device___2 *);
	int (*transfer)(struct spi_device___2 *, struct spi_message___2 *);
	void (*cleanup)(struct spi_device___2 *);
	bool (*can_dma)(struct spi_controller___2 *, struct spi_device___2 *, struct spi_transfer *);
	bool queued;
	struct kthread_worker___232 kworker;
	struct task_struct___372 *kworker_task;
	struct kthread_work___232 pump_messages;
	spinlock_t queue_lock;
	struct list_head queue;
	struct spi_message___2 *cur_msg;
	bool idling;
	bool busy;
	bool running;
	bool rt;
	bool auto_runtime_pm;
	bool cur_msg_prepared;
	bool cur_msg_mapped;
	struct completion xfer_completion;
	size_t max_dma_len;
	int (*prepare_transfer_hardware)(struct spi_controller___2 *);
	int (*transfer_one_message)(struct spi_controller___2 *, struct spi_message___2 *);
	int (*unprepare_transfer_hardware)(struct spi_controller___2 *);
	int (*prepare_message)(struct spi_controller___2 *, struct spi_message___2 *);
	int (*unprepare_message)(struct spi_controller___2 *, struct spi_message___2 *);
	int (*slave_abort)(struct spi_controller___2 *);
	void (*set_cs)(struct spi_device___2 *, bool);
	int (*transfer_one)(struct spi_controller___2 *, struct spi_device___2 *, struct spi_transfer *);
	void (*handle_err)(struct spi_controller___2 *, struct spi_message___2 *);
	const struct spi_controller_mem_ops___2 *mem_ops;
	int *cs_gpios;
	struct gpio_desc **cs_gpiods;
	bool use_gpio_descriptors;
	struct spi_statistics statistics;
	struct dma_chan___8 *dma_tx;
	struct dma_chan___8 *dma_rx;
	void *dummy_rx;
	void *dummy_tx;
	int (*fw_translate_cs)(struct spi_controller___2 *, unsigned int);
};

struct spi_driver {
	const struct spi_device_id *id_table;
	int (*probe)(struct spi_device___2 *);
	int (*remove)(struct spi_device___2 *);
	void (*shutdown)(struct spi_device___2 *);
	struct device_driver___338 driver;
};

struct spi_message___2 {
	struct list_head transfers;
	struct spi_device___2 *spi;
	unsigned int is_dma_mapped: 1;
	void (*complete)(void *);
	void *context;
	unsigned int frame_length;
	unsigned int actual_length;
	int status;
	struct list_head queue;
	void *state;
	struct list_head resources;
};

struct spi_mem;

struct spi_mem_op;

struct spi_controller_mem_ops___2 {
	int (*adjust_op_size)(struct spi_mem *, struct spi_mem_op *);
	bool (*supports_op)(struct spi_mem *, const struct spi_mem_op *);
	int (*exec_op)(struct spi_mem *, const struct spi_mem_op *);
};

typedef void (*spi_res_release_t)(struct spi_controller___2 *, struct spi_message___2 *, void *);

struct spi_res {
	struct list_head entry;
	spi_res_release_t release;
	long long unsigned int data[0];
};

struct spi_replaced_transfers;

typedef void (*spi_replaced_release_t)(struct spi_controller___2 *, struct spi_message___2 *, struct spi_replaced_transfers *);

struct spi_replaced_transfers {
	spi_replaced_release_t release;
	void *extradata;
	struct list_head replaced_transfers;
	struct list_head *replaced_after;
	size_t inserted;
	struct spi_transfer inserted_transfers[0];
};

struct spi_board_info {
	char modalias[32];
	const void *platform_data;
	const struct property_entry___2 *properties;
	void *controller_data;
	int irq;
	u32 max_speed_hz;
	u16 bus_num;
	u16 chip_select;
	u16 mode;
};

enum spi_mem_data_dir {
	SPI_MEM_DATA_IN = 0,
	SPI_MEM_DATA_OUT = 1,
};

struct spi_mem_op {
	struct {
		u8 buswidth;
		u8 opcode;
	} cmd;
	struct {
		u8 nbytes;
		u8 buswidth;
		u64 val;
	} addr;
	struct {
		u8 nbytes;
		u8 buswidth;
	} dummy;
	struct {
		u8 buswidth;
		enum spi_mem_data_dir dir;
		unsigned int nbytes;
		union {
			void *in;
			const void *out;
		} buf;
	} data;
};

struct spi_mem {
	struct spi_device___2 *spi;
	void *drvpriv;
};

typedef int (*key_restrict_link_func_t___343)(struct key___342 *, const struct key_type *, const union key_payload *, struct key___342 *);

struct key_restriction___342;

struct key___342 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___372 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___342 *restrict_link;
};

struct key_restriction___342 {
	key_restrict_link_func_t___343 check;
	struct key___342 *key;
	struct key_type *keytype;
};

struct seq_operations___314 {
	void * (*start)(struct seq_file___315 *, loff_t *);
	void (*stop)(struct seq_file___315 *, void *);
	void * (*next)(struct seq_file___315 *, void *, loff_t *);
	int (*show)(struct seq_file___315 *, void *);
};

struct dev_power_governor___6 {
	bool (*power_down_ok)(struct dev_pm_domain___338 *);
	bool (*suspend_ok)(struct device___338 *);
};

struct kernel_param_ops___299 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___299 *);
	int (*get)(char *, const struct kernel_param___299 *);
	void (*free)(void *);
};

struct kparam_array___299;

struct kernel_param___299 {
	const char *name;
	struct module___302 *mod;
	const struct kernel_param_ops___299 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___299 *arr;
	};
};

struct kparam_array___299 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___299 *ops;
	void *elem;
};

struct module_attribute___299 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___299 *, struct module_kobject___299 *, char *);
	ssize_t (*store)(struct module_attribute___299 *, struct module_kobject___299 *, const char *, size_t);
	void (*setup)(struct module___302 *, const char *);
	int (*test)(struct module___302 *);
	void (*free)(struct module___302 *);
};

struct trace_event_class___135;

struct trace_event_call___135 {
	struct list_head list;
	struct trace_event_class___135 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___13 event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___38 *prog_array;
	int (*perf_perm)(struct trace_event_call___135 *, struct perf_event___142 *);
};

struct acpi_device___17;

struct acpi_hotplug_profile___17 {
	struct kobject___358 kobj;
	int (*scan_dependent)(struct acpi_device___17 *);
	void (*notify_online)(struct acpi_device___17 *);
	bool enabled: 1;
	bool demand_offline: 1;
};

struct acpi_device_wakeup_context___17 {
	void (*func)(struct acpi_device_wakeup_context___17 *);
	struct device___338 *dev;
};

struct acpi_device_wakeup___17 {
	acpi_handle gpe_device;
	u64 gpe_number;
	u64 sleep_state;
	struct list_head resources;
	struct acpi_device_wakeup_flags flags;
	struct acpi_device_wakeup_context___17 context;
	struct wakeup_source___8 *ws;
	int prepare_count;
	int enable_count;
};

struct acpi_scan_handler___17;

struct acpi_hotplug_context___17;

struct acpi_driver___17;

struct acpi_device___17 {
	int device_type;
	acpi_handle handle;
	struct fwnode_handle___260 fwnode;
	struct acpi_device___17 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup___17 wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_device_data data;
	struct acpi_scan_handler___17 *handler;
	struct acpi_hotplug_context___17 *hp;
	struct acpi_driver___17 *driver;
	const struct acpi_gpio_mapping *driver_gpios;
	void *driver_data;
	struct device___338 dev;
	unsigned int physical_node_count;
	unsigned int dep_unmet;
	struct list_head physical_node_list;
	struct mutex physical_node_lock;
	void (*remove)(struct acpi_device___17 *);
};

struct acpi_scan_handler___17 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	bool (*match)(const char *, const struct acpi_device_id **);
	int (*attach)(struct acpi_device___17 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___17 *);
	void (*bind)(struct device___338 *);
	void (*unbind)(struct device___338 *);
	struct acpi_hotplug_profile___17 hotplug;
};

struct acpi_hotplug_context___17 {
	struct acpi_device___17 *self;
	int (*notify)(struct acpi_device___17 *, u32);
	void (*uevent)(struct acpi_device___17 *, u32);
	void (*fixup)(struct acpi_device___17 *);
};

typedef int (*acpi_op_add___17)(struct acpi_device___17 *);

typedef int (*acpi_op_remove___17)(struct acpi_device___17 *);

typedef void (*acpi_op_notify___17)(struct acpi_device___17 *, u32);

struct acpi_device_ops___17 {
	acpi_op_add___17 add;
	acpi_op_remove___17 remove;
	acpi_op_notify___17 notify;
};

struct acpi_driver___17 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___17 ops;
	struct device_driver___338 drv;
	struct module___302 *owner;
};

struct cgroup_namespace___232 {
	refcount_t count;
	struct ns_common___9 ns;
	struct user_namespace___247 *user_ns;
	struct ucounts___247 *ucounts;
	struct css_set___232 *root_cset;
};

struct ucounts___247 {
	struct hlist_node node;
	struct user_namespace___247 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___233;

struct bpf_map_ops___232 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___233 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___233 *, struct file___371 *);
	void (*map_free)(struct bpf_map___233 *);
	int (*map_get_next_key)(struct bpf_map___233 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___233 *);
	void * (*map_lookup_elem)(struct bpf_map___233 *, void *);
	int (*map_update_elem)(struct bpf_map___233 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___233 *, void *);
	int (*map_push_elem)(struct bpf_map___233 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___233 *, void *);
	int (*map_peek_elem)(struct bpf_map___233 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___233 *, struct file___371 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___233 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___233 *, void *, struct seq_file___315 *);
	int (*map_check_btf)(const struct bpf_map___233 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___233 {
	const struct bpf_map_ops___232 *ops;
	struct bpf_map___233 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___342 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct psi_group___232 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___232 *poll_kworker;
	struct kthread_delayed_work___232 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___232 {
	struct kernfs_node___365 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___232;

struct cgroup_subsys_state___232 {
	struct cgroup___232 *cgroup;
	struct cgroup_subsys___232 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___232 *parent;
};

struct cgroup_root___232;

struct cgroup_rstat_cpu___232;

struct cgroup___232 {
	struct cgroup_subsys_state___232 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___365 *kn;
	struct cgroup_file___232 procs_file;
	struct cgroup_file___232 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___232 *subsys[13];
	struct cgroup_root___232 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___232 *dom_cgrp;
	struct cgroup_rstat_cpu___232 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___38 bpf;
	atomic_t congestion_count;
	struct cgroup___232 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___232 psi;
	int ancestor_ids[0];
};

struct cftype___232;

struct cgroup_subsys___232 {
	struct cgroup_subsys_state___232 * (*css_alloc)(struct cgroup_subsys_state___232 *);
	int (*css_online)(struct cgroup_subsys_state___232 *);
	void (*css_offline)(struct cgroup_subsys_state___232 *);
	void (*css_released)(struct cgroup_subsys_state___232 *);
	void (*css_free)(struct cgroup_subsys_state___232 *);
	void (*css_reset)(struct cgroup_subsys_state___232 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___232 *, int);
	int (*css_extra_stat_show)(struct seq_file___315 *, struct cgroup_subsys_state___232 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___372 *);
	void (*cancel_fork)(struct task_struct___372 *);
	void (*fork)(struct task_struct___372 *);
	void (*exit)(struct task_struct___372 *);
	void (*free)(struct task_struct___372 *);
	void (*bind)(struct cgroup_subsys_state___232 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___232 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___232 *dfl_cftypes;
	struct cftype___232 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___232 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___232 *updated_children;
	struct cgroup___232 *updated_next;
};

struct cgroup_root___232 {
	struct kernfs_root___364 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___232 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___232 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___232 *ss;
	struct list_head node;
	struct kernfs_ops___364 *kf_ops;
	int (*open)(struct kernfs_open_file___364 *);
	void (*release)(struct kernfs_open_file___364 *);
	u64 (*read_u64)(struct cgroup_subsys_state___232 *, struct cftype___232 *);
	s64 (*read_s64)(struct cgroup_subsys_state___232 *, struct cftype___232 *);
	int (*seq_show)(struct seq_file___315 *, void *);
	void * (*seq_start)(struct seq_file___315 *, loff_t *);
	void * (*seq_next)(struct seq_file___315 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___315 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___232 *, struct cftype___232 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___232 *, struct cftype___232 *, s64);
	ssize_t (*write)(struct kernfs_open_file___364 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___364 *, struct poll_table_struct___224 *);
};

struct perf_cpu_context___142;

struct pmu___142 {
	struct list_head entry;
	struct module___302 *module;
	struct device___338 *dev;
	const struct attribute_group___335 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___142 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___142 *);
	void (*pmu_disable)(struct pmu___142 *);
	int (*event_init)(struct perf_event___142 *);
	void (*event_mapped)(struct perf_event___142 *, struct mm_struct___371 *);
	void (*event_unmapped)(struct perf_event___142 *, struct mm_struct___371 *);
	int (*add)(struct perf_event___142 *, int);
	void (*del)(struct perf_event___142 *, int);
	void (*start)(struct perf_event___142 *, int);
	void (*stop)(struct perf_event___142 *, int);
	void (*read)(struct perf_event___142 *);
	void (*start_txn)(struct pmu___142 *, unsigned int);
	int (*commit_txn)(struct pmu___142 *);
	void (*cancel_txn)(struct pmu___142 *);
	int (*event_idx)(struct perf_event___142 *);
	void (*sched_task)(struct perf_event_context___142 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___142 *);
	int (*filter_match)(struct perf_event___142 *);
	int (*check_period)(struct perf_event___142 *, u64);
};

struct perf_cpu_context___142 {
	struct perf_event_context___142 ctx;
	struct perf_event_context___142 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___142 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___142 {
	struct cgroup_subsys_state___232 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___135 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___135 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___135 *);
	struct list_head * (*get_fields)(struct trace_event_call___135 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___135 *);
};

struct trace_event_file___54;

struct trace_event_buffer___46 {
	struct ring_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___54 *trace_file;
	void *entry;
	long unsigned int flags;
	int pc;
};

struct trace_event_file___54 {
	struct list_head list;
	struct trace_event_call___135 *event_call;
	struct event_filter *filter;
	struct dentry___370 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_spi_controller {
	struct trace_entry ent;
	int bus_num;
	char __data[0];
};

struct trace_event_raw_spi_message {
	struct trace_entry ent;
	int bus_num;
	int chip_select;
	struct spi_message___2 *msg;
	char __data[0];
};

struct trace_event_raw_spi_message_done {
	struct trace_entry ent;
	int bus_num;
	int chip_select;
	struct spi_message___2 *msg;
	unsigned int frame;
	unsigned int actual;
	char __data[0];
};

struct trace_event_raw_spi_transfer {
	struct trace_entry ent;
	int bus_num;
	int chip_select;
	struct spi_transfer *xfer;
	int len;
	char __data[0];
};

struct trace_event_data_offsets_spi_controller {};

struct trace_event_data_offsets_spi_message {};

struct trace_event_data_offsets_spi_message_done {};

struct trace_event_data_offsets_spi_transfer {};

struct boardinfo {
	struct list_head list;
	struct spi_board_info board_info;
};

struct module___303;

struct file___372;

struct kiocb___372;

struct vm_area_struct___373;

struct inode___372;

struct file_lock___372;

struct page___373;

struct file_operations___372 {
	struct module___303 *owner;
	loff_t (*llseek)(struct file___372 *, loff_t, int);
	ssize_t (*read)(struct file___372 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___372 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___372 *, struct iov_iter___156 *);
	ssize_t (*write_iter)(struct kiocb___372 *, struct iov_iter___156 *);
	int (*iopoll)(struct kiocb___372 *, bool);
	int (*iterate)(struct file___372 *, struct dir_context *);
	int (*iterate_shared)(struct file___372 *, struct dir_context *);
	__poll_t (*poll)(struct file___372 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___372 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___372 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___372 *, struct vm_area_struct___373 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___372 *, struct file___372 *);
	int (*flush)(struct file___372 *, fl_owner_t);
	int (*release)(struct inode___372 *, struct file___372 *);
	int (*fsync)(struct file___372 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___372 *, int);
	int (*lock)(struct file___372 *, int, struct file_lock___372 *);
	ssize_t (*sendpage)(struct file___372 *, struct page___373 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___372 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___372 *, int, struct file_lock___372 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___372 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___372 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___372 *, long int, struct file_lock___372 **, void **);
	long int (*fallocate)(struct file___372 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___372 *);
	ssize_t (*copy_file_range)(struct file___372 *, loff_t, struct file___372 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___372 *, loff_t, struct file___372 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___372 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___372 {
	u64 seqnum;
	struct vm_area_struct___373 *vmas[4];
};

struct page_frag___372 {
	struct page___373 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___372;

struct vm_struct___278;

struct task_struct___373 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___373 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___372 *mm;
	struct mm_struct___372 *active_mm;
	struct vmacache___372 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___373 *real_parent;
	struct task_struct___373 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___373 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___218 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___218 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___218 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___2 *ptracer_cred;
	const struct cred___2 *real_cred;
	const struct cred___2 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___373 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___107 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___372 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___373 *oom_reaper_list;
	struct vm_struct___278 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___142 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rw_semaphore___373 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___373 *owner;
};

struct secondary_data___373 {
	void *stack;
	struct task_struct___373 *task;
	long int status;
};

struct blocking_notifier_head___372 {
	struct rw_semaphore___373 rwsem;
	struct notifier_block *head;
};

typedef struct page___373 *pgtable_t___372;

struct address_space___371;

struct dev_pagemap___360;

struct page___373 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___371 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___373 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___372 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___372 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___360 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct vm_operations_struct___360;

struct vm_area_struct___373 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___373 *vm_next;
	struct vm_area_struct___373 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___372 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___360 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___372 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___372;

struct mm_struct___372 {
	struct {
		struct vm_area_struct___373 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___372 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___373 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___372 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___373 *owner;
		struct user_namespace___3 *user_ns;
		struct file___372 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___372 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___371;

struct address_space___371 {
	struct inode___372 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___373 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___371 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___360)(struct vm_area_struct___373 *, long unsigned int, const struct page___373 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___360)(struct page___373 *, void *);

struct device___339;

struct dev_pagemap___360 {
	dev_page_fault_t___360 page_fault;
	dev_page_free_t___360 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___339 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct dentry___371;

struct path___372 {
	struct vfsmount *mnt;
	struct dentry___371 *dentry;
};

struct file___372 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___372 f_path;
	struct inode___372 *f_inode;
	const struct file_operations___372 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___218 f_owner;
	const struct cred___2 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___371 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___360;

struct vm_operations_struct___360 {
	void (*open)(struct vm_area_struct___373 *);
	void (*close)(struct vm_area_struct___373 *);
	int (*split)(struct vm_area_struct___373 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___373 *);
	vm_fault_t (*fault)(struct vm_fault___360 *);
	vm_fault_t (*huge_fault)(struct vm_fault___360 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___360 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___373 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___360 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___360 *);
	int (*access)(struct vm_area_struct___373 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___373 *);
	int (*set_policy)(struct vm_area_struct___373 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___373 *, long unsigned int);
	struct page___373 * (*find_special_page)(struct vm_area_struct___373 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___372 {
	struct task_struct___373 *task;
	struct core_thread___372 *next;
};

struct core_state___372 {
	atomic_t nr_threads;
	struct core_thread___372 dumper;
	struct completion startup;
};

struct vm_fault___360 {
	struct vm_area_struct___373 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___373 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___373 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___372 prealloc_pte;
};

struct vm_struct___278 {
	struct vm_struct___278 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___373 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct fwnode_operations___261;

struct fwnode_handle___261 {
	struct fwnode_handle___261 *secondary;
	const struct fwnode_operations___261 *ops;
};

struct fwnode_reference_args___261;

struct fwnode_endpoint___261;

struct fwnode_operations___261 {
	struct fwnode_handle___261 * (*get)(struct fwnode_handle___261 *);
	void (*put)(struct fwnode_handle___261 *);
	bool (*device_is_available)(const struct fwnode_handle___261 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___261 *, const struct device___339 *);
	bool (*property_present)(const struct fwnode_handle___261 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___261 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___261 *, const char *, const char **, size_t);
	struct fwnode_handle___261 * (*get_parent)(const struct fwnode_handle___261 *);
	struct fwnode_handle___261 * (*get_next_child_node)(const struct fwnode_handle___261 *, struct fwnode_handle___261 *);
	struct fwnode_handle___261 * (*get_named_child_node)(const struct fwnode_handle___261 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___261 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___261 *);
	struct fwnode_handle___261 * (*graph_get_next_endpoint)(const struct fwnode_handle___261 *, struct fwnode_handle___261 *);
	struct fwnode_handle___261 * (*graph_get_remote_endpoint)(const struct fwnode_handle___261 *);
	struct fwnode_handle___261 * (*graph_get_port_parent)(struct fwnode_handle___261 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___261 *, struct fwnode_endpoint___261 *);
};

struct fwnode_endpoint___261 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___261 *local_fwnode;
};

struct fwnode_reference_args___261 {
	struct fwnode_handle___261 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct kset___358;

struct kobj_type___358;

struct kernfs_node___366;

struct kobject___359 {
	const char *name;
	struct list_head entry;
	struct kobject___359 *parent;
	struct kset___358 *kset;
	struct kobj_type___358 *ktype;
	struct kernfs_node___366 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___339 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___6 *subsys_data;
	void (*set_latency_tolerance)(struct device___339 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___339;

struct bus_type___339;

struct device_driver___339;

struct dev_pm_domain___339;

struct dma_map_ops___127;

struct device_node___84;

struct class___339;

struct attribute_group___336;

struct device___339 {
	struct device___339 *parent;
	struct device_private *p;
	struct kobject___359 kobj;
	const char *init_name;
	const struct device_type___339 *type;
	struct mutex mutex;
	struct bus_type___339 *bus;
	struct device_driver___339 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___339 power;
	struct dev_pm_domain___339 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___127 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___84 *of_node;
	struct fwnode_handle___261 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___339 *class;
	const struct attribute_group___336 **groups;
	void (*release)(struct device___339 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct pglist_data___372;

struct lruvec___372 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___372 *pgdat;
};

struct zone___372 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___372 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___372 {
	struct zone___372 *zone;
	int zone_idx;
};

struct zonelist___372 {
	struct zoneref___372 _zonerefs[25];
};

struct pglist_data___372 {
	struct zone___372 node_zones[3];
	struct zonelist___372 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___373 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___373 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___372 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct kernfs_root___365;

struct kernfs_elem_dir___365 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___365 *root;
};

struct kernfs_syscall_ops___365;

struct kernfs_root___365 {
	struct kernfs_node___366 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___365 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___365 {
	struct kernfs_node___366 *target_kn;
};

struct kernfs_ops___365;

struct kernfs_elem_attr___365 {
	const struct kernfs_ops___365 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___366 *notify_next;
};

struct kernfs_node___366 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___366 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___365 dir;
		struct kernfs_elem_symlink___365 symlink;
		struct kernfs_elem_attr___365 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___365;

struct kernfs_ops___365 {
	int (*open)(struct kernfs_open_file___365 *);
	void (*release)(struct kernfs_open_file___365 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___365 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___365 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___365 *, struct vm_area_struct___373 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___365 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___365 {
	int (*remount_fs)(struct kernfs_root___365 *, int *, char *);
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___365 *);
	int (*mkdir)(struct kernfs_node___366 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___366 *);
	int (*rename)(struct kernfs_node___366 *, struct kernfs_node___366 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___366 *, struct kernfs_root___365 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___365 {
	struct kernfs_node___366 *kn;
	struct file___372 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___360 *vm_ops;
};

struct bin_attribute___335;

struct attribute_group___336 {
	const char *name;
	umode_t (*is_visible)(struct kobject___359 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___359 *, struct bin_attribute___335 *, int);
	struct attribute **attrs;
	struct bin_attribute___335 **bin_attrs;
};

struct bin_attribute___335 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___372 *, struct kobject___359 *, struct bin_attribute___335 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___372 *, struct kobject___359 *, struct bin_attribute___335 *, char *, loff_t, size_t);
	int (*mmap)(struct file___372 *, struct kobject___359 *, struct bin_attribute___335 *, struct vm_area_struct___373 *);
};

struct sysfs_ops___358 {
	ssize_t (*show)(struct kobject___359 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___359 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___358;

struct kset___358 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___359 kobj;
	const struct kset_uevent_ops___358 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___358 {
	void (*release)(struct kobject___359 *);
	const struct sysfs_ops___358 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___28 * (*child_ns_type)(struct kobject___359 *);
	const void * (*namespace)(struct kobject___359 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___358 {
	int (* const filter)(struct kset___358 *, struct kobject___359 *);
	const char * (* const name)(struct kset___358 *, struct kobject___359 *);
	int (* const uevent)(struct kset___358 *, struct kobject___359 *, struct kobj_uevent_env *);
};

struct kobj_attribute___350 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___359 *, struct kobj_attribute___350 *, char *);
	ssize_t (*store)(struct kobject___359 *, struct kobj_attribute___350 *, const char *, size_t);
};

struct kernel_param___300;

struct kernel_param_ops___300 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___300 *);
	int (*get)(char *, const struct kernel_param___300 *);
	void (*free)(void *);
};

struct kparam_array___300;

struct kernel_param___300 {
	const char *name;
	struct module___303 *mod;
	const struct kernel_param_ops___300 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___300 *arr;
	};
};

struct kparam_array___300 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___300 *ops;
	void *elem;
};

struct module_kobject___300 {
	struct kobject___359 kobj;
	struct module___303 *mod;
	struct kobject___359 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___300 {
	struct module___303 *mod;
	struct latch_tree_node node;
};

struct module_layout___300 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___300 mtn;
};

struct module_attribute___300;

struct module___303 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___300 mkobj;
	struct module_attribute___300 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___359 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___300 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___300 core_layout;
	struct module_layout___300 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___300 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___300 *, struct module_kobject___300 *, char *);
	ssize_t (*store)(struct module_attribute___300 *, struct module_kobject___300 *, const char *, size_t);
	void (*setup)(struct module___303 *, const char *);
	int (*test)(struct module___303 *);
	void (*free)(struct module___303 *);
};

struct property___80 {
	char *name;
	int length;
	void *value;
	struct property___80 *next;
	long unsigned int _flags;
	struct bin_attribute___335 attr;
};

struct device_node___84 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___261 fwnode;
	struct property___80 *properties;
	struct property___80 *deadprops;
	struct device_node___84 *parent;
	struct device_node___84 *child;
	struct device_node___84 *sibling;
	struct kobject___359 kobj;
	long unsigned int _flags;
	void *data;
};

struct dev_pm_ops___339 {
	int (*prepare)(struct device___339 *);
	void (*complete)(struct device___339 *);
	int (*suspend)(struct device___339 *);
	int (*resume)(struct device___339 *);
	int (*freeze)(struct device___339 *);
	int (*thaw)(struct device___339 *);
	int (*poweroff)(struct device___339 *);
	int (*restore)(struct device___339 *);
	int (*suspend_late)(struct device___339 *);
	int (*resume_early)(struct device___339 *);
	int (*freeze_late)(struct device___339 *);
	int (*thaw_early)(struct device___339 *);
	int (*poweroff_late)(struct device___339 *);
	int (*restore_early)(struct device___339 *);
	int (*suspend_noirq)(struct device___339 *);
	int (*resume_noirq)(struct device___339 *);
	int (*freeze_noirq)(struct device___339 *);
	int (*thaw_noirq)(struct device___339 *);
	int (*poweroff_noirq)(struct device___339 *);
	int (*restore_noirq)(struct device___339 *);
	int (*runtime_suspend)(struct device___339 *);
	int (*runtime_resume)(struct device___339 *);
	int (*runtime_idle)(struct device___339 *);
};

struct dev_pm_domain___339 {
	struct dev_pm_ops___339 ops;
	void (*detach)(struct device___339 *, bool);
	int (*activate)(struct device___339 *);
	void (*sync)(struct device___339 *);
	void (*dismiss)(struct device___339 *);
};

struct bus_type___339 {
	const char *name;
	const char *dev_name;
	struct device___339 *dev_root;
	const struct attribute_group___336 **bus_groups;
	const struct attribute_group___336 **dev_groups;
	const struct attribute_group___336 **drv_groups;
	int (*match)(struct device___339 *, struct device_driver___339 *);
	int (*uevent)(struct device___339 *, struct kobj_uevent_env *);
	int (*probe)(struct device___339 *);
	int (*remove)(struct device___339 *);
	void (*shutdown)(struct device___339 *);
	int (*online)(struct device___339 *);
	int (*offline)(struct device___339 *);
	int (*suspend)(struct device___339 *, pm_message_t);
	int (*resume)(struct device___339 *);
	int (*num_vf)(struct device___339 *);
	int (*dma_configure)(struct device___339 *);
	const struct dev_pm_ops___339 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___339 {
	const char *name;
	struct bus_type___339 *bus;
	struct module___303 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___339 *);
	int (*remove)(struct device___339 *);
	void (*shutdown)(struct device___339 *);
	int (*suspend)(struct device___339 *, pm_message_t);
	int (*resume)(struct device___339 *);
	const struct attribute_group___336 **groups;
	const struct dev_pm_ops___339 *pm;
	void (*coredump)(struct device___339 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___339 {
	const char *name;
	const struct attribute_group___336 **groups;
	int (*uevent)(struct device___339 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___339 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___339 *);
	const struct dev_pm_ops___339 *pm;
};

struct class___339 {
	const char *name;
	struct module___303 *owner;
	const struct attribute_group___336 **class_groups;
	const struct attribute_group___336 **dev_groups;
	struct kobject___359 *dev_kobj;
	int (*dev_uevent)(struct device___339 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___339 *, umode_t *);
	void (*class_release)(struct class___339 *);
	void (*dev_release)(struct device___339 *);
	int (*shutdown_pre)(struct device___339 *);
	const struct kobj_ns_type_operations___28 *ns_type;
	const void * (*namespace)(struct device___339 *);
	const struct dev_pm_ops___339 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___127 {
	void * (*alloc)(struct device___339 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___339 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___339 *, struct vm_area_struct___373 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___339 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___339 *, struct page___373 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___339 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___339 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___339 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___339 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___339 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___339 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___339 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___339 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___339 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___339 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___339 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___339 *, u64);
	u64 (*get_required_mask)(struct device___339 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct node___208 {
	struct device___339 dev;
};

struct platform_device___20 {
	const char *name;
	int id;
	bool id_auto;
	struct device___339 dev;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct platform_driver___17 {
	int (*probe)(struct platform_device___20 *);
	int (*remove)(struct platform_device___20 *);
	void (*shutdown)(struct platform_device___20 *);
	int (*suspend)(struct platform_device___20 *, pm_message_t);
	int (*resume)(struct platform_device___20 *);
	struct device_driver___339 driver;
	const struct platform_device_id *id_table;
	bool prevent_deferred_probe;
};

struct kthread_work___233;

typedef void (*kthread_work_func_t___233)(struct kthread_work___233 *);

struct kthread_worker___233;

struct kthread_work___233 {
	struct list_head node;
	kthread_work_func_t___233 func;
	struct kthread_worker___233 *worker;
	int canceling;
};

struct kthread_worker___233 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___373 *task;
	struct kthread_work___233 *current_work;
};

struct dentry_operations___371;

struct super_block___371;

struct dentry___371 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___371 *d_parent;
	struct qstr d_name;
	struct inode___372 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___371 *d_op;
	struct super_block___371 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___371;

struct block_device___371;

struct inode___372 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___371 *i_op;
	struct super_block___371 *i_sb;
	struct address_space___371 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___373 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___372 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___371 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___371 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___371 {
	int (*d_revalidate)(struct dentry___371 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___371 *, unsigned int);
	int (*d_hash)(const struct dentry___371 *, struct qstr *);
	int (*d_compare)(const struct dentry___371 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___371 *);
	int (*d_init)(struct dentry___371 *);
	void (*d_release)(struct dentry___371 *);
	void (*d_prune)(struct dentry___371 *);
	void (*d_iput)(struct dentry___371 *, struct inode___372 *);
	char * (*d_dname)(struct dentry___371 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___372 *);
	int (*d_manage)(const struct path___372 *, bool);
	struct dentry___371 * (*d_real)(struct dentry___371 *, const struct inode___372 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___371;

struct mem_dqinfo___371 {
	struct quota_format_type___371 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___371;

struct quota_info___371 {
	unsigned int flags;
	struct rw_semaphore___373 dqio_sem;
	struct inode___372 *files[3];
	struct mem_dqinfo___371 info[3];
	const struct quota_format_ops___371 *ops[3];
};

struct rcuwait___371 {
	struct task_struct___373 *task;
};

struct percpu_rw_semaphore___371 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___373 rw_sem;
	struct rcuwait___371 writer;
	int readers_block;
};

struct sb_writers___371 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___371 rw_sem[3];
};

struct file_system_type___371;

struct super_operations___371;

struct dquot_operations___371;

struct quotactl_ops___371;

struct super_block___371 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___371 *s_type;
	const struct super_operations___371 *s_op;
	const struct dquot_operations___371 *dq_op;
	const struct quotactl_ops___371 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___371 *s_root;
	struct rw_semaphore___373 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___371 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___371 s_dquot;
	struct sb_writers___371 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___371 *s_d_op;
	int cleancache_poolid;
	struct shrinker___133 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___372 {
	struct file___372 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___372 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___371 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___372 *ia_file;
};

struct dquot___371 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___371 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___371 {
	int qf_fmt_id;
	const struct quota_format_ops___371 *qf_ops;
	struct module___303 *qf_owner;
	struct quota_format_type___371 *qf_next;
};

struct quota_format_ops___371 {
	int (*check_quota_file)(struct super_block___371 *, int);
	int (*read_file_info)(struct super_block___371 *, int);
	int (*write_file_info)(struct super_block___371 *, int);
	int (*free_file_info)(struct super_block___371 *, int);
	int (*read_dqblk)(struct dquot___371 *);
	int (*commit_dqblk)(struct dquot___371 *);
	int (*release_dqblk)(struct dquot___371 *);
	int (*get_next_id)(struct super_block___371 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___371 {
	int (*write_dquot)(struct dquot___371 *);
	struct dquot___371 * (*alloc_dquot)(struct super_block___371 *, int);
	void (*destroy_dquot)(struct dquot___371 *);
	int (*acquire_dquot)(struct dquot___371 *);
	int (*release_dquot)(struct dquot___371 *);
	int (*mark_dirty)(struct dquot___371 *);
	int (*write_info)(struct super_block___371 *, int);
	qsize_t * (*get_reserved_space)(struct inode___372 *);
	int (*get_projid)(struct inode___372 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___372 *, qsize_t *);
	int (*get_next_id)(struct super_block___371 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___371 {
	int (*quota_on)(struct super_block___371 *, int, int, const struct path___372 *);
	int (*quota_off)(struct super_block___371 *, int);
	int (*quota_enable)(struct super_block___371 *, unsigned int);
	int (*quota_disable)(struct super_block___371 *, unsigned int);
	int (*quota_sync)(struct super_block___371 *, int);
	int (*set_info)(struct super_block___371 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___371 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___371 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___371 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___371 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___371 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___371 {
	int (*writepage)(struct page___373 *, struct writeback_control___3 *);
	int (*readpage)(struct file___372 *, struct page___373 *);
	int (*writepages)(struct address_space___371 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___373 *);
	int (*readpages)(struct file___372 *, struct address_space___371 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___372 *, struct address_space___371 *, loff_t, unsigned int, unsigned int, struct page___373 **, void **);
	int (*write_end)(struct file___372 *, struct address_space___371 *, loff_t, unsigned int, unsigned int, struct page___373 *, void *);
	sector_t (*bmap)(struct address_space___371 *, sector_t);
	void (*invalidatepage)(struct page___373 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___373 *, gfp_t);
	void (*freepage)(struct page___373 *);
	ssize_t (*direct_IO)(struct kiocb___372 *, struct iov_iter___156 *);
	int (*migratepage)(struct address_space___371 *, struct page___373 *, struct page___373 *, enum migrate_mode);
	bool (*isolate_page)(struct page___373 *, isolate_mode_t);
	void (*putback_page)(struct page___373 *);
	int (*launder_page)(struct page___373 *);
	int (*is_partially_uptodate)(struct page___373 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___373 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___371 *, struct page___373 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___372 *, sector_t *);
	void (*swap_deactivate)(struct file___372 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___371 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___372 *bd_inode;
	struct super_block___371 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___371 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___371 {
	struct dentry___371 * (*lookup)(struct inode___372 *, struct dentry___371 *, unsigned int);
	const char * (*get_link)(struct dentry___371 *, struct inode___372 *, struct delayed_call *);
	int (*permission)(struct inode___372 *, int);
	struct posix_acl * (*get_acl)(struct inode___372 *, int);
	int (*readlink)(struct dentry___371 *, char *, int);
	int (*create)(struct inode___372 *, struct dentry___371 *, umode_t, bool);
	int (*link)(struct dentry___371 *, struct inode___372 *, struct dentry___371 *);
	int (*unlink)(struct inode___372 *, struct dentry___371 *);
	int (*symlink)(struct inode___372 *, struct dentry___371 *, const char *);
	int (*mkdir)(struct inode___372 *, struct dentry___371 *, umode_t);
	int (*rmdir)(struct inode___372 *, struct dentry___371 *);
	int (*mknod)(struct inode___372 *, struct dentry___371 *, umode_t, dev_t);
	int (*rename)(struct inode___372 *, struct dentry___371 *, struct inode___372 *, struct dentry___371 *, unsigned int);
	int (*setattr)(struct dentry___371 *, struct iattr___371 *);
	int (*getattr)(const struct path___372 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___371 *, char *, size_t);
	int (*fiemap)(struct inode___372 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___372 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___372 *, struct dentry___371 *, struct file___372 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___372 *, struct dentry___371 *, umode_t);
	int (*set_acl)(struct inode___372 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___371 {
	void (*fl_copy_lock)(struct file_lock___372 *, struct file_lock___372 *);
	void (*fl_release_private)(struct file_lock___372 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___371;

struct lock_manager_operations___371;

struct file_lock___372 {
	struct file_lock___372 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___372 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___371 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___371 *fl_ops;
	const struct lock_manager_operations___371 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___371 {
	int (*lm_compare_owner)(struct file_lock___372 *, struct file_lock___372 *);
	long unsigned int (*lm_owner_key)(struct file_lock___372 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___372 *);
	int (*lm_grant)(struct file_lock___372 *, int);
	bool (*lm_break)(struct file_lock___372 *);
	int (*lm_change)(struct file_lock___372 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___372 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___371 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___371 *fa_next;
	struct file___372 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___371 {
	const char *name;
	int fs_flags;
	struct dentry___371 * (*mount)(struct file_system_type___371 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___371 *);
	struct module___303 *owner;
	struct file_system_type___371 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___371 {
	struct inode___372 * (*alloc_inode)(struct super_block___371 *);
	void (*destroy_inode)(struct inode___372 *);
	void (*dirty_inode)(struct inode___372 *, int);
	int (*write_inode)(struct inode___372 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___372 *);
	void (*evict_inode)(struct inode___372 *);
	void (*put_super)(struct super_block___371 *);
	int (*sync_fs)(struct super_block___371 *, int);
	int (*freeze_super)(struct super_block___371 *);
	int (*freeze_fs)(struct super_block___371 *);
	int (*thaw_super)(struct super_block___371 *);
	int (*unfreeze_fs)(struct super_block___371 *);
	int (*statfs)(struct dentry___371 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___371 *, int *, char *);
	void (*umount_begin)(struct super_block___371 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___371 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___371 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___371 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___371 *);
	ssize_t (*quota_read)(struct super_block___371 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___371 *, int, const char *, size_t, loff_t);
	struct dquot___371 ** (*get_dquots)(struct inode___372 *);
	int (*bdev_try_to_free_page)(struct super_block___371 *, struct page___373 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___371 *, struct shrink_control___133 *);
	long int (*free_cached_objects)(struct super_block___371 *, struct shrink_control___133 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___360(struct page___373 *);

struct spi_controller___3;

struct spi_device___3 {
	struct device___339 dev;
	struct spi_controller___3 *controller;
	struct spi_controller___3 *master;
	u32 max_speed_hz;
	u8 chip_select;
	u8 bits_per_word;
	u16 mode;
	int irq;
	void *controller_state;
	void *controller_data;
	char modalias[32];
	const char *driver_override;
	int cs_gpio;
	struct gpio_desc *cs_gpiod;
	uint8_t word_delay_usecs;
	struct spi_statistics statistics;
};

struct spi_message___3;

struct dma_chan___9;

struct spi_controller___3 {
	struct device___339 dev;
	struct list_head list;
	s16 bus_num;
	u16 num_chipselect;
	u16 dma_alignment;
	u16 mode_bits;
	u32 bits_per_word_mask;
	u32 min_speed_hz;
	u32 max_speed_hz;
	u16 flags;
	bool slave;
	size_t (*max_transfer_size)(struct spi_device___3 *);
	size_t (*max_message_size)(struct spi_device___3 *);
	struct mutex io_mutex;
	spinlock_t bus_lock_spinlock;
	struct mutex bus_lock_mutex;
	bool bus_lock_flag;
	int (*setup)(struct spi_device___3 *);
	int (*transfer)(struct spi_device___3 *, struct spi_message___3 *);
	void (*cleanup)(struct spi_device___3 *);
	bool (*can_dma)(struct spi_controller___3 *, struct spi_device___3 *, struct spi_transfer *);
	bool queued;
	struct kthread_worker___233 kworker;
	struct task_struct___373 *kworker_task;
	struct kthread_work___233 pump_messages;
	spinlock_t queue_lock;
	struct list_head queue;
	struct spi_message___3 *cur_msg;
	bool idling;
	bool busy;
	bool running;
	bool rt;
	bool auto_runtime_pm;
	bool cur_msg_prepared;
	bool cur_msg_mapped;
	struct completion xfer_completion;
	size_t max_dma_len;
	int (*prepare_transfer_hardware)(struct spi_controller___3 *);
	int (*transfer_one_message)(struct spi_controller___3 *, struct spi_message___3 *);
	int (*unprepare_transfer_hardware)(struct spi_controller___3 *);
	int (*prepare_message)(struct spi_controller___3 *, struct spi_message___3 *);
	int (*unprepare_message)(struct spi_controller___3 *, struct spi_message___3 *);
	int (*slave_abort)(struct spi_controller___3 *);
	void (*set_cs)(struct spi_device___3 *, bool);
	int (*transfer_one)(struct spi_controller___3 *, struct spi_device___3 *, struct spi_transfer *);
	void (*handle_err)(struct spi_controller___3 *, struct spi_message___3 *);
	const struct spi_controller_mem_ops *mem_ops;
	int *cs_gpios;
	struct gpio_desc **cs_gpiods;
	bool use_gpio_descriptors;
	struct spi_statistics statistics;
	struct dma_chan___9 *dma_tx;
	struct dma_chan___9 *dma_rx;
	void *dummy_rx;
	void *dummy_tx;
	int (*fw_translate_cs)(struct spi_controller___3 *, unsigned int);
};

struct spi_message___3 {
	struct list_head transfers;
	struct spi_device___3 *spi;
	unsigned int is_dma_mapped: 1;
	void (*complete)(void *);
	void *context;
	unsigned int frame_length;
	unsigned int actual_length;
	int status;
	struct list_head queue;
	void *state;
	struct list_head resources;
};

struct dma_device___8;

struct dma_chan_dev___8;

struct dma_router___8;

struct dma_chan___9 {
	struct dma_device___8 *device;
	dma_cookie_t cookie;
	dma_cookie_t completed_cookie;
	int chan_id;
	struct dma_chan_dev___8 *dev;
	struct list_head device_node;
	struct dma_chan_percpu *local;
	int client_count;
	int table_count;
	struct dma_router___8 *router;
	void *route_data;
	void *private;
};

struct dma_router___8 {
	struct device___339 *dev;
	void (*route_free)(struct device___339 *, void *);
};

typedef bool (*dma_filter_fn___8)(struct dma_chan___9 *, void *);

struct dma_filter___8 {
	dma_filter_fn___8 fn;
	int mapcnt;
	const struct dma_slave_map *map;
};

struct dma_async_tx_descriptor___8;

struct dma_device___8 {
	unsigned int chancnt;
	unsigned int privatecnt;
	struct list_head channels;
	struct list_head global_node;
	struct dma_filter___8 filter;
	dma_cap_mask_t cap_mask;
	short unsigned int max_xor;
	short unsigned int max_pq;
	enum dmaengine_alignment copy_align;
	enum dmaengine_alignment xor_align;
	enum dmaengine_alignment pq_align;
	enum dmaengine_alignment fill_align;
	int dev_id;
	struct device___339 *dev;
	u32 src_addr_widths;
	u32 dst_addr_widths;
	u32 directions;
	u32 max_burst;
	bool descriptor_reuse;
	enum dma_residue_granularity residue_granularity;
	int (*device_alloc_chan_resources)(struct dma_chan___9 *);
	void (*device_free_chan_resources)(struct dma_chan___9 *);
	struct dma_async_tx_descriptor___8 * (*device_prep_dma_memcpy)(struct dma_chan___9 *, dma_addr_t, dma_addr_t, size_t, long unsigned int);
	struct dma_async_tx_descriptor___8 * (*device_prep_dma_xor)(struct dma_chan___9 *, dma_addr_t, dma_addr_t *, unsigned int, size_t, long unsigned int);
	struct dma_async_tx_descriptor___8 * (*device_prep_dma_xor_val)(struct dma_chan___9 *, dma_addr_t *, unsigned int, size_t, enum sum_check_flags *, long unsigned int);
	struct dma_async_tx_descriptor___8 * (*device_prep_dma_pq)(struct dma_chan___9 *, dma_addr_t *, dma_addr_t *, unsigned int, const unsigned char *, size_t, long unsigned int);
	struct dma_async_tx_descriptor___8 * (*device_prep_dma_pq_val)(struct dma_chan___9 *, dma_addr_t *, dma_addr_t *, unsigned int, const unsigned char *, size_t, enum sum_check_flags *, long unsigned int);
	struct dma_async_tx_descriptor___8 * (*device_prep_dma_memset)(struct dma_chan___9 *, dma_addr_t, int, size_t, long unsigned int);
	struct dma_async_tx_descriptor___8 * (*device_prep_dma_memset_sg)(struct dma_chan___9 *, struct scatterlist *, unsigned int, int, long unsigned int);
	struct dma_async_tx_descriptor___8 * (*device_prep_dma_interrupt)(struct dma_chan___9 *, long unsigned int);
	struct dma_async_tx_descriptor___8 * (*device_prep_slave_sg)(struct dma_chan___9 *, struct scatterlist *, unsigned int, enum dma_transfer_direction, long unsigned int, void *);
	struct dma_async_tx_descriptor___8 * (*device_prep_dma_cyclic)(struct dma_chan___9 *, dma_addr_t, size_t, size_t, enum dma_transfer_direction, long unsigned int);
	struct dma_async_tx_descriptor___8 * (*device_prep_interleaved_dma)(struct dma_chan___9 *, struct dma_interleaved_template *, long unsigned int);
	struct dma_async_tx_descriptor___8 * (*device_prep_dma_imm_data)(struct dma_chan___9 *, dma_addr_t, u64, long unsigned int);
	int (*device_config)(struct dma_chan___9 *, struct dma_slave_config *);
	int (*device_pause)(struct dma_chan___9 *);
	int (*device_resume)(struct dma_chan___9 *);
	int (*device_terminate_all)(struct dma_chan___9 *);
	void (*device_synchronize)(struct dma_chan___9 *);
	enum dma_status (*device_tx_status)(struct dma_chan___9 *, dma_cookie_t, struct dma_tx_state *);
	void (*device_issue_pending)(struct dma_chan___9 *);
};

struct dma_chan_dev___8 {
	struct dma_chan___9 *chan;
	struct device___339 device;
	int dev_id;
	atomic_t *idr_ref;
};

struct dmaengine_unmap_data___8 {
	u8 map_cnt;
	u8 to_cnt;
	u8 from_cnt;
	u8 bidi_cnt;
	struct device___339 *dev;
	struct kref kref;
	size_t len;
	dma_addr_t addr[0];
};

struct dma_async_tx_descriptor___8 {
	dma_cookie_t cookie;
	enum dma_ctrl_flags flags;
	dma_addr_t phys;
	struct dma_chan___9 *chan;
	dma_cookie_t (*tx_submit)(struct dma_async_tx_descriptor___8 *);
	int (*desc_free)(struct dma_async_tx_descriptor___8 *);
	dma_async_tx_callback callback;
	dma_async_tx_callback_result callback_result;
	void *callback_param;
	struct dmaengine_unmap_data___8 *unmap;
};

struct spi_qup {
	void *base;
	struct device___339 *dev;
	struct clk *cclk;
	struct clk *iclk;
	int irq;
	spinlock_t lock;
	int in_fifo_sz;
	int out_fifo_sz;
	int in_blk_sz;
	int out_blk_sz;
	struct spi_transfer *xfer;
	struct completion done;
	int error;
	int w_size;
	int n_words;
	int tx_bytes;
	int rx_bytes;
	const u8 *tx_buf;
	u8 *rx_buf;
	int qup_v1;
	int mode;
	struct dma_slave_config rx_conf;
	struct dma_slave_config tx_conf;
};

struct devprobe2 {
	struct net_device___20 * (*probe)(int);
	int status;
};

struct module___304;

struct file___373;

struct kiocb___373;

struct iov_iter___157;

struct poll_table_struct___225;

struct vm_area_struct___374;

struct inode___373;

struct file_lock___373;

struct page___374;

struct pipe_inode_info___75;

struct seq_file___316;

struct file_operations___373 {
	struct module___304 *owner;
	loff_t (*llseek)(struct file___373 *, loff_t, int);
	ssize_t (*read)(struct file___373 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___373 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___373 *, struct iov_iter___157 *);
	ssize_t (*write_iter)(struct kiocb___373 *, struct iov_iter___157 *);
	int (*iopoll)(struct kiocb___373 *, bool);
	int (*iterate)(struct file___373 *, struct dir_context *);
	int (*iterate_shared)(struct file___373 *, struct dir_context *);
	__poll_t (*poll)(struct file___373 *, struct poll_table_struct___225 *);
	long int (*unlocked_ioctl)(struct file___373 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___373 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___373 *, struct vm_area_struct___374 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___373 *, struct file___373 *);
	int (*flush)(struct file___373 *, fl_owner_t);
	int (*release)(struct inode___373 *, struct file___373 *);
	int (*fsync)(struct file___373 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___373 *, int);
	int (*lock)(struct file___373 *, int, struct file_lock___373 *);
	ssize_t (*sendpage)(struct file___373 *, struct page___374 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___373 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___373 *, int, struct file_lock___373 *);
	ssize_t (*splice_write)(struct pipe_inode_info___75 *, struct file___373 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___373 *, loff_t *, struct pipe_inode_info___75 *, size_t, unsigned int);
	int (*setlease)(struct file___373 *, long int, struct file_lock___373 **, void **);
	long int (*fallocate)(struct file___373 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___316 *, struct file___373 *);
	ssize_t (*copy_file_range)(struct file___373 *, loff_t, struct file___373 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___373 *, loff_t, struct file___373 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___373 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___373 {
	u64 seqnum;
	struct vm_area_struct___374 *vmas[4];
};

struct page_frag___373 {
	struct page___374 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___373;

struct mem_cgroup___134;

struct cred___343;

struct nsproxy___278;

struct signal_struct___257;

struct bio_list___188;

struct backing_dev_info___188;

struct css_set___233;

struct vm_struct___279;

struct task_struct___374 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___374 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___373 *mm;
	struct mm_struct___373 *active_mm;
	struct vmacache___373 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___374 *real_parent;
	struct task_struct___374 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___374 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___134 *active_memcg;
	long int rh_reserved2;
	struct pid___218 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___218 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___218 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___343 *ptracer_cred;
	const struct cred___343 *real_cred;
	const struct cred___343 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___278 *nsproxy;
	struct signal_struct___257 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___374 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___188 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___188 *backing_dev_info;
	struct io_context___107 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___233 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___75 *splice_pipe;
	struct page_frag___373 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___134 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___374 *oom_reaper_list;
	struct vm_struct___279 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___142 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct secondary_data___374 {
	void *stack;
	struct task_struct___374 *task;
	long int status;
};

struct rw_semaphore___374 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___374 *owner;
};

struct key___343;

struct ucounts___248;

struct user_namespace___248 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___248 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___9 ns;
	long unsigned int flags;
	struct key___343 *persistent_keyring_register;
	struct rw_semaphore___374 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___248 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___374 *pgtable_t___373;

struct address_space___372;

struct dev_pagemap___361;

struct page___374 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___372 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___374 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___373 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___373 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___361 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___134 *mem_cgroup;
};

struct pglist_data___373;

struct lruvec___373 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___373 *pgdat;
};

struct zone___373 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___373 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___373 {
	struct zone___373 *zone;
	int zone_idx;
};

struct zonelist___373 {
	struct zoneref___373 _zonerefs[25];
};

struct pglist_data___373 {
	struct zone___373 node_zones[3];
	struct zonelist___373 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___374 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___374 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___373 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___373 {
	struct rw_semaphore___374 rwsem;
	struct notifier_block *head;
};

struct dentry___372;

struct path___373 {
	struct vfsmount *mnt;
	struct dentry___372 *dentry;
};

struct file___373 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___373 f_path;
	struct inode___373 *f_inode;
	const struct file_operations___373 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___218 f_owner;
	const struct cred___343 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___372 *f_mapping;
	errseq_t f_wb_err;
};

struct user_struct___343;

struct cred___343 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___343 *session_keyring;
	struct key___343 *process_keyring;
	struct key___343 *thread_keyring;
	struct key___343 *request_key_auth;
	void *security;
	struct user_struct___343 *user;
	struct user_namespace___248 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___366;

struct kernfs_elem_dir___366 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___366 *root;
};

struct kernfs_node___367;

struct kernfs_syscall_ops___366;

struct kernfs_root___366 {
	struct kernfs_node___367 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___366 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___366 {
	struct kernfs_node___367 *target_kn;
};

struct kernfs_ops___366;

struct kernfs_elem_attr___366 {
	const struct kernfs_ops___366 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___367 *notify_next;
};

struct kernfs_node___367 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___367 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___366 dir;
		struct kernfs_elem_symlink___366 symlink;
		struct kernfs_elem_attr___366 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___366;

struct kernfs_ops___366 {
	int (*open)(struct kernfs_open_file___366 *);
	void (*release)(struct kernfs_open_file___366 *);
	int (*seq_show)(struct seq_file___316 *, void *);
	void * (*seq_start)(struct seq_file___316 *, loff_t *);
	void * (*seq_next)(struct seq_file___316 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___316 *, void *);
	ssize_t (*read)(struct kernfs_open_file___366 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___366 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___366 *, struct vm_area_struct___374 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___366 *, struct poll_table_struct___225 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___366 {
	int (*remount_fs)(struct kernfs_root___366 *, int *, char *);
	int (*show_options)(struct seq_file___316 *, struct kernfs_root___366 *);
	int (*mkdir)(struct kernfs_node___367 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___367 *);
	int (*rename)(struct kernfs_node___367 *, struct kernfs_node___367 *, const char *);
	int (*show_path)(struct seq_file___316 *, struct kernfs_node___367 *, struct kernfs_root___366 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___315;

struct seq_file___316 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___315 *op;
	int poll_event;
	const struct file___373 *file;
	void *private;
};

struct vm_operations_struct___361;

struct kernfs_open_file___366 {
	struct kernfs_node___367 *kn;
	struct file___373 *file;
	struct seq_file___316 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___361 *vm_ops;
};

struct vm_fault___361;

struct vm_operations_struct___361 {
	void (*open)(struct vm_area_struct___374 *);
	void (*close)(struct vm_area_struct___374 *);
	int (*split)(struct vm_area_struct___374 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___374 *);
	vm_fault_t (*fault)(struct vm_fault___361 *);
	vm_fault_t (*huge_fault)(struct vm_fault___361 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___361 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___374 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___361 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___361 *);
	int (*access)(struct vm_area_struct___374 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___374 *);
	int (*set_policy)(struct vm_area_struct___374 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___374 *, long unsigned int);
	struct page___374 * (*find_special_page)(struct vm_area_struct___374 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___231)(struct file___373 *, wait_queue_head_t *, struct poll_table_struct___225 *);

struct poll_table_struct___225 {
	poll_queue_proc___231 _qproc;
	__poll_t _key;
};

struct vm_area_struct___374 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___374 *vm_next;
	struct vm_area_struct___374 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___373 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___361 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___373 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sock___30;

struct kobj_ns_type_operations___29 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___30 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct net___53;

typedef struct {
	struct net___53 *net;
} possible_net_t___43;

struct proto___29;

struct sock_common___29 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___29 *skc_prot;
	possible_net_t___43 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___30 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___44;

struct sk_buff_head___42 {
	struct sk_buff___44 *next;
	struct sk_buff___44 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___29;

struct socket_wq___30;

struct dst_entry___29;

struct socket___31;

struct net_device___44;

struct sock___30 {
	struct sock_common___29 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___42 sk_error_queue;
	struct sk_buff_head___42 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___44 *head;
		struct sk_buff___44 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___29 *sk_filter;
	union {
		struct socket_wq___30 *sk_wq;
		struct socket_wq___30 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___29 *sk_rx_dst;
	struct dst_entry___29 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___44 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___42 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___373 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___29 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___218 *sk_peer_pid;
	const struct cred___343 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___31 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___134 *sk_memcg;
	void (*sk_state_change)(struct sock___30 *);
	void (*sk_data_ready)(struct sock___30 *);
	void (*sk_write_space)(struct sock___30 *);
	void (*sk_error_report)(struct sock___30 *);
	int (*sk_backlog_rcv)(struct sock___30 *, struct sk_buff___44 *);
	struct sk_buff___44 * (*sk_validate_xmit_skb)(struct sock___30 *, struct net_device___44 *, struct sk_buff___44 *);
	void (*sk_destruct)(struct sock___30 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kobject___360;

struct bin_attribute___336;

struct attribute_group___337 {
	const char *name;
	umode_t (*is_visible)(struct kobject___360 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___360 *, struct bin_attribute___336 *, int);
	struct attribute **attrs;
	struct bin_attribute___336 **bin_attrs;
};

struct kset___359;

struct kobj_type___359;

struct kobject___360 {
	const char *name;
	struct list_head entry;
	struct kobject___360 *parent;
	struct kset___359 *kset;
	struct kobj_type___359 *ktype;
	struct kernfs_node___367 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___336 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___373 *, struct kobject___360 *, struct bin_attribute___336 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___373 *, struct kobject___360 *, struct bin_attribute___336 *, char *, loff_t, size_t);
	int (*mmap)(struct file___373 *, struct kobject___360 *, struct bin_attribute___336 *, struct vm_area_struct___374 *);
};

struct sysfs_ops___359 {
	ssize_t (*show)(struct kobject___360 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___360 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___359;

struct kset___359 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___360 kobj;
	const struct kset_uevent_ops___359 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___359 {
	void (*release)(struct kobject___360 *);
	const struct sysfs_ops___359 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___29 * (*child_ns_type)(struct kobject___360 *);
	const void * (*namespace)(struct kobject___360 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___359 {
	int (* const filter)(struct kset___359 *, struct kobject___360 *);
	const char * (* const name)(struct kset___359 *, struct kobject___360 *);
	int (* const uevent)(struct kset___359 *, struct kobject___360 *, struct kobj_uevent_env *);
};

struct kobj_attribute___351 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___360 *, struct kobj_attribute___351 *, char *);
	ssize_t (*store)(struct kobject___360 *, struct kobj_attribute___351 *, const char *, size_t);
};

struct kernel_param___301;

struct kernel_param_ops___301 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___301 *);
	int (*get)(char *, const struct kernel_param___301 *);
	void (*free)(void *);
};

struct kparam_array___301;

struct kernel_param___301 {
	const char *name;
	struct module___304 *mod;
	const struct kernel_param_ops___301 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___301 *arr;
	};
};

struct kparam_array___301 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___301 *ops;
	void *elem;
};

struct module_kobject___301 {
	struct kobject___360 kobj;
	struct module___304 *mod;
	struct kobject___360 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___301 {
	struct module___304 *mod;
	struct latch_tree_node node;
};

struct module_layout___301 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___301 mtn;
};

struct module_attribute___301;

struct module___304 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___301 mkobj;
	struct module_attribute___301 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___360 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___301 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___301 core_layout;
	struct module_layout___301 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___301 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___301 *, struct module_kobject___301 *, char *);
	ssize_t (*store)(struct module_attribute___301 *, struct module_kobject___301 *, const char *, size_t);
	void (*setup)(struct module___304 *, const char *);
	int (*test)(struct module___304 *);
	void (*free)(struct module___304 *);
};

struct dentry_operations___372;

struct super_block___372;

struct dentry___372 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___372 *d_parent;
	struct qstr d_name;
	struct inode___373 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___372 *d_op;
	struct super_block___372 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___372;

struct address_space___372 {
	struct inode___373 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___374 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___372 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___372;

struct bdi_writeback___188;

struct block_device___372;

struct inode___373 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___372 *i_op;
	struct super_block___372 *i_sb;
	struct address_space___372 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___374 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___188 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___373 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___372 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___75 *i_pipe;
		struct block_device___372 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___372 {
	int (*d_revalidate)(struct dentry___372 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___372 *, unsigned int);
	int (*d_hash)(const struct dentry___372 *, struct qstr *);
	int (*d_compare)(const struct dentry___372 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___372 *);
	int (*d_init)(struct dentry___372 *);
	void (*d_release)(struct dentry___372 *);
	void (*d_prune)(struct dentry___372 *);
	void (*d_iput)(struct dentry___372 *, struct inode___373 *);
	char * (*d_dname)(struct dentry___372 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___373 *);
	int (*d_manage)(const struct path___373 *, bool);
	struct dentry___372 * (*d_real)(struct dentry___372 *, const struct inode___373 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___372;

struct mem_dqinfo___372 {
	struct quota_format_type___372 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___372;

struct quota_info___372 {
	unsigned int flags;
	struct rw_semaphore___374 dqio_sem;
	struct inode___373 *files[3];
	struct mem_dqinfo___372 info[3];
	const struct quota_format_ops___372 *ops[3];
};

struct rcuwait___372 {
	struct task_struct___374 *task;
};

struct percpu_rw_semaphore___372 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___374 rw_sem;
	struct rcuwait___372 writer;
	int readers_block;
};

struct sb_writers___372 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___372 rw_sem[3];
};

struct shrink_control___134;

struct shrinker___134 {
	long unsigned int (*count_objects)(struct shrinker___134 *, struct shrink_control___134 *);
	long unsigned int (*scan_objects)(struct shrinker___134 *, struct shrink_control___134 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___372;

struct super_operations___372;

struct dquot_operations___372;

struct quotactl_ops___372;

struct super_block___372 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___372 *s_type;
	const struct super_operations___372 *s_op;
	const struct dquot_operations___372 *dq_op;
	const struct quotactl_ops___372 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___372 *s_root;
	struct rw_semaphore___374 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___372 *s_bdev;
	struct backing_dev_info___188 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___372 s_dquot;
	struct sb_writers___372 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___372 *s_d_op;
	int cleancache_poolid;
	struct shrinker___134 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___248 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___134 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___134 *memcg;
};

struct cgroup___233;

struct cgroup_subsys___233;

struct cgroup_subsys_state___233 {
	struct cgroup___233 *cgroup;
	struct cgroup_subsys___233 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___233 *parent;
};

struct cgroup_file___233 {
	struct kernfs_node___367 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___134;

struct mem_cgroup___134 {
	struct cgroup_subsys_state___233 css;
	struct mem_cgroup_id___13 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___233 events_file;
	struct cgroup_file___233 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___374 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___134 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct core_state___373;

struct mm_struct___373 {
	struct {
		struct vm_area_struct___374 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___373 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___374 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___373 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___374 *owner;
		struct user_namespace___248 *user_ns;
		struct file___373 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___373 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___361)(struct vm_area_struct___374 *, long unsigned int, const struct page___374 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___361)(struct page___374 *, void *);

struct device___340;

struct dev_pagemap___361 {
	dev_page_fault_t___361 page_fault;
	dev_page_free_t___361 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___340 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___373 {
	struct task_struct___374 *task;
	struct core_thread___373 *next;
};

struct core_state___373 {
	atomic_t nr_threads;
	struct core_thread___373 dumper;
	struct completion startup;
};

struct vm_fault___361 {
	struct vm_area_struct___374 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___374 *cow_page;
	struct mem_cgroup___134 *memcg;
	struct page___374 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___373 prealloc_pte;
};

struct user_struct___343 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___343 *uid_keyring;
	struct key___343 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cgroup_namespace___233;

struct nsproxy___278 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net___53 *net_ns;
	struct cgroup_namespace___233 *cgroup_ns;
};

struct signal_struct___257 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___374 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___374 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___218 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___218 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___373 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___218 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___188;

struct bio_list___188 {
	struct bio___188 *head;
	struct bio___188 *tail;
};

struct bdi_writeback_congested___188;

struct bdi_writeback___188 {
	struct backing_dev_info___188 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___188 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___233 *memcg_css;
	struct cgroup_subsys_state___233 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___188 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___188 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___340 *dev;
	struct device___340 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___372 *debug_dir;
	struct dentry___372 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___233 {
	struct cgroup_subsys_state___233 *subsys[13];
	refcount_t refcount;
	struct css_set___233 *dom_cset;
	struct cgroup___233 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___233 *mg_src_cgrp;
	struct cgroup___233 *mg_dst_cgrp;
	struct css_set___233 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___372;

struct pipe_buffer___75;

struct pipe_inode_info___75 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___374 *tmp_page;
	struct fasync_struct___372 *fasync_readers;
	struct fasync_struct___372 *fasync_writers;
	struct pipe_buffer___75 *bufs;
	struct user_struct___343 *user;
};

struct vm_struct___279 {
	struct vm_struct___279 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___374 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___269 {
	struct task_struct___374 task;
	long unsigned int stack[8192];
};

struct kiocb___373 {
	struct file___373 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___373 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___372 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___373 *ia_file;
};

struct dquot___372 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___372 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___372 {
	int qf_fmt_id;
	const struct quota_format_ops___372 *qf_ops;
	struct module___304 *qf_owner;
	struct quota_format_type___372 *qf_next;
};

struct quota_format_ops___372 {
	int (*check_quota_file)(struct super_block___372 *, int);
	int (*read_file_info)(struct super_block___372 *, int);
	int (*write_file_info)(struct super_block___372 *, int);
	int (*free_file_info)(struct super_block___372 *, int);
	int (*read_dqblk)(struct dquot___372 *);
	int (*commit_dqblk)(struct dquot___372 *);
	int (*release_dqblk)(struct dquot___372 *);
	int (*get_next_id)(struct super_block___372 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___372 {
	int (*write_dquot)(struct dquot___372 *);
	struct dquot___372 * (*alloc_dquot)(struct super_block___372 *, int);
	void (*destroy_dquot)(struct dquot___372 *);
	int (*acquire_dquot)(struct dquot___372 *);
	int (*release_dquot)(struct dquot___372 *);
	int (*mark_dirty)(struct dquot___372 *);
	int (*write_info)(struct super_block___372 *, int);
	qsize_t * (*get_reserved_space)(struct inode___373 *);
	int (*get_projid)(struct inode___373 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___373 *, qsize_t *);
	int (*get_next_id)(struct super_block___372 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___372 {
	int (*quota_on)(struct super_block___372 *, int, int, const struct path___373 *);
	int (*quota_off)(struct super_block___372 *, int);
	int (*quota_enable)(struct super_block___372 *, unsigned int);
	int (*quota_disable)(struct super_block___372 *, unsigned int);
	int (*quota_sync)(struct super_block___372 *, int);
	int (*set_info)(struct super_block___372 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___372 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___372 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___372 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___372 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___372 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___151;

struct address_space_operations___372 {
	int (*writepage)(struct page___374 *, struct writeback_control___151 *);
	int (*readpage)(struct file___373 *, struct page___374 *);
	int (*writepages)(struct address_space___372 *, struct writeback_control___151 *);
	int (*set_page_dirty)(struct page___374 *);
	int (*readpages)(struct file___373 *, struct address_space___372 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___373 *, struct address_space___372 *, loff_t, unsigned int, unsigned int, struct page___374 **, void **);
	int (*write_end)(struct file___373 *, struct address_space___372 *, loff_t, unsigned int, unsigned int, struct page___374 *, void *);
	sector_t (*bmap)(struct address_space___372 *, sector_t);
	void (*invalidatepage)(struct page___374 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___374 *, gfp_t);
	void (*freepage)(struct page___374 *);
	ssize_t (*direct_IO)(struct kiocb___373 *, struct iov_iter___157 *);
	int (*migratepage)(struct address_space___372 *, struct page___374 *, struct page___374 *, enum migrate_mode);
	bool (*isolate_page)(struct page___374 *, isolate_mode_t);
	void (*putback_page)(struct page___374 *);
	int (*launder_page)(struct page___374 *);
	int (*is_partially_uptodate)(struct page___374 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___374 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___372 *, struct page___374 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___373 *, sector_t *);
	void (*swap_deactivate)(struct file___373 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___151 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___188 *wb;
	struct inode___373 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___190;

struct iov_iter___157 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___190 *bvec;
		struct pipe_inode_info___75 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___372 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___373 *bd_inode;
	struct super_block___372 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___372 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___188 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___372 {
	struct dentry___372 * (*lookup)(struct inode___373 *, struct dentry___372 *, unsigned int);
	const char * (*get_link)(struct dentry___372 *, struct inode___373 *, struct delayed_call *);
	int (*permission)(struct inode___373 *, int);
	struct posix_acl * (*get_acl)(struct inode___373 *, int);
	int (*readlink)(struct dentry___372 *, char *, int);
	int (*create)(struct inode___373 *, struct dentry___372 *, umode_t, bool);
	int (*link)(struct dentry___372 *, struct inode___373 *, struct dentry___372 *);
	int (*unlink)(struct inode___373 *, struct dentry___372 *);
	int (*symlink)(struct inode___373 *, struct dentry___372 *, const char *);
	int (*mkdir)(struct inode___373 *, struct dentry___372 *, umode_t);
	int (*rmdir)(struct inode___373 *, struct dentry___372 *);
	int (*mknod)(struct inode___373 *, struct dentry___372 *, umode_t, dev_t);
	int (*rename)(struct inode___373 *, struct dentry___372 *, struct inode___373 *, struct dentry___372 *, unsigned int);
	int (*setattr)(struct dentry___372 *, struct iattr___372 *);
	int (*getattr)(const struct path___373 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___372 *, char *, size_t);
	int (*fiemap)(struct inode___373 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___373 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___373 *, struct dentry___372 *, struct file___373 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___373 *, struct dentry___372 *, umode_t);
	int (*set_acl)(struct inode___373 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___372 {
	void (*fl_copy_lock)(struct file_lock___373 *, struct file_lock___373 *);
	void (*fl_release_private)(struct file_lock___373 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___372;

struct file_lock___373 {
	struct file_lock___373 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___373 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___372 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___372 *fl_ops;
	const struct lock_manager_operations___372 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___372 {
	int (*lm_compare_owner)(struct file_lock___373 *, struct file_lock___373 *);
	long unsigned int (*lm_owner_key)(struct file_lock___373 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___373 *);
	int (*lm_grant)(struct file_lock___373 *, int);
	bool (*lm_break)(struct file_lock___373 *);
	int (*lm_change)(struct file_lock___373 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___373 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___372 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___372 *fa_next;
	struct file___373 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___372 {
	const char *name;
	int fs_flags;
	struct dentry___372 * (*mount)(struct file_system_type___372 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___372 *);
	struct module___304 *owner;
	struct file_system_type___372 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___372 {
	struct inode___373 * (*alloc_inode)(struct super_block___372 *);
	void (*destroy_inode)(struct inode___373 *);
	void (*dirty_inode)(struct inode___373 *, int);
	int (*write_inode)(struct inode___373 *, struct writeback_control___151 *);
	int (*drop_inode)(struct inode___373 *);
	void (*evict_inode)(struct inode___373 *);
	void (*put_super)(struct super_block___372 *);
	int (*sync_fs)(struct super_block___372 *, int);
	int (*freeze_super)(struct super_block___372 *);
	int (*freeze_fs)(struct super_block___372 *);
	int (*thaw_super)(struct super_block___372 *);
	int (*unfreeze_fs)(struct super_block___372 *);
	int (*statfs)(struct dentry___372 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___372 *, int *, char *);
	void (*umount_begin)(struct super_block___372 *);
	int (*show_options)(struct seq_file___316 *, struct dentry___372 *);
	int (*show_devname)(struct seq_file___316 *, struct dentry___372 *);
	int (*show_path)(struct seq_file___316 *, struct dentry___372 *);
	int (*show_stats)(struct seq_file___316 *, struct dentry___372 *);
	ssize_t (*quota_read)(struct super_block___372 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___372 *, int, const char *, size_t, loff_t);
	struct dquot___372 ** (*get_dquots)(struct inode___373 *);
	int (*bdev_try_to_free_page)(struct super_block___372 *, struct page___374 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___372 *, struct shrink_control___134 *);
	long int (*free_cached_objects)(struct super_block___372 *, struct shrink_control___134 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___188(struct bio___188 *);

struct bio_vec___190 {
	struct page___374 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___188;

struct bio_set___188;

struct bio___188 {
	struct bio___188 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___188 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___188 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___190 *bi_io_vec;
	struct bio_set___188 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___190 bi_inline_vecs[0];
};

struct msghdr___32 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___157 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___373 *msg_iocb;
};

struct fwnode_operations___262;

struct fwnode_handle___262 {
	struct fwnode_handle___262 *secondary;
	const struct fwnode_operations___262 *ops;
};

struct fwnode_reference_args___262;

struct fwnode_endpoint___262;

struct fwnode_operations___262 {
	struct fwnode_handle___262 * (*get)(struct fwnode_handle___262 *);
	void (*put)(struct fwnode_handle___262 *);
	bool (*device_is_available)(const struct fwnode_handle___262 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___262 *, const struct device___340 *);
	bool (*property_present)(const struct fwnode_handle___262 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___262 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___262 *, const char *, const char **, size_t);
	struct fwnode_handle___262 * (*get_parent)(const struct fwnode_handle___262 *);
	struct fwnode_handle___262 * (*get_next_child_node)(const struct fwnode_handle___262 *, struct fwnode_handle___262 *);
	struct fwnode_handle___262 * (*get_named_child_node)(const struct fwnode_handle___262 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___262 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___262 *);
	struct fwnode_handle___262 * (*graph_get_next_endpoint)(const struct fwnode_handle___262 *, struct fwnode_handle___262 *);
	struct fwnode_handle___262 * (*graph_get_remote_endpoint)(const struct fwnode_handle___262 *);
	struct fwnode_handle___262 * (*graph_get_port_parent)(struct fwnode_handle___262 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___262 *, struct fwnode_endpoint___262 *);
};

struct fwnode_endpoint___262 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___262 *local_fwnode;
};

struct fwnode_reference_args___262 {
	struct fwnode_handle___262 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct dev_pm_info___340 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___6 *subsys_data;
	void (*set_latency_tolerance)(struct device___340 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___340;

struct bus_type___340;

struct device_driver___340;

struct dev_pm_domain___340;

struct dma_map_ops___128;

struct class___340;

struct device___340 {
	struct device___340 *parent;
	struct device_private *p;
	struct kobject___360 kobj;
	const char *init_name;
	const struct device_type___340 *type;
	struct mutex mutex;
	struct bus_type___340 *bus;
	struct device_driver___340 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___340 power;
	struct dev_pm_domain___340 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___128 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___262 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___340 *class;
	const struct attribute_group___337 **groups;
	void (*release)(struct device___340 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct inet_frags___42;

struct netns_frags___42 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___42 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct inet_frag_queue___42;

struct inet_frags___42 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___42 *, const void *);
	void (*destructor)(struct inet_frag_queue___42 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___42 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___44 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___44 *fragments_tail;
	struct sk_buff___44 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___42 *net;
	struct callback_head rcu;
};

struct nf_bridge_info___42;

struct sk_buff___44 {
	union {
		struct {
			struct sk_buff___44 *next;
			struct sk_buff___44 *prev;
			union {
				struct net_device___44 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___30 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___44 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___42 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct fib_rules_ops___29;

struct fib_notifier_ops___29;

struct netns_ipv4___42 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___29 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___30 *fibnl;
	struct sock___30 **icmp_sk;
	struct sock___30 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___30 **tcp_sk;
	struct netns_frags___42 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___29 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___29 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___29 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct fib_rule___29;

struct fib_lookup_arg___29;

struct fib_rules_ops___29 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___29 *, struct flowi *, int, struct fib_lookup_arg___29 *);
	bool (*suppress)(struct fib_rule___29 *, struct fib_lookup_arg___29 *);
	int (*match)(struct fib_rule___29 *, struct flowi *, int);
	int (*configure)(struct fib_rule___29 *, struct sk_buff___44 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___29 *);
	int (*compare)(struct fib_rule___29 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___29 *, struct sk_buff___44 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___29 *);
	void (*flush_cache)(struct fib_rules_ops___29 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___304 *owner;
	struct net___53 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___29 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___53 *);
	int (*fib_dump)(struct net___53 *, struct notifier_block *);
	struct module___304 *owner;
	struct callback_head rcu;
};

struct neighbour___29;

struct dst_ops___52 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___52 *);
	struct dst_entry___29 * (*check)(struct dst_entry___29 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___29 *);
	unsigned int (*mtu)(const struct dst_entry___29 *);
	u32 * (*cow_metrics)(struct dst_entry___29 *, long unsigned int);
	void (*destroy)(struct dst_entry___29 *);
	void (*ifdown)(struct dst_entry___29 *, struct net_device___44 *, int);
	struct dst_entry___29 * (*negative_advice)(struct dst_entry___29 *);
	void (*link_failure)(struct sk_buff___44 *);
	void (*update_pmtu)(struct dst_entry___29 *, struct sock___30 *, struct sk_buff___44 *, u32);
	void (*redirect)(struct dst_entry___29 *, struct sock___30 *, struct sk_buff___44 *);
	int (*local_out)(struct net___53 *, struct sock___30 *, struct sk_buff___44 *);
	struct neighbour___29 * (*neigh_lookup)(const struct dst_entry___29 *, struct sk_buff___44 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___29 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct dst_entry___29 {
	struct net_device___44 *dev;
	struct dst_ops___52 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___44 *);
	int (*output)(struct net___53 *, struct sock___30 *, struct sk_buff___44 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

typedef rx_handler_result_t rx_handler_func_t___42(struct sk_buff___44 **);

struct net_device_ops___42;

struct ethtool_ops___42;

struct l3mdev_ops___29;

struct xfrmdev_ops___42;

struct tlsdev_ops___42;

struct header_ops___42;

struct netdev_rx_queue___42;

struct bpf_prog___39;

struct mini_Qdisc___39;

struct netdev_queue___42;

struct Qdisc___39;

struct rtnl_link_ops___39;

struct dcbnl_rtnl_ops___42;

struct net_device___44 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___42 *netdev_ops;
	const struct ethtool_ops___42 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___29 *l3mdev_ops;
	const struct ndisc_ops___2 *ndisc_ops;
	const struct xfrmdev_ops___42 *xfrmdev_ops;
	const struct tlsdev_ops___42 *tlsdev_ops;
	const struct header_ops___42 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___359 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___2 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___42 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___39 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___42 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___39 *miniq_ingress;
	struct netdev_queue___42 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___42 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___39 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___39 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___42 = 0,
		NETREG_REGISTERED___42 = 1,
		NETREG_UNREGISTERING___42 = 2,
		NETREG_UNREGISTERED___42 = 3,
		NETREG_RELEASED___42 = 4,
		NETREG_DUMMY___42 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___42 = 0,
		RTNL_LINK_INITIALIZING___42 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___44 *);
	struct netpoll_info *npinfo;
	possible_net_t___43 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___340 dev;
	const struct attribute_group___337 *sysfs_groups[4];
	const struct attribute_group___337 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___39 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___42 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide35;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct netns_ipv6___52 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___42 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___52 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___29 *fib6_rules_ops;
	struct sock___30 **icmp_sk;
	struct sock___30 *ndisc_sk;
	struct sock___30 *tcp_sk;
	struct sock___30 *igmp_sk;
	struct sock___30 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___29 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___29 *notifier_ops;
	struct fib_notifier_ops___29 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___30 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___30 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___42 {
	struct netns_frags___42 frags;
};

struct netns_xfrm___52 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___30 *nlsk;
	struct sock___30 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___52 xfrm4_dst_ops;
	struct dst_ops___52 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct net___53 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___248 *user_ns;
	struct ucounts___248 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___9 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___30 *rtnl;
	struct sock___30 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___44 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___42 ipv4;
	struct netns_ipv6___52 ipv6;
	struct netns_sctp___30 sctp;
	struct netns_nf nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___42 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___30 *nfnl;
	struct sock___30 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___52 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___30 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___39 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neigh_table___29;

struct neigh_parms___29;

struct neigh_ops___29;

struct neighbour___29 {
	struct neighbour___29 *next;
	struct neigh_table___29 *tbl;
	struct neigh_parms___29 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___42 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___29 *, struct sk_buff___44 *);
	const struct neigh_ops___29 *ops;
	struct callback_head rcu;
	struct net_device___44 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct socket_wq___30 {
	wait_queue_head_t wait;
	struct fasync_struct___372 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___30;

struct socket___31 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___30 *wq;
	struct file___373 *file;
	struct sock___30 *sk;
	const struct proto_ops___30 *ops;
};

typedef int (*sk_read_actor_t___29)(read_descriptor_t *, struct sk_buff___44 *, unsigned int, size_t);

struct proto_ops___30 {
	int family;
	struct module___304 *owner;
	int (*release)(struct socket___31 *);
	int (*bind)(struct socket___31 *, struct sockaddr *, int);
	int (*connect)(struct socket___31 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___31 *, struct socket___31 *);
	int (*accept)(struct socket___31 *, struct socket___31 *, int, bool);
	int (*getname)(struct socket___31 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___373 *, struct socket___31 *, struct poll_table_struct___225 *);
	int (*ioctl)(struct socket___31 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___31 *, int);
	int (*shutdown)(struct socket___31 *, int);
	int (*setsockopt)(struct socket___31 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___31 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___31 *, struct msghdr___32 *, size_t);
	int (*recvmsg)(struct socket___31 *, struct msghdr___32 *, size_t, int);
	int (*mmap)(struct file___373 *, struct socket___31 *, struct vm_area_struct___374 *);
	ssize_t (*sendpage)(struct socket___31 *, struct page___374 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___31 *, loff_t *, struct pipe_inode_info___75 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___30 *, int);
	int (*peek_len)(struct socket___31 *);
	int (*read_sock)(struct sock___30 *, read_descriptor_t *, sk_read_actor_t___29);
	int (*sendpage_locked)(struct sock___30 *, struct page___374 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___30 *, struct msghdr___32 *, size_t);
	int (*set_rcvlowat)(struct sock___30 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct dev_pm_ops___340 {
	int (*prepare)(struct device___340 *);
	void (*complete)(struct device___340 *);
	int (*suspend)(struct device___340 *);
	int (*resume)(struct device___340 *);
	int (*freeze)(struct device___340 *);
	int (*thaw)(struct device___340 *);
	int (*poweroff)(struct device___340 *);
	int (*restore)(struct device___340 *);
	int (*suspend_late)(struct device___340 *);
	int (*resume_early)(struct device___340 *);
	int (*freeze_late)(struct device___340 *);
	int (*thaw_early)(struct device___340 *);
	int (*poweroff_late)(struct device___340 *);
	int (*restore_early)(struct device___340 *);
	int (*suspend_noirq)(struct device___340 *);
	int (*resume_noirq)(struct device___340 *);
	int (*freeze_noirq)(struct device___340 *);
	int (*thaw_noirq)(struct device___340 *);
	int (*poweroff_noirq)(struct device___340 *);
	int (*restore_noirq)(struct device___340 *);
	int (*runtime_suspend)(struct device___340 *);
	int (*runtime_resume)(struct device___340 *);
	int (*runtime_idle)(struct device___340 *);
};

struct dev_pm_domain___340 {
	struct dev_pm_ops___340 ops;
	void (*detach)(struct device___340 *, bool);
	int (*activate)(struct device___340 *);
	void (*sync)(struct device___340 *);
	void (*dismiss)(struct device___340 *);
};

struct bus_type___340 {
	const char *name;
	const char *dev_name;
	struct device___340 *dev_root;
	const struct attribute_group___337 **bus_groups;
	const struct attribute_group___337 **dev_groups;
	const struct attribute_group___337 **drv_groups;
	int (*match)(struct device___340 *, struct device_driver___340 *);
	int (*uevent)(struct device___340 *, struct kobj_uevent_env *);
	int (*probe)(struct device___340 *);
	int (*remove)(struct device___340 *);
	void (*shutdown)(struct device___340 *);
	int (*online)(struct device___340 *);
	int (*offline)(struct device___340 *);
	int (*suspend)(struct device___340 *, pm_message_t);
	int (*resume)(struct device___340 *);
	int (*num_vf)(struct device___340 *);
	int (*dma_configure)(struct device___340 *);
	const struct dev_pm_ops___340 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___340 {
	const char *name;
	struct bus_type___340 *bus;
	struct module___304 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___340 *);
	int (*remove)(struct device___340 *);
	void (*shutdown)(struct device___340 *);
	int (*suspend)(struct device___340 *, pm_message_t);
	int (*resume)(struct device___340 *);
	const struct attribute_group___337 **groups;
	const struct dev_pm_ops___340 *pm;
	void (*coredump)(struct device___340 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___340 {
	const char *name;
	const struct attribute_group___337 **groups;
	int (*uevent)(struct device___340 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___340 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___340 *);
	const struct dev_pm_ops___340 *pm;
};

struct class___340 {
	const char *name;
	struct module___304 *owner;
	const struct attribute_group___337 **class_groups;
	const struct attribute_group___337 **dev_groups;
	struct kobject___360 *dev_kobj;
	int (*dev_uevent)(struct device___340 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___340 *, umode_t *);
	void (*class_release)(struct class___340 *);
	void (*dev_release)(struct device___340 *);
	int (*shutdown_pre)(struct device___340 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___340 *);
	const struct dev_pm_ops___340 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___128 {
	void * (*alloc)(struct device___340 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___340 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___340 *, struct vm_area_struct___374 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___340 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___340 *, struct page___374 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___340 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___340 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___340 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___340 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___340 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___340 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___340 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___340 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___340 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___340 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___340 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___340 *, u64);
	u64 (*get_required_mask)(struct device___340 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

typedef void compound_page_dtor___361(struct page___374 *);

enum {
	NETIF_F_SG_BIT = 0,
	NETIF_F_IP_CSUM_BIT = 1,
	__UNUSED_NETIF_F_1 = 2,
	NETIF_F_HW_CSUM_BIT = 3,
	NETIF_F_IPV6_CSUM_BIT = 4,
	NETIF_F_HIGHDMA_BIT = 5,
	NETIF_F_FRAGLIST_BIT = 6,
	NETIF_F_HW_VLAN_CTAG_TX_BIT = 7,
	NETIF_F_HW_VLAN_CTAG_RX_BIT = 8,
	NETIF_F_HW_VLAN_CTAG_FILTER_BIT = 9,
	NETIF_F_VLAN_CHALLENGED_BIT = 10,
	NETIF_F_GSO_BIT = 11,
	NETIF_F_LLTX_BIT = 12,
	NETIF_F_NETNS_LOCAL_BIT = 13,
	NETIF_F_GRO_BIT = 14,
	NETIF_F_LRO_BIT = 15,
	NETIF_F_GSO_SHIFT = 16,
	NETIF_F_TSO_BIT = 16,
	NETIF_F_GSO_ROBUST_BIT = 17,
	NETIF_F_TSO_ECN_BIT = 18,
	NETIF_F_TSO_MANGLEID_BIT = 19,
	NETIF_F_TSO6_BIT = 20,
	NETIF_F_FSO_BIT = 21,
	NETIF_F_GSO_GRE_BIT = 22,
	NETIF_F_GSO_GRE_CSUM_BIT = 23,
	NETIF_F_GSO_IPXIP4_BIT = 24,
	NETIF_F_GSO_IPXIP6_BIT = 25,
	NETIF_F_GSO_UDP_TUNNEL_BIT = 26,
	NETIF_F_GSO_UDP_TUNNEL_CSUM_BIT = 27,
	NETIF_F_GSO_PARTIAL_BIT = 28,
	NETIF_F_GSO_TUNNEL_REMCSUM_BIT = 29,
	NETIF_F_GSO_SCTP_BIT = 30,
	NETIF_F_GSO_ESP_BIT = 31,
	NETIF_F_GSO_UDP_BIT = 32,
	NETIF_F_GSO_UDP_L4_BIT = 33,
	NETIF_F_GSO_LAST = 33,
	__NETIF_F_RH_KABI_PLACEHOLDER_1 = 34,
	__NETIF_F_RH_KABI_PLACEHOLDER_2 = 35,
	__NETIF_F_RH_KABI_PLACEHOLDER_3 = 36,
	__NETIF_F_RH_KABI_PLACEHOLDER_4 = 37,
	__NETIF_F_RH_KABI_PLACEHOLDER_5 = 38,
	__NETIF_F_RH_KABI_PLACEHOLDER_6 = 39,
	__NETIF_F_RH_KABI_PLACEHOLDER_7 = 40,
	__NETIF_F_RH_KABI_PLACEHOLDER_8 = 41,
	NETIF_F_HW_TLS_RX_BIT = 42,
	NETIF_F_FCOE_CRC_BIT = 43,
	NETIF_F_SCTP_CRC_BIT = 44,
	NETIF_F_FCOE_MTU_BIT = 45,
	NETIF_F_NTUPLE_BIT = 46,
	NETIF_F_RXHASH_BIT = 47,
	NETIF_F_RXCSUM_BIT = 48,
	NETIF_F_NOCACHE_COPY_BIT = 49,
	NETIF_F_LOOPBACK_BIT = 50,
	NETIF_F_RXFCS_BIT = 51,
	NETIF_F_RXALL_BIT = 52,
	NETIF_F_HW_VLAN_STAG_TX_BIT = 53,
	NETIF_F_HW_VLAN_STAG_RX_BIT = 54,
	NETIF_F_HW_VLAN_STAG_FILTER_BIT = 55,
	NETIF_F_HW_L2FW_DOFFLOAD_BIT = 56,
	NETIF_F_HW_TC_BIT = 57,
	NETIF_F_HW_ESP_BIT = 58,
	NETIF_F_HW_ESP_TX_CSUM_BIT = 59,
	NETIF_F_RX_UDP_TUNNEL_PORT_BIT = 60,
	NETIF_F_HW_TLS_TX_BIT = 61,
	NETIF_F_GRO_HW_BIT = 62,
	NETIF_F_HW_TLS_RECORD_BIT = 63,
	NETDEV_FEATURE_COUNT = 64,
};

struct pipe_buf_operations___75;

struct pipe_buffer___75 {
	struct page___374 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___75 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___75 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___75 *, struct pipe_buffer___75 *);
	void (*release)(struct pipe_inode_info___75 *, struct pipe_buffer___75 *);
	int (*steal)(struct pipe_inode_info___75 *, struct pipe_buffer___75 *);
	union {
		bool (*get)(struct pipe_inode_info___75 *, struct pipe_buffer___75 *);
		struct {
			void (*get)(struct pipe_inode_info___75 *, struct pipe_buffer___75 *);
		} __UNIQUE_ID_rh_kabi_hide21;
		union {		};
	};
};

struct nf_bridge_info___42 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___42 = 0,
		BRNF_PROTO_8021Q___42 = 1,
		BRNF_PROTO_PPPOE___42 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___44 *physindev;
	struct net_device___44 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

struct skb_frag_struct___2 {
	struct {
		struct page___374 *p;
	} page;
	__u32 page_offset;
	__u32 size;
};

typedef struct skb_frag_struct___2 skb_frag_t___2;

enum {
	SKBTX_HW_TSTAMP = 1,
	SKBTX_SW_TSTAMP = 2,
	SKBTX_IN_PROGRESS = 4,
	SKBTX_DEV_ZEROCOPY = 8,
	SKBTX_WIFI_STATUS = 16,
	SKBTX_SHARED_FRAG = 32,
	SKBTX_SCHED_TSTAMP = 64,
};

struct skb_shared_info___2 {
	__u8 __unused;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___44 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___2 frags[16];
};

struct ucounts___248 {
	struct hlist_node node;
	struct user_namespace___248 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_prog_aux___42;

struct bpf_prog___39 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___42 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

typedef int (*key_restrict_link_func_t___344)(struct key___343 *, const struct key_type *, const union key_payload *, struct key___343 *);

struct key_restriction___343;

struct key___343 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___374 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___343 *restrict_link;
};

struct key_restriction___343 {
	key_restrict_link_func_t___344 check;
	struct key___343 *key;
	struct key_type *keytype;
};

struct seq_operations___315 {
	void * (*start)(struct seq_file___316 *, loff_t *);
	void (*stop)(struct seq_file___316 *, void *);
	void * (*next)(struct seq_file___316 *, void *, loff_t *);
	int (*show)(struct seq_file___316 *, void *);
};

struct pernet_operations___43 {
	struct list_head list;
	int (*init)(struct net___53 *);
	void (*exit)(struct net___53 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct ethtool_ops___42 {
	int (*get_settings)(struct net_device___44 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___44 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___44 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___44 *);
	void (*get_regs)(struct net_device___44 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___44 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___44 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___44 *);
	void (*set_msglevel)(struct net_device___44 *, u32);
	int (*nway_reset)(struct net_device___44 *);
	u32 (*get_link)(struct net_device___44 *);
	int (*get_eeprom_len)(struct net_device___44 *);
	int (*get_eeprom)(struct net_device___44 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___44 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___44 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___44 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___44 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___44 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___44 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___44 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___44 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___44 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___44 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___44 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___44 *);
	void (*complete)(struct net_device___44 *);
	u32 (*get_priv_flags)(struct net_device___44 *);
	int (*set_priv_flags)(struct net_device___44 *, u32);
	int (*get_sset_count)(struct net_device___44 *, int);
	int (*get_rxnfc)(struct net_device___44 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___44 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___44 *, struct ethtool_flash *);
	int (*reset)(struct net_device___44 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___44 *);
	u32 (*get_rxfh_indir_size)(struct net_device___44 *);
	int (*get_rxfh)(struct net_device___44 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___44 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___44 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___44 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___44 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___44 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___44 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___44 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___44 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___44 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___44 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___44 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___44 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___44 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___44 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___44 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___44 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___44 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___44 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___44 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___44 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___44 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	int (*get_fecparam)(struct net_device___44 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___44 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___44 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___44 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___44 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct dcbnl_rtnl_ops___42 {
	int (*ieee_getets)(struct net_device___44 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___44 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___44 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___44 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___44 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___44 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___44 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___44 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___44 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___44 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___44 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___44 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___44 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___44 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___44 *);
	u8 (*setstate)(struct net_device___44 *, u8);
	void (*getpermhwaddr)(struct net_device___44 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___44 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___44 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___44 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___44 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___44 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___44 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___44 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___44 *, int, u8 *);
	void (*setpfccfg)(struct net_device___44 *, int, u8);
	void (*getpfccfg)(struct net_device___44 *, int, u8 *);
	u8 (*setall)(struct net_device___44 *);
	u8 (*getcap)(struct net_device___44 *, int, u8 *);
	int (*getnumtcs)(struct net_device___44 *, int, u8 *);
	int (*setnumtcs)(struct net_device___44 *, int, u8);
	u8 (*getpfcstate)(struct net_device___44 *);
	void (*setpfcstate)(struct net_device___44 *, u8);
	void (*getbcncfg)(struct net_device___44 *, int, u32 *);
	void (*setbcncfg)(struct net_device___44 *, int, u32);
	void (*getbcnrp)(struct net_device___44 *, int, u8 *);
	void (*setbcnrp)(struct net_device___44 *, int, u8);
	int (*setapp)(struct net_device___44 *, u8, u16, u8);
	int (*getapp)(struct net_device___44 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___44 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___44 *, int, u8);
	u8 (*getdcbx)(struct net_device___44 *);
	u8 (*setdcbx)(struct net_device___44 *, u8);
	int (*peer_getappinfo)(struct net_device___44 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___44 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___44 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___44 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___44 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___44 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___233 {
	refcount_t count;
	struct ns_common___9 ns;
	struct user_namespace___248 *user_ns;
	struct ucounts___248 *ucounts;
	struct css_set___233 *root_cset;
};

struct bpf_map___234;

struct bpf_map_ops___233 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___234 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___234 *, struct file___373 *);
	void (*map_free)(struct bpf_map___234 *);
	int (*map_get_next_key)(struct bpf_map___234 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___234 *);
	void * (*map_lookup_elem)(struct bpf_map___234 *, void *);
	int (*map_update_elem)(struct bpf_map___234 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___234 *, void *);
	int (*map_push_elem)(struct bpf_map___234 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___234 *, void *);
	int (*map_peek_elem)(struct bpf_map___234 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___234 *, struct file___373 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___234 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___234 *, void *, struct seq_file___316 *);
	int (*map_check_btf)(const struct bpf_map___234 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___234 {
	const struct bpf_map_ops___233 *ops;
	struct bpf_map___234 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___343 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___42;

struct bpf_map_dev_ops___42 {
	int (*map_get_next_key)(struct bpf_offloaded_map___42 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___42 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___42 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___42 *, void *);
};

struct bpf_offloaded_map___42 {
	struct bpf_map___234 map;
	struct net_device___44 *netdev;
	const struct bpf_map_dev_ops___42 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___39 {
	int (*test_run)(struct bpf_prog___39 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___39 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___39 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___39 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___39 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___39 *, u32 *);
};

struct bpf_prog_offload_ops___39 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___39 *);
	int (*translate)(struct bpf_prog___39 *);
	void (*destroy)(struct bpf_prog___39 *);
};

struct bpf_prog_offload___39 {
	struct bpf_prog___39 *prog;
	struct net_device___44 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___39 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___42 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___39 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___39 *ops;
	struct bpf_map___234 **used_maps;
	struct bpf_prog___39 *prog;
	struct user_struct___343 *user;
	u64 load_time;
	struct bpf_map___234 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___39 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___39 {
	struct bpf_prog___39 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___39 {
	struct callback_head rcu;
	struct bpf_prog_array_item___39 items[0];
};

struct cgroup_bpf___39 {
	struct bpf_prog_array___39 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___39 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___234;

typedef void (*kthread_work_func_t___234)(struct kthread_work___234 *);

struct kthread_worker___234;

struct kthread_work___234 {
	struct list_head node;
	kthread_work_func_t___234 func;
	struct kthread_worker___234 *worker;
	int canceling;
};

struct kthread_worker___234 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___374 *task;
	struct kthread_work___234 *current_work;
};

struct kthread_delayed_work___233 {
	struct kthread_work___234 work;
	struct timer_list timer;
};

struct psi_group___233 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___234 *poll_kworker;
	struct kthread_delayed_work___233 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___233;

struct cgroup_rstat_cpu___233;

struct cgroup___233 {
	struct cgroup_subsys_state___233 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___367 *kn;
	struct cgroup_file___233 procs_file;
	struct cgroup_file___233 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___233 *subsys[13];
	struct cgroup_root___233 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___233 *dom_cgrp;
	struct cgroup_rstat_cpu___233 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___39 bpf;
	atomic_t congestion_count;
	struct cgroup___233 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___233 psi;
	int ancestor_ids[0];
};

struct cftype___233;

struct cgroup_subsys___233 {
	struct cgroup_subsys_state___233 * (*css_alloc)(struct cgroup_subsys_state___233 *);
	int (*css_online)(struct cgroup_subsys_state___233 *);
	void (*css_offline)(struct cgroup_subsys_state___233 *);
	void (*css_released)(struct cgroup_subsys_state___233 *);
	void (*css_free)(struct cgroup_subsys_state___233 *);
	void (*css_reset)(struct cgroup_subsys_state___233 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___233 *, int);
	int (*css_extra_stat_show)(struct seq_file___316 *, struct cgroup_subsys_state___233 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___374 *);
	void (*cancel_fork)(struct task_struct___374 *);
	void (*fork)(struct task_struct___374 *);
	void (*exit)(struct task_struct___374 *);
	void (*free)(struct task_struct___374 *);
	void (*bind)(struct cgroup_subsys_state___233 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___233 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___233 *dfl_cftypes;
	struct cftype___233 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___233 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___233 *updated_children;
	struct cgroup___233 *updated_next;
};

struct cgroup_root___233 {
	struct kernfs_root___366 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___233 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___233 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___233 *ss;
	struct list_head node;
	struct kernfs_ops___366 *kf_ops;
	int (*open)(struct kernfs_open_file___366 *);
	void (*release)(struct kernfs_open_file___366 *);
	u64 (*read_u64)(struct cgroup_subsys_state___233 *, struct cftype___233 *);
	s64 (*read_s64)(struct cgroup_subsys_state___233 *, struct cftype___233 *);
	int (*seq_show)(struct seq_file___316 *, void *);
	void * (*seq_start)(struct seq_file___316 *, loff_t *);
	void * (*seq_next)(struct seq_file___316 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___316 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___233 *, struct cftype___233 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___233 *, struct cftype___233 *, s64);
	ssize_t (*write)(struct kernfs_open_file___366 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___366 *, struct poll_table_struct___225 *);
};

struct xdp_rxq_info___42 {
	struct net_device___44 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___42 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___44 *dev_rx;
};

struct netlink_callback___43 {
	struct sk_buff___44 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___43 *);
	int (*dump)(struct sk_buff___44 *, struct netlink_callback___43 *);
	int (*done)(struct netlink_callback___43 *);
	void *data;
	struct module___304 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___42 {
	int (*create)(struct sk_buff___44 *, struct net_device___44 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___44 *, unsigned char *);
	int (*cache)(const struct neighbour___29 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___44 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___42 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___42 *, int);
	int poll_owner;
	struct net_device___44 *dev;
	struct sk_buff___44 *gro_list;
	struct sk_buff___44 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___42 {
	struct net_device___44 *dev;
	struct Qdisc___39 *qdisc;
	struct Qdisc___39 *qdisc_sleeping;
	struct kobject___360 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___44 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___39 {
	struct sk_buff___44 *head;
	struct sk_buff___44 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___39;

struct Qdisc___39 {
	int (*enqueue)(struct sk_buff___44 *, struct Qdisc___39 *, struct sk_buff___44 **);
	struct sk_buff___44 * (*dequeue)(struct Qdisc___39 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___39 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___42 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___42 gso_skb;
	struct qdisc_skb_head___39 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___39 *next_sched;
	struct sk_buff_head___42 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___42 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___360 kobj;
	struct net_device___44 *dev;
	long: 64;
	struct xdp_rxq_info___42 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___42)(struct net_device___44 *, struct sk_buff___44 *, struct net_device___44 *);

struct netdev_bpf___42 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___39 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___39 *prog;
			const struct bpf_prog_offload_ops___39 *ops;
		} verifier;
		struct {
			struct bpf_prog___39 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___42 *offmap;
		};
		struct {
			struct xdp_umem *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___42 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___44 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___42 {
	int (*tls_dev_add)(struct net_device___44 *, struct sock___30 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___44 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___44 *, struct sock___30 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___42 {
	int (*ndo_init)(struct net_device___44 *);
	void (*ndo_uninit)(struct net_device___44 *);
	int (*ndo_open)(struct net_device___44 *);
	int (*ndo_stop)(struct net_device___44 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___44 *, struct net_device___44 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___44 *, struct net_device___44 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___44 *, struct sk_buff___44 *, struct net_device___44 *, select_queue_fallback_t___42);
	void (*ndo_change_rx_flags)(struct net_device___44 *, int);
	void (*ndo_set_rx_mode)(struct net_device___44 *);
	int (*ndo_set_mac_address)(struct net_device___44 *, void *);
	int (*ndo_validate_addr)(struct net_device___44 *);
	int (*ndo_do_ioctl)(struct net_device___44 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___44 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___44 *, int);
	int (*ndo_neigh_setup)(struct net_device___44 *, struct neigh_parms___29 *);
	void (*ndo_tx_timeout)(struct net_device___44 *);
	void (*ndo_get_stats64)(struct net_device___44 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___44 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___44 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___44 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___44 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___44 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___44 *);
	int (*ndo_netpoll_setup)(struct net_device___44 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___44 *);
	int (*ndo_set_vf_mac)(struct net_device___44 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___44 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___44 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___44 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___44 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___44 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___44 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___44 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___44 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___44 *, int, struct sk_buff___44 *);
	int (*ndo_set_vf_guid)(struct net_device___44 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___44 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___44 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___44 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___44 *, const struct sk_buff___44 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___44 *, struct net_device___44 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___44 *, struct net_device___44 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___44 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___44 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___44 *, struct neighbour___29 *);
	void (*ndo_neigh_destroy)(struct net_device___44 *, struct neighbour___29 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___44 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___44 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___44 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___44 *, struct netlink_callback___43 *, struct net_device___44 *, struct net_device___44 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___44 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___44 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___44 *, u32, u32, struct net_device___44 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___44 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___44 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___44 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___44 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___44 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___44 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___44 *, struct net_device___44 *);
	void (*ndo_dfwd_del_station)(struct net_device___44 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___44 *);
	int (*ndo_set_tx_maxrate)(struct net_device___44 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___44 *);
	int (*ndo_change_proto_down)(struct net_device___44 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___44 *, struct sk_buff___44 *);
	void (*ndo_set_rx_headroom)(struct net_device___44 *, int);
	int (*ndo_bpf)(struct net_device___44 *, struct netdev_bpf___42 *);
	int (*ndo_xdp_xmit)(struct net_device___44 *, int, struct xdp_frame___42 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___44 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___44 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___29 {
	possible_net_t___43 net;
	struct net_device___44 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___29 *);
	void (*neigh_cleanup)(struct neighbour___29 *);
	struct neigh_table___29 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

enum netdev_priv_flags {
	IFF_802_1Q_VLAN = 1,
	IFF_EBRIDGE = 2,
	IFF_BONDING = 4,
	IFF_ISATAP = 8,
	IFF_WAN_HDLC = 16,
	IFF_XMIT_DST_RELEASE = 32,
	IFF_DONT_BRIDGE = 64,
	IFF_DISABLE_NETPOLL = 128,
	IFF_MACVLAN_PORT = 256,
	IFF_BRIDGE_PORT = 512,
	IFF_OVS_DATAPATH = 1024,
	IFF_TX_SKB_SHARING = 2048,
	IFF_UNICAST_FLT = 4096,
	IFF_TEAM_PORT = 8192,
	IFF_SUPP_NOFCS = 16384,
	IFF_LIVE_ADDR_CHANGE = 32768,
	IFF_MACVLAN = 65536,
	IFF_XMIT_DST_RELEASE_PERM = 131072,
	IFF_L3MDEV_MASTER = 262144,
	IFF_NO_QUEUE = 524288,
	IFF_OPENVSWITCH = 1048576,
	IFF_L3MDEV_SLAVE = 2097152,
	IFF_TEAM = 4194304,
	IFF_RXFH_CONFIGURED = 8388608,
	IFF_PHONY_HEADROOM = 16777216,
	IFF_MACSEC = 33554432,
	IFF_NO_RX_HANDLER = 67108864,
	IFF_FAILOVER = 134217728,
	IFF_FAILOVER_SLAVE = 268435456,
	IFF_L3MDEV_RX_HANDLER = 536870912,
};

struct l3mdev_ops___29 {
	u32 (*l3mdev_fib_table)(const struct net_device___44 *);
	struct sk_buff___44 * (*l3mdev_l3_rcv)(struct net_device___44 *, struct sk_buff___44 *, u16);
	struct sk_buff___44 * (*l3mdev_l3_out)(struct net_device___44 *, struct sock___30 *, struct sk_buff___44 *, u16);
	struct dst_entry___29 * (*l3mdev_link_scope_lookup)(const struct net_device___44 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct tcf_proto___39;

struct mini_Qdisc___39 {
	struct tcf_proto___39 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___39 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___44 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___53 *, struct net_device___44 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___44 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___44 *, struct list_head *);
	size_t (*get_size)(const struct net_device___44 *);
	int (*fill_info)(struct sk_buff___44 *, const struct net_device___44 *);
	size_t (*get_xstats_size)(const struct net_device___44 *);
	int (*fill_xstats)(struct sk_buff___44 *, const struct net_device___44 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___44 *, struct net_device___44 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___44 *, const struct net_device___44 *);
	int (*fill_slave_info)(struct sk_buff___44 *, const struct net_device___44 *, const struct net_device___44 *);
	struct net___53 * (*get_link_net)(const struct net_device___44 *);
	size_t (*get_linkxstats_size)(const struct net_device___44 *, int);
	int (*fill_linkxstats)(struct sk_buff___44 *, const struct net_device___44 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___42 {
	struct list_head poll_list;
	struct sk_buff_head___42 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___42 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___39 *output_queue;
	struct Qdisc___39 **output_queue_tailp;
	struct sk_buff___44 *completion_queue;
	struct sk_buff_head___42 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___42 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___42 input_pkt_queue;
	struct napi_struct___42 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bdi_writeback_congested___188 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___188 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___188 {
	struct bio___188 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___190 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___190 bip_inline_vecs[0];
};

struct bio_set___188 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___188 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___134 {
	struct mem_cgroup___134 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___134 {
	struct lruvec___373 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___134 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___134 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct gnet_dump___39 {
	spinlock_t *lock;
	struct sk_buff___44 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___39;

struct Qdisc_ops___39 {
	struct Qdisc_ops___39 *next;
	const struct Qdisc_class_ops___39 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___44 *, struct Qdisc___39 *, struct sk_buff___44 **);
	struct sk_buff___44 * (*dequeue)(struct Qdisc___39 *);
	struct sk_buff___44 * (*peek)(struct Qdisc___39 *);
	int (*init)(struct Qdisc___39 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___39 *);
	void (*destroy)(struct Qdisc___39 *);
	int (*change)(struct Qdisc___39 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___39 *);
	int (*change_tx_queue_len)(struct Qdisc___39 *, unsigned int);
	int (*dump)(struct Qdisc___39 *, struct sk_buff___44 *);
	int (*dump_stats)(struct Qdisc___39 *, struct gnet_dump___39 *);
	void (*ingress_block_set)(struct Qdisc___39 *, u32);
	void (*egress_block_set)(struct Qdisc___39 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___39 *);
	u32 (*egress_block_get)(struct Qdisc___39 *);
	struct module___304 *owner;
};

struct tcf_block___39;

struct Qdisc_class_ops___39 {
	unsigned int flags;
	struct netdev_queue___42 * (*select_queue)(struct Qdisc___39 *, struct tcmsg *);
	int (*graft)(struct Qdisc___39 *, long unsigned int, struct Qdisc___39 *, struct Qdisc___39 **, struct netlink_ext_ack *);
	struct Qdisc___39 * (*leaf)(struct Qdisc___39 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___39 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___39 *, u32);
	int (*change)(struct Qdisc___39 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___39 *, long unsigned int);
	void (*walk)(struct Qdisc___39 *, struct qdisc_walker *);
	struct tcf_block___39 * (*tcf_block)(struct Qdisc___39 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___39 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___39 *, long unsigned int);
	int (*dump)(struct Qdisc___39 *, long unsigned int, struct sk_buff___44 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___39 *, long unsigned int, struct gnet_dump___39 *);
};

struct tcf_chain___39;

struct tcf_block___39 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___53 *net;
	struct Qdisc___39 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___39 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___39;

struct tcf_proto_ops___39;

struct tcf_proto___39 {
	struct tcf_proto___39 *next;
	void *root;
	int (*classify)(struct sk_buff___44 *, const struct tcf_proto___39 *, struct tcf_result___39 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___39 *ops;
	struct tcf_chain___39 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___39 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___39 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___39 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___44 *, const struct tcf_proto___39 *, struct tcf_result___39 *);
	int (*init)(struct tcf_proto___39 *);
	void (*destroy)(struct tcf_proto___39 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___39 *, u32);
	void (*put)(struct tcf_proto___39 *, void *);
	int (*change)(struct net___53 *, struct sk_buff___44 *, struct tcf_proto___39 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___39 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___39 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___39 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___53 *, struct tcf_chain___39 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___53 *, struct tcf_proto___39 *, void *, struct sk_buff___44 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___44 *, struct net___53 *, void *);
	struct module___304 *owner;
	int flags;
};

struct tcf_chain___39 {
	struct mutex filter_chain_lock;
	struct tcf_proto___39 *filter_chain;
	struct list_head list;
	struct tcf_block___39 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___39 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___29 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___39 *prog;
};

struct bpf_redirect_info___39 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___234 *map;
	struct bpf_map___234 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___29;

struct neigh_hash_table___29;

struct neigh_table___29 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___44 *, __u32 *);
	bool (*key_eq)(const struct neighbour___29 *, const void *);
	int (*constructor)(struct neighbour___29 *);
	int (*pconstructor)(struct pneigh_entry___29 *);
	void (*pdestructor)(struct pneigh_entry___29 *);
	void (*proxy_redo)(struct sk_buff___44 *);
	char *id;
	struct neigh_parms___29 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___42 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___29 *nht;
	struct pneigh_entry___29 **phash_buckets;
};

struct neigh_ops___29 {
	int family;
	void (*solicit)(struct neighbour___29 *, struct sk_buff___44 *);
	void (*error_report)(struct neighbour___29 *, struct sk_buff___44 *);
	int (*output)(struct neighbour___29 *, struct sk_buff___44 *);
	int (*connected_output)(struct neighbour___29 *, struct sk_buff___44 *);
};

struct pneigh_entry___29 {
	struct pneigh_entry___29 *next;
	possible_net_t___43 net;
	struct net_device___44 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___29 {
	struct neighbour___29 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

enum {
	SOF_TIMESTAMPING_TX_HARDWARE = 1,
	SOF_TIMESTAMPING_TX_SOFTWARE = 2,
	SOF_TIMESTAMPING_RX_HARDWARE = 4,
	SOF_TIMESTAMPING_RX_SOFTWARE = 8,
	SOF_TIMESTAMPING_SOFTWARE = 16,
	SOF_TIMESTAMPING_SYS_HARDWARE = 32,
	SOF_TIMESTAMPING_RAW_HARDWARE = 64,
	SOF_TIMESTAMPING_OPT_ID = 128,
	SOF_TIMESTAMPING_TX_SCHED = 256,
	SOF_TIMESTAMPING_TX_ACK = 512,
	SOF_TIMESTAMPING_OPT_CMSG = 1024,
	SOF_TIMESTAMPING_OPT_TSONLY = 2048,
	SOF_TIMESTAMPING_OPT_STATS = 4096,
	SOF_TIMESTAMPING_OPT_PKTINFO = 8192,
	SOF_TIMESTAMPING_OPT_TX_SWHW = 16384,
	SOF_TIMESTAMPING_LAST = 16384,
	SOF_TIMESTAMPING_MASK = 32767,
};

struct fib_rule___29 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___29 *ctarget;
	struct net___53 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___29 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___29 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___18;

struct timewait_sock_ops___16;

struct proto___29 {
	void (*close)(struct sock___30 *, long int);
	int (*pre_connect)(struct sock___30 *, struct sockaddr *, int);
	int (*connect)(struct sock___30 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___30 *, int);
	struct sock___30 * (*accept)(struct sock___30 *, int, int *, bool);
	int (*ioctl)(struct sock___30 *, int, long unsigned int);
	int (*init)(struct sock___30 *);
	void (*destroy)(struct sock___30 *);
	void (*shutdown)(struct sock___30 *, int);
	int (*setsockopt)(struct sock___30 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___30 *, int, int, char *, int *);
	void (*keepalive)(struct sock___30 *, int);
	int (*sendmsg)(struct sock___30 *, struct msghdr___32 *, size_t);
	int (*recvmsg)(struct sock___30 *, struct msghdr___32 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___30 *, struct page___374 *, int, size_t, int);
	int (*bind)(struct sock___30 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___30 *, struct sk_buff___44 *);
	void (*release_cb)(struct sock___30 *);
	int (*hash)(struct sock___30 *);
	void (*unhash)(struct sock___30 *);
	void (*rehash)(struct sock___30 *);
	int (*get_port)(struct sock___30 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___30 *);
	bool (*stream_memory_read)(const struct sock___30 *);
	void (*enter_memory_pressure)(struct sock___30 *);
	void (*leave_memory_pressure)(struct sock___30 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___18 *rsk_prot;
	struct timewait_sock_ops___16 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___304 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___30 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct request_sock___19;

struct request_sock_ops___18 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___30 *, struct request_sock___19 *);
	void (*send_ack)(const struct sock___30 *, struct sk_buff___44 *, struct request_sock___19 *);
	void (*send_reset)(const struct sock___30 *, struct sk_buff___44 *);
	void (*destructor)(struct request_sock___19 *);
	void (*syn_ack_timeout)(const struct request_sock___19 *);
};

struct timewait_sock_ops___16 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___30 *, struct sock___30 *, void *);
	void (*twsk_destructor)(struct sock___30 *);
};

struct request_sock___19 {
	struct sock_common___29 __req_common;
	struct request_sock___19 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___18 *rsk_ops;
	struct sock___30 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct module___305;

struct file___374;

struct kiocb___374;

struct iov_iter___158;

struct vm_area_struct___375;

struct inode___374;

struct file_lock___374;

struct page___375;

struct pipe_inode_info___76;

struct file_operations___374 {
	struct module___305 *owner;
	loff_t (*llseek)(struct file___374 *, loff_t, int);
	ssize_t (*read)(struct file___374 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___374 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___374 *, struct iov_iter___158 *);
	ssize_t (*write_iter)(struct kiocb___374 *, struct iov_iter___158 *);
	int (*iopoll)(struct kiocb___374 *, bool);
	int (*iterate)(struct file___374 *, struct dir_context *);
	int (*iterate_shared)(struct file___374 *, struct dir_context *);
	__poll_t (*poll)(struct file___374 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___374 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___374 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___374 *, struct vm_area_struct___375 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___374 *, struct file___374 *);
	int (*flush)(struct file___374 *, fl_owner_t);
	int (*release)(struct inode___374 *, struct file___374 *);
	int (*fsync)(struct file___374 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___374 *, int);
	int (*lock)(struct file___374 *, int, struct file_lock___374 *);
	ssize_t (*sendpage)(struct file___374 *, struct page___375 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___374 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___374 *, int, struct file_lock___374 *);
	ssize_t (*splice_write)(struct pipe_inode_info___76 *, struct file___374 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___374 *, loff_t *, struct pipe_inode_info___76 *, size_t, unsigned int);
	int (*setlease)(struct file___374 *, long int, struct file_lock___374 **, void **);
	long int (*fallocate)(struct file___374 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___374 *);
	ssize_t (*copy_file_range)(struct file___374 *, loff_t, struct file___374 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___374 *, loff_t, struct file___374 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___374 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___374 {
	u64 seqnum;
	struct vm_area_struct___375 *vmas[4];
};

struct page_frag___374 {
	struct page___375 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___374;

struct vm_struct___280;

struct task_struct___375 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___375 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___374 *mm;
	struct mm_struct___374 *active_mm;
	struct vmacache___374 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___375 *real_parent;
	struct task_struct___375 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___375 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___218 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___218 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___218 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___2 *ptracer_cred;
	const struct cred___2 *real_cred;
	const struct cred___2 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___375 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___107 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___76 *splice_pipe;
	struct page_frag___374 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___375 *oom_reaper_list;
	struct vm_struct___280 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___142 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___375 *pgtable_t___374;

struct address_space___373;

struct dev_pagemap___362;

struct page___375 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___373 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___375 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___374 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___374 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___362 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___374;

struct lruvec___374 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___374 *pgdat;
};

struct zone___374 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___374 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___374 {
	struct zone___374 *zone;
	int zone_idx;
};

struct zonelist___374 {
	struct zoneref___374 _zonerefs[25];
};

struct pglist_data___374 {
	struct zone___374 node_zones[3];
	struct zonelist___374 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___375 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___375 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___374 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___375 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___375 *owner;
};

struct secondary_data___375 {
	void *stack;
	struct task_struct___375 *task;
	long int status;
};

struct blocking_notifier_head___374 {
	struct rw_semaphore___375 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___362;

struct vm_area_struct___375 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___375 *vm_next;
	struct vm_area_struct___375 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___374 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___362 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___374 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___374;

struct mm_struct___374 {
	struct {
		struct vm_area_struct___375 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___374 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___375 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___374 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___375 *owner;
		struct user_namespace___3 *user_ns;
		struct file___374 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___374 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct fasync_struct___373;

struct pipe_buffer___76;

struct pipe_inode_info___76 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___375 *tmp_page;
	struct fasync_struct___373 *fasync_readers;
	struct fasync_struct___373 *fasync_writers;
	struct pipe_buffer___76 *bufs;
	struct user_struct___25 *user;
};

struct vm_struct___280 {
	struct vm_struct___280 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___375 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___373;

struct address_space___373 {
	struct inode___374 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___375 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___373 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___362)(struct vm_area_struct___375 *, long unsigned int, const struct page___375 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___362)(struct page___375 *, void *);

struct device___341;

struct dev_pagemap___362 {
	dev_page_fault_t___362 page_fault;
	dev_page_free_t___362 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___341 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct dentry___373;

struct path___374 {
	struct vfsmount *mnt;
	struct dentry___373 *dentry;
};

struct file___374 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___374 f_path;
	struct inode___374 *f_inode;
	const struct file_operations___374 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___218 f_owner;
	const struct cred___2 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___373 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___362;

struct vm_operations_struct___362 {
	void (*open)(struct vm_area_struct___375 *);
	void (*close)(struct vm_area_struct___375 *);
	int (*split)(struct vm_area_struct___375 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___375 *);
	vm_fault_t (*fault)(struct vm_fault___362 *);
	vm_fault_t (*huge_fault)(struct vm_fault___362 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___362 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___375 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___362 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___362 *);
	int (*access)(struct vm_area_struct___375 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___375 *);
	int (*set_policy)(struct vm_area_struct___375 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___375 *, long unsigned int);
	struct page___375 * (*find_special_page)(struct vm_area_struct___375 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___374 {
	struct task_struct___375 *task;
	struct core_thread___374 *next;
};

struct core_state___374 {
	atomic_t nr_threads;
	struct core_thread___374 dumper;
	struct completion startup;
};

struct vm_fault___362 {
	struct vm_area_struct___375 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___375 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___375 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___374 prealloc_pte;
};

struct kset___360;

struct kobj_type___360;

struct kernfs_node___368;

struct kobject___361 {
	const char *name;
	struct list_head entry;
	struct kobject___361 *parent;
	struct kset___360 *kset;
	struct kobj_type___360 *ktype;
	struct kernfs_node___368 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___302 {
	struct kobject___361 kobj;
	struct module___305 *mod;
	struct kobject___361 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___302 {
	struct module___305 *mod;
	struct latch_tree_node node;
};

struct module_layout___302 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___302 mtn;
};

struct module_attribute___302;

struct kernel_param___302;

struct module___305 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___302 mkobj;
	struct module_attribute___302 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___361 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___302 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___302 core_layout;
	struct module_layout___302 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct iov_iter___158 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___3 *bvec;
		struct pipe_inode_info___76 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct kiocb___374 {
	struct file___374 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___374 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dentry_operations___373;

struct super_block___373;

struct dentry___373 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___373 *d_parent;
	struct qstr d_name;
	struct inode___374 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___373 *d_op;
	struct super_block___373 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___373;

struct block_device___373;

struct inode___374 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___373 *i_op;
	struct super_block___373 *i_sb;
	struct address_space___373 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___375 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___374 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___373 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___76 *i_pipe;
		struct block_device___373 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___373 {
	int (*d_revalidate)(struct dentry___373 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___373 *, unsigned int);
	int (*d_hash)(const struct dentry___373 *, struct qstr *);
	int (*d_compare)(const struct dentry___373 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___373 *);
	int (*d_init)(struct dentry___373 *);
	void (*d_release)(struct dentry___373 *);
	void (*d_prune)(struct dentry___373 *);
	void (*d_iput)(struct dentry___373 *, struct inode___374 *);
	char * (*d_dname)(struct dentry___373 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___374 *);
	int (*d_manage)(const struct path___374 *, bool);
	struct dentry___373 * (*d_real)(struct dentry___373 *, const struct inode___374 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___373;

struct mem_dqinfo___373 {
	struct quota_format_type___373 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___373;

struct quota_info___373 {
	unsigned int flags;
	struct rw_semaphore___375 dqio_sem;
	struct inode___374 *files[3];
	struct mem_dqinfo___373 info[3];
	const struct quota_format_ops___373 *ops[3];
};

struct rcuwait___373 {
	struct task_struct___375 *task;
};

struct percpu_rw_semaphore___373 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___375 rw_sem;
	struct rcuwait___373 writer;
	int readers_block;
};

struct sb_writers___373 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___373 rw_sem[3];
};

struct file_system_type___373;

struct super_operations___373;

struct dquot_operations___373;

struct quotactl_ops___373;

struct super_block___373 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___373 *s_type;
	const struct super_operations___373 *s_op;
	const struct dquot_operations___373 *dq_op;
	const struct quotactl_ops___373 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___373 *s_root;
	struct rw_semaphore___375 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___373 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___373 s_dquot;
	struct sb_writers___373 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___373 *s_d_op;
	int cleancache_poolid;
	struct shrinker___134 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct iattr___373 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___374 *ia_file;
};

struct dquot___373 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___373 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___373 {
	int qf_fmt_id;
	const struct quota_format_ops___373 *qf_ops;
	struct module___305 *qf_owner;
	struct quota_format_type___373 *qf_next;
};

struct quota_format_ops___373 {
	int (*check_quota_file)(struct super_block___373 *, int);
	int (*read_file_info)(struct super_block___373 *, int);
	int (*write_file_info)(struct super_block___373 *, int);
	int (*free_file_info)(struct super_block___373 *, int);
	int (*read_dqblk)(struct dquot___373 *);
	int (*commit_dqblk)(struct dquot___373 *);
	int (*release_dqblk)(struct dquot___373 *);
	int (*get_next_id)(struct super_block___373 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___373 {
	int (*write_dquot)(struct dquot___373 *);
	struct dquot___373 * (*alloc_dquot)(struct super_block___373 *, int);
	void (*destroy_dquot)(struct dquot___373 *);
	int (*acquire_dquot)(struct dquot___373 *);
	int (*release_dquot)(struct dquot___373 *);
	int (*mark_dirty)(struct dquot___373 *);
	int (*write_info)(struct super_block___373 *, int);
	qsize_t * (*get_reserved_space)(struct inode___374 *);
	int (*get_projid)(struct inode___374 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___374 *, qsize_t *);
	int (*get_next_id)(struct super_block___373 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___373 {
	int (*quota_on)(struct super_block___373 *, int, int, const struct path___374 *);
	int (*quota_off)(struct super_block___373 *, int);
	int (*quota_enable)(struct super_block___373 *, unsigned int);
	int (*quota_disable)(struct super_block___373 *, unsigned int);
	int (*quota_sync)(struct super_block___373 *, int);
	int (*set_info)(struct super_block___373 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___373 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___373 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___373 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___373 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___373 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___373 {
	int (*writepage)(struct page___375 *, struct writeback_control___3 *);
	int (*readpage)(struct file___374 *, struct page___375 *);
	int (*writepages)(struct address_space___373 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___375 *);
	int (*readpages)(struct file___374 *, struct address_space___373 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___374 *, struct address_space___373 *, loff_t, unsigned int, unsigned int, struct page___375 **, void **);
	int (*write_end)(struct file___374 *, struct address_space___373 *, loff_t, unsigned int, unsigned int, struct page___375 *, void *);
	sector_t (*bmap)(struct address_space___373 *, sector_t);
	void (*invalidatepage)(struct page___375 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___375 *, gfp_t);
	void (*freepage)(struct page___375 *);
	ssize_t (*direct_IO)(struct kiocb___374 *, struct iov_iter___158 *);
	int (*migratepage)(struct address_space___373 *, struct page___375 *, struct page___375 *, enum migrate_mode);
	bool (*isolate_page)(struct page___375 *, isolate_mode_t);
	void (*putback_page)(struct page___375 *);
	int (*launder_page)(struct page___375 *);
	int (*is_partially_uptodate)(struct page___375 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___375 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___373 *, struct page___375 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___374 *, sector_t *);
	void (*swap_deactivate)(struct file___374 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___373 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___374 *bd_inode;
	struct super_block___373 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___373 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___373 {
	struct dentry___373 * (*lookup)(struct inode___374 *, struct dentry___373 *, unsigned int);
	const char * (*get_link)(struct dentry___373 *, struct inode___374 *, struct delayed_call *);
	int (*permission)(struct inode___374 *, int);
	struct posix_acl * (*get_acl)(struct inode___374 *, int);
	int (*readlink)(struct dentry___373 *, char *, int);
	int (*create)(struct inode___374 *, struct dentry___373 *, umode_t, bool);
	int (*link)(struct dentry___373 *, struct inode___374 *, struct dentry___373 *);
	int (*unlink)(struct inode___374 *, struct dentry___373 *);
	int (*symlink)(struct inode___374 *, struct dentry___373 *, const char *);
	int (*mkdir)(struct inode___374 *, struct dentry___373 *, umode_t);
	int (*rmdir)(struct inode___374 *, struct dentry___373 *);
	int (*mknod)(struct inode___374 *, struct dentry___373 *, umode_t, dev_t);
	int (*rename)(struct inode___374 *, struct dentry___373 *, struct inode___374 *, struct dentry___373 *, unsigned int);
	int (*setattr)(struct dentry___373 *, struct iattr___373 *);
	int (*getattr)(const struct path___374 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___373 *, char *, size_t);
	int (*fiemap)(struct inode___374 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___374 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___374 *, struct dentry___373 *, struct file___374 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___374 *, struct dentry___373 *, umode_t);
	int (*set_acl)(struct inode___374 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___373 {
	void (*fl_copy_lock)(struct file_lock___374 *, struct file_lock___374 *);
	void (*fl_release_private)(struct file_lock___374 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___373;

struct file_lock___374 {
	struct file_lock___374 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___374 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___373 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___373 *fl_ops;
	const struct lock_manager_operations___373 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___373 {
	int (*lm_compare_owner)(struct file_lock___374 *, struct file_lock___374 *);
	long unsigned int (*lm_owner_key)(struct file_lock___374 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___374 *);
	int (*lm_grant)(struct file_lock___374 *, int);
	bool (*lm_break)(struct file_lock___374 *);
	int (*lm_change)(struct file_lock___374 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___374 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___373 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___373 *fa_next;
	struct file___374 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___373 {
	const char *name;
	int fs_flags;
	struct dentry___373 * (*mount)(struct file_system_type___373 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___373 *);
	struct module___305 *owner;
	struct file_system_type___373 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___373 {
	struct inode___374 * (*alloc_inode)(struct super_block___373 *);
	void (*destroy_inode)(struct inode___374 *);
	void (*dirty_inode)(struct inode___374 *, int);
	int (*write_inode)(struct inode___374 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___374 *);
	void (*evict_inode)(struct inode___374 *);
	void (*put_super)(struct super_block___373 *);
	int (*sync_fs)(struct super_block___373 *, int);
	int (*freeze_super)(struct super_block___373 *);
	int (*freeze_fs)(struct super_block___373 *);
	int (*thaw_super)(struct super_block___373 *);
	int (*unfreeze_fs)(struct super_block___373 *);
	int (*statfs)(struct dentry___373 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___373 *, int *, char *);
	void (*umount_begin)(struct super_block___373 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___373 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___373 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___373 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___373 *);
	ssize_t (*quota_read)(struct super_block___373 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___373 *, int, const char *, size_t, loff_t);
	struct dquot___373 ** (*get_dquots)(struct inode___374 *);
	int (*bdev_try_to_free_page)(struct super_block___373 *, struct page___375 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___373 *, struct shrink_control___134 *);
	long int (*free_cached_objects)(struct super_block___373 *, struct shrink_control___134 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_root___367;

struct kernfs_elem_dir___367 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___367 *root;
};

struct kernfs_syscall_ops___367;

struct kernfs_root___367 {
	struct kernfs_node___368 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___367 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___367 {
	struct kernfs_node___368 *target_kn;
};

struct kernfs_ops___367;

struct kernfs_elem_attr___367 {
	const struct kernfs_ops___367 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___368 *notify_next;
};

struct kernfs_node___368 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___368 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___367 dir;
		struct kernfs_elem_symlink___367 symlink;
		struct kernfs_elem_attr___367 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___367;

struct kernfs_ops___367 {
	int (*open)(struct kernfs_open_file___367 *);
	void (*release)(struct kernfs_open_file___367 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___367 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___367 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___367 *, struct vm_area_struct___375 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___367 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___367 {
	int (*remount_fs)(struct kernfs_root___367 *, int *, char *);
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___367 *);
	int (*mkdir)(struct kernfs_node___368 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___368 *);
	int (*rename)(struct kernfs_node___368 *, struct kernfs_node___368 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___368 *, struct kernfs_root___367 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___367 {
	struct kernfs_node___368 *kn;
	struct file___374 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___362 *vm_ops;
};

struct bin_attribute___337;

struct attribute_group___338 {
	const char *name;
	umode_t (*is_visible)(struct kobject___361 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___361 *, struct bin_attribute___337 *, int);
	struct attribute **attrs;
	struct bin_attribute___337 **bin_attrs;
};

struct bin_attribute___337 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___374 *, struct kobject___361 *, struct bin_attribute___337 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___374 *, struct kobject___361 *, struct bin_attribute___337 *, char *, loff_t, size_t);
	int (*mmap)(struct file___374 *, struct kobject___361 *, struct bin_attribute___337 *, struct vm_area_struct___375 *);
};

struct sysfs_ops___360 {
	ssize_t (*show)(struct kobject___361 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___361 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___360;

struct kset___360 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___361 kobj;
	const struct kset_uevent_ops___360 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___360 {
	void (*release)(struct kobject___361 *);
	const struct sysfs_ops___360 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___29 * (*child_ns_type)(struct kobject___361 *);
	const void * (*namespace)(struct kobject___361 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___360 {
	int (* const filter)(struct kset___360 *, struct kobject___361 *);
	const char * (* const name)(struct kset___360 *, struct kobject___361 *);
	int (* const uevent)(struct kset___360 *, struct kobject___361 *, struct kobj_uevent_env *);
};

struct kobj_attribute___352 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___361 *, struct kobj_attribute___352 *, char *);
	ssize_t (*store)(struct kobject___361 *, struct kobj_attribute___352 *, const char *, size_t);
};

struct dev_pm_ops___341 {
	int (*prepare)(struct device___341 *);
	void (*complete)(struct device___341 *);
	int (*suspend)(struct device___341 *);
	int (*resume)(struct device___341 *);
	int (*freeze)(struct device___341 *);
	int (*thaw)(struct device___341 *);
	int (*poweroff)(struct device___341 *);
	int (*restore)(struct device___341 *);
	int (*suspend_late)(struct device___341 *);
	int (*resume_early)(struct device___341 *);
	int (*freeze_late)(struct device___341 *);
	int (*thaw_early)(struct device___341 *);
	int (*poweroff_late)(struct device___341 *);
	int (*restore_early)(struct device___341 *);
	int (*suspend_noirq)(struct device___341 *);
	int (*resume_noirq)(struct device___341 *);
	int (*freeze_noirq)(struct device___341 *);
	int (*thaw_noirq)(struct device___341 *);
	int (*poweroff_noirq)(struct device___341 *);
	int (*restore_noirq)(struct device___341 *);
	int (*runtime_suspend)(struct device___341 *);
	int (*runtime_resume)(struct device___341 *);
	int (*runtime_idle)(struct device___341 *);
};

struct dev_pm_info___341 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___6 *subsys_data;
	void (*set_latency_tolerance)(struct device___341 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___341;

struct bus_type___341;

struct device_driver___341;

struct dev_pm_domain___341;

struct dma_map_ops___129;

struct fwnode_handle___263;

struct class___341;

struct device___341 {
	struct device___341 *parent;
	struct device_private *p;
	struct kobject___361 kobj;
	const char *init_name;
	const struct device_type___341 *type;
	struct mutex mutex;
	struct bus_type___341 *bus;
	struct device_driver___341 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___341 power;
	struct dev_pm_domain___341 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___129 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___263 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___341 *class;
	const struct attribute_group___338 **groups;
	void (*release)(struct device___341 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___341 {
	struct dev_pm_ops___341 ops;
	void (*detach)(struct device___341 *, bool);
	int (*activate)(struct device___341 *);
	void (*sync)(struct device___341 *);
	void (*dismiss)(struct device___341 *);
};

struct bus_type___341 {
	const char *name;
	const char *dev_name;
	struct device___341 *dev_root;
	const struct attribute_group___338 **bus_groups;
	const struct attribute_group___338 **dev_groups;
	const struct attribute_group___338 **drv_groups;
	int (*match)(struct device___341 *, struct device_driver___341 *);
	int (*uevent)(struct device___341 *, struct kobj_uevent_env *);
	int (*probe)(struct device___341 *);
	int (*remove)(struct device___341 *);
	void (*shutdown)(struct device___341 *);
	int (*online)(struct device___341 *);
	int (*offline)(struct device___341 *);
	int (*suspend)(struct device___341 *, pm_message_t);
	int (*resume)(struct device___341 *);
	int (*num_vf)(struct device___341 *);
	int (*dma_configure)(struct device___341 *);
	const struct dev_pm_ops___341 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___341 {
	const char *name;
	struct bus_type___341 *bus;
	struct module___305 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___341 *);
	int (*remove)(struct device___341 *);
	void (*shutdown)(struct device___341 *);
	int (*suspend)(struct device___341 *, pm_message_t);
	int (*resume)(struct device___341 *);
	const struct attribute_group___338 **groups;
	const struct dev_pm_ops___341 *pm;
	void (*coredump)(struct device___341 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___341 {
	const char *name;
	const struct attribute_group___338 **groups;
	int (*uevent)(struct device___341 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___341 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___341 *);
	const struct dev_pm_ops___341 *pm;
};

struct class___341 {
	const char *name;
	struct module___305 *owner;
	const struct attribute_group___338 **class_groups;
	const struct attribute_group___338 **dev_groups;
	struct kobject___361 *dev_kobj;
	int (*dev_uevent)(struct device___341 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___341 *, umode_t *);
	void (*class_release)(struct class___341 *);
	void (*dev_release)(struct device___341 *);
	int (*shutdown_pre)(struct device___341 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___341 *);
	const struct dev_pm_ops___341 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___129 {
	void * (*alloc)(struct device___341 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___341 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___341 *, struct vm_area_struct___375 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___341 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___341 *, struct page___375 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___341 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___341 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___341 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___341 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___341 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___341 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___341 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___341 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___341 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___341 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___341 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___341 *, u64);
	u64 (*get_required_mask)(struct device___341 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___263;

struct fwnode_handle___263 {
	struct fwnode_handle___263 *secondary;
	const struct fwnode_operations___263 *ops;
};

typedef void compound_page_dtor___362(struct page___375 *);

struct fwnode_reference_args___263;

struct fwnode_endpoint___263;

struct fwnode_operations___263 {
	struct fwnode_handle___263 * (*get)(struct fwnode_handle___263 *);
	void (*put)(struct fwnode_handle___263 *);
	bool (*device_is_available)(const struct fwnode_handle___263 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___263 *, const struct device___341 *);
	bool (*property_present)(const struct fwnode_handle___263 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___263 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___263 *, const char *, const char **, size_t);
	struct fwnode_handle___263 * (*get_parent)(const struct fwnode_handle___263 *);
	struct fwnode_handle___263 * (*get_next_child_node)(const struct fwnode_handle___263 *, struct fwnode_handle___263 *);
	struct fwnode_handle___263 * (*get_named_child_node)(const struct fwnode_handle___263 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___263 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___263 *);
	struct fwnode_handle___263 * (*graph_get_next_endpoint)(const struct fwnode_handle___263 *, struct fwnode_handle___263 *);
	struct fwnode_handle___263 * (*graph_get_remote_endpoint)(const struct fwnode_handle___263 *);
	struct fwnode_handle___263 * (*graph_get_port_parent)(struct fwnode_handle___263 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___263 *, struct fwnode_endpoint___263 *);
};

struct fwnode_endpoint___263 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___263 *local_fwnode;
};

struct fwnode_reference_args___263 {
	struct fwnode_handle___263 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___76;

struct pipe_buffer___76 {
	struct page___375 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___76 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___76 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___76 *, struct pipe_buffer___76 *);
	void (*release)(struct pipe_inode_info___76 *, struct pipe_buffer___76 *);
	int (*steal)(struct pipe_inode_info___76 *, struct pipe_buffer___76 *);
	union {
		bool (*get)(struct pipe_inode_info___76 *, struct pipe_buffer___76 *);
		struct {
			void (*get)(struct pipe_inode_info___76 *, struct pipe_buffer___76 *);
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
};

struct mii_bus___2;

struct mdio_device___2 {
	struct device___341 dev;
	struct mii_bus___2 *bus;
	char modalias[32];
	int (*bus_match)(struct device___341 *, struct device_driver___341 *);
	void (*device_free)(struct mdio_device___2 *);
	void (*device_remove)(struct mdio_device___2 *);
	int addr;
	int flags;
	struct gpio_desc *reset;
	unsigned int reset_assert_delay;
	unsigned int reset_deassert_delay;
};

struct mii_bus___2 {
	struct module___305 *owner;
	const char *name;
	char id[61];
	void *priv;
	int (*read)(struct mii_bus___2 *, int, int);
	int (*write)(struct mii_bus___2 *, int, int, u16);
	int (*reset)(struct mii_bus___2 *);
	struct mutex mdio_lock;
	struct device___341 *parent;
	enum {
		MDIOBUS_ALLOCATED___2 = 1,
		MDIOBUS_REGISTERED___2 = 2,
		MDIOBUS_UNREGISTERED___2 = 3,
		MDIOBUS_RELEASED___2 = 4,
	} state;
	struct device___341 dev;
	struct mdio_device___2 *mdio_map[32];
	u32 phy_mask;
	u32 phy_ignore_ta_mask;
	int irq[32];
	int reset_delay_us;
	struct gpio_desc *reset_gpiod;
};

struct kernel_param_ops___302 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___302 *);
	int (*get)(char *, const struct kernel_param___302 *);
	void (*free)(void *);
};

struct kparam_array___302;

struct kernel_param___302 {
	const char *name;
	struct module___305 *mod;
	const struct kernel_param_ops___302 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___302 *arr;
	};
};

struct kparam_array___302 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___302 *ops;
	void *elem;
};

struct module_attribute___302 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___302 *, struct module_kobject___302 *, char *);
	ssize_t (*store)(struct module_attribute___302 *, struct module_kobject___302 *, const char *, size_t);
	void (*setup)(struct module___305 *, const char *);
	int (*test)(struct module___305 *);
	void (*free)(struct module___305 *);
};

struct mdio_board_info {
	const char *bus_id;
	char modalias[32];
	int mdio_addr;
	const void *platform_data;
};

struct mdio_board_entry {
	struct list_head list;
	struct mdio_board_info board_info;
};

struct mii_bus___3;

struct mdio_device___3 {
	struct device___106 dev;
	struct mii_bus___3 *bus;
	char modalias[32];
	int (*bus_match)(struct device___106 *, struct device_driver___106 *);
	void (*device_free)(struct mdio_device___3 *);
	void (*device_remove)(struct mdio_device___3 *);
	int addr;
	int flags;
	struct gpio_desc *reset;
	unsigned int reset_assert_delay;
	unsigned int reset_deassert_delay;
};

struct phy_driver___2;

struct phy_led_trigger___2;

struct phy_device {
	struct mdio_device___3 mdio;
	struct phy_driver___2 *drv;
	u32 phy_id;
	struct phy_c45_device_ids c45_ids;
	unsigned int is_c45: 1;
	unsigned int is_internal: 1;
	unsigned int is_pseudo_fixed_link: 1;
	unsigned int has_fixups: 1;
	unsigned int suspended: 1;
	unsigned int sysfs_links: 1;
	unsigned int loopback_enabled: 1;
	unsigned int autoneg: 1;
	unsigned int link: 1;
	enum phy_state state;
	u32 dev_flags;
	phy_interface_t interface;
	int speed;
	int duplex;
	int pause;
	int asym_pause;
	u32 interrupts;
	u32 rh_reserved_supported;
	u32 rh_reserved_advertising;
	u32 rh_reserved_lp_advertising;
	u32 eee_broken_modes;
	int link_timeout;
	struct phy_led_trigger___2 *phy_led_triggers;
	unsigned int phy_num_led_triggers;
	struct phy_led_trigger___2 *last_triggered;
	struct phy_led_trigger___2 *led_link_trigger;
	int irq;
	void *priv;
	struct work_struct phy_queue;
	struct delayed_work state_queue;
	struct mutex lock;
	struct phylink *phylink;
	struct net_device___17 *attached_dev;
	u8 mdix;
	u8 mdix_ctrl;
	long unsigned int supported[2];
	long unsigned int advertising[2];
	long unsigned int lp_advertising[2];
	void (*phy_link_change)(struct phy_device *, bool, bool);
	void (*adjust_link)(struct net_device___17 *);
};

struct mii_ioctl_data {
	__u16 phy_id;
	__u16 reg_num;
	__u16 val_in;
	__u16 val_out;
};

struct mii_bus___3 {
	struct module___98 *owner;
	const char *name;
	char id[61];
	void *priv;
	int (*read)(struct mii_bus___3 *, int, int);
	int (*write)(struct mii_bus___3 *, int, int, u16);
	int (*reset)(struct mii_bus___3 *);
	struct mutex mdio_lock;
	struct device___106 *parent;
	enum {
		MDIOBUS_ALLOCATED___3 = 1,
		MDIOBUS_REGISTERED___3 = 2,
		MDIOBUS_UNREGISTERED___3 = 3,
		MDIOBUS_RELEASED___3 = 4,
	} state;
	struct device___106 dev;
	struct mdio_device___3 *mdio_map[32];
	u32 phy_mask;
	u32 phy_ignore_ta_mask;
	int irq[32];
	int reset_delay_us;
	struct gpio_desc *reset_gpiod;
};

struct mdio_driver_common___2 {
	struct device_driver___106 driver;
	int flags;
};

struct phy_driver___2 {
	struct mdio_driver_common___2 mdiodrv;
	u32 phy_id;
	char *name;
	u32 phy_id_mask;
	u32 rh_reserved_features;
	u32 flags;
	const void *driver_data;
	const long unsigned int * const features;
	int (*soft_reset)(struct phy_device *);
	int (*config_init)(struct phy_device *);
	int (*probe)(struct phy_device *);
	int (*suspend)(struct phy_device *);
	int (*resume)(struct phy_device *);
	int (*config_aneg)(struct phy_device *);
	int (*aneg_done)(struct phy_device *);
	int (*read_status)(struct phy_device *);
	int (*ack_interrupt)(struct phy_device *);
	int (*config_intr)(struct phy_device *);
	int (*did_interrupt)(struct phy_device *);
	void (*remove)(struct phy_device *);
	int (*match_phy_device)(struct phy_device *);
	int (*ts_info)(struct phy_device *, struct ethtool_ts_info *);
	int (*hwtstamp)(struct phy_device *, struct ifreq *);
	bool (*rxtstamp)(struct phy_device *, struct sk_buff___16 *, int);
	void (*txtstamp)(struct phy_device *, struct sk_buff___16 *, int);
	int (*set_wol)(struct phy_device *, struct ethtool_wolinfo *);
	void (*get_wol)(struct phy_device *, struct ethtool_wolinfo *);
	void (*link_change_notify)(struct phy_device *);
	int (*read_mmd)(struct phy_device *, int, u16);
	int (*write_mmd)(struct phy_device *, int, u16, u16);
	int (*read_page)(struct phy_device *);
	int (*write_page)(struct phy_device *, int);
	int (*module_info)(struct phy_device *, struct ethtool_modinfo *);
	int (*module_eeprom)(struct phy_device *, struct ethtool_eeprom *, u8 *);
	int (*get_sset_count)(struct phy_device *);
	void (*get_strings)(struct phy_device *, u8 *);
	void (*get_stats)(struct phy_device *, struct ethtool_stats *, u64 *);
	int (*get_tunable)(struct phy_device *, struct ethtool_tunable *, void *);
	int (*set_tunable)(struct phy_device *, struct ethtool_tunable *, const void *);
	int (*set_loopback)(struct phy_device *, bool);
};

struct led_classdev___2;

struct led_trigger___2 {
	const char *name;
	void (*activate)(struct led_classdev___2 *);
	void (*deactivate)(struct led_classdev___2 *);
	rwlock_t leddev_list_lock;
	struct list_head led_cdevs;
	struct list_head next_trig;
};

struct phy_led_trigger___2 {
	struct led_trigger___2 trigger;
	char name[75];
	unsigned int speed;
};

struct phy_setting {
	u32 speed;
	u8 duplex;
	u8 bit;
};

struct led_classdev___2 {
	const char *name;
	enum led_brightness brightness;
	enum led_brightness max_brightness;
	int flags;
	long unsigned int work_flags;
	void (*brightness_set)(struct led_classdev___2 *, enum led_brightness);
	int (*brightness_set_blocking)(struct led_classdev___2 *, enum led_brightness);
	enum led_brightness (*brightness_get)(struct led_classdev___2 *);
	int (*blink_set)(struct led_classdev___2 *, long unsigned int *, long unsigned int *);
	int (*pattern_set)(struct led_classdev___2 *, struct led_pattern *, u32, int);
	int (*pattern_clear)(struct led_classdev___2 *);
	struct device___106 *dev;
	const struct attribute_group___105 **groups;
	struct list_head node;
	const char *default_trigger;
	long unsigned int blink_delay_on;
	long unsigned int blink_delay_off;
	struct timer_list blink_timer;
	int blink_brightness;
	int new_blink_brightness;
	void (*flash_resume)(struct led_classdev___2 *);
	struct work_struct set_brightness_work;
	int delayed_set_value;
	struct rw_semaphore___115 trigger_lock;
	struct led_trigger___2 *trigger;
	struct list_head trig_list;
	void *trigger_data;
	bool activated;
	struct mutex led_access;
};

struct mdio_driver_common___3 {
	struct device_driver___341 driver;
	int flags;
};

struct phy_driver___3;

struct phy_device___3 {
	struct mdio_device___2 mdio;
	struct phy_driver___3 *drv;
	u32 phy_id;
	struct phy_c45_device_ids c45_ids;
	unsigned int is_c45: 1;
	unsigned int is_internal: 1;
	unsigned int is_pseudo_fixed_link: 1;
	unsigned int has_fixups: 1;
	unsigned int suspended: 1;
	unsigned int sysfs_links: 1;
	unsigned int loopback_enabled: 1;
	unsigned int autoneg: 1;
	unsigned int link: 1;
	enum phy_state state;
	u32 dev_flags;
	phy_interface_t interface;
	int speed;
	int duplex;
	int pause;
	int asym_pause;
	u32 interrupts;
	u32 rh_reserved_supported;
	u32 rh_reserved_advertising;
	u32 rh_reserved_lp_advertising;
	u32 eee_broken_modes;
	int link_timeout;
	struct phy_led_trigger *phy_led_triggers;
	unsigned int phy_num_led_triggers;
	struct phy_led_trigger *last_triggered;
	struct phy_led_trigger *led_link_trigger;
	int irq;
	void *priv;
	struct work_struct phy_queue;
	struct delayed_work state_queue;
	struct mutex lock;
	struct phylink *phylink;
	struct net_device *attached_dev;
	u8 mdix;
	u8 mdix_ctrl;
	long unsigned int supported[2];
	long unsigned int advertising[2];
	long unsigned int lp_advertising[2];
	void (*phy_link_change)(struct phy_device___3 *, bool, bool);
	void (*adjust_link)(struct net_device *);
};

struct phy_driver___3 {
	struct mdio_driver_common___3 mdiodrv;
	u32 phy_id;
	char *name;
	u32 phy_id_mask;
	u32 rh_reserved_features;
	u32 flags;
	const void *driver_data;
	const long unsigned int * const features;
	int (*soft_reset)(struct phy_device___3 *);
	int (*config_init)(struct phy_device___3 *);
	int (*probe)(struct phy_device___3 *);
	int (*suspend)(struct phy_device___3 *);
	int (*resume)(struct phy_device___3 *);
	int (*config_aneg)(struct phy_device___3 *);
	int (*aneg_done)(struct phy_device___3 *);
	int (*read_status)(struct phy_device___3 *);
	int (*ack_interrupt)(struct phy_device___3 *);
	int (*config_intr)(struct phy_device___3 *);
	int (*did_interrupt)(struct phy_device___3 *);
	void (*remove)(struct phy_device___3 *);
	int (*match_phy_device)(struct phy_device___3 *);
	int (*ts_info)(struct phy_device___3 *, struct ethtool_ts_info *);
	int (*hwtstamp)(struct phy_device___3 *, struct ifreq *);
	bool (*rxtstamp)(struct phy_device___3 *, struct sk_buff___44 *, int);
	void (*txtstamp)(struct phy_device___3 *, struct sk_buff___44 *, int);
	int (*set_wol)(struct phy_device___3 *, struct ethtool_wolinfo *);
	void (*get_wol)(struct phy_device___3 *, struct ethtool_wolinfo *);
	void (*link_change_notify)(struct phy_device___3 *);
	int (*read_mmd)(struct phy_device___3 *, int, u16);
	int (*write_mmd)(struct phy_device___3 *, int, u16, u16);
	int (*read_page)(struct phy_device___3 *);
	int (*write_page)(struct phy_device___3 *, int);
	int (*module_info)(struct phy_device___3 *, struct ethtool_modinfo *);
	int (*module_eeprom)(struct phy_device___3 *, struct ethtool_eeprom *, u8 *);
	int (*get_sset_count)(struct phy_device___3 *);
	void (*get_strings)(struct phy_device___3 *, u8 *);
	void (*get_stats)(struct phy_device___3 *, struct ethtool_stats *, u64 *);
	int (*get_tunable)(struct phy_device___3 *, struct ethtool_tunable *, void *);
	int (*set_tunable)(struct phy_device___3 *, struct ethtool_tunable *, const void *);
	int (*set_loopback)(struct phy_device___3 *, bool);
};

struct module___306;

struct file___375;

struct kiocb___375;

struct iov_iter___159;

struct vm_area_struct___376;

struct inode___375;

struct file_lock___375;

struct page___376;

struct pipe_inode_info___77;

struct seq_file___317;

struct file_operations___375 {
	struct module___306 *owner;
	loff_t (*llseek)(struct file___375 *, loff_t, int);
	ssize_t (*read)(struct file___375 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___375 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___375 *, struct iov_iter___159 *);
	ssize_t (*write_iter)(struct kiocb___375 *, struct iov_iter___159 *);
	int (*iopoll)(struct kiocb___375 *, bool);
	int (*iterate)(struct file___375 *, struct dir_context *);
	int (*iterate_shared)(struct file___375 *, struct dir_context *);
	__poll_t (*poll)(struct file___375 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___375 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___375 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___375 *, struct vm_area_struct___376 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___375 *, struct file___375 *);
	int (*flush)(struct file___375 *, fl_owner_t);
	int (*release)(struct inode___375 *, struct file___375 *);
	int (*fsync)(struct file___375 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___375 *, int);
	int (*lock)(struct file___375 *, int, struct file_lock___375 *);
	ssize_t (*sendpage)(struct file___375 *, struct page___376 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___375 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___375 *, int, struct file_lock___375 *);
	ssize_t (*splice_write)(struct pipe_inode_info___77 *, struct file___375 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___375 *, loff_t *, struct pipe_inode_info___77 *, size_t, unsigned int);
	int (*setlease)(struct file___375 *, long int, struct file_lock___375 **, void **);
	long int (*fallocate)(struct file___375 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___317 *, struct file___375 *);
	ssize_t (*copy_file_range)(struct file___375 *, loff_t, struct file___375 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___375 *, loff_t, struct file___375 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___375 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___375 {
	u64 seqnum;
	struct vm_area_struct___376 *vmas[4];
};

struct page_frag___375 {
	struct page___376 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___375;

struct cred___344;

struct nsproxy___279;

struct signal_struct___258;

struct css_set___234;

struct vm_struct___281;

struct task_struct___376 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___376 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___375 *mm;
	struct mm_struct___375 *active_mm;
	struct vmacache___375 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___376 *real_parent;
	struct task_struct___376 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___376 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___218 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___218 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___218 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___344 *ptracer_cred;
	const struct cred___344 *real_cred;
	const struct cred___344 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___279 *nsproxy;
	struct signal_struct___258 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___376 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___107 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___234 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___77 *splice_pipe;
	struct page_frag___375 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___376 *oom_reaper_list;
	struct vm_struct___281 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___142 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___376 *pgtable_t___375;

struct address_space___374;

struct dev_pagemap___363;

struct page___376 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___374 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___376 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___375 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___375 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___363 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___375;

struct lruvec___375 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___375 *pgdat;
};

struct zone___375 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___375 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___375 {
	struct zone___375 *zone;
	int zone_idx;
};

struct zonelist___375 {
	struct zoneref___375 _zonerefs[25];
};

struct pglist_data___375 {
	struct zone___375 node_zones[3];
	struct zonelist___375 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___376 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___376 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___375 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___376 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___376 *owner;
};

struct secondary_data___376 {
	void *stack;
	struct task_struct___376 *task;
	long int status;
};

struct blocking_notifier_head___375 {
	struct rw_semaphore___376 rwsem;
	struct notifier_block *head;
};

struct key___344;

struct ucounts___249;

struct user_namespace___249 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___249 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___9 ns;
	long unsigned int flags;
	struct key___344 *persistent_keyring_register;
	struct rw_semaphore___376 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___249 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct user_struct___344 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___344 *uid_keyring;
	struct key___344 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___363;

struct vm_area_struct___376 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___376 *vm_next;
	struct vm_area_struct___376 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___375 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___363 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___375 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___375;

struct mm_struct___375 {
	struct {
		struct vm_area_struct___376 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___375 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___376 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___375 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___376 *owner;
		struct user_namespace___249 *user_ns;
		struct file___375 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___375 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___344 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___344 *session_keyring;
	struct key___344 *process_keyring;
	struct key___344 *thread_keyring;
	struct key___344 *request_key_auth;
	void *security;
	struct user_struct___344 *user;
	struct user_namespace___249 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___54;

struct cgroup_namespace___234;

struct nsproxy___279 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net___54 *net_ns;
	struct cgroup_namespace___234 *cgroup_ns;
};

struct signal_struct___258 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___376 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___376 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___218 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___218 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___375 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___218 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___234;

struct cgroup___234;

struct css_set___234 {
	struct cgroup_subsys_state___234 *subsys[13];
	refcount_t refcount;
	struct css_set___234 *dom_cset;
	struct cgroup___234 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___234 *mg_src_cgrp;
	struct cgroup___234 *mg_dst_cgrp;
	struct css_set___234 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___374;

struct pipe_buffer___77;

struct pipe_inode_info___77 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___376 *tmp_page;
	struct fasync_struct___374 *fasync_readers;
	struct fasync_struct___374 *fasync_writers;
	struct pipe_buffer___77 *bufs;
	struct user_struct___344 *user;
};

struct vm_struct___281 {
	struct vm_struct___281 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___376 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___270 {
	struct task_struct___376 task;
	long unsigned int stack[8192];
};

struct address_space_operations___374;

struct address_space___374 {
	struct inode___375 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___376 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___374 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___363)(struct vm_area_struct___376 *, long unsigned int, const struct page___376 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___363)(struct page___376 *, void *);

struct device___342;

struct dev_pagemap___363 {
	dev_page_fault_t___363 page_fault;
	dev_page_free_t___363 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___342 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct dentry___374;

struct path___375 {
	struct vfsmount *mnt;
	struct dentry___374 *dentry;
};

struct file___375 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___375 f_path;
	struct inode___375 *f_inode;
	const struct file_operations___375 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___218 f_owner;
	const struct cred___344 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___374 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___363;

struct vm_operations_struct___363 {
	void (*open)(struct vm_area_struct___376 *);
	void (*close)(struct vm_area_struct___376 *);
	int (*split)(struct vm_area_struct___376 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___376 *);
	vm_fault_t (*fault)(struct vm_fault___363 *);
	vm_fault_t (*huge_fault)(struct vm_fault___363 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___363 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___376 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___363 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___363 *);
	int (*access)(struct vm_area_struct___376 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___376 *);
	int (*set_policy)(struct vm_area_struct___376 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___376 *, long unsigned int);
	struct page___376 * (*find_special_page)(struct vm_area_struct___376 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___375 {
	struct task_struct___376 *task;
	struct core_thread___375 *next;
};

struct core_state___375 {
	atomic_t nr_threads;
	struct core_thread___375 dumper;
	struct completion startup;
};

struct vm_fault___363 {
	struct vm_area_struct___376 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___376 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___376 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___375 prealloc_pte;
};

struct kset___361;

struct kobj_type___361;

struct kernfs_node___369;

struct kobject___362 {
	const char *name;
	struct list_head entry;
	struct kobject___362 *parent;
	struct kset___361 *kset;
	struct kobj_type___361 *ktype;
	struct kernfs_node___369 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___303 {
	struct kobject___362 kobj;
	struct module___306 *mod;
	struct kobject___362 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___303 {
	struct module___306 *mod;
	struct latch_tree_node node;
};

struct module_layout___303 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___303 mtn;
};

struct module_attribute___303;

struct kernel_param___303;

struct module___306 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___303 mkobj;
	struct module_attribute___303 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___362 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___303 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___303 core_layout;
	struct module_layout___303 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide38;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide39;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct iov_iter___159 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___3 *bvec;
		struct pipe_inode_info___77 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct kiocb___375 {
	struct file___375 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___375 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dentry_operations___374;

struct super_block___374;

struct dentry___374 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___374 *d_parent;
	struct qstr d_name;
	struct inode___375 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___374 *d_op;
	struct super_block___374 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___374;

struct block_device___374;

struct inode___375 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___374 *i_op;
	struct super_block___374 *i_sb;
	struct address_space___374 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___376 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___375 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___374 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___77 *i_pipe;
		struct block_device___374 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___374 {
	int (*d_revalidate)(struct dentry___374 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___374 *, unsigned int);
	int (*d_hash)(const struct dentry___374 *, struct qstr *);
	int (*d_compare)(const struct dentry___374 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___374 *);
	int (*d_init)(struct dentry___374 *);
	void (*d_release)(struct dentry___374 *);
	void (*d_prune)(struct dentry___374 *);
	void (*d_iput)(struct dentry___374 *, struct inode___375 *);
	char * (*d_dname)(struct dentry___374 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___375 *);
	int (*d_manage)(const struct path___375 *, bool);
	struct dentry___374 * (*d_real)(struct dentry___374 *, const struct inode___375 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___374;

struct mem_dqinfo___374 {
	struct quota_format_type___374 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___374;

struct quota_info___374 {
	unsigned int flags;
	struct rw_semaphore___376 dqio_sem;
	struct inode___375 *files[3];
	struct mem_dqinfo___374 info[3];
	const struct quota_format_ops___374 *ops[3];
};

struct rcuwait___374 {
	struct task_struct___376 *task;
};

struct percpu_rw_semaphore___374 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___376 rw_sem;
	struct rcuwait___374 writer;
	int readers_block;
};

struct sb_writers___374 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___374 rw_sem[3];
};

struct file_system_type___374;

struct super_operations___374;

struct dquot_operations___374;

struct quotactl_ops___374;

struct super_block___374 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___374 *s_type;
	const struct super_operations___374 *s_op;
	const struct dquot_operations___374 *dq_op;
	const struct quotactl_ops___374 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___374 *s_root;
	struct rw_semaphore___376 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___374 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___374 s_dquot;
	struct sb_writers___374 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___374 *s_d_op;
	int cleancache_poolid;
	struct shrinker___134 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___249 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct iattr___374 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___375 *ia_file;
};

struct dquot___374 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___374 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___374 {
	int qf_fmt_id;
	const struct quota_format_ops___374 *qf_ops;
	struct module___306 *qf_owner;
	struct quota_format_type___374 *qf_next;
};

struct quota_format_ops___374 {
	int (*check_quota_file)(struct super_block___374 *, int);
	int (*read_file_info)(struct super_block___374 *, int);
	int (*write_file_info)(struct super_block___374 *, int);
	int (*free_file_info)(struct super_block___374 *, int);
	int (*read_dqblk)(struct dquot___374 *);
	int (*commit_dqblk)(struct dquot___374 *);
	int (*release_dqblk)(struct dquot___374 *);
	int (*get_next_id)(struct super_block___374 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___374 {
	int (*write_dquot)(struct dquot___374 *);
	struct dquot___374 * (*alloc_dquot)(struct super_block___374 *, int);
	void (*destroy_dquot)(struct dquot___374 *);
	int (*acquire_dquot)(struct dquot___374 *);
	int (*release_dquot)(struct dquot___374 *);
	int (*mark_dirty)(struct dquot___374 *);
	int (*write_info)(struct super_block___374 *, int);
	qsize_t * (*get_reserved_space)(struct inode___375 *);
	int (*get_projid)(struct inode___375 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___375 *, qsize_t *);
	int (*get_next_id)(struct super_block___374 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___374 {
	int (*quota_on)(struct super_block___374 *, int, int, const struct path___375 *);
	int (*quota_off)(struct super_block___374 *, int);
	int (*quota_enable)(struct super_block___374 *, unsigned int);
	int (*quota_disable)(struct super_block___374 *, unsigned int);
	int (*quota_sync)(struct super_block___374 *, int);
	int (*set_info)(struct super_block___374 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___374 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___374 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___374 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___374 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___374 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___374 {
	int (*writepage)(struct page___376 *, struct writeback_control___3 *);
	int (*readpage)(struct file___375 *, struct page___376 *);
	int (*writepages)(struct address_space___374 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___376 *);
	int (*readpages)(struct file___375 *, struct address_space___374 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___375 *, struct address_space___374 *, loff_t, unsigned int, unsigned int, struct page___376 **, void **);
	int (*write_end)(struct file___375 *, struct address_space___374 *, loff_t, unsigned int, unsigned int, struct page___376 *, void *);
	sector_t (*bmap)(struct address_space___374 *, sector_t);
	void (*invalidatepage)(struct page___376 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___376 *, gfp_t);
	void (*freepage)(struct page___376 *);
	ssize_t (*direct_IO)(struct kiocb___375 *, struct iov_iter___159 *);
	int (*migratepage)(struct address_space___374 *, struct page___376 *, struct page___376 *, enum migrate_mode);
	bool (*isolate_page)(struct page___376 *, isolate_mode_t);
	void (*putback_page)(struct page___376 *);
	int (*launder_page)(struct page___376 *);
	int (*is_partially_uptodate)(struct page___376 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___376 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___374 *, struct page___376 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___375 *, sector_t *);
	void (*swap_deactivate)(struct file___375 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___374 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___375 *bd_inode;
	struct super_block___374 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___374 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___374 {
	struct dentry___374 * (*lookup)(struct inode___375 *, struct dentry___374 *, unsigned int);
	const char * (*get_link)(struct dentry___374 *, struct inode___375 *, struct delayed_call *);
	int (*permission)(struct inode___375 *, int);
	struct posix_acl * (*get_acl)(struct inode___375 *, int);
	int (*readlink)(struct dentry___374 *, char *, int);
	int (*create)(struct inode___375 *, struct dentry___374 *, umode_t, bool);
	int (*link)(struct dentry___374 *, struct inode___375 *, struct dentry___374 *);
	int (*unlink)(struct inode___375 *, struct dentry___374 *);
	int (*symlink)(struct inode___375 *, struct dentry___374 *, const char *);
	int (*mkdir)(struct inode___375 *, struct dentry___374 *, umode_t);
	int (*rmdir)(struct inode___375 *, struct dentry___374 *);
	int (*mknod)(struct inode___375 *, struct dentry___374 *, umode_t, dev_t);
	int (*rename)(struct inode___375 *, struct dentry___374 *, struct inode___375 *, struct dentry___374 *, unsigned int);
	int (*setattr)(struct dentry___374 *, struct iattr___374 *);
	int (*getattr)(const struct path___375 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___374 *, char *, size_t);
	int (*fiemap)(struct inode___375 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___375 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___375 *, struct dentry___374 *, struct file___375 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___375 *, struct dentry___374 *, umode_t);
	int (*set_acl)(struct inode___375 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___374 {
	void (*fl_copy_lock)(struct file_lock___375 *, struct file_lock___375 *);
	void (*fl_release_private)(struct file_lock___375 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___374;

struct file_lock___375 {
	struct file_lock___375 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___375 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___374 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___374 *fl_ops;
	const struct lock_manager_operations___374 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___374 {
	int (*lm_compare_owner)(struct file_lock___375 *, struct file_lock___375 *);
	long unsigned int (*lm_owner_key)(struct file_lock___375 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___375 *);
	int (*lm_grant)(struct file_lock___375 *, int);
	bool (*lm_break)(struct file_lock___375 *);
	int (*lm_change)(struct file_lock___375 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___375 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___374 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___374 *fa_next;
	struct file___375 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___374 {
	const char *name;
	int fs_flags;
	struct dentry___374 * (*mount)(struct file_system_type___374 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___374 *);
	struct module___306 *owner;
	struct file_system_type___374 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___374 {
	struct inode___375 * (*alloc_inode)(struct super_block___374 *);
	void (*destroy_inode)(struct inode___375 *);
	void (*dirty_inode)(struct inode___375 *, int);
	int (*write_inode)(struct inode___375 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___375 *);
	void (*evict_inode)(struct inode___375 *);
	void (*put_super)(struct super_block___374 *);
	int (*sync_fs)(struct super_block___374 *, int);
	int (*freeze_super)(struct super_block___374 *);
	int (*freeze_fs)(struct super_block___374 *);
	int (*thaw_super)(struct super_block___374 *);
	int (*unfreeze_fs)(struct super_block___374 *);
	int (*statfs)(struct dentry___374 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___374 *, int *, char *);
	void (*umount_begin)(struct super_block___374 *);
	int (*show_options)(struct seq_file___317 *, struct dentry___374 *);
	int (*show_devname)(struct seq_file___317 *, struct dentry___374 *);
	int (*show_path)(struct seq_file___317 *, struct dentry___374 *);
	int (*show_stats)(struct seq_file___317 *, struct dentry___374 *);
	ssize_t (*quota_read)(struct super_block___374 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___374 *, int, const char *, size_t, loff_t);
	struct dquot___374 ** (*get_dquots)(struct inode___375 *);
	int (*bdev_try_to_free_page)(struct super_block___374 *, struct page___376 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___374 *, struct shrink_control___134 *);
	long int (*free_cached_objects)(struct super_block___374 *, struct shrink_control___134 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___316;

struct seq_file___317 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___316 *op;
	int poll_event;
	const struct file___375 *file;
	void *private;
};

struct net_device___45;

struct nf_bridge_info___43;

struct sk_buff___45 {
	union {
		struct {
			struct sk_buff___45 *next;
			struct sk_buff___45 *prev;
			union {
				struct net_device___45 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___30 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___45 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___43 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___43;

struct netns_frags___43 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___43 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv4___43 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct sock *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock **tcp_sk;
	struct netns_frags___43 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct dst_ops___53 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___53 *);
	struct dst_entry___2 * (*check)(struct dst_entry___2 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___2 *);
	unsigned int (*mtu)(const struct dst_entry___2 *);
	u32 * (*cow_metrics)(struct dst_entry___2 *, long unsigned int);
	void (*destroy)(struct dst_entry___2 *);
	void (*ifdown)(struct dst_entry___2 *, struct net_device___45 *, int);
	struct dst_entry___2 * (*negative_advice)(struct dst_entry___2 *);
	void (*link_failure)(struct sk_buff___45 *);
	void (*update_pmtu)(struct dst_entry___2 *, struct sock *, struct sk_buff___45 *, u32);
	void (*redirect)(struct dst_entry___2 *, struct sock *, struct sk_buff___45 *);
	int (*local_out)(struct net___54 *, struct sock *, struct sk_buff___45 *);
	struct neighbour___2 * (*neigh_lookup)(const struct dst_entry___2 *, struct sk_buff___45 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___2 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___53 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___43 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___53 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct sock *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops *notifier_ops;
	struct fib_notifier_ops *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_nf_frag___43 {
	struct netns_frags___43 frags;
};

struct netns_xfrm___53 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___53 xfrm4_dst_ops;
	struct dst_ops___53 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct net___54 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___249 *user_ns;
	struct ucounts___249 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___9 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___45 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___43 ipv4;
	struct netns_ipv6___53 ipv6;
	struct netns_sctp___30 sctp;
	struct netns_nf nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___43 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock *nfnl;
	struct sock *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___53 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kernfs_root___368;

struct kernfs_elem_dir___368 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___368 *root;
};

struct kernfs_syscall_ops___368;

struct kernfs_root___368 {
	struct kernfs_node___369 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___368 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___368 {
	struct kernfs_node___369 *target_kn;
};

struct kernfs_ops___368;

struct kernfs_elem_attr___368 {
	const struct kernfs_ops___368 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___369 *notify_next;
};

struct kernfs_node___369 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___369 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___368 dir;
		struct kernfs_elem_symlink___368 symlink;
		struct kernfs_elem_attr___368 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___368;

struct kernfs_ops___368 {
	int (*open)(struct kernfs_open_file___368 *);
	void (*release)(struct kernfs_open_file___368 *);
	int (*seq_show)(struct seq_file___317 *, void *);
	void * (*seq_start)(struct seq_file___317 *, loff_t *);
	void * (*seq_next)(struct seq_file___317 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___317 *, void *);
	ssize_t (*read)(struct kernfs_open_file___368 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___368 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___368 *, struct vm_area_struct___376 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___368 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___368 {
	int (*remount_fs)(struct kernfs_root___368 *, int *, char *);
	int (*show_options)(struct seq_file___317 *, struct kernfs_root___368 *);
	int (*mkdir)(struct kernfs_node___369 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___369 *);
	int (*rename)(struct kernfs_node___369 *, struct kernfs_node___369 *, const char *);
	int (*show_path)(struct seq_file___317 *, struct kernfs_node___369 *, struct kernfs_root___368 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___368 {
	struct kernfs_node___369 *kn;
	struct file___375 *file;
	struct seq_file___317 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___363 *vm_ops;
};

struct bin_attribute___338;

struct attribute_group___339 {
	const char *name;
	umode_t (*is_visible)(struct kobject___362 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___362 *, struct bin_attribute___338 *, int);
	struct attribute **attrs;
	struct bin_attribute___338 **bin_attrs;
};

struct bin_attribute___338 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___375 *, struct kobject___362 *, struct bin_attribute___338 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___375 *, struct kobject___362 *, struct bin_attribute___338 *, char *, loff_t, size_t);
	int (*mmap)(struct file___375 *, struct kobject___362 *, struct bin_attribute___338 *, struct vm_area_struct___376 *);
};

struct sysfs_ops___361 {
	ssize_t (*show)(struct kobject___362 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___362 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___361;

struct kset___361 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___362 kobj;
	const struct kset_uevent_ops___361 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___361 {
	void (*release)(struct kobject___362 *);
	const struct sysfs_ops___361 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___29 * (*child_ns_type)(struct kobject___362 *);
	const void * (*namespace)(struct kobject___362 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___361 {
	int (* const filter)(struct kset___361 *, struct kobject___362 *);
	const char * (* const name)(struct kset___361 *, struct kobject___362 *);
	int (* const uevent)(struct kset___361 *, struct kobject___362 *, struct kobj_uevent_env *);
};

struct kobj_attribute___353 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___362 *, struct kobj_attribute___353 *, char *);
	ssize_t (*store)(struct kobject___362 *, struct kobj_attribute___353 *, const char *, size_t);
};

struct dev_pm_ops___342 {
	int (*prepare)(struct device___342 *);
	void (*complete)(struct device___342 *);
	int (*suspend)(struct device___342 *);
	int (*resume)(struct device___342 *);
	int (*freeze)(struct device___342 *);
	int (*thaw)(struct device___342 *);
	int (*poweroff)(struct device___342 *);
	int (*restore)(struct device___342 *);
	int (*suspend_late)(struct device___342 *);
	int (*resume_early)(struct device___342 *);
	int (*freeze_late)(struct device___342 *);
	int (*thaw_early)(struct device___342 *);
	int (*poweroff_late)(struct device___342 *);
	int (*restore_early)(struct device___342 *);
	int (*suspend_noirq)(struct device___342 *);
	int (*resume_noirq)(struct device___342 *);
	int (*freeze_noirq)(struct device___342 *);
	int (*thaw_noirq)(struct device___342 *);
	int (*poweroff_noirq)(struct device___342 *);
	int (*restore_noirq)(struct device___342 *);
	int (*runtime_suspend)(struct device___342 *);
	int (*runtime_resume)(struct device___342 *);
	int (*runtime_idle)(struct device___342 *);
};

struct dev_pm_info___342 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___6 *subsys_data;
	void (*set_latency_tolerance)(struct device___342 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___342;

struct bus_type___342;

struct device_driver___342;

struct dev_pm_domain___342;

struct dma_map_ops___130;

struct device_node___85;

struct fwnode_handle___264;

struct class___342;

struct device___342 {
	struct device___342 *parent;
	struct device_private *p;
	struct kobject___362 kobj;
	const char *init_name;
	const struct device_type___342 *type;
	struct mutex mutex;
	struct bus_type___342 *bus;
	struct device_driver___342 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___342 power;
	struct dev_pm_domain___342 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___130 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___85 *of_node;
	struct fwnode_handle___264 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___342 *class;
	const struct attribute_group___339 **groups;
	void (*release)(struct device___342 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___342 {
	struct dev_pm_ops___342 ops;
	void (*detach)(struct device___342 *, bool);
	int (*activate)(struct device___342 *);
	void (*sync)(struct device___342 *);
	void (*dismiss)(struct device___342 *);
};

struct bus_type___342 {
	const char *name;
	const char *dev_name;
	struct device___342 *dev_root;
	const struct attribute_group___339 **bus_groups;
	const struct attribute_group___339 **dev_groups;
	const struct attribute_group___339 **drv_groups;
	int (*match)(struct device___342 *, struct device_driver___342 *);
	int (*uevent)(struct device___342 *, struct kobj_uevent_env *);
	int (*probe)(struct device___342 *);
	int (*remove)(struct device___342 *);
	void (*shutdown)(struct device___342 *);
	int (*online)(struct device___342 *);
	int (*offline)(struct device___342 *);
	int (*suspend)(struct device___342 *, pm_message_t);
	int (*resume)(struct device___342 *);
	int (*num_vf)(struct device___342 *);
	int (*dma_configure)(struct device___342 *);
	const struct dev_pm_ops___342 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___342 {
	const char *name;
	struct bus_type___342 *bus;
	struct module___306 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___342 *);
	int (*remove)(struct device___342 *);
	void (*shutdown)(struct device___342 *);
	int (*suspend)(struct device___342 *, pm_message_t);
	int (*resume)(struct device___342 *);
	const struct attribute_group___339 **groups;
	const struct dev_pm_ops___342 *pm;
	void (*coredump)(struct device___342 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___342 {
	const char *name;
	const struct attribute_group___339 **groups;
	int (*uevent)(struct device___342 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___342 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___342 *);
	const struct dev_pm_ops___342 *pm;
};

struct class___342 {
	const char *name;
	struct module___306 *owner;
	const struct attribute_group___339 **class_groups;
	const struct attribute_group___339 **dev_groups;
	struct kobject___362 *dev_kobj;
	int (*dev_uevent)(struct device___342 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___342 *, umode_t *);
	void (*class_release)(struct class___342 *);
	void (*dev_release)(struct device___342 *);
	int (*shutdown_pre)(struct device___342 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___342 *);
	const struct dev_pm_ops___342 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct device_attribute___51 {
	struct attribute attr;
	ssize_t (*show)(struct device___342 *, struct device_attribute___51 *, char *);
	ssize_t (*store)(struct device___342 *, struct device_attribute___51 *, const char *, size_t);
};

struct dma_map_ops___130 {
	void * (*alloc)(struct device___342 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___342 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___342 *, struct vm_area_struct___376 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___342 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___342 *, struct page___376 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___342 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___342 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___342 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___342 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___342 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___342 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___342 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___342 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___342 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___342 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___342 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___342 *, u64);
	u64 (*get_required_mask)(struct device___342 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___264;

struct fwnode_handle___264 {
	struct fwnode_handle___264 *secondary;
	const struct fwnode_operations___264 *ops;
};

struct property___81;

struct device_node___85 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___264 fwnode;
	struct property___81 *properties;
	struct property___81 *deadprops;
	struct device_node___85 *parent;
	struct device_node___85 *child;
	struct device_node___85 *sibling;
	struct kobject___362 kobj;
	long unsigned int _flags;
	void *data;
};

typedef void compound_page_dtor___363(struct page___376 *);

struct fwnode_reference_args___264;

struct fwnode_endpoint___264;

struct fwnode_operations___264 {
	struct fwnode_handle___264 * (*get)(struct fwnode_handle___264 *);
	void (*put)(struct fwnode_handle___264 *);
	bool (*device_is_available)(const struct fwnode_handle___264 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___264 *, const struct device___342 *);
	bool (*property_present)(const struct fwnode_handle___264 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___264 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___264 *, const char *, const char **, size_t);
	struct fwnode_handle___264 * (*get_parent)(const struct fwnode_handle___264 *);
	struct fwnode_handle___264 * (*get_next_child_node)(const struct fwnode_handle___264 *, struct fwnode_handle___264 *);
	struct fwnode_handle___264 * (*get_named_child_node)(const struct fwnode_handle___264 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___264 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___264 *);
	struct fwnode_handle___264 * (*graph_get_next_endpoint)(const struct fwnode_handle___264 *, struct fwnode_handle___264 *);
	struct fwnode_handle___264 * (*graph_get_remote_endpoint)(const struct fwnode_handle___264 *);
	struct fwnode_handle___264 * (*graph_get_port_parent)(struct fwnode_handle___264 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___264 *, struct fwnode_endpoint___264 *);
};

struct fwnode_endpoint___264 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___264 *local_fwnode;
};

struct fwnode_reference_args___264 {
	struct fwnode_handle___264 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___77;

struct pipe_buffer___77 {
	struct page___376 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___77 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___77 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___77 *, struct pipe_buffer___77 *);
	void (*release)(struct pipe_inode_info___77 *, struct pipe_buffer___77 *);
	int (*steal)(struct pipe_inode_info___77 *, struct pipe_buffer___77 *);
	union {
		bool (*get)(struct pipe_inode_info___77 *, struct pipe_buffer___77 *);
		struct {
			void (*get)(struct pipe_inode_info___77 *, struct pipe_buffer___77 *);
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
};

struct nf_bridge_info___43 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___43 = 0,
		BRNF_PROTO_8021Q___43 = 1,
		BRNF_PROTO_PPPOE___43 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___45 *physindev;
	struct net_device___45 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___43(struct sk_buff___45 **);

typedef struct {
	struct net___54 *net;
} possible_net_t___44;

struct net_device_ops___43;

struct ethtool_ops___43;

struct xfrmdev_ops___43;

struct tlsdev_ops___43;

struct header_ops___43;

struct netdev_rx_queue___43;

struct netdev_queue___43;

struct dcbnl_rtnl_ops___43;

struct phy_device___4;

struct net_device___45 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___43 *netdev_ops;
	const struct ethtool_ops___43 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___2 *l3mdev_ops;
	const struct ndisc_ops___2 *ndisc_ops;
	const struct xfrmdev_ops___43 *xfrmdev_ops;
	const struct tlsdev_ops___43 *tlsdev_ops;
	const struct header_ops___43 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___361 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___2 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___43 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___43 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___2 *miniq_ingress;
	struct netdev_queue___43 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___43 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___2 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___2 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___43 = 0,
		NETREG_REGISTERED___43 = 1,
		NETREG_UNREGISTERING___43 = 2,
		NETREG_UNREGISTERED___43 = 3,
		NETREG_RELEASED___43 = 4,
		NETREG_DUMMY___43 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___43 = 0,
		RTNL_LINK_INITIALIZING___43 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___45 *);
	struct netpoll_info *npinfo;
	possible_net_t___44 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___342 dev;
	const struct attribute_group___339 *sysfs_groups[4];
	const struct attribute_group___339 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___2 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___43 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device___4 *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct sk_buff_head___43 {
	struct sk_buff___45 *next;
	struct sk_buff___45 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct ethtool_ops___43 {
	int (*get_settings)(struct net_device___45 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___45 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___45 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___45 *);
	void (*get_regs)(struct net_device___45 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___45 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___45 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___45 *);
	void (*set_msglevel)(struct net_device___45 *, u32);
	int (*nway_reset)(struct net_device___45 *);
	u32 (*get_link)(struct net_device___45 *);
	int (*get_eeprom_len)(struct net_device___45 *);
	int (*get_eeprom)(struct net_device___45 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___45 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___45 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___45 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___45 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___45 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___45 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___45 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___45 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___45 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___45 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___45 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___45 *);
	void (*complete)(struct net_device___45 *);
	u32 (*get_priv_flags)(struct net_device___45 *);
	int (*set_priv_flags)(struct net_device___45 *, u32);
	int (*get_sset_count)(struct net_device___45 *, int);
	int (*get_rxnfc)(struct net_device___45 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___45 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___45 *, struct ethtool_flash *);
	int (*reset)(struct net_device___45 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___45 *);
	u32 (*get_rxfh_indir_size)(struct net_device___45 *);
	int (*get_rxfh)(struct net_device___45 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___45 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___45 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___45 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___45 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___45 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___45 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___45 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___45 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___45 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___45 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___45 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___45 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___45 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___45 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___45 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___45 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___45 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___45 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___45 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___45 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___45 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	int (*get_fecparam)(struct net_device___45 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___45 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___45 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___45 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___45 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___43;

struct inet_frags___43 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___43 *, const void *);
	void (*destructor)(struct inet_frag_queue___43 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___43 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___45 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___45 *fragments_tail;
	struct sk_buff___45 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___43 *net;
	struct callback_head rcu;
};

struct ucounts___249 {
	struct hlist_node node;
	struct user_namespace___249 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

typedef int (*key_restrict_link_func_t___345)(struct key___344 *, const struct key_type *, const union key_payload *, struct key___344 *);

struct key_restriction___344;

struct key___344 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___376 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___344 *restrict_link;
};

struct key_restriction___344 {
	key_restrict_link_func_t___345 check;
	struct key___344 *key;
	struct key_type *keytype;
};

struct seq_operations___316 {
	void * (*start)(struct seq_file___317 *, loff_t *);
	void (*stop)(struct seq_file___317 *, void *);
	void * (*next)(struct seq_file___317 *, void *, loff_t *);
	int (*show)(struct seq_file___317 *, void *);
};

struct pernet_operations___44 {
	struct list_head list;
	int (*init)(struct net___54 *);
	void (*exit)(struct net___54 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___43 {
	int (*ieee_getets)(struct net_device___45 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___45 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___45 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___45 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___45 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___45 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___45 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___45 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___45 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___45 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___45 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___45 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___45 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___45 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___45 *);
	u8 (*setstate)(struct net_device___45 *, u8);
	void (*getpermhwaddr)(struct net_device___45 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___45 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___45 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___45 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___45 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___45 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___45 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___45 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___45 *, int, u8 *);
	void (*setpfccfg)(struct net_device___45 *, int, u8);
	void (*getpfccfg)(struct net_device___45 *, int, u8 *);
	u8 (*setall)(struct net_device___45 *);
	u8 (*getcap)(struct net_device___45 *, int, u8 *);
	int (*getnumtcs)(struct net_device___45 *, int, u8 *);
	int (*setnumtcs)(struct net_device___45 *, int, u8);
	u8 (*getpfcstate)(struct net_device___45 *);
	void (*setpfcstate)(struct net_device___45 *, u8);
	void (*getbcncfg)(struct net_device___45 *, int, u32 *);
	void (*setbcncfg)(struct net_device___45 *, int, u32);
	void (*getbcnrp)(struct net_device___45 *, int, u8 *);
	void (*setbcnrp)(struct net_device___45 *, int, u8);
	int (*setapp)(struct net_device___45 *, u8, u16, u8);
	int (*getapp)(struct net_device___45 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___45 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___45 *, int, u8);
	u8 (*getdcbx)(struct net_device___45 *);
	u8 (*setdcbx)(struct net_device___45 *, u8);
	int (*peer_getappinfo)(struct net_device___45 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___45 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___45 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___45 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___45 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___45 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___234 {
	refcount_t count;
	struct ns_common___9 ns;
	struct user_namespace___249 *user_ns;
	struct ucounts___249 *ucounts;
	struct css_set___234 *root_cset;
};

struct bpf_map___235;

struct bpf_map_ops___234 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___235 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___235 *, struct file___375 *);
	void (*map_free)(struct bpf_map___235 *);
	int (*map_get_next_key)(struct bpf_map___235 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___235 *);
	void * (*map_lookup_elem)(struct bpf_map___235 *, void *);
	int (*map_update_elem)(struct bpf_map___235 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___235 *, void *);
	int (*map_push_elem)(struct bpf_map___235 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___235 *, void *);
	int (*map_peek_elem)(struct bpf_map___235 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___235 *, struct file___375 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___235 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___235 *, void *, struct seq_file___317 *);
	int (*map_check_btf)(const struct bpf_map___235 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___235 {
	const struct bpf_map_ops___234 *ops;
	struct bpf_map___235 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___344 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___43;

struct bpf_map_dev_ops___43 {
	int (*map_get_next_key)(struct bpf_offloaded_map___43 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___43 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___43 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___43 *, void *);
};

struct bpf_offloaded_map___43 {
	struct bpf_map___235 map;
	struct net_device___45 *netdev;
	const struct bpf_map_dev_ops___43 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___235;

typedef void (*kthread_work_func_t___235)(struct kthread_work___235 *);

struct kthread_worker___235;

struct kthread_work___235 {
	struct list_head node;
	kthread_work_func_t___235 func;
	struct kthread_worker___235 *worker;
	int canceling;
};

struct kthread_worker___235 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___376 *task;
	struct kthread_work___235 *current_work;
};

struct kthread_delayed_work___234 {
	struct kthread_work___235 work;
	struct timer_list timer;
};

struct psi_group___234 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___235 *poll_kworker;
	struct kthread_delayed_work___234 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___234 {
	struct kernfs_node___369 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___234;

struct cgroup_subsys_state___234 {
	struct cgroup___234 *cgroup;
	struct cgroup_subsys___234 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___234 *parent;
};

struct cgroup_root___234;

struct cgroup_rstat_cpu___234;

struct cgroup___234 {
	struct cgroup_subsys_state___234 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___369 *kn;
	struct cgroup_file___234 procs_file;
	struct cgroup_file___234 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___234 *subsys[13];
	struct cgroup_root___234 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___234 *dom_cgrp;
	struct cgroup_rstat_cpu___234 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___39 bpf;
	atomic_t congestion_count;
	struct cgroup___234 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___234 psi;
	int ancestor_ids[0];
};

struct cftype___234;

struct cgroup_subsys___234 {
	struct cgroup_subsys_state___234 * (*css_alloc)(struct cgroup_subsys_state___234 *);
	int (*css_online)(struct cgroup_subsys_state___234 *);
	void (*css_offline)(struct cgroup_subsys_state___234 *);
	void (*css_released)(struct cgroup_subsys_state___234 *);
	void (*css_free)(struct cgroup_subsys_state___234 *);
	void (*css_reset)(struct cgroup_subsys_state___234 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___234 *, int);
	int (*css_extra_stat_show)(struct seq_file___317 *, struct cgroup_subsys_state___234 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___376 *);
	void (*cancel_fork)(struct task_struct___376 *);
	void (*fork)(struct task_struct___376 *);
	void (*exit)(struct task_struct___376 *);
	void (*free)(struct task_struct___376 *);
	void (*bind)(struct cgroup_subsys_state___234 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___234 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___234 *dfl_cftypes;
	struct cftype___234 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___234 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___234 *updated_children;
	struct cgroup___234 *updated_next;
};

struct cgroup_root___234 {
	struct kernfs_root___368 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___234 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___234 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___234 *ss;
	struct list_head node;
	struct kernfs_ops___368 *kf_ops;
	int (*open)(struct kernfs_open_file___368 *);
	void (*release)(struct kernfs_open_file___368 *);
	u64 (*read_u64)(struct cgroup_subsys_state___234 *, struct cftype___234 *);
	s64 (*read_s64)(struct cgroup_subsys_state___234 *, struct cftype___234 *);
	int (*seq_show)(struct seq_file___317 *, void *);
	void * (*seq_start)(struct seq_file___317 *, loff_t *);
	void * (*seq_next)(struct seq_file___317 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___317 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___234 *, struct cftype___234 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___234 *, struct cftype___234 *, s64);
	ssize_t (*write)(struct kernfs_open_file___368 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___368 *, struct poll_table_struct___6 *);
};

struct xdp_rxq_info___43 {
	struct net_device___45 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___43 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___45 *dev_rx;
};

struct netlink_callback___44 {
	struct sk_buff___45 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___44 *);
	int (*dump)(struct sk_buff___45 *, struct netlink_callback___44 *);
	int (*done)(struct netlink_callback___44 *);
	void *data;
	struct module___306 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___43 {
	int (*create)(struct sk_buff___45 *, struct net_device___45 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___45 *, unsigned char *);
	int (*cache)(const struct neighbour___2 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___45 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___43 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___43 *, int);
	int poll_owner;
	struct net_device___45 *dev;
	struct sk_buff___45 *gro_list;
	struct sk_buff___45 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___43 {
	struct net_device___45 *dev;
	struct Qdisc___2 *qdisc;
	struct Qdisc___2 *qdisc_sleeping;
	struct kobject___362 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___45 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct netdev_rx_queue___43 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___362 kobj;
	struct net_device___45 *dev;
	long: 64;
	struct xdp_rxq_info___43 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___43)(struct net_device___45 *, struct sk_buff___45 *, struct net_device___45 *);

struct netdev_bpf___43 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___39 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___39 *prog;
			const struct bpf_prog_offload_ops___39 *ops;
		} verifier;
		struct {
			struct bpf_prog___39 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___43 *offmap;
		};
		struct {
			struct xdp_umem *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___43 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___45 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___43 {
	int (*tls_dev_add)(struct net_device___45 *, struct sock *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___45 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___45 *, struct sock *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___43 {
	int (*ndo_init)(struct net_device___45 *);
	void (*ndo_uninit)(struct net_device___45 *);
	int (*ndo_open)(struct net_device___45 *);
	int (*ndo_stop)(struct net_device___45 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___45 *, struct net_device___45 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___45 *, struct net_device___45 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___45 *, struct sk_buff___45 *, struct net_device___45 *, select_queue_fallback_t___43);
	void (*ndo_change_rx_flags)(struct net_device___45 *, int);
	void (*ndo_set_rx_mode)(struct net_device___45 *);
	int (*ndo_set_mac_address)(struct net_device___45 *, void *);
	int (*ndo_validate_addr)(struct net_device___45 *);
	int (*ndo_do_ioctl)(struct net_device___45 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___45 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___45 *, int);
	int (*ndo_neigh_setup)(struct net_device___45 *, struct neigh_parms___3 *);
	void (*ndo_tx_timeout)(struct net_device___45 *);
	void (*ndo_get_stats64)(struct net_device___45 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___45 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___45 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___45 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___45 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___45 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___45 *);
	int (*ndo_netpoll_setup)(struct net_device___45 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___45 *);
	int (*ndo_set_vf_mac)(struct net_device___45 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___45 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___45 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___45 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___45 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___45 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___45 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___45 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___45 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___45 *, int, struct sk_buff___45 *);
	int (*ndo_set_vf_guid)(struct net_device___45 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___45 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___45 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___45 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___45 *, const struct sk_buff___45 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___45 *, struct net_device___45 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___45 *, struct net_device___45 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___45 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___45 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___45 *, struct neighbour___2 *);
	void (*ndo_neigh_destroy)(struct net_device___45 *, struct neighbour___2 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___45 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___45 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___45 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___45 *, struct netlink_callback___44 *, struct net_device___45 *, struct net_device___45 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___45 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___45 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___45 *, u32, u32, struct net_device___45 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___45 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___45 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___45 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___45 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___45 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___45 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___45 *, struct net_device___45 *);
	void (*ndo_dfwd_del_station)(struct net_device___45 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___45 *);
	int (*ndo_set_tx_maxrate)(struct net_device___45 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___45 *);
	int (*ndo_change_proto_down)(struct net_device___45 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___45 *, struct sk_buff___45 *);
	void (*ndo_set_rx_headroom)(struct net_device___45 *, int);
	int (*ndo_bpf)(struct net_device___45 *, struct netdev_bpf___43 *);
	int (*ndo_xdp_xmit)(struct net_device___45 *, int, struct xdp_frame___43 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___45 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___45 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct mii_bus___4;

struct mdio_device___4 {
	struct device___342 dev;
	struct mii_bus___4 *bus;
	char modalias[32];
	int (*bus_match)(struct device___342 *, struct device_driver___342 *);
	void (*device_free)(struct mdio_device___4 *);
	void (*device_remove)(struct mdio_device___4 *);
	int addr;
	int flags;
	struct gpio_desc *reset;
	unsigned int reset_assert_delay;
	unsigned int reset_deassert_delay;
};

struct phy_driver___4;

struct phy_led_trigger___3;

struct phy_device___4 {
	struct mdio_device___4 mdio;
	struct phy_driver___4 *drv;
	u32 phy_id;
	struct phy_c45_device_ids c45_ids;
	unsigned int is_c45: 1;
	unsigned int is_internal: 1;
	unsigned int is_pseudo_fixed_link: 1;
	unsigned int has_fixups: 1;
	unsigned int suspended: 1;
	unsigned int sysfs_links: 1;
	unsigned int loopback_enabled: 1;
	unsigned int autoneg: 1;
	unsigned int link: 1;
	enum phy_state state;
	u32 dev_flags;
	phy_interface_t interface;
	int speed;
	int duplex;
	int pause;
	int asym_pause;
	u32 interrupts;
	u32 rh_reserved_supported;
	u32 rh_reserved_advertising;
	u32 rh_reserved_lp_advertising;
	u32 eee_broken_modes;
	int link_timeout;
	struct phy_led_trigger___3 *phy_led_triggers;
	unsigned int phy_num_led_triggers;
	struct phy_led_trigger___3 *last_triggered;
	struct phy_led_trigger___3 *led_link_trigger;
	int irq;
	void *priv;
	struct work_struct phy_queue;
	struct delayed_work state_queue;
	struct mutex lock;
	struct phylink *phylink;
	struct net_device___45 *attached_dev;
	u8 mdix;
	u8 mdix_ctrl;
	long unsigned int supported[2];
	long unsigned int advertising[2];
	long unsigned int lp_advertising[2];
	void (*phy_link_change)(struct phy_device___4 *, bool, bool);
	void (*adjust_link)(struct net_device___45 *);
};

struct softnet_data___43 {
	struct list_head poll_list;
	struct sk_buff_head___43 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___43 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___2 *output_queue;
	struct Qdisc___2 **output_queue_tailp;
	struct sk_buff___45 *completion_queue;
	struct sk_buff_head___43 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___43 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___43 input_pkt_queue;
	struct napi_struct___43 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kernel_param_ops___303 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___303 *);
	int (*get)(char *, const struct kernel_param___303 *);
	void (*free)(void *);
};

struct kparam_array___303;

struct kernel_param___303 {
	const char *name;
	struct module___306 *mod;
	const struct kernel_param_ops___303 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___303 *arr;
	};
};

struct kparam_array___303 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___303 *ops;
	void *elem;
};

struct module_attribute___303 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___303 *, struct module_kobject___303 *, char *);
	ssize_t (*store)(struct module_attribute___303 *, struct module_kobject___303 *, const char *, size_t);
	void (*setup)(struct module___306 *, const char *);
	int (*test)(struct module___306 *);
	void (*free)(struct module___306 *);
};

struct mii_bus___4 {
	struct module___306 *owner;
	const char *name;
	char id[61];
	void *priv;
	int (*read)(struct mii_bus___4 *, int, int);
	int (*write)(struct mii_bus___4 *, int, int, u16);
	int (*reset)(struct mii_bus___4 *);
	struct mutex mdio_lock;
	struct device___342 *parent;
	enum {
		MDIOBUS_ALLOCATED___4 = 1,
		MDIOBUS_REGISTERED___4 = 2,
		MDIOBUS_UNREGISTERED___4 = 3,
		MDIOBUS_RELEASED___4 = 4,
	} state;
	struct device___342 dev;
	struct mdio_device___4 *mdio_map[32];
	u32 phy_mask;
	u32 phy_ignore_ta_mask;
	int irq[32];
	int reset_delay_us;
	struct gpio_desc *reset_gpiod;
};

struct mdio_driver_common___4 {
	struct device_driver___342 driver;
	int flags;
};

struct phy_driver___4 {
	struct mdio_driver_common___4 mdiodrv;
	u32 phy_id;
	char *name;
	u32 phy_id_mask;
	u32 rh_reserved_features;
	u32 flags;
	const void *driver_data;
	const long unsigned int * const features;
	int (*soft_reset)(struct phy_device___4 *);
	int (*config_init)(struct phy_device___4 *);
	int (*probe)(struct phy_device___4 *);
	int (*suspend)(struct phy_device___4 *);
	int (*resume)(struct phy_device___4 *);
	int (*config_aneg)(struct phy_device___4 *);
	int (*aneg_done)(struct phy_device___4 *);
	int (*read_status)(struct phy_device___4 *);
	int (*ack_interrupt)(struct phy_device___4 *);
	int (*config_intr)(struct phy_device___4 *);
	int (*did_interrupt)(struct phy_device___4 *);
	void (*remove)(struct phy_device___4 *);
	int (*match_phy_device)(struct phy_device___4 *);
	int (*ts_info)(struct phy_device___4 *, struct ethtool_ts_info *);
	int (*hwtstamp)(struct phy_device___4 *, struct ifreq *);
	bool (*rxtstamp)(struct phy_device___4 *, struct sk_buff___45 *, int);
	void (*txtstamp)(struct phy_device___4 *, struct sk_buff___45 *, int);
	int (*set_wol)(struct phy_device___4 *, struct ethtool_wolinfo *);
	void (*get_wol)(struct phy_device___4 *, struct ethtool_wolinfo *);
	void (*link_change_notify)(struct phy_device___4 *);
	int (*read_mmd)(struct phy_device___4 *, int, u16);
	int (*write_mmd)(struct phy_device___4 *, int, u16, u16);
	int (*read_page)(struct phy_device___4 *);
	int (*write_page)(struct phy_device___4 *, int);
	int (*module_info)(struct phy_device___4 *, struct ethtool_modinfo *);
	int (*module_eeprom)(struct phy_device___4 *, struct ethtool_eeprom *, u8 *);
	int (*get_sset_count)(struct phy_device___4 *);
	void (*get_strings)(struct phy_device___4 *, u8 *);
	void (*get_stats)(struct phy_device___4 *, struct ethtool_stats *, u64 *);
	int (*get_tunable)(struct phy_device___4 *, struct ethtool_tunable *, void *);
	int (*set_tunable)(struct phy_device___4 *, struct ethtool_tunable *, const void *);
	int (*set_loopback)(struct phy_device___4 *, bool);
};

struct led_classdev___3;

struct led_trigger___3 {
	const char *name;
	void (*activate)(struct led_classdev___3 *);
	void (*deactivate)(struct led_classdev___3 *);
	rwlock_t leddev_list_lock;
	struct list_head led_cdevs;
	struct list_head next_trig;
};

struct phy_led_trigger___3 {
	struct led_trigger___3 trigger;
	char name[75];
	unsigned int speed;
};

struct phy_fixup {
	struct list_head list;
	char bus_id[64];
	u32 phy_uid;
	u32 phy_uid_mask;
	int (*run)(struct phy_device___4 *);
};

struct led_classdev___3 {
	const char *name;
	enum led_brightness brightness;
	enum led_brightness max_brightness;
	int flags;
	long unsigned int work_flags;
	void (*brightness_set)(struct led_classdev___3 *, enum led_brightness);
	int (*brightness_set_blocking)(struct led_classdev___3 *, enum led_brightness);
	enum led_brightness (*brightness_get)(struct led_classdev___3 *);
	int (*blink_set)(struct led_classdev___3 *, long unsigned int *, long unsigned int *);
	int (*pattern_set)(struct led_classdev___3 *, struct led_pattern *, u32, int);
	int (*pattern_clear)(struct led_classdev___3 *);
	struct device___342 *dev;
	const struct attribute_group___339 **groups;
	struct list_head node;
	const char *default_trigger;
	long unsigned int blink_delay_on;
	long unsigned int blink_delay_off;
	struct timer_list blink_timer;
	int blink_brightness;
	int new_blink_brightness;
	void (*flash_resume)(struct led_classdev___3 *);
	struct work_struct set_brightness_work;
	int delayed_set_value;
	struct rw_semaphore___376 trigger_lock;
	struct led_trigger___3 *trigger;
	struct list_head trig_list;
	void *trigger_data;
	bool activated;
	struct mutex led_access;
};

struct property___81 {
	char *name;
	int length;
	void *value;
	struct property___81 *next;
	long unsigned int _flags;
	struct bin_attribute___338 attr;
};

struct module___307;

struct file___376;

struct kiocb___376;

struct iov_iter___160;

struct poll_table_struct___226;

struct vm_area_struct___377;

struct inode___376;

struct file_lock___376;

struct page___377;

struct pipe_inode_info___78;

struct seq_file___318;

struct file_operations___376 {
	struct module___307 *owner;
	loff_t (*llseek)(struct file___376 *, loff_t, int);
	ssize_t (*read)(struct file___376 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___376 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___376 *, struct iov_iter___160 *);
	ssize_t (*write_iter)(struct kiocb___376 *, struct iov_iter___160 *);
	int (*iopoll)(struct kiocb___376 *, bool);
	int (*iterate)(struct file___376 *, struct dir_context *);
	int (*iterate_shared)(struct file___376 *, struct dir_context *);
	__poll_t (*poll)(struct file___376 *, struct poll_table_struct___226 *);
	long int (*unlocked_ioctl)(struct file___376 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___376 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___376 *, struct vm_area_struct___377 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___376 *, struct file___376 *);
	int (*flush)(struct file___376 *, fl_owner_t);
	int (*release)(struct inode___376 *, struct file___376 *);
	int (*fsync)(struct file___376 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___376 *, int);
	int (*lock)(struct file___376 *, int, struct file_lock___376 *);
	ssize_t (*sendpage)(struct file___376 *, struct page___377 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___376 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___376 *, int, struct file_lock___376 *);
	ssize_t (*splice_write)(struct pipe_inode_info___78 *, struct file___376 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___376 *, loff_t *, struct pipe_inode_info___78 *, size_t, unsigned int);
	int (*setlease)(struct file___376 *, long int, struct file_lock___376 **, void **);
	long int (*fallocate)(struct file___376 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___318 *, struct file___376 *);
	ssize_t (*copy_file_range)(struct file___376 *, loff_t, struct file___376 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___376 *, loff_t, struct file___376 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___376 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___376 {
	u64 seqnum;
	struct vm_area_struct___377 *vmas[4];
};

struct page_frag___376 {
	struct page___377 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___143;

struct debug_info___143 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___143 *hbp_break[16];
	struct perf_event___143 *hbp_watch[16];
};

struct thread_struct___143 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___143 debug;
	long: 64;
};

struct mm_struct___376;

struct pid___219;

struct cred___345;

struct nsproxy___280;

struct signal_struct___259;

struct css_set___235;

struct perf_event_context___143;

struct vm_struct___282;

struct task_struct___377 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___377 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___376 *mm;
	struct mm_struct___376 *active_mm;
	struct vmacache___376 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___377 *real_parent;
	struct task_struct___377 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___377 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___219 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___219 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___219 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___345 *ptracer_cred;
	const struct cred___345 *real_cred;
	const struct cred___345 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___280 *nsproxy;
	struct signal_struct___259 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___377 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___107 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___235 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___143 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___78 *splice_pipe;
	struct page_frag___376 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___377 *oom_reaper_list;
	struct vm_struct___282 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___143 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___143 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___377 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___143)(struct perf_event___143 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___143;

struct fasync_struct___375;

struct pid_namespace___219;

struct trace_event_call___136;

struct perf_cgroup___143;

struct perf_event___143 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___143 *group_leader;
	struct pmu___143 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___143 hw;
	struct perf_event_context___143 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___143 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___377 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___375 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___143 *);
	struct callback_head callback_head;
	struct pid_namespace___219 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___143 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___143 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___136 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___143 *cgrp;
	struct list_head sb_list;
};

typedef struct page___377 *pgtable_t___376;

struct address_space___375;

struct dev_pagemap___364;

struct page___377 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___375 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___377 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___376 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___376 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___364 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___376;

struct lruvec___376 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___376 *pgdat;
};

struct zone___376 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___376 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___376 {
	struct zone___376 *zone;
	int zone_idx;
};

struct zonelist___376 {
	struct zoneref___376 _zonerefs[25];
};

struct pglist_data___376 {
	struct zone___376 node_zones[3];
	struct zonelist___376 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___377 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___377 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___376 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___377 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___377 *owner;
};

struct secondary_data___377 {
	void *stack;
	struct task_struct___377 *task;
	long int status;
};

struct blocking_notifier_head___376 {
	struct rw_semaphore___377 rwsem;
	struct notifier_block *head;
};

struct irqaction___18 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___18 *next;
	irq_handler_t thread_fn;
	struct task_struct___377 *thread;
	struct irqaction___18 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct key___345;

struct ucounts___250;

struct user_namespace___250 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___250 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___9 ns;
	long unsigned int flags;
	struct key___345 *persistent_keyring_register;
	struct rw_semaphore___377 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___250 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_root___369;

struct kernfs_elem_dir___369 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___369 *root;
};

struct kernfs_node___370;

struct kernfs_syscall_ops___369;

struct kernfs_root___369 {
	struct kernfs_node___370 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___369 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___369 {
	struct kernfs_node___370 *target_kn;
};

struct kernfs_ops___369;

struct kernfs_elem_attr___369 {
	const struct kernfs_ops___369 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___370 *notify_next;
};

struct kernfs_node___370 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___370 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___369 dir;
		struct kernfs_elem_symlink___369 symlink;
		struct kernfs_elem_attr___369 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___369;

struct kernfs_ops___369 {
	int (*open)(struct kernfs_open_file___369 *);
	void (*release)(struct kernfs_open_file___369 *);
	int (*seq_show)(struct seq_file___318 *, void *);
	void * (*seq_start)(struct seq_file___318 *, loff_t *);
	void * (*seq_next)(struct seq_file___318 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___318 *, void *);
	ssize_t (*read)(struct kernfs_open_file___369 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___369 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___369 *, struct vm_area_struct___377 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___369 *, struct poll_table_struct___226 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___369 {
	int (*remount_fs)(struct kernfs_root___369 *, int *, char *);
	int (*show_options)(struct seq_file___318 *, struct kernfs_root___369 *);
	int (*mkdir)(struct kernfs_node___370 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___370 *);
	int (*rename)(struct kernfs_node___370 *, struct kernfs_node___370 *, const char *);
	int (*show_path)(struct seq_file___318 *, struct kernfs_node___370 *, struct kernfs_root___369 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___317;

struct seq_file___318 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___317 *op;
	int poll_event;
	const struct file___376 *file;
	void *private;
};

struct vm_operations_struct___364;

struct kernfs_open_file___369 {
	struct kernfs_node___370 *kn;
	struct file___376 *file;
	struct seq_file___318 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___364 *vm_ops;
};

struct dentry___375;

struct path___376 {
	struct vfsmount *mnt;
	struct dentry___375 *dentry;
};

struct fown_struct___219 {
	rwlock_t lock;
	struct pid___219 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___376 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___376 f_path;
	struct inode___376 *f_inode;
	const struct file_operations___376 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___219 f_owner;
	const struct cred___345 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___375 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___364;

struct vm_operations_struct___364 {
	void (*open)(struct vm_area_struct___377 *);
	void (*close)(struct vm_area_struct___377 *);
	int (*split)(struct vm_area_struct___377 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___377 *);
	vm_fault_t (*fault)(struct vm_fault___364 *);
	vm_fault_t (*huge_fault)(struct vm_fault___364 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___364 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___377 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___364 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___364 *);
	int (*access)(struct vm_area_struct___377 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___377 *);
	int (*set_policy)(struct vm_area_struct___377 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___377 *, long unsigned int);
	struct page___377 * (*find_special_page)(struct vm_area_struct___377 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___232)(struct file___376 *, wait_queue_head_t *, struct poll_table_struct___226 *);

struct poll_table_struct___226 {
	poll_queue_proc___232 _qproc;
	__poll_t _key;
};

struct vm_area_struct___377 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___377 *vm_next;
	struct vm_area_struct___377 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___376 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___364 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___376 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___363;

struct bin_attribute___339;

struct attribute_group___340 {
	const char *name;
	umode_t (*is_visible)(struct kobject___363 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___363 *, struct bin_attribute___339 *, int);
	struct attribute **attrs;
	struct bin_attribute___339 **bin_attrs;
};

struct kset___362;

struct kobj_type___362;

struct kobject___363 {
	const char *name;
	struct list_head entry;
	struct kobject___363 *parent;
	struct kset___362 *kset;
	struct kobj_type___362 *ktype;
	struct kernfs_node___370 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___339 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___376 *, struct kobject___363 *, struct bin_attribute___339 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___376 *, struct kobject___363 *, struct bin_attribute___339 *, char *, loff_t, size_t);
	int (*mmap)(struct file___376 *, struct kobject___363 *, struct bin_attribute___339 *, struct vm_area_struct___377 *);
};

struct sysfs_ops___362 {
	ssize_t (*show)(struct kobject___363 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___363 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___362;

struct kset___362 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___363 kobj;
	const struct kset_uevent_ops___362 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___362 {
	void (*release)(struct kobject___363 *);
	const struct sysfs_ops___362 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___29 * (*child_ns_type)(struct kobject___363 *);
	const void * (*namespace)(struct kobject___363 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___362 {
	int (* const filter)(struct kset___362 *, struct kobject___363 *);
	const char * (* const name)(struct kset___362 *, struct kobject___363 *);
	int (* const uevent)(struct kset___362 *, struct kobject___363 *, struct kobj_uevent_env *);
};

struct kobj_attribute___354 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___363 *, struct kobj_attribute___354 *, char *);
	ssize_t (*store)(struct kobject___363 *, struct kobj_attribute___354 *, const char *, size_t);
};

struct device___343;

struct dev_pm_ops___343 {
	int (*prepare)(struct device___343 *);
	void (*complete)(struct device___343 *);
	int (*suspend)(struct device___343 *);
	int (*resume)(struct device___343 *);
	int (*freeze)(struct device___343 *);
	int (*thaw)(struct device___343 *);
	int (*poweroff)(struct device___343 *);
	int (*restore)(struct device___343 *);
	int (*suspend_late)(struct device___343 *);
	int (*resume_early)(struct device___343 *);
	int (*freeze_late)(struct device___343 *);
	int (*thaw_early)(struct device___343 *);
	int (*poweroff_late)(struct device___343 *);
	int (*restore_early)(struct device___343 *);
	int (*suspend_noirq)(struct device___343 *);
	int (*resume_noirq)(struct device___343 *);
	int (*freeze_noirq)(struct device___343 *);
	int (*thaw_noirq)(struct device___343 *);
	int (*poweroff_noirq)(struct device___343 *);
	int (*restore_noirq)(struct device___343 *);
	int (*runtime_suspend)(struct device___343 *);
	int (*runtime_resume)(struct device___343 *);
	int (*runtime_idle)(struct device___343 *);
};

struct dev_pm_info___343 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___6 *subsys_data;
	void (*set_latency_tolerance)(struct device___343 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___343;

struct bus_type___343;

struct device_driver___343;

struct dev_pm_domain___343;

struct irq_domain___28;

struct dma_map_ops___131;

struct device_node___86;

struct fwnode_handle___265;

struct class___343;

struct device___343 {
	struct device___343 *parent;
	struct device_private *p;
	struct kobject___363 kobj;
	const char *init_name;
	const struct device_type___343 *type;
	struct mutex mutex;
	struct bus_type___343 *bus;
	struct device_driver___343 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___343 power;
	struct dev_pm_domain___343 *pm_domain;
	struct irq_domain___28 *msi_domain;
	struct dev_pin_info___4 *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___131 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___86 *of_node;
	struct fwnode_handle___265 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___343 *class;
	const struct attribute_group___340 **groups;
	void (*release)(struct device___343 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___343 {
	struct dev_pm_ops___343 ops;
	void (*detach)(struct device___343 *, bool);
	int (*activate)(struct device___343 *);
	void (*sync)(struct device___343 *);
	void (*dismiss)(struct device___343 *);
};

struct upid___219 {
	int nr;
	struct pid_namespace___219 *ns;
};

struct pid_namespace___219 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___377 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___219 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___375 *proc_self;
	struct dentry___375 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___250 *user_ns;
	struct ucounts___250 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___9 ns;
};

struct pid___219 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___219 numbers[1];
};

struct user_struct___345 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___345 *uid_keyring;
	struct key___345 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___376;

struct mm_struct___376 {
	struct {
		struct vm_area_struct___377 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___376 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___377 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___376 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___377 *owner;
		struct user_namespace___250 *user_ns;
		struct file___376 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___376 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___345 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___345 *session_keyring;
	struct key___345 *process_keyring;
	struct key___345 *thread_keyring;
	struct key___345 *request_key_auth;
	void *security;
	struct user_struct___345 *user;
	struct user_namespace___250 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___55;

struct cgroup_namespace___235;

struct nsproxy___280 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___219 *pid_ns_for_children;
	struct net___55 *net_ns;
	struct cgroup_namespace___235 *cgroup_ns;
};

struct signal_struct___259 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___377 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___377 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___219 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___219 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___376 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___219 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___235;

struct cgroup___235;

struct css_set___235 {
	struct cgroup_subsys_state___235 *subsys[13];
	refcount_t refcount;
	struct css_set___235 *dom_cset;
	struct cgroup___235 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___235 *mg_src_cgrp;
	struct cgroup___235 *mg_dst_cgrp;
	struct css_set___235 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___143 {
	struct pmu___143 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___377 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___143 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___78;

struct pipe_inode_info___78 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___377 *tmp_page;
	struct fasync_struct___375 *fasync_readers;
	struct fasync_struct___375 *fasync_writers;
	struct pipe_buffer___78 *bufs;
	struct user_struct___345 *user;
};

struct vm_struct___282 {
	struct vm_struct___282 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___377 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___271 {
	struct task_struct___377 task;
	long unsigned int stack[8192];
};

struct bus_type___343 {
	const char *name;
	const char *dev_name;
	struct device___343 *dev_root;
	const struct attribute_group___340 **bus_groups;
	const struct attribute_group___340 **dev_groups;
	const struct attribute_group___340 **drv_groups;
	int (*match)(struct device___343 *, struct device_driver___343 *);
	int (*uevent)(struct device___343 *, struct kobj_uevent_env *);
	int (*probe)(struct device___343 *);
	int (*remove)(struct device___343 *);
	void (*shutdown)(struct device___343 *);
	int (*online)(struct device___343 *);
	int (*offline)(struct device___343 *);
	int (*suspend)(struct device___343 *, pm_message_t);
	int (*resume)(struct device___343 *);
	int (*num_vf)(struct device___343 *);
	int (*dma_configure)(struct device___343 *);
	const struct dev_pm_ops___343 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___343 {
	const char *name;
	struct bus_type___343 *bus;
	struct module___307 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___343 *);
	int (*remove)(struct device___343 *);
	void (*shutdown)(struct device___343 *);
	int (*suspend)(struct device___343 *, pm_message_t);
	int (*resume)(struct device___343 *);
	const struct attribute_group___340 **groups;
	const struct dev_pm_ops___343 *pm;
	void (*coredump)(struct device___343 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___343 {
	const char *name;
	const struct attribute_group___340 **groups;
	int (*uevent)(struct device___343 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___343 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___343 *);
	const struct dev_pm_ops___343 *pm;
};

struct module_kobject___304 {
	struct kobject___363 kobj;
	struct module___307 *mod;
	struct kobject___363 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___304 {
	struct module___307 *mod;
	struct latch_tree_node node;
};

struct module_layout___304 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___304 mtn;
};

struct module_attribute___304;

struct kernel_param___304;

struct module___307 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___304 mkobj;
	struct module_attribute___304 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___363 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___304 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___304 core_layout;
	struct module_layout___304 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___136 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct class___343 {
	const char *name;
	struct module___307 *owner;
	const struct attribute_group___340 **class_groups;
	const struct attribute_group___340 **dev_groups;
	struct kobject___363 *dev_kobj;
	int (*dev_uevent)(struct device___343 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___343 *, umode_t *);
	void (*class_release)(struct class___343 *);
	void (*dev_release)(struct device___343 *);
	int (*shutdown_pre)(struct device___343 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___343 *);
	const struct dev_pm_ops___343 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

typedef void (*dr_release_t___23)(struct device___343 *, void *);

struct irq_domain_ops___28;

struct irq_domain_chip_generic___16;

struct irq_domain___28 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___28 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___265 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___16 *gc;
	struct irq_domain___28 *parent;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_direct_max_irq;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_tree_mutex;
	unsigned int linear_revmap[0];
};

struct dma_map_ops___131 {
	void * (*alloc)(struct device___343 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___343 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___343 *, struct vm_area_struct___377 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___343 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___343 *, struct page___377 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___343 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___343 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___343 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___343 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___343 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___343 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___343 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___343 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___343 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___343 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___343 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___343 *, u64);
	u64 (*get_required_mask)(struct device___343 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___265;

struct fwnode_handle___265 {
	struct fwnode_handle___265 *secondary;
	const struct fwnode_operations___265 *ops;
};

struct property___82;

struct device_node___86 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___265 fwnode;
	struct property___82 *properties;
	struct property___82 *deadprops;
	struct device_node___86 *parent;
	struct device_node___86 *child;
	struct device_node___86 *sibling;
	struct kobject___363 kobj;
	long unsigned int _flags;
	void *data;
};

struct fwnode_reference_args___265;

struct fwnode_endpoint___265;

struct fwnode_operations___265 {
	struct fwnode_handle___265 * (*get)(struct fwnode_handle___265 *);
	void (*put)(struct fwnode_handle___265 *);
	bool (*device_is_available)(const struct fwnode_handle___265 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___265 *, const struct device___343 *);
	bool (*property_present)(const struct fwnode_handle___265 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___265 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___265 *, const char *, const char **, size_t);
	struct fwnode_handle___265 * (*get_parent)(const struct fwnode_handle___265 *);
	struct fwnode_handle___265 * (*get_next_child_node)(const struct fwnode_handle___265 *, struct fwnode_handle___265 *);
	struct fwnode_handle___265 * (*get_named_child_node)(const struct fwnode_handle___265 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___265 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___265 *);
	struct fwnode_handle___265 * (*graph_get_next_endpoint)(const struct fwnode_handle___265 *, struct fwnode_handle___265 *);
	struct fwnode_handle___265 * (*graph_get_remote_endpoint)(const struct fwnode_handle___265 *);
	struct fwnode_handle___265 * (*graph_get_port_parent)(struct fwnode_handle___265 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___265 *, struct fwnode_endpoint___265 *);
};

struct fwnode_endpoint___265 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___265 *local_fwnode;
};

struct fwnode_reference_args___265 {
	struct fwnode_handle___265 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct property___82 {
	char *name;
	int length;
	void *value;
	struct property___82 *next;
	long unsigned int _flags;
	struct bin_attribute___339 attr;
};

struct irq_desc___21;

typedef void (*irq_flow_handler_t___21)(struct irq_desc___21 *);

struct irq_chip___28;

struct irq_data___28 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___11 *common;
	struct irq_chip___28 *chip;
	struct irq_domain___28 *domain;
	struct irq_data___28 *parent_data;
	void *chip_data;
};

struct irq_desc___21 {
	struct irq_common_data___11 irq_common_data;
	struct irq_data___28 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___21 handle_irq;
	struct irqaction___18 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int irq_count;
	unsigned int tot_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___363 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___307 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___375;

struct address_space___375 {
	struct inode___376 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___377 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___375 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___364)(struct vm_area_struct___377 *, long unsigned int, const struct page___377 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___364)(struct page___377 *, void *);

struct dev_pagemap___364 {
	dev_page_fault_t___364 page_fault;
	dev_page_free_t___364 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___343 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___376 {
	struct task_struct___377 *task;
	struct core_thread___376 *next;
};

struct core_state___376 {
	atomic_t nr_threads;
	struct core_thread___376 dumper;
	struct completion startup;
};

struct vm_fault___364 {
	struct vm_area_struct___377 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___377 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___377 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___376 prealloc_pte;
};

struct irq_chip___28 {
	struct device___343 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___28 *);
	void (*irq_shutdown)(struct irq_data___28 *);
	void (*irq_enable)(struct irq_data___28 *);
	void (*irq_disable)(struct irq_data___28 *);
	void (*irq_ack)(struct irq_data___28 *);
	void (*irq_mask)(struct irq_data___28 *);
	void (*irq_mask_ack)(struct irq_data___28 *);
	void (*irq_unmask)(struct irq_data___28 *);
	void (*irq_eoi)(struct irq_data___28 *);
	int (*irq_set_affinity)(struct irq_data___28 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___28 *);
	int (*irq_set_type)(struct irq_data___28 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___28 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___28 *);
	void (*irq_bus_sync_unlock)(struct irq_data___28 *);
	void (*irq_cpu_online)(struct irq_data___28 *);
	void (*irq_cpu_offline)(struct irq_data___28 *);
	void (*irq_suspend)(struct irq_data___28 *);
	void (*irq_resume)(struct irq_data___28 *);
	void (*irq_pm_shutdown)(struct irq_data___28 *);
	void (*irq_calc_mask)(struct irq_data___28 *);
	void (*irq_print_chip)(struct irq_data___28 *, struct seq_file___318 *);
	int (*irq_request_resources)(struct irq_data___28 *);
	void (*irq_release_resources)(struct irq_data___28 *);
	void (*irq_compose_msi_msg)(struct irq_data___28 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___28 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___28 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___28 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___28 *, void *);
	void (*ipi_send_single)(struct irq_data___28 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___28 *, const struct cpumask *);
	long unsigned int flags;
};

struct irq_chip_type___17 {
	struct irq_chip___28 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___21 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___17 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___17 *);
	void (*resume)(struct irq_chip_generic___17 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___28 *domain;
	struct list_head list;
	struct irq_chip_type___17 chip_types[0];
};

struct irq_domain_chip_generic___16 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___17 *gc[0];
};

struct irq_fwspec___28 {
	struct fwnode_handle___265 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___28 {
	int (*match)(struct irq_domain___28 *, struct device_node___86 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___28 *, struct irq_fwspec___28 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___28 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___28 *, unsigned int);
	int (*xlate)(struct irq_domain___28 *, struct device_node___86 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___28 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___28 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___28 *, struct irq_data___28 *, bool);
	void (*deactivate)(struct irq_domain___28 *, struct irq_data___28 *);
	int (*translate)(struct irq_domain___28 *, struct irq_fwspec___28 *, long unsigned int *, unsigned int *);
};

struct dentry_operations___375;

struct super_block___375;

struct dentry___375 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___375 *d_parent;
	struct qstr d_name;
	struct inode___376 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___375 *d_op;
	struct super_block___375 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___375;

struct block_device___375;

struct inode___376 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___375 *i_op;
	struct super_block___375 *i_sb;
	struct address_space___375 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___377 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___376 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___375 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___78 *i_pipe;
		struct block_device___375 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___375 {
	int (*d_revalidate)(struct dentry___375 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___375 *, unsigned int);
	int (*d_hash)(const struct dentry___375 *, struct qstr *);
	int (*d_compare)(const struct dentry___375 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___375 *);
	int (*d_init)(struct dentry___375 *);
	void (*d_release)(struct dentry___375 *);
	void (*d_prune)(struct dentry___375 *);
	void (*d_iput)(struct dentry___375 *, struct inode___376 *);
	char * (*d_dname)(struct dentry___375 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___376 *);
	int (*d_manage)(const struct path___376 *, bool);
	struct dentry___375 * (*d_real)(struct dentry___375 *, const struct inode___376 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___375;

struct mem_dqinfo___375 {
	struct quota_format_type___375 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___375;

struct quota_info___375 {
	unsigned int flags;
	struct rw_semaphore___377 dqio_sem;
	struct inode___376 *files[3];
	struct mem_dqinfo___375 info[3];
	const struct quota_format_ops___375 *ops[3];
};

struct rcuwait___375 {
	struct task_struct___377 *task;
};

struct percpu_rw_semaphore___375 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___377 rw_sem;
	struct rcuwait___375 writer;
	int readers_block;
};

struct sb_writers___375 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___375 rw_sem[3];
};

struct file_system_type___375;

struct super_operations___375;

struct dquot_operations___375;

struct quotactl_ops___375;

struct super_block___375 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___375 *s_type;
	const struct super_operations___375 *s_op;
	const struct dquot_operations___375 *dq_op;
	const struct quotactl_ops___375 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___375 *s_root;
	struct rw_semaphore___377 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___375 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___375 s_dquot;
	struct sb_writers___375 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___375 *s_d_op;
	int cleancache_poolid;
	struct shrinker___134 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___250 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___376 {
	struct file___376 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___376 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___375 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___376 *ia_file;
};

struct dquot___375 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___375 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___375 {
	int qf_fmt_id;
	const struct quota_format_ops___375 *qf_ops;
	struct module___307 *qf_owner;
	struct quota_format_type___375 *qf_next;
};

struct quota_format_ops___375 {
	int (*check_quota_file)(struct super_block___375 *, int);
	int (*read_file_info)(struct super_block___375 *, int);
	int (*write_file_info)(struct super_block___375 *, int);
	int (*free_file_info)(struct super_block___375 *, int);
	int (*read_dqblk)(struct dquot___375 *);
	int (*commit_dqblk)(struct dquot___375 *);
	int (*release_dqblk)(struct dquot___375 *);
	int (*get_next_id)(struct super_block___375 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___375 {
	int (*write_dquot)(struct dquot___375 *);
	struct dquot___375 * (*alloc_dquot)(struct super_block___375 *, int);
	void (*destroy_dquot)(struct dquot___375 *);
	int (*acquire_dquot)(struct dquot___375 *);
	int (*release_dquot)(struct dquot___375 *);
	int (*mark_dirty)(struct dquot___375 *);
	int (*write_info)(struct super_block___375 *, int);
	qsize_t * (*get_reserved_space)(struct inode___376 *);
	int (*get_projid)(struct inode___376 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___376 *, qsize_t *);
	int (*get_next_id)(struct super_block___375 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___375 {
	int (*quota_on)(struct super_block___375 *, int, int, const struct path___376 *);
	int (*quota_off)(struct super_block___375 *, int);
	int (*quota_enable)(struct super_block___375 *, unsigned int);
	int (*quota_disable)(struct super_block___375 *, unsigned int);
	int (*quota_sync)(struct super_block___375 *, int);
	int (*set_info)(struct super_block___375 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___375 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___375 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___375 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___375 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___375 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___375 {
	int (*writepage)(struct page___377 *, struct writeback_control___3 *);
	int (*readpage)(struct file___376 *, struct page___377 *);
	int (*writepages)(struct address_space___375 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___377 *);
	int (*readpages)(struct file___376 *, struct address_space___375 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___376 *, struct address_space___375 *, loff_t, unsigned int, unsigned int, struct page___377 **, void **);
	int (*write_end)(struct file___376 *, struct address_space___375 *, loff_t, unsigned int, unsigned int, struct page___377 *, void *);
	sector_t (*bmap)(struct address_space___375 *, sector_t);
	void (*invalidatepage)(struct page___377 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___377 *, gfp_t);
	void (*freepage)(struct page___377 *);
	ssize_t (*direct_IO)(struct kiocb___376 *, struct iov_iter___160 *);
	int (*migratepage)(struct address_space___375 *, struct page___377 *, struct page___377 *, enum migrate_mode);
	bool (*isolate_page)(struct page___377 *, isolate_mode_t);
	void (*putback_page)(struct page___377 *);
	int (*launder_page)(struct page___377 *);
	int (*is_partially_uptodate)(struct page___377 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___377 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___375 *, struct page___377 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___376 *, sector_t *);
	void (*swap_deactivate)(struct file___376 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct iov_iter___160 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___3 *bvec;
		struct pipe_inode_info___78 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___375 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___376 *bd_inode;
	struct super_block___375 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___375 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___375 {
	struct dentry___375 * (*lookup)(struct inode___376 *, struct dentry___375 *, unsigned int);
	const char * (*get_link)(struct dentry___375 *, struct inode___376 *, struct delayed_call *);
	int (*permission)(struct inode___376 *, int);
	struct posix_acl * (*get_acl)(struct inode___376 *, int);
	int (*readlink)(struct dentry___375 *, char *, int);
	int (*create)(struct inode___376 *, struct dentry___375 *, umode_t, bool);
	int (*link)(struct dentry___375 *, struct inode___376 *, struct dentry___375 *);
	int (*unlink)(struct inode___376 *, struct dentry___375 *);
	int (*symlink)(struct inode___376 *, struct dentry___375 *, const char *);
	int (*mkdir)(struct inode___376 *, struct dentry___375 *, umode_t);
	int (*rmdir)(struct inode___376 *, struct dentry___375 *);
	int (*mknod)(struct inode___376 *, struct dentry___375 *, umode_t, dev_t);
	int (*rename)(struct inode___376 *, struct dentry___375 *, struct inode___376 *, struct dentry___375 *, unsigned int);
	int (*setattr)(struct dentry___375 *, struct iattr___375 *);
	int (*getattr)(const struct path___376 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___375 *, char *, size_t);
	int (*fiemap)(struct inode___376 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___376 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___376 *, struct dentry___375 *, struct file___376 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___376 *, struct dentry___375 *, umode_t);
	int (*set_acl)(struct inode___376 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___375 {
	void (*fl_copy_lock)(struct file_lock___376 *, struct file_lock___376 *);
	void (*fl_release_private)(struct file_lock___376 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___375;

struct file_lock___376 {
	struct file_lock___376 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___376 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___375 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___375 *fl_ops;
	const struct lock_manager_operations___375 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___375 {
	int (*lm_compare_owner)(struct file_lock___376 *, struct file_lock___376 *);
	long unsigned int (*lm_owner_key)(struct file_lock___376 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___376 *);
	int (*lm_grant)(struct file_lock___376 *, int);
	bool (*lm_break)(struct file_lock___376 *);
	int (*lm_change)(struct file_lock___376 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___376 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___375 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___375 *fa_next;
	struct file___376 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___375 {
	const char *name;
	int fs_flags;
	struct dentry___375 * (*mount)(struct file_system_type___375 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___375 *);
	struct module___307 *owner;
	struct file_system_type___375 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___375 {
	struct inode___376 * (*alloc_inode)(struct super_block___375 *);
	void (*destroy_inode)(struct inode___376 *);
	void (*dirty_inode)(struct inode___376 *, int);
	int (*write_inode)(struct inode___376 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___376 *);
	void (*evict_inode)(struct inode___376 *);
	void (*put_super)(struct super_block___375 *);
	int (*sync_fs)(struct super_block___375 *, int);
	int (*freeze_super)(struct super_block___375 *);
	int (*freeze_fs)(struct super_block___375 *);
	int (*thaw_super)(struct super_block___375 *);
	int (*unfreeze_fs)(struct super_block___375 *);
	int (*statfs)(struct dentry___375 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___375 *, int *, char *);
	void (*umount_begin)(struct super_block___375 *);
	int (*show_options)(struct seq_file___318 *, struct dentry___375 *);
	int (*show_devname)(struct seq_file___318 *, struct dentry___375 *);
	int (*show_path)(struct seq_file___318 *, struct dentry___375 *);
	int (*show_stats)(struct seq_file___318 *, struct dentry___375 *);
	ssize_t (*quota_read)(struct super_block___375 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___375 *, int, const char *, size_t, loff_t);
	struct dquot___375 ** (*get_dquots)(struct inode___376 *);
	int (*bdev_try_to_free_page)(struct super_block___375 *, struct page___377 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___375 *, struct shrink_control___134 *);
	long int (*free_cached_objects)(struct super_block___375 *, struct shrink_control___134 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*key_restrict_link_func_t___346)(struct key___345 *, const struct key_type *, const union key_payload *, struct key___345 *);

struct key_restriction___345;

struct key___345 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___377 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___345 *restrict_link;
};

struct key_restriction___345 {
	key_restrict_link_func_t___346 check;
	struct key___345 *key;
	struct key_type *keytype;
};

struct seq_operations___317 {
	void * (*start)(struct seq_file___318 *, loff_t *);
	void (*stop)(struct seq_file___318 *, void *);
	void * (*next)(struct seq_file___318 *, void *, loff_t *);
	int (*show)(struct seq_file___318 *, void *);
};

struct node___209 {
	struct device___343 dev;
};

struct net_device___46;

struct nf_bridge_info___44;

struct sk_buff___46 {
	union {
		struct {
			struct sk_buff___46 *next;
			struct sk_buff___46 *prev;
			union {
				struct net_device___46 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___30 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___46 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___44 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___44;

struct netns_frags___44 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___44 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv4___44 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct sock *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock **tcp_sk;
	struct netns_frags___44 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct dst_ops___54 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___54 *);
	struct dst_entry___2 * (*check)(struct dst_entry___2 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___2 *);
	unsigned int (*mtu)(const struct dst_entry___2 *);
	u32 * (*cow_metrics)(struct dst_entry___2 *, long unsigned int);
	void (*destroy)(struct dst_entry___2 *);
	void (*ifdown)(struct dst_entry___2 *, struct net_device___46 *, int);
	struct dst_entry___2 * (*negative_advice)(struct dst_entry___2 *);
	void (*link_failure)(struct sk_buff___46 *);
	void (*update_pmtu)(struct dst_entry___2 *, struct sock *, struct sk_buff___46 *, u32);
	void (*redirect)(struct dst_entry___2 *, struct sock *, struct sk_buff___46 *);
	int (*local_out)(struct net___55 *, struct sock *, struct sk_buff___46 *);
	struct neighbour___2 * (*neigh_lookup)(const struct dst_entry___2 *, struct sk_buff___46 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___2 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___54 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___44 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___54 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct sock *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops *notifier_ops;
	struct fib_notifier_ops *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_nf_frag___44 {
	struct netns_frags___44 frags;
};

struct netns_xfrm___54 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___54 xfrm4_dst_ops;
	struct dst_ops___54 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct net___55 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___250 *user_ns;
	struct ucounts___250 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___9 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___46 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___44 ipv4;
	struct netns_ipv6___54 ipv6;
	struct netns_sctp___30 sctp;
	struct netns_nf nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___44 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock *nfnl;
	struct sock *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___54 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef void compound_page_dtor___364(struct page___377 *);

struct pipe_buf_operations___78;

struct pipe_buffer___78 {
	struct page___377 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___78 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___78 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___78 *, struct pipe_buffer___78 *);
	void (*release)(struct pipe_inode_info___78 *, struct pipe_buffer___78 *);
	int (*steal)(struct pipe_inode_info___78 *, struct pipe_buffer___78 *);
	union {
		bool (*get)(struct pipe_inode_info___78 *, struct pipe_buffer___78 *);
		struct {
			void (*get)(struct pipe_inode_info___78 *, struct pipe_buffer___78 *);
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
};

struct nf_bridge_info___44 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___44 = 0,
		BRNF_PROTO_8021Q___44 = 1,
		BRNF_PROTO_PPPOE___44 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___46 *physindev;
	struct net_device___46 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___44(struct sk_buff___46 **);

typedef struct {
	struct net___55 *net;
} possible_net_t___45;

struct net_device_ops___44;

struct ethtool_ops___44;

struct xfrmdev_ops___44;

struct tlsdev_ops___44;

struct header_ops___44;

struct netdev_rx_queue___44;

struct netdev_queue___44;

struct dcbnl_rtnl_ops___44;

struct phy_device___5;

struct net_device___46 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___44 *netdev_ops;
	const struct ethtool_ops___44 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___2 *l3mdev_ops;
	const struct ndisc_ops___2 *ndisc_ops;
	const struct xfrmdev_ops___44 *xfrmdev_ops;
	const struct tlsdev_ops___44 *tlsdev_ops;
	const struct header_ops___44 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___362 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___2 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___44 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___44 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___2 *miniq_ingress;
	struct netdev_queue___44 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___44 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___2 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___2 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___44 = 0,
		NETREG_REGISTERED___44 = 1,
		NETREG_UNREGISTERING___44 = 2,
		NETREG_UNREGISTERED___44 = 3,
		NETREG_RELEASED___44 = 4,
		NETREG_DUMMY___44 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___44 = 0,
		RTNL_LINK_INITIALIZING___44 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___46 *);
	struct netpoll_info *npinfo;
	possible_net_t___45 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___343 dev;
	const struct attribute_group___340 *sysfs_groups[4];
	const struct attribute_group___340 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___2 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___44 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device___5 *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide35;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct sk_buff_head___44 {
	struct sk_buff___46 *next;
	struct sk_buff___46 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct ethtool_ops___44 {
	int (*get_settings)(struct net_device___46 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___46 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___46 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___46 *);
	void (*get_regs)(struct net_device___46 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___46 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___46 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___46 *);
	void (*set_msglevel)(struct net_device___46 *, u32);
	int (*nway_reset)(struct net_device___46 *);
	u32 (*get_link)(struct net_device___46 *);
	int (*get_eeprom_len)(struct net_device___46 *);
	int (*get_eeprom)(struct net_device___46 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___46 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___46 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___46 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___46 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___46 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___46 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___46 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___46 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___46 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___46 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___46 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___46 *);
	void (*complete)(struct net_device___46 *);
	u32 (*get_priv_flags)(struct net_device___46 *);
	int (*set_priv_flags)(struct net_device___46 *, u32);
	int (*get_sset_count)(struct net_device___46 *, int);
	int (*get_rxnfc)(struct net_device___46 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___46 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___46 *, struct ethtool_flash *);
	int (*reset)(struct net_device___46 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___46 *);
	u32 (*get_rxfh_indir_size)(struct net_device___46 *);
	int (*get_rxfh)(struct net_device___46 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___46 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___46 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___46 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___46 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___46 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___46 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___46 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___46 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___46 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___46 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___46 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___46 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___46 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___46 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___46 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___46 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___46 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___46 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___46 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___46 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___46 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	int (*get_fecparam)(struct net_device___46 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___46 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___46 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___46 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___46 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct mii_bus___5;

struct mdio_device___5 {
	struct device___343 dev;
	struct mii_bus___5 *bus;
	char modalias[32];
	int (*bus_match)(struct device___343 *, struct device_driver___343 *);
	void (*device_free)(struct mdio_device___5 *);
	void (*device_remove)(struct mdio_device___5 *);
	int addr;
	int flags;
	struct gpio_desc *reset;
	unsigned int reset_assert_delay;
	unsigned int reset_deassert_delay;
};

struct mii_bus___5 {
	struct module___307 *owner;
	const char *name;
	char id[61];
	void *priv;
	int (*read)(struct mii_bus___5 *, int, int);
	int (*write)(struct mii_bus___5 *, int, int, u16);
	int (*reset)(struct mii_bus___5 *);
	struct mutex mdio_lock;
	struct device___343 *parent;
	enum {
		MDIOBUS_ALLOCATED___5 = 1,
		MDIOBUS_REGISTERED___5 = 2,
		MDIOBUS_UNREGISTERED___5 = 3,
		MDIOBUS_RELEASED___5 = 4,
	} state;
	struct device___343 dev;
	struct mdio_device___5 *mdio_map[32];
	u32 phy_mask;
	u32 phy_ignore_ta_mask;
	int irq[32];
	int reset_delay_us;
	struct gpio_desc *reset_gpiod;
};

struct mdio_driver_common___5 {
	struct device_driver___343 driver;
	int flags;
};

struct kernel_param_ops___304 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___304 *);
	int (*get)(char *, const struct kernel_param___304 *);
	void (*free)(void *);
};

struct kparam_array___304;

struct kernel_param___304 {
	const char *name;
	struct module___307 *mod;
	const struct kernel_param_ops___304 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___304 *arr;
	};
};

struct kparam_array___304 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___304 *ops;
	void *elem;
};

struct module_attribute___304 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___304 *, struct module_kobject___304 *, char *);
	ssize_t (*store)(struct module_attribute___304 *, struct module_kobject___304 *, const char *, size_t);
	void (*setup)(struct module___307 *, const char *);
	int (*test)(struct module___307 *);
	void (*free)(struct module___307 *);
};

struct trace_event_class___136;

struct trace_event_call___136 {
	struct list_head list;
	struct trace_event_class___136 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___13 event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___39 *prog_array;
	int (*perf_perm)(struct trace_event_call___136 *, struct perf_event___143 *);
};

struct phy_driver___5;

struct phy_device___5 {
	struct mdio_device___5 mdio;
	struct phy_driver___5 *drv;
	u32 phy_id;
	struct phy_c45_device_ids c45_ids;
	unsigned int is_c45: 1;
	unsigned int is_internal: 1;
	unsigned int is_pseudo_fixed_link: 1;
	unsigned int has_fixups: 1;
	unsigned int suspended: 1;
	unsigned int sysfs_links: 1;
	unsigned int loopback_enabled: 1;
	unsigned int autoneg: 1;
	unsigned int link: 1;
	enum phy_state state;
	u32 dev_flags;
	phy_interface_t interface;
	int speed;
	int duplex;
	int pause;
	int asym_pause;
	u32 interrupts;
	u32 rh_reserved_supported;
	u32 rh_reserved_advertising;
	u32 rh_reserved_lp_advertising;
	u32 eee_broken_modes;
	int link_timeout;
	struct phy_led_trigger *phy_led_triggers;
	unsigned int phy_num_led_triggers;
	struct phy_led_trigger *last_triggered;
	struct phy_led_trigger *led_link_trigger;
	int irq;
	void *priv;
	struct work_struct phy_queue;
	struct delayed_work state_queue;
	struct mutex lock;
	struct phylink *phylink;
	struct net_device___46 *attached_dev;
	u8 mdix;
	u8 mdix_ctrl;
	long unsigned int supported[2];
	long unsigned int advertising[2];
	long unsigned int lp_advertising[2];
	void (*phy_link_change)(struct phy_device___5 *, bool, bool);
	void (*adjust_link)(struct net_device___46 *);
};

struct phy_driver___5 {
	struct mdio_driver_common___5 mdiodrv;
	u32 phy_id;
	char *name;
	u32 phy_id_mask;
	u32 rh_reserved_features;
	u32 flags;
	const void *driver_data;
	const long unsigned int * const features;
	int (*soft_reset)(struct phy_device___5 *);
	int (*config_init)(struct phy_device___5 *);
	int (*probe)(struct phy_device___5 *);
	int (*suspend)(struct phy_device___5 *);
	int (*resume)(struct phy_device___5 *);
	int (*config_aneg)(struct phy_device___5 *);
	int (*aneg_done)(struct phy_device___5 *);
	int (*read_status)(struct phy_device___5 *);
	int (*ack_interrupt)(struct phy_device___5 *);
	int (*config_intr)(struct phy_device___5 *);
	int (*did_interrupt)(struct phy_device___5 *);
	void (*remove)(struct phy_device___5 *);
	int (*match_phy_device)(struct phy_device___5 *);
	int (*ts_info)(struct phy_device___5 *, struct ethtool_ts_info *);
	int (*hwtstamp)(struct phy_device___5 *, struct ifreq *);
	bool (*rxtstamp)(struct phy_device___5 *, struct sk_buff___46 *, int);
	void (*txtstamp)(struct phy_device___5 *, struct sk_buff___46 *, int);
	int (*set_wol)(struct phy_device___5 *, struct ethtool_wolinfo *);
	void (*get_wol)(struct phy_device___5 *, struct ethtool_wolinfo *);
	void (*link_change_notify)(struct phy_device___5 *);
	int (*read_mmd)(struct phy_device___5 *, int, u16);
	int (*write_mmd)(struct phy_device___5 *, int, u16, u16);
	int (*read_page)(struct phy_device___5 *);
	int (*write_page)(struct phy_device___5 *, int);
	int (*module_info)(struct phy_device___5 *, struct ethtool_modinfo *);
	int (*module_eeprom)(struct phy_device___5 *, struct ethtool_eeprom *, u8 *);
	int (*get_sset_count)(struct phy_device___5 *);
	void (*get_strings)(struct phy_device___5 *, u8 *);
	void (*get_stats)(struct phy_device___5 *, struct ethtool_stats *, u64 *);
	int (*get_tunable)(struct phy_device___5 *, struct ethtool_tunable *, void *);
	int (*set_tunable)(struct phy_device___5 *, struct ethtool_tunable *, const void *);
	int (*set_loopback)(struct phy_device___5 *, bool);
};

struct inet_frag_queue___44;

struct inet_frags___44 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___44 *, const void *);
	void (*destructor)(struct inet_frag_queue___44 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___44 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___46 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___46 *fragments_tail;
	struct sk_buff___46 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___44 *net;
	struct callback_head rcu;
};

struct ucounts___250 {
	struct hlist_node node;
	struct user_namespace___250 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct pernet_operations___45 {
	struct list_head list;
	int (*init)(struct net___55 *);
	void (*exit)(struct net___55 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___44 {
	int (*ieee_getets)(struct net_device___46 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___46 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___46 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___46 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___46 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___46 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___46 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___46 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___46 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___46 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___46 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___46 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___46 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___46 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___46 *);
	u8 (*setstate)(struct net_device___46 *, u8);
	void (*getpermhwaddr)(struct net_device___46 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___46 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___46 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___46 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___46 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___46 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___46 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___46 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___46 *, int, u8 *);
	void (*setpfccfg)(struct net_device___46 *, int, u8);
	void (*getpfccfg)(struct net_device___46 *, int, u8 *);
	u8 (*setall)(struct net_device___46 *);
	u8 (*getcap)(struct net_device___46 *, int, u8 *);
	int (*getnumtcs)(struct net_device___46 *, int, u8 *);
	int (*setnumtcs)(struct net_device___46 *, int, u8);
	u8 (*getpfcstate)(struct net_device___46 *);
	void (*setpfcstate)(struct net_device___46 *, u8);
	void (*getbcncfg)(struct net_device___46 *, int, u32 *);
	void (*setbcncfg)(struct net_device___46 *, int, u32);
	void (*getbcnrp)(struct net_device___46 *, int, u8 *);
	void (*setbcnrp)(struct net_device___46 *, int, u8);
	int (*setapp)(struct net_device___46 *, u8, u16, u8);
	int (*getapp)(struct net_device___46 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___46 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___46 *, int, u8);
	u8 (*getdcbx)(struct net_device___46 *);
	u8 (*setdcbx)(struct net_device___46 *, u8);
	int (*peer_getappinfo)(struct net_device___46 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___46 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___46 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___46 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___46 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___46 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___235 {
	refcount_t count;
	struct ns_common___9 ns;
	struct user_namespace___250 *user_ns;
	struct ucounts___250 *ucounts;
	struct css_set___235 *root_cset;
};

struct bpf_map___236;

struct bpf_map_ops___235 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___236 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___236 *, struct file___376 *);
	void (*map_free)(struct bpf_map___236 *);
	int (*map_get_next_key)(struct bpf_map___236 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___236 *);
	void * (*map_lookup_elem)(struct bpf_map___236 *, void *);
	int (*map_update_elem)(struct bpf_map___236 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___236 *, void *);
	int (*map_push_elem)(struct bpf_map___236 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___236 *, void *);
	int (*map_peek_elem)(struct bpf_map___236 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___236 *, struct file___376 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___236 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___236 *, void *, struct seq_file___318 *);
	int (*map_check_btf)(const struct bpf_map___236 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___236 {
	const struct bpf_map_ops___235 *ops;
	struct bpf_map___236 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___345 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___44;

struct bpf_map_dev_ops___44 {
	int (*map_get_next_key)(struct bpf_offloaded_map___44 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___44 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___44 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___44 *, void *);
};

struct bpf_offloaded_map___44 {
	struct bpf_map___236 map;
	struct net_device___46 *netdev;
	const struct bpf_map_dev_ops___44 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___236;

typedef void (*kthread_work_func_t___236)(struct kthread_work___236 *);

struct kthread_worker___236;

struct kthread_work___236 {
	struct list_head node;
	kthread_work_func_t___236 func;
	struct kthread_worker___236 *worker;
	int canceling;
};

struct kthread_worker___236 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___377 *task;
	struct kthread_work___236 *current_work;
};

struct kthread_delayed_work___235 {
	struct kthread_work___236 work;
	struct timer_list timer;
};

struct psi_group___235 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___236 *poll_kworker;
	struct kthread_delayed_work___235 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___235 {
	struct kernfs_node___370 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___235;

struct cgroup_subsys_state___235 {
	struct cgroup___235 *cgroup;
	struct cgroup_subsys___235 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___235 *parent;
};

struct cgroup_root___235;

struct cgroup_rstat_cpu___235;

struct cgroup___235 {
	struct cgroup_subsys_state___235 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___370 *kn;
	struct cgroup_file___235 procs_file;
	struct cgroup_file___235 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___235 *subsys[13];
	struct cgroup_root___235 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___235 *dom_cgrp;
	struct cgroup_rstat_cpu___235 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___39 bpf;
	atomic_t congestion_count;
	struct cgroup___235 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___235 psi;
	int ancestor_ids[0];
};

struct cftype___235;

struct cgroup_subsys___235 {
	struct cgroup_subsys_state___235 * (*css_alloc)(struct cgroup_subsys_state___235 *);
	int (*css_online)(struct cgroup_subsys_state___235 *);
	void (*css_offline)(struct cgroup_subsys_state___235 *);
	void (*css_released)(struct cgroup_subsys_state___235 *);
	void (*css_free)(struct cgroup_subsys_state___235 *);
	void (*css_reset)(struct cgroup_subsys_state___235 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___235 *, int);
	int (*css_extra_stat_show)(struct seq_file___318 *, struct cgroup_subsys_state___235 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___377 *);
	void (*cancel_fork)(struct task_struct___377 *);
	void (*fork)(struct task_struct___377 *);
	void (*exit)(struct task_struct___377 *);
	void (*free)(struct task_struct___377 *);
	void (*bind)(struct cgroup_subsys_state___235 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___235 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___235 *dfl_cftypes;
	struct cftype___235 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___235 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___235 *updated_children;
	struct cgroup___235 *updated_next;
};

struct cgroup_root___235 {
	struct kernfs_root___369 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___235 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___235 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___235 *ss;
	struct list_head node;
	struct kernfs_ops___369 *kf_ops;
	int (*open)(struct kernfs_open_file___369 *);
	void (*release)(struct kernfs_open_file___369 *);
	u64 (*read_u64)(struct cgroup_subsys_state___235 *, struct cftype___235 *);
	s64 (*read_s64)(struct cgroup_subsys_state___235 *, struct cftype___235 *);
	int (*seq_show)(struct seq_file___318 *, void *);
	void * (*seq_start)(struct seq_file___318 *, loff_t *);
	void * (*seq_next)(struct seq_file___318 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___318 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___235 *, struct cftype___235 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___235 *, struct cftype___235 *, s64);
	ssize_t (*write)(struct kernfs_open_file___369 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___369 *, struct poll_table_struct___226 *);
};

struct xdp_rxq_info___44 {
	struct net_device___46 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___44 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___46 *dev_rx;
};

struct netlink_callback___45 {
	struct sk_buff___46 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___45 *);
	int (*dump)(struct sk_buff___46 *, struct netlink_callback___45 *);
	int (*done)(struct netlink_callback___45 *);
	void *data;
	struct module___307 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___44 {
	int (*create)(struct sk_buff___46 *, struct net_device___46 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___46 *, unsigned char *);
	int (*cache)(const struct neighbour___2 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___46 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___44 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___44 *, int);
	int poll_owner;
	struct net_device___46 *dev;
	struct sk_buff___46 *gro_list;
	struct sk_buff___46 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___44 {
	struct net_device___46 *dev;
	struct Qdisc___2 *qdisc;
	struct Qdisc___2 *qdisc_sleeping;
	struct kobject___363 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___46 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct netdev_rx_queue___44 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___363 kobj;
	struct net_device___46 *dev;
	long: 64;
	struct xdp_rxq_info___44 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___44)(struct net_device___46 *, struct sk_buff___46 *, struct net_device___46 *);

struct netdev_bpf___44 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___39 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___39 *prog;
			const struct bpf_prog_offload_ops___39 *ops;
		} verifier;
		struct {
			struct bpf_prog___39 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___44 *offmap;
		};
		struct {
			struct xdp_umem *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___44 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___46 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___44 {
	int (*tls_dev_add)(struct net_device___46 *, struct sock *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___46 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___46 *, struct sock *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___44 {
	int (*ndo_init)(struct net_device___46 *);
	void (*ndo_uninit)(struct net_device___46 *);
	int (*ndo_open)(struct net_device___46 *);
	int (*ndo_stop)(struct net_device___46 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___46 *, struct net_device___46 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___46 *, struct net_device___46 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___46 *, struct sk_buff___46 *, struct net_device___46 *, select_queue_fallback_t___44);
	void (*ndo_change_rx_flags)(struct net_device___46 *, int);
	void (*ndo_set_rx_mode)(struct net_device___46 *);
	int (*ndo_set_mac_address)(struct net_device___46 *, void *);
	int (*ndo_validate_addr)(struct net_device___46 *);
	int (*ndo_do_ioctl)(struct net_device___46 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___46 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___46 *, int);
	int (*ndo_neigh_setup)(struct net_device___46 *, struct neigh_parms___3 *);
	void (*ndo_tx_timeout)(struct net_device___46 *);
	void (*ndo_get_stats64)(struct net_device___46 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___46 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___46 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___46 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___46 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___46 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___46 *);
	int (*ndo_netpoll_setup)(struct net_device___46 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___46 *);
	int (*ndo_set_vf_mac)(struct net_device___46 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___46 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___46 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___46 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___46 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___46 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___46 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___46 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___46 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___46 *, int, struct sk_buff___46 *);
	int (*ndo_set_vf_guid)(struct net_device___46 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___46 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___46 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___46 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___46 *, const struct sk_buff___46 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___46 *, struct net_device___46 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___46 *, struct net_device___46 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___46 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___46 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___46 *, struct neighbour___2 *);
	void (*ndo_neigh_destroy)(struct net_device___46 *, struct neighbour___2 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___46 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___46 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___46 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___46 *, struct netlink_callback___45 *, struct net_device___46 *, struct net_device___46 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___46 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___46 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___46 *, u32, u32, struct net_device___46 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___46 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___46 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___46 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___46 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___46 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___46 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___46 *, struct net_device___46 *);
	void (*ndo_dfwd_del_station)(struct net_device___46 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___46 *);
	int (*ndo_set_tx_maxrate)(struct net_device___46 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___46 *);
	int (*ndo_change_proto_down)(struct net_device___46 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___46 *, struct sk_buff___46 *);
	void (*ndo_set_rx_headroom)(struct net_device___46 *, int);
	int (*ndo_bpf)(struct net_device___46 *, struct netdev_bpf___44 *);
	int (*ndo_xdp_xmit)(struct net_device___46 *, int, struct xdp_frame___44 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___46 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___46 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct softnet_data___44 {
	struct list_head poll_list;
	struct sk_buff_head___44 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___44 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___2 *output_queue;
	struct Qdisc___2 **output_queue_tailp;
	struct sk_buff___46 *completion_queue;
	struct sk_buff_head___44 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___44 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___44 input_pkt_queue;
	struct napi_struct___44 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct perf_cpu_context___143;

struct pmu___143 {
	struct list_head entry;
	struct module___307 *module;
	struct device___343 *dev;
	const struct attribute_group___340 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___143 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___143 *);
	void (*pmu_disable)(struct pmu___143 *);
	int (*event_init)(struct perf_event___143 *);
	void (*event_mapped)(struct perf_event___143 *, struct mm_struct___376 *);
	void (*event_unmapped)(struct perf_event___143 *, struct mm_struct___376 *);
	int (*add)(struct perf_event___143 *, int);
	void (*del)(struct perf_event___143 *, int);
	void (*start)(struct perf_event___143 *, int);
	void (*stop)(struct perf_event___143 *, int);
	void (*read)(struct perf_event___143 *);
	void (*start_txn)(struct pmu___143 *, unsigned int);
	int (*commit_txn)(struct pmu___143 *);
	void (*cancel_txn)(struct pmu___143 *);
	int (*event_idx)(struct perf_event___143 *);
	void (*sched_task)(struct perf_event_context___143 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___143 *);
	int (*filter_match)(struct perf_event___143 *);
	int (*check_period)(struct perf_event___143 *, u64);
};

struct perf_cpu_context___143 {
	struct perf_event_context___143 ctx;
	struct perf_event_context___143 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___143 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___143 {
	struct cgroup_subsys_state___235 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___136 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___136 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___136 *);
	struct list_head * (*get_fields)(struct trace_event_call___136 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___136 *);
};

struct trace_event_file___55;

struct trace_event_buffer___47 {
	struct ring_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___55 *trace_file;
	void *entry;
	long unsigned int flags;
	int pc;
};

struct trace_event_file___55 {
	struct list_head list;
	struct trace_event_call___136 *event_call;
	struct event_filter *filter;
	struct dentry___375 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_mdio_access {
	struct trace_entry ent;
	char busid[61];
	char read;
	u8 addr;
	u16 val;
	unsigned int regnum;
	char __data[0];
};

struct trace_event_data_offsets_mdio_access {};

struct mdio_driver {
	struct mdio_driver_common___5 mdiodrv;
	int (*probe)(struct mdio_device___5 *);
	void (*remove)(struct mdio_device___5 *);
};

struct fixed_phy_status {
	int link;
	int speed;
	int duplex;
	int pause;
	int asym_pause;
};

struct swmii_regs {
	u16 bmcr;
	u16 bmsr;
	u16 lpa;
	u16 lpagb;
};

enum {
	SWMII_SPEED_10 = 0,
	SWMII_SPEED_100 = 1,
	SWMII_SPEED_1000 = 2,
	SWMII_DUPLEX_HALF = 0,
	SWMII_DUPLEX_FULL = 1,
};

struct led_trigger___4;

struct led_classdev___4 {
	const char *name;
	enum led_brightness brightness;
	enum led_brightness max_brightness;
	int flags;
	long unsigned int work_flags;
	void (*brightness_set)(struct led_classdev___4 *, enum led_brightness);
	int (*brightness_set_blocking)(struct led_classdev___4 *, enum led_brightness);
	enum led_brightness (*brightness_get)(struct led_classdev___4 *);
	int (*blink_set)(struct led_classdev___4 *, long unsigned int *, long unsigned int *);
	int (*pattern_set)(struct led_classdev___4 *, struct led_pattern *, u32, int);
	int (*pattern_clear)(struct led_classdev___4 *);
	struct device___343 *dev;
	const struct attribute_group___340 **groups;
	struct list_head node;
	const char *default_trigger;
	long unsigned int blink_delay_on;
	long unsigned int blink_delay_off;
	struct timer_list blink_timer;
	int blink_brightness;
	int new_blink_brightness;
	void (*flash_resume)(struct led_classdev___4 *);
	struct work_struct set_brightness_work;
	int delayed_set_value;
	struct rw_semaphore___377 trigger_lock;
	struct led_trigger___4 *trigger;
	struct list_head trig_list;
	void *trigger_data;
	bool activated;
	struct mutex led_access;
};

struct led_trigger___4 {
	const char *name;
	void (*activate)(struct led_classdev___4 *);
	void (*deactivate)(struct led_classdev___4 *);
	rwlock_t leddev_list_lock;
	struct list_head led_cdevs;
	struct list_head next_trig;
};

struct phy_led_trigger {
	struct led_trigger___4 trigger;
	char name[75];
	unsigned int speed;
};

struct module___308;

struct file___377;

struct kiocb___377;

struct vm_area_struct___378;

struct inode___377;

struct file_lock___377;

struct page___378;

struct pipe_inode_info___79;

struct seq_file___319;

struct file_operations___377 {
	struct module___308 *owner;
	loff_t (*llseek)(struct file___377 *, loff_t, int);
	ssize_t (*read)(struct file___377 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___377 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___377 *, struct iov_iter___2 *);
	ssize_t (*write_iter)(struct kiocb___377 *, struct iov_iter___2 *);
	int (*iopoll)(struct kiocb___377 *, bool);
	int (*iterate)(struct file___377 *, struct dir_context *);
	int (*iterate_shared)(struct file___377 *, struct dir_context *);
	__poll_t (*poll)(struct file___377 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___377 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___377 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___377 *, struct vm_area_struct___378 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___377 *, struct file___377 *);
	int (*flush)(struct file___377 *, fl_owner_t);
	int (*release)(struct inode___377 *, struct file___377 *);
	int (*fsync)(struct file___377 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___377 *, int);
	int (*lock)(struct file___377 *, int, struct file_lock___377 *);
	ssize_t (*sendpage)(struct file___377 *, struct page___378 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___377 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___377 *, int, struct file_lock___377 *);
	ssize_t (*splice_write)(struct pipe_inode_info___79 *, struct file___377 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___377 *, loff_t *, struct pipe_inode_info___79 *, size_t, unsigned int);
	int (*setlease)(struct file___377 *, long int, struct file_lock___377 **, void **);
	long int (*fallocate)(struct file___377 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___319 *, struct file___377 *);
	ssize_t (*copy_file_range)(struct file___377 *, loff_t, struct file___377 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___377 *, loff_t, struct file___377 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___377 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___377 {
	u64 seqnum;
	struct vm_area_struct___378 *vmas[4];
};

struct page_frag___377 {
	struct page___378 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___377;

struct cred___346;

struct vm_struct___283;

struct task_struct___378 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___378 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___377 *mm;
	struct mm_struct___377 *active_mm;
	struct vmacache___377 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___378 *real_parent;
	struct task_struct___378 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___378 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___219 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___219 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___219 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___346 *ptracer_cred;
	const struct cred___346 *real_cred;
	const struct cred___346 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___378 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___107 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___79 *splice_pipe;
	struct page_frag___377 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___378 *oom_reaper_list;
	struct vm_struct___283 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___143 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___378 *pgtable_t___377;

struct address_space___376;

struct dev_pagemap___365;

struct page___378 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___376 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___378 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___377 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___377 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___365 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___377;

struct lruvec___377 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___377 *pgdat;
};

struct zone___377 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___377 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___377 {
	struct zone___377 *zone;
	int zone_idx;
};

struct zonelist___377 {
	struct zoneref___377 _zonerefs[25];
};

struct pglist_data___377 {
	struct zone___377 node_zones[3];
	struct zonelist___377 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___378 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___378 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___377 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___378 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___378 *owner;
};

struct secondary_data___378 {
	void *stack;
	struct task_struct___378 *task;
	long int status;
};

struct blocking_notifier_head___377 {
	struct rw_semaphore___378 rwsem;
	struct notifier_block *head;
};

struct dentry___376;

struct path___377 {
	struct vfsmount *mnt;
	struct dentry___376 *dentry;
};

struct file___377 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___377 f_path;
	struct inode___377 *f_inode;
	const struct file_operations___377 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___219 f_owner;
	const struct cred___346 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___376 *f_mapping;
	errseq_t f_wb_err;
};

struct key___346;

struct user_struct___346;

struct cred___346 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___346 *session_keyring;
	struct key___346 *process_keyring;
	struct key___346 *thread_keyring;
	struct key___346 *request_key_auth;
	void *security;
	struct user_struct___346 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___370;

struct kernfs_elem_dir___370 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___370 *root;
};

struct kernfs_node___371;

struct kernfs_syscall_ops___370;

struct kernfs_root___370 {
	struct kernfs_node___371 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___370 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___370 {
	struct kernfs_node___371 *target_kn;
};

struct kernfs_ops___370;

struct kernfs_elem_attr___370 {
	const struct kernfs_ops___370 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___371 *notify_next;
};

struct kernfs_node___371 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___371 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___370 dir;
		struct kernfs_elem_symlink___370 symlink;
		struct kernfs_elem_attr___370 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___370;

struct kernfs_ops___370 {
	int (*open)(struct kernfs_open_file___370 *);
	void (*release)(struct kernfs_open_file___370 *);
	int (*seq_show)(struct seq_file___319 *, void *);
	void * (*seq_start)(struct seq_file___319 *, loff_t *);
	void * (*seq_next)(struct seq_file___319 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___319 *, void *);
	ssize_t (*read)(struct kernfs_open_file___370 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___370 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___370 *, struct vm_area_struct___378 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___370 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___370 {
	int (*remount_fs)(struct kernfs_root___370 *, int *, char *);
	int (*show_options)(struct seq_file___319 *, struct kernfs_root___370 *);
	int (*mkdir)(struct kernfs_node___371 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___371 *);
	int (*rename)(struct kernfs_node___371 *, struct kernfs_node___371 *, const char *);
	int (*show_path)(struct seq_file___319 *, struct kernfs_node___371 *, struct kernfs_root___370 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___318;

struct seq_file___319 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___318 *op;
	int poll_event;
	const struct file___377 *file;
	void *private;
};

struct vm_operations_struct___365;

struct kernfs_open_file___370 {
	struct kernfs_node___371 *kn;
	struct file___377 *file;
	struct seq_file___319 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___365 *vm_ops;
};

struct vm_fault___365;

struct vm_operations_struct___365 {
	void (*open)(struct vm_area_struct___378 *);
	void (*close)(struct vm_area_struct___378 *);
	int (*split)(struct vm_area_struct___378 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___378 *);
	vm_fault_t (*fault)(struct vm_fault___365 *);
	vm_fault_t (*huge_fault)(struct vm_fault___365 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___365 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___378 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___365 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___365 *);
	int (*access)(struct vm_area_struct___378 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___378 *);
	int (*set_policy)(struct vm_area_struct___378 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___378 *, long unsigned int);
	struct page___378 * (*find_special_page)(struct vm_area_struct___378 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_area_struct___378 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___378 *vm_next;
	struct vm_area_struct___378 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___377 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___365 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___377 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___364;

struct bin_attribute___340;

struct attribute_group___341 {
	const char *name;
	umode_t (*is_visible)(struct kobject___364 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___364 *, struct bin_attribute___340 *, int);
	struct attribute **attrs;
	struct bin_attribute___340 **bin_attrs;
};

struct kset___363;

struct kobj_type___363;

struct kobject___364 {
	const char *name;
	struct list_head entry;
	struct kobject___364 *parent;
	struct kset___363 *kset;
	struct kobj_type___363 *ktype;
	struct kernfs_node___371 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___340 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___377 *, struct kobject___364 *, struct bin_attribute___340 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___377 *, struct kobject___364 *, struct bin_attribute___340 *, char *, loff_t, size_t);
	int (*mmap)(struct file___377 *, struct kobject___364 *, struct bin_attribute___340 *, struct vm_area_struct___378 *);
};

struct sysfs_ops___363 {
	ssize_t (*show)(struct kobject___364 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___364 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___363;

struct kset___363 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___364 kobj;
	const struct kset_uevent_ops___363 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___363 {
	void (*release)(struct kobject___364 *);
	const struct sysfs_ops___363 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___29 * (*child_ns_type)(struct kobject___364 *);
	const void * (*namespace)(struct kobject___364 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___363 {
	int (* const filter)(struct kset___363 *, struct kobject___364 *);
	const char * (* const name)(struct kset___363 *, struct kobject___364 *);
	int (* const uevent)(struct kset___363 *, struct kobject___364 *, struct kobj_uevent_env *);
};

struct kobj_attribute___355 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___364 *, struct kobj_attribute___355 *, char *);
	ssize_t (*store)(struct kobject___364 *, struct kobj_attribute___355 *, const char *, size_t);
};

struct kernel_param___305;

struct kernel_param_ops___305 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___305 *);
	int (*get)(char *, const struct kernel_param___305 *);
	void (*free)(void *);
};

struct kparam_array___305;

struct kernel_param___305 {
	const char *name;
	struct module___308 *mod;
	const struct kernel_param_ops___305 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___305 *arr;
	};
};

struct kparam_array___305 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___305 *ops;
	void *elem;
};

struct module_kobject___305 {
	struct kobject___364 kobj;
	struct module___308 *mod;
	struct kobject___364 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___305 {
	struct module___308 *mod;
	struct latch_tree_node node;
};

struct module_layout___305 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___305 mtn;
};

struct module_attribute___305;

struct module___308 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___305 mkobj;
	struct module_attribute___305 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___364 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___305 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___305 core_layout;
	struct module_layout___305 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___305 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___305 *, struct module_kobject___305 *, char *);
	ssize_t (*store)(struct module_attribute___305 *, struct module_kobject___305 *, const char *, size_t);
	void (*setup)(struct module___308 *, const char *);
	int (*test)(struct module___308 *);
	void (*free)(struct module___308 *);
};

struct device___344;

struct dev_pm_ops___344 {
	int (*prepare)(struct device___344 *);
	void (*complete)(struct device___344 *);
	int (*suspend)(struct device___344 *);
	int (*resume)(struct device___344 *);
	int (*freeze)(struct device___344 *);
	int (*thaw)(struct device___344 *);
	int (*poweroff)(struct device___344 *);
	int (*restore)(struct device___344 *);
	int (*suspend_late)(struct device___344 *);
	int (*resume_early)(struct device___344 *);
	int (*freeze_late)(struct device___344 *);
	int (*thaw_early)(struct device___344 *);
	int (*poweroff_late)(struct device___344 *);
	int (*restore_early)(struct device___344 *);
	int (*suspend_noirq)(struct device___344 *);
	int (*resume_noirq)(struct device___344 *);
	int (*freeze_noirq)(struct device___344 *);
	int (*thaw_noirq)(struct device___344 *);
	int (*poweroff_noirq)(struct device___344 *);
	int (*restore_noirq)(struct device___344 *);
	int (*runtime_suspend)(struct device___344 *);
	int (*runtime_resume)(struct device___344 *);
	int (*runtime_idle)(struct device___344 *);
};

struct dev_pm_info___344 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___6 *subsys_data;
	void (*set_latency_tolerance)(struct device___344 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___344;

struct bus_type___344;

struct device_driver___344;

struct dev_pm_domain___344;

struct irq_domain___29;

struct dma_map_ops___132;

struct device_node___87;

struct fwnode_handle___266;

struct class___344;

struct device___344 {
	struct device___344 *parent;
	struct device_private *p;
	struct kobject___364 kobj;
	const char *init_name;
	const struct device_type___344 *type;
	struct mutex mutex;
	struct bus_type___344 *bus;
	struct device_driver___344 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___344 power;
	struct dev_pm_domain___344 *pm_domain;
	struct irq_domain___29 *msi_domain;
	struct dev_pin_info___4 *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___132 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___87 *of_node;
	struct fwnode_handle___266 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___344 *class;
	const struct attribute_group___341 **groups;
	void (*release)(struct device___344 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___344 {
	struct dev_pm_ops___344 ops;
	void (*detach)(struct device___344 *, bool);
	int (*activate)(struct device___344 *);
	void (*sync)(struct device___344 *);
	void (*dismiss)(struct device___344 *);
};

struct user_struct___346 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___346 *uid_keyring;
	struct key___346 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___377;

struct mm_struct___377 {
	struct {
		struct vm_area_struct___378 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___377 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___378 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___377 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___378 *owner;
		struct user_namespace___3 *user_ns;
		struct file___377 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___377 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct fasync_struct___376;

struct pipe_buffer___79;

struct pipe_inode_info___79 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___378 *tmp_page;
	struct fasync_struct___376 *fasync_readers;
	struct fasync_struct___376 *fasync_writers;
	struct pipe_buffer___79 *bufs;
	struct user_struct___346 *user;
};

struct vm_struct___283 {
	struct vm_struct___283 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___378 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bus_type___344 {
	const char *name;
	const char *dev_name;
	struct device___344 *dev_root;
	const struct attribute_group___341 **bus_groups;
	const struct attribute_group___341 **dev_groups;
	const struct attribute_group___341 **drv_groups;
	int (*match)(struct device___344 *, struct device_driver___344 *);
	int (*uevent)(struct device___344 *, struct kobj_uevent_env *);
	int (*probe)(struct device___344 *);
	int (*remove)(struct device___344 *);
	void (*shutdown)(struct device___344 *);
	int (*online)(struct device___344 *);
	int (*offline)(struct device___344 *);
	int (*suspend)(struct device___344 *, pm_message_t);
	int (*resume)(struct device___344 *);
	int (*num_vf)(struct device___344 *);
	int (*dma_configure)(struct device___344 *);
	const struct dev_pm_ops___344 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___344 {
	const char *name;
	struct bus_type___344 *bus;
	struct module___308 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___344 *);
	int (*remove)(struct device___344 *);
	void (*shutdown)(struct device___344 *);
	int (*suspend)(struct device___344 *, pm_message_t);
	int (*resume)(struct device___344 *);
	const struct attribute_group___341 **groups;
	const struct dev_pm_ops___344 *pm;
	void (*coredump)(struct device___344 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___344 {
	const char *name;
	const struct attribute_group___341 **groups;
	int (*uevent)(struct device___344 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___344 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___344 *);
	const struct dev_pm_ops___344 *pm;
};

struct class___344 {
	const char *name;
	struct module___308 *owner;
	const struct attribute_group___341 **class_groups;
	const struct attribute_group___341 **dev_groups;
	struct kobject___364 *dev_kobj;
	int (*dev_uevent)(struct device___344 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___344 *, umode_t *);
	void (*class_release)(struct class___344 *);
	void (*dev_release)(struct device___344 *);
	int (*shutdown_pre)(struct device___344 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___344 *);
	const struct dev_pm_ops___344 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct irq_domain_ops___29;

struct irq_domain_chip_generic___17;

struct irq_domain___29 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___29 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___266 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___17 *gc;
	struct irq_domain___29 *parent;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_direct_max_irq;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_tree_mutex;
	unsigned int linear_revmap[0];
};

struct dma_map_ops___132 {
	void * (*alloc)(struct device___344 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___344 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___344 *, struct vm_area_struct___378 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___344 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___344 *, struct page___378 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___344 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___344 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___344 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___344 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___344 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___344 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___344 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___344 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___344 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___344 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___344 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___344 *, u64);
	u64 (*get_required_mask)(struct device___344 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___266;

struct fwnode_handle___266 {
	struct fwnode_handle___266 *secondary;
	const struct fwnode_operations___266 *ops;
};

struct property___83;

struct device_node___87 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___266 fwnode;
	struct property___83 *properties;
	struct property___83 *deadprops;
	struct device_node___87 *parent;
	struct device_node___87 *child;
	struct device_node___87 *sibling;
	struct kobject___364 kobj;
	long unsigned int _flags;
	void *data;
};

struct platform_device___21 {
	const char *name;
	int id;
	bool id_auto;
	struct device___344 dev;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct platform_device_info___5 {
	struct device___344 *parent;
	struct fwnode_handle___266 *fwnode;
	const char *name;
	int id;
	const struct resource *res;
	unsigned int num_res;
	const void *data;
	size_t size_data;
	u64 dma_mask;
	struct property_entry___2 *properties;
};

struct address_space_operations___376;

struct address_space___376 {
	struct inode___377 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___378 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___376 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___365)(struct vm_area_struct___378 *, long unsigned int, const struct page___378 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___365)(struct page___378 *, void *);

struct dev_pagemap___365 {
	dev_page_fault_t___365 page_fault;
	dev_page_free_t___365 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___344 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___377 {
	struct task_struct___378 *task;
	struct core_thread___377 *next;
};

struct core_state___377 {
	atomic_t nr_threads;
	struct core_thread___377 dumper;
	struct completion startup;
};

struct vm_fault___365 {
	struct vm_area_struct___378 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___378 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___378 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___377 prealloc_pte;
};

struct iov_iter___2 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___3 *bvec;
		struct pipe_inode_info___79 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct kiocb___377 {
	struct file___377 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___377 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dentry_operations___376;

struct super_block___376;

struct dentry___376 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___376 *d_parent;
	struct qstr d_name;
	struct inode___377 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___376 *d_op;
	struct super_block___376 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___376;

struct block_device___376;

struct inode___377 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___376 *i_op;
	struct super_block___376 *i_sb;
	struct address_space___376 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___378 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___377 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___376 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___79 *i_pipe;
		struct block_device___376 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___376 {
	int (*d_revalidate)(struct dentry___376 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___376 *, unsigned int);
	int (*d_hash)(const struct dentry___376 *, struct qstr *);
	int (*d_compare)(const struct dentry___376 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___376 *);
	int (*d_init)(struct dentry___376 *);
	void (*d_release)(struct dentry___376 *);
	void (*d_prune)(struct dentry___376 *);
	void (*d_iput)(struct dentry___376 *, struct inode___377 *);
	char * (*d_dname)(struct dentry___376 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___377 *);
	int (*d_manage)(const struct path___377 *, bool);
	struct dentry___376 * (*d_real)(struct dentry___376 *, const struct inode___377 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___376;

struct mem_dqinfo___376 {
	struct quota_format_type___376 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___376;

struct quota_info___376 {
	unsigned int flags;
	struct rw_semaphore___378 dqio_sem;
	struct inode___377 *files[3];
	struct mem_dqinfo___376 info[3];
	const struct quota_format_ops___376 *ops[3];
};

struct rcuwait___376 {
	struct task_struct___378 *task;
};

struct percpu_rw_semaphore___376 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___378 rw_sem;
	struct rcuwait___376 writer;
	int readers_block;
};

struct sb_writers___376 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___376 rw_sem[3];
};

struct file_system_type___376;

struct super_operations___376;

struct dquot_operations___376;

struct quotactl_ops___376;

struct super_block___376 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___376 *s_type;
	const struct super_operations___376 *s_op;
	const struct dquot_operations___376 *dq_op;
	const struct quotactl_ops___376 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___376 *s_root;
	struct rw_semaphore___378 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___376 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___376 s_dquot;
	struct sb_writers___376 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___376 *s_d_op;
	int cleancache_poolid;
	struct shrinker___134 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct iattr___376 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___377 *ia_file;
};

struct dquot___376 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___376 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___376 {
	int qf_fmt_id;
	const struct quota_format_ops___376 *qf_ops;
	struct module___308 *qf_owner;
	struct quota_format_type___376 *qf_next;
};

struct quota_format_ops___376 {
	int (*check_quota_file)(struct super_block___376 *, int);
	int (*read_file_info)(struct super_block___376 *, int);
	int (*write_file_info)(struct super_block___376 *, int);
	int (*free_file_info)(struct super_block___376 *, int);
	int (*read_dqblk)(struct dquot___376 *);
	int (*commit_dqblk)(struct dquot___376 *);
	int (*release_dqblk)(struct dquot___376 *);
	int (*get_next_id)(struct super_block___376 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___376 {
	int (*write_dquot)(struct dquot___376 *);
	struct dquot___376 * (*alloc_dquot)(struct super_block___376 *, int);
	void (*destroy_dquot)(struct dquot___376 *);
	int (*acquire_dquot)(struct dquot___376 *);
	int (*release_dquot)(struct dquot___376 *);
	int (*mark_dirty)(struct dquot___376 *);
	int (*write_info)(struct super_block___376 *, int);
	qsize_t * (*get_reserved_space)(struct inode___377 *);
	int (*get_projid)(struct inode___377 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___377 *, qsize_t *);
	int (*get_next_id)(struct super_block___376 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___376 {
	int (*quota_on)(struct super_block___376 *, int, int, const struct path___377 *);
	int (*quota_off)(struct super_block___376 *, int);
	int (*quota_enable)(struct super_block___376 *, unsigned int);
	int (*quota_disable)(struct super_block___376 *, unsigned int);
	int (*quota_sync)(struct super_block___376 *, int);
	int (*set_info)(struct super_block___376 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___376 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___376 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___376 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___376 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___376 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___376 {
	int (*writepage)(struct page___378 *, struct writeback_control___3 *);
	int (*readpage)(struct file___377 *, struct page___378 *);
	int (*writepages)(struct address_space___376 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___378 *);
	int (*readpages)(struct file___377 *, struct address_space___376 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___377 *, struct address_space___376 *, loff_t, unsigned int, unsigned int, struct page___378 **, void **);
	int (*write_end)(struct file___377 *, struct address_space___376 *, loff_t, unsigned int, unsigned int, struct page___378 *, void *);
	sector_t (*bmap)(struct address_space___376 *, sector_t);
	void (*invalidatepage)(struct page___378 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___378 *, gfp_t);
	void (*freepage)(struct page___378 *);
	ssize_t (*direct_IO)(struct kiocb___377 *, struct iov_iter___2 *);
	int (*migratepage)(struct address_space___376 *, struct page___378 *, struct page___378 *, enum migrate_mode);
	bool (*isolate_page)(struct page___378 *, isolate_mode_t);
	void (*putback_page)(struct page___378 *);
	int (*launder_page)(struct page___378 *);
	int (*is_partially_uptodate)(struct page___378 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___378 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___376 *, struct page___378 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___377 *, sector_t *);
	void (*swap_deactivate)(struct file___377 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___376 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___377 *bd_inode;
	struct super_block___376 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___376 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___376 {
	struct dentry___376 * (*lookup)(struct inode___377 *, struct dentry___376 *, unsigned int);
	const char * (*get_link)(struct dentry___376 *, struct inode___377 *, struct delayed_call *);
	int (*permission)(struct inode___377 *, int);
	struct posix_acl * (*get_acl)(struct inode___377 *, int);
	int (*readlink)(struct dentry___376 *, char *, int);
	int (*create)(struct inode___377 *, struct dentry___376 *, umode_t, bool);
	int (*link)(struct dentry___376 *, struct inode___377 *, struct dentry___376 *);
	int (*unlink)(struct inode___377 *, struct dentry___376 *);
	int (*symlink)(struct inode___377 *, struct dentry___376 *, const char *);
	int (*mkdir)(struct inode___377 *, struct dentry___376 *, umode_t);
	int (*rmdir)(struct inode___377 *, struct dentry___376 *);
	int (*mknod)(struct inode___377 *, struct dentry___376 *, umode_t, dev_t);
	int (*rename)(struct inode___377 *, struct dentry___376 *, struct inode___377 *, struct dentry___376 *, unsigned int);
	int (*setattr)(struct dentry___376 *, struct iattr___376 *);
	int (*getattr)(const struct path___377 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___376 *, char *, size_t);
	int (*fiemap)(struct inode___377 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___377 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___377 *, struct dentry___376 *, struct file___377 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___377 *, struct dentry___376 *, umode_t);
	int (*set_acl)(struct inode___377 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___376 {
	void (*fl_copy_lock)(struct file_lock___377 *, struct file_lock___377 *);
	void (*fl_release_private)(struct file_lock___377 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___376;

struct file_lock___377 {
	struct file_lock___377 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___377 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___376 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___376 *fl_ops;
	const struct lock_manager_operations___376 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___376 {
	int (*lm_compare_owner)(struct file_lock___377 *, struct file_lock___377 *);
	long unsigned int (*lm_owner_key)(struct file_lock___377 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___377 *);
	int (*lm_grant)(struct file_lock___377 *, int);
	bool (*lm_break)(struct file_lock___377 *);
	int (*lm_change)(struct file_lock___377 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___377 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___376 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___376 *fa_next;
	struct file___377 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___376 {
	const char *name;
	int fs_flags;
	struct dentry___376 * (*mount)(struct file_system_type___376 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___376 *);
	struct module___308 *owner;
	struct file_system_type___376 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___376 {
	struct inode___377 * (*alloc_inode)(struct super_block___376 *);
	void (*destroy_inode)(struct inode___377 *);
	void (*dirty_inode)(struct inode___377 *, int);
	int (*write_inode)(struct inode___377 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___377 *);
	void (*evict_inode)(struct inode___377 *);
	void (*put_super)(struct super_block___376 *);
	int (*sync_fs)(struct super_block___376 *, int);
	int (*freeze_super)(struct super_block___376 *);
	int (*freeze_fs)(struct super_block___376 *);
	int (*thaw_super)(struct super_block___376 *);
	int (*unfreeze_fs)(struct super_block___376 *);
	int (*statfs)(struct dentry___376 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___376 *, int *, char *);
	void (*umount_begin)(struct super_block___376 *);
	int (*show_options)(struct seq_file___319 *, struct dentry___376 *);
	int (*show_devname)(struct seq_file___319 *, struct dentry___376 *);
	int (*show_path)(struct seq_file___319 *, struct dentry___376 *);
	int (*show_stats)(struct seq_file___319 *, struct dentry___376 *);
	ssize_t (*quota_read)(struct super_block___376 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___376 *, int, const char *, size_t, loff_t);
	struct dquot___376 ** (*get_dquots)(struct inode___377 *);
	int (*bdev_try_to_free_page)(struct super_block___376 *, struct page___378 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___376 *, struct shrink_control___134 *);
	long int (*free_cached_objects)(struct super_block___376 *, struct shrink_control___134 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___365(struct page___378 *);

struct fwnode_reference_args___266;

struct fwnode_endpoint___266;

struct fwnode_operations___266 {
	struct fwnode_handle___266 * (*get)(struct fwnode_handle___266 *);
	void (*put)(struct fwnode_handle___266 *);
	bool (*device_is_available)(const struct fwnode_handle___266 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___266 *, const struct device___344 *);
	bool (*property_present)(const struct fwnode_handle___266 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___266 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___266 *, const char *, const char **, size_t);
	struct fwnode_handle___266 * (*get_parent)(const struct fwnode_handle___266 *);
	struct fwnode_handle___266 * (*get_next_child_node)(const struct fwnode_handle___266 *, struct fwnode_handle___266 *);
	struct fwnode_handle___266 * (*get_named_child_node)(const struct fwnode_handle___266 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___266 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___266 *);
	struct fwnode_handle___266 * (*graph_get_next_endpoint)(const struct fwnode_handle___266 *, struct fwnode_handle___266 *);
	struct fwnode_handle___266 * (*graph_get_remote_endpoint)(const struct fwnode_handle___266 *);
	struct fwnode_handle___266 * (*graph_get_port_parent)(struct fwnode_handle___266 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___266 *, struct fwnode_endpoint___266 *);
};

struct fwnode_endpoint___266 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___266 *local_fwnode;
};

struct fwnode_reference_args___266 {
	struct fwnode_handle___266 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___79;

struct pipe_buffer___79 {
	struct page___378 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___79 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___79 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___79 *, struct pipe_buffer___79 *);
	void (*release)(struct pipe_inode_info___79 *, struct pipe_buffer___79 *);
	int (*steal)(struct pipe_inode_info___79 *, struct pipe_buffer___79 *);
	union {
		bool (*get)(struct pipe_inode_info___79 *, struct pipe_buffer___79 *);
		struct {
			void (*get)(struct pipe_inode_info___79 *, struct pipe_buffer___79 *);
		} __UNIQUE_ID_rh_kabi_hide21;
		union {		};
	};
};

struct mii_bus___6;

struct mdio_device___6 {
	struct device___344 dev;
	struct mii_bus___6 *bus;
	char modalias[32];
	int (*bus_match)(struct device___344 *, struct device_driver___344 *);
	void (*device_free)(struct mdio_device___6 *);
	void (*device_remove)(struct mdio_device___6 *);
	int addr;
	int flags;
	struct gpio_desc *reset;
	unsigned int reset_assert_delay;
	unsigned int reset_deassert_delay;
};

struct mii_bus___6 {
	struct module___308 *owner;
	const char *name;
	char id[61];
	void *priv;
	int (*read)(struct mii_bus___6 *, int, int);
	int (*write)(struct mii_bus___6 *, int, int, u16);
	int (*reset)(struct mii_bus___6 *);
	struct mutex mdio_lock;
	struct device___344 *parent;
	enum {
		MDIOBUS_ALLOCATED___6 = 1,
		MDIOBUS_REGISTERED___6 = 2,
		MDIOBUS_UNREGISTERED___6 = 3,
		MDIOBUS_RELEASED___6 = 4,
	} state;
	struct device___344 dev;
	struct mdio_device___6 *mdio_map[32];
	u32 phy_mask;
	u32 phy_ignore_ta_mask;
	int irq[32];
	int reset_delay_us;
	struct gpio_desc *reset_gpiod;
};

struct mdio_driver_common___6 {
	struct device_driver___344 driver;
	int flags;
};

struct phy_driver___6;

struct phy_device___6 {
	struct mdio_device___6 mdio;
	struct phy_driver___6 *drv;
	u32 phy_id;
	struct phy_c45_device_ids c45_ids;
	unsigned int is_c45: 1;
	unsigned int is_internal: 1;
	unsigned int is_pseudo_fixed_link: 1;
	unsigned int has_fixups: 1;
	unsigned int suspended: 1;
	unsigned int sysfs_links: 1;
	unsigned int loopback_enabled: 1;
	unsigned int autoneg: 1;
	unsigned int link: 1;
	enum phy_state state;
	u32 dev_flags;
	phy_interface_t interface;
	int speed;
	int duplex;
	int pause;
	int asym_pause;
	u32 interrupts;
	u32 rh_reserved_supported;
	u32 rh_reserved_advertising;
	u32 rh_reserved_lp_advertising;
	u32 eee_broken_modes;
	int link_timeout;
	struct phy_led_trigger *phy_led_triggers;
	unsigned int phy_num_led_triggers;
	struct phy_led_trigger *last_triggered;
	struct phy_led_trigger *led_link_trigger;
	int irq;
	void *priv;
	struct work_struct phy_queue;
	struct delayed_work state_queue;
	struct mutex lock;
	struct phylink *phylink;
	struct net_device *attached_dev;
	u8 mdix;
	u8 mdix_ctrl;
	long unsigned int supported[2];
	long unsigned int advertising[2];
	long unsigned int lp_advertising[2];
	void (*phy_link_change)(struct phy_device___6 *, bool, bool);
	void (*adjust_link)(struct net_device *);
};

struct phy_driver___6 {
	struct mdio_driver_common___6 mdiodrv;
	u32 phy_id;
	char *name;
	u32 phy_id_mask;
	u32 rh_reserved_features;
	u32 flags;
	const void *driver_data;
	const long unsigned int * const features;
	int (*soft_reset)(struct phy_device___6 *);
	int (*config_init)(struct phy_device___6 *);
	int (*probe)(struct phy_device___6 *);
	int (*suspend)(struct phy_device___6 *);
	int (*resume)(struct phy_device___6 *);
	int (*config_aneg)(struct phy_device___6 *);
	int (*aneg_done)(struct phy_device___6 *);
	int (*read_status)(struct phy_device___6 *);
	int (*ack_interrupt)(struct phy_device___6 *);
	int (*config_intr)(struct phy_device___6 *);
	int (*did_interrupt)(struct phy_device___6 *);
	void (*remove)(struct phy_device___6 *);
	int (*match_phy_device)(struct phy_device___6 *);
	int (*ts_info)(struct phy_device___6 *, struct ethtool_ts_info *);
	int (*hwtstamp)(struct phy_device___6 *, struct ifreq *);
	bool (*rxtstamp)(struct phy_device___6 *, struct sk_buff___46 *, int);
	void (*txtstamp)(struct phy_device___6 *, struct sk_buff___46 *, int);
	int (*set_wol)(struct phy_device___6 *, struct ethtool_wolinfo *);
	void (*get_wol)(struct phy_device___6 *, struct ethtool_wolinfo *);
	void (*link_change_notify)(struct phy_device___6 *);
	int (*read_mmd)(struct phy_device___6 *, int, u16);
	int (*write_mmd)(struct phy_device___6 *, int, u16, u16);
	int (*read_page)(struct phy_device___6 *);
	int (*write_page)(struct phy_device___6 *, int);
	int (*module_info)(struct phy_device___6 *, struct ethtool_modinfo *);
	int (*module_eeprom)(struct phy_device___6 *, struct ethtool_eeprom *, u8 *);
	int (*get_sset_count)(struct phy_device___6 *);
	void (*get_strings)(struct phy_device___6 *, u8 *);
	void (*get_stats)(struct phy_device___6 *, struct ethtool_stats *, u64 *);
	int (*get_tunable)(struct phy_device___6 *, struct ethtool_tunable *, void *);
	int (*set_tunable)(struct phy_device___6 *, struct ethtool_tunable *, const void *);
	int (*set_loopback)(struct phy_device___6 *, bool);
};

struct property___83 {
	char *name;
	int length;
	void *value;
	struct property___83 *next;
	long unsigned int _flags;
	struct bin_attribute___340 attr;
};

struct irq_desc___22;

typedef void (*irq_flow_handler_t___22)(struct irq_desc___22 *);

struct irq_chip___29;

struct irq_data___29 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___11 *common;
	struct irq_chip___29 *chip;
	struct irq_domain___29 *domain;
	struct irq_data___29 *parent_data;
	void *chip_data;
};

struct irq_desc___22 {
	struct irq_common_data___11 irq_common_data;
	struct irq_data___29 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___22 handle_irq;
	struct irqaction___11 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int irq_count;
	unsigned int tot_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___364 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___308 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip___29 {
	struct device___344 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___29 *);
	void (*irq_shutdown)(struct irq_data___29 *);
	void (*irq_enable)(struct irq_data___29 *);
	void (*irq_disable)(struct irq_data___29 *);
	void (*irq_ack)(struct irq_data___29 *);
	void (*irq_mask)(struct irq_data___29 *);
	void (*irq_mask_ack)(struct irq_data___29 *);
	void (*irq_unmask)(struct irq_data___29 *);
	void (*irq_eoi)(struct irq_data___29 *);
	int (*irq_set_affinity)(struct irq_data___29 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___29 *);
	int (*irq_set_type)(struct irq_data___29 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___29 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___29 *);
	void (*irq_bus_sync_unlock)(struct irq_data___29 *);
	void (*irq_cpu_online)(struct irq_data___29 *);
	void (*irq_cpu_offline)(struct irq_data___29 *);
	void (*irq_suspend)(struct irq_data___29 *);
	void (*irq_resume)(struct irq_data___29 *);
	void (*irq_pm_shutdown)(struct irq_data___29 *);
	void (*irq_calc_mask)(struct irq_data___29 *);
	void (*irq_print_chip)(struct irq_data___29 *, struct seq_file___319 *);
	int (*irq_request_resources)(struct irq_data___29 *);
	void (*irq_release_resources)(struct irq_data___29 *);
	void (*irq_compose_msi_msg)(struct irq_data___29 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___29 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___29 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___29 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___29 *, void *);
	void (*ipi_send_single)(struct irq_data___29 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___29 *, const struct cpumask *);
	long unsigned int flags;
};

struct irq_chip_type___18 {
	struct irq_chip___29 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___22 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___18 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___18 *);
	void (*resume)(struct irq_chip_generic___18 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___29 *domain;
	struct list_head list;
	struct irq_chip_type___18 chip_types[0];
};

struct irq_domain_chip_generic___17 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___18 *gc[0];
};

struct irq_fwspec___29 {
	struct fwnode_handle___266 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___29 {
	int (*match)(struct irq_domain___29 *, struct device_node___87 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___29 *, struct irq_fwspec___29 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___29 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___29 *, unsigned int);
	int (*xlate)(struct irq_domain___29 *, struct device_node___87 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___29 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___29 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___29 *, struct irq_data___29 *, bool);
	void (*deactivate)(struct irq_domain___29 *, struct irq_data___29 *);
	int (*translate)(struct irq_domain___29 *, struct irq_fwspec___29 *, long unsigned int *, unsigned int *);
};

typedef int (*key_restrict_link_func_t___347)(struct key___346 *, const struct key_type *, const union key_payload *, struct key___346 *);

struct key_restriction___346;

struct key___346 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___378 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___346 *restrict_link;
};

struct key_restriction___346 {
	key_restrict_link_func_t___347 check;
	struct key___346 *key;
	struct key_type *keytype;
};

struct seq_operations___318 {
	void * (*start)(struct seq_file___319 *, loff_t *);
	void (*stop)(struct seq_file___319 *, void *);
	void * (*next)(struct seq_file___319 *, void *, loff_t *);
	int (*show)(struct seq_file___319 *, void *);
};

struct fixed_mdio_bus {
	struct mii_bus___6 *mii_bus;
	struct list_head phys;
};

struct fixed_phy {
	int addr;
	struct phy_device___6 *phydev;
	seqcount_t seqcount;
	struct fixed_phy_status status;
	int (*link_update)(struct net_device *, struct fixed_phy_status *);
	struct list_head node;
	int link_gpio;
};

struct ptp_clock_time {
	__s64 sec;
	__u32 nsec;
	__u32 reserved;
};

struct ptp_extts_request {
	unsigned int index;
	unsigned int flags;
	unsigned int rsv[2];
};

struct ptp_perout_request {
	struct ptp_clock_time start;
	struct ptp_clock_time period;
	unsigned int index;
	unsigned int flags;
	unsigned int rsv[4];
};

enum ptp_pin_function {
	PTP_PF_NONE = 0,
	PTP_PF_EXTTS = 1,
	PTP_PF_PEROUT = 2,
	PTP_PF_PHYSYNC = 3,
};

struct ptp_pin_desc {
	char name[64];
	unsigned int index;
	unsigned int func;
	unsigned int chan;
	unsigned int rsv[5];
};

struct ptp_clock_request {
	enum {
		PTP_CLK_REQ_EXTTS = 0,
		PTP_CLK_REQ_PEROUT = 1,
		PTP_CLK_REQ_PPS = 2,
	} type;
	union {
		struct ptp_extts_request extts;
		struct ptp_perout_request perout;
	};
};

struct ptp_system_timestamp {
	struct timespec64 pre_ts;
	struct timespec64 post_ts;
};

struct ptp_clock_info {
	struct module___11 *owner;
	char name[16];
	s32 max_adj;
	int n_alarm;
	int n_ext_ts;
	int n_per_out;
	int n_pins;
	int pps;
	struct ptp_pin_desc *pin_config;
	int (*adjfine)(struct ptp_clock_info *, long int);
	int (*adjfreq)(struct ptp_clock_info *, s32);
	int (*adjtime)(struct ptp_clock_info *, s64);
	int (*gettime64)(struct ptp_clock_info *, struct timespec64 *);
	int (*gettimex64)(struct ptp_clock_info *, struct timespec64 *, struct ptp_system_timestamp *);
	int (*getcrosststamp)(struct ptp_clock_info *, struct system_device_crosststamp *);
	int (*settime64)(struct ptp_clock_info *, const struct timespec64 *);
	int (*enable)(struct ptp_clock_info *, struct ptp_clock_request *, int);
	int (*verify)(struct ptp_clock_info *, unsigned int, enum ptp_pin_function, unsigned int);
	long int (*do_aux_work)(struct ptp_clock_info *);
};

struct ptp_clock;

struct cavium_ptp {
	struct pci_dev___8 *pdev;
	spinlock_t spin_lock;
	struct cyclecounter cycle_counter;
	struct timecounter time_counter;
	void *reg_base;
	u32 clock_rate;
	struct ptp_clock_info ptp_info;
	struct ptp_clock *ptp_clock;
};

struct module___309;

struct file___378;

struct kiocb___378;

struct poll_table_struct___227;

struct vm_area_struct___379;

struct inode___378;

struct file_lock___378;

struct page___379;

struct seq_file___320;

struct file_operations___378 {
	struct module___309 *owner;
	loff_t (*llseek)(struct file___378 *, loff_t, int);
	ssize_t (*read)(struct file___378 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___378 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___378 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___378 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___378 *, bool);
	int (*iterate)(struct file___378 *, struct dir_context *);
	int (*iterate_shared)(struct file___378 *, struct dir_context *);
	__poll_t (*poll)(struct file___378 *, struct poll_table_struct___227 *);
	long int (*unlocked_ioctl)(struct file___378 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___378 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___378 *, struct vm_area_struct___379 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___378 *, struct file___378 *);
	int (*flush)(struct file___378 *, fl_owner_t);
	int (*release)(struct inode___378 *, struct file___378 *);
	int (*fsync)(struct file___378 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___378 *, int);
	int (*lock)(struct file___378 *, int, struct file_lock___378 *);
	ssize_t (*sendpage)(struct file___378 *, struct page___379 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___378 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___378 *, int, struct file_lock___378 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___378 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___378 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___378 *, long int, struct file_lock___378 **, void **);
	long int (*fallocate)(struct file___378 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___320 *, struct file___378 *);
	ssize_t (*copy_file_range)(struct file___378 *, loff_t, struct file___378 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___378 *, loff_t, struct file___378 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___378 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___378 {
	u64 seqnum;
	struct vm_area_struct___379 *vmas[4];
};

struct page_frag___378 {
	struct page___379 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___378;

struct cred___347;

struct vm_struct___284;

struct task_struct___379 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___379 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___378 *mm;
	struct mm_struct___378 *active_mm;
	struct vmacache___378 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___379 *real_parent;
	struct task_struct___379 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___379 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___219 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___219 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___219 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___347 *ptracer_cred;
	const struct cred___347 *real_cred;
	const struct cred___347 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___379 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___107 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___378 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___379 *oom_reaper_list;
	struct vm_struct___284 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___143 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___379 *pgtable_t___378;

struct address_space___377;

struct dev_pagemap___366;

struct page___379 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___377 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___379 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___378 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___378 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___366 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___378;

struct lruvec___378 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___378 *pgdat;
};

struct zone___378 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___378 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___378 {
	struct zone___378 *zone;
	int zone_idx;
};

struct zonelist___378 {
	struct zoneref___378 _zonerefs[25];
};

struct pglist_data___378 {
	struct zone___378 node_zones[3];
	struct zonelist___378 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___379 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___379 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___378 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___379 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___379 *owner;
};

struct secondary_data___379 {
	void *stack;
	struct task_struct___379 *task;
	long int status;
};

struct blocking_notifier_head___378 {
	struct rw_semaphore___379 rwsem;
	struct notifier_block *head;
};

struct dentry___377;

struct path___378 {
	struct vfsmount *mnt;
	struct dentry___377 *dentry;
};

struct file___378 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___378 f_path;
	struct inode___378 *f_inode;
	const struct file_operations___378 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___219 f_owner;
	const struct cred___347 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___377 *f_mapping;
	errseq_t f_wb_err;
};

struct key___347;

struct user_struct___347;

struct cred___347 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___347 *session_keyring;
	struct key___347 *process_keyring;
	struct key___347 *thread_keyring;
	struct key___347 *request_key_auth;
	void *security;
	struct user_struct___347 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___371;

struct kernfs_elem_dir___371 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___371 *root;
};

struct kernfs_node___372;

struct kernfs_syscall_ops___371;

struct kernfs_root___371 {
	struct kernfs_node___372 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___371 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___371 {
	struct kernfs_node___372 *target_kn;
};

struct kernfs_ops___371;

struct kernfs_elem_attr___371 {
	const struct kernfs_ops___371 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___372 *notify_next;
};

struct kernfs_node___372 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___372 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___371 dir;
		struct kernfs_elem_symlink___371 symlink;
		struct kernfs_elem_attr___371 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___371;

struct kernfs_ops___371 {
	int (*open)(struct kernfs_open_file___371 *);
	void (*release)(struct kernfs_open_file___371 *);
	int (*seq_show)(struct seq_file___320 *, void *);
	void * (*seq_start)(struct seq_file___320 *, loff_t *);
	void * (*seq_next)(struct seq_file___320 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___320 *, void *);
	ssize_t (*read)(struct kernfs_open_file___371 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___371 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___371 *, struct vm_area_struct___379 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___371 *, struct poll_table_struct___227 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___371 {
	int (*remount_fs)(struct kernfs_root___371 *, int *, char *);
	int (*show_options)(struct seq_file___320 *, struct kernfs_root___371 *);
	int (*mkdir)(struct kernfs_node___372 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___372 *);
	int (*rename)(struct kernfs_node___372 *, struct kernfs_node___372 *, const char *);
	int (*show_path)(struct seq_file___320 *, struct kernfs_node___372 *, struct kernfs_root___371 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___319;

struct seq_file___320 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___319 *op;
	int poll_event;
	const struct file___378 *file;
	void *private;
};

struct vm_operations_struct___366;

struct kernfs_open_file___371 {
	struct kernfs_node___372 *kn;
	struct file___378 *file;
	struct seq_file___320 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___366 *vm_ops;
};

struct vm_fault___366;

struct vm_operations_struct___366 {
	void (*open)(struct vm_area_struct___379 *);
	void (*close)(struct vm_area_struct___379 *);
	int (*split)(struct vm_area_struct___379 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___379 *);
	vm_fault_t (*fault)(struct vm_fault___366 *);
	vm_fault_t (*huge_fault)(struct vm_fault___366 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___366 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___379 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___366 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___366 *);
	int (*access)(struct vm_area_struct___379 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___379 *);
	int (*set_policy)(struct vm_area_struct___379 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___379 *, long unsigned int);
	struct page___379 * (*find_special_page)(struct vm_area_struct___379 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___233)(struct file___378 *, wait_queue_head_t *, struct poll_table_struct___227 *);

struct poll_table_struct___227 {
	poll_queue_proc___233 _qproc;
	__poll_t _key;
};

struct vm_area_struct___379 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___379 *vm_next;
	struct vm_area_struct___379 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___378 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___366 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___378 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___365;

struct bin_attribute___341;

struct attribute_group___342 {
	const char *name;
	umode_t (*is_visible)(struct kobject___365 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___365 *, struct bin_attribute___341 *, int);
	struct attribute **attrs;
	struct bin_attribute___341 **bin_attrs;
};

struct kset___364;

struct kobj_type___364;

struct kobject___365 {
	const char *name;
	struct list_head entry;
	struct kobject___365 *parent;
	struct kset___364 *kset;
	struct kobj_type___364 *ktype;
	struct kernfs_node___372 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___341 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___378 *, struct kobject___365 *, struct bin_attribute___341 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___378 *, struct kobject___365 *, struct bin_attribute___341 *, char *, loff_t, size_t);
	int (*mmap)(struct file___378 *, struct kobject___365 *, struct bin_attribute___341 *, struct vm_area_struct___379 *);
};

struct sysfs_ops___364 {
	ssize_t (*show)(struct kobject___365 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___365 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___364;

struct kset___364 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___365 kobj;
	const struct kset_uevent_ops___364 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___364 {
	void (*release)(struct kobject___365 *);
	const struct sysfs_ops___364 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___29 * (*child_ns_type)(struct kobject___365 *);
	const void * (*namespace)(struct kobject___365 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___364 {
	int (* const filter)(struct kset___364 *, struct kobject___365 *);
	const char * (* const name)(struct kset___364 *, struct kobject___365 *);
	int (* const uevent)(struct kset___364 *, struct kobject___365 *, struct kobj_uevent_env *);
};

struct kobj_attribute___356 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___365 *, struct kobj_attribute___356 *, char *);
	ssize_t (*store)(struct kobject___365 *, struct kobj_attribute___356 *, const char *, size_t);
};

struct kernel_param___306;

struct kernel_param_ops___306 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___306 *);
	int (*get)(char *, const struct kernel_param___306 *);
	void (*free)(void *);
};

struct kparam_array___306;

struct kernel_param___306 {
	const char *name;
	struct module___309 *mod;
	const struct kernel_param_ops___306 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___306 *arr;
	};
};

struct kparam_array___306 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___306 *ops;
	void *elem;
};

struct module_kobject___306 {
	struct kobject___365 kobj;
	struct module___309 *mod;
	struct kobject___365 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___306 {
	struct module___309 *mod;
	struct latch_tree_node node;
};

struct module_layout___306 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___306 mtn;
};

struct module_attribute___306;

struct module___309 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___306 mkobj;
	struct module_attribute___306 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___365 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___306 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___306 core_layout;
	struct module_layout___306 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___306 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___306 *, struct module_kobject___306 *, char *);
	ssize_t (*store)(struct module_attribute___306 *, struct module_kobject___306 *, const char *, size_t);
	void (*setup)(struct module___309 *, const char *);
	int (*test)(struct module___309 *);
	void (*free)(struct module___309 *);
};

struct usb_device_id {
	__u16 match_flags;
	__u16 idVendor;
	__u16 idProduct;
	__u16 bcdDevice_lo;
	__u16 bcdDevice_hi;
	__u8 bDeviceClass;
	__u8 bDeviceSubClass;
	__u8 bDeviceProtocol;
	__u8 bInterfaceClass;
	__u8 bInterfaceSubClass;
	__u8 bInterfaceProtocol;
	__u8 bInterfaceNumber;
	kernel_ulong_t driver_info;
};

struct device___345;

struct dev_pm_ops___345 {
	int (*prepare)(struct device___345 *);
	void (*complete)(struct device___345 *);
	int (*suspend)(struct device___345 *);
	int (*resume)(struct device___345 *);
	int (*freeze)(struct device___345 *);
	int (*thaw)(struct device___345 *);
	int (*poweroff)(struct device___345 *);
	int (*restore)(struct device___345 *);
	int (*suspend_late)(struct device___345 *);
	int (*resume_early)(struct device___345 *);
	int (*freeze_late)(struct device___345 *);
	int (*thaw_early)(struct device___345 *);
	int (*poweroff_late)(struct device___345 *);
	int (*restore_early)(struct device___345 *);
	int (*suspend_noirq)(struct device___345 *);
	int (*resume_noirq)(struct device___345 *);
	int (*freeze_noirq)(struct device___345 *);
	int (*thaw_noirq)(struct device___345 *);
	int (*poweroff_noirq)(struct device___345 *);
	int (*restore_noirq)(struct device___345 *);
	int (*runtime_suspend)(struct device___345 *);
	int (*runtime_resume)(struct device___345 *);
	int (*runtime_idle)(struct device___345 *);
};

struct dev_pm_info___345 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___6 *subsys_data;
	void (*set_latency_tolerance)(struct device___345 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___345;

struct bus_type___345;

struct device_driver___345;

struct dev_pm_domain___345;

struct dma_map_ops___133;

struct device_node___88;

struct fwnode_handle___267;

struct class___345;

struct device___345 {
	struct device___345 *parent;
	struct device_private *p;
	struct kobject___365 kobj;
	const char *init_name;
	const struct device_type___345 *type;
	struct mutex mutex;
	struct bus_type___345 *bus;
	struct device_driver___345 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___345 power;
	struct dev_pm_domain___345 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___133 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___88 *of_node;
	struct fwnode_handle___267 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___345 *class;
	const struct attribute_group___342 **groups;
	void (*release)(struct device___345 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___345 {
	struct dev_pm_ops___345 ops;
	void (*detach)(struct device___345 *, bool);
	int (*activate)(struct device___345 *);
	void (*sync)(struct device___345 *);
	void (*dismiss)(struct device___345 *);
};

struct user_struct___347 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___347 *uid_keyring;
	struct key___347 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___378;

struct mm_struct___378 {
	struct {
		struct vm_area_struct___379 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___378 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___379 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___378 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___379 *owner;
		struct user_namespace___3 *user_ns;
		struct file___378 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___378 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct vm_struct___284 {
	struct vm_struct___284 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___379 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bus_type___345 {
	const char *name;
	const char *dev_name;
	struct device___345 *dev_root;
	const struct attribute_group___342 **bus_groups;
	const struct attribute_group___342 **dev_groups;
	const struct attribute_group___342 **drv_groups;
	int (*match)(struct device___345 *, struct device_driver___345 *);
	int (*uevent)(struct device___345 *, struct kobj_uevent_env *);
	int (*probe)(struct device___345 *);
	int (*remove)(struct device___345 *);
	void (*shutdown)(struct device___345 *);
	int (*online)(struct device___345 *);
	int (*offline)(struct device___345 *);
	int (*suspend)(struct device___345 *, pm_message_t);
	int (*resume)(struct device___345 *);
	int (*num_vf)(struct device___345 *);
	int (*dma_configure)(struct device___345 *);
	const struct dev_pm_ops___345 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___345 {
	const char *name;
	struct bus_type___345 *bus;
	struct module___309 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___345 *);
	int (*remove)(struct device___345 *);
	void (*shutdown)(struct device___345 *);
	int (*suspend)(struct device___345 *, pm_message_t);
	int (*resume)(struct device___345 *);
	const struct attribute_group___342 **groups;
	const struct dev_pm_ops___345 *pm;
	void (*coredump)(struct device___345 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___345 {
	const char *name;
	const struct attribute_group___342 **groups;
	int (*uevent)(struct device___345 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___345 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___345 *);
	const struct dev_pm_ops___345 *pm;
};

struct class___345 {
	const char *name;
	struct module___309 *owner;
	const struct attribute_group___342 **class_groups;
	const struct attribute_group___342 **dev_groups;
	struct kobject___365 *dev_kobj;
	int (*dev_uevent)(struct device___345 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___345 *, umode_t *);
	void (*class_release)(struct class___345 *);
	void (*dev_release)(struct device___345 *);
	int (*shutdown_pre)(struct device___345 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___345 *);
	const struct dev_pm_ops___345 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___133 {
	void * (*alloc)(struct device___345 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___345 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___345 *, struct vm_area_struct___379 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___345 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___345 *, struct page___379 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___345 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___345 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___345 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___345 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___345 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___345 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___345 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___345 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___345 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___345 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___345 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___345 *, u64);
	u64 (*get_required_mask)(struct device___345 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___267;

struct fwnode_handle___267 {
	struct fwnode_handle___267 *secondary;
	const struct fwnode_operations___267 *ops;
};

struct property___84;

struct device_node___88 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___267 fwnode;
	struct property___84 *properties;
	struct property___84 *deadprops;
	struct device_node___88 *parent;
	struct device_node___88 *child;
	struct device_node___88 *sibling;
	struct kobject___365 kobj;
	long unsigned int _flags;
	void *data;
};

struct usb_descriptor_header {
	__u8 bLength;
	__u8 bDescriptorType;
};

struct usb_device_descriptor {
	__u8 bLength;
	__u8 bDescriptorType;
	__le16 bcdUSB;
	__u8 bDeviceClass;
	__u8 bDeviceSubClass;
	__u8 bDeviceProtocol;
	__u8 bMaxPacketSize0;
	__le16 idVendor;
	__le16 idProduct;
	__le16 bcdDevice;
	__u8 iManufacturer;
	__u8 iProduct;
	__u8 iSerialNumber;
	__u8 bNumConfigurations;
};

struct usb_config_descriptor {
	__u8 bLength;
	__u8 bDescriptorType;
	__le16 wTotalLength;
	__u8 bNumInterfaces;
	__u8 bConfigurationValue;
	__u8 iConfiguration;
	__u8 bmAttributes;
	__u8 bMaxPower;
} __attribute__((packed));

struct usb_interface_descriptor {
	__u8 bLength;
	__u8 bDescriptorType;
	__u8 bInterfaceNumber;
	__u8 bAlternateSetting;
	__u8 bNumEndpoints;
	__u8 bInterfaceClass;
	__u8 bInterfaceSubClass;
	__u8 bInterfaceProtocol;
	__u8 iInterface;
};

struct usb_endpoint_descriptor {
	__u8 bLength;
	__u8 bDescriptorType;
	__u8 bEndpointAddress;
	__u8 bmAttributes;
	__le16 wMaxPacketSize;
	__u8 bInterval;
	__u8 bRefresh;
	__u8 bSynchAddress;
} __attribute__((packed));

struct usb_ssp_isoc_ep_comp_descriptor {
	__u8 bLength;
	__u8 bDescriptorType;
	__le16 wReseved;
	__le32 dwBytesPerInterval;
};

struct usb_ss_ep_comp_descriptor {
	__u8 bLength;
	__u8 bDescriptorType;
	__u8 bMaxBurst;
	__u8 bmAttributes;
	__le16 wBytesPerInterval;
};

struct usb_interface_assoc_descriptor {
	__u8 bLength;
	__u8 bDescriptorType;
	__u8 bFirstInterface;
	__u8 bInterfaceCount;
	__u8 bFunctionClass;
	__u8 bFunctionSubClass;
	__u8 bFunctionProtocol;
	__u8 iFunction;
};

struct usb_bos_descriptor {
	__u8 bLength;
	__u8 bDescriptorType;
	__le16 wTotalLength;
	__u8 bNumDeviceCaps;
} __attribute__((packed));

struct usb_ext_cap_descriptor {
	__u8 bLength;
	__u8 bDescriptorType;
	__u8 bDevCapabilityType;
	__le32 bmAttributes;
} __attribute__((packed));

struct usb_ss_cap_descriptor {
	__u8 bLength;
	__u8 bDescriptorType;
	__u8 bDevCapabilityType;
	__u8 bmAttributes;
	__le16 wSpeedSupported;
	__u8 bFunctionalitySupport;
	__u8 bU1devExitLat;
	__le16 bU2DevExitLat;
};

struct usb_ss_container_id_descriptor {
	__u8 bLength;
	__u8 bDescriptorType;
	__u8 bDevCapabilityType;
	__u8 bReserved;
	__u8 ContainerID[16];
};

struct usb_ssp_cap_descriptor {
	__u8 bLength;
	__u8 bDescriptorType;
	__u8 bDevCapabilityType;
	__u8 bReserved;
	__le32 bmAttributes;
	__le16 wFunctionalitySupport;
	__le16 wReserved;
	__le32 bmSublinkSpeedAttr[1];
};

struct usb_ptm_cap_descriptor {
	__u8 bLength;
	__u8 bDescriptorType;
	__u8 bDevCapabilityType;
};

enum usb_device_speed {
	USB_SPEED_UNKNOWN = 0,
	USB_SPEED_LOW = 1,
	USB_SPEED_FULL = 2,
	USB_SPEED_HIGH = 3,
	USB_SPEED_WIRELESS = 4,
	USB_SPEED_SUPER = 5,
	USB_SPEED_SUPER_PLUS = 6,
};

enum usb_device_state {
	USB_STATE_NOTATTACHED = 0,
	USB_STATE_ATTACHED = 1,
	USB_STATE_POWERED = 2,
	USB_STATE_RECONNECTING = 3,
	USB_STATE_UNAUTHENTICATED = 4,
	USB_STATE_DEFAULT = 5,
	USB_STATE_ADDRESS = 6,
	USB_STATE_CONFIGURED = 7,
	USB_STATE_SUSPENDED = 8,
};

enum usb3_link_state {
	USB3_LPM_U0 = 0,
	USB3_LPM_U1 = 1,
	USB3_LPM_U2 = 2,
	USB3_LPM_U3 = 3,
};

struct dentry_operations___377;

struct super_block___377;

struct dentry___377 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___377 *d_parent;
	struct qstr d_name;
	struct inode___378 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___377 *d_op;
	struct super_block___377 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___377;

struct address_space___377 {
	struct inode___378 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___379 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___377 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___377;

struct block_device___377;

struct cdev___91;

struct inode___378 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___377 *i_op;
	struct super_block___377 *i_sb;
	struct address_space___377 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___379 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___378 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___377 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___377 *i_bdev;
		struct cdev___91 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___377 {
	int (*d_revalidate)(struct dentry___377 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___377 *, unsigned int);
	int (*d_hash)(const struct dentry___377 *, struct qstr *);
	int (*d_compare)(const struct dentry___377 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___377 *);
	int (*d_init)(struct dentry___377 *);
	void (*d_release)(struct dentry___377 *);
	void (*d_prune)(struct dentry___377 *);
	void (*d_iput)(struct dentry___377 *, struct inode___378 *);
	char * (*d_dname)(struct dentry___377 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___378 *);
	int (*d_manage)(const struct path___378 *, bool);
	struct dentry___377 * (*d_real)(struct dentry___377 *, const struct inode___378 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___377;

struct mem_dqinfo___377 {
	struct quota_format_type___377 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___377;

struct quota_info___377 {
	unsigned int flags;
	struct rw_semaphore___379 dqio_sem;
	struct inode___378 *files[3];
	struct mem_dqinfo___377 info[3];
	const struct quota_format_ops___377 *ops[3];
};

struct rcuwait___377 {
	struct task_struct___379 *task;
};

struct percpu_rw_semaphore___377 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___379 rw_sem;
	struct rcuwait___377 writer;
	int readers_block;
};

struct sb_writers___377 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___377 rw_sem[3];
};

struct file_system_type___377;

struct super_operations___377;

struct dquot_operations___377;

struct quotactl_ops___377;

struct super_block___377 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___377 *s_type;
	const struct super_operations___377 *s_op;
	const struct dquot_operations___377 *dq_op;
	const struct quotactl_ops___377 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___377 *s_root;
	struct rw_semaphore___379 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___377 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___377 s_dquot;
	struct sb_writers___377 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___377 *s_d_op;
	int cleancache_poolid;
	struct shrinker___134 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

typedef int (*dev_page_fault_t___366)(struct vm_area_struct___379 *, long unsigned int, const struct page___379 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___366)(struct page___379 *, void *);

struct dev_pagemap___366 {
	dev_page_fault_t___366 page_fault;
	dev_page_free_t___366 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___345 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___378 {
	struct task_struct___379 *task;
	struct core_thread___378 *next;
};

struct core_state___378 {
	atomic_t nr_threads;
	struct core_thread___378 dumper;
	struct completion startup;
};

struct vm_fault___366 {
	struct vm_area_struct___379 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___379 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___379 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___378 prealloc_pte;
};

struct kiocb___378 {
	struct file___378 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___378 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___377 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___378 *ia_file;
};

struct dquot___377 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___377 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___377 {
	int qf_fmt_id;
	const struct quota_format_ops___377 *qf_ops;
	struct module___309 *qf_owner;
	struct quota_format_type___377 *qf_next;
};

struct quota_format_ops___377 {
	int (*check_quota_file)(struct super_block___377 *, int);
	int (*read_file_info)(struct super_block___377 *, int);
	int (*write_file_info)(struct super_block___377 *, int);
	int (*free_file_info)(struct super_block___377 *, int);
	int (*read_dqblk)(struct dquot___377 *);
	int (*commit_dqblk)(struct dquot___377 *);
	int (*release_dqblk)(struct dquot___377 *);
	int (*get_next_id)(struct super_block___377 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___377 {
	int (*write_dquot)(struct dquot___377 *);
	struct dquot___377 * (*alloc_dquot)(struct super_block___377 *, int);
	void (*destroy_dquot)(struct dquot___377 *);
	int (*acquire_dquot)(struct dquot___377 *);
	int (*release_dquot)(struct dquot___377 *);
	int (*mark_dirty)(struct dquot___377 *);
	int (*write_info)(struct super_block___377 *, int);
	qsize_t * (*get_reserved_space)(struct inode___378 *);
	int (*get_projid)(struct inode___378 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___378 *, qsize_t *);
	int (*get_next_id)(struct super_block___377 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___377 {
	int (*quota_on)(struct super_block___377 *, int, int, const struct path___378 *);
	int (*quota_off)(struct super_block___377 *, int);
	int (*quota_enable)(struct super_block___377 *, unsigned int);
	int (*quota_disable)(struct super_block___377 *, unsigned int);
	int (*quota_sync)(struct super_block___377 *, int);
	int (*set_info)(struct super_block___377 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___377 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___377 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___377 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___377 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___377 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___377 {
	int (*writepage)(struct page___379 *, struct writeback_control___3 *);
	int (*readpage)(struct file___378 *, struct page___379 *);
	int (*writepages)(struct address_space___377 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___379 *);
	int (*readpages)(struct file___378 *, struct address_space___377 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___378 *, struct address_space___377 *, loff_t, unsigned int, unsigned int, struct page___379 **, void **);
	int (*write_end)(struct file___378 *, struct address_space___377 *, loff_t, unsigned int, unsigned int, struct page___379 *, void *);
	sector_t (*bmap)(struct address_space___377 *, sector_t);
	void (*invalidatepage)(struct page___379 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___379 *, gfp_t);
	void (*freepage)(struct page___379 *);
	ssize_t (*direct_IO)(struct kiocb___378 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___377 *, struct page___379 *, struct page___379 *, enum migrate_mode);
	bool (*isolate_page)(struct page___379 *, isolate_mode_t);
	void (*putback_page)(struct page___379 *);
	int (*launder_page)(struct page___379 *);
	int (*is_partially_uptodate)(struct page___379 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___379 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___377 *, struct page___379 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___378 *, sector_t *);
	void (*swap_deactivate)(struct file___378 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___377 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___378 *bd_inode;
	struct super_block___377 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___377 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___91 {
	struct kobject___365 kobj;
	struct module___309 *owner;
	const struct file_operations___378 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___377 {
	struct dentry___377 * (*lookup)(struct inode___378 *, struct dentry___377 *, unsigned int);
	const char * (*get_link)(struct dentry___377 *, struct inode___378 *, struct delayed_call *);
	int (*permission)(struct inode___378 *, int);
	struct posix_acl * (*get_acl)(struct inode___378 *, int);
	int (*readlink)(struct dentry___377 *, char *, int);
	int (*create)(struct inode___378 *, struct dentry___377 *, umode_t, bool);
	int (*link)(struct dentry___377 *, struct inode___378 *, struct dentry___377 *);
	int (*unlink)(struct inode___378 *, struct dentry___377 *);
	int (*symlink)(struct inode___378 *, struct dentry___377 *, const char *);
	int (*mkdir)(struct inode___378 *, struct dentry___377 *, umode_t);
	int (*rmdir)(struct inode___378 *, struct dentry___377 *);
	int (*mknod)(struct inode___378 *, struct dentry___377 *, umode_t, dev_t);
	int (*rename)(struct inode___378 *, struct dentry___377 *, struct inode___378 *, struct dentry___377 *, unsigned int);
	int (*setattr)(struct dentry___377 *, struct iattr___377 *);
	int (*getattr)(const struct path___378 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___377 *, char *, size_t);
	int (*fiemap)(struct inode___378 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___378 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___378 *, struct dentry___377 *, struct file___378 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___378 *, struct dentry___377 *, umode_t);
	int (*set_acl)(struct inode___378 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___377 {
	void (*fl_copy_lock)(struct file_lock___378 *, struct file_lock___378 *);
	void (*fl_release_private)(struct file_lock___378 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___377;

struct lock_manager_operations___377;

struct file_lock___378 {
	struct file_lock___378 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___378 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___377 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___377 *fl_ops;
	const struct lock_manager_operations___377 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___377 {
	int (*lm_compare_owner)(struct file_lock___378 *, struct file_lock___378 *);
	long unsigned int (*lm_owner_key)(struct file_lock___378 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___378 *);
	int (*lm_grant)(struct file_lock___378 *, int);
	bool (*lm_break)(struct file_lock___378 *);
	int (*lm_change)(struct file_lock___378 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___378 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___377 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___377 *fa_next;
	struct file___378 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___377 {
	const char *name;
	int fs_flags;
	struct dentry___377 * (*mount)(struct file_system_type___377 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___377 *);
	struct module___309 *owner;
	struct file_system_type___377 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___377 {
	struct inode___378 * (*alloc_inode)(struct super_block___377 *);
	void (*destroy_inode)(struct inode___378 *);
	void (*dirty_inode)(struct inode___378 *, int);
	int (*write_inode)(struct inode___378 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___378 *);
	void (*evict_inode)(struct inode___378 *);
	void (*put_super)(struct super_block___377 *);
	int (*sync_fs)(struct super_block___377 *, int);
	int (*freeze_super)(struct super_block___377 *);
	int (*freeze_fs)(struct super_block___377 *);
	int (*thaw_super)(struct super_block___377 *);
	int (*unfreeze_fs)(struct super_block___377 *);
	int (*statfs)(struct dentry___377 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___377 *, int *, char *);
	void (*umount_begin)(struct super_block___377 *);
	int (*show_options)(struct seq_file___320 *, struct dentry___377 *);
	int (*show_devname)(struct seq_file___320 *, struct dentry___377 *);
	int (*show_path)(struct seq_file___320 *, struct dentry___377 *);
	int (*show_stats)(struct seq_file___320 *, struct dentry___377 *);
	ssize_t (*quota_read)(struct super_block___377 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___377 *, int, const char *, size_t, loff_t);
	struct dquot___377 ** (*get_dquots)(struct inode___378 *);
	int (*bdev_try_to_free_page)(struct super_block___377 *, struct page___379 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___377 *, struct shrink_control___134 *);
	long int (*free_cached_objects)(struct super_block___377 *, struct shrink_control___134 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct ep_device;

struct usb_host_endpoint {
	struct usb_endpoint_descriptor desc;
	struct usb_ss_ep_comp_descriptor ss_ep_comp;
	struct usb_ssp_isoc_ep_comp_descriptor ssp_isoc_ep_comp;
	char: 8;
	struct list_head urb_list;
	void *hcpriv;
	struct ep_device *ep_dev;
	unsigned char *extra;
	int extralen;
	int enabled;
	int streams;
	int: 32;
} __attribute__((packed));

struct usb_host_interface {
	struct usb_interface_descriptor desc;
	int extralen;
	unsigned char *extra;
	struct usb_host_endpoint *endpoint;
	char *string;
};

enum usb_interface_condition {
	USB_INTERFACE_UNBOUND = 0,
	USB_INTERFACE_BINDING = 1,
	USB_INTERFACE_BOUND = 2,
	USB_INTERFACE_UNBINDING = 3,
};

struct usb_interface {
	struct usb_host_interface *altsetting;
	struct usb_host_interface *cur_altsetting;
	unsigned int num_altsetting;
	struct usb_interface_assoc_descriptor *intf_assoc;
	int minor;
	enum usb_interface_condition condition;
	unsigned int sysfs_files_created: 1;
	unsigned int ep_devs_created: 1;
	unsigned int unregistering: 1;
	unsigned int needs_remote_wakeup: 1;
	unsigned int needs_altsetting0: 1;
	unsigned int needs_binding: 1;
	unsigned int resetting_device: 1;
	unsigned int authorized: 1;
	struct device___345 dev;
	struct device___345 *usb_dev;
	atomic_t pm_usage_cnt;
	struct work_struct reset_ws;
};

struct usb_interface_cache {
	unsigned int num_altsetting;
	struct kref ref;
	struct usb_host_interface altsetting[0];
};

struct usb_host_config {
	struct usb_config_descriptor desc;
	char *string;
	struct usb_interface_assoc_descriptor *intf_assoc[16];
	struct usb_interface *interface[32];
	struct usb_interface_cache *intf_cache[32];
	unsigned char *extra;
	int extralen;
};

struct usb_host_bos {
	struct usb_bos_descriptor *desc;
	struct usb_ext_cap_descriptor *ext_cap;
	struct usb_ss_cap_descriptor *ss_cap;
	struct usb_ssp_cap_descriptor *ssp_cap;
	struct usb_ss_container_id_descriptor *ss_id;
	struct usb_ptm_cap_descriptor *ptm_cap;
};

struct usb_devmap {
	long unsigned int devicemap[2];
};

struct usb_device;

struct mon_bus;

struct usb_bus {
	struct device___345 *controller;
	struct device___345 *sysdev;
	int busnum;
	const char *bus_name;
	u8 uses_dma;
	u8 uses_pio_for_control;
	u8 otg_port;
	unsigned int is_b_host: 1;
	unsigned int b_hnp_enable: 1;
	unsigned int no_stop_on_short: 1;
	unsigned int no_sg_constraint: 1;
	unsigned int sg_tablesize;
	int devnum_next;
	struct mutex devnum_next_mutex;
	struct usb_devmap devmap;
	struct usb_device *root_hub;
	struct usb_bus *hs_companion;
	int bandwidth_allocated;
	int bandwidth_int_reqs;
	int bandwidth_isoc_reqs;
	unsigned int resuming_ports;
	struct mon_bus *mon_bus;
	int monitored;
};

struct wusb_dev;

enum usb_device_removable {
	USB_DEVICE_REMOVABLE_UNKNOWN = 0,
	USB_DEVICE_REMOVABLE = 1,
	USB_DEVICE_FIXED = 2,
};

struct usb2_lpm_parameters {
	unsigned int besl;
	int timeout;
};

struct usb3_lpm_parameters {
	unsigned int mel;
	unsigned int pel;
	unsigned int sel;
	int timeout;
};

struct usb_tt;

struct usb_device {
	int devnum;
	char devpath[16];
	u32 route;
	enum usb_device_state state;
	enum usb_device_speed speed;
	unsigned int rx_lanes;
	unsigned int tx_lanes;
	struct usb_tt *tt;
	int ttport;
	unsigned int toggle[2];
	struct usb_device *parent;
	struct usb_bus *bus;
	struct usb_host_endpoint ep0;
	struct device___345 dev;
	struct usb_device_descriptor descriptor;
	struct usb_host_bos *bos;
	struct usb_host_config *config;
	struct usb_host_config *actconfig;
	struct usb_host_endpoint *ep_in[16];
	struct usb_host_endpoint *ep_out[16];
	char **rawdescriptors;
	short unsigned int bus_mA;
	u8 portnum;
	u8 level;
	unsigned int can_submit: 1;
	unsigned int persist_enabled: 1;
	unsigned int have_langid: 1;
	unsigned int authorized: 1;
	unsigned int authenticated: 1;
	unsigned int wusb: 1;
	unsigned int lpm_capable: 1;
	unsigned int usb2_hw_lpm_capable: 1;
	unsigned int usb2_hw_lpm_besl_capable: 1;
	unsigned int usb2_hw_lpm_enabled: 1;
	unsigned int usb2_hw_lpm_allowed: 1;
	unsigned int usb3_lpm_u1_enabled: 1;
	unsigned int usb3_lpm_u2_enabled: 1;
	int string_langid;
	char *product;
	char *manufacturer;
	char *serial;
	struct list_head filelist;
	int maxchild;
	u32 quirks;
	atomic_t urbnum;
	long unsigned int active_duration;
	long unsigned int connect_time;
	unsigned int do_remote_wakeup: 1;
	unsigned int reset_resume: 1;
	unsigned int port_is_suspended: 1;
	struct wusb_dev *wusb_dev;
	int slot_id;
	enum usb_device_removable removable;
	struct usb2_lpm_parameters l1_params;
	struct usb3_lpm_parameters u1_params;
	struct usb3_lpm_parameters u2_params;
	unsigned int lpm_disable_count;
	u16 hub_delay;
};

struct usb_tt {
	struct usb_device *hub;
	int multi;
	unsigned int think_time;
	void *hcpriv;
	spinlock_t lock;
	struct list_head clear_list;
	struct work_struct clear_work;
};

struct usb_dynids {
	spinlock_t lock;
	struct list_head list;
};

struct usbdrv_wrap {
	struct device_driver___345 driver;
	int for_devices;
};

struct usb_driver {
	const char *name;
	int (*probe)(struct usb_interface *, const struct usb_device_id *);
	void (*disconnect)(struct usb_interface *);
	int (*unlocked_ioctl)(struct usb_interface *, unsigned int, void *);
	int (*suspend)(struct usb_interface *, pm_message_t);
	int (*resume)(struct usb_interface *);
	int (*reset_resume)(struct usb_interface *);
	int (*pre_reset)(struct usb_interface *);
	int (*post_reset)(struct usb_interface *);
	const struct usb_device_id *id_table;
	struct usb_dynids dynids;
	struct usbdrv_wrap drvwrap;
	unsigned int no_dynamic_id: 1;
	unsigned int supports_autosuspend: 1;
	unsigned int disable_hub_initiated_lpm: 1;
	unsigned int soft_unbind: 1;
};

struct usb_device_driver {
	const char *name;
	int (*probe)(struct usb_device *);
	void (*disconnect)(struct usb_device *);
	int (*suspend)(struct usb_device *, pm_message_t);
	int (*resume)(struct usb_device *, pm_message_t);
	struct usbdrv_wrap drvwrap;
	unsigned int supports_autosuspend: 1;
};

struct usb_iso_packet_descriptor {
	unsigned int offset;
	unsigned int length;
	unsigned int actual_length;
	int status;
};

struct usb_anchor {
	struct list_head urb_list;
	wait_queue_head_t wait;
	spinlock_t lock;
	atomic_t suspend_wakeups;
	unsigned int poisoned: 1;
};

struct urb;

typedef void (*usb_complete_t)(struct urb *);

struct urb {
	struct kref kref;
	void *hcpriv;
	atomic_t use_count;
	atomic_t reject;
	int unlinked;
	struct list_head urb_list;
	struct list_head anchor_list;
	struct usb_anchor *anchor;
	struct usb_device *dev;
	struct usb_host_endpoint *ep;
	unsigned int pipe;
	unsigned int stream_id;
	int status;
	unsigned int transfer_flags;
	void *transfer_buffer;
	dma_addr_t transfer_dma;
	struct scatterlist *sg;
	int num_mapped_sgs;
	int num_sgs;
	u32 transfer_buffer_length;
	u32 actual_length;
	unsigned char *setup_packet;
	dma_addr_t setup_dma;
	int start_frame;
	int number_of_packets;
	int interval;
	int error_count;
	void *context;
	usb_complete_t complete;
	struct usb_iso_packet_descriptor iso_frame_desc[0];
};

struct giveback_urb_bh {
	bool running;
	spinlock_t lock;
	struct list_head head;
	struct tasklet_struct bh;
	struct usb_host_endpoint *completing_ep;
};

struct usb_phy_roothub;

struct dma_pool___2;

struct hc_driver;

struct usb_phy;

struct usb_hcd {
	struct usb_bus self;
	struct kref kref;
	const char *product_desc;
	int speed;
	char irq_descr[24];
	struct timer_list rh_timer;
	struct urb *status_urb;
	struct work_struct wakeup_work;
	const struct hc_driver *driver;
	struct usb_phy *usb_phy;
	struct usb_phy_roothub *phy_roothub;
	long unsigned int flags;
	unsigned int rh_registered: 1;
	unsigned int rh_pollable: 1;
	unsigned int msix_enabled: 1;
	unsigned int msi_enabled: 1;
	unsigned int skip_phy_initialization: 1;
	unsigned int uses_new_polling: 1;
	unsigned int wireless: 1;
	unsigned int has_tt: 1;
	unsigned int amd_resume_bug: 1;
	unsigned int can_do_streams: 1;
	unsigned int tpl_support: 1;
	unsigned int cant_recv_wakeups: 1;
	unsigned int irq;
	void *regs;
	resource_size_t rsrc_start;
	resource_size_t rsrc_len;
	unsigned int power_budget;
	struct giveback_urb_bh high_prio_bh;
	struct giveback_urb_bh low_prio_bh;
	struct mutex *address0_mutex;
	struct mutex *bandwidth_mutex;
	struct usb_hcd *shared_hcd;
	struct usb_hcd *primary_hcd;
	struct dma_pool___2 *pool[4];
	int state;
	long unsigned int hcd_priv[0];
};

struct hc_driver {
	const char *description;
	const char *product_desc;
	size_t hcd_priv_size;
	irqreturn_t (*irq)(struct usb_hcd *);
	int flags;
	int (*reset)(struct usb_hcd *);
	int (*start)(struct usb_hcd *);
	int (*pci_suspend)(struct usb_hcd *, bool);
	int (*pci_resume)(struct usb_hcd *, bool);
	void (*stop)(struct usb_hcd *);
	void (*shutdown)(struct usb_hcd *);
	int (*get_frame_number)(struct usb_hcd *);
	int (*urb_enqueue)(struct usb_hcd *, struct urb *, gfp_t);
	int (*urb_dequeue)(struct usb_hcd *, struct urb *, int);
	int (*map_urb_for_dma)(struct usb_hcd *, struct urb *, gfp_t);
	void (*unmap_urb_for_dma)(struct usb_hcd *, struct urb *);
	void (*endpoint_disable)(struct usb_hcd *, struct usb_host_endpoint *);
	void (*endpoint_reset)(struct usb_hcd *, struct usb_host_endpoint *);
	int (*hub_status_data)(struct usb_hcd *, char *);
	int (*hub_control)(struct usb_hcd *, u16, u16, u16, char *, u16);
	int (*bus_suspend)(struct usb_hcd *);
	int (*bus_resume)(struct usb_hcd *);
	int (*start_port_reset)(struct usb_hcd *, unsigned int);
	long unsigned int (*get_resuming_ports)(struct usb_hcd *);
	void (*relinquish_port)(struct usb_hcd *, int);
	int (*port_handed_over)(struct usb_hcd *, int);
	void (*clear_tt_buffer_complete)(struct usb_hcd *, struct usb_host_endpoint *);
	int (*alloc_dev)(struct usb_hcd *, struct usb_device *);
	void (*free_dev)(struct usb_hcd *, struct usb_device *);
	int (*alloc_streams)(struct usb_hcd *, struct usb_device *, struct usb_host_endpoint **, unsigned int, unsigned int, gfp_t);
	int (*free_streams)(struct usb_hcd *, struct usb_device *, struct usb_host_endpoint **, unsigned int, gfp_t);
	int (*add_endpoint)(struct usb_hcd *, struct usb_device *, struct usb_host_endpoint *);
	int (*drop_endpoint)(struct usb_hcd *, struct usb_device *, struct usb_host_endpoint *);
	int (*check_bandwidth)(struct usb_hcd *, struct usb_device *);
	void (*reset_bandwidth)(struct usb_hcd *, struct usb_device *);
	int (*address_device)(struct usb_hcd *, struct usb_device *);
	int (*enable_device)(struct usb_hcd *, struct usb_device *);
	int (*update_hub_device)(struct usb_hcd *, struct usb_device *, struct usb_tt *, gfp_t);
	int (*reset_device)(struct usb_hcd *, struct usb_device *);
	int (*update_device)(struct usb_hcd *, struct usb_device *);
	int (*set_usb2_hw_lpm)(struct usb_hcd *, struct usb_device *, int);
	int (*enable_usb3_lpm_timeout)(struct usb_hcd *, struct usb_device *, enum usb3_link_state);
	int (*disable_usb3_lpm_timeout)(struct usb_hcd *, struct usb_device *, enum usb3_link_state);
	int (*find_raw_port_number)(struct usb_hcd *, int);
	int (*port_power)(struct usb_hcd *, int, bool);
};

enum usb_phy_type {
	USB_PHY_TYPE_UNDEFINED = 0,
	USB_PHY_TYPE_USB2 = 1,
	USB_PHY_TYPE_USB3 = 2,
};

enum usb_phy_events {
	USB_EVENT_NONE = 0,
	USB_EVENT_VBUS = 1,
	USB_EVENT_ID = 2,
	USB_EVENT_CHARGER = 3,
	USB_EVENT_ENUMERATED = 4,
};

enum usb_charger_type {
	UNKNOWN_TYPE = 0,
	SDP_TYPE = 1,
	DCP_TYPE = 2,
	CDP_TYPE = 3,
	ACA_TYPE = 4,
};

enum usb_charger_state {
	USB_CHARGER_DEFAULT = 0,
	USB_CHARGER_PRESENT = 1,
	USB_CHARGER_ABSENT = 2,
};

struct usb_charger_current {
	unsigned int sdp_min;
	unsigned int sdp_max;
	unsigned int dcp_min;
	unsigned int dcp_max;
	unsigned int cdp_min;
	unsigned int cdp_max;
	unsigned int aca_min;
	unsigned int aca_max;
};

struct usb_otg;

struct usb_phy_io_ops;

struct usb_phy {
	struct device___345 *dev;
	const char *label;
	unsigned int flags;
	enum usb_phy_type type;
	enum usb_phy_events last_event;
	struct usb_otg *otg;
	struct device___345 *io_dev;
	struct usb_phy_io_ops *io_ops;
	void *io_priv;
	struct extcon_dev *edev;
	struct extcon_dev *id_edev;
	struct notifier_block vbus_nb;
	struct notifier_block id_nb;
	struct notifier_block type_nb;
	enum usb_charger_type chg_type;
	enum usb_charger_state chg_state;
	struct usb_charger_current chg_cur;
	struct work_struct chg_work;
	struct atomic_notifier_head notifier;
	u16 port_status;
	u16 port_change;
	struct list_head head;
	int (*init)(struct usb_phy *);
	void (*shutdown)(struct usb_phy *);
	int (*set_vbus)(struct usb_phy *, int);
	int (*set_power)(struct usb_phy *, unsigned int);
	int (*set_suspend)(struct usb_phy *, int);
	int (*set_wakeup)(struct usb_phy *, bool);
	int (*notify_connect)(struct usb_phy *, enum usb_device_speed);
	int (*notify_disconnect)(struct usb_phy *, enum usb_device_speed);
	enum usb_charger_type (*charger_detect)(struct usb_phy *);
};

struct usb_mon_operations {
	void (*urb_submit)(struct usb_bus *, struct urb *);
	void (*urb_submit_error)(struct usb_bus *, struct urb *, int);
	void (*urb_complete)(struct usb_bus *, struct urb *, int);
};

typedef int (*key_restrict_link_func_t___348)(struct key___347 *, const struct key_type *, const union key_payload *, struct key___347 *);

struct key_restriction___347;

struct key___347 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___379 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___347 *restrict_link;
};

struct key_restriction___347 {
	key_restrict_link_func_t___348 check;
	struct key___347 *key;
	struct key_type *keytype;
};

struct seq_operations___319 {
	void * (*start)(struct seq_file___320 *, loff_t *);
	void (*stop)(struct seq_file___320 *, void *);
	void * (*next)(struct seq_file___320 *, void *, loff_t *);
	int (*show)(struct seq_file___320 *, void *);
};

struct fwnode_reference_args___267;

struct fwnode_endpoint___267;

struct fwnode_operations___267 {
	struct fwnode_handle___267 * (*get)(struct fwnode_handle___267 *);
	void (*put)(struct fwnode_handle___267 *);
	bool (*device_is_available)(const struct fwnode_handle___267 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___267 *, const struct device___345 *);
	bool (*property_present)(const struct fwnode_handle___267 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___267 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___267 *, const char *, const char **, size_t);
	struct fwnode_handle___267 * (*get_parent)(const struct fwnode_handle___267 *);
	struct fwnode_handle___267 * (*get_next_child_node)(const struct fwnode_handle___267 *, struct fwnode_handle___267 *);
	struct fwnode_handle___267 * (*get_named_child_node)(const struct fwnode_handle___267 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___267 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___267 *);
	struct fwnode_handle___267 * (*graph_get_next_endpoint)(const struct fwnode_handle___267 *, struct fwnode_handle___267 *);
	struct fwnode_handle___267 * (*graph_get_remote_endpoint)(const struct fwnode_handle___267 *);
	struct fwnode_handle___267 * (*graph_get_port_parent)(struct fwnode_handle___267 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___267 *, struct fwnode_endpoint___267 *);
};

struct fwnode_endpoint___267 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___267 *local_fwnode;
};

struct fwnode_reference_args___267 {
	struct fwnode_handle___267 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct property___84 {
	char *name;
	int length;
	void *value;
	struct property___84 *next;
	long unsigned int _flags;
	struct bin_attribute___341 attr;
};

struct phy___8;

struct phy_ops___7 {
	int (*init)(struct phy___8 *);
	int (*exit)(struct phy___8 *);
	int (*power_on)(struct phy___8 *);
	int (*power_off)(struct phy___8 *);
	int (*set_mode)(struct phy___8 *, enum phy_mode);
	int (*reset)(struct phy___8 *);
	int (*calibrate)(struct phy___8 *);
	struct module___309 *owner;
};

struct phy___8 {
	struct device___345 dev;
	int id;
	const struct phy_ops___7 *ops;
	struct mutex mutex;
	int init_count;
	int power_count;
	struct phy_attrs attrs;
	struct regulator *pwr;
};

enum usb_otg_state {
	OTG_STATE_UNDEFINED = 0,
	OTG_STATE_B_IDLE = 1,
	OTG_STATE_B_SRP_INIT = 2,
	OTG_STATE_B_PERIPHERAL = 3,
	OTG_STATE_B_WAIT_ACON = 4,
	OTG_STATE_B_HOST = 5,
	OTG_STATE_A_IDLE = 6,
	OTG_STATE_A_WAIT_VRISE = 7,
	OTG_STATE_A_WAIT_BCON = 8,
	OTG_STATE_A_HOST = 9,
	OTG_STATE_A_SUSPEND = 10,
	OTG_STATE_A_PERIPHERAL = 11,
	OTG_STATE_A_WAIT_VFALL = 12,
	OTG_STATE_A_VBUS_ERR = 13,
};

struct usb_phy_io_ops {
	int (*read)(struct usb_phy *, u32);
	int (*write)(struct usb_phy *, u32, u32);
};

struct usb_gadget;

struct usb_otg {
	u8 default_a;
	struct phy___8 *phy;
	struct usb_phy *usb_phy;
	struct usb_bus *host;
	struct usb_gadget *gadget;
	enum usb_otg_state state;
	int (*set_host)(struct usb_otg *, struct usb_bus *);
	int (*set_peripheral)(struct usb_otg *, struct usb_gadget *);
	int (*set_vbus)(struct usb_otg *, bool);
	int (*start_srp)(struct usb_otg *);
	int (*start_hnp)(struct usb_otg *);
};

typedef void compound_page_dtor___366(struct page___379 *);

struct find_interface_arg {
	int minor;
	struct device_driver___345 *drv;
};

struct each_dev_arg {
	void *data;
	int (*fn)(struct usb_device *, void *);
};

struct usb_qualifier_descriptor {
	__u8 bLength;
	__u8 bDescriptorType;
	__le16 bcdUSB;
	__u8 bDeviceClass;
	__u8 bDeviceSubClass;
	__u8 bDeviceProtocol;
	__u8 bMaxPacketSize0;
	__u8 bNumConfigurations;
	__u8 bRESERVED;
};

struct usb_set_sel_req {
	__u8 u1_sel;
	__u8 u1_pel;
	__le16 u2_sel;
	__le16 u2_pel;
};

struct usb_interface___2 {
	struct usb_host_interface *altsetting;
	struct usb_host_interface *cur_altsetting;
	unsigned int num_altsetting;
	struct usb_interface_assoc_descriptor *intf_assoc;
	int minor;
	enum usb_interface_condition condition;
	unsigned int sysfs_files_created: 1;
	unsigned int ep_devs_created: 1;
	unsigned int unregistering: 1;
	unsigned int needs_remote_wakeup: 1;
	unsigned int needs_altsetting0: 1;
	unsigned int needs_binding: 1;
	unsigned int resetting_device: 1;
	unsigned int authorized: 1;
	struct device___305 dev;
	struct device___305 *usb_dev;
	atomic_t pm_usage_cnt;
	struct work_struct reset_ws;
};

struct usb_host_config___2 {
	struct usb_config_descriptor desc;
	char *string;
	struct usb_interface_assoc_descriptor *intf_assoc[16];
	struct usb_interface___2 *interface[32];
	struct usb_interface_cache *intf_cache[32];
	unsigned char *extra;
	int extralen;
};

struct usb_device___2;

struct usb_bus___2 {
	struct device___305 *controller;
	struct device___305 *sysdev;
	int busnum;
	const char *bus_name;
	u8 uses_dma;
	u8 uses_pio_for_control;
	u8 otg_port;
	unsigned int is_b_host: 1;
	unsigned int b_hnp_enable: 1;
	unsigned int no_stop_on_short: 1;
	unsigned int no_sg_constraint: 1;
	unsigned int sg_tablesize;
	int devnum_next;
	struct mutex devnum_next_mutex;
	struct usb_devmap devmap;
	struct usb_device___2 *root_hub;
	struct usb_bus___2 *hs_companion;
	int bandwidth_allocated;
	int bandwidth_int_reqs;
	int bandwidth_isoc_reqs;
	unsigned int resuming_ports;
	struct mon_bus *mon_bus;
	int monitored;
};

struct usb_tt___2;

struct usb_device___2 {
	int devnum;
	char devpath[16];
	u32 route;
	enum usb_device_state state;
	enum usb_device_speed speed;
	unsigned int rx_lanes;
	unsigned int tx_lanes;
	struct usb_tt___2 *tt;
	int ttport;
	unsigned int toggle[2];
	struct usb_device___2 *parent;
	struct usb_bus___2 *bus;
	struct usb_host_endpoint ep0;
	struct device___305 dev;
	struct usb_device_descriptor descriptor;
	struct usb_host_bos *bos;
	struct usb_host_config___2 *config;
	struct usb_host_config___2 *actconfig;
	struct usb_host_endpoint *ep_in[16];
	struct usb_host_endpoint *ep_out[16];
	char **rawdescriptors;
	short unsigned int bus_mA;
	u8 portnum;
	u8 level;
	unsigned int can_submit: 1;
	unsigned int persist_enabled: 1;
	unsigned int have_langid: 1;
	unsigned int authorized: 1;
	unsigned int authenticated: 1;
	unsigned int wusb: 1;
	unsigned int lpm_capable: 1;
	unsigned int usb2_hw_lpm_capable: 1;
	unsigned int usb2_hw_lpm_besl_capable: 1;
	unsigned int usb2_hw_lpm_enabled: 1;
	unsigned int usb2_hw_lpm_allowed: 1;
	unsigned int usb3_lpm_u1_enabled: 1;
	unsigned int usb3_lpm_u2_enabled: 1;
	int string_langid;
	char *product;
	char *manufacturer;
	char *serial;
	struct list_head filelist;
	int maxchild;
	u32 quirks;
	atomic_t urbnum;
	long unsigned int active_duration;
	long unsigned int connect_time;
	unsigned int do_remote_wakeup: 1;
	unsigned int reset_resume: 1;
	unsigned int port_is_suspended: 1;
	struct wusb_dev *wusb_dev;
	int slot_id;
	enum usb_device_removable removable;
	struct usb2_lpm_parameters l1_params;
	struct usb3_lpm_parameters u1_params;
	struct usb3_lpm_parameters u2_params;
	unsigned int lpm_disable_count;
	u16 hub_delay;
};

enum usb_port_connect_type {
	USB_PORT_CONNECT_TYPE_UNKNOWN = 0,
	USB_PORT_CONNECT_TYPE_HOT_PLUG = 1,
	USB_PORT_CONNECT_TYPE_HARD_WIRED = 2,
	USB_PORT_NOT_USED = 3,
};

struct usb_tt___2 {
	struct usb_device___2 *hub;
	int multi;
	unsigned int think_time;
	void *hcpriv;
	spinlock_t lock;
	struct list_head clear_list;
	struct work_struct clear_work;
};

struct usbdrv_wrap___2 {
	struct device_driver___305 driver;
	int for_devices;
};

struct usb_driver___2 {
	const char *name;
	int (*probe)(struct usb_interface___2 *, const struct usb_device_id *);
	void (*disconnect)(struct usb_interface___2 *);
	int (*unlocked_ioctl)(struct usb_interface___2 *, unsigned int, void *);
	int (*suspend)(struct usb_interface___2 *, pm_message_t);
	int (*resume)(struct usb_interface___2 *);
	int (*reset_resume)(struct usb_interface___2 *);
	int (*pre_reset)(struct usb_interface___2 *);
	int (*post_reset)(struct usb_interface___2 *);
	const struct usb_device_id *id_table;
	struct usb_dynids dynids;
	struct usbdrv_wrap___2 drvwrap;
	unsigned int no_dynamic_id: 1;
	unsigned int supports_autosuspend: 1;
	unsigned int disable_hub_initiated_lpm: 1;
	unsigned int soft_unbind: 1;
};

struct usb_device_driver___2 {
	const char *name;
	int (*probe)(struct usb_device___2 *);
	void (*disconnect)(struct usb_device___2 *);
	int (*suspend)(struct usb_device___2 *, pm_message_t);
	int (*resume)(struct usb_device___2 *, pm_message_t);
	struct usbdrv_wrap___2 drvwrap;
	unsigned int supports_autosuspend: 1;
};

struct urb___2;

typedef void (*usb_complete_t___2)(struct urb___2 *);

struct urb___2 {
	struct kref kref;
	void *hcpriv;
	atomic_t use_count;
	atomic_t reject;
	int unlinked;
	struct list_head urb_list;
	struct list_head anchor_list;
	struct usb_anchor *anchor;
	struct usb_device___2 *dev;
	struct usb_host_endpoint *ep;
	unsigned int pipe;
	unsigned int stream_id;
	int status;
	unsigned int transfer_flags;
	void *transfer_buffer;
	dma_addr_t transfer_dma;
	struct scatterlist *sg;
	int num_mapped_sgs;
	int num_sgs;
	u32 transfer_buffer_length;
	u32 actual_length;
	unsigned char *setup_packet;
	dma_addr_t setup_dma;
	int start_frame;
	int number_of_packets;
	int interval;
	int error_count;
	void *context;
	usb_complete_t___2 complete;
	struct usb_iso_packet_descriptor iso_frame_desc[0];
};

struct usbdevfs_hub_portinfo {
	char nports;
	char port[127];
};

struct hc_driver___2;

struct usb_phy___2;

struct usb_hcd___2 {
	struct usb_bus___2 self;
	struct kref kref;
	const char *product_desc;
	int speed;
	char irq_descr[24];
	struct timer_list rh_timer;
	struct urb___2 *status_urb;
	struct work_struct wakeup_work;
	const struct hc_driver___2 *driver;
	struct usb_phy___2 *usb_phy;
	struct usb_phy_roothub *phy_roothub;
	long unsigned int flags;
	unsigned int rh_registered: 1;
	unsigned int rh_pollable: 1;
	unsigned int msix_enabled: 1;
	unsigned int msi_enabled: 1;
	unsigned int skip_phy_initialization: 1;
	unsigned int uses_new_polling: 1;
	unsigned int wireless: 1;
	unsigned int has_tt: 1;
	unsigned int amd_resume_bug: 1;
	unsigned int can_do_streams: 1;
	unsigned int tpl_support: 1;
	unsigned int cant_recv_wakeups: 1;
	unsigned int irq;
	void *regs;
	resource_size_t rsrc_start;
	resource_size_t rsrc_len;
	unsigned int power_budget;
	struct giveback_urb_bh high_prio_bh;
	struct giveback_urb_bh low_prio_bh;
	struct mutex *address0_mutex;
	struct mutex *bandwidth_mutex;
	struct usb_hcd___2 *shared_hcd;
	struct usb_hcd___2 *primary_hcd;
	struct dma_pool___2 *pool[4];
	int state;
	long unsigned int hcd_priv[0];
};

struct hc_driver___2 {
	const char *description;
	const char *product_desc;
	size_t hcd_priv_size;
	irqreturn_t (*irq)(struct usb_hcd___2 *);
	int flags;
	int (*reset)(struct usb_hcd___2 *);
	int (*start)(struct usb_hcd___2 *);
	int (*pci_suspend)(struct usb_hcd___2 *, bool);
	int (*pci_resume)(struct usb_hcd___2 *, bool);
	void (*stop)(struct usb_hcd___2 *);
	void (*shutdown)(struct usb_hcd___2 *);
	int (*get_frame_number)(struct usb_hcd___2 *);
	int (*urb_enqueue)(struct usb_hcd___2 *, struct urb___2 *, gfp_t);
	int (*urb_dequeue)(struct usb_hcd___2 *, struct urb___2 *, int);
	int (*map_urb_for_dma)(struct usb_hcd___2 *, struct urb___2 *, gfp_t);
	void (*unmap_urb_for_dma)(struct usb_hcd___2 *, struct urb___2 *);
	void (*endpoint_disable)(struct usb_hcd___2 *, struct usb_host_endpoint *);
	void (*endpoint_reset)(struct usb_hcd___2 *, struct usb_host_endpoint *);
	int (*hub_status_data)(struct usb_hcd___2 *, char *);
	int (*hub_control)(struct usb_hcd___2 *, u16, u16, u16, char *, u16);
	int (*bus_suspend)(struct usb_hcd___2 *);
	int (*bus_resume)(struct usb_hcd___2 *);
	int (*start_port_reset)(struct usb_hcd___2 *, unsigned int);
	long unsigned int (*get_resuming_ports)(struct usb_hcd___2 *);
	void (*relinquish_port)(struct usb_hcd___2 *, int);
	int (*port_handed_over)(struct usb_hcd___2 *, int);
	void (*clear_tt_buffer_complete)(struct usb_hcd___2 *, struct usb_host_endpoint *);
	int (*alloc_dev)(struct usb_hcd___2 *, struct usb_device___2 *);
	void (*free_dev)(struct usb_hcd___2 *, struct usb_device___2 *);
	int (*alloc_streams)(struct usb_hcd___2 *, struct usb_device___2 *, struct usb_host_endpoint **, unsigned int, unsigned int, gfp_t);
	int (*free_streams)(struct usb_hcd___2 *, struct usb_device___2 *, struct usb_host_endpoint **, unsigned int, gfp_t);
	int (*add_endpoint)(struct usb_hcd___2 *, struct usb_device___2 *, struct usb_host_endpoint *);
	int (*drop_endpoint)(struct usb_hcd___2 *, struct usb_device___2 *, struct usb_host_endpoint *);
	int (*check_bandwidth)(struct usb_hcd___2 *, struct usb_device___2 *);
	void (*reset_bandwidth)(struct usb_hcd___2 *, struct usb_device___2 *);
	int (*address_device)(struct usb_hcd___2 *, struct usb_device___2 *);
	int (*enable_device)(struct usb_hcd___2 *, struct usb_device___2 *);
	int (*update_hub_device)(struct usb_hcd___2 *, struct usb_device___2 *, struct usb_tt___2 *, gfp_t);
	int (*reset_device)(struct usb_hcd___2 *, struct usb_device___2 *);
	int (*update_device)(struct usb_hcd___2 *, struct usb_device___2 *);
	int (*set_usb2_hw_lpm)(struct usb_hcd___2 *, struct usb_device___2 *, int);
	int (*enable_usb3_lpm_timeout)(struct usb_hcd___2 *, struct usb_device___2 *, enum usb3_link_state);
	int (*disable_usb3_lpm_timeout)(struct usb_hcd___2 *, struct usb_device___2 *, enum usb3_link_state);
	int (*find_raw_port_number)(struct usb_hcd___2 *, int);
	int (*port_power)(struct usb_hcd___2 *, int, bool);
};

struct usb_otg___2;

struct usb_phy_io_ops___2;

struct usb_phy___2 {
	struct device___305 *dev;
	const char *label;
	unsigned int flags;
	enum usb_phy_type type;
	enum usb_phy_events last_event;
	struct usb_otg___2 *otg;
	struct device___305 *io_dev;
	struct usb_phy_io_ops___2 *io_ops;
	void *io_priv;
	struct extcon_dev *edev;
	struct extcon_dev *id_edev;
	struct notifier_block vbus_nb;
	struct notifier_block id_nb;
	struct notifier_block type_nb;
	enum usb_charger_type chg_type;
	enum usb_charger_state chg_state;
	struct usb_charger_current chg_cur;
	struct work_struct chg_work;
	struct atomic_notifier_head notifier;
	u16 port_status;
	u16 port_change;
	struct list_head head;
	int (*init)(struct usb_phy___2 *);
	void (*shutdown)(struct usb_phy___2 *);
	int (*set_vbus)(struct usb_phy___2 *, int);
	int (*set_power)(struct usb_phy___2 *, unsigned int);
	int (*set_suspend)(struct usb_phy___2 *, int);
	int (*set_wakeup)(struct usb_phy___2 *, bool);
	int (*notify_connect)(struct usb_phy___2 *, enum usb_device_speed);
	int (*notify_disconnect)(struct usb_phy___2 *, enum usb_device_speed);
	enum usb_charger_type (*charger_detect)(struct usb_phy___2 *);
};

struct usb_port_status {
	__le16 wPortStatus;
	__le16 wPortChange;
	__le32 dwExtPortStatus;
};

struct usb_hub_status {
	__le16 wHubStatus;
	__le16 wHubChange;
};

struct usb_hub_descriptor {
	__u8 bDescLength;
	__u8 bDescriptorType;
	__u8 bNbrPorts;
	__le16 wHubCharacteristics;
	__u8 bPwrOn2PwrGood;
	__u8 bHubContrCurrent;
	union {
		struct {
			__u8 DeviceRemovable[4];
			__u8 PortPwrCtrlMask[4];
		} hs;
		struct {
			__u8 bHubHdrDecLat;
			__le16 wHubDelay;
			__le16 DeviceRemovable;
		} __attribute__((packed)) ss;
	} u;
} __attribute__((packed));

enum hub_led_mode {
	INDICATOR_AUTO = 0,
	INDICATOR_CYCLE = 1,
	INDICATOR_GREEN_BLINK = 2,
	INDICATOR_GREEN_BLINK_OFF = 3,
	INDICATOR_AMBER_BLINK = 4,
	INDICATOR_AMBER_BLINK_OFF = 5,
	INDICATOR_ALT_BLINK = 6,
	INDICATOR_ALT_BLINK_OFF = 7,
};

struct usb_tt_clear {
	struct list_head clear_list;
	unsigned int tt;
	u16 devinfo;
	struct usb_hcd___2 *hcd;
	struct usb_host_endpoint *ep;
};

struct usb_mon_operations___2 {
	void (*urb_submit)(struct usb_bus___2 *, struct urb___2 *);
	void (*urb_submit_error)(struct usb_bus___2 *, struct urb___2 *, int);
	void (*urb_complete)(struct usb_bus___2 *, struct urb___2 *, int);
};

struct phy___9;

struct phy_ops___8 {
	int (*init)(struct phy___9 *);
	int (*exit)(struct phy___9 *);
	int (*power_on)(struct phy___9 *);
	int (*power_off)(struct phy___9 *);
	int (*set_mode)(struct phy___9 *, enum phy_mode);
	int (*reset)(struct phy___9 *);
	int (*calibrate)(struct phy___9 *);
	struct module___277 *owner;
};

struct phy___9 {
	struct device___305 dev;
	int id;
	const struct phy_ops___8 *ops;
	struct mutex mutex;
	int init_count;
	int power_count;
	struct phy_attrs attrs;
	struct regulator *pwr;
};

struct usb_phy_io_ops___2 {
	int (*read)(struct usb_phy___2 *, u32);
	int (*write)(struct usb_phy___2 *, u32, u32);
};

struct usb_otg___2 {
	u8 default_a;
	struct phy___9 *phy;
	struct usb_phy___2 *usb_phy;
	struct usb_bus___2 *host;
	struct usb_gadget *gadget;
	enum usb_otg_state state;
	int (*set_host)(struct usb_otg___2 *, struct usb_bus___2 *);
	int (*set_peripheral)(struct usb_otg___2 *, struct usb_gadget *);
	int (*set_vbus)(struct usb_otg___2 *, bool);
	int (*start_srp)(struct usb_otg___2 *);
	int (*start_hnp)(struct usb_otg___2 *);
};

struct acpi_device___18;

struct acpi_hotplug_profile___18 {
	struct kobject___326 kobj;
	int (*scan_dependent)(struct acpi_device___18 *);
	void (*notify_online)(struct acpi_device___18 *);
	bool enabled: 1;
	bool demand_offline: 1;
};

struct acpi_device_wakeup_context___18 {
	void (*func)(struct acpi_device_wakeup_context___18 *);
	struct device___305 *dev;
};

struct acpi_device_wakeup___18 {
	acpi_handle gpe_device;
	u64 gpe_number;
	u64 sleep_state;
	struct list_head resources;
	struct acpi_device_wakeup_flags flags;
	struct acpi_device_wakeup_context___18 context;
	struct wakeup_source___3 *ws;
	int prepare_count;
	int enable_count;
};

struct acpi_scan_handler___18;

struct acpi_hotplug_context___18;

struct acpi_driver___18;

struct acpi_device___18 {
	int device_type;
	acpi_handle handle;
	struct fwnode_handle___233 fwnode;
	struct acpi_device___18 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup___18 wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_device_data data;
	struct acpi_scan_handler___18 *handler;
	struct acpi_hotplug_context___18 *hp;
	struct acpi_driver___18 *driver;
	const struct acpi_gpio_mapping *driver_gpios;
	void *driver_data;
	struct device___305 dev;
	unsigned int physical_node_count;
	unsigned int dep_unmet;
	struct list_head physical_node_list;
	struct mutex physical_node_lock;
	void (*remove)(struct acpi_device___18 *);
};

struct acpi_scan_handler___18 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	bool (*match)(const char *, const struct acpi_device_id **);
	int (*attach)(struct acpi_device___18 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___18 *);
	void (*bind)(struct device___305 *);
	void (*unbind)(struct device___305 *);
	struct acpi_hotplug_profile___18 hotplug;
};

struct acpi_hotplug_context___18 {
	struct acpi_device___18 *self;
	int (*notify)(struct acpi_device___18 *, u32);
	void (*uevent)(struct acpi_device___18 *, u32);
	void (*fixup)(struct acpi_device___18 *);
};

typedef int (*acpi_op_add___18)(struct acpi_device___18 *);

typedef int (*acpi_op_remove___18)(struct acpi_device___18 *);

typedef void (*acpi_op_notify___18)(struct acpi_device___18 *, u32);

struct acpi_device_ops___18 {
	acpi_op_add___18 add;
	acpi_op_remove___18 remove;
	acpi_op_notify___18 notify;
};

struct acpi_driver___18 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___18 ops;
	struct device_driver___305 drv;
	struct module___277 *owner;
};

typedef u32 usb_port_location_t;

struct usb_port;

struct usb_hub {
	struct device___305 *intfdev;
	struct usb_device___2 *hdev;
	struct kref kref;
	struct urb___2 *urb;
	u8 (*buffer)[8];
	union {
		struct usb_hub_status hub;
		struct usb_port_status port;
	} *status;
	struct mutex status_mutex;
	int error;
	int nerrors;
	long unsigned int event_bits[1];
	long unsigned int change_bits[1];
	long unsigned int removed_bits[1];
	long unsigned int wakeup_bits[1];
	long unsigned int power_bits[1];
	long unsigned int child_usage_bits[1];
	long unsigned int warm_reset_bits[1];
	struct usb_hub_descriptor *descriptor;
	struct usb_tt___2 tt;
	unsigned int mA_per_port;
	unsigned int wakeup_enabled_descendants;
	unsigned int limited_power: 1;
	unsigned int quiescing: 1;
	unsigned int disconnected: 1;
	unsigned int in_reset: 1;
	unsigned int quirk_check_port_auto_suspend: 1;
	unsigned int has_indicators: 1;
	u8 indicator[31];
	struct delayed_work leds;
	struct delayed_work init_work;
	struct work_struct events;
	struct usb_port **ports;
};

struct usb_dev_state;

struct usb_port {
	struct usb_device___2 *child;
	struct device___305 dev;
	struct usb_dev_state *port_owner;
	struct usb_port *peer;
	struct dev_pm_qos_request___16 *req;
	enum usb_port_connect_type connect_type;
	usb_port_location_t location;
	struct mutex status_lock;
	u32 over_current_count;
	u8 portnum;
	u32 quirks;
	unsigned int is_superspeed: 1;
	unsigned int usb3_lpm_u1_permit: 1;
	unsigned int usb3_lpm_u2_permit: 1;
};

enum hub_activation_type {
	HUB_INIT = 0,
	HUB_INIT2 = 1,
	HUB_INIT3 = 2,
	HUB_POST_RESET = 3,
	HUB_RESUME = 4,
	HUB_RESET_RESUME = 5,
};

enum hub_quiescing_type {
	HUB_DISCONNECT = 0,
	HUB_PRE_RESET = 1,
	HUB_SUSPEND = 2,
};

struct platform_device___22 {
	const char *name;
	int id;
	bool id_auto;
	struct device___336 dev;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct usb_ctrlrequest {
	__u8 bRequestType;
	__u8 bRequest;
	__le16 wValue;
	__le16 wIndex;
	__le16 wLength;
};

struct usb_interface___3 {
	struct usb_host_interface *altsetting;
	struct usb_host_interface *cur_altsetting;
	unsigned int num_altsetting;
	struct usb_interface_assoc_descriptor *intf_assoc;
	int minor;
	enum usb_interface_condition condition;
	unsigned int sysfs_files_created: 1;
	unsigned int ep_devs_created: 1;
	unsigned int unregistering: 1;
	unsigned int needs_remote_wakeup: 1;
	unsigned int needs_altsetting0: 1;
	unsigned int needs_binding: 1;
	unsigned int resetting_device: 1;
	unsigned int authorized: 1;
	struct device___336 dev;
	struct device___336 *usb_dev;
	atomic_t pm_usage_cnt;
	struct work_struct reset_ws;
};

struct usb_host_config___3 {
	struct usb_config_descriptor desc;
	char *string;
	struct usb_interface_assoc_descriptor *intf_assoc[16];
	struct usb_interface___3 *interface[32];
	struct usb_interface_cache *intf_cache[32];
	unsigned char *extra;
	int extralen;
};

struct usb_device___3;

struct usb_bus___3 {
	struct device___336 *controller;
	struct device___336 *sysdev;
	int busnum;
	const char *bus_name;
	u8 uses_dma;
	u8 uses_pio_for_control;
	u8 otg_port;
	unsigned int is_b_host: 1;
	unsigned int b_hnp_enable: 1;
	unsigned int no_stop_on_short: 1;
	unsigned int no_sg_constraint: 1;
	unsigned int sg_tablesize;
	int devnum_next;
	struct mutex devnum_next_mutex;
	struct usb_devmap devmap;
	struct usb_device___3 *root_hub;
	struct usb_bus___3 *hs_companion;
	int bandwidth_allocated;
	int bandwidth_int_reqs;
	int bandwidth_isoc_reqs;
	unsigned int resuming_ports;
	struct mon_bus *mon_bus;
	int monitored;
};

struct usb_tt___3;

struct usb_device___3 {
	int devnum;
	char devpath[16];
	u32 route;
	enum usb_device_state state;
	enum usb_device_speed speed;
	unsigned int rx_lanes;
	unsigned int tx_lanes;
	struct usb_tt___3 *tt;
	int ttport;
	unsigned int toggle[2];
	struct usb_device___3 *parent;
	struct usb_bus___3 *bus;
	struct usb_host_endpoint ep0;
	struct device___336 dev;
	struct usb_device_descriptor descriptor;
	struct usb_host_bos *bos;
	struct usb_host_config___3 *config;
	struct usb_host_config___3 *actconfig;
	struct usb_host_endpoint *ep_in[16];
	struct usb_host_endpoint *ep_out[16];
	char **rawdescriptors;
	short unsigned int bus_mA;
	u8 portnum;
	u8 level;
	unsigned int can_submit: 1;
	unsigned int persist_enabled: 1;
	unsigned int have_langid: 1;
	unsigned int authorized: 1;
	unsigned int authenticated: 1;
	unsigned int wusb: 1;
	unsigned int lpm_capable: 1;
	unsigned int usb2_hw_lpm_capable: 1;
	unsigned int usb2_hw_lpm_besl_capable: 1;
	unsigned int usb2_hw_lpm_enabled: 1;
	unsigned int usb2_hw_lpm_allowed: 1;
	unsigned int usb3_lpm_u1_enabled: 1;
	unsigned int usb3_lpm_u2_enabled: 1;
	int string_langid;
	char *product;
	char *manufacturer;
	char *serial;
	struct list_head filelist;
	int maxchild;
	u32 quirks;
	atomic_t urbnum;
	long unsigned int active_duration;
	long unsigned int connect_time;
	unsigned int do_remote_wakeup: 1;
	unsigned int reset_resume: 1;
	unsigned int port_is_suspended: 1;
	struct wusb_dev *wusb_dev;
	int slot_id;
	enum usb_device_removable removable;
	struct usb2_lpm_parameters l1_params;
	struct usb3_lpm_parameters u1_params;
	struct usb3_lpm_parameters u2_params;
	unsigned int lpm_disable_count;
	u16 hub_delay;
};

struct usb_tt___3 {
	struct usb_device___3 *hub;
	int multi;
	unsigned int think_time;
	void *hcpriv;
	spinlock_t lock;
	struct list_head clear_list;
	struct work_struct clear_work;
};

struct usbdrv_wrap___3 {
	struct device_driver___336 driver;
	int for_devices;
};

struct usb_driver___3 {
	const char *name;
	int (*probe)(struct usb_interface___3 *, const struct usb_device_id *);
	void (*disconnect)(struct usb_interface___3 *);
	int (*unlocked_ioctl)(struct usb_interface___3 *, unsigned int, void *);
	int (*suspend)(struct usb_interface___3 *, pm_message_t);
	int (*resume)(struct usb_interface___3 *);
	int (*reset_resume)(struct usb_interface___3 *);
	int (*pre_reset)(struct usb_interface___3 *);
	int (*post_reset)(struct usb_interface___3 *);
	const struct usb_device_id *id_table;
	struct usb_dynids dynids;
	struct usbdrv_wrap___3 drvwrap;
	unsigned int no_dynamic_id: 1;
	unsigned int supports_autosuspend: 1;
	unsigned int disable_hub_initiated_lpm: 1;
	unsigned int soft_unbind: 1;
};

struct usb_device_driver___3 {
	const char *name;
	int (*probe)(struct usb_device___3 *);
	void (*disconnect)(struct usb_device___3 *);
	int (*suspend)(struct usb_device___3 *, pm_message_t);
	int (*resume)(struct usb_device___3 *, pm_message_t);
	struct usbdrv_wrap___3 drvwrap;
	unsigned int supports_autosuspend: 1;
};

struct urb___3;

typedef void (*usb_complete_t___3)(struct urb___3 *);

struct urb___3 {
	struct kref kref;
	void *hcpriv;
	atomic_t use_count;
	atomic_t reject;
	int unlinked;
	struct list_head urb_list;
	struct list_head anchor_list;
	struct usb_anchor *anchor;
	struct usb_device___3 *dev;
	struct usb_host_endpoint *ep;
	unsigned int pipe;
	unsigned int stream_id;
	int status;
	unsigned int transfer_flags;
	void *transfer_buffer;
	dma_addr_t transfer_dma;
	struct scatterlist *sg;
	int num_mapped_sgs;
	int num_sgs;
	u32 transfer_buffer_length;
	u32 actual_length;
	unsigned char *setup_packet;
	dma_addr_t setup_dma;
	int start_frame;
	int number_of_packets;
	int interval;
	int error_count;
	void *context;
	usb_complete_t___3 complete;
	struct usb_iso_packet_descriptor iso_frame_desc[0];
};

enum usb_led_event {
	USB_LED_EVENT_HOST = 0,
	USB_LED_EVENT_GADGET = 1,
};

struct hc_driver___3;

struct usb_phy___3;

struct usb_hcd___3 {
	struct usb_bus___3 self;
	struct kref kref;
	const char *product_desc;
	int speed;
	char irq_descr[24];
	struct timer_list rh_timer;
	struct urb___3 *status_urb;
	struct work_struct wakeup_work;
	const struct hc_driver___3 *driver;
	struct usb_phy___3 *usb_phy;
	struct usb_phy_roothub *phy_roothub;
	long unsigned int flags;
	unsigned int rh_registered: 1;
	unsigned int rh_pollable: 1;
	unsigned int msix_enabled: 1;
	unsigned int msi_enabled: 1;
	unsigned int skip_phy_initialization: 1;
	unsigned int uses_new_polling: 1;
	unsigned int wireless: 1;
	unsigned int has_tt: 1;
	unsigned int amd_resume_bug: 1;
	unsigned int can_do_streams: 1;
	unsigned int tpl_support: 1;
	unsigned int cant_recv_wakeups: 1;
	unsigned int irq;
	void *regs;
	resource_size_t rsrc_start;
	resource_size_t rsrc_len;
	unsigned int power_budget;
	struct giveback_urb_bh high_prio_bh;
	struct giveback_urb_bh low_prio_bh;
	struct mutex *address0_mutex;
	struct mutex *bandwidth_mutex;
	struct usb_hcd___3 *shared_hcd;
	struct usb_hcd___3 *primary_hcd;
	struct dma_pool___2 *pool[4];
	int state;
	long unsigned int hcd_priv[0];
};

struct hc_driver___3 {
	const char *description;
	const char *product_desc;
	size_t hcd_priv_size;
	irqreturn_t (*irq)(struct usb_hcd___3 *);
	int flags;
	int (*reset)(struct usb_hcd___3 *);
	int (*start)(struct usb_hcd___3 *);
	int (*pci_suspend)(struct usb_hcd___3 *, bool);
	int (*pci_resume)(struct usb_hcd___3 *, bool);
	void (*stop)(struct usb_hcd___3 *);
	void (*shutdown)(struct usb_hcd___3 *);
	int (*get_frame_number)(struct usb_hcd___3 *);
	int (*urb_enqueue)(struct usb_hcd___3 *, struct urb___3 *, gfp_t);
	int (*urb_dequeue)(struct usb_hcd___3 *, struct urb___3 *, int);
	int (*map_urb_for_dma)(struct usb_hcd___3 *, struct urb___3 *, gfp_t);
	void (*unmap_urb_for_dma)(struct usb_hcd___3 *, struct urb___3 *);
	void (*endpoint_disable)(struct usb_hcd___3 *, struct usb_host_endpoint *);
	void (*endpoint_reset)(struct usb_hcd___3 *, struct usb_host_endpoint *);
	int (*hub_status_data)(struct usb_hcd___3 *, char *);
	int (*hub_control)(struct usb_hcd___3 *, u16, u16, u16, char *, u16);
	int (*bus_suspend)(struct usb_hcd___3 *);
	int (*bus_resume)(struct usb_hcd___3 *);
	int (*start_port_reset)(struct usb_hcd___3 *, unsigned int);
	long unsigned int (*get_resuming_ports)(struct usb_hcd___3 *);
	void (*relinquish_port)(struct usb_hcd___3 *, int);
	int (*port_handed_over)(struct usb_hcd___3 *, int);
	void (*clear_tt_buffer_complete)(struct usb_hcd___3 *, struct usb_host_endpoint *);
	int (*alloc_dev)(struct usb_hcd___3 *, struct usb_device___3 *);
	void (*free_dev)(struct usb_hcd___3 *, struct usb_device___3 *);
	int (*alloc_streams)(struct usb_hcd___3 *, struct usb_device___3 *, struct usb_host_endpoint **, unsigned int, unsigned int, gfp_t);
	int (*free_streams)(struct usb_hcd___3 *, struct usb_device___3 *, struct usb_host_endpoint **, unsigned int, gfp_t);
	int (*add_endpoint)(struct usb_hcd___3 *, struct usb_device___3 *, struct usb_host_endpoint *);
	int (*drop_endpoint)(struct usb_hcd___3 *, struct usb_device___3 *, struct usb_host_endpoint *);
	int (*check_bandwidth)(struct usb_hcd___3 *, struct usb_device___3 *);
	void (*reset_bandwidth)(struct usb_hcd___3 *, struct usb_device___3 *);
	int (*address_device)(struct usb_hcd___3 *, struct usb_device___3 *);
	int (*enable_device)(struct usb_hcd___3 *, struct usb_device___3 *);
	int (*update_hub_device)(struct usb_hcd___3 *, struct usb_device___3 *, struct usb_tt___3 *, gfp_t);
	int (*reset_device)(struct usb_hcd___3 *, struct usb_device___3 *);
	int (*update_device)(struct usb_hcd___3 *, struct usb_device___3 *);
	int (*set_usb2_hw_lpm)(struct usb_hcd___3 *, struct usb_device___3 *, int);
	int (*enable_usb3_lpm_timeout)(struct usb_hcd___3 *, struct usb_device___3 *, enum usb3_link_state);
	int (*disable_usb3_lpm_timeout)(struct usb_hcd___3 *, struct usb_device___3 *, enum usb3_link_state);
	int (*find_raw_port_number)(struct usb_hcd___3 *, int);
	int (*port_power)(struct usb_hcd___3 *, int, bool);
};

struct usb_otg___3;

struct usb_phy_io_ops___3;

struct usb_phy___3 {
	struct device___336 *dev;
	const char *label;
	unsigned int flags;
	enum usb_phy_type type;
	enum usb_phy_events last_event;
	struct usb_otg___3 *otg;
	struct device___336 *io_dev;
	struct usb_phy_io_ops___3 *io_ops;
	void *io_priv;
	struct extcon_dev *edev;
	struct extcon_dev *id_edev;
	struct notifier_block vbus_nb;
	struct notifier_block id_nb;
	struct notifier_block type_nb;
	enum usb_charger_type chg_type;
	enum usb_charger_state chg_state;
	struct usb_charger_current chg_cur;
	struct work_struct chg_work;
	struct atomic_notifier_head notifier;
	u16 port_status;
	u16 port_change;
	struct list_head head;
	int (*init)(struct usb_phy___3 *);
	void (*shutdown)(struct usb_phy___3 *);
	int (*set_vbus)(struct usb_phy___3 *, int);
	int (*set_power)(struct usb_phy___3 *, unsigned int);
	int (*set_suspend)(struct usb_phy___3 *, int);
	int (*set_wakeup)(struct usb_phy___3 *, bool);
	int (*notify_connect)(struct usb_phy___3 *, enum usb_device_speed);
	int (*notify_disconnect)(struct usb_phy___3 *, enum usb_device_speed);
	enum usb_charger_type (*charger_detect)(struct usb_phy___3 *);
};

struct usb_mon_operations___3 {
	void (*urb_submit)(struct usb_bus___3 *, struct urb___3 *);
	void (*urb_submit_error)(struct usb_bus___3 *, struct urb___3 *, int);
	void (*urb_complete)(struct usb_bus___3 *, struct urb___3 *, int);
};

struct usb_phy_io_ops___3 {
	int (*read)(struct usb_phy___3 *, u32);
	int (*write)(struct usb_phy___3 *, u32, u32);
};

struct usb_otg___3 {
	u8 default_a;
	struct phy___6 *phy;
	struct usb_phy___3 *usb_phy;
	struct usb_bus___3 *host;
	struct usb_gadget *gadget;
	enum usb_otg_state state;
	int (*set_host)(struct usb_otg___3 *, struct usb_bus___3 *);
	int (*set_peripheral)(struct usb_otg___3 *, struct usb_gadget *);
	int (*set_vbus)(struct usb_otg___3 *, bool);
	int (*start_srp)(struct usb_otg___3 *);
	int (*start_hnp)(struct usb_otg___3 *);
};

struct usb_interface___4 {
	struct usb_host_interface *altsetting;
	struct usb_host_interface *cur_altsetting;
	unsigned int num_altsetting;
	struct usb_interface_assoc_descriptor *intf_assoc;
	int minor;
	enum usb_interface_condition condition;
	unsigned int sysfs_files_created: 1;
	unsigned int ep_devs_created: 1;
	unsigned int unregistering: 1;
	unsigned int needs_remote_wakeup: 1;
	unsigned int needs_altsetting0: 1;
	unsigned int needs_binding: 1;
	unsigned int resetting_device: 1;
	unsigned int authorized: 1;
	struct device___338 dev;
	struct device___338 *usb_dev;
	atomic_t pm_usage_cnt;
	struct work_struct reset_ws;
};

struct usb_host_config___4 {
	struct usb_config_descriptor desc;
	char *string;
	struct usb_interface_assoc_descriptor *intf_assoc[16];
	struct usb_interface___4 *interface[32];
	struct usb_interface_cache *intf_cache[32];
	unsigned char *extra;
	int extralen;
};

struct usb_device___4;

struct usb_bus___4 {
	struct device___338 *controller;
	struct device___338 *sysdev;
	int busnum;
	const char *bus_name;
	u8 uses_dma;
	u8 uses_pio_for_control;
	u8 otg_port;
	unsigned int is_b_host: 1;
	unsigned int b_hnp_enable: 1;
	unsigned int no_stop_on_short: 1;
	unsigned int no_sg_constraint: 1;
	unsigned int sg_tablesize;
	int devnum_next;
	struct mutex devnum_next_mutex;
	struct usb_devmap devmap;
	struct usb_device___4 *root_hub;
	struct usb_bus___4 *hs_companion;
	int bandwidth_allocated;
	int bandwidth_int_reqs;
	int bandwidth_isoc_reqs;
	unsigned int resuming_ports;
	struct mon_bus *mon_bus;
	int monitored;
};

struct usb_tt___4;

struct usb_device___4 {
	int devnum;
	char devpath[16];
	u32 route;
	enum usb_device_state state;
	enum usb_device_speed speed;
	unsigned int rx_lanes;
	unsigned int tx_lanes;
	struct usb_tt___4 *tt;
	int ttport;
	unsigned int toggle[2];
	struct usb_device___4 *parent;
	struct usb_bus___4 *bus;
	struct usb_host_endpoint ep0;
	struct device___338 dev;
	struct usb_device_descriptor descriptor;
	struct usb_host_bos *bos;
	struct usb_host_config___4 *config;
	struct usb_host_config___4 *actconfig;
	struct usb_host_endpoint *ep_in[16];
	struct usb_host_endpoint *ep_out[16];
	char **rawdescriptors;
	short unsigned int bus_mA;
	u8 portnum;
	u8 level;
	unsigned int can_submit: 1;
	unsigned int persist_enabled: 1;
	unsigned int have_langid: 1;
	unsigned int authorized: 1;
	unsigned int authenticated: 1;
	unsigned int wusb: 1;
	unsigned int lpm_capable: 1;
	unsigned int usb2_hw_lpm_capable: 1;
	unsigned int usb2_hw_lpm_besl_capable: 1;
	unsigned int usb2_hw_lpm_enabled: 1;
	unsigned int usb2_hw_lpm_allowed: 1;
	unsigned int usb3_lpm_u1_enabled: 1;
	unsigned int usb3_lpm_u2_enabled: 1;
	int string_langid;
	char *product;
	char *manufacturer;
	char *serial;
	struct list_head filelist;
	int maxchild;
	u32 quirks;
	atomic_t urbnum;
	long unsigned int active_duration;
	long unsigned int connect_time;
	unsigned int do_remote_wakeup: 1;
	unsigned int reset_resume: 1;
	unsigned int port_is_suspended: 1;
	struct wusb_dev *wusb_dev;
	int slot_id;
	enum usb_device_removable removable;
	struct usb2_lpm_parameters l1_params;
	struct usb3_lpm_parameters u1_params;
	struct usb3_lpm_parameters u2_params;
	unsigned int lpm_disable_count;
	u16 hub_delay;
};

struct usb_tt___4 {
	struct usb_device___4 *hub;
	int multi;
	unsigned int think_time;
	void *hcpriv;
	spinlock_t lock;
	struct list_head clear_list;
	struct work_struct clear_work;
};

struct usbdrv_wrap___4 {
	struct device_driver___338 driver;
	int for_devices;
};

struct usb_driver___4 {
	const char *name;
	int (*probe)(struct usb_interface___4 *, const struct usb_device_id *);
	void (*disconnect)(struct usb_interface___4 *);
	int (*unlocked_ioctl)(struct usb_interface___4 *, unsigned int, void *);
	int (*suspend)(struct usb_interface___4 *, pm_message_t);
	int (*resume)(struct usb_interface___4 *);
	int (*reset_resume)(struct usb_interface___4 *);
	int (*pre_reset)(struct usb_interface___4 *);
	int (*post_reset)(struct usb_interface___4 *);
	const struct usb_device_id *id_table;
	struct usb_dynids dynids;
	struct usbdrv_wrap___4 drvwrap;
	unsigned int no_dynamic_id: 1;
	unsigned int supports_autosuspend: 1;
	unsigned int disable_hub_initiated_lpm: 1;
	unsigned int soft_unbind: 1;
};

struct usb_device_driver___4 {
	const char *name;
	int (*probe)(struct usb_device___4 *);
	void (*disconnect)(struct usb_device___4 *);
	int (*suspend)(struct usb_device___4 *, pm_message_t);
	int (*resume)(struct usb_device___4 *, pm_message_t);
	struct usbdrv_wrap___4 drvwrap;
	unsigned int supports_autosuspend: 1;
};

struct urb___4;

typedef void (*usb_complete_t___4)(struct urb___4 *);

struct urb___4 {
	struct kref kref;
	void *hcpriv;
	atomic_t use_count;
	atomic_t reject;
	int unlinked;
	struct list_head urb_list;
	struct list_head anchor_list;
	struct usb_anchor *anchor;
	struct usb_device___4 *dev;
	struct usb_host_endpoint *ep;
	unsigned int pipe;
	unsigned int stream_id;
	int status;
	unsigned int transfer_flags;
	void *transfer_buffer;
	dma_addr_t transfer_dma;
	struct scatterlist *sg;
	int num_mapped_sgs;
	int num_sgs;
	u32 transfer_buffer_length;
	u32 actual_length;
	unsigned char *setup_packet;
	dma_addr_t setup_dma;
	int start_frame;
	int number_of_packets;
	int interval;
	int error_count;
	void *context;
	usb_complete_t___4 complete;
	struct usb_iso_packet_descriptor iso_frame_desc[0];
};

struct usb_sg_request {
	int status;
	size_t bytes;
	spinlock_t lock;
	struct usb_device___4 *dev;
	int pipe;
	int entries;
	struct urb___4 **urbs;
	int count;
	struct completion complete;
};

struct usb_cdc_header_desc {
	__u8 bLength;
	__u8 bDescriptorType;
	__u8 bDescriptorSubType;
	__le16 bcdCDC;
} __attribute__((packed));

struct usb_cdc_call_mgmt_descriptor {
	__u8 bLength;
	__u8 bDescriptorType;
	__u8 bDescriptorSubType;
	__u8 bmCapabilities;
	__u8 bDataInterface;
};

struct usb_cdc_acm_descriptor {
	__u8 bLength;
	__u8 bDescriptorType;
	__u8 bDescriptorSubType;
	__u8 bmCapabilities;
};

struct usb_cdc_union_desc {
	__u8 bLength;
	__u8 bDescriptorType;
	__u8 bDescriptorSubType;
	__u8 bMasterInterface0;
	__u8 bSlaveInterface0;
};

struct usb_cdc_country_functional_desc {
	__u8 bLength;
	__u8 bDescriptorType;
	__u8 bDescriptorSubType;
	__u8 iCountryCodeRelDate;
	__le16 wCountyCode0;
};

struct usb_cdc_network_terminal_desc {
	__u8 bLength;
	__u8 bDescriptorType;
	__u8 bDescriptorSubType;
	__u8 bEntityId;
	__u8 iName;
	__u8 bChannelIndex;
	__u8 bPhysicalInterface;
};

struct usb_cdc_ether_desc {
	__u8 bLength;
	__u8 bDescriptorType;
	__u8 bDescriptorSubType;
	__u8 iMACAddress;
	__le32 bmEthernetStatistics;
	__le16 wMaxSegmentSize;
	__le16 wNumberMCFilters;
	__u8 bNumberPowerFilters;
} __attribute__((packed));

struct usb_cdc_dmm_desc {
	__u8 bFunctionLength;
	__u8 bDescriptorType;
	__u8 bDescriptorSubtype;
	__u16 bcdVersion;
	__le16 wMaxCommand;
} __attribute__((packed));

struct usb_cdc_mdlm_desc {
	__u8 bLength;
	__u8 bDescriptorType;
	__u8 bDescriptorSubType;
	__le16 bcdVersion;
	__u8 bGUID[16];
} __attribute__((packed));

struct usb_cdc_mdlm_detail_desc {
	__u8 bLength;
	__u8 bDescriptorType;
	__u8 bDescriptorSubType;
	__u8 bGuidDescriptorType;
	__u8 bDetailData[0];
};

struct usb_cdc_obex_desc {
	__u8 bLength;
	__u8 bDescriptorType;
	__u8 bDescriptorSubType;
	__le16 bcdVersion;
} __attribute__((packed));

struct usb_cdc_ncm_desc {
	__u8 bLength;
	__u8 bDescriptorType;
	__u8 bDescriptorSubType;
	__le16 bcdNcmVersion;
	__u8 bmNetworkCapabilities;
} __attribute__((packed));

struct usb_cdc_mbim_desc {
	__u8 bLength;
	__u8 bDescriptorType;
	__u8 bDescriptorSubType;
	__le16 bcdMBIMVersion;
	__le16 wMaxControlMessage;
	__u8 bNumberFilters;
	__u8 bMaxFilterSize;
	__le16 wMaxSegmentSize;
	__u8 bmNetworkCapabilities;
} __attribute__((packed));

struct usb_cdc_mbim_extended_desc {
	__u8 bLength;
	__u8 bDescriptorType;
	__u8 bDescriptorSubType;
	__le16 bcdMBIMExtendedVersion;
	__u8 bMaxOutstandingCommandMessages;
	__le16 wMTU;
} __attribute__((packed));

struct usb_cdc_parsed_header {
	struct usb_cdc_union_desc *usb_cdc_union_desc;
	struct usb_cdc_header_desc *usb_cdc_header_desc;
	struct usb_cdc_call_mgmt_descriptor *usb_cdc_call_mgmt_descriptor;
	struct usb_cdc_acm_descriptor *usb_cdc_acm_descriptor;
	struct usb_cdc_country_functional_desc *usb_cdc_country_functional_desc;
	struct usb_cdc_network_terminal_desc *usb_cdc_network_terminal_desc;
	struct usb_cdc_ether_desc *usb_cdc_ether_desc;
	struct usb_cdc_dmm_desc *usb_cdc_dmm_desc;
	struct usb_cdc_mdlm_desc *usb_cdc_mdlm_desc;
	struct usb_cdc_mdlm_detail_desc *usb_cdc_mdlm_detail_desc;
	struct usb_cdc_obex_desc *usb_cdc_obex_desc;
	struct usb_cdc_ncm_desc *usb_cdc_ncm_desc;
	struct usb_cdc_mbim_desc *usb_cdc_mbim_desc;
	struct usb_cdc_mbim_extended_desc *usb_cdc_mbim_extended_desc;
	bool phonet_magic_present;
};

struct hc_driver___4;

struct usb_phy___4;

struct usb_hcd___4 {
	struct usb_bus___4 self;
	struct kref kref;
	const char *product_desc;
	int speed;
	char irq_descr[24];
	struct timer_list rh_timer;
	struct urb___4 *status_urb;
	struct work_struct wakeup_work;
	const struct hc_driver___4 *driver;
	struct usb_phy___4 *usb_phy;
	struct usb_phy_roothub *phy_roothub;
	long unsigned int flags;
	unsigned int rh_registered: 1;
	unsigned int rh_pollable: 1;
	unsigned int msix_enabled: 1;
	unsigned int msi_enabled: 1;
	unsigned int skip_phy_initialization: 1;
	unsigned int uses_new_polling: 1;
	unsigned int wireless: 1;
	unsigned int has_tt: 1;
	unsigned int amd_resume_bug: 1;
	unsigned int can_do_streams: 1;
	unsigned int tpl_support: 1;
	unsigned int cant_recv_wakeups: 1;
	unsigned int irq;
	void *regs;
	resource_size_t rsrc_start;
	resource_size_t rsrc_len;
	unsigned int power_budget;
	struct giveback_urb_bh high_prio_bh;
	struct giveback_urb_bh low_prio_bh;
	struct mutex *address0_mutex;
	struct mutex *bandwidth_mutex;
	struct usb_hcd___4 *shared_hcd;
	struct usb_hcd___4 *primary_hcd;
	struct dma_pool___2 *pool[4];
	int state;
	long unsigned int hcd_priv[0];
};

struct hc_driver___4 {
	const char *description;
	const char *product_desc;
	size_t hcd_priv_size;
	irqreturn_t (*irq)(struct usb_hcd___4 *);
	int flags;
	int (*reset)(struct usb_hcd___4 *);
	int (*start)(struct usb_hcd___4 *);
	int (*pci_suspend)(struct usb_hcd___4 *, bool);
	int (*pci_resume)(struct usb_hcd___4 *, bool);
	void (*stop)(struct usb_hcd___4 *);
	void (*shutdown)(struct usb_hcd___4 *);
	int (*get_frame_number)(struct usb_hcd___4 *);
	int (*urb_enqueue)(struct usb_hcd___4 *, struct urb___4 *, gfp_t);
	int (*urb_dequeue)(struct usb_hcd___4 *, struct urb___4 *, int);
	int (*map_urb_for_dma)(struct usb_hcd___4 *, struct urb___4 *, gfp_t);
	void (*unmap_urb_for_dma)(struct usb_hcd___4 *, struct urb___4 *);
	void (*endpoint_disable)(struct usb_hcd___4 *, struct usb_host_endpoint *);
	void (*endpoint_reset)(struct usb_hcd___4 *, struct usb_host_endpoint *);
	int (*hub_status_data)(struct usb_hcd___4 *, char *);
	int (*hub_control)(struct usb_hcd___4 *, u16, u16, u16, char *, u16);
	int (*bus_suspend)(struct usb_hcd___4 *);
	int (*bus_resume)(struct usb_hcd___4 *);
	int (*start_port_reset)(struct usb_hcd___4 *, unsigned int);
	long unsigned int (*get_resuming_ports)(struct usb_hcd___4 *);
	void (*relinquish_port)(struct usb_hcd___4 *, int);
	int (*port_handed_over)(struct usb_hcd___4 *, int);
	void (*clear_tt_buffer_complete)(struct usb_hcd___4 *, struct usb_host_endpoint *);
	int (*alloc_dev)(struct usb_hcd___4 *, struct usb_device___4 *);
	void (*free_dev)(struct usb_hcd___4 *, struct usb_device___4 *);
	int (*alloc_streams)(struct usb_hcd___4 *, struct usb_device___4 *, struct usb_host_endpoint **, unsigned int, unsigned int, gfp_t);
	int (*free_streams)(struct usb_hcd___4 *, struct usb_device___4 *, struct usb_host_endpoint **, unsigned int, gfp_t);
	int (*add_endpoint)(struct usb_hcd___4 *, struct usb_device___4 *, struct usb_host_endpoint *);
	int (*drop_endpoint)(struct usb_hcd___4 *, struct usb_device___4 *, struct usb_host_endpoint *);
	int (*check_bandwidth)(struct usb_hcd___4 *, struct usb_device___4 *);
	void (*reset_bandwidth)(struct usb_hcd___4 *, struct usb_device___4 *);
	int (*address_device)(struct usb_hcd___4 *, struct usb_device___4 *);
	int (*enable_device)(struct usb_hcd___4 *, struct usb_device___4 *);
	int (*update_hub_device)(struct usb_hcd___4 *, struct usb_device___4 *, struct usb_tt___4 *, gfp_t);
	int (*reset_device)(struct usb_hcd___4 *, struct usb_device___4 *);
	int (*update_device)(struct usb_hcd___4 *, struct usb_device___4 *);
	int (*set_usb2_hw_lpm)(struct usb_hcd___4 *, struct usb_device___4 *, int);
	int (*enable_usb3_lpm_timeout)(struct usb_hcd___4 *, struct usb_device___4 *, enum usb3_link_state);
	int (*disable_usb3_lpm_timeout)(struct usb_hcd___4 *, struct usb_device___4 *, enum usb3_link_state);
	int (*find_raw_port_number)(struct usb_hcd___4 *, int);
	int (*port_power)(struct usb_hcd___4 *, int, bool);
};

struct usb_otg___4;

struct usb_phy_io_ops___4;

struct usb_phy___4 {
	struct device___338 *dev;
	const char *label;
	unsigned int flags;
	enum usb_phy_type type;
	enum usb_phy_events last_event;
	struct usb_otg___4 *otg;
	struct device___338 *io_dev;
	struct usb_phy_io_ops___4 *io_ops;
	void *io_priv;
	struct extcon_dev *edev;
	struct extcon_dev *id_edev;
	struct notifier_block vbus_nb;
	struct notifier_block id_nb;
	struct notifier_block type_nb;
	enum usb_charger_type chg_type;
	enum usb_charger_state chg_state;
	struct usb_charger_current chg_cur;
	struct work_struct chg_work;
	struct atomic_notifier_head notifier;
	u16 port_status;
	u16 port_change;
	struct list_head head;
	int (*init)(struct usb_phy___4 *);
	void (*shutdown)(struct usb_phy___4 *);
	int (*set_vbus)(struct usb_phy___4 *, int);
	int (*set_power)(struct usb_phy___4 *, unsigned int);
	int (*set_suspend)(struct usb_phy___4 *, int);
	int (*set_wakeup)(struct usb_phy___4 *, bool);
	int (*notify_connect)(struct usb_phy___4 *, enum usb_device_speed);
	int (*notify_disconnect)(struct usb_phy___4 *, enum usb_device_speed);
	enum usb_charger_type (*charger_detect)(struct usb_phy___4 *);
};

struct usb_mon_operations___4 {
	void (*urb_submit)(struct usb_bus___4 *, struct urb___4 *);
	void (*urb_submit_error)(struct usb_bus___4 *, struct urb___4 *, int);
	void (*urb_complete)(struct usb_bus___4 *, struct urb___4 *, int);
};

struct phy___10;

struct phy_ops___9 {
	int (*init)(struct phy___10 *);
	int (*exit)(struct phy___10 *);
	int (*power_on)(struct phy___10 *);
	int (*power_off)(struct phy___10 *);
	int (*set_mode)(struct phy___10 *, enum phy_mode);
	int (*reset)(struct phy___10 *);
	int (*calibrate)(struct phy___10 *);
	struct module___302 *owner;
};

struct phy___10 {
	struct device___338 dev;
	int id;
	const struct phy_ops___9 *ops;
	struct mutex mutex;
	int init_count;
	int power_count;
	struct phy_attrs attrs;
	struct regulator *pwr;
};

struct usb_phy_io_ops___4 {
	int (*read)(struct usb_phy___4 *, u32);
	int (*write)(struct usb_phy___4 *, u32, u32);
};

struct usb_otg___4 {
	u8 default_a;
	struct phy___10 *phy;
	struct usb_phy___4 *usb_phy;
	struct usb_bus___4 *host;
	struct usb_gadget *gadget;
	enum usb_otg_state state;
	int (*set_host)(struct usb_otg___4 *, struct usb_bus___4 *);
	int (*set_peripheral)(struct usb_otg___4 *, struct usb_gadget *);
	int (*set_vbus)(struct usb_otg___4 *, bool);
	int (*start_srp)(struct usb_otg___4 *);
	int (*start_hnp)(struct usb_otg___4 *);
};

struct api_context {
	struct completion done;
	int status;
};

struct set_config_request {
	struct usb_device___4 *udev;
	int config;
	struct work_struct work;
	struct list_head node;
};

struct driver_attribute___3 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___64 *, char *);
	ssize_t (*store)(struct device_driver___64 *, const char *, size_t);
};

struct usb_interface___5 {
	struct usb_host_interface *altsetting;
	struct usb_host_interface *cur_altsetting;
	unsigned int num_altsetting;
	struct usb_interface_assoc_descriptor *intf_assoc;
	int minor;
	enum usb_interface_condition condition;
	unsigned int sysfs_files_created: 1;
	unsigned int ep_devs_created: 1;
	unsigned int unregistering: 1;
	unsigned int needs_remote_wakeup: 1;
	unsigned int needs_altsetting0: 1;
	unsigned int needs_binding: 1;
	unsigned int resetting_device: 1;
	unsigned int authorized: 1;
	struct device___64 dev;
	struct device___64 *usb_dev;
	atomic_t pm_usage_cnt;
	struct work_struct reset_ws;
};

struct usb_host_config___5 {
	struct usb_config_descriptor desc;
	char *string;
	struct usb_interface_assoc_descriptor *intf_assoc[16];
	struct usb_interface___5 *interface[32];
	struct usb_interface_cache *intf_cache[32];
	unsigned char *extra;
	int extralen;
};

struct usb_device___5;

struct usb_bus___5 {
	struct device___64 *controller;
	struct device___64 *sysdev;
	int busnum;
	const char *bus_name;
	u8 uses_dma;
	u8 uses_pio_for_control;
	u8 otg_port;
	unsigned int is_b_host: 1;
	unsigned int b_hnp_enable: 1;
	unsigned int no_stop_on_short: 1;
	unsigned int no_sg_constraint: 1;
	unsigned int sg_tablesize;
	int devnum_next;
	struct mutex devnum_next_mutex;
	struct usb_devmap devmap;
	struct usb_device___5 *root_hub;
	struct usb_bus___5 *hs_companion;
	int bandwidth_allocated;
	int bandwidth_int_reqs;
	int bandwidth_isoc_reqs;
	unsigned int resuming_ports;
	struct mon_bus *mon_bus;
	int monitored;
};

struct usb_tt___5;

struct usb_device___5 {
	int devnum;
	char devpath[16];
	u32 route;
	enum usb_device_state state;
	enum usb_device_speed speed;
	unsigned int rx_lanes;
	unsigned int tx_lanes;
	struct usb_tt___5 *tt;
	int ttport;
	unsigned int toggle[2];
	struct usb_device___5 *parent;
	struct usb_bus___5 *bus;
	struct usb_host_endpoint ep0;
	struct device___64 dev;
	struct usb_device_descriptor descriptor;
	struct usb_host_bos *bos;
	struct usb_host_config___5 *config;
	struct usb_host_config___5 *actconfig;
	struct usb_host_endpoint *ep_in[16];
	struct usb_host_endpoint *ep_out[16];
	char **rawdescriptors;
	short unsigned int bus_mA;
	u8 portnum;
	u8 level;
	unsigned int can_submit: 1;
	unsigned int persist_enabled: 1;
	unsigned int have_langid: 1;
	unsigned int authorized: 1;
	unsigned int authenticated: 1;
	unsigned int wusb: 1;
	unsigned int lpm_capable: 1;
	unsigned int usb2_hw_lpm_capable: 1;
	unsigned int usb2_hw_lpm_besl_capable: 1;
	unsigned int usb2_hw_lpm_enabled: 1;
	unsigned int usb2_hw_lpm_allowed: 1;
	unsigned int usb3_lpm_u1_enabled: 1;
	unsigned int usb3_lpm_u2_enabled: 1;
	int string_langid;
	char *product;
	char *manufacturer;
	char *serial;
	struct list_head filelist;
	int maxchild;
	u32 quirks;
	atomic_t urbnum;
	long unsigned int active_duration;
	long unsigned int connect_time;
	unsigned int do_remote_wakeup: 1;
	unsigned int reset_resume: 1;
	unsigned int port_is_suspended: 1;
	struct wusb_dev *wusb_dev;
	int slot_id;
	enum usb_device_removable removable;
	struct usb2_lpm_parameters l1_params;
	struct usb3_lpm_parameters u1_params;
	struct usb3_lpm_parameters u2_params;
	unsigned int lpm_disable_count;
	u16 hub_delay;
};

struct usb_tt___5 {
	struct usb_device___5 *hub;
	int multi;
	unsigned int think_time;
	void *hcpriv;
	spinlock_t lock;
	struct list_head clear_list;
	struct work_struct clear_work;
};

struct usb_dynid {
	struct list_head node;
	struct usb_device_id id;
};

struct usbdrv_wrap___5 {
	struct device_driver___64 driver;
	int for_devices;
};

struct usb_driver___5 {
	const char *name;
	int (*probe)(struct usb_interface___5 *, const struct usb_device_id *);
	void (*disconnect)(struct usb_interface___5 *);
	int (*unlocked_ioctl)(struct usb_interface___5 *, unsigned int, void *);
	int (*suspend)(struct usb_interface___5 *, pm_message_t);
	int (*resume)(struct usb_interface___5 *);
	int (*reset_resume)(struct usb_interface___5 *);
	int (*pre_reset)(struct usb_interface___5 *);
	int (*post_reset)(struct usb_interface___5 *);
	const struct usb_device_id *id_table;
	struct usb_dynids dynids;
	struct usbdrv_wrap___5 drvwrap;
	unsigned int no_dynamic_id: 1;
	unsigned int supports_autosuspend: 1;
	unsigned int disable_hub_initiated_lpm: 1;
	unsigned int soft_unbind: 1;
};

struct usb_device_driver___5 {
	const char *name;
	int (*probe)(struct usb_device___5 *);
	void (*disconnect)(struct usb_device___5 *);
	int (*suspend)(struct usb_device___5 *, pm_message_t);
	int (*resume)(struct usb_device___5 *, pm_message_t);
	struct usbdrv_wrap___5 drvwrap;
	unsigned int supports_autosuspend: 1;
};

struct urb___5;

typedef void (*usb_complete_t___5)(struct urb___5 *);

struct urb___5 {
	struct kref kref;
	void *hcpriv;
	atomic_t use_count;
	atomic_t reject;
	int unlinked;
	struct list_head urb_list;
	struct list_head anchor_list;
	struct usb_anchor *anchor;
	struct usb_device___5 *dev;
	struct usb_host_endpoint *ep;
	unsigned int pipe;
	unsigned int stream_id;
	int status;
	unsigned int transfer_flags;
	void *transfer_buffer;
	dma_addr_t transfer_dma;
	struct scatterlist *sg;
	int num_mapped_sgs;
	int num_sgs;
	u32 transfer_buffer_length;
	u32 actual_length;
	unsigned char *setup_packet;
	dma_addr_t setup_dma;
	int start_frame;
	int number_of_packets;
	int interval;
	int error_count;
	void *context;
	usb_complete_t___5 complete;
	struct usb_iso_packet_descriptor iso_frame_desc[0];
};

struct hc_driver___5;

struct usb_hcd___5 {
	struct usb_bus___5 self;
	struct kref kref;
	const char *product_desc;
	int speed;
	char irq_descr[24];
	struct timer_list rh_timer;
	struct urb___5 *status_urb;
	struct work_struct wakeup_work;
	const struct hc_driver___5 *driver;
	struct usb_phy___3 *usb_phy;
	struct usb_phy_roothub *phy_roothub;
	long unsigned int flags;
	unsigned int rh_registered: 1;
	unsigned int rh_pollable: 1;
	unsigned int msix_enabled: 1;
	unsigned int msi_enabled: 1;
	unsigned int skip_phy_initialization: 1;
	unsigned int uses_new_polling: 1;
	unsigned int wireless: 1;
	unsigned int has_tt: 1;
	unsigned int amd_resume_bug: 1;
	unsigned int can_do_streams: 1;
	unsigned int tpl_support: 1;
	unsigned int cant_recv_wakeups: 1;
	unsigned int irq;
	void *regs;
	resource_size_t rsrc_start;
	resource_size_t rsrc_len;
	unsigned int power_budget;
	struct giveback_urb_bh high_prio_bh;
	struct giveback_urb_bh low_prio_bh;
	struct mutex *address0_mutex;
	struct mutex *bandwidth_mutex;
	struct usb_hcd___5 *shared_hcd;
	struct usb_hcd___5 *primary_hcd;
	struct dma_pool___2 *pool[4];
	int state;
	long unsigned int hcd_priv[0];
};

struct hc_driver___5 {
	const char *description;
	const char *product_desc;
	size_t hcd_priv_size;
	irqreturn_t (*irq)(struct usb_hcd___5 *);
	int flags;
	int (*reset)(struct usb_hcd___5 *);
	int (*start)(struct usb_hcd___5 *);
	int (*pci_suspend)(struct usb_hcd___5 *, bool);
	int (*pci_resume)(struct usb_hcd___5 *, bool);
	void (*stop)(struct usb_hcd___5 *);
	void (*shutdown)(struct usb_hcd___5 *);
	int (*get_frame_number)(struct usb_hcd___5 *);
	int (*urb_enqueue)(struct usb_hcd___5 *, struct urb___5 *, gfp_t);
	int (*urb_dequeue)(struct usb_hcd___5 *, struct urb___5 *, int);
	int (*map_urb_for_dma)(struct usb_hcd___5 *, struct urb___5 *, gfp_t);
	void (*unmap_urb_for_dma)(struct usb_hcd___5 *, struct urb___5 *);
	void (*endpoint_disable)(struct usb_hcd___5 *, struct usb_host_endpoint *);
	void (*endpoint_reset)(struct usb_hcd___5 *, struct usb_host_endpoint *);
	int (*hub_status_data)(struct usb_hcd___5 *, char *);
	int (*hub_control)(struct usb_hcd___5 *, u16, u16, u16, char *, u16);
	int (*bus_suspend)(struct usb_hcd___5 *);
	int (*bus_resume)(struct usb_hcd___5 *);
	int (*start_port_reset)(struct usb_hcd___5 *, unsigned int);
	long unsigned int (*get_resuming_ports)(struct usb_hcd___5 *);
	void (*relinquish_port)(struct usb_hcd___5 *, int);
	int (*port_handed_over)(struct usb_hcd___5 *, int);
	void (*clear_tt_buffer_complete)(struct usb_hcd___5 *, struct usb_host_endpoint *);
	int (*alloc_dev)(struct usb_hcd___5 *, struct usb_device___5 *);
	void (*free_dev)(struct usb_hcd___5 *, struct usb_device___5 *);
	int (*alloc_streams)(struct usb_hcd___5 *, struct usb_device___5 *, struct usb_host_endpoint **, unsigned int, unsigned int, gfp_t);
	int (*free_streams)(struct usb_hcd___5 *, struct usb_device___5 *, struct usb_host_endpoint **, unsigned int, gfp_t);
	int (*add_endpoint)(struct usb_hcd___5 *, struct usb_device___5 *, struct usb_host_endpoint *);
	int (*drop_endpoint)(struct usb_hcd___5 *, struct usb_device___5 *, struct usb_host_endpoint *);
	int (*check_bandwidth)(struct usb_hcd___5 *, struct usb_device___5 *);
	void (*reset_bandwidth)(struct usb_hcd___5 *, struct usb_device___5 *);
	int (*address_device)(struct usb_hcd___5 *, struct usb_device___5 *);
	int (*enable_device)(struct usb_hcd___5 *, struct usb_device___5 *);
	int (*update_hub_device)(struct usb_hcd___5 *, struct usb_device___5 *, struct usb_tt___5 *, gfp_t);
	int (*reset_device)(struct usb_hcd___5 *, struct usb_device___5 *);
	int (*update_device)(struct usb_hcd___5 *, struct usb_device___5 *);
	int (*set_usb2_hw_lpm)(struct usb_hcd___5 *, struct usb_device___5 *, int);
	int (*enable_usb3_lpm_timeout)(struct usb_hcd___5 *, struct usb_device___5 *, enum usb3_link_state);
	int (*disable_usb3_lpm_timeout)(struct usb_hcd___5 *, struct usb_device___5 *, enum usb3_link_state);
	int (*find_raw_port_number)(struct usb_hcd___5 *, int);
	int (*port_power)(struct usb_hcd___5 *, int, bool);
};

struct usb_mon_operations___5 {
	void (*urb_submit)(struct usb_bus___5 *, struct urb___5 *);
	void (*urb_submit_error)(struct usb_bus___5 *, struct urb___5 *, int);
	void (*urb_complete)(struct usb_bus___5 *, struct urb___5 *, int);
};

struct usb_dev_cap_header {
	__u8 bLength;
	__u8 bDescriptorType;
	__u8 bDevCapabilityType;
};

struct usb_class_driver {
	char *name;
	char * (*devnode)(struct device___345 *, umode_t *);
	const struct file_operations___378 *fops;
	int minor_base;
};

struct usb_class {
	struct kref kref;
	struct class___345 *class;
};

struct device_attribute___52 {
	struct attribute attr;
	ssize_t (*show)(struct device___64 *, struct device_attribute___52 *, char *);
	ssize_t (*store)(struct device___64 *, struct device_attribute___52 *, const char *, size_t);
};

struct ep_device {
	struct usb_endpoint_descriptor *desc;
	struct usb_device___5 *udev;
	struct device___64 dev;
};

struct module___310;

struct file___379;

struct kiocb___379;

struct poll_table_struct___228;

struct vm_area_struct___380;

struct inode___379;

struct file_lock___379;

struct page___380;

struct seq_file___321;

struct file_operations___379 {
	struct module___310 *owner;
	loff_t (*llseek)(struct file___379 *, loff_t, int);
	ssize_t (*read)(struct file___379 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___379 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___379 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___379 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___379 *, bool);
	int (*iterate)(struct file___379 *, struct dir_context *);
	int (*iterate_shared)(struct file___379 *, struct dir_context *);
	__poll_t (*poll)(struct file___379 *, struct poll_table_struct___228 *);
	long int (*unlocked_ioctl)(struct file___379 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___379 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___379 *, struct vm_area_struct___380 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___379 *, struct file___379 *);
	int (*flush)(struct file___379 *, fl_owner_t);
	int (*release)(struct inode___379 *, struct file___379 *);
	int (*fsync)(struct file___379 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___379 *, int);
	int (*lock)(struct file___379 *, int, struct file_lock___379 *);
	ssize_t (*sendpage)(struct file___379 *, struct page___380 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___379 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___379 *, int, struct file_lock___379 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___379 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___379 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___379 *, long int, struct file_lock___379 **, void **);
	long int (*fallocate)(struct file___379 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___321 *, struct file___379 *);
	ssize_t (*copy_file_range)(struct file___379 *, loff_t, struct file___379 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___379 *, loff_t, struct file___379 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___379 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___379 {
	u64 seqnum;
	struct vm_area_struct___380 *vmas[4];
};

struct page_frag___379 {
	struct page___380 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___379;

struct cred___348;

struct signal_struct___260;

struct vm_struct___285;

struct task_struct___380 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___380 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___379 *mm;
	struct mm_struct___379 *active_mm;
	struct vmacache___379 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___380 *real_parent;
	struct task_struct___380 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___380 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___219 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___219 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___219 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___348 *ptracer_cred;
	const struct cred___348 *real_cred;
	const struct cred___348 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___280 *nsproxy;
	struct signal_struct___260 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___380 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___107 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___379 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___380 *oom_reaper_list;
	struct vm_struct___285 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___143 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___378;

struct super_block___378;

struct dentry___378 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___378 *d_parent;
	struct qstr d_name;
	struct inode___379 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___378 *d_op;
	struct super_block___378 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct rw_semaphore___380 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___380 *owner;
};

struct address_space_operations___378;

struct address_space___378 {
	struct inode___379 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___380 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___378 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___378;

struct block_device___378;

struct cdev___92;

struct inode___379 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___378 *i_op;
	struct super_block___378 *i_sb;
	struct address_space___378 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___380 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___379 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___378 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___378 *i_bdev;
		struct cdev___92 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___379;

struct dentry_operations___378 {
	int (*d_revalidate)(struct dentry___378 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___378 *, unsigned int);
	int (*d_hash)(const struct dentry___378 *, struct qstr *);
	int (*d_compare)(const struct dentry___378 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___378 *);
	int (*d_init)(struct dentry___378 *);
	void (*d_release)(struct dentry___378 *);
	void (*d_prune)(struct dentry___378 *);
	void (*d_iput)(struct dentry___378 *, struct inode___379 *);
	char * (*d_dname)(struct dentry___378 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___379 *);
	int (*d_manage)(const struct path___379 *, bool);
	struct dentry___378 * (*d_real)(struct dentry___378 *, const struct inode___379 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___378;

struct mem_dqinfo___378 {
	struct quota_format_type___378 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___378;

struct quota_info___378 {
	unsigned int flags;
	struct rw_semaphore___380 dqio_sem;
	struct inode___379 *files[3];
	struct mem_dqinfo___378 info[3];
	const struct quota_format_ops___378 *ops[3];
};

struct rcuwait___378 {
	struct task_struct___380 *task;
};

struct percpu_rw_semaphore___378 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___380 rw_sem;
	struct rcuwait___378 writer;
	int readers_block;
};

struct sb_writers___378 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___378 rw_sem[3];
};

struct file_system_type___378;

struct super_operations___378;

struct dquot_operations___378;

struct quotactl_ops___378;

struct user_namespace___251;

struct super_block___378 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___378 *s_type;
	const struct super_operations___378 *s_op;
	const struct dquot_operations___378 *dq_op;
	const struct quotactl_ops___378 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___378 *s_root;
	struct rw_semaphore___380 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___378 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___378 s_dquot;
	struct sb_writers___378 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___378 *s_d_op;
	int cleancache_poolid;
	struct shrinker___134 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___251 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct path___379 {
	struct vfsmount *mnt;
	struct dentry___378 *dentry;
};

struct key___348;

struct ucounts___251;

struct user_namespace___251 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___251 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___9 ns;
	long unsigned int flags;
	struct key___348 *persistent_keyring_register;
	struct rw_semaphore___380 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___251 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___380 *pgtable_t___379;

struct dev_pagemap___367;

struct page___380 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___378 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___380 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___379 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___379 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___367 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___379;

struct lruvec___379 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___379 *pgdat;
};

struct zone___379 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___379 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___379 {
	struct zone___379 *zone;
	int zone_idx;
};

struct zonelist___379 {
	struct zoneref___379 _zonerefs[25];
};

struct pglist_data___379 {
	struct zone___379 node_zones[3];
	struct zonelist___379 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___380 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___380 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___379 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___380 {
	void *stack;
	struct task_struct___380 *task;
	long int status;
};

struct blocking_notifier_head___379 {
	struct rw_semaphore___380 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___367;

struct vm_area_struct___380 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___380 *vm_next;
	struct vm_area_struct___380 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___379 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___367 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___379 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___379;

struct mm_struct___379 {
	struct {
		struct vm_area_struct___380 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___379 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___380 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___379 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___380 *owner;
		struct user_namespace___251 *user_ns;
		struct file___379 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___379 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___367)(struct vm_area_struct___380 *, long unsigned int, const struct page___380 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___367)(struct page___380 *, void *);

struct device___346;

struct dev_pagemap___367 {
	dev_page_fault_t___367 page_fault;
	dev_page_free_t___367 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___346 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct file___379 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___379 f_path;
	struct inode___379 *f_inode;
	const struct file_operations___379 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___219 f_owner;
	const struct cred___348 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___378 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___367;

struct vm_operations_struct___367 {
	void (*open)(struct vm_area_struct___380 *);
	void (*close)(struct vm_area_struct___380 *);
	int (*split)(struct vm_area_struct___380 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___380 *);
	vm_fault_t (*fault)(struct vm_fault___367 *);
	vm_fault_t (*huge_fault)(struct vm_fault___367 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___367 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___380 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___367 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___367 *);
	int (*access)(struct vm_area_struct___380 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___380 *);
	int (*set_policy)(struct vm_area_struct___380 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___380 *, long unsigned int);
	struct page___380 * (*find_special_page)(struct vm_area_struct___380 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___379 {
	struct task_struct___380 *task;
	struct core_thread___379 *next;
};

struct core_state___379 {
	atomic_t nr_threads;
	struct core_thread___379 dumper;
	struct completion startup;
};

struct vm_fault___367 {
	struct vm_area_struct___380 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___380 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___380 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___379 prealloc_pte;
};

struct user_struct___348 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___348 *uid_keyring;
	struct key___348 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___348 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___348 *session_keyring;
	struct key___348 *process_keyring;
	struct key___348 *thread_keyring;
	struct key___348 *request_key_auth;
	void *security;
	struct user_struct___348 *user;
	struct user_namespace___251 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct signal_struct___260 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___380 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___380 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___219 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___219 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___379 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___219 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_struct___285 {
	struct vm_struct___285 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___380 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___272 {
	struct task_struct___380 task;
	long unsigned int stack[8192];
};

struct kiocb___379 {
	struct file___379 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___379 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___378 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___379 *ia_file;
};

struct dquot___378 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___378 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___378 {
	int qf_fmt_id;
	const struct quota_format_ops___378 *qf_ops;
	struct module___310 *qf_owner;
	struct quota_format_type___378 *qf_next;
};

struct quota_format_ops___378 {
	int (*check_quota_file)(struct super_block___378 *, int);
	int (*read_file_info)(struct super_block___378 *, int);
	int (*write_file_info)(struct super_block___378 *, int);
	int (*free_file_info)(struct super_block___378 *, int);
	int (*read_dqblk)(struct dquot___378 *);
	int (*commit_dqblk)(struct dquot___378 *);
	int (*release_dqblk)(struct dquot___378 *);
	int (*get_next_id)(struct super_block___378 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___378 {
	int (*write_dquot)(struct dquot___378 *);
	struct dquot___378 * (*alloc_dquot)(struct super_block___378 *, int);
	void (*destroy_dquot)(struct dquot___378 *);
	int (*acquire_dquot)(struct dquot___378 *);
	int (*release_dquot)(struct dquot___378 *);
	int (*mark_dirty)(struct dquot___378 *);
	int (*write_info)(struct super_block___378 *, int);
	qsize_t * (*get_reserved_space)(struct inode___379 *);
	int (*get_projid)(struct inode___379 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___379 *, qsize_t *);
	int (*get_next_id)(struct super_block___378 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___378 {
	int (*quota_on)(struct super_block___378 *, int, int, const struct path___379 *);
	int (*quota_off)(struct super_block___378 *, int);
	int (*quota_enable)(struct super_block___378 *, unsigned int);
	int (*quota_disable)(struct super_block___378 *, unsigned int);
	int (*quota_sync)(struct super_block___378 *, int);
	int (*set_info)(struct super_block___378 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___378 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___378 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___378 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___378 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___378 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___365;

struct kobj_type___365;

struct kernfs_node___373;

struct kobject___366 {
	const char *name;
	struct list_head entry;
	struct kobject___366 *parent;
	struct kset___365 *kset;
	struct kobj_type___365 *ktype;
	struct kernfs_node___373 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___307 {
	struct kobject___366 kobj;
	struct module___310 *mod;
	struct kobject___366 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___307 {
	struct module___310 *mod;
	struct latch_tree_node node;
};

struct module_layout___307 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___307 mtn;
};

struct module_attribute___307;

struct kernel_param___307;

struct module___310 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___307 mkobj;
	struct module_attribute___307 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___366 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___307 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___307 core_layout;
	struct module_layout___307 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___378 {
	int (*writepage)(struct page___380 *, struct writeback_control___3 *);
	int (*readpage)(struct file___379 *, struct page___380 *);
	int (*writepages)(struct address_space___378 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___380 *);
	int (*readpages)(struct file___379 *, struct address_space___378 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___379 *, struct address_space___378 *, loff_t, unsigned int, unsigned int, struct page___380 **, void **);
	int (*write_end)(struct file___379 *, struct address_space___378 *, loff_t, unsigned int, unsigned int, struct page___380 *, void *);
	sector_t (*bmap)(struct address_space___378 *, sector_t);
	void (*invalidatepage)(struct page___380 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___380 *, gfp_t);
	void (*freepage)(struct page___380 *);
	ssize_t (*direct_IO)(struct kiocb___379 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___378 *, struct page___380 *, struct page___380 *, enum migrate_mode);
	bool (*isolate_page)(struct page___380 *, isolate_mode_t);
	void (*putback_page)(struct page___380 *);
	int (*launder_page)(struct page___380 *);
	int (*is_partially_uptodate)(struct page___380 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___380 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___378 *, struct page___380 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___379 *, sector_t *);
	void (*swap_deactivate)(struct file___379 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___378 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___379 *bd_inode;
	struct super_block___378 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___378 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___92 {
	struct kobject___366 kobj;
	struct module___310 *owner;
	const struct file_operations___379 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___378 {
	struct dentry___378 * (*lookup)(struct inode___379 *, struct dentry___378 *, unsigned int);
	const char * (*get_link)(struct dentry___378 *, struct inode___379 *, struct delayed_call *);
	int (*permission)(struct inode___379 *, int);
	struct posix_acl * (*get_acl)(struct inode___379 *, int);
	int (*readlink)(struct dentry___378 *, char *, int);
	int (*create)(struct inode___379 *, struct dentry___378 *, umode_t, bool);
	int (*link)(struct dentry___378 *, struct inode___379 *, struct dentry___378 *);
	int (*unlink)(struct inode___379 *, struct dentry___378 *);
	int (*symlink)(struct inode___379 *, struct dentry___378 *, const char *);
	int (*mkdir)(struct inode___379 *, struct dentry___378 *, umode_t);
	int (*rmdir)(struct inode___379 *, struct dentry___378 *);
	int (*mknod)(struct inode___379 *, struct dentry___378 *, umode_t, dev_t);
	int (*rename)(struct inode___379 *, struct dentry___378 *, struct inode___379 *, struct dentry___378 *, unsigned int);
	int (*setattr)(struct dentry___378 *, struct iattr___378 *);
	int (*getattr)(const struct path___379 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___378 *, char *, size_t);
	int (*fiemap)(struct inode___379 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___379 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___379 *, struct dentry___378 *, struct file___379 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___379 *, struct dentry___378 *, umode_t);
	int (*set_acl)(struct inode___379 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___378 {
	void (*fl_copy_lock)(struct file_lock___379 *, struct file_lock___379 *);
	void (*fl_release_private)(struct file_lock___379 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___378;

struct lock_manager_operations___378;

struct file_lock___379 {
	struct file_lock___379 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___379 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___378 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___378 *fl_ops;
	const struct lock_manager_operations___378 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___378 {
	int (*lm_compare_owner)(struct file_lock___379 *, struct file_lock___379 *);
	long unsigned int (*lm_owner_key)(struct file_lock___379 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___379 *);
	int (*lm_grant)(struct file_lock___379 *, int);
	bool (*lm_break)(struct file_lock___379 *);
	int (*lm_change)(struct file_lock___379 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___379 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___378 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___378 *fa_next;
	struct file___379 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___378 {
	const char *name;
	int fs_flags;
	struct dentry___378 * (*mount)(struct file_system_type___378 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___378 *);
	struct module___310 *owner;
	struct file_system_type___378 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___378 {
	struct inode___379 * (*alloc_inode)(struct super_block___378 *);
	void (*destroy_inode)(struct inode___379 *);
	void (*dirty_inode)(struct inode___379 *, int);
	int (*write_inode)(struct inode___379 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___379 *);
	void (*evict_inode)(struct inode___379 *);
	void (*put_super)(struct super_block___378 *);
	int (*sync_fs)(struct super_block___378 *, int);
	int (*freeze_super)(struct super_block___378 *);
	int (*freeze_fs)(struct super_block___378 *);
	int (*thaw_super)(struct super_block___378 *);
	int (*unfreeze_fs)(struct super_block___378 *);
	int (*statfs)(struct dentry___378 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___378 *, int *, char *);
	void (*umount_begin)(struct super_block___378 *);
	int (*show_options)(struct seq_file___321 *, struct dentry___378 *);
	int (*show_devname)(struct seq_file___321 *, struct dentry___378 *);
	int (*show_path)(struct seq_file___321 *, struct dentry___378 *);
	int (*show_stats)(struct seq_file___321 *, struct dentry___378 *);
	ssize_t (*quota_read)(struct super_block___378 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___378 *, int, const char *, size_t, loff_t);
	struct dquot___378 ** (*get_dquots)(struct inode___379 *);
	int (*bdev_try_to_free_page)(struct super_block___378 *, struct page___380 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___378 *, struct shrink_control___134 *);
	long int (*free_cached_objects)(struct super_block___378 *, struct shrink_control___134 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___234)(struct file___379 *, wait_queue_head_t *, struct poll_table_struct___228 *);

struct poll_table_struct___228 {
	poll_queue_proc___234 _qproc;
	__poll_t _key;
};

struct seq_operations___320;

struct seq_file___321 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___320 *op;
	int poll_event;
	const struct file___379 *file;
	void *private;
};

struct dev_pm_info___346 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___6 *subsys_data;
	void (*set_latency_tolerance)(struct device___346 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___346;

struct bus_type___346;

struct device_driver___346;

struct dev_pm_domain___346;

struct dma_map_ops___134;

struct fwnode_handle___268;

struct class___346;

struct attribute_group___343;

struct device___346 {
	struct device___346 *parent;
	struct device_private *p;
	struct kobject___366 kobj;
	const char *init_name;
	const struct device_type___346 *type;
	struct mutex mutex;
	struct bus_type___346 *bus;
	struct device_driver___346 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___346 power;
	struct dev_pm_domain___346 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___134 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___268 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___346 *class;
	const struct attribute_group___343 **groups;
	void (*release)(struct device___346 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct kobj_attribute___357 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___366 *, struct kobj_attribute___357 *, char *);
	ssize_t (*store)(struct kobject___366 *, struct kobj_attribute___357 *, const char *, size_t);
};

typedef void compound_page_dtor___367(struct page___380 *);

typedef int (*key_restrict_link_func_t___349)(struct key___348 *, const struct key_type *, const union key_payload *, struct key___348 *);

struct key_restriction___348;

struct key___348 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___380 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___348 *restrict_link;
};

struct key_restriction___348 {
	key_restrict_link_func_t___349 check;
	struct key___348 *key;
	struct key_type *keytype;
};

typedef struct poll_table_struct___228 poll_table___31;

struct kernfs_root___372;

struct kernfs_elem_dir___372 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___372 *root;
};

struct kernfs_syscall_ops___372;

struct kernfs_root___372 {
	struct kernfs_node___373 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___372 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___372 {
	struct kernfs_node___373 *target_kn;
};

struct kernfs_ops___372;

struct kernfs_elem_attr___372 {
	const struct kernfs_ops___372 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___373 *notify_next;
};

struct kernfs_node___373 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___373 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___372 dir;
		struct kernfs_elem_symlink___372 symlink;
		struct kernfs_elem_attr___372 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___372;

struct kernfs_ops___372 {
	int (*open)(struct kernfs_open_file___372 *);
	void (*release)(struct kernfs_open_file___372 *);
	int (*seq_show)(struct seq_file___321 *, void *);
	void * (*seq_start)(struct seq_file___321 *, loff_t *);
	void * (*seq_next)(struct seq_file___321 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___321 *, void *);
	ssize_t (*read)(struct kernfs_open_file___372 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___372 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___372 *, struct vm_area_struct___380 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___372 *, struct poll_table_struct___228 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___372 {
	int (*remount_fs)(struct kernfs_root___372 *, int *, char *);
	int (*show_options)(struct seq_file___321 *, struct kernfs_root___372 *);
	int (*mkdir)(struct kernfs_node___373 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___373 *);
	int (*rename)(struct kernfs_node___373 *, struct kernfs_node___373 *, const char *);
	int (*show_path)(struct seq_file___321 *, struct kernfs_node___373 *, struct kernfs_root___372 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___372 {
	struct kernfs_node___373 *kn;
	struct file___379 *file;
	struct seq_file___321 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___367 *vm_ops;
};

struct bin_attribute___342;

struct attribute_group___343 {
	const char *name;
	umode_t (*is_visible)(struct kobject___366 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___366 *, struct bin_attribute___342 *, int);
	struct attribute **attrs;
	struct bin_attribute___342 **bin_attrs;
};

struct bin_attribute___342 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___379 *, struct kobject___366 *, struct bin_attribute___342 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___379 *, struct kobject___366 *, struct bin_attribute___342 *, char *, loff_t, size_t);
	int (*mmap)(struct file___379 *, struct kobject___366 *, struct bin_attribute___342 *, struct vm_area_struct___380 *);
};

struct sysfs_ops___365 {
	ssize_t (*show)(struct kobject___366 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___366 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___365;

struct kset___365 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___366 kobj;
	const struct kset_uevent_ops___365 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___365 {
	void (*release)(struct kobject___366 *);
	const struct sysfs_ops___365 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___29 * (*child_ns_type)(struct kobject___366 *);
	const void * (*namespace)(struct kobject___366 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___365 {
	int (* const filter)(struct kset___365 *, struct kobject___366 *);
	const char * (* const name)(struct kset___365 *, struct kobject___366 *);
	int (* const uevent)(struct kset___365 *, struct kobject___366 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___307 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___307 *);
	int (*get)(char *, const struct kernel_param___307 *);
	void (*free)(void *);
};

struct kparam_array___307;

struct kernel_param___307 {
	const char *name;
	struct module___310 *mod;
	const struct kernel_param_ops___307 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___307 *arr;
	};
};

struct kparam_array___307 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___307 *ops;
	void *elem;
};

struct module_attribute___307 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___307 *, struct module_kobject___307 *, char *);
	ssize_t (*store)(struct module_attribute___307 *, struct module_kobject___307 *, const char *, size_t);
	void (*setup)(struct module___310 *, const char *);
	int (*test)(struct module___310 *);
	void (*free)(struct module___310 *);
};

struct dev_pm_ops___346 {
	int (*prepare)(struct device___346 *);
	void (*complete)(struct device___346 *);
	int (*suspend)(struct device___346 *);
	int (*resume)(struct device___346 *);
	int (*freeze)(struct device___346 *);
	int (*thaw)(struct device___346 *);
	int (*poweroff)(struct device___346 *);
	int (*restore)(struct device___346 *);
	int (*suspend_late)(struct device___346 *);
	int (*resume_early)(struct device___346 *);
	int (*freeze_late)(struct device___346 *);
	int (*thaw_early)(struct device___346 *);
	int (*poweroff_late)(struct device___346 *);
	int (*restore_early)(struct device___346 *);
	int (*suspend_noirq)(struct device___346 *);
	int (*resume_noirq)(struct device___346 *);
	int (*freeze_noirq)(struct device___346 *);
	int (*thaw_noirq)(struct device___346 *);
	int (*poweroff_noirq)(struct device___346 *);
	int (*restore_noirq)(struct device___346 *);
	int (*runtime_suspend)(struct device___346 *);
	int (*runtime_resume)(struct device___346 *);
	int (*runtime_idle)(struct device___346 *);
};

struct dev_pm_domain___346 {
	struct dev_pm_ops___346 ops;
	void (*detach)(struct device___346 *, bool);
	int (*activate)(struct device___346 *);
	void (*sync)(struct device___346 *);
	void (*dismiss)(struct device___346 *);
};

struct bus_type___346 {
	const char *name;
	const char *dev_name;
	struct device___346 *dev_root;
	const struct attribute_group___343 **bus_groups;
	const struct attribute_group___343 **dev_groups;
	const struct attribute_group___343 **drv_groups;
	int (*match)(struct device___346 *, struct device_driver___346 *);
	int (*uevent)(struct device___346 *, struct kobj_uevent_env *);
	int (*probe)(struct device___346 *);
	int (*remove)(struct device___346 *);
	void (*shutdown)(struct device___346 *);
	int (*online)(struct device___346 *);
	int (*offline)(struct device___346 *);
	int (*suspend)(struct device___346 *, pm_message_t);
	int (*resume)(struct device___346 *);
	int (*num_vf)(struct device___346 *);
	int (*dma_configure)(struct device___346 *);
	const struct dev_pm_ops___346 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___346 {
	const char *name;
	struct bus_type___346 *bus;
	struct module___310 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___346 *);
	int (*remove)(struct device___346 *);
	void (*shutdown)(struct device___346 *);
	int (*suspend)(struct device___346 *, pm_message_t);
	int (*resume)(struct device___346 *);
	const struct attribute_group___343 **groups;
	const struct dev_pm_ops___346 *pm;
	void (*coredump)(struct device___346 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___346 {
	const char *name;
	const struct attribute_group___343 **groups;
	int (*uevent)(struct device___346 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___346 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___346 *);
	const struct dev_pm_ops___346 *pm;
};

struct class___346 {
	const char *name;
	struct module___310 *owner;
	const struct attribute_group___343 **class_groups;
	const struct attribute_group___343 **dev_groups;
	struct kobject___366 *dev_kobj;
	int (*dev_uevent)(struct device___346 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___346 *, umode_t *);
	void (*class_release)(struct class___346 *);
	void (*dev_release)(struct device___346 *);
	int (*shutdown_pre)(struct device___346 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___346 *);
	const struct dev_pm_ops___346 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___134 {
	void * (*alloc)(struct device___346 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___346 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___346 *, struct vm_area_struct___380 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___346 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___346 *, struct page___380 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___346 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___346 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___346 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___346 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___346 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___346 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide21;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___346 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___346 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___346 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___346 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___346 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___346 *, u64);
	u64 (*get_required_mask)(struct device___346 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___268;

struct fwnode_handle___268 {
	struct fwnode_handle___268 *secondary;
	const struct fwnode_operations___268 *ops;
};

struct usb_interface___6 {
	struct usb_host_interface *altsetting;
	struct usb_host_interface *cur_altsetting;
	unsigned int num_altsetting;
	struct usb_interface_assoc_descriptor *intf_assoc;
	int minor;
	enum usb_interface_condition condition;
	unsigned int sysfs_files_created: 1;
	unsigned int ep_devs_created: 1;
	unsigned int unregistering: 1;
	unsigned int needs_remote_wakeup: 1;
	unsigned int needs_altsetting0: 1;
	unsigned int needs_binding: 1;
	unsigned int resetting_device: 1;
	unsigned int authorized: 1;
	struct device___346 dev;
	struct device___346 *usb_dev;
	atomic_t pm_usage_cnt;
	struct work_struct reset_ws;
};

struct usb_host_config___6 {
	struct usb_config_descriptor desc;
	char *string;
	struct usb_interface_assoc_descriptor *intf_assoc[16];
	struct usb_interface___6 *interface[32];
	struct usb_interface_cache *intf_cache[32];
	unsigned char *extra;
	int extralen;
};

struct usb_device___6;

struct usb_bus___6 {
	struct device___346 *controller;
	struct device___346 *sysdev;
	int busnum;
	const char *bus_name;
	u8 uses_dma;
	u8 uses_pio_for_control;
	u8 otg_port;
	unsigned int is_b_host: 1;
	unsigned int b_hnp_enable: 1;
	unsigned int no_stop_on_short: 1;
	unsigned int no_sg_constraint: 1;
	unsigned int sg_tablesize;
	int devnum_next;
	struct mutex devnum_next_mutex;
	struct usb_devmap devmap;
	struct usb_device___6 *root_hub;
	struct usb_bus___6 *hs_companion;
	int bandwidth_allocated;
	int bandwidth_int_reqs;
	int bandwidth_isoc_reqs;
	unsigned int resuming_ports;
	struct mon_bus *mon_bus;
	int monitored;
};

struct usb_tt___6;

struct usb_device___6 {
	int devnum;
	char devpath[16];
	u32 route;
	enum usb_device_state state;
	enum usb_device_speed speed;
	unsigned int rx_lanes;
	unsigned int tx_lanes;
	struct usb_tt___6 *tt;
	int ttport;
	unsigned int toggle[2];
	struct usb_device___6 *parent;
	struct usb_bus___6 *bus;
	struct usb_host_endpoint ep0;
	struct device___346 dev;
	struct usb_device_descriptor descriptor;
	struct usb_host_bos *bos;
	struct usb_host_config___6 *config;
	struct usb_host_config___6 *actconfig;
	struct usb_host_endpoint *ep_in[16];
	struct usb_host_endpoint *ep_out[16];
	char **rawdescriptors;
	short unsigned int bus_mA;
	u8 portnum;
	u8 level;
	unsigned int can_submit: 1;
	unsigned int persist_enabled: 1;
	unsigned int have_langid: 1;
	unsigned int authorized: 1;
	unsigned int authenticated: 1;
	unsigned int wusb: 1;
	unsigned int lpm_capable: 1;
	unsigned int usb2_hw_lpm_capable: 1;
	unsigned int usb2_hw_lpm_besl_capable: 1;
	unsigned int usb2_hw_lpm_enabled: 1;
	unsigned int usb2_hw_lpm_allowed: 1;
	unsigned int usb3_lpm_u1_enabled: 1;
	unsigned int usb3_lpm_u2_enabled: 1;
	int string_langid;
	char *product;
	char *manufacturer;
	char *serial;
	struct list_head filelist;
	int maxchild;
	u32 quirks;
	atomic_t urbnum;
	long unsigned int active_duration;
	long unsigned int connect_time;
	unsigned int do_remote_wakeup: 1;
	unsigned int reset_resume: 1;
	unsigned int port_is_suspended: 1;
	struct wusb_dev *wusb_dev;
	int slot_id;
	enum usb_device_removable removable;
	struct usb2_lpm_parameters l1_params;
	struct usb3_lpm_parameters u1_params;
	struct usb3_lpm_parameters u2_params;
	unsigned int lpm_disable_count;
	u16 hub_delay;
};

struct usb_tt___6 {
	struct usb_device___6 *hub;
	int multi;
	unsigned int think_time;
	void *hcpriv;
	spinlock_t lock;
	struct list_head clear_list;
	struct work_struct clear_work;
};

struct usbdrv_wrap___6 {
	struct device_driver___346 driver;
	int for_devices;
};

struct usb_driver___6 {
	const char *name;
	int (*probe)(struct usb_interface___6 *, const struct usb_device_id *);
	void (*disconnect)(struct usb_interface___6 *);
	int (*unlocked_ioctl)(struct usb_interface___6 *, unsigned int, void *);
	int (*suspend)(struct usb_interface___6 *, pm_message_t);
	int (*resume)(struct usb_interface___6 *);
	int (*reset_resume)(struct usb_interface___6 *);
	int (*pre_reset)(struct usb_interface___6 *);
	int (*post_reset)(struct usb_interface___6 *);
	const struct usb_device_id *id_table;
	struct usb_dynids dynids;
	struct usbdrv_wrap___6 drvwrap;
	unsigned int no_dynamic_id: 1;
	unsigned int supports_autosuspend: 1;
	unsigned int disable_hub_initiated_lpm: 1;
	unsigned int soft_unbind: 1;
};

struct usb_device_driver___6 {
	const char *name;
	int (*probe)(struct usb_device___6 *);
	void (*disconnect)(struct usb_device___6 *);
	int (*suspend)(struct usb_device___6 *, pm_message_t);
	int (*resume)(struct usb_device___6 *, pm_message_t);
	struct usbdrv_wrap___6 drvwrap;
	unsigned int supports_autosuspend: 1;
};

struct urb___6;

typedef void (*usb_complete_t___6)(struct urb___6 *);

struct urb___6 {
	struct kref kref;
	void *hcpriv;
	atomic_t use_count;
	atomic_t reject;
	int unlinked;
	struct list_head urb_list;
	struct list_head anchor_list;
	struct usb_anchor *anchor;
	struct usb_device___6 *dev;
	struct usb_host_endpoint *ep;
	unsigned int pipe;
	unsigned int stream_id;
	int status;
	unsigned int transfer_flags;
	void *transfer_buffer;
	dma_addr_t transfer_dma;
	struct scatterlist *sg;
	int num_mapped_sgs;
	int num_sgs;
	u32 transfer_buffer_length;
	u32 actual_length;
	unsigned char *setup_packet;
	dma_addr_t setup_dma;
	int start_frame;
	int number_of_packets;
	int interval;
	int error_count;
	void *context;
	usb_complete_t___6 complete;
	struct usb_iso_packet_descriptor iso_frame_desc[0];
};

struct usbdevfs_ctrltransfer {
	__u8 bRequestType;
	__u8 bRequest;
	__u16 wValue;
	__u16 wIndex;
	__u16 wLength;
	__u32 timeout;
	void *data;
};

struct usbdevfs_bulktransfer {
	unsigned int ep;
	unsigned int len;
	unsigned int timeout;
	void *data;
};

struct usbdevfs_setinterface {
	unsigned int interface;
	unsigned int altsetting;
};

struct usbdevfs_disconnectsignal {
	unsigned int signr;
	void *context;
};

struct usbdevfs_getdriver {
	unsigned int interface;
	char driver[256];
};

struct usbdevfs_connectinfo {
	unsigned int devnum;
	unsigned char slow;
};

struct usbdevfs_iso_packet_desc {
	unsigned int length;
	unsigned int actual_length;
	unsigned int status;
};

struct usbdevfs_urb {
	unsigned char type;
	unsigned char endpoint;
	int status;
	unsigned int flags;
	void *buffer;
	int buffer_length;
	int actual_length;
	int start_frame;
	union {
		int number_of_packets;
		unsigned int stream_id;
	};
	int error_count;
	unsigned int signr;
	void *usercontext;
	struct usbdevfs_iso_packet_desc iso_frame_desc[0];
};

struct usbdevfs_ioctl {
	int ifno;
	int ioctl_code;
	void *data;
};

struct usbdevfs_disconnect_claim {
	unsigned int interface;
	unsigned int flags;
	char driver[256];
};

struct usbdevfs_streams {
	unsigned int num_streams;
	unsigned int num_eps;
	unsigned char eps[0];
};

struct usb_mon_operations___6 {
	void (*urb_submit)(struct usb_bus___6 *, struct urb___6 *);
	void (*urb_submit_error)(struct usb_bus___6 *, struct urb___6 *, int);
	void (*urb_complete)(struct usb_bus___6 *, struct urb___6 *, int);
};

struct ucounts___251 {
	struct hlist_node node;
	struct user_namespace___251 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct seq_operations___320 {
	void * (*start)(struct seq_file___321 *, loff_t *);
	void (*stop)(struct seq_file___321 *, void *);
	void * (*next)(struct seq_file___321 *, void *, loff_t *);
	int (*show)(struct seq_file___321 *, void *);
};

struct fwnode_reference_args___268;

struct fwnode_endpoint___268;

struct fwnode_operations___268 {
	struct fwnode_handle___268 * (*get)(struct fwnode_handle___268 *);
	void (*put)(struct fwnode_handle___268 *);
	bool (*device_is_available)(const struct fwnode_handle___268 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___268 *, const struct device___346 *);
	bool (*property_present)(const struct fwnode_handle___268 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___268 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___268 *, const char *, const char **, size_t);
	struct fwnode_handle___268 * (*get_parent)(const struct fwnode_handle___268 *);
	struct fwnode_handle___268 * (*get_next_child_node)(const struct fwnode_handle___268 *, struct fwnode_handle___268 *);
	struct fwnode_handle___268 * (*get_named_child_node)(const struct fwnode_handle___268 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___268 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___268 *);
	struct fwnode_handle___268 * (*graph_get_next_endpoint)(const struct fwnode_handle___268 *, struct fwnode_handle___268 *);
	struct fwnode_handle___268 * (*graph_get_remote_endpoint)(const struct fwnode_handle___268 *);
	struct fwnode_handle___268 * (*graph_get_port_parent)(struct fwnode_handle___268 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___268 *, struct fwnode_endpoint___268 *);
};

struct fwnode_endpoint___268 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___268 *local_fwnode;
};

struct fwnode_reference_args___268 {
	struct fwnode_handle___268 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct usb_dev_state___2 {
	struct list_head list;
	struct usb_device___6 *dev;
	struct file___379 *file;
	spinlock_t lock;
	struct list_head async_pending;
	struct list_head async_completed;
	struct list_head memory_list;
	wait_queue_head_t wait;
	unsigned int discsignr;
	struct pid___219 *disc_pid;
	const struct cred___348 *cred;
	void *disccontext;
	long unsigned int ifclaimed;
	u32 disabled_bulk_eps;
	bool privileges_dropped;
	long unsigned int interface_allowed_mask;
};

struct usb_memory {
	struct list_head memlist;
	int vma_use_count;
	int urb_use_count;
	u32 size;
	void *mem;
	dma_addr_t dma_handle;
	long unsigned int vm_start;
	struct usb_dev_state___2 *ps;
};

struct async {
	struct list_head asynclist;
	struct usb_dev_state___2 *ps;
	struct pid___219 *pid;
	const struct cred___348 *cred;
	unsigned int signr;
	unsigned int ifnum;
	void *userbuffer;
	void *userurb;
	struct urb___6 *urb;
	struct usb_memory *usbm;
	unsigned int mem_usage;
	int status;
	u8 bulk_addr;
	u8 bulk_status;
};

enum snoop_when {
	SUBMIT = 0,
	COMPLETE = 1,
};

struct quirk_entry {
	u16 vid;
	u16 pid;
	u32 flags;
};

struct module___311;

struct file___380;

struct kiocb___380;

struct poll_table_struct___229;

struct vm_area_struct___381;

struct inode___380;

struct file_lock___380;

struct page___381;

struct seq_file___322;

struct file_operations___380 {
	struct module___311 *owner;
	loff_t (*llseek)(struct file___380 *, loff_t, int);
	ssize_t (*read)(struct file___380 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___380 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___380 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___380 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___380 *, bool);
	int (*iterate)(struct file___380 *, struct dir_context *);
	int (*iterate_shared)(struct file___380 *, struct dir_context *);
	__poll_t (*poll)(struct file___380 *, struct poll_table_struct___229 *);
	long int (*unlocked_ioctl)(struct file___380 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___380 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___380 *, struct vm_area_struct___381 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___380 *, struct file___380 *);
	int (*flush)(struct file___380 *, fl_owner_t);
	int (*release)(struct inode___380 *, struct file___380 *);
	int (*fsync)(struct file___380 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___380 *, int);
	int (*lock)(struct file___380 *, int, struct file_lock___380 *);
	ssize_t (*sendpage)(struct file___380 *, struct page___381 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___380 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___380 *, int, struct file_lock___380 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___380 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___380 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___380 *, long int, struct file_lock___380 **, void **);
	long int (*fallocate)(struct file___380 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___322 *, struct file___380 *);
	ssize_t (*copy_file_range)(struct file___380 *, loff_t, struct file___380 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___380 *, loff_t, struct file___380 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___380 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___380 {
	u64 seqnum;
	struct vm_area_struct___381 *vmas[4];
};

struct page_frag___380 {
	struct page___381 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___380;

struct cred___349;

struct vm_struct___286;

struct task_struct___381 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___381 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___380 *mm;
	struct mm_struct___380 *active_mm;
	struct vmacache___380 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___381 *real_parent;
	struct task_struct___381 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___381 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___219 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___219 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___219 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___349 *ptracer_cred;
	const struct cred___349 *real_cred;
	const struct cred___349 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___381 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___107 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___380 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___381 *oom_reaper_list;
	struct vm_struct___286 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___143 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___379;

struct super_block___379;

struct dentry___379 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___379 *d_parent;
	struct qstr d_name;
	struct inode___380 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___379 *d_op;
	struct super_block___379 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct rw_semaphore___381 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___381 *owner;
};

struct address_space_operations___379;

struct address_space___379 {
	struct inode___380 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___381 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___379 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___379;

struct block_device___379;

struct cdev___93;

struct inode___380 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___379 *i_op;
	struct super_block___379 *i_sb;
	struct address_space___379 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___381 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___380 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___379 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___379 *i_bdev;
		struct cdev___93 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___380;

struct dentry_operations___379 {
	int (*d_revalidate)(struct dentry___379 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___379 *, unsigned int);
	int (*d_hash)(const struct dentry___379 *, struct qstr *);
	int (*d_compare)(const struct dentry___379 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___379 *);
	int (*d_init)(struct dentry___379 *);
	void (*d_release)(struct dentry___379 *);
	void (*d_prune)(struct dentry___379 *);
	void (*d_iput)(struct dentry___379 *, struct inode___380 *);
	char * (*d_dname)(struct dentry___379 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___380 *);
	int (*d_manage)(const struct path___380 *, bool);
	struct dentry___379 * (*d_real)(struct dentry___379 *, const struct inode___380 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___379;

struct mem_dqinfo___379 {
	struct quota_format_type___379 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___379;

struct quota_info___379 {
	unsigned int flags;
	struct rw_semaphore___381 dqio_sem;
	struct inode___380 *files[3];
	struct mem_dqinfo___379 info[3];
	const struct quota_format_ops___379 *ops[3];
};

struct rcuwait___379 {
	struct task_struct___381 *task;
};

struct percpu_rw_semaphore___379 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___381 rw_sem;
	struct rcuwait___379 writer;
	int readers_block;
};

struct sb_writers___379 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___379 rw_sem[3];
};

struct file_system_type___379;

struct super_operations___379;

struct dquot_operations___379;

struct quotactl_ops___379;

struct super_block___379 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___379 *s_type;
	const struct super_operations___379 *s_op;
	const struct dquot_operations___379 *dq_op;
	const struct quotactl_ops___379 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___379 *s_root;
	struct rw_semaphore___381 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___379 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___379 s_dquot;
	struct sb_writers___379 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___379 *s_d_op;
	int cleancache_poolid;
	struct shrinker___134 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct path___380 {
	struct vfsmount *mnt;
	struct dentry___379 *dentry;
};

typedef struct page___381 *pgtable_t___380;

struct dev_pagemap___368;

struct page___381 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___379 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___381 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___380 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___380 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___368 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___380;

struct lruvec___380 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___380 *pgdat;
};

struct zone___380 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___380 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___380 {
	struct zone___380 *zone;
	int zone_idx;
};

struct zonelist___380 {
	struct zoneref___380 _zonerefs[25];
};

struct pglist_data___380 {
	struct zone___380 node_zones[3];
	struct zonelist___380 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___381 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___381 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___380 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___381 {
	void *stack;
	struct task_struct___381 *task;
	long int status;
};

struct blocking_notifier_head___380 {
	struct rw_semaphore___381 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___368;

struct vm_area_struct___381 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___381 *vm_next;
	struct vm_area_struct___381 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___380 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___368 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___380 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___380;

struct mm_struct___380 {
	struct {
		struct vm_area_struct___381 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___380 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___381 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___380 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___381 *owner;
		struct user_namespace___3 *user_ns;
		struct file___380 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___380 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___368)(struct vm_area_struct___381 *, long unsigned int, const struct page___381 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___368)(struct page___381 *, void *);

struct device___347;

struct dev_pagemap___368 {
	dev_page_fault_t___368 page_fault;
	dev_page_free_t___368 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___347 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct file___380 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___380 f_path;
	struct inode___380 *f_inode;
	const struct file_operations___380 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___219 f_owner;
	const struct cred___349 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___379 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___368;

struct vm_operations_struct___368 {
	void (*open)(struct vm_area_struct___381 *);
	void (*close)(struct vm_area_struct___381 *);
	int (*split)(struct vm_area_struct___381 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___381 *);
	vm_fault_t (*fault)(struct vm_fault___368 *);
	vm_fault_t (*huge_fault)(struct vm_fault___368 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___368 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___381 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___368 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___368 *);
	int (*access)(struct vm_area_struct___381 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___381 *);
	int (*set_policy)(struct vm_area_struct___381 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___381 *, long unsigned int);
	struct page___381 * (*find_special_page)(struct vm_area_struct___381 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___380 {
	struct task_struct___381 *task;
	struct core_thread___380 *next;
};

struct core_state___380 {
	atomic_t nr_threads;
	struct core_thread___380 dumper;
	struct completion startup;
};

struct vm_fault___368 {
	struct vm_area_struct___381 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___381 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___381 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___380 prealloc_pte;
};

struct key___349;

struct user_struct___349 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___349 *uid_keyring;
	struct key___349 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___349 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___349 *session_keyring;
	struct key___349 *process_keyring;
	struct key___349 *thread_keyring;
	struct key___349 *request_key_auth;
	void *security;
	struct user_struct___349 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct vm_struct___286 {
	struct vm_struct___286 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___381 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct kiocb___380 {
	struct file___380 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___380 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___379 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___380 *ia_file;
};

struct dquot___379 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___379 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___379 {
	int qf_fmt_id;
	const struct quota_format_ops___379 *qf_ops;
	struct module___311 *qf_owner;
	struct quota_format_type___379 *qf_next;
};

struct quota_format_ops___379 {
	int (*check_quota_file)(struct super_block___379 *, int);
	int (*read_file_info)(struct super_block___379 *, int);
	int (*write_file_info)(struct super_block___379 *, int);
	int (*free_file_info)(struct super_block___379 *, int);
	int (*read_dqblk)(struct dquot___379 *);
	int (*commit_dqblk)(struct dquot___379 *);
	int (*release_dqblk)(struct dquot___379 *);
	int (*get_next_id)(struct super_block___379 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___379 {
	int (*write_dquot)(struct dquot___379 *);
	struct dquot___379 * (*alloc_dquot)(struct super_block___379 *, int);
	void (*destroy_dquot)(struct dquot___379 *);
	int (*acquire_dquot)(struct dquot___379 *);
	int (*release_dquot)(struct dquot___379 *);
	int (*mark_dirty)(struct dquot___379 *);
	int (*write_info)(struct super_block___379 *, int);
	qsize_t * (*get_reserved_space)(struct inode___380 *);
	int (*get_projid)(struct inode___380 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___380 *, qsize_t *);
	int (*get_next_id)(struct super_block___379 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___379 {
	int (*quota_on)(struct super_block___379 *, int, int, const struct path___380 *);
	int (*quota_off)(struct super_block___379 *, int);
	int (*quota_enable)(struct super_block___379 *, unsigned int);
	int (*quota_disable)(struct super_block___379 *, unsigned int);
	int (*quota_sync)(struct super_block___379 *, int);
	int (*set_info)(struct super_block___379 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___379 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___379 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___379 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___379 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___379 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___366;

struct kobj_type___366;

struct kernfs_node___374;

struct kobject___367 {
	const char *name;
	struct list_head entry;
	struct kobject___367 *parent;
	struct kset___366 *kset;
	struct kobj_type___366 *ktype;
	struct kernfs_node___374 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___308 {
	struct kobject___367 kobj;
	struct module___311 *mod;
	struct kobject___367 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___308 {
	struct module___311 *mod;
	struct latch_tree_node node;
};

struct module_layout___308 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___308 mtn;
};

struct module_attribute___308;

struct kernel_param___308;

struct module___311 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___308 mkobj;
	struct module_attribute___308 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___367 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___308 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___308 core_layout;
	struct module_layout___308 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___379 {
	int (*writepage)(struct page___381 *, struct writeback_control___3 *);
	int (*readpage)(struct file___380 *, struct page___381 *);
	int (*writepages)(struct address_space___379 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___381 *);
	int (*readpages)(struct file___380 *, struct address_space___379 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___380 *, struct address_space___379 *, loff_t, unsigned int, unsigned int, struct page___381 **, void **);
	int (*write_end)(struct file___380 *, struct address_space___379 *, loff_t, unsigned int, unsigned int, struct page___381 *, void *);
	sector_t (*bmap)(struct address_space___379 *, sector_t);
	void (*invalidatepage)(struct page___381 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___381 *, gfp_t);
	void (*freepage)(struct page___381 *);
	ssize_t (*direct_IO)(struct kiocb___380 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___379 *, struct page___381 *, struct page___381 *, enum migrate_mode);
	bool (*isolate_page)(struct page___381 *, isolate_mode_t);
	void (*putback_page)(struct page___381 *);
	int (*launder_page)(struct page___381 *);
	int (*is_partially_uptodate)(struct page___381 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___381 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___379 *, struct page___381 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___380 *, sector_t *);
	void (*swap_deactivate)(struct file___380 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___379 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___380 *bd_inode;
	struct super_block___379 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___379 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___93 {
	struct kobject___367 kobj;
	struct module___311 *owner;
	const struct file_operations___380 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___379 {
	struct dentry___379 * (*lookup)(struct inode___380 *, struct dentry___379 *, unsigned int);
	const char * (*get_link)(struct dentry___379 *, struct inode___380 *, struct delayed_call *);
	int (*permission)(struct inode___380 *, int);
	struct posix_acl * (*get_acl)(struct inode___380 *, int);
	int (*readlink)(struct dentry___379 *, char *, int);
	int (*create)(struct inode___380 *, struct dentry___379 *, umode_t, bool);
	int (*link)(struct dentry___379 *, struct inode___380 *, struct dentry___379 *);
	int (*unlink)(struct inode___380 *, struct dentry___379 *);
	int (*symlink)(struct inode___380 *, struct dentry___379 *, const char *);
	int (*mkdir)(struct inode___380 *, struct dentry___379 *, umode_t);
	int (*rmdir)(struct inode___380 *, struct dentry___379 *);
	int (*mknod)(struct inode___380 *, struct dentry___379 *, umode_t, dev_t);
	int (*rename)(struct inode___380 *, struct dentry___379 *, struct inode___380 *, struct dentry___379 *, unsigned int);
	int (*setattr)(struct dentry___379 *, struct iattr___379 *);
	int (*getattr)(const struct path___380 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___379 *, char *, size_t);
	int (*fiemap)(struct inode___380 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___380 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___380 *, struct dentry___379 *, struct file___380 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___380 *, struct dentry___379 *, umode_t);
	int (*set_acl)(struct inode___380 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___379 {
	void (*fl_copy_lock)(struct file_lock___380 *, struct file_lock___380 *);
	void (*fl_release_private)(struct file_lock___380 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___379;

struct lock_manager_operations___379;

struct file_lock___380 {
	struct file_lock___380 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___380 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___379 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___379 *fl_ops;
	const struct lock_manager_operations___379 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___379 {
	int (*lm_compare_owner)(struct file_lock___380 *, struct file_lock___380 *);
	long unsigned int (*lm_owner_key)(struct file_lock___380 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___380 *);
	int (*lm_grant)(struct file_lock___380 *, int);
	bool (*lm_break)(struct file_lock___380 *);
	int (*lm_change)(struct file_lock___380 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___380 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___379 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___379 *fa_next;
	struct file___380 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___379 {
	const char *name;
	int fs_flags;
	struct dentry___379 * (*mount)(struct file_system_type___379 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___379 *);
	struct module___311 *owner;
	struct file_system_type___379 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___379 {
	struct inode___380 * (*alloc_inode)(struct super_block___379 *);
	void (*destroy_inode)(struct inode___380 *);
	void (*dirty_inode)(struct inode___380 *, int);
	int (*write_inode)(struct inode___380 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___380 *);
	void (*evict_inode)(struct inode___380 *);
	void (*put_super)(struct super_block___379 *);
	int (*sync_fs)(struct super_block___379 *, int);
	int (*freeze_super)(struct super_block___379 *);
	int (*freeze_fs)(struct super_block___379 *);
	int (*thaw_super)(struct super_block___379 *);
	int (*unfreeze_fs)(struct super_block___379 *);
	int (*statfs)(struct dentry___379 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___379 *, int *, char *);
	void (*umount_begin)(struct super_block___379 *);
	int (*show_options)(struct seq_file___322 *, struct dentry___379 *);
	int (*show_devname)(struct seq_file___322 *, struct dentry___379 *);
	int (*show_path)(struct seq_file___322 *, struct dentry___379 *);
	int (*show_stats)(struct seq_file___322 *, struct dentry___379 *);
	ssize_t (*quota_read)(struct super_block___379 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___379 *, int, const char *, size_t, loff_t);
	struct dquot___379 ** (*get_dquots)(struct inode___380 *);
	int (*bdev_try_to_free_page)(struct super_block___379 *, struct page___381 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___379 *, struct shrink_control___134 *);
	long int (*free_cached_objects)(struct super_block___379 *, struct shrink_control___134 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___235)(struct file___380 *, wait_queue_head_t *, struct poll_table_struct___229 *);

struct poll_table_struct___229 {
	poll_queue_proc___235 _qproc;
	__poll_t _key;
};

struct seq_operations___321;

struct seq_file___322 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___321 *op;
	int poll_event;
	const struct file___380 *file;
	void *private;
};

struct dev_pm_info___347 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___6 *subsys_data;
	void (*set_latency_tolerance)(struct device___347 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___347;

struct bus_type___347;

struct device_driver___347;

struct dev_pm_domain___347;

struct fwnode_handle___269;

struct class___347;

struct attribute_group___344;

struct device___347 {
	struct device___347 *parent;
	struct device_private *p;
	struct kobject___367 kobj;
	const char *init_name;
	const struct device_type___347 *type;
	struct mutex mutex;
	struct bus_type___347 *bus;
	struct device_driver___347 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___347 power;
	struct dev_pm_domain___347 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___269 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___347 *class;
	const struct attribute_group___344 **groups;
	void (*release)(struct device___347 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct kobj_attribute___358 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___367 *, struct kobj_attribute___358 *, char *);
	ssize_t (*store)(struct kobject___367 *, struct kobj_attribute___358 *, const char *, size_t);
};

typedef void compound_page_dtor___368(struct page___381 *);

typedef struct poll_table_struct___229 poll_table___32;

struct kernfs_root___373;

struct kernfs_elem_dir___373 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___373 *root;
};

struct kernfs_syscall_ops___373;

struct kernfs_root___373 {
	struct kernfs_node___374 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___373 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___373 {
	struct kernfs_node___374 *target_kn;
};

struct kernfs_ops___373;

struct kernfs_elem_attr___373 {
	const struct kernfs_ops___373 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___374 *notify_next;
};

struct kernfs_node___374 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___374 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___373 dir;
		struct kernfs_elem_symlink___373 symlink;
		struct kernfs_elem_attr___373 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___373;

struct kernfs_ops___373 {
	int (*open)(struct kernfs_open_file___373 *);
	void (*release)(struct kernfs_open_file___373 *);
	int (*seq_show)(struct seq_file___322 *, void *);
	void * (*seq_start)(struct seq_file___322 *, loff_t *);
	void * (*seq_next)(struct seq_file___322 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___322 *, void *);
	ssize_t (*read)(struct kernfs_open_file___373 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___373 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___373 *, struct vm_area_struct___381 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___373 *, struct poll_table_struct___229 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___373 {
	int (*remount_fs)(struct kernfs_root___373 *, int *, char *);
	int (*show_options)(struct seq_file___322 *, struct kernfs_root___373 *);
	int (*mkdir)(struct kernfs_node___374 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___374 *);
	int (*rename)(struct kernfs_node___374 *, struct kernfs_node___374 *, const char *);
	int (*show_path)(struct seq_file___322 *, struct kernfs_node___374 *, struct kernfs_root___373 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___373 {
	struct kernfs_node___374 *kn;
	struct file___380 *file;
	struct seq_file___322 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___368 *vm_ops;
};

struct bin_attribute___343;

struct attribute_group___344 {
	const char *name;
	umode_t (*is_visible)(struct kobject___367 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___367 *, struct bin_attribute___343 *, int);
	struct attribute **attrs;
	struct bin_attribute___343 **bin_attrs;
};

struct bin_attribute___343 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___380 *, struct kobject___367 *, struct bin_attribute___343 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___380 *, struct kobject___367 *, struct bin_attribute___343 *, char *, loff_t, size_t);
	int (*mmap)(struct file___380 *, struct kobject___367 *, struct bin_attribute___343 *, struct vm_area_struct___381 *);
};

struct sysfs_ops___366 {
	ssize_t (*show)(struct kobject___367 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___367 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___366;

struct kset___366 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___367 kobj;
	const struct kset_uevent_ops___366 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___366 {
	void (*release)(struct kobject___367 *);
	const struct sysfs_ops___366 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___29 * (*child_ns_type)(struct kobject___367 *);
	const void * (*namespace)(struct kobject___367 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___366 {
	int (* const filter)(struct kset___366 *, struct kobject___367 *);
	const char * (* const name)(struct kset___366 *, struct kobject___367 *);
	int (* const uevent)(struct kset___366 *, struct kobject___367 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___347 {
	int (*prepare)(struct device___347 *);
	void (*complete)(struct device___347 *);
	int (*suspend)(struct device___347 *);
	int (*resume)(struct device___347 *);
	int (*freeze)(struct device___347 *);
	int (*thaw)(struct device___347 *);
	int (*poweroff)(struct device___347 *);
	int (*restore)(struct device___347 *);
	int (*suspend_late)(struct device___347 *);
	int (*resume_early)(struct device___347 *);
	int (*freeze_late)(struct device___347 *);
	int (*thaw_early)(struct device___347 *);
	int (*poweroff_late)(struct device___347 *);
	int (*restore_early)(struct device___347 *);
	int (*suspend_noirq)(struct device___347 *);
	int (*resume_noirq)(struct device___347 *);
	int (*freeze_noirq)(struct device___347 *);
	int (*thaw_noirq)(struct device___347 *);
	int (*poweroff_noirq)(struct device___347 *);
	int (*restore_noirq)(struct device___347 *);
	int (*runtime_suspend)(struct device___347 *);
	int (*runtime_resume)(struct device___347 *);
	int (*runtime_idle)(struct device___347 *);
};

struct dev_pm_domain___347 {
	struct dev_pm_ops___347 ops;
	void (*detach)(struct device___347 *, bool);
	int (*activate)(struct device___347 *);
	void (*sync)(struct device___347 *);
	void (*dismiss)(struct device___347 *);
};

struct bus_type___347 {
	const char *name;
	const char *dev_name;
	struct device___347 *dev_root;
	const struct attribute_group___344 **bus_groups;
	const struct attribute_group___344 **dev_groups;
	const struct attribute_group___344 **drv_groups;
	int (*match)(struct device___347 *, struct device_driver___347 *);
	int (*uevent)(struct device___347 *, struct kobj_uevent_env *);
	int (*probe)(struct device___347 *);
	int (*remove)(struct device___347 *);
	void (*shutdown)(struct device___347 *);
	int (*online)(struct device___347 *);
	int (*offline)(struct device___347 *);
	int (*suspend)(struct device___347 *, pm_message_t);
	int (*resume)(struct device___347 *);
	int (*num_vf)(struct device___347 *);
	int (*dma_configure)(struct device___347 *);
	const struct dev_pm_ops___347 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___347 {
	const char *name;
	struct bus_type___347 *bus;
	struct module___311 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___347 *);
	int (*remove)(struct device___347 *);
	void (*shutdown)(struct device___347 *);
	int (*suspend)(struct device___347 *, pm_message_t);
	int (*resume)(struct device___347 *);
	const struct attribute_group___344 **groups;
	const struct dev_pm_ops___347 *pm;
	void (*coredump)(struct device___347 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___347 {
	const char *name;
	const struct attribute_group___344 **groups;
	int (*uevent)(struct device___347 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___347 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___347 *);
	const struct dev_pm_ops___347 *pm;
};

struct class___347 {
	const char *name;
	struct module___311 *owner;
	const struct attribute_group___344 **class_groups;
	const struct attribute_group___344 **dev_groups;
	struct kobject___367 *dev_kobj;
	int (*dev_uevent)(struct device___347 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___347 *, umode_t *);
	void (*class_release)(struct class___347 *);
	void (*dev_release)(struct device___347 *);
	int (*shutdown_pre)(struct device___347 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___347 *);
	const struct dev_pm_ops___347 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct fwnode_operations___269;

struct fwnode_handle___269 {
	struct fwnode_handle___269 *secondary;
	const struct fwnode_operations___269 *ops;
};

struct usb_interface___7 {
	struct usb_host_interface *altsetting;
	struct usb_host_interface *cur_altsetting;
	unsigned int num_altsetting;
	struct usb_interface_assoc_descriptor *intf_assoc;
	int minor;
	enum usb_interface_condition condition;
	unsigned int sysfs_files_created: 1;
	unsigned int ep_devs_created: 1;
	unsigned int unregistering: 1;
	unsigned int needs_remote_wakeup: 1;
	unsigned int needs_altsetting0: 1;
	unsigned int needs_binding: 1;
	unsigned int resetting_device: 1;
	unsigned int authorized: 1;
	struct device___347 dev;
	struct device___347 *usb_dev;
	atomic_t pm_usage_cnt;
	struct work_struct reset_ws;
};

struct usb_host_config___7 {
	struct usb_config_descriptor desc;
	char *string;
	struct usb_interface_assoc_descriptor *intf_assoc[16];
	struct usb_interface___7 *interface[32];
	struct usb_interface_cache *intf_cache[32];
	unsigned char *extra;
	int extralen;
};

struct usb_device___7;

struct usb_bus___7 {
	struct device___347 *controller;
	struct device___347 *sysdev;
	int busnum;
	const char *bus_name;
	u8 uses_dma;
	u8 uses_pio_for_control;
	u8 otg_port;
	unsigned int is_b_host: 1;
	unsigned int b_hnp_enable: 1;
	unsigned int no_stop_on_short: 1;
	unsigned int no_sg_constraint: 1;
	unsigned int sg_tablesize;
	int devnum_next;
	struct mutex devnum_next_mutex;
	struct usb_devmap devmap;
	struct usb_device___7 *root_hub;
	struct usb_bus___7 *hs_companion;
	int bandwidth_allocated;
	int bandwidth_int_reqs;
	int bandwidth_isoc_reqs;
	unsigned int resuming_ports;
	struct mon_bus *mon_bus;
	int monitored;
};

struct usb_tt___7;

struct usb_device___7 {
	int devnum;
	char devpath[16];
	u32 route;
	enum usb_device_state state;
	enum usb_device_speed speed;
	unsigned int rx_lanes;
	unsigned int tx_lanes;
	struct usb_tt___7 *tt;
	int ttport;
	unsigned int toggle[2];
	struct usb_device___7 *parent;
	struct usb_bus___7 *bus;
	struct usb_host_endpoint ep0;
	struct device___347 dev;
	struct usb_device_descriptor descriptor;
	struct usb_host_bos *bos;
	struct usb_host_config___7 *config;
	struct usb_host_config___7 *actconfig;
	struct usb_host_endpoint *ep_in[16];
	struct usb_host_endpoint *ep_out[16];
	char **rawdescriptors;
	short unsigned int bus_mA;
	u8 portnum;
	u8 level;
	unsigned int can_submit: 1;
	unsigned int persist_enabled: 1;
	unsigned int have_langid: 1;
	unsigned int authorized: 1;
	unsigned int authenticated: 1;
	unsigned int wusb: 1;
	unsigned int lpm_capable: 1;
	unsigned int usb2_hw_lpm_capable: 1;
	unsigned int usb2_hw_lpm_besl_capable: 1;
	unsigned int usb2_hw_lpm_enabled: 1;
	unsigned int usb2_hw_lpm_allowed: 1;
	unsigned int usb3_lpm_u1_enabled: 1;
	unsigned int usb3_lpm_u2_enabled: 1;
	int string_langid;
	char *product;
	char *manufacturer;
	char *serial;
	struct list_head filelist;
	int maxchild;
	u32 quirks;
	atomic_t urbnum;
	long unsigned int active_duration;
	long unsigned int connect_time;
	unsigned int do_remote_wakeup: 1;
	unsigned int reset_resume: 1;
	unsigned int port_is_suspended: 1;
	struct wusb_dev *wusb_dev;
	int slot_id;
	enum usb_device_removable removable;
	struct usb2_lpm_parameters l1_params;
	struct usb3_lpm_parameters u1_params;
	struct usb3_lpm_parameters u2_params;
	unsigned int lpm_disable_count;
	u16 hub_delay;
};

struct usb_tt___7 {
	struct usb_device___7 *hub;
	int multi;
	unsigned int think_time;
	void *hcpriv;
	spinlock_t lock;
	struct list_head clear_list;
	struct work_struct clear_work;
};

struct usbdrv_wrap___7 {
	struct device_driver___347 driver;
	int for_devices;
};

struct usb_driver___7 {
	const char *name;
	int (*probe)(struct usb_interface___7 *, const struct usb_device_id *);
	void (*disconnect)(struct usb_interface___7 *);
	int (*unlocked_ioctl)(struct usb_interface___7 *, unsigned int, void *);
	int (*suspend)(struct usb_interface___7 *, pm_message_t);
	int (*resume)(struct usb_interface___7 *);
	int (*reset_resume)(struct usb_interface___7 *);
	int (*pre_reset)(struct usb_interface___7 *);
	int (*post_reset)(struct usb_interface___7 *);
	const struct usb_device_id *id_table;
	struct usb_dynids dynids;
	struct usbdrv_wrap___7 drvwrap;
	unsigned int no_dynamic_id: 1;
	unsigned int supports_autosuspend: 1;
	unsigned int disable_hub_initiated_lpm: 1;
	unsigned int soft_unbind: 1;
};

struct usb_device_driver___7 {
	const char *name;
	int (*probe)(struct usb_device___7 *);
	void (*disconnect)(struct usb_device___7 *);
	int (*suspend)(struct usb_device___7 *, pm_message_t);
	int (*resume)(struct usb_device___7 *, pm_message_t);
	struct usbdrv_wrap___7 drvwrap;
	unsigned int supports_autosuspend: 1;
};

struct urb___7;

typedef void (*usb_complete_t___7)(struct urb___7 *);

struct urb___7 {
	struct kref kref;
	void *hcpriv;
	atomic_t use_count;
	atomic_t reject;
	int unlinked;
	struct list_head urb_list;
	struct list_head anchor_list;
	struct usb_anchor *anchor;
	struct usb_device___7 *dev;
	struct usb_host_endpoint *ep;
	unsigned int pipe;
	unsigned int stream_id;
	int status;
	unsigned int transfer_flags;
	void *transfer_buffer;
	dma_addr_t transfer_dma;
	struct scatterlist *sg;
	int num_mapped_sgs;
	int num_sgs;
	u32 transfer_buffer_length;
	u32 actual_length;
	unsigned char *setup_packet;
	dma_addr_t setup_dma;
	int start_frame;
	int number_of_packets;
	int interval;
	int error_count;
	void *context;
	usb_complete_t___7 complete;
	struct usb_iso_packet_descriptor iso_frame_desc[0];
};

struct hc_driver___6;

struct usb_hcd___6 {
	struct usb_bus___7 self;
	struct kref kref;
	const char *product_desc;
	int speed;
	char irq_descr[24];
	struct timer_list rh_timer;
	struct urb___7 *status_urb;
	struct work_struct wakeup_work;
	const struct hc_driver___6 *driver;
	struct usb_phy___3 *usb_phy;
	struct usb_phy_roothub *phy_roothub;
	long unsigned int flags;
	unsigned int rh_registered: 1;
	unsigned int rh_pollable: 1;
	unsigned int msix_enabled: 1;
	unsigned int msi_enabled: 1;
	unsigned int skip_phy_initialization: 1;
	unsigned int uses_new_polling: 1;
	unsigned int wireless: 1;
	unsigned int has_tt: 1;
	unsigned int amd_resume_bug: 1;
	unsigned int can_do_streams: 1;
	unsigned int tpl_support: 1;
	unsigned int cant_recv_wakeups: 1;
	unsigned int irq;
	void *regs;
	resource_size_t rsrc_start;
	resource_size_t rsrc_len;
	unsigned int power_budget;
	struct giveback_urb_bh high_prio_bh;
	struct giveback_urb_bh low_prio_bh;
	struct mutex *address0_mutex;
	struct mutex *bandwidth_mutex;
	struct usb_hcd___6 *shared_hcd;
	struct usb_hcd___6 *primary_hcd;
	struct dma_pool___2 *pool[4];
	int state;
	long unsigned int hcd_priv[0];
};

struct hc_driver___6 {
	const char *description;
	const char *product_desc;
	size_t hcd_priv_size;
	irqreturn_t (*irq)(struct usb_hcd___6 *);
	int flags;
	int (*reset)(struct usb_hcd___6 *);
	int (*start)(struct usb_hcd___6 *);
	int (*pci_suspend)(struct usb_hcd___6 *, bool);
	int (*pci_resume)(struct usb_hcd___6 *, bool);
	void (*stop)(struct usb_hcd___6 *);
	void (*shutdown)(struct usb_hcd___6 *);
	int (*get_frame_number)(struct usb_hcd___6 *);
	int (*urb_enqueue)(struct usb_hcd___6 *, struct urb___7 *, gfp_t);
	int (*urb_dequeue)(struct usb_hcd___6 *, struct urb___7 *, int);
	int (*map_urb_for_dma)(struct usb_hcd___6 *, struct urb___7 *, gfp_t);
	void (*unmap_urb_for_dma)(struct usb_hcd___6 *, struct urb___7 *);
	void (*endpoint_disable)(struct usb_hcd___6 *, struct usb_host_endpoint *);
	void (*endpoint_reset)(struct usb_hcd___6 *, struct usb_host_endpoint *);
	int (*hub_status_data)(struct usb_hcd___6 *, char *);
	int (*hub_control)(struct usb_hcd___6 *, u16, u16, u16, char *, u16);
	int (*bus_suspend)(struct usb_hcd___6 *);
	int (*bus_resume)(struct usb_hcd___6 *);
	int (*start_port_reset)(struct usb_hcd___6 *, unsigned int);
	long unsigned int (*get_resuming_ports)(struct usb_hcd___6 *);
	void (*relinquish_port)(struct usb_hcd___6 *, int);
	int (*port_handed_over)(struct usb_hcd___6 *, int);
	void (*clear_tt_buffer_complete)(struct usb_hcd___6 *, struct usb_host_endpoint *);
	int (*alloc_dev)(struct usb_hcd___6 *, struct usb_device___7 *);
	void (*free_dev)(struct usb_hcd___6 *, struct usb_device___7 *);
	int (*alloc_streams)(struct usb_hcd___6 *, struct usb_device___7 *, struct usb_host_endpoint **, unsigned int, unsigned int, gfp_t);
	int (*free_streams)(struct usb_hcd___6 *, struct usb_device___7 *, struct usb_host_endpoint **, unsigned int, gfp_t);
	int (*add_endpoint)(struct usb_hcd___6 *, struct usb_device___7 *, struct usb_host_endpoint *);
	int (*drop_endpoint)(struct usb_hcd___6 *, struct usb_device___7 *, struct usb_host_endpoint *);
	int (*check_bandwidth)(struct usb_hcd___6 *, struct usb_device___7 *);
	void (*reset_bandwidth)(struct usb_hcd___6 *, struct usb_device___7 *);
	int (*address_device)(struct usb_hcd___6 *, struct usb_device___7 *);
	int (*enable_device)(struct usb_hcd___6 *, struct usb_device___7 *);
	int (*update_hub_device)(struct usb_hcd___6 *, struct usb_device___7 *, struct usb_tt___7 *, gfp_t);
	int (*reset_device)(struct usb_hcd___6 *, struct usb_device___7 *);
	int (*update_device)(struct usb_hcd___6 *, struct usb_device___7 *);
	int (*set_usb2_hw_lpm)(struct usb_hcd___6 *, struct usb_device___7 *, int);
	int (*enable_usb3_lpm_timeout)(struct usb_hcd___6 *, struct usb_device___7 *, enum usb3_link_state);
	int (*disable_usb3_lpm_timeout)(struct usb_hcd___6 *, struct usb_device___7 *, enum usb3_link_state);
	int (*find_raw_port_number)(struct usb_hcd___6 *, int);
	int (*port_power)(struct usb_hcd___6 *, int, bool);
};

struct usb_mon_operations___7 {
	void (*urb_submit)(struct usb_bus___7 *, struct urb___7 *);
	void (*urb_submit_error)(struct usb_bus___7 *, struct urb___7 *, int);
	void (*urb_complete)(struct usb_bus___7 *, struct urb___7 *, int);
};

struct fwnode_reference_args___269;

struct fwnode_endpoint___269;

struct fwnode_operations___269 {
	struct fwnode_handle___269 * (*get)(struct fwnode_handle___269 *);
	void (*put)(struct fwnode_handle___269 *);
	bool (*device_is_available)(const struct fwnode_handle___269 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___269 *, const struct device___347 *);
	bool (*property_present)(const struct fwnode_handle___269 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___269 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___269 *, const char *, const char **, size_t);
	struct fwnode_handle___269 * (*get_parent)(const struct fwnode_handle___269 *);
	struct fwnode_handle___269 * (*get_next_child_node)(const struct fwnode_handle___269 *, struct fwnode_handle___269 *);
	struct fwnode_handle___269 * (*get_named_child_node)(const struct fwnode_handle___269 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___269 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___269 *);
	struct fwnode_handle___269 * (*graph_get_next_endpoint)(const struct fwnode_handle___269 *, struct fwnode_handle___269 *);
	struct fwnode_handle___269 * (*graph_get_remote_endpoint)(const struct fwnode_handle___269 *);
	struct fwnode_handle___269 * (*graph_get_port_parent)(struct fwnode_handle___269 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___269 *, struct fwnode_endpoint___269 *);
};

struct fwnode_endpoint___269 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___269 *local_fwnode;
};

struct fwnode_reference_args___269 {
	struct fwnode_handle___269 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct kernel_param_ops___308 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___308 *);
	int (*get)(char *, const struct kernel_param___308 *);
	void (*free)(void *);
};

struct kparam_array___308;

struct kernel_param___308 {
	const char *name;
	struct module___311 *mod;
	const struct kernel_param_ops___308 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___308 *arr;
	};
};

struct kparam_array___308 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___308 *ops;
	void *elem;
};

struct module_attribute___308 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___308 *, struct module_kobject___308 *, char *);
	ssize_t (*store)(struct module_attribute___308 *, struct module_kobject___308 *, const char *, size_t);
	void (*setup)(struct module___311 *, const char *);
	int (*test)(struct module___311 *);
	void (*free)(struct module___311 *);
};

typedef int (*key_restrict_link_func_t___350)(struct key___349 *, const struct key_type *, const union key_payload *, struct key___349 *);

struct key_restriction___349;

struct key___349 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___381 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___349 *restrict_link;
};

struct key_restriction___349 {
	key_restrict_link_func_t___350 check;
	struct key___349 *key;
	struct key_type *keytype;
};

struct seq_operations___321 {
	void * (*start)(struct seq_file___322 *, loff_t *);
	void (*stop)(struct seq_file___322 *, void *);
	void * (*next)(struct seq_file___322 *, void *, loff_t *);
	int (*show)(struct seq_file___322 *, void *);
};

struct device_connect_event {
	atomic_t count;
	wait_queue_head_t wait;
};

struct class_info {
	int class;
	char *class_name;
};

struct usb_phy_roothub___2 {
	struct phy___10 *phy;
	struct list_head list;
};

struct module___312;

struct file___381;

struct kiocb___381;

struct poll_table_struct___230;

struct vm_area_struct___382;

struct inode___381;

struct file_lock___381;

struct page___382;

struct seq_file___323;

struct file_operations___381 {
	struct module___312 *owner;
	loff_t (*llseek)(struct file___381 *, loff_t, int);
	ssize_t (*read)(struct file___381 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___381 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___381 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___381 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___381 *, bool);
	int (*iterate)(struct file___381 *, struct dir_context *);
	int (*iterate_shared)(struct file___381 *, struct dir_context *);
	__poll_t (*poll)(struct file___381 *, struct poll_table_struct___230 *);
	long int (*unlocked_ioctl)(struct file___381 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___381 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___381 *, struct vm_area_struct___382 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___381 *, struct file___381 *);
	int (*flush)(struct file___381 *, fl_owner_t);
	int (*release)(struct inode___381 *, struct file___381 *);
	int (*fsync)(struct file___381 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___381 *, int);
	int (*lock)(struct file___381 *, int, struct file_lock___381 *);
	ssize_t (*sendpage)(struct file___381 *, struct page___382 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___381 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___381 *, int, struct file_lock___381 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___381 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___381 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___381 *, long int, struct file_lock___381 **, void **);
	long int (*fallocate)(struct file___381 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___323 *, struct file___381 *);
	ssize_t (*copy_file_range)(struct file___381 *, loff_t, struct file___381 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___381 *, loff_t, struct file___381 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___381 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___381 {
	u64 seqnum;
	struct vm_area_struct___382 *vmas[4];
};

struct page_frag___381 {
	struct page___382 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___381;

struct cred___350;

struct vm_struct___287;

struct task_struct___382 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___382 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___381 *mm;
	struct mm_struct___381 *active_mm;
	struct vmacache___381 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___382 *real_parent;
	struct task_struct___382 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___382 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___219 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___219 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___219 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___350 *ptracer_cred;
	const struct cred___350 *real_cred;
	const struct cred___350 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___382 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___107 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___381 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___382 *oom_reaper_list;
	struct vm_struct___287 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___143 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___382 *pgtable_t___381;

struct address_space___380;

struct dev_pagemap___369;

struct page___382 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___380 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___382 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___381 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___381 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___369 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___381;

struct lruvec___381 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___381 *pgdat;
};

struct zone___381 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___381 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___381 {
	struct zone___381 *zone;
	int zone_idx;
};

struct zonelist___381 {
	struct zoneref___381 _zonerefs[25];
};

struct pglist_data___381 {
	struct zone___381 node_zones[3];
	struct zonelist___381 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___382 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___382 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___381 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___382 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___382 *owner;
};

struct secondary_data___382 {
	void *stack;
	struct task_struct___382 *task;
	long int status;
};

struct blocking_notifier_head___381 {
	struct rw_semaphore___382 rwsem;
	struct notifier_block *head;
};

struct kernfs_root___374;

struct kernfs_elem_dir___374 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___374 *root;
};

struct kernfs_node___375;

struct kernfs_syscall_ops___374;

struct kernfs_root___374 {
	struct kernfs_node___375 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___374 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___374 {
	struct kernfs_node___375 *target_kn;
};

struct kernfs_ops___374;

struct kernfs_elem_attr___374 {
	const struct kernfs_ops___374 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___375 *notify_next;
};

struct kernfs_node___375 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___375 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___374 dir;
		struct kernfs_elem_symlink___374 symlink;
		struct kernfs_elem_attr___374 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___374;

struct kernfs_ops___374 {
	int (*open)(struct kernfs_open_file___374 *);
	void (*release)(struct kernfs_open_file___374 *);
	int (*seq_show)(struct seq_file___323 *, void *);
	void * (*seq_start)(struct seq_file___323 *, loff_t *);
	void * (*seq_next)(struct seq_file___323 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___323 *, void *);
	ssize_t (*read)(struct kernfs_open_file___374 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___374 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___374 *, struct vm_area_struct___382 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___374 *, struct poll_table_struct___230 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___374 {
	int (*remount_fs)(struct kernfs_root___374 *, int *, char *);
	int (*show_options)(struct seq_file___323 *, struct kernfs_root___374 *);
	int (*mkdir)(struct kernfs_node___375 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___375 *);
	int (*rename)(struct kernfs_node___375 *, struct kernfs_node___375 *, const char *);
	int (*show_path)(struct seq_file___323 *, struct kernfs_node___375 *, struct kernfs_root___374 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___322;

struct seq_file___323 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___322 *op;
	int poll_event;
	const struct file___381 *file;
	void *private;
};

struct vm_operations_struct___369;

struct kernfs_open_file___374 {
	struct kernfs_node___375 *kn;
	struct file___381 *file;
	struct seq_file___323 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___369 *vm_ops;
};

struct dentry___380;

struct path___381 {
	struct vfsmount *mnt;
	struct dentry___380 *dentry;
};

struct file___381 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___381 f_path;
	struct inode___381 *f_inode;
	const struct file_operations___381 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___219 f_owner;
	const struct cred___350 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___380 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___369;

struct vm_operations_struct___369 {
	void (*open)(struct vm_area_struct___382 *);
	void (*close)(struct vm_area_struct___382 *);
	int (*split)(struct vm_area_struct___382 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___382 *);
	vm_fault_t (*fault)(struct vm_fault___369 *);
	vm_fault_t (*huge_fault)(struct vm_fault___369 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___369 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___382 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___369 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___369 *);
	int (*access)(struct vm_area_struct___382 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___382 *);
	int (*set_policy)(struct vm_area_struct___382 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___382 *, long unsigned int);
	struct page___382 * (*find_special_page)(struct vm_area_struct___382 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___236)(struct file___381 *, wait_queue_head_t *, struct poll_table_struct___230 *);

struct poll_table_struct___230 {
	poll_queue_proc___236 _qproc;
	__poll_t _key;
};

struct vm_area_struct___382 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___382 *vm_next;
	struct vm_area_struct___382 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___381 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___369 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___381 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___368;

struct bin_attribute___344;

struct attribute_group___345 {
	const char *name;
	umode_t (*is_visible)(struct kobject___368 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___368 *, struct bin_attribute___344 *, int);
	struct attribute **attrs;
	struct bin_attribute___344 **bin_attrs;
};

struct kset___367;

struct kobj_type___367;

struct kobject___368 {
	const char *name;
	struct list_head entry;
	struct kobject___368 *parent;
	struct kset___367 *kset;
	struct kobj_type___367 *ktype;
	struct kernfs_node___375 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___344 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___381 *, struct kobject___368 *, struct bin_attribute___344 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___381 *, struct kobject___368 *, struct bin_attribute___344 *, char *, loff_t, size_t);
	int (*mmap)(struct file___381 *, struct kobject___368 *, struct bin_attribute___344 *, struct vm_area_struct___382 *);
};

struct sysfs_ops___367 {
	ssize_t (*show)(struct kobject___368 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___368 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___367;

struct kset___367 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___368 kobj;
	const struct kset_uevent_ops___367 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___367 {
	void (*release)(struct kobject___368 *);
	const struct sysfs_ops___367 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___29 * (*child_ns_type)(struct kobject___368 *);
	const void * (*namespace)(struct kobject___368 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___367 {
	int (* const filter)(struct kset___367 *, struct kobject___368 *);
	const char * (* const name)(struct kset___367 *, struct kobject___368 *);
	int (* const uevent)(struct kset___367 *, struct kobject___368 *, struct kobj_uevent_env *);
};

struct kobj_attribute___359 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___368 *, struct kobj_attribute___359 *, char *);
	ssize_t (*store)(struct kobject___368 *, struct kobj_attribute___359 *, const char *, size_t);
};

struct device___348;

struct dev_pm_ops___348 {
	int (*prepare)(struct device___348 *);
	void (*complete)(struct device___348 *);
	int (*suspend)(struct device___348 *);
	int (*resume)(struct device___348 *);
	int (*freeze)(struct device___348 *);
	int (*thaw)(struct device___348 *);
	int (*poweroff)(struct device___348 *);
	int (*restore)(struct device___348 *);
	int (*suspend_late)(struct device___348 *);
	int (*resume_early)(struct device___348 *);
	int (*freeze_late)(struct device___348 *);
	int (*thaw_early)(struct device___348 *);
	int (*poweroff_late)(struct device___348 *);
	int (*restore_early)(struct device___348 *);
	int (*suspend_noirq)(struct device___348 *);
	int (*resume_noirq)(struct device___348 *);
	int (*freeze_noirq)(struct device___348 *);
	int (*thaw_noirq)(struct device___348 *);
	int (*poweroff_noirq)(struct device___348 *);
	int (*restore_noirq)(struct device___348 *);
	int (*runtime_suspend)(struct device___348 *);
	int (*runtime_resume)(struct device___348 *);
	int (*runtime_idle)(struct device___348 *);
};

struct dev_pm_qos___22;

struct dev_pm_info___348 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___6 *subsys_data;
	void (*set_latency_tolerance)(struct device___348 *, s32);
	struct dev_pm_qos___22 *qos;
};

struct device_type___348;

struct bus_type___348;

struct device_driver___348;

struct dev_pm_domain___348;

struct fwnode_handle___270;

struct class___348;

struct device___348 {
	struct device___348 *parent;
	struct device_private *p;
	struct kobject___368 kobj;
	const char *init_name;
	const struct device_type___348 *type;
	struct mutex mutex;
	struct bus_type___348 *bus;
	struct device_driver___348 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___348 power;
	struct dev_pm_domain___348 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___270 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___348 *class;
	const struct attribute_group___345 **groups;
	void (*release)(struct device___348 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct pm_qos_constraints___21 {
	struct plist_head list;
	s32 target_value;
	s32 default_value;
	s32 no_constraint_value;
	enum pm_qos_type type;
	struct blocking_notifier_head___381 *notifiers;
};

struct dev_pm_qos_request___22;

struct dev_pm_qos___22 {
	struct pm_qos_constraints___21 resume_latency;
	struct pm_qos_constraints___21 latency_tolerance;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___22 *resume_latency_req;
	struct dev_pm_qos_request___22 *latency_tolerance_req;
	struct dev_pm_qos_request___22 *flags_req;
};

struct dev_pm_domain___348 {
	struct dev_pm_ops___348 ops;
	void (*detach)(struct device___348 *, bool);
	int (*activate)(struct device___348 *);
	void (*sync)(struct device___348 *);
	void (*dismiss)(struct device___348 *);
};

struct key___350;

struct user_struct___350 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___350 *uid_keyring;
	struct key___350 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___381;

struct mm_struct___381 {
	struct {
		struct vm_area_struct___382 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___381 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___382 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___381 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___382 *owner;
		struct user_namespace___3 *user_ns;
		struct file___381 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___381 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___350 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___350 *session_keyring;
	struct key___350 *process_keyring;
	struct key___350 *thread_keyring;
	struct key___350 *request_key_auth;
	void *security;
	struct user_struct___350 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct vm_struct___287 {
	struct vm_struct___287 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___382 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bus_type___348 {
	const char *name;
	const char *dev_name;
	struct device___348 *dev_root;
	const struct attribute_group___345 **bus_groups;
	const struct attribute_group___345 **dev_groups;
	const struct attribute_group___345 **drv_groups;
	int (*match)(struct device___348 *, struct device_driver___348 *);
	int (*uevent)(struct device___348 *, struct kobj_uevent_env *);
	int (*probe)(struct device___348 *);
	int (*remove)(struct device___348 *);
	void (*shutdown)(struct device___348 *);
	int (*online)(struct device___348 *);
	int (*offline)(struct device___348 *);
	int (*suspend)(struct device___348 *, pm_message_t);
	int (*resume)(struct device___348 *);
	int (*num_vf)(struct device___348 *);
	int (*dma_configure)(struct device___348 *);
	const struct dev_pm_ops___348 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___348 {
	const char *name;
	struct bus_type___348 *bus;
	struct module___312 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___348 *);
	int (*remove)(struct device___348 *);
	void (*shutdown)(struct device___348 *);
	int (*suspend)(struct device___348 *, pm_message_t);
	int (*resume)(struct device___348 *);
	const struct attribute_group___345 **groups;
	const struct dev_pm_ops___348 *pm;
	void (*coredump)(struct device___348 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___348 {
	const char *name;
	const struct attribute_group___345 **groups;
	int (*uevent)(struct device___348 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___348 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___348 *);
	const struct dev_pm_ops___348 *pm;
};

struct module_kobject___309 {
	struct kobject___368 kobj;
	struct module___312 *mod;
	struct kobject___368 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___309 {
	struct module___312 *mod;
	struct latch_tree_node node;
};

struct module_layout___309 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___309 mtn;
};

struct module_attribute___309;

struct kernel_param___309;

struct module___312 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___309 mkobj;
	struct module_attribute___309 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___368 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___309 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___309 core_layout;
	struct module_layout___309 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct class___348 {
	const char *name;
	struct module___312 *owner;
	const struct attribute_group___345 **class_groups;
	const struct attribute_group___345 **dev_groups;
	struct kobject___368 *dev_kobj;
	int (*dev_uevent)(struct device___348 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___348 *, umode_t *);
	void (*class_release)(struct class___348 *);
	void (*dev_release)(struct device___348 *);
	int (*shutdown_pre)(struct device___348 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___348 *);
	const struct dev_pm_ops___348 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct device_attribute___53 {
	struct attribute attr;
	ssize_t (*show)(struct device___348 *, struct device_attribute___53 *, char *);
	ssize_t (*store)(struct device___348 *, struct device_attribute___53 *, const char *, size_t);
};

struct fwnode_operations___270;

struct fwnode_handle___270 {
	struct fwnode_handle___270 *secondary;
	const struct fwnode_operations___270 *ops;
};

struct dev_pm_qos_request___22 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___348 *dev;
};

struct dentry_operations___380;

struct super_block___380;

struct dentry___380 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___380 *d_parent;
	struct qstr d_name;
	struct inode___381 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___380 *d_op;
	struct super_block___380 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___380;

struct address_space___380 {
	struct inode___381 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___382 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___380 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___380;

struct block_device___380;

struct cdev___94;

struct inode___381 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___380 *i_op;
	struct super_block___380 *i_sb;
	struct address_space___380 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___382 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___381 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___380 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___380 *i_bdev;
		struct cdev___94 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___380 {
	int (*d_revalidate)(struct dentry___380 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___380 *, unsigned int);
	int (*d_hash)(const struct dentry___380 *, struct qstr *);
	int (*d_compare)(const struct dentry___380 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___380 *);
	int (*d_init)(struct dentry___380 *);
	void (*d_release)(struct dentry___380 *);
	void (*d_prune)(struct dentry___380 *);
	void (*d_iput)(struct dentry___380 *, struct inode___381 *);
	char * (*d_dname)(struct dentry___380 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___381 *);
	int (*d_manage)(const struct path___381 *, bool);
	struct dentry___380 * (*d_real)(struct dentry___380 *, const struct inode___381 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___380;

struct mem_dqinfo___380 {
	struct quota_format_type___380 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___380;

struct quota_info___380 {
	unsigned int flags;
	struct rw_semaphore___382 dqio_sem;
	struct inode___381 *files[3];
	struct mem_dqinfo___380 info[3];
	const struct quota_format_ops___380 *ops[3];
};

struct rcuwait___380 {
	struct task_struct___382 *task;
};

struct percpu_rw_semaphore___380 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___382 rw_sem;
	struct rcuwait___380 writer;
	int readers_block;
};

struct sb_writers___380 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___380 rw_sem[3];
};

struct file_system_type___380;

struct super_operations___380;

struct dquot_operations___380;

struct quotactl_ops___380;

struct super_block___380 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___380 *s_type;
	const struct super_operations___380 *s_op;
	const struct dquot_operations___380 *dq_op;
	const struct quotactl_ops___380 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___380 *s_root;
	struct rw_semaphore___382 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___380 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___380 s_dquot;
	struct sb_writers___380 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___380 *s_d_op;
	int cleancache_poolid;
	struct shrinker___134 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

typedef int (*dev_page_fault_t___369)(struct vm_area_struct___382 *, long unsigned int, const struct page___382 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___369)(struct page___382 *, void *);

struct dev_pagemap___369 {
	dev_page_fault_t___369 page_fault;
	dev_page_free_t___369 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___348 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___381 {
	struct task_struct___382 *task;
	struct core_thread___381 *next;
};

struct core_state___381 {
	atomic_t nr_threads;
	struct core_thread___381 dumper;
	struct completion startup;
};

struct vm_fault___369 {
	struct vm_area_struct___382 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___382 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___382 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___381 prealloc_pte;
};

struct kiocb___381 {
	struct file___381 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___381 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___380 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___381 *ia_file;
};

struct dquot___380 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___380 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___380 {
	int qf_fmt_id;
	const struct quota_format_ops___380 *qf_ops;
	struct module___312 *qf_owner;
	struct quota_format_type___380 *qf_next;
};

struct quota_format_ops___380 {
	int (*check_quota_file)(struct super_block___380 *, int);
	int (*read_file_info)(struct super_block___380 *, int);
	int (*write_file_info)(struct super_block___380 *, int);
	int (*free_file_info)(struct super_block___380 *, int);
	int (*read_dqblk)(struct dquot___380 *);
	int (*commit_dqblk)(struct dquot___380 *);
	int (*release_dqblk)(struct dquot___380 *);
	int (*get_next_id)(struct super_block___380 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___380 {
	int (*write_dquot)(struct dquot___380 *);
	struct dquot___380 * (*alloc_dquot)(struct super_block___380 *, int);
	void (*destroy_dquot)(struct dquot___380 *);
	int (*acquire_dquot)(struct dquot___380 *);
	int (*release_dquot)(struct dquot___380 *);
	int (*mark_dirty)(struct dquot___380 *);
	int (*write_info)(struct super_block___380 *, int);
	qsize_t * (*get_reserved_space)(struct inode___381 *);
	int (*get_projid)(struct inode___381 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___381 *, qsize_t *);
	int (*get_next_id)(struct super_block___380 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___380 {
	int (*quota_on)(struct super_block___380 *, int, int, const struct path___381 *);
	int (*quota_off)(struct super_block___380 *, int);
	int (*quota_enable)(struct super_block___380 *, unsigned int);
	int (*quota_disable)(struct super_block___380 *, unsigned int);
	int (*quota_sync)(struct super_block___380 *, int);
	int (*set_info)(struct super_block___380 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___380 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___380 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___380 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___380 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___380 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___380 {
	int (*writepage)(struct page___382 *, struct writeback_control___3 *);
	int (*readpage)(struct file___381 *, struct page___382 *);
	int (*writepages)(struct address_space___380 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___382 *);
	int (*readpages)(struct file___381 *, struct address_space___380 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___381 *, struct address_space___380 *, loff_t, unsigned int, unsigned int, struct page___382 **, void **);
	int (*write_end)(struct file___381 *, struct address_space___380 *, loff_t, unsigned int, unsigned int, struct page___382 *, void *);
	sector_t (*bmap)(struct address_space___380 *, sector_t);
	void (*invalidatepage)(struct page___382 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___382 *, gfp_t);
	void (*freepage)(struct page___382 *);
	ssize_t (*direct_IO)(struct kiocb___381 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___380 *, struct page___382 *, struct page___382 *, enum migrate_mode);
	bool (*isolate_page)(struct page___382 *, isolate_mode_t);
	void (*putback_page)(struct page___382 *);
	int (*launder_page)(struct page___382 *);
	int (*is_partially_uptodate)(struct page___382 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___382 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___380 *, struct page___382 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___381 *, sector_t *);
	void (*swap_deactivate)(struct file___381 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___380 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___381 *bd_inode;
	struct super_block___380 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___380 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___94 {
	struct kobject___368 kobj;
	struct module___312 *owner;
	const struct file_operations___381 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___380 {
	struct dentry___380 * (*lookup)(struct inode___381 *, struct dentry___380 *, unsigned int);
	const char * (*get_link)(struct dentry___380 *, struct inode___381 *, struct delayed_call *);
	int (*permission)(struct inode___381 *, int);
	struct posix_acl * (*get_acl)(struct inode___381 *, int);
	int (*readlink)(struct dentry___380 *, char *, int);
	int (*create)(struct inode___381 *, struct dentry___380 *, umode_t, bool);
	int (*link)(struct dentry___380 *, struct inode___381 *, struct dentry___380 *);
	int (*unlink)(struct inode___381 *, struct dentry___380 *);
	int (*symlink)(struct inode___381 *, struct dentry___380 *, const char *);
	int (*mkdir)(struct inode___381 *, struct dentry___380 *, umode_t);
	int (*rmdir)(struct inode___381 *, struct dentry___380 *);
	int (*mknod)(struct inode___381 *, struct dentry___380 *, umode_t, dev_t);
	int (*rename)(struct inode___381 *, struct dentry___380 *, struct inode___381 *, struct dentry___380 *, unsigned int);
	int (*setattr)(struct dentry___380 *, struct iattr___380 *);
	int (*getattr)(const struct path___381 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___380 *, char *, size_t);
	int (*fiemap)(struct inode___381 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___381 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___381 *, struct dentry___380 *, struct file___381 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___381 *, struct dentry___380 *, umode_t);
	int (*set_acl)(struct inode___381 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___380 {
	void (*fl_copy_lock)(struct file_lock___381 *, struct file_lock___381 *);
	void (*fl_release_private)(struct file_lock___381 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___380;

struct lock_manager_operations___380;

struct file_lock___381 {
	struct file_lock___381 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___381 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___380 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___380 *fl_ops;
	const struct lock_manager_operations___380 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___380 {
	int (*lm_compare_owner)(struct file_lock___381 *, struct file_lock___381 *);
	long unsigned int (*lm_owner_key)(struct file_lock___381 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___381 *);
	int (*lm_grant)(struct file_lock___381 *, int);
	bool (*lm_break)(struct file_lock___381 *);
	int (*lm_change)(struct file_lock___381 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___381 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___380 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___380 *fa_next;
	struct file___381 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___380 {
	const char *name;
	int fs_flags;
	struct dentry___380 * (*mount)(struct file_system_type___380 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___380 *);
	struct module___312 *owner;
	struct file_system_type___380 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___380 {
	struct inode___381 * (*alloc_inode)(struct super_block___380 *);
	void (*destroy_inode)(struct inode___381 *);
	void (*dirty_inode)(struct inode___381 *, int);
	int (*write_inode)(struct inode___381 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___381 *);
	void (*evict_inode)(struct inode___381 *);
	void (*put_super)(struct super_block___380 *);
	int (*sync_fs)(struct super_block___380 *, int);
	int (*freeze_super)(struct super_block___380 *);
	int (*freeze_fs)(struct super_block___380 *);
	int (*thaw_super)(struct super_block___380 *);
	int (*unfreeze_fs)(struct super_block___380 *);
	int (*statfs)(struct dentry___380 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___380 *, int *, char *);
	void (*umount_begin)(struct super_block___380 *);
	int (*show_options)(struct seq_file___323 *, struct dentry___380 *);
	int (*show_devname)(struct seq_file___323 *, struct dentry___380 *);
	int (*show_path)(struct seq_file___323 *, struct dentry___380 *);
	int (*show_stats)(struct seq_file___323 *, struct dentry___380 *);
	ssize_t (*quota_read)(struct super_block___380 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___380 *, int, const char *, size_t, loff_t);
	struct dquot___380 ** (*get_dquots)(struct inode___381 *);
	int (*bdev_try_to_free_page)(struct super_block___380 *, struct page___382 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___380 *, struct shrink_control___134 *);
	long int (*free_cached_objects)(struct super_block___380 *, struct shrink_control___134 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct usb_interface___8 {
	struct usb_host_interface *altsetting;
	struct usb_host_interface *cur_altsetting;
	unsigned int num_altsetting;
	struct usb_interface_assoc_descriptor *intf_assoc;
	int minor;
	enum usb_interface_condition condition;
	unsigned int sysfs_files_created: 1;
	unsigned int ep_devs_created: 1;
	unsigned int unregistering: 1;
	unsigned int needs_remote_wakeup: 1;
	unsigned int needs_altsetting0: 1;
	unsigned int needs_binding: 1;
	unsigned int resetting_device: 1;
	unsigned int authorized: 1;
	struct device___348 dev;
	struct device___348 *usb_dev;
	atomic_t pm_usage_cnt;
	struct work_struct reset_ws;
};

struct usb_host_config___8 {
	struct usb_config_descriptor desc;
	char *string;
	struct usb_interface_assoc_descriptor *intf_assoc[16];
	struct usb_interface___8 *interface[32];
	struct usb_interface_cache *intf_cache[32];
	unsigned char *extra;
	int extralen;
};

struct usb_device___8;

struct usb_bus___8 {
	struct device___348 *controller;
	struct device___348 *sysdev;
	int busnum;
	const char *bus_name;
	u8 uses_dma;
	u8 uses_pio_for_control;
	u8 otg_port;
	unsigned int is_b_host: 1;
	unsigned int b_hnp_enable: 1;
	unsigned int no_stop_on_short: 1;
	unsigned int no_sg_constraint: 1;
	unsigned int sg_tablesize;
	int devnum_next;
	struct mutex devnum_next_mutex;
	struct usb_devmap devmap;
	struct usb_device___8 *root_hub;
	struct usb_bus___8 *hs_companion;
	int bandwidth_allocated;
	int bandwidth_int_reqs;
	int bandwidth_isoc_reqs;
	unsigned int resuming_ports;
	struct mon_bus *mon_bus;
	int monitored;
};

struct usb_tt___8;

struct usb_device___8 {
	int devnum;
	char devpath[16];
	u32 route;
	enum usb_device_state state;
	enum usb_device_speed speed;
	unsigned int rx_lanes;
	unsigned int tx_lanes;
	struct usb_tt___8 *tt;
	int ttport;
	unsigned int toggle[2];
	struct usb_device___8 *parent;
	struct usb_bus___8 *bus;
	struct usb_host_endpoint ep0;
	struct device___348 dev;
	struct usb_device_descriptor descriptor;
	struct usb_host_bos *bos;
	struct usb_host_config___8 *config;
	struct usb_host_config___8 *actconfig;
	struct usb_host_endpoint *ep_in[16];
	struct usb_host_endpoint *ep_out[16];
	char **rawdescriptors;
	short unsigned int bus_mA;
	u8 portnum;
	u8 level;
	unsigned int can_submit: 1;
	unsigned int persist_enabled: 1;
	unsigned int have_langid: 1;
	unsigned int authorized: 1;
	unsigned int authenticated: 1;
	unsigned int wusb: 1;
	unsigned int lpm_capable: 1;
	unsigned int usb2_hw_lpm_capable: 1;
	unsigned int usb2_hw_lpm_besl_capable: 1;
	unsigned int usb2_hw_lpm_enabled: 1;
	unsigned int usb2_hw_lpm_allowed: 1;
	unsigned int usb3_lpm_u1_enabled: 1;
	unsigned int usb3_lpm_u2_enabled: 1;
	int string_langid;
	char *product;
	char *manufacturer;
	char *serial;
	struct list_head filelist;
	int maxchild;
	u32 quirks;
	atomic_t urbnum;
	long unsigned int active_duration;
	long unsigned int connect_time;
	unsigned int do_remote_wakeup: 1;
	unsigned int reset_resume: 1;
	unsigned int port_is_suspended: 1;
	struct wusb_dev *wusb_dev;
	int slot_id;
	enum usb_device_removable removable;
	struct usb2_lpm_parameters l1_params;
	struct usb3_lpm_parameters u1_params;
	struct usb3_lpm_parameters u2_params;
	unsigned int lpm_disable_count;
	u16 hub_delay;
};

struct usb_tt___8 {
	struct usb_device___8 *hub;
	int multi;
	unsigned int think_time;
	void *hcpriv;
	spinlock_t lock;
	struct list_head clear_list;
	struct work_struct clear_work;
};

struct usbdrv_wrap___8 {
	struct device_driver___348 driver;
	int for_devices;
};

struct usb_driver___8 {
	const char *name;
	int (*probe)(struct usb_interface___8 *, const struct usb_device_id *);
	void (*disconnect)(struct usb_interface___8 *);
	int (*unlocked_ioctl)(struct usb_interface___8 *, unsigned int, void *);
	int (*suspend)(struct usb_interface___8 *, pm_message_t);
	int (*resume)(struct usb_interface___8 *);
	int (*reset_resume)(struct usb_interface___8 *);
	int (*pre_reset)(struct usb_interface___8 *);
	int (*post_reset)(struct usb_interface___8 *);
	const struct usb_device_id *id_table;
	struct usb_dynids dynids;
	struct usbdrv_wrap___8 drvwrap;
	unsigned int no_dynamic_id: 1;
	unsigned int supports_autosuspend: 1;
	unsigned int disable_hub_initiated_lpm: 1;
	unsigned int soft_unbind: 1;
};

struct usb_device_driver___8 {
	const char *name;
	int (*probe)(struct usb_device___8 *);
	void (*disconnect)(struct usb_device___8 *);
	int (*suspend)(struct usb_device___8 *, pm_message_t);
	int (*resume)(struct usb_device___8 *, pm_message_t);
	struct usbdrv_wrap___8 drvwrap;
	unsigned int supports_autosuspend: 1;
};

struct urb___8;

typedef void (*usb_complete_t___8)(struct urb___8 *);

struct urb___8 {
	struct kref kref;
	void *hcpriv;
	atomic_t use_count;
	atomic_t reject;
	int unlinked;
	struct list_head urb_list;
	struct list_head anchor_list;
	struct usb_anchor *anchor;
	struct usb_device___8 *dev;
	struct usb_host_endpoint *ep;
	unsigned int pipe;
	unsigned int stream_id;
	int status;
	unsigned int transfer_flags;
	void *transfer_buffer;
	dma_addr_t transfer_dma;
	struct scatterlist *sg;
	int num_mapped_sgs;
	int num_sgs;
	u32 transfer_buffer_length;
	u32 actual_length;
	unsigned char *setup_packet;
	dma_addr_t setup_dma;
	int start_frame;
	int number_of_packets;
	int interval;
	int error_count;
	void *context;
	usb_complete_t___8 complete;
	struct usb_iso_packet_descriptor iso_frame_desc[0];
};

struct hc_driver___7;

struct usb_hcd___7 {
	struct usb_bus___8 self;
	struct kref kref;
	const char *product_desc;
	int speed;
	char irq_descr[24];
	struct timer_list rh_timer;
	struct urb___8 *status_urb;
	struct work_struct wakeup_work;
	const struct hc_driver___7 *driver;
	struct usb_phy___3 *usb_phy;
	struct usb_phy_roothub *phy_roothub;
	long unsigned int flags;
	unsigned int rh_registered: 1;
	unsigned int rh_pollable: 1;
	unsigned int msix_enabled: 1;
	unsigned int msi_enabled: 1;
	unsigned int skip_phy_initialization: 1;
	unsigned int uses_new_polling: 1;
	unsigned int wireless: 1;
	unsigned int has_tt: 1;
	unsigned int amd_resume_bug: 1;
	unsigned int can_do_streams: 1;
	unsigned int tpl_support: 1;
	unsigned int cant_recv_wakeups: 1;
	unsigned int irq;
	void *regs;
	resource_size_t rsrc_start;
	resource_size_t rsrc_len;
	unsigned int power_budget;
	struct giveback_urb_bh high_prio_bh;
	struct giveback_urb_bh low_prio_bh;
	struct mutex *address0_mutex;
	struct mutex *bandwidth_mutex;
	struct usb_hcd___7 *shared_hcd;
	struct usb_hcd___7 *primary_hcd;
	struct dma_pool___2 *pool[4];
	int state;
	long unsigned int hcd_priv[0];
};

struct hc_driver___7 {
	const char *description;
	const char *product_desc;
	size_t hcd_priv_size;
	irqreturn_t (*irq)(struct usb_hcd___7 *);
	int flags;
	int (*reset)(struct usb_hcd___7 *);
	int (*start)(struct usb_hcd___7 *);
	int (*pci_suspend)(struct usb_hcd___7 *, bool);
	int (*pci_resume)(struct usb_hcd___7 *, bool);
	void (*stop)(struct usb_hcd___7 *);
	void (*shutdown)(struct usb_hcd___7 *);
	int (*get_frame_number)(struct usb_hcd___7 *);
	int (*urb_enqueue)(struct usb_hcd___7 *, struct urb___8 *, gfp_t);
	int (*urb_dequeue)(struct usb_hcd___7 *, struct urb___8 *, int);
	int (*map_urb_for_dma)(struct usb_hcd___7 *, struct urb___8 *, gfp_t);
	void (*unmap_urb_for_dma)(struct usb_hcd___7 *, struct urb___8 *);
	void (*endpoint_disable)(struct usb_hcd___7 *, struct usb_host_endpoint *);
	void (*endpoint_reset)(struct usb_hcd___7 *, struct usb_host_endpoint *);
	int (*hub_status_data)(struct usb_hcd___7 *, char *);
	int (*hub_control)(struct usb_hcd___7 *, u16, u16, u16, char *, u16);
	int (*bus_suspend)(struct usb_hcd___7 *);
	int (*bus_resume)(struct usb_hcd___7 *);
	int (*start_port_reset)(struct usb_hcd___7 *, unsigned int);
	long unsigned int (*get_resuming_ports)(struct usb_hcd___7 *);
	void (*relinquish_port)(struct usb_hcd___7 *, int);
	int (*port_handed_over)(struct usb_hcd___7 *, int);
	void (*clear_tt_buffer_complete)(struct usb_hcd___7 *, struct usb_host_endpoint *);
	int (*alloc_dev)(struct usb_hcd___7 *, struct usb_device___8 *);
	void (*free_dev)(struct usb_hcd___7 *, struct usb_device___8 *);
	int (*alloc_streams)(struct usb_hcd___7 *, struct usb_device___8 *, struct usb_host_endpoint **, unsigned int, unsigned int, gfp_t);
	int (*free_streams)(struct usb_hcd___7 *, struct usb_device___8 *, struct usb_host_endpoint **, unsigned int, gfp_t);
	int (*add_endpoint)(struct usb_hcd___7 *, struct usb_device___8 *, struct usb_host_endpoint *);
	int (*drop_endpoint)(struct usb_hcd___7 *, struct usb_device___8 *, struct usb_host_endpoint *);
	int (*check_bandwidth)(struct usb_hcd___7 *, struct usb_device___8 *);
	void (*reset_bandwidth)(struct usb_hcd___7 *, struct usb_device___8 *);
	int (*address_device)(struct usb_hcd___7 *, struct usb_device___8 *);
	int (*enable_device)(struct usb_hcd___7 *, struct usb_device___8 *);
	int (*update_hub_device)(struct usb_hcd___7 *, struct usb_device___8 *, struct usb_tt___8 *, gfp_t);
	int (*reset_device)(struct usb_hcd___7 *, struct usb_device___8 *);
	int (*update_device)(struct usb_hcd___7 *, struct usb_device___8 *);
	int (*set_usb2_hw_lpm)(struct usb_hcd___7 *, struct usb_device___8 *, int);
	int (*enable_usb3_lpm_timeout)(struct usb_hcd___7 *, struct usb_device___8 *, enum usb3_link_state);
	int (*disable_usb3_lpm_timeout)(struct usb_hcd___7 *, struct usb_device___8 *, enum usb3_link_state);
	int (*find_raw_port_number)(struct usb_hcd___7 *, int);
	int (*port_power)(struct usb_hcd___7 *, int, bool);
};

struct usb_mon_operations___8 {
	void (*urb_submit)(struct usb_bus___8 *, struct urb___8 *);
	void (*urb_submit_error)(struct usb_bus___8 *, struct urb___8 *, int);
	void (*urb_complete)(struct usb_bus___8 *, struct urb___8 *, int);
};

struct fwnode_reference_args___270;

struct fwnode_endpoint___270;

struct fwnode_operations___270 {
	struct fwnode_handle___270 * (*get)(struct fwnode_handle___270 *);
	void (*put)(struct fwnode_handle___270 *);
	bool (*device_is_available)(const struct fwnode_handle___270 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___270 *, const struct device___348 *);
	bool (*property_present)(const struct fwnode_handle___270 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___270 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___270 *, const char *, const char **, size_t);
	struct fwnode_handle___270 * (*get_parent)(const struct fwnode_handle___270 *);
	struct fwnode_handle___270 * (*get_next_child_node)(const struct fwnode_handle___270 *, struct fwnode_handle___270 *);
	struct fwnode_handle___270 * (*get_named_child_node)(const struct fwnode_handle___270 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___270 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___270 *);
	struct fwnode_handle___270 * (*graph_get_next_endpoint)(const struct fwnode_handle___270 *, struct fwnode_handle___270 *);
	struct fwnode_handle___270 * (*graph_get_remote_endpoint)(const struct fwnode_handle___270 *);
	struct fwnode_handle___270 * (*graph_get_port_parent)(struct fwnode_handle___270 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___270 *, struct fwnode_endpoint___270 *);
};

struct fwnode_endpoint___270 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___270 *local_fwnode;
};

struct fwnode_reference_args___270 {
	struct fwnode_handle___270 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct kernel_param_ops___309 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___309 *);
	int (*get)(char *, const struct kernel_param___309 *);
	void (*free)(void *);
};

struct kparam_array___309;

struct kernel_param___309 {
	const char *name;
	struct module___312 *mod;
	const struct kernel_param_ops___309 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___309 *arr;
	};
};

struct kparam_array___309 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___309 *ops;
	void *elem;
};

struct module_attribute___309 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___309 *, struct module_kobject___309 *, char *);
	ssize_t (*store)(struct module_attribute___309 *, struct module_kobject___309 *, const char *, size_t);
	void (*setup)(struct module___312 *, const char *);
	int (*test)(struct module___312 *);
	void (*free)(struct module___312 *);
};

typedef int (*key_restrict_link_func_t___351)(struct key___350 *, const struct key_type *, const union key_payload *, struct key___350 *);

struct key_restriction___350;

struct key___350 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___382 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___350 *restrict_link;
};

struct key_restriction___350 {
	key_restrict_link_func_t___351 check;
	struct key___350 *key;
	struct key_type *keytype;
};

struct seq_operations___322 {
	void * (*start)(struct seq_file___323 *, loff_t *);
	void (*stop)(struct seq_file___323 *, void *);
	void * (*next)(struct seq_file___323 *, void *, loff_t *);
	int (*show)(struct seq_file___323 *, void *);
};

typedef void compound_page_dtor___369(struct page___382 *);

struct usb_port___2;

struct usb_hub___2 {
	struct device___348 *intfdev;
	struct usb_device___8 *hdev;
	struct kref kref;
	struct urb___8 *urb;
	u8 (*buffer)[8];
	union {
		struct usb_hub_status hub;
		struct usb_port_status port;
	} *status;
	struct mutex status_mutex;
	int error;
	int nerrors;
	long unsigned int event_bits[1];
	long unsigned int change_bits[1];
	long unsigned int removed_bits[1];
	long unsigned int wakeup_bits[1];
	long unsigned int power_bits[1];
	long unsigned int child_usage_bits[1];
	long unsigned int warm_reset_bits[1];
	struct usb_hub_descriptor *descriptor;
	struct usb_tt___8 tt;
	unsigned int mA_per_port;
	unsigned int wakeup_enabled_descendants;
	unsigned int limited_power: 1;
	unsigned int quiescing: 1;
	unsigned int disconnected: 1;
	unsigned int in_reset: 1;
	unsigned int quirk_check_port_auto_suspend: 1;
	unsigned int has_indicators: 1;
	u8 indicator[31];
	struct delayed_work leds;
	struct delayed_work init_work;
	struct work_struct events;
	struct usb_port___2 **ports;
};

struct usb_port___2 {
	struct usb_device___8 *child;
	struct device___348 dev;
	struct usb_dev_state *port_owner;
	struct usb_port___2 *peer;
	struct dev_pm_qos_request___22 *req;
	enum usb_port_connect_type connect_type;
	usb_port_location_t location;
	struct mutex status_lock;
	u32 over_current_count;
	u8 portnum;
	u32 quirks;
	unsigned int is_superspeed: 1;
	unsigned int usb3_lpm_u1_permit: 1;
	unsigned int usb3_lpm_u2_permit: 1;
};

typedef void (*companion_fn)(struct pci_dev___33 *, struct usb_hcd___3 *, struct pci_dev___33 *, struct usb_hcd___3 *);

struct acpi_device___19;

struct acpi_hotplug_profile___19 {
	struct kobject___365 kobj;
	int (*scan_dependent)(struct acpi_device___19 *);
	void (*notify_online)(struct acpi_device___19 *);
	bool enabled: 1;
	bool demand_offline: 1;
};

struct acpi_device_wakeup_context___19 {
	void (*func)(struct acpi_device_wakeup_context___19 *);
	struct device___345 *dev;
};

struct acpi_device_wakeup___19 {
	acpi_handle gpe_device;
	u64 gpe_number;
	u64 sleep_state;
	struct list_head resources;
	struct acpi_device_wakeup_flags flags;
	struct acpi_device_wakeup_context___19 context;
	struct wakeup_source___8 *ws;
	int prepare_count;
	int enable_count;
};

struct acpi_scan_handler___19;

struct acpi_hotplug_context___19;

struct acpi_driver___19;

struct acpi_device___19 {
	int device_type;
	acpi_handle handle;
	struct fwnode_handle___267 fwnode;
	struct acpi_device___19 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup___19 wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_device_data data;
	struct acpi_scan_handler___19 *handler;
	struct acpi_hotplug_context___19 *hp;
	struct acpi_driver___19 *driver;
	const struct acpi_gpio_mapping *driver_gpios;
	void *driver_data;
	struct device___345 dev;
	unsigned int physical_node_count;
	unsigned int dep_unmet;
	struct list_head physical_node_list;
	struct mutex physical_node_lock;
	void (*remove)(struct acpi_device___19 *);
};

struct acpi_scan_handler___19 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	bool (*match)(const char *, const struct acpi_device_id **);
	int (*attach)(struct acpi_device___19 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___19 *);
	void (*bind)(struct device___345 *);
	void (*unbind)(struct device___345 *);
	struct acpi_hotplug_profile___19 hotplug;
};

struct acpi_hotplug_context___19 {
	struct acpi_device___19 *self;
	int (*notify)(struct acpi_device___19 *, u32);
	void (*uevent)(struct acpi_device___19 *, u32);
	void (*fixup)(struct acpi_device___19 *);
};

typedef int (*acpi_op_add___19)(struct acpi_device___19 *);

typedef int (*acpi_op_remove___19)(struct acpi_device___19 *);

typedef void (*acpi_op_notify___19)(struct acpi_device___19 *, u32);

struct acpi_device_ops___19 {
	acpi_op_add___19 add;
	acpi_op_remove___19 remove;
	acpi_op_notify___19 notify;
};

struct acpi_driver___19 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___19 ops;
	struct device_driver___345 drv;
	struct module___309 *owner;
};

struct acpi_bus_type___3 {
	struct list_head list;
	const char *name;
	bool (*match)(struct device___345 *);
	struct acpi_device___19 * (*find_companion)(struct device___345 *);
	void (*setup)(struct device___345 *);
	void (*cleanup)(struct device___345 *);
};

struct usb_port___3;

struct usb_hub___3 {
	struct device___345 *intfdev;
	struct usb_device *hdev;
	struct kref kref;
	struct urb *urb;
	u8 (*buffer)[8];
	union {
		struct usb_hub_status hub;
		struct usb_port_status port;
	} *status;
	struct mutex status_mutex;
	int error;
	int nerrors;
	long unsigned int event_bits[1];
	long unsigned int change_bits[1];
	long unsigned int removed_bits[1];
	long unsigned int wakeup_bits[1];
	long unsigned int power_bits[1];
	long unsigned int child_usage_bits[1];
	long unsigned int warm_reset_bits[1];
	struct usb_hub_descriptor *descriptor;
	struct usb_tt tt;
	unsigned int mA_per_port;
	unsigned int wakeup_enabled_descendants;
	unsigned int limited_power: 1;
	unsigned int quiescing: 1;
	unsigned int disconnected: 1;
	unsigned int in_reset: 1;
	unsigned int quirk_check_port_auto_suspend: 1;
	unsigned int has_indicators: 1;
	u8 indicator[31];
	struct delayed_work leds;
	struct delayed_work init_work;
	struct work_struct events;
	struct usb_port___3 **ports;
};

struct dev_pm_qos_request___23;

struct usb_port___3 {
	struct usb_device *child;
	struct device___345 dev;
	struct usb_dev_state *port_owner;
	struct usb_port___3 *peer;
	struct dev_pm_qos_request___23 *req;
	enum usb_port_connect_type connect_type;
	usb_port_location_t location;
	struct mutex status_lock;
	u32 over_current_count;
	u8 portnum;
	u32 quirks;
	unsigned int is_superspeed: 1;
	unsigned int usb3_lpm_u1_permit: 1;
	unsigned int usb3_lpm_u2_permit: 1;
};

enum usb_phy_interface {
	USBPHY_INTERFACE_MODE_UNKNOWN = 0,
	USBPHY_INTERFACE_MODE_UTMI = 1,
	USBPHY_INTERFACE_MODE_UTMIW = 2,
	USBPHY_INTERFACE_MODE_ULPI = 3,
	USBPHY_INTERFACE_MODE_SERIAL = 4,
	USBPHY_INTERFACE_MODE_HSIC = 5,
};

struct mon_bus {
	struct list_head bus_link;
	spinlock_t lock;
	struct usb_bus___3 *u_bus;
	int text_inited;
	int bin_inited;
	struct dentry___377 *dent_s;
	struct dentry___377 *dent_t;
	struct dentry___377 *dent_u;
	struct device___345 *classdev;
	int nreaders;
	struct list_head r_list;
	struct kref ref;
	unsigned int cnt_events;
	unsigned int cnt_text_lost;
};

struct mon_reader {
	struct list_head r_link;
	struct mon_bus *m_bus;
	void *r_data;
	void (*rnf_submit)(void *, struct urb___3 *);
	void (*rnf_error)(void *, struct urb___3 *, int);
	void (*rnf_complete)(void *, struct urb___3 *, int);
};

struct usb_device___9;

struct mon_bus___2;

struct usb_bus___9 {
	struct device___348 *controller;
	struct device___348 *sysdev;
	int busnum;
	const char *bus_name;
	u8 uses_dma;
	u8 uses_pio_for_control;
	u8 otg_port;
	unsigned int is_b_host: 1;
	unsigned int b_hnp_enable: 1;
	unsigned int no_stop_on_short: 1;
	unsigned int no_sg_constraint: 1;
	unsigned int sg_tablesize;
	int devnum_next;
	struct mutex devnum_next_mutex;
	struct usb_devmap devmap;
	struct usb_device___9 *root_hub;
	struct usb_bus___9 *hs_companion;
	int bandwidth_allocated;
	int bandwidth_int_reqs;
	int bandwidth_isoc_reqs;
	unsigned int resuming_ports;
	struct mon_bus___2 *mon_bus;
	int monitored;
};

struct usb_device___9 {
	int devnum;
	char devpath[16];
	u32 route;
	enum usb_device_state state;
	enum usb_device_speed speed;
	unsigned int rx_lanes;
	unsigned int tx_lanes;
	struct usb_tt___3 *tt;
	int ttport;
	unsigned int toggle[2];
	struct usb_device___9 *parent;
	struct usb_bus___9 *bus;
	struct usb_host_endpoint ep0;
	struct device___348 dev;
	struct usb_device_descriptor descriptor;
	struct usb_host_bos *bos;
	struct usb_host_config___8 *config;
	struct usb_host_config___8 *actconfig;
	struct usb_host_endpoint *ep_in[16];
	struct usb_host_endpoint *ep_out[16];
	char **rawdescriptors;
	short unsigned int bus_mA;
	u8 portnum;
	u8 level;
	unsigned int can_submit: 1;
	unsigned int persist_enabled: 1;
	unsigned int have_langid: 1;
	unsigned int authorized: 1;
	unsigned int authenticated: 1;
	unsigned int wusb: 1;
	unsigned int lpm_capable: 1;
	unsigned int usb2_hw_lpm_capable: 1;
	unsigned int usb2_hw_lpm_besl_capable: 1;
	unsigned int usb2_hw_lpm_enabled: 1;
	unsigned int usb2_hw_lpm_allowed: 1;
	unsigned int usb3_lpm_u1_enabled: 1;
	unsigned int usb3_lpm_u2_enabled: 1;
	int string_langid;
	char *product;
	char *manufacturer;
	char *serial;
	struct list_head filelist;
	int maxchild;
	u32 quirks;
	atomic_t urbnum;
	long unsigned int active_duration;
	long unsigned int connect_time;
	unsigned int do_remote_wakeup: 1;
	unsigned int reset_resume: 1;
	unsigned int port_is_suspended: 1;
	struct wusb_dev *wusb_dev;
	int slot_id;
	enum usb_device_removable removable;
	struct usb2_lpm_parameters l1_params;
	struct usb3_lpm_parameters u1_params;
	struct usb3_lpm_parameters u2_params;
	unsigned int lpm_disable_count;
	u16 hub_delay;
};

struct mon_bus___2 {
	struct list_head bus_link;
	spinlock_t lock;
	struct usb_bus___9 *u_bus;
	int text_inited;
	int bin_inited;
	struct dentry___380 *dent_s;
	struct dentry___380 *dent_t;
	struct dentry___380 *dent_u;
	struct device___348 *classdev;
	int nreaders;
	struct list_head r_list;
	struct kref ref;
	unsigned int cnt_events;
	unsigned int cnt_text_lost;
};

struct snap {
	int slen;
	char str[80];
};

struct file___382;

struct kiocb___382;

struct vm_area_struct___383;

struct inode___382;

struct file_lock___382;

struct page___383;

struct seq_file___324;

struct file_operations___382 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___382 *, loff_t, int);
	ssize_t (*read)(struct file___382 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___382 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___382 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___382 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___382 *, bool);
	int (*iterate)(struct file___382 *, struct dir_context *);
	int (*iterate_shared)(struct file___382 *, struct dir_context *);
	__poll_t (*poll)(struct file___382 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___382 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___382 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___382 *, struct vm_area_struct___383 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___382 *, struct file___382 *);
	int (*flush)(struct file___382 *, fl_owner_t);
	int (*release)(struct inode___382 *, struct file___382 *);
	int (*fsync)(struct file___382 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___382 *, int);
	int (*lock)(struct file___382 *, int, struct file_lock___382 *);
	ssize_t (*sendpage)(struct file___382 *, struct page___383 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___382 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___382 *, int, struct file_lock___382 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___382 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___382 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___382 *, long int, struct file_lock___382 **, void **);
	long int (*fallocate)(struct file___382 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___324 *, struct file___382 *);
	ssize_t (*copy_file_range)(struct file___382 *, loff_t, struct file___382 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___382 *, loff_t, struct file___382 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___382 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___382 {
	u64 seqnum;
	struct vm_area_struct___383 *vmas[4];
};

struct page_frag___382 {
	struct page___383 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___382;

struct cred___351;

struct signal_struct___261;

struct vm_struct___288;

struct task_struct___383 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___383 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___382 *mm;
	struct mm_struct___382 *active_mm;
	struct vmacache___382 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___383 *real_parent;
	struct task_struct___383 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___383 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___219 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___219 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___219 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___351 *ptracer_cred;
	const struct cred___351 *real_cred;
	const struct cred___351 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___261 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___383 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___107 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___382 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___383 *oom_reaper_list;
	struct vm_struct___288 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___143 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___383 *pgtable_t___382;

struct address_space___381;

struct dev_pagemap___370;

struct page___383 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___381 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___383 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___382 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___382 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___370 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___382;

struct lruvec___382 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___382 *pgdat;
};

struct zone___382 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___382 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___382 {
	struct zone___382 *zone;
	int zone_idx;
};

struct zonelist___382 {
	struct zoneref___382 _zonerefs[25];
};

struct pglist_data___382 {
	struct zone___382 node_zones[3];
	struct zonelist___382 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___383 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___383 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___382 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___383 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___383 *owner;
};

struct secondary_data___383 {
	void *stack;
	struct task_struct___383 *task;
	long int status;
};

struct blocking_notifier_head___382 {
	struct rw_semaphore___383 rwsem;
	struct notifier_block *head;
};

struct kernfs_root___375;

struct kernfs_elem_dir___375 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___375 *root;
};

struct kernfs_node___376;

struct kernfs_syscall_ops___375;

struct kernfs_root___375 {
	struct kernfs_node___376 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___375 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___375 {
	struct kernfs_node___376 *target_kn;
};

struct kernfs_ops___375;

struct kernfs_elem_attr___375 {
	const struct kernfs_ops___375 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___376 *notify_next;
};

struct kernfs_node___376 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___376 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___375 dir;
		struct kernfs_elem_symlink___375 symlink;
		struct kernfs_elem_attr___375 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___375;

struct kernfs_ops___375 {
	int (*open)(struct kernfs_open_file___375 *);
	void (*release)(struct kernfs_open_file___375 *);
	int (*seq_show)(struct seq_file___324 *, void *);
	void * (*seq_start)(struct seq_file___324 *, loff_t *);
	void * (*seq_next)(struct seq_file___324 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___324 *, void *);
	ssize_t (*read)(struct kernfs_open_file___375 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___375 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___375 *, struct vm_area_struct___383 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___375 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___375 {
	int (*remount_fs)(struct kernfs_root___375 *, int *, char *);
	int (*show_options)(struct seq_file___324 *, struct kernfs_root___375 *);
	int (*mkdir)(struct kernfs_node___376 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___376 *);
	int (*rename)(struct kernfs_node___376 *, struct kernfs_node___376 *, const char *);
	int (*show_path)(struct seq_file___324 *, struct kernfs_node___376 *, struct kernfs_root___375 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___323;

struct seq_file___324 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___323 *op;
	int poll_event;
	const struct file___382 *file;
	void *private;
};

struct vm_operations_struct___370;

struct kernfs_open_file___375 {
	struct kernfs_node___376 *kn;
	struct file___382 *file;
	struct seq_file___324 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___370 *vm_ops;
};

struct dentry___381;

struct path___382 {
	struct vfsmount *mnt;
	struct dentry___381 *dentry;
};

struct file___382 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___382 f_path;
	struct inode___382 *f_inode;
	const struct file_operations___382 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___219 f_owner;
	const struct cred___351 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___381 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___370;

struct vm_operations_struct___370 {
	void (*open)(struct vm_area_struct___383 *);
	void (*close)(struct vm_area_struct___383 *);
	int (*split)(struct vm_area_struct___383 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___383 *);
	vm_fault_t (*fault)(struct vm_fault___370 *);
	vm_fault_t (*huge_fault)(struct vm_fault___370 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___370 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___383 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___370 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___370 *);
	int (*access)(struct vm_area_struct___383 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___383 *);
	int (*set_policy)(struct vm_area_struct___383 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___383 *, long unsigned int);
	struct page___383 * (*find_special_page)(struct vm_area_struct___383 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_area_struct___383 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___383 *vm_next;
	struct vm_area_struct___383 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___382 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___370 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___382 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___369;

struct bin_attribute___345;

struct attribute_group___346 {
	const char *name;
	umode_t (*is_visible)(struct kobject___369 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___369 *, struct bin_attribute___345 *, int);
	struct attribute **attrs;
	struct bin_attribute___345 **bin_attrs;
};

struct kset___368;

struct kobj_type___368;

struct kobject___369 {
	const char *name;
	struct list_head entry;
	struct kobject___369 *parent;
	struct kset___368 *kset;
	struct kobj_type___368 *ktype;
	struct kernfs_node___376 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___345 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___382 *, struct kobject___369 *, struct bin_attribute___345 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___382 *, struct kobject___369 *, struct bin_attribute___345 *, char *, loff_t, size_t);
	int (*mmap)(struct file___382 *, struct kobject___369 *, struct bin_attribute___345 *, struct vm_area_struct___383 *);
};

struct sysfs_ops___368 {
	ssize_t (*show)(struct kobject___369 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___369 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___368;

struct kset___368 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___369 kobj;
	const struct kset_uevent_ops___368 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___368 {
	void (*release)(struct kobject___369 *);
	const struct sysfs_ops___368 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___29 * (*child_ns_type)(struct kobject___369 *);
	const void * (*namespace)(struct kobject___369 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___368 {
	int (* const filter)(struct kset___368 *, struct kobject___369 *);
	const char * (* const name)(struct kset___368 *, struct kobject___369 *);
	int (* const uevent)(struct kset___368 *, struct kobject___369 *, struct kobj_uevent_env *);
};

struct kobj_attribute___360 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___369 *, struct kobj_attribute___360 *, char *);
	ssize_t (*store)(struct kobject___369 *, struct kobj_attribute___360 *, const char *, size_t);
};

struct device___349;

struct dev_pm_ops___349 {
	int (*prepare)(struct device___349 *);
	void (*complete)(struct device___349 *);
	int (*suspend)(struct device___349 *);
	int (*resume)(struct device___349 *);
	int (*freeze)(struct device___349 *);
	int (*thaw)(struct device___349 *);
	int (*poweroff)(struct device___349 *);
	int (*restore)(struct device___349 *);
	int (*suspend_late)(struct device___349 *);
	int (*resume_early)(struct device___349 *);
	int (*freeze_late)(struct device___349 *);
	int (*thaw_early)(struct device___349 *);
	int (*poweroff_late)(struct device___349 *);
	int (*restore_early)(struct device___349 *);
	int (*suspend_noirq)(struct device___349 *);
	int (*resume_noirq)(struct device___349 *);
	int (*freeze_noirq)(struct device___349 *);
	int (*thaw_noirq)(struct device___349 *);
	int (*poweroff_noirq)(struct device___349 *);
	int (*restore_noirq)(struct device___349 *);
	int (*runtime_suspend)(struct device___349 *);
	int (*runtime_resume)(struct device___349 *);
	int (*runtime_idle)(struct device___349 *);
};

struct dev_pm_info___349 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___6 *subsys_data;
	void (*set_latency_tolerance)(struct device___349 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___349;

struct bus_type___349;

struct device_driver___349;

struct dev_pm_domain___349;

struct fwnode_handle___271;

struct class___349;

struct device___349 {
	struct device___349 *parent;
	struct device_private *p;
	struct kobject___369 kobj;
	const char *init_name;
	const struct device_type___349 *type;
	struct mutex mutex;
	struct bus_type___349 *bus;
	struct device_driver___349 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___349 power;
	struct dev_pm_domain___349 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___271 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___349 *class;
	const struct attribute_group___346 **groups;
	void (*release)(struct device___349 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___349 {
	struct dev_pm_ops___349 ops;
	void (*detach)(struct device___349 *, bool);
	int (*activate)(struct device___349 *);
	void (*sync)(struct device___349 *);
	void (*dismiss)(struct device___349 *);
};

struct key___351;

struct user_struct___351 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___351 *uid_keyring;
	struct key___351 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___382;

struct mm_struct___382 {
	struct {
		struct vm_area_struct___383 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___382 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___383 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___382 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___383 *owner;
		struct user_namespace___3 *user_ns;
		struct file___382 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___382 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___351 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___351 *session_keyring;
	struct key___351 *process_keyring;
	struct key___351 *thread_keyring;
	struct key___351 *request_key_auth;
	void *security;
	struct user_struct___351 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct signal_struct___261 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___383 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___383 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___219 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___219 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___382 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___219 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_struct___288 {
	struct vm_struct___288 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___383 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___273 {
	struct task_struct___383 task;
	long unsigned int stack[8192];
};

struct bus_type___349 {
	const char *name;
	const char *dev_name;
	struct device___349 *dev_root;
	const struct attribute_group___346 **bus_groups;
	const struct attribute_group___346 **dev_groups;
	const struct attribute_group___346 **drv_groups;
	int (*match)(struct device___349 *, struct device_driver___349 *);
	int (*uevent)(struct device___349 *, struct kobj_uevent_env *);
	int (*probe)(struct device___349 *);
	int (*remove)(struct device___349 *);
	void (*shutdown)(struct device___349 *);
	int (*online)(struct device___349 *);
	int (*offline)(struct device___349 *);
	int (*suspend)(struct device___349 *, pm_message_t);
	int (*resume)(struct device___349 *);
	int (*num_vf)(struct device___349 *);
	int (*dma_configure)(struct device___349 *);
	const struct dev_pm_ops___349 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___349 {
	const char *name;
	struct bus_type___349 *bus;
	struct module___11 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___349 *);
	int (*remove)(struct device___349 *);
	void (*shutdown)(struct device___349 *);
	int (*suspend)(struct device___349 *, pm_message_t);
	int (*resume)(struct device___349 *);
	const struct attribute_group___346 **groups;
	const struct dev_pm_ops___349 *pm;
	void (*coredump)(struct device___349 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___349 {
	const char *name;
	const struct attribute_group___346 **groups;
	int (*uevent)(struct device___349 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___349 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___349 *);
	const struct dev_pm_ops___349 *pm;
};

struct class___349 {
	const char *name;
	struct module___11 *owner;
	const struct attribute_group___346 **class_groups;
	const struct attribute_group___346 **dev_groups;
	struct kobject___369 *dev_kobj;
	int (*dev_uevent)(struct device___349 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___349 *, umode_t *);
	void (*class_release)(struct class___349 *);
	void (*dev_release)(struct device___349 *);
	int (*shutdown_pre)(struct device___349 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___349 *);
	const struct dev_pm_ops___349 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct fwnode_operations___271;

struct fwnode_handle___271 {
	struct fwnode_handle___271 *secondary;
	const struct fwnode_operations___271 *ops;
};

struct dentry_operations___381;

struct super_block___381;

struct dentry___381 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___381 *d_parent;
	struct qstr d_name;
	struct inode___382 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___381 *d_op;
	struct super_block___381 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___381;

struct address_space___381 {
	struct inode___382 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___383 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___381 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___381;

struct block_device___381;

struct inode___382 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___381 *i_op;
	struct super_block___381 *i_sb;
	struct address_space___381 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___383 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___382 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___381 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___381 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___381 {
	int (*d_revalidate)(struct dentry___381 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___381 *, unsigned int);
	int (*d_hash)(const struct dentry___381 *, struct qstr *);
	int (*d_compare)(const struct dentry___381 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___381 *);
	int (*d_init)(struct dentry___381 *);
	void (*d_release)(struct dentry___381 *);
	void (*d_prune)(struct dentry___381 *);
	void (*d_iput)(struct dentry___381 *, struct inode___382 *);
	char * (*d_dname)(struct dentry___381 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___382 *);
	int (*d_manage)(const struct path___382 *, bool);
	struct dentry___381 * (*d_real)(struct dentry___381 *, const struct inode___382 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___381;

struct mem_dqinfo___381 {
	struct quota_format_type___381 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___381;

struct quota_info___381 {
	unsigned int flags;
	struct rw_semaphore___383 dqio_sem;
	struct inode___382 *files[3];
	struct mem_dqinfo___381 info[3];
	const struct quota_format_ops___381 *ops[3];
};

struct rcuwait___381 {
	struct task_struct___383 *task;
};

struct percpu_rw_semaphore___381 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___383 rw_sem;
	struct rcuwait___381 writer;
	int readers_block;
};

struct sb_writers___381 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___381 rw_sem[3];
};

struct file_system_type___381;

struct super_operations___381;

struct dquot_operations___381;

struct quotactl_ops___381;

struct super_block___381 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___381 *s_type;
	const struct super_operations___381 *s_op;
	const struct dquot_operations___381 *dq_op;
	const struct quotactl_ops___381 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___381 *s_root;
	struct rw_semaphore___383 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___381 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___381 s_dquot;
	struct sb_writers___381 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___381 *s_d_op;
	int cleancache_poolid;
	struct shrinker___134 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

typedef int (*dev_page_fault_t___370)(struct vm_area_struct___383 *, long unsigned int, const struct page___383 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___370)(struct page___383 *, void *);

struct dev_pagemap___370 {
	dev_page_fault_t___370 page_fault;
	dev_page_free_t___370 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___349 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___382 {
	struct task_struct___383 *task;
	struct core_thread___382 *next;
};

struct core_state___382 {
	atomic_t nr_threads;
	struct core_thread___382 dumper;
	struct completion startup;
};

struct vm_fault___370 {
	struct vm_area_struct___383 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___383 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___383 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___382 prealloc_pte;
};

struct kiocb___382 {
	struct file___382 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___382 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___381 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___382 *ia_file;
};

struct dquot___381 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___381 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___381 {
	int qf_fmt_id;
	const struct quota_format_ops___381 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___381 *qf_next;
};

struct quota_format_ops___381 {
	int (*check_quota_file)(struct super_block___381 *, int);
	int (*read_file_info)(struct super_block___381 *, int);
	int (*write_file_info)(struct super_block___381 *, int);
	int (*free_file_info)(struct super_block___381 *, int);
	int (*read_dqblk)(struct dquot___381 *);
	int (*commit_dqblk)(struct dquot___381 *);
	int (*release_dqblk)(struct dquot___381 *);
	int (*get_next_id)(struct super_block___381 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___381 {
	int (*write_dquot)(struct dquot___381 *);
	struct dquot___381 * (*alloc_dquot)(struct super_block___381 *, int);
	void (*destroy_dquot)(struct dquot___381 *);
	int (*acquire_dquot)(struct dquot___381 *);
	int (*release_dquot)(struct dquot___381 *);
	int (*mark_dirty)(struct dquot___381 *);
	int (*write_info)(struct super_block___381 *, int);
	qsize_t * (*get_reserved_space)(struct inode___382 *);
	int (*get_projid)(struct inode___382 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___382 *, qsize_t *);
	int (*get_next_id)(struct super_block___381 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___381 {
	int (*quota_on)(struct super_block___381 *, int, int, const struct path___382 *);
	int (*quota_off)(struct super_block___381 *, int);
	int (*quota_enable)(struct super_block___381 *, unsigned int);
	int (*quota_disable)(struct super_block___381 *, unsigned int);
	int (*quota_sync)(struct super_block___381 *, int);
	int (*set_info)(struct super_block___381 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___381 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___381 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___381 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___381 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___381 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___381 {
	int (*writepage)(struct page___383 *, struct writeback_control___3 *);
	int (*readpage)(struct file___382 *, struct page___383 *);
	int (*writepages)(struct address_space___381 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___383 *);
	int (*readpages)(struct file___382 *, struct address_space___381 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___382 *, struct address_space___381 *, loff_t, unsigned int, unsigned int, struct page___383 **, void **);
	int (*write_end)(struct file___382 *, struct address_space___381 *, loff_t, unsigned int, unsigned int, struct page___383 *, void *);
	sector_t (*bmap)(struct address_space___381 *, sector_t);
	void (*invalidatepage)(struct page___383 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___383 *, gfp_t);
	void (*freepage)(struct page___383 *);
	ssize_t (*direct_IO)(struct kiocb___382 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___381 *, struct page___383 *, struct page___383 *, enum migrate_mode);
	bool (*isolate_page)(struct page___383 *, isolate_mode_t);
	void (*putback_page)(struct page___383 *);
	int (*launder_page)(struct page___383 *);
	int (*is_partially_uptodate)(struct page___383 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___383 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___381 *, struct page___383 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___382 *, sector_t *);
	void (*swap_deactivate)(struct file___382 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___381 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___382 *bd_inode;
	struct super_block___381 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___381 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___381 {
	struct dentry___381 * (*lookup)(struct inode___382 *, struct dentry___381 *, unsigned int);
	const char * (*get_link)(struct dentry___381 *, struct inode___382 *, struct delayed_call *);
	int (*permission)(struct inode___382 *, int);
	struct posix_acl * (*get_acl)(struct inode___382 *, int);
	int (*readlink)(struct dentry___381 *, char *, int);
	int (*create)(struct inode___382 *, struct dentry___381 *, umode_t, bool);
	int (*link)(struct dentry___381 *, struct inode___382 *, struct dentry___381 *);
	int (*unlink)(struct inode___382 *, struct dentry___381 *);
	int (*symlink)(struct inode___382 *, struct dentry___381 *, const char *);
	int (*mkdir)(struct inode___382 *, struct dentry___381 *, umode_t);
	int (*rmdir)(struct inode___382 *, struct dentry___381 *);
	int (*mknod)(struct inode___382 *, struct dentry___381 *, umode_t, dev_t);
	int (*rename)(struct inode___382 *, struct dentry___381 *, struct inode___382 *, struct dentry___381 *, unsigned int);
	int (*setattr)(struct dentry___381 *, struct iattr___381 *);
	int (*getattr)(const struct path___382 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___381 *, char *, size_t);
	int (*fiemap)(struct inode___382 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___382 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___382 *, struct dentry___381 *, struct file___382 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___382 *, struct dentry___381 *, umode_t);
	int (*set_acl)(struct inode___382 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___381 {
	void (*fl_copy_lock)(struct file_lock___382 *, struct file_lock___382 *);
	void (*fl_release_private)(struct file_lock___382 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___381;

struct lock_manager_operations___381;

struct file_lock___382 {
	struct file_lock___382 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___382 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___381 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___381 *fl_ops;
	const struct lock_manager_operations___381 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___381 {
	int (*lm_compare_owner)(struct file_lock___382 *, struct file_lock___382 *);
	long unsigned int (*lm_owner_key)(struct file_lock___382 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___382 *);
	int (*lm_grant)(struct file_lock___382 *, int);
	bool (*lm_break)(struct file_lock___382 *);
	int (*lm_change)(struct file_lock___382 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___382 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___381 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___381 *fa_next;
	struct file___382 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___381 {
	const char *name;
	int fs_flags;
	struct dentry___381 * (*mount)(struct file_system_type___381 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___381 *);
	struct module___11 *owner;
	struct file_system_type___381 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___381 {
	struct inode___382 * (*alloc_inode)(struct super_block___381 *);
	void (*destroy_inode)(struct inode___382 *);
	void (*dirty_inode)(struct inode___382 *, int);
	int (*write_inode)(struct inode___382 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___382 *);
	void (*evict_inode)(struct inode___382 *);
	void (*put_super)(struct super_block___381 *);
	int (*sync_fs)(struct super_block___381 *, int);
	int (*freeze_super)(struct super_block___381 *);
	int (*freeze_fs)(struct super_block___381 *);
	int (*thaw_super)(struct super_block___381 *);
	int (*unfreeze_fs)(struct super_block___381 *);
	int (*statfs)(struct dentry___381 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___381 *, int *, char *);
	void (*umount_begin)(struct super_block___381 *);
	int (*show_options)(struct seq_file___324 *, struct dentry___381 *);
	int (*show_devname)(struct seq_file___324 *, struct dentry___381 *);
	int (*show_path)(struct seq_file___324 *, struct dentry___381 *);
	int (*show_stats)(struct seq_file___324 *, struct dentry___381 *);
	ssize_t (*quota_read)(struct super_block___381 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___381 *, int, const char *, size_t, loff_t);
	struct dquot___381 ** (*get_dquots)(struct inode___382 *);
	int (*bdev_try_to_free_page)(struct super_block___381 *, struct page___383 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___381 *, struct shrink_control___134 *);
	long int (*free_cached_objects)(struct super_block___381 *, struct shrink_control___134 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct usb_interface___9 {
	struct usb_host_interface *altsetting;
	struct usb_host_interface *cur_altsetting;
	unsigned int num_altsetting;
	struct usb_interface_assoc_descriptor *intf_assoc;
	int minor;
	enum usb_interface_condition condition;
	unsigned int sysfs_files_created: 1;
	unsigned int ep_devs_created: 1;
	unsigned int unregistering: 1;
	unsigned int needs_remote_wakeup: 1;
	unsigned int needs_altsetting0: 1;
	unsigned int needs_binding: 1;
	unsigned int resetting_device: 1;
	unsigned int authorized: 1;
	struct device___349 dev;
	struct device___349 *usb_dev;
	atomic_t pm_usage_cnt;
	struct work_struct reset_ws;
};

struct usb_host_config___9 {
	struct usb_config_descriptor desc;
	char *string;
	struct usb_interface_assoc_descriptor *intf_assoc[16];
	struct usb_interface___9 *interface[32];
	struct usb_interface_cache *intf_cache[32];
	unsigned char *extra;
	int extralen;
};

struct usb_device___10;

struct mon_bus___3;

struct usb_bus___10 {
	struct device___349 *controller;
	struct device___349 *sysdev;
	int busnum;
	const char *bus_name;
	u8 uses_dma;
	u8 uses_pio_for_control;
	u8 otg_port;
	unsigned int is_b_host: 1;
	unsigned int b_hnp_enable: 1;
	unsigned int no_stop_on_short: 1;
	unsigned int no_sg_constraint: 1;
	unsigned int sg_tablesize;
	int devnum_next;
	struct mutex devnum_next_mutex;
	struct usb_devmap devmap;
	struct usb_device___10 *root_hub;
	struct usb_bus___10 *hs_companion;
	int bandwidth_allocated;
	int bandwidth_int_reqs;
	int bandwidth_isoc_reqs;
	unsigned int resuming_ports;
	struct mon_bus___3 *mon_bus;
	int monitored;
};

struct usb_device___10 {
	int devnum;
	char devpath[16];
	u32 route;
	enum usb_device_state state;
	enum usb_device_speed speed;
	unsigned int rx_lanes;
	unsigned int tx_lanes;
	struct usb_tt___3 *tt;
	int ttport;
	unsigned int toggle[2];
	struct usb_device___10 *parent;
	struct usb_bus___10 *bus;
	struct usb_host_endpoint ep0;
	struct device___349 dev;
	struct usb_device_descriptor descriptor;
	struct usb_host_bos *bos;
	struct usb_host_config___9 *config;
	struct usb_host_config___9 *actconfig;
	struct usb_host_endpoint *ep_in[16];
	struct usb_host_endpoint *ep_out[16];
	char **rawdescriptors;
	short unsigned int bus_mA;
	u8 portnum;
	u8 level;
	unsigned int can_submit: 1;
	unsigned int persist_enabled: 1;
	unsigned int have_langid: 1;
	unsigned int authorized: 1;
	unsigned int authenticated: 1;
	unsigned int wusb: 1;
	unsigned int lpm_capable: 1;
	unsigned int usb2_hw_lpm_capable: 1;
	unsigned int usb2_hw_lpm_besl_capable: 1;
	unsigned int usb2_hw_lpm_enabled: 1;
	unsigned int usb2_hw_lpm_allowed: 1;
	unsigned int usb3_lpm_u1_enabled: 1;
	unsigned int usb3_lpm_u2_enabled: 1;
	int string_langid;
	char *product;
	char *manufacturer;
	char *serial;
	struct list_head filelist;
	int maxchild;
	u32 quirks;
	atomic_t urbnum;
	long unsigned int active_duration;
	long unsigned int connect_time;
	unsigned int do_remote_wakeup: 1;
	unsigned int reset_resume: 1;
	unsigned int port_is_suspended: 1;
	struct wusb_dev *wusb_dev;
	int slot_id;
	enum usb_device_removable removable;
	struct usb2_lpm_parameters l1_params;
	struct usb3_lpm_parameters u1_params;
	struct usb3_lpm_parameters u2_params;
	unsigned int lpm_disable_count;
	u16 hub_delay;
};

struct mon_bus___3 {
	struct list_head bus_link;
	spinlock_t lock;
	struct usb_bus___10 *u_bus;
	int text_inited;
	int bin_inited;
	struct dentry___381 *dent_s;
	struct dentry___381 *dent_t;
	struct dentry___381 *dent_u;
	struct device___349 *classdev;
	int nreaders;
	struct list_head r_list;
	struct kref ref;
	unsigned int cnt_events;
	unsigned int cnt_text_lost;
};

struct urb___9;

typedef void (*usb_complete_t___9)(struct urb___9 *);

struct urb___9 {
	struct kref kref;
	void *hcpriv;
	atomic_t use_count;
	atomic_t reject;
	int unlinked;
	struct list_head urb_list;
	struct list_head anchor_list;
	struct usb_anchor *anchor;
	struct usb_device___10 *dev;
	struct usb_host_endpoint *ep;
	unsigned int pipe;
	unsigned int stream_id;
	int status;
	unsigned int transfer_flags;
	void *transfer_buffer;
	dma_addr_t transfer_dma;
	struct scatterlist *sg;
	int num_mapped_sgs;
	int num_sgs;
	u32 transfer_buffer_length;
	u32 actual_length;
	unsigned char *setup_packet;
	dma_addr_t setup_dma;
	int start_frame;
	int number_of_packets;
	int interval;
	int error_count;
	void *context;
	usb_complete_t___9 complete;
	struct usb_iso_packet_descriptor iso_frame_desc[0];
};

typedef int (*key_restrict_link_func_t___352)(struct key___351 *, const struct key_type *, const union key_payload *, struct key___351 *);

struct key_restriction___351;

struct key___351 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___383 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___351 *restrict_link;
};

struct key_restriction___351 {
	key_restrict_link_func_t___352 check;
	struct key___351 *key;
	struct key_type *keytype;
};

struct seq_operations___323 {
	void * (*start)(struct seq_file___324 *, loff_t *);
	void (*stop)(struct seq_file___324 *, void *);
	void * (*next)(struct seq_file___324 *, void *, loff_t *);
	int (*show)(struct seq_file___324 *, void *);
};

typedef void compound_page_dtor___370(struct page___383 *);

struct fwnode_reference_args___271;

struct fwnode_endpoint___271;

struct fwnode_operations___271 {
	struct fwnode_handle___271 * (*get)(struct fwnode_handle___271 *);
	void (*put)(struct fwnode_handle___271 *);
	bool (*device_is_available)(const struct fwnode_handle___271 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___271 *, const struct device___349 *);
	bool (*property_present)(const struct fwnode_handle___271 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___271 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___271 *, const char *, const char **, size_t);
	struct fwnode_handle___271 * (*get_parent)(const struct fwnode_handle___271 *);
	struct fwnode_handle___271 * (*get_next_child_node)(const struct fwnode_handle___271 *, struct fwnode_handle___271 *);
	struct fwnode_handle___271 * (*get_named_child_node)(const struct fwnode_handle___271 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___271 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___271 *);
	struct fwnode_handle___271 * (*graph_get_next_endpoint)(const struct fwnode_handle___271 *, struct fwnode_handle___271 *);
	struct fwnode_handle___271 * (*graph_get_remote_endpoint)(const struct fwnode_handle___271 *);
	struct fwnode_handle___271 * (*graph_get_port_parent)(struct fwnode_handle___271 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___271 *, struct fwnode_endpoint___271 *);
};

struct fwnode_endpoint___271 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___271 *local_fwnode;
};

struct fwnode_reference_args___271 {
	struct fwnode_handle___271 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct mon_reader___2 {
	struct list_head r_link;
	struct mon_bus___3 *m_bus;
	void *r_data;
	void (*rnf_submit)(void *, struct urb___9 *);
	void (*rnf_error)(void *, struct urb___9 *, int);
	void (*rnf_complete)(void *, struct urb___9 *, int);
};

struct mon_iso_desc {
	int status;
	unsigned int offset;
	unsigned int length;
};

struct mon_event_text {
	struct list_head e_link;
	int type;
	long unsigned int id;
	unsigned int tstamp;
	int busnum;
	char devnum;
	char epnum;
	char is_in;
	char xfertype;
	int length;
	int status;
	int interval;
	int start_frame;
	int error_count;
	char setup_flag;
	char data_flag;
	int numdesc;
	struct mon_iso_desc isodesc[5];
	unsigned char setup[8];
	unsigned char data[32];
};

struct mon_reader_text {
	struct kmem_cache *e_slab;
	int nevents;
	struct list_head e_list;
	struct mon_reader___2 r;
	wait_queue_head_t wait;
	int printf_size;
	size_t printf_offset;
	size_t printf_togo;
	char *printf_buf;
	struct mutex printf_lock;
	char slab_name[30];
};

struct mon_text_ptr {
	int cnt;
	int limit;
	char *pbuf;
};

enum {
	NAMESZ = 10,
};

struct usb_interface___10 {
	struct usb_host_interface *altsetting;
	struct usb_host_interface *cur_altsetting;
	unsigned int num_altsetting;
	struct usb_interface_assoc_descriptor *intf_assoc;
	int minor;
	enum usb_interface_condition condition;
	unsigned int sysfs_files_created: 1;
	unsigned int ep_devs_created: 1;
	unsigned int unregistering: 1;
	unsigned int needs_remote_wakeup: 1;
	unsigned int needs_altsetting0: 1;
	unsigned int needs_binding: 1;
	unsigned int resetting_device: 1;
	unsigned int authorized: 1;
	struct device___27 dev;
	struct device___27 *usb_dev;
	atomic_t pm_usage_cnt;
	struct work_struct reset_ws;
};

struct usb_host_config___10 {
	struct usb_config_descriptor desc;
	char *string;
	struct usb_interface_assoc_descriptor *intf_assoc[16];
	struct usb_interface___10 *interface[32];
	struct usb_interface_cache *intf_cache[32];
	unsigned char *extra;
	int extralen;
};

struct usb_device___11;

struct mon_bus___4;

struct usb_bus___11 {
	struct device___27 *controller;
	struct device___27 *sysdev;
	int busnum;
	const char *bus_name;
	u8 uses_dma;
	u8 uses_pio_for_control;
	u8 otg_port;
	unsigned int is_b_host: 1;
	unsigned int b_hnp_enable: 1;
	unsigned int no_stop_on_short: 1;
	unsigned int no_sg_constraint: 1;
	unsigned int sg_tablesize;
	int devnum_next;
	struct mutex devnum_next_mutex;
	struct usb_devmap devmap;
	struct usb_device___11 *root_hub;
	struct usb_bus___11 *hs_companion;
	int bandwidth_allocated;
	int bandwidth_int_reqs;
	int bandwidth_isoc_reqs;
	unsigned int resuming_ports;
	struct mon_bus___4 *mon_bus;
	int monitored;
};

struct usb_device___11 {
	int devnum;
	char devpath[16];
	u32 route;
	enum usb_device_state state;
	enum usb_device_speed speed;
	unsigned int rx_lanes;
	unsigned int tx_lanes;
	struct usb_tt___3 *tt;
	int ttport;
	unsigned int toggle[2];
	struct usb_device___11 *parent;
	struct usb_bus___11 *bus;
	struct usb_host_endpoint ep0;
	struct device___27 dev;
	struct usb_device_descriptor descriptor;
	struct usb_host_bos *bos;
	struct usb_host_config___10 *config;
	struct usb_host_config___10 *actconfig;
	struct usb_host_endpoint *ep_in[16];
	struct usb_host_endpoint *ep_out[16];
	char **rawdescriptors;
	short unsigned int bus_mA;
	u8 portnum;
	u8 level;
	unsigned int can_submit: 1;
	unsigned int persist_enabled: 1;
	unsigned int have_langid: 1;
	unsigned int authorized: 1;
	unsigned int authenticated: 1;
	unsigned int wusb: 1;
	unsigned int lpm_capable: 1;
	unsigned int usb2_hw_lpm_capable: 1;
	unsigned int usb2_hw_lpm_besl_capable: 1;
	unsigned int usb2_hw_lpm_enabled: 1;
	unsigned int usb2_hw_lpm_allowed: 1;
	unsigned int usb3_lpm_u1_enabled: 1;
	unsigned int usb3_lpm_u2_enabled: 1;
	int string_langid;
	char *product;
	char *manufacturer;
	char *serial;
	struct list_head filelist;
	int maxchild;
	u32 quirks;
	atomic_t urbnum;
	long unsigned int active_duration;
	long unsigned int connect_time;
	unsigned int do_remote_wakeup: 1;
	unsigned int reset_resume: 1;
	unsigned int port_is_suspended: 1;
	struct wusb_dev *wusb_dev;
	int slot_id;
	enum usb_device_removable removable;
	struct usb2_lpm_parameters l1_params;
	struct usb3_lpm_parameters u1_params;
	struct usb3_lpm_parameters u2_params;
	unsigned int lpm_disable_count;
	u16 hub_delay;
};

struct mon_bus___4 {
	struct list_head bus_link;
	spinlock_t lock;
	struct usb_bus___11 *u_bus;
	int text_inited;
	int bin_inited;
	struct dentry___33 *dent_s;
	struct dentry___33 *dent_t;
	struct dentry___33 *dent_u;
	struct device___27 *classdev;
	int nreaders;
	struct list_head r_list;
	struct kref ref;
	unsigned int cnt_events;
	unsigned int cnt_text_lost;
};

struct urb___10;

typedef void (*usb_complete_t___10)(struct urb___10 *);

struct urb___10 {
	struct kref kref;
	void *hcpriv;
	atomic_t use_count;
	atomic_t reject;
	int unlinked;
	struct list_head urb_list;
	struct list_head anchor_list;
	struct usb_anchor *anchor;
	struct usb_device___11 *dev;
	struct usb_host_endpoint *ep;
	unsigned int pipe;
	unsigned int stream_id;
	int status;
	unsigned int transfer_flags;
	void *transfer_buffer;
	dma_addr_t transfer_dma;
	struct scatterlist *sg;
	int num_mapped_sgs;
	int num_sgs;
	u32 transfer_buffer_length;
	u32 actual_length;
	unsigned char *setup_packet;
	dma_addr_t setup_dma;
	int start_frame;
	int number_of_packets;
	int interval;
	int error_count;
	void *context;
	usb_complete_t___10 complete;
	struct usb_iso_packet_descriptor iso_frame_desc[0];
};

typedef struct poll_table_struct___18 poll_table___33;

struct mon_reader___3 {
	struct list_head r_link;
	struct mon_bus___4 *m_bus;
	void *r_data;
	void (*rnf_submit)(void *, struct urb___10 *);
	void (*rnf_error)(void *, struct urb___10 *, int);
	void (*rnf_complete)(void *, struct urb___10 *, int);
};

struct iso_rec {
	int error_count;
	int numdesc;
};

struct mon_bin_hdr {
	u64 id;
	unsigned char type;
	unsigned char xfer_type;
	unsigned char epnum;
	unsigned char devnum;
	short unsigned int busnum;
	char flag_setup;
	char flag_data;
	s64 ts_sec;
	s32 ts_usec;
	int status;
	unsigned int len_urb;
	unsigned int len_cap;
	union {
		unsigned char setup[8];
		struct iso_rec iso;
	} s;
	int interval;
	int start_frame;
	unsigned int xfer_flags;
	unsigned int ndesc;
};

struct mon_bin_isodesc {
	int iso_status;
	unsigned int iso_off;
	unsigned int iso_len;
	u32 _pad;
};

struct mon_bin_stats {
	u32 queued;
	u32 dropped;
};

struct mon_bin_get {
	struct mon_bin_hdr *hdr;
	void *data;
	size_t alloc;
};

struct mon_bin_mfetch {
	u32 *offvec;
	u32 nfetch;
	u32 nflush;
};

struct mon_pgmap {
	struct page___32 *pg;
	unsigned char *ptr;
};

struct mon_reader_bin {
	spinlock_t b_lock;
	unsigned int b_size;
	unsigned int b_cnt;
	unsigned int b_in;
	unsigned int b_out;
	unsigned int b_read;
	struct mon_pgmap *b_vec;
	wait_queue_head_t b_wait;
	struct mutex fetch_lock;
	int mmap_active;
	struct mon_reader___3 r;
	unsigned int cnt_lost;
};

enum amd_chipset_gen {
	NOT_AMD_CHIPSET = 0,
	AMD_CHIPSET_SB600 = 1,
	AMD_CHIPSET_SB700 = 2,
	AMD_CHIPSET_SB800 = 3,
	AMD_CHIPSET_HUDSON2 = 4,
	AMD_CHIPSET_BOLTON = 5,
	AMD_CHIPSET_YANGTZE = 6,
	AMD_CHIPSET_TAISHAN = 7,
	AMD_CHIPSET_UNKNOWN = 8,
};

struct amd_chipset_type {
	enum amd_chipset_gen gen;
	u8 rev;
};

struct amd_chipset_info {
	struct pci_dev___32 *nb_dev;
	struct pci_dev___32 *smbus_dev;
	int nb_type;
	struct amd_chipset_type sb_type;
	int isoc_reqs;
	int probe_count;
	int probe_result;
};

struct ehci_stats {
	long unsigned int normal;
	long unsigned int error;
	long unsigned int iaa;
	long unsigned int lost_iaa;
	long unsigned int complete;
	long unsigned int unlink;
};

struct ehci_per_sched {
	struct usb_device___3 *udev;
	struct usb_host_endpoint *ep;
	struct list_head ps_list;
	u16 tt_usecs;
	u16 cs_mask;
	u16 period;
	u16 phase;
	u8 bw_phase;
	u8 phase_uf;
	u8 usecs;
	u8 c_usecs;
	u8 bw_uperiod;
	u8 bw_period;
};

enum ehci_rh_state {
	EHCI_RH_HALTED = 0,
	EHCI_RH_SUSPENDED = 1,
	EHCI_RH_RUNNING = 2,
	EHCI_RH_STOPPING = 3,
};

enum ehci_hrtimer_event {
	EHCI_HRTIMER_POLL_ASS = 0,
	EHCI_HRTIMER_POLL_PSS = 1,
	EHCI_HRTIMER_POLL_DEAD = 2,
	EHCI_HRTIMER_UNLINK_INTR = 3,
	EHCI_HRTIMER_FREE_ITDS = 4,
	EHCI_HRTIMER_ACTIVE_UNLINK = 5,
	EHCI_HRTIMER_START_UNLINK_INTR = 6,
	EHCI_HRTIMER_ASYNC_UNLINKS = 7,
	EHCI_HRTIMER_IAA_WATCHDOG = 8,
	EHCI_HRTIMER_DISABLE_PERIODIC = 9,
	EHCI_HRTIMER_DISABLE_ASYNC = 10,
	EHCI_HRTIMER_IO_WATCHDOG = 11,
	EHCI_HRTIMER_NUM_EVENTS = 12,
};

struct ehci_caps;

struct ehci_regs;

struct ehci_dbg_port;

struct ehci_qh;

union ehci_shadow;

struct ehci_itd;

struct ehci_sitd;

struct ehci_hcd {
	enum ehci_hrtimer_event next_hrtimer_event;
	unsigned int enabled_hrtimer_events;
	ktime_t hr_timeouts[12];
	struct hrtimer hrtimer;
	int PSS_poll_count;
	int ASS_poll_count;
	int died_poll_count;
	struct ehci_caps *caps;
	struct ehci_regs *regs;
	struct ehci_dbg_port *debug;
	__u32 hcs_params;
	spinlock_t lock;
	enum ehci_rh_state rh_state;
	bool scanning: 1;
	bool need_rescan: 1;
	bool intr_unlinking: 1;
	bool iaa_in_progress: 1;
	bool async_unlinking: 1;
	bool shutdown: 1;
	struct ehci_qh *qh_scan_next;
	struct ehci_qh *async;
	struct ehci_qh *dummy;
	struct list_head async_unlink;
	struct list_head async_idle;
	unsigned int async_unlink_cycle;
	unsigned int async_count;
	__le32 old_current;
	__le32 old_token;
	unsigned int periodic_size;
	__le32 *periodic;
	dma_addr_t periodic_dma;
	struct list_head intr_qh_list;
	unsigned int i_thresh;
	union ehci_shadow *pshadow;
	struct list_head intr_unlink_wait;
	struct list_head intr_unlink;
	unsigned int intr_unlink_wait_cycle;
	unsigned int intr_unlink_cycle;
	unsigned int now_frame;
	unsigned int last_iso_frame;
	unsigned int intr_count;
	unsigned int isoc_count;
	unsigned int periodic_count;
	unsigned int uframe_periodic_max;
	struct list_head cached_itd_list;
	struct ehci_itd *last_itd_to_free;
	struct list_head cached_sitd_list;
	struct ehci_sitd *last_sitd_to_free;
	long unsigned int reset_done[15];
	long unsigned int bus_suspended;
	long unsigned int companion_ports;
	long unsigned int owned_ports;
	long unsigned int port_c_suspend;
	long unsigned int suspended_ports;
	long unsigned int resuming_ports;
	struct dma_pool___2 *qh_pool;
	struct dma_pool___2 *qtd_pool;
	struct dma_pool___2 *itd_pool;
	struct dma_pool___2 *sitd_pool;
	unsigned int random_frame;
	long unsigned int next_statechange;
	ktime_t last_periodic_enable;
	u32 command;
	unsigned int no_selective_suspend: 1;
	unsigned int has_fsl_port_bug: 1;
	unsigned int has_fsl_hs_errata: 1;
	unsigned int has_fsl_susp_errata: 1;
	unsigned int big_endian_mmio: 1;
	unsigned int big_endian_desc: 1;
	unsigned int big_endian_capbase: 1;
	unsigned int has_amcc_usb23: 1;
	unsigned int need_io_watchdog: 1;
	unsigned int amd_pll_fix: 1;
	unsigned int use_dummy_qh: 1;
	unsigned int has_synopsys_hc_bug: 1;
	unsigned int frame_index_bug: 1;
	unsigned int need_oc_pp_cycle: 1;
	unsigned int imx28_write_fix: 1;
	__le32 *ohci_hcctrl_reg;
	unsigned int has_hostpc: 1;
	unsigned int has_tdi_phy_lpm: 1;
	unsigned int has_ppcd: 1;
	u8 sbrn;
	struct ehci_stats stats;
	struct dentry___368 *debug_dir;
	u8 bandwidth[64];
	u8 tt_budget[64];
	struct list_head tt_list;
	long unsigned int priv[0];
};

struct ehci_caps {
	u32 hc_capbase;
	u32 hcs_params;
	u32 hcc_params;
	u8 portroute[8];
};

struct ehci_regs {
	u32 command;
	u32 status;
	u32 intr_enable;
	u32 frame_index;
	u32 segment;
	u32 frame_list;
	u32 async_next;
	u32 reserved1[2];
	u32 txfill_tuning;
	u32 reserved2[6];
	u32 configured_flag;
	u32 port_status[0];
	u32 reserved3[9];
	u32 usbmode;
	u32 reserved4[6];
	u32 hostpc[0];
	u32 reserved5[17];
	u32 usbmode_ex;
};

struct ehci_dbg_port {
	u32 control;
	u32 pids;
	u32 data03;
	u32 data47;
	u32 address;
};

struct ehci_fstn;

union ehci_shadow {
	struct ehci_qh *qh;
	struct ehci_itd *itd;
	struct ehci_sitd *sitd;
	struct ehci_fstn *fstn;
	__le32 *hw_next;
	void *ptr;
};

struct ehci_qh_hw;

struct ehci_qtd;

struct ehci_qh {
	struct ehci_qh_hw *hw;
	dma_addr_t qh_dma;
	union ehci_shadow qh_next;
	struct list_head qtd_list;
	struct list_head intr_node;
	struct ehci_qtd *dummy;
	struct list_head unlink_node;
	struct ehci_per_sched ps;
	unsigned int unlink_cycle;
	u8 qh_state;
	u8 xacterrs;
	u8 unlink_reason;
	u8 gap_uf;
	unsigned int is_out: 1;
	unsigned int clearing_tt: 1;
	unsigned int dequeue_during_giveback: 1;
	unsigned int should_be_inactive: 1;
};

struct ehci_iso_stream;

struct ehci_itd {
	__le32 hw_next;
	__le32 hw_transaction[8];
	__le32 hw_bufp[7];
	__le32 hw_bufp_hi[7];
	dma_addr_t itd_dma;
	union ehci_shadow itd_next;
	struct urb___3 *urb;
	struct ehci_iso_stream *stream;
	struct list_head itd_list;
	unsigned int frame;
	unsigned int pg;
	unsigned int index[8];
	long: 64;
};

struct ehci_sitd {
	__le32 hw_next;
	__le32 hw_fullspeed_ep;
	__le32 hw_uframe;
	__le32 hw_results;
	__le32 hw_buf[2];
	__le32 hw_backpointer;
	__le32 hw_buf_hi[2];
	dma_addr_t sitd_dma;
	union ehci_shadow sitd_next;
	struct urb___3 *urb;
	struct ehci_iso_stream *stream;
	struct list_head sitd_list;
	unsigned int frame;
	unsigned int index;
};

struct consw___23 {
	struct module___300 *owner;
	const char * (*con_startup)();
	void (*con_init)(struct vc_data *, int);
	void (*con_deinit)(struct vc_data *);
	void (*con_clear)(struct vc_data *, int, int, int, int);
	void (*con_putc)(struct vc_data *, int, int, int);
	void (*con_putcs)(struct vc_data *, const short unsigned int *, int, int, int);
	void (*con_cursor)(struct vc_data *, int);
	bool (*con_scroll)(struct vc_data *, unsigned int, unsigned int, enum con_scroll, unsigned int);
	int (*con_switch)(struct vc_data *);
	int (*con_blank)(struct vc_data *, int, int);
	int (*con_font_set)(struct vc_data *, struct console_font *, unsigned int);
	int (*con_font_get)(struct vc_data *, struct console_font *);
	int (*con_font_default)(struct vc_data *, struct console_font *, char *);
	int (*con_font_copy)(struct vc_data *, int);
	int (*con_resize)(struct vc_data *, unsigned int, unsigned int, unsigned int);
	void (*con_set_palette)(struct vc_data *, const unsigned char *);
	void (*con_scrolldelta)(struct vc_data *, int);
	int (*con_set_origin)(struct vc_data *);
	void (*con_save_screen)(struct vc_data *);
	u8 (*con_build_attr)(struct vc_data *, u8, u8, u8, u8, u8, u8);
	void (*con_invert_region)(struct vc_data *, u16 *, int);
	u16 * (*con_screen_pos)(struct vc_data *, int);
	long unsigned int (*con_getxy)(struct vc_data *, long unsigned int, int *, int *);
	void (*con_flush_scrollback)(struct vc_data *);
	int (*con_debug_enter)(struct vc_data *);
	int (*con_debug_leave)(struct vc_data *);
};

struct ehci_qtd {
	__le32 hw_next;
	__le32 hw_alt_next;
	__le32 hw_token;
	__le32 hw_buf[5];
	__le32 hw_buf_hi[5];
	dma_addr_t qtd_dma;
	struct list_head qtd_list;
	struct urb___3 *urb;
	size_t length;
};

struct ehci_fstn {
	__le32 hw_next;
	__le32 hw_prev;
	dma_addr_t fstn_dma;
	union ehci_shadow fstn_next;
	long: 64;
};

struct ehci_qh_hw {
	__le32 hw_next;
	__le32 hw_info1;
	__le32 hw_info2;
	__le32 hw_current;
	__le32 hw_qtd_next;
	__le32 hw_alt_next;
	__le32 hw_token;
	__le32 hw_buf[5];
	__le32 hw_buf_hi[5];
	long: 32;
	long: 64;
	long: 64;
	long: 64;
};

struct ehci_iso_packet {
	u64 bufp;
	__le32 transaction;
	u8 cross;
	u32 buf1;
};

struct ehci_iso_sched {
	struct list_head td_list;
	unsigned int span;
	unsigned int first_packet;
	struct ehci_iso_packet packet[0];
};

struct ehci_iso_stream {
	struct ehci_qh_hw *hw;
	u8 bEndpointAddress;
	u8 highspeed;
	struct list_head td_list;
	struct list_head free_list;
	struct ehci_per_sched ps;
	unsigned int next_uframe;
	__le32 splits;
	u16 uperiod;
	u16 maxp;
	unsigned int bandwidth;
	__le32 buf0;
	__le32 buf1;
	__le32 buf2;
	__le32 address;
};

struct ehci_tt {
	u16 bandwidth[8];
	struct list_head tt_list;
	struct list_head ps_list;
	struct usb_tt___3 *usb_tt;
	int tt_port;
};

struct ehci_driver_overrides {
	size_t extra_priv_size;
	int (*reset)(struct usb_hcd___3 *);
	int (*port_power)(struct usb_hcd___3 *, int, bool);
};

struct debug_buffer {
	ssize_t (*fill_func)(struct debug_buffer *);
	struct usb_bus___3 *bus;
	struct mutex mutex;
	size_t count;
	char *output_buf;
	size_t alloc_size;
};

typedef __u32 __hc32;

typedef __u16 __hc16;

struct td;

struct ed {
	__hc32 hwINFO;
	__hc32 hwTailP;
	__hc32 hwHeadP;
	__hc32 hwNextED;
	dma_addr_t dma;
	struct td *dummy;
	struct ed *ed_next;
	struct ed *ed_prev;
	struct list_head td_list;
	struct list_head in_use_list;
	u8 state;
	u8 type;
	u8 branch;
	u16 interval;
	u16 load;
	u16 last_iso;
	u16 tick;
	unsigned int takeback_wdh_cnt;
	struct td *pending_td;
	long: 64;
};

struct td {
	__hc32 hwINFO;
	__hc32 hwCBP;
	__hc32 hwNextTD;
	__hc32 hwBE;
	__hc16 hwPSW[2];
	__u8 index;
	struct ed *ed;
	struct td *td_hash;
	struct td *next_dl_td;
	struct urb___3 *urb;
	dma_addr_t td_dma;
	dma_addr_t data_dma;
	struct list_head td_list;
	long: 64;
};

struct ohci_hcca {
	__hc32 int_table[32];
	__hc32 frame_no;
	__hc32 done_head;
	u8 reserved_for_hc[116];
	u8 what[4];
};

struct ohci_roothub_regs {
	__hc32 a;
	__hc32 b;
	__hc32 status;
	__hc32 portstatus[15];
};

struct ohci_regs {
	__hc32 revision;
	__hc32 control;
	__hc32 cmdstatus;
	__hc32 intrstatus;
	__hc32 intrenable;
	__hc32 intrdisable;
	__hc32 hcca;
	__hc32 ed_periodcurrent;
	__hc32 ed_controlhead;
	__hc32 ed_controlcurrent;
	__hc32 ed_bulkhead;
	__hc32 ed_bulkcurrent;
	__hc32 donehead;
	__hc32 fminterval;
	__hc32 fmremaining;
	__hc32 fmnumber;
	__hc32 periodicstart;
	__hc32 lsthresh;
	struct ohci_roothub_regs roothub;
	long: 64;
	long: 64;
};

struct urb_priv {
	struct ed *ed;
	u16 length;
	u16 td_cnt;
	struct list_head pending;
	struct td *td[0];
};

typedef struct urb_priv urb_priv_t;

enum ohci_rh_state {
	OHCI_RH_HALTED = 0,
	OHCI_RH_SUSPENDED = 1,
	OHCI_RH_RUNNING = 2,
};

struct ohci_hcd {
	spinlock_t lock;
	struct ohci_regs *regs;
	struct ohci_hcca *hcca;
	dma_addr_t hcca_dma;
	struct ed *ed_rm_list;
	struct ed *ed_bulktail;
	struct ed *ed_controltail;
	struct ed *periodic[32];
	void (*start_hnp)(struct ohci_hcd *);
	struct dma_pool___2 *td_cache;
	struct dma_pool___2 *ed_cache;
	struct td *td_hash[64];
	struct td *dl_start;
	struct td *dl_end;
	struct list_head pending;
	struct list_head eds_in_use;
	enum ohci_rh_state rh_state;
	int num_ports;
	int load[32];
	u32 hc_control;
	long unsigned int next_statechange;
	u32 fminterval;
	unsigned int autostop: 1;
	unsigned int working: 1;
	unsigned int restart_work: 1;
	long unsigned int flags;
	unsigned int prev_frame_no;
	unsigned int wdh_cnt;
	unsigned int prev_wdh_cnt;
	u32 prev_donehead;
	struct timer_list io_watchdog;
	struct work_struct nec_work;
	struct dentry___368 *debug_dir;
	long unsigned int priv[0];
};

struct ohci_driver_overrides {
	const char *product_desc;
	size_t extra_priv_size;
	int (*reset)(struct usb_hcd___3 *);
};

struct debug_buffer___2 {
	ssize_t (*fill_func)(struct debug_buffer___2 *);
	struct ohci_hcd *ohci;
	struct mutex mutex;
	size_t count;
	char *page;
};

struct irq_chip___30;

struct irq_data___30 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___11 *common;
	struct irq_chip___30 *chip;
	struct irq_domain *domain;
	struct irq_data___30 *parent_data;
	void *chip_data;
};

struct irq_chip___30 {
	struct device___336 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___30 *);
	void (*irq_shutdown)(struct irq_data___30 *);
	void (*irq_enable)(struct irq_data___30 *);
	void (*irq_disable)(struct irq_data___30 *);
	void (*irq_ack)(struct irq_data___30 *);
	void (*irq_mask)(struct irq_data___30 *);
	void (*irq_mask_ack)(struct irq_data___30 *);
	void (*irq_unmask)(struct irq_data___30 *);
	void (*irq_eoi)(struct irq_data___30 *);
	int (*irq_set_affinity)(struct irq_data___30 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___30 *);
	int (*irq_set_type)(struct irq_data___30 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___30 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___30 *);
	void (*irq_bus_sync_unlock)(struct irq_data___30 *);
	void (*irq_cpu_online)(struct irq_data___30 *);
	void (*irq_cpu_offline)(struct irq_data___30 *);
	void (*irq_suspend)(struct irq_data___30 *);
	void (*irq_resume)(struct irq_data___30 *);
	void (*irq_pm_shutdown)(struct irq_data___30 *);
	void (*irq_calc_mask)(struct irq_data___30 *);
	void (*irq_print_chip)(struct irq_data___30 *, struct seq_file___313 *);
	int (*irq_request_resources)(struct irq_data___30 *);
	void (*irq_release_resources)(struct irq_data___30 *);
	void (*irq_compose_msi_msg)(struct irq_data___30 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___30 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___30 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___30 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___30 *, void *);
	void (*ipi_send_single)(struct irq_data___30 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___30 *, const struct cpumask *);
	long unsigned int flags;
};

struct pci_bus___35;

struct pci_slot___35 {
	struct pci_bus___35 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject___62 kobj;
};

struct pci_dev___35;

struct pci_ops___35;

struct pci_bus___35 {
	struct list_head node;
	struct pci_bus___35 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___35 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___35 *ops;
	struct msi_controller___2 *msi;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	int domain_nr;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___59 *bridge;
	struct device___59 dev;
	struct bin_attribute___59 *legacy_io;
	struct bin_attribute___59 *legacy_mem;
	unsigned int is_added: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
};

struct pci_driver___35;

struct pci_dev___35 {
	struct list_head bus_list;
	struct pci_bus___35 *bus;
	struct pci_bus___35 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___35 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u16 aer_cap;
	struct aer_stats *aer_stats;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	long unsigned int *dma_alias_mask;
	struct pci_driver___35 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	unsigned int imm_ready: 1;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int bridge_d3: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int hotplug_user_indicators: 1;
	unsigned int clear_retrain_link: 1;
	unsigned int d3_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	unsigned int ltr_path: 1;
	unsigned int eetlp_prefix_path: 1;
	pci_channel_state_t error_state;
	struct device___59 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int multifunction: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int ats_enabled: 1;
	unsigned int pasid_enabled: 1;
	unsigned int pri_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int reset_fn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int shpc_managed: 1;
	unsigned int is_thunderbolt: 1;
	unsigned int __aer_firmware_first_valid: 1;
	unsigned int __aer_firmware_first: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int irq_managed: 1;
	unsigned int has_secondary_link: 1;
	unsigned int non_compliant_bars: 1;
	unsigned int is_probed: 1;
	unsigned int link_active_reporting: 1;
	unsigned int untrusted: 1;
	unsigned int no_vf_scan: 1;
	unsigned int io_window: 1;
	unsigned int pref_window: 1;
	unsigned int pref_64_window: 1;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	struct bin_attribute___59 *rom_attr;
	int rom_attr_enabled;
	struct bin_attribute___59 *res_attr[17];
	struct bin_attribute___59 *res_attr_wc[17];
	unsigned int broken_cmd_compl: 1;
	const struct attribute_group___59 **msi_irq_groups;
	struct pci_vpd *vpd;
	union {
		struct pci_sriov *sriov;
		struct pci_dev___35 *physfn;
	};
	u16 ats_cap;
	u8 ats_stu;
	atomic_t ats_ref_cnt;
	u32 pri_reqs_alloc;
	u16 pasid_features;
	struct pci_p2pdma *p2pdma;
	phys_addr_t rom;
	size_t romlen;
	char *driver_override;
	long unsigned int priv_flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t pci_dev_extended_size_rh;
	struct pci_dev_extended_rh pci_dev_extended_rh;
};

struct pci_error_handlers___35;

struct pci_driver___35 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___35 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___35 *);
	int (*suspend)(struct pci_dev___35 *, pm_message_t);
	int (*suspend_late)(struct pci_dev___35 *, pm_message_t);
	int (*resume_early)(struct pci_dev___35 *);
	int (*resume)(struct pci_dev___35 *);
	void (*shutdown)(struct pci_dev___35 *);
	int (*sriov_configure)(struct pci_dev___35 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	const struct pci_error_handlers___35 *err_handler;
	const struct attribute_group___59 **groups;
	struct device_driver___59 driver;
	struct pci_dynids dynids;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct pci_ops___35 {
	int (*add_bus)(struct pci_bus___35 *);
	void (*remove_bus)(struct pci_bus___35 *);
	void * (*map_bus)(struct pci_bus___35 *, unsigned int, int);
	int (*read)(struct pci_bus___35 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___35 *, unsigned int, int, int, u32);
};

struct pci_error_handlers___35 {
	pci_ers_result_t (*error_detected)(struct pci_dev___35 *, enum pci_channel_state);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___35 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___35 *);
	void (*reset_prepare)(struct pci_dev___35 *);
	void (*reset_done)(struct pci_dev___35 *);
	void (*resume)(struct pci_dev___35 *);
};

struct usb_interface___11 {
	struct usb_host_interface *altsetting;
	struct usb_host_interface *cur_altsetting;
	unsigned int num_altsetting;
	struct usb_interface_assoc_descriptor *intf_assoc;
	int minor;
	enum usb_interface_condition condition;
	unsigned int sysfs_files_created: 1;
	unsigned int ep_devs_created: 1;
	unsigned int unregistering: 1;
	unsigned int needs_remote_wakeup: 1;
	unsigned int needs_altsetting0: 1;
	unsigned int needs_binding: 1;
	unsigned int resetting_device: 1;
	unsigned int authorized: 1;
	struct device___59 dev;
	struct device___59 *usb_dev;
	atomic_t pm_usage_cnt;
	struct work_struct reset_ws;
};

struct usb_host_config___11 {
	struct usb_config_descriptor desc;
	char *string;
	struct usb_interface_assoc_descriptor *intf_assoc[16];
	struct usb_interface___11 *interface[32];
	struct usb_interface_cache *intf_cache[32];
	unsigned char *extra;
	int extralen;
};

struct usb_device___12;

struct usb_bus___12 {
	struct device___59 *controller;
	struct device___59 *sysdev;
	int busnum;
	const char *bus_name;
	u8 uses_dma;
	u8 uses_pio_for_control;
	u8 otg_port;
	unsigned int is_b_host: 1;
	unsigned int b_hnp_enable: 1;
	unsigned int no_stop_on_short: 1;
	unsigned int no_sg_constraint: 1;
	unsigned int sg_tablesize;
	int devnum_next;
	struct mutex devnum_next_mutex;
	struct usb_devmap devmap;
	struct usb_device___12 *root_hub;
	struct usb_bus___12 *hs_companion;
	int bandwidth_allocated;
	int bandwidth_int_reqs;
	int bandwidth_isoc_reqs;
	unsigned int resuming_ports;
	struct mon_bus *mon_bus;
	int monitored;
};

struct usb_tt___9;

struct usb_device___12 {
	int devnum;
	char devpath[16];
	u32 route;
	enum usb_device_state state;
	enum usb_device_speed speed;
	unsigned int rx_lanes;
	unsigned int tx_lanes;
	struct usb_tt___9 *tt;
	int ttport;
	unsigned int toggle[2];
	struct usb_device___12 *parent;
	struct usb_bus___12 *bus;
	struct usb_host_endpoint ep0;
	struct device___59 dev;
	struct usb_device_descriptor descriptor;
	struct usb_host_bos *bos;
	struct usb_host_config___11 *config;
	struct usb_host_config___11 *actconfig;
	struct usb_host_endpoint *ep_in[16];
	struct usb_host_endpoint *ep_out[16];
	char **rawdescriptors;
	short unsigned int bus_mA;
	u8 portnum;
	u8 level;
	unsigned int can_submit: 1;
	unsigned int persist_enabled: 1;
	unsigned int have_langid: 1;
	unsigned int authorized: 1;
	unsigned int authenticated: 1;
	unsigned int wusb: 1;
	unsigned int lpm_capable: 1;
	unsigned int usb2_hw_lpm_capable: 1;
	unsigned int usb2_hw_lpm_besl_capable: 1;
	unsigned int usb2_hw_lpm_enabled: 1;
	unsigned int usb2_hw_lpm_allowed: 1;
	unsigned int usb3_lpm_u1_enabled: 1;
	unsigned int usb3_lpm_u2_enabled: 1;
	int string_langid;
	char *product;
	char *manufacturer;
	char *serial;
	struct list_head filelist;
	int maxchild;
	u32 quirks;
	atomic_t urbnum;
	long unsigned int active_duration;
	long unsigned int connect_time;
	unsigned int do_remote_wakeup: 1;
	unsigned int reset_resume: 1;
	unsigned int port_is_suspended: 1;
	struct wusb_dev *wusb_dev;
	int slot_id;
	enum usb_device_removable removable;
	struct usb2_lpm_parameters l1_params;
	struct usb3_lpm_parameters u1_params;
	struct usb3_lpm_parameters u2_params;
	unsigned int lpm_disable_count;
	u16 hub_delay;
};

struct usb_tt___9 {
	struct usb_device___12 *hub;
	int multi;
	unsigned int think_time;
	void *hcpriv;
	spinlock_t lock;
	struct list_head clear_list;
	struct work_struct clear_work;
};

struct urb___11;

typedef void (*usb_complete_t___11)(struct urb___11 *);

struct urb___11 {
	struct kref kref;
	void *hcpriv;
	atomic_t use_count;
	atomic_t reject;
	int unlinked;
	struct list_head urb_list;
	struct list_head anchor_list;
	struct usb_anchor *anchor;
	struct usb_device___12 *dev;
	struct usb_host_endpoint *ep;
	unsigned int pipe;
	unsigned int stream_id;
	int status;
	unsigned int transfer_flags;
	void *transfer_buffer;
	dma_addr_t transfer_dma;
	struct scatterlist *sg;
	int num_mapped_sgs;
	int num_sgs;
	u32 transfer_buffer_length;
	u32 actual_length;
	unsigned char *setup_packet;
	dma_addr_t setup_dma;
	int start_frame;
	int number_of_packets;
	int interval;
	int error_count;
	void *context;
	usb_complete_t___11 complete;
	struct usb_iso_packet_descriptor iso_frame_desc[0];
};

struct hc_driver___8;

struct usb_hcd___8 {
	struct usb_bus___12 self;
	struct kref kref;
	const char *product_desc;
	int speed;
	char irq_descr[24];
	struct timer_list rh_timer;
	struct urb___11 *status_urb;
	struct work_struct wakeup_work;
	const struct hc_driver___8 *driver;
	struct usb_phy___3 *usb_phy;
	struct usb_phy_roothub *phy_roothub;
	long unsigned int flags;
	unsigned int rh_registered: 1;
	unsigned int rh_pollable: 1;
	unsigned int msix_enabled: 1;
	unsigned int msi_enabled: 1;
	unsigned int skip_phy_initialization: 1;
	unsigned int uses_new_polling: 1;
	unsigned int wireless: 1;
	unsigned int has_tt: 1;
	unsigned int amd_resume_bug: 1;
	unsigned int can_do_streams: 1;
	unsigned int tpl_support: 1;
	unsigned int cant_recv_wakeups: 1;
	unsigned int irq;
	void *regs;
	resource_size_t rsrc_start;
	resource_size_t rsrc_len;
	unsigned int power_budget;
	struct giveback_urb_bh high_prio_bh;
	struct giveback_urb_bh low_prio_bh;
	struct mutex *address0_mutex;
	struct mutex *bandwidth_mutex;
	struct usb_hcd___8 *shared_hcd;
	struct usb_hcd___8 *primary_hcd;
	struct dma_pool___2 *pool[4];
	int state;
	long unsigned int hcd_priv[0];
};

struct hc_driver___8 {
	const char *description;
	const char *product_desc;
	size_t hcd_priv_size;
	irqreturn_t (*irq)(struct usb_hcd___8 *);
	int flags;
	int (*reset)(struct usb_hcd___8 *);
	int (*start)(struct usb_hcd___8 *);
	int (*pci_suspend)(struct usb_hcd___8 *, bool);
	int (*pci_resume)(struct usb_hcd___8 *, bool);
	void (*stop)(struct usb_hcd___8 *);
	void (*shutdown)(struct usb_hcd___8 *);
	int (*get_frame_number)(struct usb_hcd___8 *);
	int (*urb_enqueue)(struct usb_hcd___8 *, struct urb___11 *, gfp_t);
	int (*urb_dequeue)(struct usb_hcd___8 *, struct urb___11 *, int);
	int (*map_urb_for_dma)(struct usb_hcd___8 *, struct urb___11 *, gfp_t);
	void (*unmap_urb_for_dma)(struct usb_hcd___8 *, struct urb___11 *);
	void (*endpoint_disable)(struct usb_hcd___8 *, struct usb_host_endpoint *);
	void (*endpoint_reset)(struct usb_hcd___8 *, struct usb_host_endpoint *);
	int (*hub_status_data)(struct usb_hcd___8 *, char *);
	int (*hub_control)(struct usb_hcd___8 *, u16, u16, u16, char *, u16);
	int (*bus_suspend)(struct usb_hcd___8 *);
	int (*bus_resume)(struct usb_hcd___8 *);
	int (*start_port_reset)(struct usb_hcd___8 *, unsigned int);
	long unsigned int (*get_resuming_ports)(struct usb_hcd___8 *);
	void (*relinquish_port)(struct usb_hcd___8 *, int);
	int (*port_handed_over)(struct usb_hcd___8 *, int);
	void (*clear_tt_buffer_complete)(struct usb_hcd___8 *, struct usb_host_endpoint *);
	int (*alloc_dev)(struct usb_hcd___8 *, struct usb_device___12 *);
	void (*free_dev)(struct usb_hcd___8 *, struct usb_device___12 *);
	int (*alloc_streams)(struct usb_hcd___8 *, struct usb_device___12 *, struct usb_host_endpoint **, unsigned int, unsigned int, gfp_t);
	int (*free_streams)(struct usb_hcd___8 *, struct usb_device___12 *, struct usb_host_endpoint **, unsigned int, gfp_t);
	int (*add_endpoint)(struct usb_hcd___8 *, struct usb_device___12 *, struct usb_host_endpoint *);
	int (*drop_endpoint)(struct usb_hcd___8 *, struct usb_device___12 *, struct usb_host_endpoint *);
	int (*check_bandwidth)(struct usb_hcd___8 *, struct usb_device___12 *);
	void (*reset_bandwidth)(struct usb_hcd___8 *, struct usb_device___12 *);
	int (*address_device)(struct usb_hcd___8 *, struct usb_device___12 *);
	int (*enable_device)(struct usb_hcd___8 *, struct usb_device___12 *);
	int (*update_hub_device)(struct usb_hcd___8 *, struct usb_device___12 *, struct usb_tt___9 *, gfp_t);
	int (*reset_device)(struct usb_hcd___8 *, struct usb_device___12 *);
	int (*update_device)(struct usb_hcd___8 *, struct usb_device___12 *);
	int (*set_usb2_hw_lpm)(struct usb_hcd___8 *, struct usb_device___12 *, int);
	int (*enable_usb3_lpm_timeout)(struct usb_hcd___8 *, struct usb_device___12 *, enum usb3_link_state);
	int (*disable_usb3_lpm_timeout)(struct usb_hcd___8 *, struct usb_device___12 *, enum usb3_link_state);
	int (*find_raw_port_number)(struct usb_hcd___8 *, int);
	int (*port_power)(struct usb_hcd___8 *, int, bool);
};

struct usb_mon_operations___9 {
	void (*urb_submit)(struct usb_bus___12 *, struct urb___11 *);
	void (*urb_submit_error)(struct usb_bus___12 *, struct urb___11 *, int);
	void (*urb_complete)(struct usb_bus___12 *, struct urb___11 *, int);
};

struct td___2;

struct ed___2 {
	__hc32 hwINFO;
	__hc32 hwTailP;
	__hc32 hwHeadP;
	__hc32 hwNextED;
	dma_addr_t dma;
	struct td___2 *dummy;
	struct ed___2 *ed_next;
	struct ed___2 *ed_prev;
	struct list_head td_list;
	struct list_head in_use_list;
	u8 state;
	u8 type;
	u8 branch;
	u16 interval;
	u16 load;
	u16 last_iso;
	u16 tick;
	unsigned int takeback_wdh_cnt;
	struct td___2 *pending_td;
	long: 64;
};

struct td___2 {
	__hc32 hwINFO;
	__hc32 hwCBP;
	__hc32 hwNextTD;
	__hc32 hwBE;
	__hc16 hwPSW[2];
	__u8 index;
	struct ed___2 *ed;
	struct td___2 *td_hash;
	struct td___2 *next_dl_td;
	struct urb___11 *urb;
	dma_addr_t td_dma;
	dma_addr_t data_dma;
	struct list_head td_list;
	long: 64;
};

struct ohci_hcd___2 {
	spinlock_t lock;
	struct ohci_regs *regs;
	struct ohci_hcca *hcca;
	dma_addr_t hcca_dma;
	struct ed___2 *ed_rm_list;
	struct ed___2 *ed_bulktail;
	struct ed___2 *ed_controltail;
	struct ed___2 *periodic[32];
	void (*start_hnp)(struct ohci_hcd___2 *);
	struct dma_pool___2 *td_cache;
	struct dma_pool___2 *ed_cache;
	struct td___2 *td_hash[64];
	struct td___2 *dl_start;
	struct td___2 *dl_end;
	struct list_head pending;
	struct list_head eds_in_use;
	enum ohci_rh_state rh_state;
	int num_ports;
	int load[32];
	u32 hc_control;
	long unsigned int next_statechange;
	u32 fminterval;
	unsigned int autostop: 1;
	unsigned int working: 1;
	unsigned int restart_work: 1;
	long unsigned int flags;
	unsigned int prev_frame_no;
	unsigned int wdh_cnt;
	unsigned int prev_wdh_cnt;
	u32 prev_donehead;
	struct timer_list io_watchdog;
	struct work_struct nec_work;
	struct dentry___65 *debug_dir;
	long unsigned int priv[0];
};

struct ohci_driver_overrides___2 {
	const char *product_desc;
	size_t extra_priv_size;
	int (*reset)(struct usb_hcd___8 *);
};

struct uhci_td;

struct uhci_qh {
	__le32 link;
	__le32 element;
	dma_addr_t dma_handle;
	struct list_head node;
	struct usb_host_endpoint *hep;
	struct usb_device___3 *udev;
	struct list_head queue;
	struct uhci_td *dummy_td;
	struct uhci_td *post_td;
	struct usb_iso_packet_descriptor *iso_packet_desc;
	long unsigned int advance_jiffies;
	unsigned int unlink_frame;
	unsigned int period;
	short int phase;
	short int load;
	unsigned int iso_frame;
	int state;
	int type;
	int skel;
	unsigned int initial_toggle: 1;
	unsigned int needs_fixup: 1;
	unsigned int is_stopped: 1;
	unsigned int wait_expired: 1;
	unsigned int bandwidth_reserved: 1;
};

struct uhci_td {
	__le32 link;
	__le32 status;
	__le32 token;
	__le32 buffer;
	dma_addr_t dma_handle;
	struct list_head list;
	int frame;
	struct list_head fl_list;
};

enum uhci_rh_state {
	UHCI_RH_RESET = 0,
	UHCI_RH_SUSPENDED = 1,
	UHCI_RH_AUTO_STOPPED = 2,
	UHCI_RH_RESUMING = 3,
	UHCI_RH_SUSPENDING = 4,
	UHCI_RH_RUNNING = 5,
	UHCI_RH_RUNNING_NODEVS = 6,
};

struct uhci_hcd {
	struct dentry___368 *dentry;
	long unsigned int io_addr;
	void *regs;
	struct dma_pool___2 *qh_pool;
	struct dma_pool___2 *td_pool;
	struct uhci_td *term_td;
	struct uhci_qh *skelqh[11];
	struct uhci_qh *next_qh;
	spinlock_t lock;
	dma_addr_t frame_dma_handle;
	__le32 *frame;
	void **frame_cpu;
	enum uhci_rh_state rh_state;
	long unsigned int auto_stop_time;
	unsigned int frame_number;
	unsigned int is_stopped;
	unsigned int last_iso_frame;
	unsigned int cur_iso_frame;
	unsigned int scan_in_progress: 1;
	unsigned int need_rescan: 1;
	unsigned int dead: 1;
	unsigned int RD_enable: 1;
	unsigned int is_initialized: 1;
	unsigned int fsbr_is_on: 1;
	unsigned int fsbr_is_wanted: 1;
	unsigned int fsbr_expiring: 1;
	struct timer_list fsbr_timer;
	unsigned int oc_low: 1;
	unsigned int wait_for_hp: 1;
	unsigned int big_endian_mmio: 1;
	unsigned int big_endian_desc: 1;
	unsigned int is_aspeed: 1;
	long unsigned int port_c_suspend;
	long unsigned int resuming_ports;
	long unsigned int ports_timeout;
	struct list_head idle_qh_list;
	int rh_numports;
	wait_queue_head_t waitqh;
	int num_waiting;
	int total_load;
	short int load[32];
	struct clk *clk;
	void (*reset_hc)(struct uhci_hcd *);
	int (*check_and_reset_hc)(struct uhci_hcd *);
	void (*configure_hc)(struct uhci_hcd *);
	int (*resume_detect_interrupts_are_broken)(struct uhci_hcd *);
	int (*global_suspend_mode_is_broken)(struct uhci_hcd *);
};

struct urb_priv___2 {
	struct list_head node;
	struct urb___3 *urb;
	struct uhci_qh *qh;
	struct list_head td_list;
	unsigned int fsbr: 1;
};

struct uhci_debug {
	int size;
	char *data;
};

struct usb_interface___12 {
	struct usb_host_interface *altsetting;
	struct usb_host_interface *cur_altsetting;
	unsigned int num_altsetting;
	struct usb_interface_assoc_descriptor *intf_assoc;
	int minor;
	enum usb_interface_condition condition;
	unsigned int sysfs_files_created: 1;
	unsigned int ep_devs_created: 1;
	unsigned int unregistering: 1;
	unsigned int needs_remote_wakeup: 1;
	unsigned int needs_altsetting0: 1;
	unsigned int needs_binding: 1;
	unsigned int resetting_device: 1;
	unsigned int authorized: 1;
	struct device___333 dev;
	struct device___333 *usb_dev;
	atomic_t pm_usage_cnt;
	struct work_struct reset_ws;
};

struct usb_host_config___12 {
	struct usb_config_descriptor desc;
	char *string;
	struct usb_interface_assoc_descriptor *intf_assoc[16];
	struct usb_interface___12 *interface[32];
	struct usb_interface_cache *intf_cache[32];
	unsigned char *extra;
	int extralen;
};

struct usb_device___13;

struct usb_bus___13 {
	struct device___333 *controller;
	struct device___333 *sysdev;
	int busnum;
	const char *bus_name;
	u8 uses_dma;
	u8 uses_pio_for_control;
	u8 otg_port;
	unsigned int is_b_host: 1;
	unsigned int b_hnp_enable: 1;
	unsigned int no_stop_on_short: 1;
	unsigned int no_sg_constraint: 1;
	unsigned int sg_tablesize;
	int devnum_next;
	struct mutex devnum_next_mutex;
	struct usb_devmap devmap;
	struct usb_device___13 *root_hub;
	struct usb_bus___13 *hs_companion;
	int bandwidth_allocated;
	int bandwidth_int_reqs;
	int bandwidth_isoc_reqs;
	unsigned int resuming_ports;
	struct mon_bus *mon_bus;
	int monitored;
};

struct usb_tt___10;

struct usb_device___13 {
	int devnum;
	char devpath[16];
	u32 route;
	enum usb_device_state state;
	enum usb_device_speed speed;
	unsigned int rx_lanes;
	unsigned int tx_lanes;
	struct usb_tt___10 *tt;
	int ttport;
	unsigned int toggle[2];
	struct usb_device___13 *parent;
	struct usb_bus___13 *bus;
	struct usb_host_endpoint ep0;
	struct device___333 dev;
	struct usb_device_descriptor descriptor;
	struct usb_host_bos *bos;
	struct usb_host_config___12 *config;
	struct usb_host_config___12 *actconfig;
	struct usb_host_endpoint *ep_in[16];
	struct usb_host_endpoint *ep_out[16];
	char **rawdescriptors;
	short unsigned int bus_mA;
	u8 portnum;
	u8 level;
	unsigned int can_submit: 1;
	unsigned int persist_enabled: 1;
	unsigned int have_langid: 1;
	unsigned int authorized: 1;
	unsigned int authenticated: 1;
	unsigned int wusb: 1;
	unsigned int lpm_capable: 1;
	unsigned int usb2_hw_lpm_capable: 1;
	unsigned int usb2_hw_lpm_besl_capable: 1;
	unsigned int usb2_hw_lpm_enabled: 1;
	unsigned int usb2_hw_lpm_allowed: 1;
	unsigned int usb3_lpm_u1_enabled: 1;
	unsigned int usb3_lpm_u2_enabled: 1;
	int string_langid;
	char *product;
	char *manufacturer;
	char *serial;
	struct list_head filelist;
	int maxchild;
	u32 quirks;
	atomic_t urbnum;
	long unsigned int active_duration;
	long unsigned int connect_time;
	unsigned int do_remote_wakeup: 1;
	unsigned int reset_resume: 1;
	unsigned int port_is_suspended: 1;
	struct wusb_dev *wusb_dev;
	int slot_id;
	enum usb_device_removable removable;
	struct usb2_lpm_parameters l1_params;
	struct usb3_lpm_parameters u1_params;
	struct usb3_lpm_parameters u2_params;
	unsigned int lpm_disable_count;
	u16 hub_delay;
};

struct usb_tt___10 {
	struct usb_device___13 *hub;
	int multi;
	unsigned int think_time;
	void *hcpriv;
	spinlock_t lock;
	struct list_head clear_list;
	struct work_struct clear_work;
};

struct usbdrv_wrap___9 {
	struct device_driver___333 driver;
	int for_devices;
};

struct usb_driver___9 {
	const char *name;
	int (*probe)(struct usb_interface___12 *, const struct usb_device_id *);
	void (*disconnect)(struct usb_interface___12 *);
	int (*unlocked_ioctl)(struct usb_interface___12 *, unsigned int, void *);
	int (*suspend)(struct usb_interface___12 *, pm_message_t);
	int (*resume)(struct usb_interface___12 *);
	int (*reset_resume)(struct usb_interface___12 *);
	int (*pre_reset)(struct usb_interface___12 *);
	int (*post_reset)(struct usb_interface___12 *);
	const struct usb_device_id *id_table;
	struct usb_dynids dynids;
	struct usbdrv_wrap___9 drvwrap;
	unsigned int no_dynamic_id: 1;
	unsigned int supports_autosuspend: 1;
	unsigned int disable_hub_initiated_lpm: 1;
	unsigned int soft_unbind: 1;
};

struct urb___12;

typedef void (*usb_complete_t___12)(struct urb___12 *);

struct urb___12 {
	struct kref kref;
	void *hcpriv;
	atomic_t use_count;
	atomic_t reject;
	int unlinked;
	struct list_head urb_list;
	struct list_head anchor_list;
	struct usb_anchor *anchor;
	struct usb_device___13 *dev;
	struct usb_host_endpoint *ep;
	unsigned int pipe;
	unsigned int stream_id;
	int status;
	unsigned int transfer_flags;
	void *transfer_buffer;
	dma_addr_t transfer_dma;
	struct scatterlist *sg;
	int num_mapped_sgs;
	int num_sgs;
	u32 transfer_buffer_length;
	u32 actual_length;
	unsigned char *setup_packet;
	dma_addr_t setup_dma;
	int start_frame;
	int number_of_packets;
	int interval;
	int error_count;
	void *context;
	usb_complete_t___12 complete;
	struct usb_iso_packet_descriptor iso_frame_desc[0];
};

struct hc_driver___9;

struct usb_hcd___9 {
	struct usb_bus___13 self;
	struct kref kref;
	const char *product_desc;
	int speed;
	char irq_descr[24];
	struct timer_list rh_timer;
	struct urb___12 *status_urb;
	struct work_struct wakeup_work;
	const struct hc_driver___9 *driver;
	struct usb_phy___3 *usb_phy;
	struct usb_phy_roothub *phy_roothub;
	long unsigned int flags;
	unsigned int rh_registered: 1;
	unsigned int rh_pollable: 1;
	unsigned int msix_enabled: 1;
	unsigned int msi_enabled: 1;
	unsigned int skip_phy_initialization: 1;
	unsigned int uses_new_polling: 1;
	unsigned int wireless: 1;
	unsigned int has_tt: 1;
	unsigned int amd_resume_bug: 1;
	unsigned int can_do_streams: 1;
	unsigned int tpl_support: 1;
	unsigned int cant_recv_wakeups: 1;
	unsigned int irq;
	void *regs;
	resource_size_t rsrc_start;
	resource_size_t rsrc_len;
	unsigned int power_budget;
	struct giveback_urb_bh high_prio_bh;
	struct giveback_urb_bh low_prio_bh;
	struct mutex *address0_mutex;
	struct mutex *bandwidth_mutex;
	struct usb_hcd___9 *shared_hcd;
	struct usb_hcd___9 *primary_hcd;
	struct dma_pool___2 *pool[4];
	int state;
	long unsigned int hcd_priv[0];
};

struct hc_driver___9 {
	const char *description;
	const char *product_desc;
	size_t hcd_priv_size;
	irqreturn_t (*irq)(struct usb_hcd___9 *);
	int flags;
	int (*reset)(struct usb_hcd___9 *);
	int (*start)(struct usb_hcd___9 *);
	int (*pci_suspend)(struct usb_hcd___9 *, bool);
	int (*pci_resume)(struct usb_hcd___9 *, bool);
	void (*stop)(struct usb_hcd___9 *);
	void (*shutdown)(struct usb_hcd___9 *);
	int (*get_frame_number)(struct usb_hcd___9 *);
	int (*urb_enqueue)(struct usb_hcd___9 *, struct urb___12 *, gfp_t);
	int (*urb_dequeue)(struct usb_hcd___9 *, struct urb___12 *, int);
	int (*map_urb_for_dma)(struct usb_hcd___9 *, struct urb___12 *, gfp_t);
	void (*unmap_urb_for_dma)(struct usb_hcd___9 *, struct urb___12 *);
	void (*endpoint_disable)(struct usb_hcd___9 *, struct usb_host_endpoint *);
	void (*endpoint_reset)(struct usb_hcd___9 *, struct usb_host_endpoint *);
	int (*hub_status_data)(struct usb_hcd___9 *, char *);
	int (*hub_control)(struct usb_hcd___9 *, u16, u16, u16, char *, u16);
	int (*bus_suspend)(struct usb_hcd___9 *);
	int (*bus_resume)(struct usb_hcd___9 *);
	int (*start_port_reset)(struct usb_hcd___9 *, unsigned int);
	long unsigned int (*get_resuming_ports)(struct usb_hcd___9 *);
	void (*relinquish_port)(struct usb_hcd___9 *, int);
	int (*port_handed_over)(struct usb_hcd___9 *, int);
	void (*clear_tt_buffer_complete)(struct usb_hcd___9 *, struct usb_host_endpoint *);
	int (*alloc_dev)(struct usb_hcd___9 *, struct usb_device___13 *);
	void (*free_dev)(struct usb_hcd___9 *, struct usb_device___13 *);
	int (*alloc_streams)(struct usb_hcd___9 *, struct usb_device___13 *, struct usb_host_endpoint **, unsigned int, unsigned int, gfp_t);
	int (*free_streams)(struct usb_hcd___9 *, struct usb_device___13 *, struct usb_host_endpoint **, unsigned int, gfp_t);
	int (*add_endpoint)(struct usb_hcd___9 *, struct usb_device___13 *, struct usb_host_endpoint *);
	int (*drop_endpoint)(struct usb_hcd___9 *, struct usb_device___13 *, struct usb_host_endpoint *);
	int (*check_bandwidth)(struct usb_hcd___9 *, struct usb_device___13 *);
	void (*reset_bandwidth)(struct usb_hcd___9 *, struct usb_device___13 *);
	int (*address_device)(struct usb_hcd___9 *, struct usb_device___13 *);
	int (*enable_device)(struct usb_hcd___9 *, struct usb_device___13 *);
	int (*update_hub_device)(struct usb_hcd___9 *, struct usb_device___13 *, struct usb_tt___10 *, gfp_t);
	int (*reset_device)(struct usb_hcd___9 *, struct usb_device___13 *);
	int (*update_device)(struct usb_hcd___9 *, struct usb_device___13 *);
	int (*set_usb2_hw_lpm)(struct usb_hcd___9 *, struct usb_device___13 *, int);
	int (*enable_usb3_lpm_timeout)(struct usb_hcd___9 *, struct usb_device___13 *, enum usb3_link_state);
	int (*disable_usb3_lpm_timeout)(struct usb_hcd___9 *, struct usb_device___13 *, enum usb3_link_state);
	int (*find_raw_port_number)(struct usb_hcd___9 *, int);
	int (*port_power)(struct usb_hcd___9 *, int, bool);
};

struct usb_mon_operations___10 {
	void (*urb_submit)(struct usb_bus___13 *, struct urb___12 *);
	void (*urb_submit_error)(struct usb_bus___13 *, struct urb___12 *, int);
	void (*urb_complete)(struct usb_bus___13 *, struct urb___12 *, int);
};

struct xhci_cap_regs {
	__le32 hc_capbase;
	__le32 hcs_params1;
	__le32 hcs_params2;
	__le32 hcs_params3;
	__le32 hcc_params;
	__le32 db_off;
	__le32 run_regs_off;
	__le32 hcc_params2;
};

struct xhci_op_regs {
	__le32 command;
	__le32 status;
	__le32 page_size;
	__le32 reserved1;
	__le32 reserved2;
	__le32 dev_notification;
	__le64 cmd_ring;
	__le32 reserved3[4];
	__le64 dcbaa_ptr;
	__le32 config_reg;
	__le32 reserved4[241];
	__le32 port_status_base;
	__le32 port_power_base;
	__le32 port_link_base;
	__le32 reserved5;
	__le32 reserved6[1016];
};

struct xhci_intr_reg {
	__le32 irq_pending;
	__le32 irq_control;
	__le32 erst_size;
	__le32 rsvd;
	__le64 erst_base;
	__le64 erst_dequeue;
};

struct xhci_run_regs {
	__le32 microframe_index;
	__le32 rsvd[7];
	struct xhci_intr_reg ir_set[128];
};

struct xhci_doorbell_array {
	__le32 doorbell[256];
};

struct xhci_container_ctx {
	unsigned int type;
	int size;
	u8 *bytes;
	dma_addr_t dma;
};

struct xhci_slot_ctx {
	__le32 dev_info;
	__le32 dev_info2;
	__le32 tt_info;
	__le32 dev_state;
	__le32 reserved[4];
};

struct xhci_ep_ctx {
	__le32 ep_info;
	__le32 ep_info2;
	__le64 deq;
	__le32 tx_info;
	__le32 reserved[3];
};

struct xhci_input_control_ctx {
	__le32 drop_flags;
	__le32 add_flags;
	__le32 rsvd2[6];
};

union xhci_trb;

struct xhci_command {
	struct xhci_container_ctx *in_ctx;
	u32 status;
	int slot_id;
	struct completion *completion;
	union xhci_trb *command_trb;
	struct list_head cmd_list;
};

struct xhci_link_trb {
	__le64 segment_ptr;
	__le32 intr_target;
	__le32 control;
};

struct xhci_transfer_event {
	__le64 buffer;
	__le32 transfer_len;
	__le32 flags;
};

struct xhci_event_cmd {
	__le64 cmd_trb;
	__le32 status;
	__le32 flags;
};

struct xhci_generic_trb {
	__le32 field[4];
};

union xhci_trb {
	struct xhci_link_trb link;
	struct xhci_transfer_event trans_event;
	struct xhci_event_cmd event_cmd;
	struct xhci_generic_trb generic;
};

struct xhci_stream_ctx {
	__le64 stream_ring;
	__le32 reserved[2];
};

struct xhci_ring;

struct xhci_stream_info {
	struct xhci_ring **stream_rings;
	unsigned int num_streams;
	struct xhci_stream_ctx *stream_ctx_array;
	unsigned int num_stream_ctxs;
	dma_addr_t ctx_array_dma;
	struct xarray trb_address_map;
	struct xhci_command *free_streams_command;
};

enum xhci_ring_type {
	TYPE_CTRL = 0,
	TYPE_ISOC = 1,
	TYPE_BULK = 2,
	TYPE_INTR = 3,
	TYPE_STREAM = 4,
	TYPE_COMMAND = 5,
	TYPE_EVENT = 6,
};

struct xhci_segment;

struct xhci_ring {
	struct xhci_segment *first_seg;
	struct xhci_segment *last_seg;
	union xhci_trb *enqueue;
	struct xhci_segment *enq_seg;
	union xhci_trb *dequeue;
	struct xhci_segment *deq_seg;
	struct list_head td_list;
	u32 cycle_state;
	unsigned int stream_id;
	unsigned int num_segs;
	unsigned int num_trbs_free;
	unsigned int num_trbs_free_temp;
	unsigned int bounce_buf_len;
	enum xhci_ring_type type;
	bool last_td_was_short;
	struct xarray *trb_address_map;
};

struct xhci_bw_info {
	unsigned int ep_interval;
	unsigned int mult;
	unsigned int num_packets;
	unsigned int max_packet_size;
	unsigned int max_esit_payload;
	unsigned int type;
};

struct xhci_hcd;

struct xhci_virt_ep {
	struct xhci_ring *ring;
	struct xhci_stream_info *stream_info;
	struct xhci_ring *new_ring;
	unsigned int ep_state;
	struct list_head cancelled_td_list;
	struct timer_list stop_cmd_timer;
	struct xhci_hcd *xhci;
	struct xhci_segment *queued_deq_seg;
	union xhci_trb *queued_deq_ptr;
	bool skip;
	struct xhci_bw_info bw_info;
	struct list_head bw_endpoint_list;
	int next_frame_id;
	bool use_extended_tbc;
};

struct xhci_erst_entry;

struct xhci_erst {
	struct xhci_erst_entry *entries;
	unsigned int num_entries;
	dma_addr_t erst_dma_addr;
	unsigned int erst_size;
};

struct s3_save {
	u32 command;
	u32 dev_nt;
	u64 dcbaa_ptr;
	u32 config_reg;
	u32 irq_pending;
	u32 irq_control;
	u32 erst_size;
	u64 erst_base;
	u64 erst_dequeue;
};

struct xhci_bus_state {
	long unsigned int bus_suspended;
	long unsigned int next_statechange;
	u32 port_c_suspend;
	u32 suspended_ports;
	u32 port_remote_wakeup;
	long unsigned int resume_done[31];
	long unsigned int resuming_ports;
	long unsigned int rexit_ports;
	struct completion rexit_done[31];
};

struct xhci_port;

struct xhci_hub {
	struct xhci_port **ports;
	unsigned int num_ports;
	struct usb_hcd___9 *hcd;
	u8 maj_rev;
	u8 min_rev;
	u32 *psi;
	u8 psi_count;
	u8 psi_uid_count;
};

struct xhci_device_context_array;

struct xhci_scratchpad;

struct xhci_virt_device;

struct xhci_root_port_bw_info;

struct xhci_hcd {
	struct usb_hcd___9 *main_hcd;
	struct usb_hcd___9 *shared_hcd;
	struct xhci_cap_regs *cap_regs;
	struct xhci_op_regs *op_regs;
	struct xhci_run_regs *run_regs;
	struct xhci_doorbell_array *dba;
	struct xhci_intr_reg *ir_set;
	__u32 hcs_params1;
	__u32 hcs_params2;
	__u32 hcs_params3;
	__u32 hcc_params;
	__u32 hcc_params2;
	spinlock_t lock;
	u8 sbrn;
	u16 hci_version;
	u8 max_slots;
	u8 max_interrupters;
	u8 max_ports;
	u8 isoc_threshold;
	u32 imod_interval;
	int event_ring_max;
	int page_size;
	int page_shift;
	int msix_count;
	struct clk *clk;
	struct clk *reg_clk;
	struct xhci_device_context_array *dcbaa;
	struct xhci_ring *cmd_ring;
	unsigned int cmd_ring_state;
	struct list_head cmd_list;
	unsigned int cmd_ring_reserved_trbs;
	struct delayed_work cmd_timer;
	struct completion cmd_ring_stop_completion;
	struct xhci_command *current_cmd;
	struct xhci_ring *event_ring;
	struct xhci_erst erst;
	struct xhci_scratchpad *scratchpad;
	struct list_head lpm_failed_devs;
	struct mutex mutex;
	struct xhci_command *lpm_command;
	struct xhci_virt_device *devs[256];
	struct xhci_root_port_bw_info *rh_bw;
	struct dma_pool___2 *device_pool;
	struct dma_pool___2 *segment_pool;
	struct dma_pool___2 *small_streams_pool;
	struct dma_pool___2 *medium_streams_pool;
	unsigned int xhc_state;
	u32 command;
	struct s3_save s3;
	long long unsigned int quirks;
	unsigned int num_active_eps;
	unsigned int limit_active_eps;
	struct xhci_bus_state bus_state[2];
	struct xhci_port *hw_ports;
	struct xhci_hub usb2_rhub;
	struct xhci_hub usb3_rhub;
	unsigned int sw_lpm_support: 1;
	unsigned int hw_lpm_support: 1;
	u32 *ext_caps;
	unsigned int num_ext_caps;
	struct timer_list comp_mode_recovery_timer;
	u32 port_status_u0;
	u16 test_mode;
	struct dentry___365 *debugfs_root;
	struct dentry___365 *debugfs_slots;
	struct list_head regset_list;
	void *dbc;
	long unsigned int priv[0];
};

struct xhci_segment {
	union xhci_trb *trbs;
	struct xhci_segment *next;
	dma_addr_t dma;
	dma_addr_t bounce_dma;
	void *bounce_buf;
	unsigned int bounce_offs;
	unsigned int bounce_len;
};

enum xhci_overhead_type {
	LS_OVERHEAD_TYPE = 0,
	FS_OVERHEAD_TYPE = 1,
	HS_OVERHEAD_TYPE = 2,
};

struct xhci_interval_bw {
	unsigned int num_packets;
	struct list_head endpoints;
	unsigned int overhead[3];
};

struct xhci_interval_bw_table {
	unsigned int interval0_esit_payload;
	struct xhci_interval_bw interval_bw[16];
	unsigned int bw_used;
	unsigned int ss_bw_in;
	unsigned int ss_bw_out;
};

struct xhci_tt_bw_info;

struct xhci_virt_device {
	struct usb_device___13 *udev;
	struct xhci_container_ctx *out_ctx;
	struct xhci_container_ctx *in_ctx;
	struct xhci_virt_ep eps[31];
	u8 fake_port;
	u8 real_port;
	struct xhci_interval_bw_table *bw_table;
	struct xhci_tt_bw_info *tt_info;
	u16 current_mel;
	void *debugfs_private;
};

struct xhci_tt_bw_info {
	struct list_head tt_list;
	int slot_id;
	int ttport;
	struct xhci_interval_bw_table bw_table;
	int active_eps;
};

struct xhci_root_port_bw_info {
	struct list_head tts;
	unsigned int num_active_tts;
	struct xhci_interval_bw_table bw_table;
};

struct xhci_device_context_array {
	__le64 dev_context_ptrs[256];
	dma_addr_t dma;
};

enum xhci_setup_dev {
	SETUP_CONTEXT_ONLY = 0,
	SETUP_CONTEXT_ADDRESS = 1,
};

struct xhci_td {
	struct list_head td_list;
	struct list_head cancelled_td_list;
	struct urb___12 *urb;
	struct xhci_segment *start_seg;
	union xhci_trb *first_trb;
	union xhci_trb *last_trb;
	struct xhci_segment *bounce_seg;
	bool urb_length_set;
};

struct xhci_dequeue_state {
	struct xhci_segment *new_deq_seg;
	union xhci_trb *new_deq_ptr;
	int new_cycle_state;
	unsigned int stream_id;
};

struct xhci_erst_entry {
	__le64 seg_addr;
	__le32 seg_size;
	__le32 rsvd;
};

struct xhci_scratchpad {
	u64 *sp_array;
	dma_addr_t sp_dma;
	void **sp_buffers;
};

struct urb_priv___3 {
	int num_tds;
	int num_tds_done;
	struct xhci_td td[0];
};

struct xhci_port {
	__le32 *addr;
	int hw_portnum;
	int hcd_portnum;
	struct xhci_hub *rhub;
};

struct xhci_driver_overrides {
	size_t extra_priv_size;
	int (*reset)(struct usb_hcd___9 *);
	int (*start)(struct usb_hcd___9 *);
};

typedef void (*xhci_get_quirks_t)(struct device___333 *, struct xhci_hcd *);

struct usb_interface___13 {
	struct usb_host_interface *altsetting;
	struct usb_host_interface *cur_altsetting;
	unsigned int num_altsetting;
	struct usb_interface_assoc_descriptor *intf_assoc;
	int minor;
	enum usb_interface_condition condition;
	unsigned int sysfs_files_created: 1;
	unsigned int ep_devs_created: 1;
	unsigned int unregistering: 1;
	unsigned int needs_remote_wakeup: 1;
	unsigned int needs_altsetting0: 1;
	unsigned int needs_binding: 1;
	unsigned int resetting_device: 1;
	unsigned int authorized: 1;
	struct device___306 dev;
	struct device___306 *usb_dev;
	atomic_t pm_usage_cnt;
	struct work_struct reset_ws;
};

struct usb_host_config___13 {
	struct usb_config_descriptor desc;
	char *string;
	struct usb_interface_assoc_descriptor *intf_assoc[16];
	struct usb_interface___13 *interface[32];
	struct usb_interface_cache *intf_cache[32];
	unsigned char *extra;
	int extralen;
};

struct usb_device___14;

struct usb_bus___14 {
	struct device___306 *controller;
	struct device___306 *sysdev;
	int busnum;
	const char *bus_name;
	u8 uses_dma;
	u8 uses_pio_for_control;
	u8 otg_port;
	unsigned int is_b_host: 1;
	unsigned int b_hnp_enable: 1;
	unsigned int no_stop_on_short: 1;
	unsigned int no_sg_constraint: 1;
	unsigned int sg_tablesize;
	int devnum_next;
	struct mutex devnum_next_mutex;
	struct usb_devmap devmap;
	struct usb_device___14 *root_hub;
	struct usb_bus___14 *hs_companion;
	int bandwidth_allocated;
	int bandwidth_int_reqs;
	int bandwidth_isoc_reqs;
	unsigned int resuming_ports;
	struct mon_bus *mon_bus;
	int monitored;
};

struct usb_tt___11;

struct usb_device___14 {
	int devnum;
	char devpath[16];
	u32 route;
	enum usb_device_state state;
	enum usb_device_speed speed;
	unsigned int rx_lanes;
	unsigned int tx_lanes;
	struct usb_tt___11 *tt;
	int ttport;
	unsigned int toggle[2];
	struct usb_device___14 *parent;
	struct usb_bus___14 *bus;
	struct usb_host_endpoint ep0;
	struct device___306 dev;
	struct usb_device_descriptor descriptor;
	struct usb_host_bos *bos;
	struct usb_host_config___13 *config;
	struct usb_host_config___13 *actconfig;
	struct usb_host_endpoint *ep_in[16];
	struct usb_host_endpoint *ep_out[16];
	char **rawdescriptors;
	short unsigned int bus_mA;
	u8 portnum;
	u8 level;
	unsigned int can_submit: 1;
	unsigned int persist_enabled: 1;
	unsigned int have_langid: 1;
	unsigned int authorized: 1;
	unsigned int authenticated: 1;
	unsigned int wusb: 1;
	unsigned int lpm_capable: 1;
	unsigned int usb2_hw_lpm_capable: 1;
	unsigned int usb2_hw_lpm_besl_capable: 1;
	unsigned int usb2_hw_lpm_enabled: 1;
	unsigned int usb2_hw_lpm_allowed: 1;
	unsigned int usb3_lpm_u1_enabled: 1;
	unsigned int usb3_lpm_u2_enabled: 1;
	int string_langid;
	char *product;
	char *manufacturer;
	char *serial;
	struct list_head filelist;
	int maxchild;
	u32 quirks;
	atomic_t urbnum;
	long unsigned int active_duration;
	long unsigned int connect_time;
	unsigned int do_remote_wakeup: 1;
	unsigned int reset_resume: 1;
	unsigned int port_is_suspended: 1;
	struct wusb_dev *wusb_dev;
	int slot_id;
	enum usb_device_removable removable;
	struct usb2_lpm_parameters l1_params;
	struct usb3_lpm_parameters u1_params;
	struct usb3_lpm_parameters u2_params;
	unsigned int lpm_disable_count;
	u16 hub_delay;
};

struct usb_tt___11 {
	struct usb_device___14 *hub;
	int multi;
	unsigned int think_time;
	void *hcpriv;
	spinlock_t lock;
	struct list_head clear_list;
	struct work_struct clear_work;
};

struct urb___13;

typedef void (*usb_complete_t___13)(struct urb___13 *);

struct urb___13 {
	struct kref kref;
	void *hcpriv;
	atomic_t use_count;
	atomic_t reject;
	int unlinked;
	struct list_head urb_list;
	struct list_head anchor_list;
	struct usb_anchor *anchor;
	struct usb_device___14 *dev;
	struct usb_host_endpoint *ep;
	unsigned int pipe;
	unsigned int stream_id;
	int status;
	unsigned int transfer_flags;
	void *transfer_buffer;
	dma_addr_t transfer_dma;
	struct scatterlist *sg;
	int num_mapped_sgs;
	int num_sgs;
	u32 transfer_buffer_length;
	u32 actual_length;
	unsigned char *setup_packet;
	dma_addr_t setup_dma;
	int start_frame;
	int number_of_packets;
	int interval;
	int error_count;
	void *context;
	usb_complete_t___13 complete;
	struct usb_iso_packet_descriptor iso_frame_desc[0];
};

struct hc_driver___10;

struct usb_hcd___10 {
	struct usb_bus___14 self;
	struct kref kref;
	const char *product_desc;
	int speed;
	char irq_descr[24];
	struct timer_list rh_timer;
	struct urb___13 *status_urb;
	struct work_struct wakeup_work;
	const struct hc_driver___10 *driver;
	struct usb_phy___3 *usb_phy;
	struct usb_phy_roothub *phy_roothub;
	long unsigned int flags;
	unsigned int rh_registered: 1;
	unsigned int rh_pollable: 1;
	unsigned int msix_enabled: 1;
	unsigned int msi_enabled: 1;
	unsigned int skip_phy_initialization: 1;
	unsigned int uses_new_polling: 1;
	unsigned int wireless: 1;
	unsigned int has_tt: 1;
	unsigned int amd_resume_bug: 1;
	unsigned int can_do_streams: 1;
	unsigned int tpl_support: 1;
	unsigned int cant_recv_wakeups: 1;
	unsigned int irq;
	void *regs;
	resource_size_t rsrc_start;
	resource_size_t rsrc_len;
	unsigned int power_budget;
	struct giveback_urb_bh high_prio_bh;
	struct giveback_urb_bh low_prio_bh;
	struct mutex *address0_mutex;
	struct mutex *bandwidth_mutex;
	struct usb_hcd___10 *shared_hcd;
	struct usb_hcd___10 *primary_hcd;
	struct dma_pool___2 *pool[4];
	int state;
	long unsigned int hcd_priv[0];
};

struct hc_driver___10 {
	const char *description;
	const char *product_desc;
	size_t hcd_priv_size;
	irqreturn_t (*irq)(struct usb_hcd___10 *);
	int flags;
	int (*reset)(struct usb_hcd___10 *);
	int (*start)(struct usb_hcd___10 *);
	int (*pci_suspend)(struct usb_hcd___10 *, bool);
	int (*pci_resume)(struct usb_hcd___10 *, bool);
	void (*stop)(struct usb_hcd___10 *);
	void (*shutdown)(struct usb_hcd___10 *);
	int (*get_frame_number)(struct usb_hcd___10 *);
	int (*urb_enqueue)(struct usb_hcd___10 *, struct urb___13 *, gfp_t);
	int (*urb_dequeue)(struct usb_hcd___10 *, struct urb___13 *, int);
	int (*map_urb_for_dma)(struct usb_hcd___10 *, struct urb___13 *, gfp_t);
	void (*unmap_urb_for_dma)(struct usb_hcd___10 *, struct urb___13 *);
	void (*endpoint_disable)(struct usb_hcd___10 *, struct usb_host_endpoint *);
	void (*endpoint_reset)(struct usb_hcd___10 *, struct usb_host_endpoint *);
	int (*hub_status_data)(struct usb_hcd___10 *, char *);
	int (*hub_control)(struct usb_hcd___10 *, u16, u16, u16, char *, u16);
	int (*bus_suspend)(struct usb_hcd___10 *);
	int (*bus_resume)(struct usb_hcd___10 *);
	int (*start_port_reset)(struct usb_hcd___10 *, unsigned int);
	long unsigned int (*get_resuming_ports)(struct usb_hcd___10 *);
	void (*relinquish_port)(struct usb_hcd___10 *, int);
	int (*port_handed_over)(struct usb_hcd___10 *, int);
	void (*clear_tt_buffer_complete)(struct usb_hcd___10 *, struct usb_host_endpoint *);
	int (*alloc_dev)(struct usb_hcd___10 *, struct usb_device___14 *);
	void (*free_dev)(struct usb_hcd___10 *, struct usb_device___14 *);
	int (*alloc_streams)(struct usb_hcd___10 *, struct usb_device___14 *, struct usb_host_endpoint **, unsigned int, unsigned int, gfp_t);
	int (*free_streams)(struct usb_hcd___10 *, struct usb_device___14 *, struct usb_host_endpoint **, unsigned int, gfp_t);
	int (*add_endpoint)(struct usb_hcd___10 *, struct usb_device___14 *, struct usb_host_endpoint *);
	int (*drop_endpoint)(struct usb_hcd___10 *, struct usb_device___14 *, struct usb_host_endpoint *);
	int (*check_bandwidth)(struct usb_hcd___10 *, struct usb_device___14 *);
	void (*reset_bandwidth)(struct usb_hcd___10 *, struct usb_device___14 *);
	int (*address_device)(struct usb_hcd___10 *, struct usb_device___14 *);
	int (*enable_device)(struct usb_hcd___10 *, struct usb_device___14 *);
	int (*update_hub_device)(struct usb_hcd___10 *, struct usb_device___14 *, struct usb_tt___11 *, gfp_t);
	int (*reset_device)(struct usb_hcd___10 *, struct usb_device___14 *);
	int (*update_device)(struct usb_hcd___10 *, struct usb_device___14 *);
	int (*set_usb2_hw_lpm)(struct usb_hcd___10 *, struct usb_device___14 *, int);
	int (*enable_usb3_lpm_timeout)(struct usb_hcd___10 *, struct usb_device___14 *, enum usb3_link_state);
	int (*disable_usb3_lpm_timeout)(struct usb_hcd___10 *, struct usb_device___14 *, enum usb3_link_state);
	int (*find_raw_port_number)(struct usb_hcd___10 *, int);
	int (*port_power)(struct usb_hcd___10 *, int, bool);
};

struct usb_mon_operations___11 {
	void (*urb_submit)(struct usb_bus___14 *, struct urb___13 *);
	void (*urb_submit_error)(struct usb_bus___14 *, struct urb___13 *, int);
	void (*urb_complete)(struct usb_bus___14 *, struct urb___13 *, int);
};

struct xhci_hcd___2;

struct xhci_virt_ep___2 {
	struct xhci_ring *ring;
	struct xhci_stream_info *stream_info;
	struct xhci_ring *new_ring;
	unsigned int ep_state;
	struct list_head cancelled_td_list;
	struct timer_list stop_cmd_timer;
	struct xhci_hcd___2 *xhci;
	struct xhci_segment *queued_deq_seg;
	union xhci_trb *queued_deq_ptr;
	bool skip;
	struct xhci_bw_info bw_info;
	struct list_head bw_endpoint_list;
	int next_frame_id;
	bool use_extended_tbc;
};

struct xhci_port___2;

struct xhci_hub___2 {
	struct xhci_port___2 **ports;
	unsigned int num_ports;
	struct usb_hcd___10 *hcd;
	u8 maj_rev;
	u8 min_rev;
	u32 *psi;
	u8 psi_count;
	u8 psi_uid_count;
};

struct xhci_virt_device___2;

struct xhci_hcd___2 {
	struct usb_hcd___10 *main_hcd;
	struct usb_hcd___10 *shared_hcd;
	struct xhci_cap_regs *cap_regs;
	struct xhci_op_regs *op_regs;
	struct xhci_run_regs *run_regs;
	struct xhci_doorbell_array *dba;
	struct xhci_intr_reg *ir_set;
	__u32 hcs_params1;
	__u32 hcs_params2;
	__u32 hcs_params3;
	__u32 hcc_params;
	__u32 hcc_params2;
	spinlock_t lock;
	u8 sbrn;
	u16 hci_version;
	u8 max_slots;
	u8 max_interrupters;
	u8 max_ports;
	u8 isoc_threshold;
	u32 imod_interval;
	int event_ring_max;
	int page_size;
	int page_shift;
	int msix_count;
	struct clk *clk;
	struct clk *reg_clk;
	struct xhci_device_context_array *dcbaa;
	struct xhci_ring *cmd_ring;
	unsigned int cmd_ring_state;
	struct list_head cmd_list;
	unsigned int cmd_ring_reserved_trbs;
	struct delayed_work cmd_timer;
	struct completion cmd_ring_stop_completion;
	struct xhci_command *current_cmd;
	struct xhci_ring *event_ring;
	struct xhci_erst erst;
	struct xhci_scratchpad *scratchpad;
	struct list_head lpm_failed_devs;
	struct mutex mutex;
	struct xhci_command *lpm_command;
	struct xhci_virt_device___2 *devs[256];
	struct xhci_root_port_bw_info *rh_bw;
	struct dma_pool___2 *device_pool;
	struct dma_pool___2 *segment_pool;
	struct dma_pool___2 *small_streams_pool;
	struct dma_pool___2 *medium_streams_pool;
	unsigned int xhc_state;
	u32 command;
	struct s3_save s3;
	long long unsigned int quirks;
	unsigned int num_active_eps;
	unsigned int limit_active_eps;
	struct xhci_bus_state bus_state[2];
	struct xhci_port___2 *hw_ports;
	struct xhci_hub___2 usb2_rhub;
	struct xhci_hub___2 usb3_rhub;
	unsigned int sw_lpm_support: 1;
	unsigned int hw_lpm_support: 1;
	u32 *ext_caps;
	unsigned int num_ext_caps;
	struct timer_list comp_mode_recovery_timer;
	u32 port_status_u0;
	u16 test_mode;
	struct dentry___339 *debugfs_root;
	struct dentry___339 *debugfs_slots;
	struct list_head regset_list;
	void *dbc;
	long unsigned int priv[0];
};

struct xhci_virt_device___2 {
	struct usb_device___14 *udev;
	struct xhci_container_ctx *out_ctx;
	struct xhci_container_ctx *in_ctx;
	struct xhci_virt_ep___2 eps[31];
	u8 fake_port;
	u8 real_port;
	struct xhci_interval_bw_table *bw_table;
	struct xhci_tt_bw_info *tt_info;
	u16 current_mel;
	void *debugfs_private;
};

struct xhci_td___2 {
	struct list_head td_list;
	struct list_head cancelled_td_list;
	struct urb___13 *urb;
	struct xhci_segment *start_seg;
	union xhci_trb *first_trb;
	union xhci_trb *last_trb;
	struct xhci_segment *bounce_seg;
	bool urb_length_set;
};

struct urb_priv___4 {
	int num_tds;
	int num_tds_done;
	struct xhci_td___2 td[0];
};

struct xhci_port___2 {
	__le32 *addr;
	int hw_portnum;
	int hcd_portnum;
	struct xhci_hub___2 *rhub;
};

struct usb_interface___14 {
	struct usb_host_interface *altsetting;
	struct usb_host_interface *cur_altsetting;
	unsigned int num_altsetting;
	struct usb_interface_assoc_descriptor *intf_assoc;
	int minor;
	enum usb_interface_condition condition;
	unsigned int sysfs_files_created: 1;
	unsigned int ep_devs_created: 1;
	unsigned int unregistering: 1;
	unsigned int needs_remote_wakeup: 1;
	unsigned int needs_altsetting0: 1;
	unsigned int needs_binding: 1;
	unsigned int resetting_device: 1;
	unsigned int authorized: 1;
	struct device___259 dev;
	struct device___259 *usb_dev;
	atomic_t pm_usage_cnt;
	struct work_struct reset_ws;
};

struct usb_host_config___14 {
	struct usb_config_descriptor desc;
	char *string;
	struct usb_interface_assoc_descriptor *intf_assoc[16];
	struct usb_interface___14 *interface[32];
	struct usb_interface_cache *intf_cache[32];
	unsigned char *extra;
	int extralen;
};

struct usb_device___15;

struct usb_bus___15 {
	struct device___259 *controller;
	struct device___259 *sysdev;
	int busnum;
	const char *bus_name;
	u8 uses_dma;
	u8 uses_pio_for_control;
	u8 otg_port;
	unsigned int is_b_host: 1;
	unsigned int b_hnp_enable: 1;
	unsigned int no_stop_on_short: 1;
	unsigned int no_sg_constraint: 1;
	unsigned int sg_tablesize;
	int devnum_next;
	struct mutex devnum_next_mutex;
	struct usb_devmap devmap;
	struct usb_device___15 *root_hub;
	struct usb_bus___15 *hs_companion;
	int bandwidth_allocated;
	int bandwidth_int_reqs;
	int bandwidth_isoc_reqs;
	unsigned int resuming_ports;
	struct mon_bus *mon_bus;
	int monitored;
};

struct usb_tt___12;

struct usb_device___15 {
	int devnum;
	char devpath[16];
	u32 route;
	enum usb_device_state state;
	enum usb_device_speed speed;
	unsigned int rx_lanes;
	unsigned int tx_lanes;
	struct usb_tt___12 *tt;
	int ttport;
	unsigned int toggle[2];
	struct usb_device___15 *parent;
	struct usb_bus___15 *bus;
	struct usb_host_endpoint ep0;
	struct device___259 dev;
	struct usb_device_descriptor descriptor;
	struct usb_host_bos *bos;
	struct usb_host_config___14 *config;
	struct usb_host_config___14 *actconfig;
	struct usb_host_endpoint *ep_in[16];
	struct usb_host_endpoint *ep_out[16];
	char **rawdescriptors;
	short unsigned int bus_mA;
	u8 portnum;
	u8 level;
	unsigned int can_submit: 1;
	unsigned int persist_enabled: 1;
	unsigned int have_langid: 1;
	unsigned int authorized: 1;
	unsigned int authenticated: 1;
	unsigned int wusb: 1;
	unsigned int lpm_capable: 1;
	unsigned int usb2_hw_lpm_capable: 1;
	unsigned int usb2_hw_lpm_besl_capable: 1;
	unsigned int usb2_hw_lpm_enabled: 1;
	unsigned int usb2_hw_lpm_allowed: 1;
	unsigned int usb3_lpm_u1_enabled: 1;
	unsigned int usb3_lpm_u2_enabled: 1;
	int string_langid;
	char *product;
	char *manufacturer;
	char *serial;
	struct list_head filelist;
	int maxchild;
	u32 quirks;
	atomic_t urbnum;
	long unsigned int active_duration;
	long unsigned int connect_time;
	unsigned int do_remote_wakeup: 1;
	unsigned int reset_resume: 1;
	unsigned int port_is_suspended: 1;
	struct wusb_dev *wusb_dev;
	int slot_id;
	enum usb_device_removable removable;
	struct usb2_lpm_parameters l1_params;
	struct usb3_lpm_parameters u1_params;
	struct usb3_lpm_parameters u2_params;
	unsigned int lpm_disable_count;
	u16 hub_delay;
};

struct usb_tt___12 {
	struct usb_device___15 *hub;
	int multi;
	unsigned int think_time;
	void *hcpriv;
	spinlock_t lock;
	struct list_head clear_list;
	struct work_struct clear_work;
};

struct urb___14;

typedef void (*usb_complete_t___14)(struct urb___14 *);

struct urb___14 {
	struct kref kref;
	void *hcpriv;
	atomic_t use_count;
	atomic_t reject;
	int unlinked;
	struct list_head urb_list;
	struct list_head anchor_list;
	struct usb_anchor *anchor;
	struct usb_device___15 *dev;
	struct usb_host_endpoint *ep;
	unsigned int pipe;
	unsigned int stream_id;
	int status;
	unsigned int transfer_flags;
	void *transfer_buffer;
	dma_addr_t transfer_dma;
	struct scatterlist *sg;
	int num_mapped_sgs;
	int num_sgs;
	u32 transfer_buffer_length;
	u32 actual_length;
	unsigned char *setup_packet;
	dma_addr_t setup_dma;
	int start_frame;
	int number_of_packets;
	int interval;
	int error_count;
	void *context;
	usb_complete_t___14 complete;
	struct usb_iso_packet_descriptor iso_frame_desc[0];
};

struct hc_driver___11;

struct usb_hcd___11 {
	struct usb_bus___15 self;
	struct kref kref;
	const char *product_desc;
	int speed;
	char irq_descr[24];
	struct timer_list rh_timer;
	struct urb___14 *status_urb;
	struct work_struct wakeup_work;
	const struct hc_driver___11 *driver;
	struct usb_phy___3 *usb_phy;
	struct usb_phy_roothub *phy_roothub;
	long unsigned int flags;
	unsigned int rh_registered: 1;
	unsigned int rh_pollable: 1;
	unsigned int msix_enabled: 1;
	unsigned int msi_enabled: 1;
	unsigned int skip_phy_initialization: 1;
	unsigned int uses_new_polling: 1;
	unsigned int wireless: 1;
	unsigned int has_tt: 1;
	unsigned int amd_resume_bug: 1;
	unsigned int can_do_streams: 1;
	unsigned int tpl_support: 1;
	unsigned int cant_recv_wakeups: 1;
	unsigned int irq;
	void *regs;
	resource_size_t rsrc_start;
	resource_size_t rsrc_len;
	unsigned int power_budget;
	struct giveback_urb_bh high_prio_bh;
	struct giveback_urb_bh low_prio_bh;
	struct mutex *address0_mutex;
	struct mutex *bandwidth_mutex;
	struct usb_hcd___11 *shared_hcd;
	struct usb_hcd___11 *primary_hcd;
	struct dma_pool___2 *pool[4];
	int state;
	long unsigned int hcd_priv[0];
};

struct hc_driver___11 {
	const char *description;
	const char *product_desc;
	size_t hcd_priv_size;
	irqreturn_t (*irq)(struct usb_hcd___11 *);
	int flags;
	int (*reset)(struct usb_hcd___11 *);
	int (*start)(struct usb_hcd___11 *);
	int (*pci_suspend)(struct usb_hcd___11 *, bool);
	int (*pci_resume)(struct usb_hcd___11 *, bool);
	void (*stop)(struct usb_hcd___11 *);
	void (*shutdown)(struct usb_hcd___11 *);
	int (*get_frame_number)(struct usb_hcd___11 *);
	int (*urb_enqueue)(struct usb_hcd___11 *, struct urb___14 *, gfp_t);
	int (*urb_dequeue)(struct usb_hcd___11 *, struct urb___14 *, int);
	int (*map_urb_for_dma)(struct usb_hcd___11 *, struct urb___14 *, gfp_t);
	void (*unmap_urb_for_dma)(struct usb_hcd___11 *, struct urb___14 *);
	void (*endpoint_disable)(struct usb_hcd___11 *, struct usb_host_endpoint *);
	void (*endpoint_reset)(struct usb_hcd___11 *, struct usb_host_endpoint *);
	int (*hub_status_data)(struct usb_hcd___11 *, char *);
	int (*hub_control)(struct usb_hcd___11 *, u16, u16, u16, char *, u16);
	int (*bus_suspend)(struct usb_hcd___11 *);
	int (*bus_resume)(struct usb_hcd___11 *);
	int (*start_port_reset)(struct usb_hcd___11 *, unsigned int);
	long unsigned int (*get_resuming_ports)(struct usb_hcd___11 *);
	void (*relinquish_port)(struct usb_hcd___11 *, int);
	int (*port_handed_over)(struct usb_hcd___11 *, int);
	void (*clear_tt_buffer_complete)(struct usb_hcd___11 *, struct usb_host_endpoint *);
	int (*alloc_dev)(struct usb_hcd___11 *, struct usb_device___15 *);
	void (*free_dev)(struct usb_hcd___11 *, struct usb_device___15 *);
	int (*alloc_streams)(struct usb_hcd___11 *, struct usb_device___15 *, struct usb_host_endpoint **, unsigned int, unsigned int, gfp_t);
	int (*free_streams)(struct usb_hcd___11 *, struct usb_device___15 *, struct usb_host_endpoint **, unsigned int, gfp_t);
	int (*add_endpoint)(struct usb_hcd___11 *, struct usb_device___15 *, struct usb_host_endpoint *);
	int (*drop_endpoint)(struct usb_hcd___11 *, struct usb_device___15 *, struct usb_host_endpoint *);
	int (*check_bandwidth)(struct usb_hcd___11 *, struct usb_device___15 *);
	void (*reset_bandwidth)(struct usb_hcd___11 *, struct usb_device___15 *);
	int (*address_device)(struct usb_hcd___11 *, struct usb_device___15 *);
	int (*enable_device)(struct usb_hcd___11 *, struct usb_device___15 *);
	int (*update_hub_device)(struct usb_hcd___11 *, struct usb_device___15 *, struct usb_tt___12 *, gfp_t);
	int (*reset_device)(struct usb_hcd___11 *, struct usb_device___15 *);
	int (*update_device)(struct usb_hcd___11 *, struct usb_device___15 *);
	int (*set_usb2_hw_lpm)(struct usb_hcd___11 *, struct usb_device___15 *, int);
	int (*enable_usb3_lpm_timeout)(struct usb_hcd___11 *, struct usb_device___15 *, enum usb3_link_state);
	int (*disable_usb3_lpm_timeout)(struct usb_hcd___11 *, struct usb_device___15 *, enum usb3_link_state);
	int (*find_raw_port_number)(struct usb_hcd___11 *, int);
	int (*port_power)(struct usb_hcd___11 *, int, bool);
};

struct usb_mon_operations___12 {
	void (*urb_submit)(struct usb_bus___15 *, struct urb___14 *);
	void (*urb_submit_error)(struct usb_bus___15 *, struct urb___14 *, int);
	void (*urb_complete)(struct usb_bus___15 *, struct urb___14 *, int);
};

struct xhci_hcd___3;

struct xhci_virt_ep___3 {
	struct xhci_ring *ring;
	struct xhci_stream_info *stream_info;
	struct xhci_ring *new_ring;
	unsigned int ep_state;
	struct list_head cancelled_td_list;
	struct timer_list stop_cmd_timer;
	struct xhci_hcd___3 *xhci;
	struct xhci_segment *queued_deq_seg;
	union xhci_trb *queued_deq_ptr;
	bool skip;
	struct xhci_bw_info bw_info;
	struct list_head bw_endpoint_list;
	int next_frame_id;
	bool use_extended_tbc;
};

struct xhci_port___3;

struct xhci_hub___3 {
	struct xhci_port___3 **ports;
	unsigned int num_ports;
	struct usb_hcd___11 *hcd;
	u8 maj_rev;
	u8 min_rev;
	u32 *psi;
	u8 psi_count;
	u8 psi_uid_count;
};

struct xhci_virt_device___3;

struct xhci_hcd___3 {
	struct usb_hcd___11 *main_hcd;
	struct usb_hcd___11 *shared_hcd;
	struct xhci_cap_regs *cap_regs;
	struct xhci_op_regs *op_regs;
	struct xhci_run_regs *run_regs;
	struct xhci_doorbell_array *dba;
	struct xhci_intr_reg *ir_set;
	__u32 hcs_params1;
	__u32 hcs_params2;
	__u32 hcs_params3;
	__u32 hcc_params;
	__u32 hcc_params2;
	spinlock_t lock;
	u8 sbrn;
	u16 hci_version;
	u8 max_slots;
	u8 max_interrupters;
	u8 max_ports;
	u8 isoc_threshold;
	u32 imod_interval;
	int event_ring_max;
	int page_size;
	int page_shift;
	int msix_count;
	struct clk *clk;
	struct clk *reg_clk;
	struct xhci_device_context_array *dcbaa;
	struct xhci_ring *cmd_ring;
	unsigned int cmd_ring_state;
	struct list_head cmd_list;
	unsigned int cmd_ring_reserved_trbs;
	struct delayed_work cmd_timer;
	struct completion cmd_ring_stop_completion;
	struct xhci_command *current_cmd;
	struct xhci_ring *event_ring;
	struct xhci_erst erst;
	struct xhci_scratchpad *scratchpad;
	struct list_head lpm_failed_devs;
	struct mutex mutex;
	struct xhci_command *lpm_command;
	struct xhci_virt_device___3 *devs[256];
	struct xhci_root_port_bw_info *rh_bw;
	struct dma_pool___2 *device_pool;
	struct dma_pool___2 *segment_pool;
	struct dma_pool___2 *small_streams_pool;
	struct dma_pool___2 *medium_streams_pool;
	unsigned int xhc_state;
	u32 command;
	struct s3_save s3;
	long long unsigned int quirks;
	unsigned int num_active_eps;
	unsigned int limit_active_eps;
	struct xhci_bus_state bus_state[2];
	struct xhci_port___3 *hw_ports;
	struct xhci_hub___3 usb2_rhub;
	struct xhci_hub___3 usb3_rhub;
	unsigned int sw_lpm_support: 1;
	unsigned int hw_lpm_support: 1;
	u32 *ext_caps;
	unsigned int num_ext_caps;
	struct timer_list comp_mode_recovery_timer;
	u32 port_status_u0;
	u16 test_mode;
	struct dentry___294 *debugfs_root;
	struct dentry___294 *debugfs_slots;
	struct list_head regset_list;
	void *dbc;
	long unsigned int priv[0];
};

struct xhci_virt_device___3 {
	struct usb_device___15 *udev;
	struct xhci_container_ctx *out_ctx;
	struct xhci_container_ctx *in_ctx;
	struct xhci_virt_ep___3 eps[31];
	u8 fake_port;
	u8 real_port;
	struct xhci_interval_bw_table *bw_table;
	struct xhci_tt_bw_info *tt_info;
	u16 current_mel;
	void *debugfs_private;
};

enum xhci_ep_reset_type {
	EP_HARD_RESET = 0,
	EP_SOFT_RESET = 1,
};

struct xhci_td___3 {
	struct list_head td_list;
	struct list_head cancelled_td_list;
	struct urb___14 *urb;
	struct xhci_segment *start_seg;
	union xhci_trb *first_trb;
	union xhci_trb *last_trb;
	struct xhci_segment *bounce_seg;
	bool urb_length_set;
};

struct urb_priv___5 {
	int num_tds;
	int num_tds_done;
	struct xhci_td___3 td[0];
};

struct xhci_port___3 {
	__le32 *addr;
	int hw_portnum;
	int hcd_portnum;
	struct xhci_hub___3 *rhub;
};

struct module___313;

struct file___383;

struct kiocb___383;

struct poll_table_struct___231;

struct vm_area_struct___384;

struct inode___383;

struct file_lock___383;

struct page___384;

struct seq_file___325;

struct file_operations___383 {
	struct module___313 *owner;
	loff_t (*llseek)(struct file___383 *, loff_t, int);
	ssize_t (*read)(struct file___383 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___383 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___383 *, struct iov_iter___2 *);
	ssize_t (*write_iter)(struct kiocb___383 *, struct iov_iter___2 *);
	int (*iopoll)(struct kiocb___383 *, bool);
	int (*iterate)(struct file___383 *, struct dir_context *);
	int (*iterate_shared)(struct file___383 *, struct dir_context *);
	__poll_t (*poll)(struct file___383 *, struct poll_table_struct___231 *);
	long int (*unlocked_ioctl)(struct file___383 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___383 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___383 *, struct vm_area_struct___384 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___383 *, struct file___383 *);
	int (*flush)(struct file___383 *, fl_owner_t);
	int (*release)(struct inode___383 *, struct file___383 *);
	int (*fsync)(struct file___383 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___383 *, int);
	int (*lock)(struct file___383 *, int, struct file_lock___383 *);
	ssize_t (*sendpage)(struct file___383 *, struct page___384 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___383 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___383 *, int, struct file_lock___383 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___383 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___383 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___383 *, long int, struct file_lock___383 **, void **);
	long int (*fallocate)(struct file___383 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___325 *, struct file___383 *);
	ssize_t (*copy_file_range)(struct file___383 *, loff_t, struct file___383 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___383 *, loff_t, struct file___383 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___383 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___383 {
	u64 seqnum;
	struct vm_area_struct___384 *vmas[4];
};

struct page_frag___383 {
	struct page___384 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___144;

struct debug_info___144 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___144 *hbp_break[16];
	struct perf_event___144 *hbp_watch[16];
};

struct thread_struct___144 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___144 debug;
	long: 64;
};

struct mm_struct___383;

struct pid___220;

struct cred___352;

struct nsproxy___281;

struct signal_struct___262;

struct css_set___236;

struct perf_event_context___144;

struct vm_struct___289;

struct task_struct___384 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___384 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___383 *mm;
	struct mm_struct___383 *active_mm;
	struct vmacache___383 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___384 *real_parent;
	struct task_struct___384 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___384 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___220 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___220 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___220 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___352 *ptracer_cred;
	const struct cred___352 *real_cred;
	const struct cred___352 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___281 *nsproxy;
	struct signal_struct___262 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___384 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___107 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___236 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___144 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___383 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___384 *oom_reaper_list;
	struct vm_struct___289 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___144 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct secondary_data___384 {
	void *stack;
	struct task_struct___384 *task;
	long int status;
};

struct hw_perf_event___144 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___384 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___144)(struct perf_event___144 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___144;

struct fasync_struct___382;

struct pid_namespace___220;

struct trace_event_call___137;

struct perf_cgroup___144;

struct perf_event___144 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___144 *group_leader;
	struct pmu___144 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___144 hw;
	struct perf_event_context___144 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___144 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___384 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___382 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___144 *);
	struct callback_head callback_head;
	struct pid_namespace___220 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___144 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___144 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___137 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___144 *cgrp;
	struct list_head sb_list;
};

struct kset___369;

struct kobj_type___369;

struct kernfs_node___377;

struct kobject___370 {
	const char *name;
	struct list_head entry;
	struct kobject___370 *parent;
	struct kset___369 *kset;
	struct kobj_type___369 *ktype;
	struct kernfs_node___377 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___310 {
	struct kobject___370 kobj;
	struct module___313 *mod;
	struct kobject___370 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___310 {
	struct module___313 *mod;
	struct latch_tree_node node;
};

struct module_layout___310 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___310 mtn;
};

struct module_attribute___310;

struct kernel_param___310;

struct module___313 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___310 mkobj;
	struct module_attribute___310 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___370 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___310 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___310 core_layout;
	struct module_layout___310 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___137 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide21;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___384 *pgtable_t___383;

struct address_space___382;

struct dev_pagemap___371;

struct page___384 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___382 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___384 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___383 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___383 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___371 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___383;

struct lruvec___383 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___383 *pgdat;
};

struct zone___383 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___383 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___383 {
	struct zone___383 *zone;
	int zone_idx;
};

struct zonelist___383 {
	struct zoneref___383 _zonerefs[25];
};

struct pglist_data___383 {
	struct zone___383 node_zones[3];
	struct zonelist___383 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___384 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___384 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___383 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___384 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___384 *owner;
};

struct blocking_notifier_head___383 {
	struct rw_semaphore___384 rwsem;
	struct notifier_block *head;
};

struct key___352;

struct ucounts___252;

struct user_namespace___252 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___252 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___9 ns;
	long unsigned int flags;
	struct key___352 *persistent_keyring_register;
	struct rw_semaphore___384 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___252 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_root___376;

struct kernfs_elem_dir___376 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___376 *root;
};

struct kernfs_syscall_ops___376;

struct kernfs_root___376 {
	struct kernfs_node___377 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___376 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___376 {
	struct kernfs_node___377 *target_kn;
};

struct kernfs_ops___376;

struct kernfs_elem_attr___376 {
	const struct kernfs_ops___376 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___377 *notify_next;
};

struct kernfs_node___377 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___377 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___376 dir;
		struct kernfs_elem_symlink___376 symlink;
		struct kernfs_elem_attr___376 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___376;

struct kernfs_ops___376 {
	int (*open)(struct kernfs_open_file___376 *);
	void (*release)(struct kernfs_open_file___376 *);
	int (*seq_show)(struct seq_file___325 *, void *);
	void * (*seq_start)(struct seq_file___325 *, loff_t *);
	void * (*seq_next)(struct seq_file___325 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___325 *, void *);
	ssize_t (*read)(struct kernfs_open_file___376 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___376 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___376 *, struct vm_area_struct___384 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___376 *, struct poll_table_struct___231 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___376 {
	int (*remount_fs)(struct kernfs_root___376 *, int *, char *);
	int (*show_options)(struct seq_file___325 *, struct kernfs_root___376 *);
	int (*mkdir)(struct kernfs_node___377 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___377 *);
	int (*rename)(struct kernfs_node___377 *, struct kernfs_node___377 *, const char *);
	int (*show_path)(struct seq_file___325 *, struct kernfs_node___377 *, struct kernfs_root___376 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___324;

struct seq_file___325 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___324 *op;
	int poll_event;
	const struct file___383 *file;
	void *private;
};

struct vm_operations_struct___371;

struct kernfs_open_file___376 {
	struct kernfs_node___377 *kn;
	struct file___383 *file;
	struct seq_file___325 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___371 *vm_ops;
};

struct dentry___382;

struct path___383 {
	struct vfsmount *mnt;
	struct dentry___382 *dentry;
};

struct fown_struct___220 {
	rwlock_t lock;
	struct pid___220 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___383 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___383 f_path;
	struct inode___383 *f_inode;
	const struct file_operations___383 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___220 f_owner;
	const struct cred___352 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___382 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___371;

struct vm_operations_struct___371 {
	void (*open)(struct vm_area_struct___384 *);
	void (*close)(struct vm_area_struct___384 *);
	int (*split)(struct vm_area_struct___384 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___384 *);
	vm_fault_t (*fault)(struct vm_fault___371 *);
	vm_fault_t (*huge_fault)(struct vm_fault___371 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___371 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___384 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___371 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___371 *);
	int (*access)(struct vm_area_struct___384 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___384 *);
	int (*set_policy)(struct vm_area_struct___384 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___384 *, long unsigned int);
	struct page___384 * (*find_special_page)(struct vm_area_struct___384 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___237)(struct file___383 *, wait_queue_head_t *, struct poll_table_struct___231 *);

struct poll_table_struct___231 {
	poll_queue_proc___237 _qproc;
	__poll_t _key;
};

struct vm_area_struct___384 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___384 *vm_next;
	struct vm_area_struct___384 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___383 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___371 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___383 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___346;

struct attribute_group___347 {
	const char *name;
	umode_t (*is_visible)(struct kobject___370 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___370 *, struct bin_attribute___346 *, int);
	struct attribute **attrs;
	struct bin_attribute___346 **bin_attrs;
};

struct bin_attribute___346 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___383 *, struct kobject___370 *, struct bin_attribute___346 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___383 *, struct kobject___370 *, struct bin_attribute___346 *, char *, loff_t, size_t);
	int (*mmap)(struct file___383 *, struct kobject___370 *, struct bin_attribute___346 *, struct vm_area_struct___384 *);
};

struct sysfs_ops___369 {
	ssize_t (*show)(struct kobject___370 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___370 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___369;

struct kset___369 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___370 kobj;
	const struct kset_uevent_ops___369 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___369 {
	void (*release)(struct kobject___370 *);
	const struct sysfs_ops___369 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___29 * (*child_ns_type)(struct kobject___370 *);
	const void * (*namespace)(struct kobject___370 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___369 {
	int (* const filter)(struct kset___369 *, struct kobject___370 *);
	const char * (* const name)(struct kset___369 *, struct kobject___370 *);
	int (* const uevent)(struct kset___369 *, struct kobject___370 *, struct kobj_uevent_env *);
};

struct kobj_attribute___361 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___370 *, struct kobj_attribute___361 *, char *);
	ssize_t (*store)(struct kobject___370 *, struct kobj_attribute___361 *, const char *, size_t);
};

struct device___350;

struct dev_pm_ops___350 {
	int (*prepare)(struct device___350 *);
	void (*complete)(struct device___350 *);
	int (*suspend)(struct device___350 *);
	int (*resume)(struct device___350 *);
	int (*freeze)(struct device___350 *);
	int (*thaw)(struct device___350 *);
	int (*poweroff)(struct device___350 *);
	int (*restore)(struct device___350 *);
	int (*suspend_late)(struct device___350 *);
	int (*resume_early)(struct device___350 *);
	int (*freeze_late)(struct device___350 *);
	int (*thaw_early)(struct device___350 *);
	int (*poweroff_late)(struct device___350 *);
	int (*restore_early)(struct device___350 *);
	int (*suspend_noirq)(struct device___350 *);
	int (*resume_noirq)(struct device___350 *);
	int (*freeze_noirq)(struct device___350 *);
	int (*thaw_noirq)(struct device___350 *);
	int (*poweroff_noirq)(struct device___350 *);
	int (*restore_noirq)(struct device___350 *);
	int (*runtime_suspend)(struct device___350 *);
	int (*runtime_resume)(struct device___350 *);
	int (*runtime_idle)(struct device___350 *);
};

struct dev_pm_info___350 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___6 *subsys_data;
	void (*set_latency_tolerance)(struct device___350 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___350;

struct bus_type___350;

struct device_driver___350;

struct dev_pm_domain___350;

struct fwnode_handle___272;

struct class___350;

struct device___350 {
	struct device___350 *parent;
	struct device_private *p;
	struct kobject___370 kobj;
	const char *init_name;
	const struct device_type___350 *type;
	struct mutex mutex;
	struct bus_type___350 *bus;
	struct device_driver___350 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___350 power;
	struct dev_pm_domain___350 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___272 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___350 *class;
	const struct attribute_group___347 **groups;
	void (*release)(struct device___350 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___350 {
	struct dev_pm_ops___350 ops;
	void (*detach)(struct device___350 *, bool);
	int (*activate)(struct device___350 *);
	void (*sync)(struct device___350 *);
	void (*dismiss)(struct device___350 *);
};

struct upid___220 {
	int nr;
	struct pid_namespace___220 *ns;
};

struct pid_namespace___220 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___384 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___220 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___382 *proc_self;
	struct dentry___382 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___252 *user_ns;
	struct ucounts___252 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___9 ns;
};

struct pid___220 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___220 numbers[1];
};

struct user_struct___352 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___352 *uid_keyring;
	struct key___352 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___383;

struct mm_struct___383 {
	struct {
		struct vm_area_struct___384 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___383 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___384 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___383 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___384 *owner;
		struct user_namespace___252 *user_ns;
		struct file___383 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___383 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___352 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___352 *session_keyring;
	struct key___352 *process_keyring;
	struct key___352 *thread_keyring;
	struct key___352 *request_key_auth;
	void *security;
	struct user_struct___352 *user;
	struct user_namespace___252 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___236;

struct nsproxy___281 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___220 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___236 *cgroup_ns;
};

struct tty_struct___37;

struct signal_struct___262 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___384 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___384 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___220 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___220 *tty_old_pgrp;
	int leader;
	struct tty_struct___37 *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___383 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___220 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___236;

struct cgroup___236;

struct css_set___236 {
	struct cgroup_subsys_state___236 *subsys[13];
	refcount_t refcount;
	struct css_set___236 *dom_cset;
	struct cgroup___236 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___236 *mg_src_cgrp;
	struct cgroup___236 *mg_dst_cgrp;
	struct css_set___236 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___144 {
	struct pmu___144 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___384 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___144 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___289 {
	struct vm_struct___289 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___384 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___274 {
	struct task_struct___384 task;
	long unsigned int stack[8192];
};

struct bus_type___350 {
	const char *name;
	const char *dev_name;
	struct device___350 *dev_root;
	const struct attribute_group___347 **bus_groups;
	const struct attribute_group___347 **dev_groups;
	const struct attribute_group___347 **drv_groups;
	int (*match)(struct device___350 *, struct device_driver___350 *);
	int (*uevent)(struct device___350 *, struct kobj_uevent_env *);
	int (*probe)(struct device___350 *);
	int (*remove)(struct device___350 *);
	void (*shutdown)(struct device___350 *);
	int (*online)(struct device___350 *);
	int (*offline)(struct device___350 *);
	int (*suspend)(struct device___350 *, pm_message_t);
	int (*resume)(struct device___350 *);
	int (*num_vf)(struct device___350 *);
	int (*dma_configure)(struct device___350 *);
	const struct dev_pm_ops___350 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___350 {
	const char *name;
	struct bus_type___350 *bus;
	struct module___313 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___350 *);
	int (*remove)(struct device___350 *);
	void (*shutdown)(struct device___350 *);
	int (*suspend)(struct device___350 *, pm_message_t);
	int (*resume)(struct device___350 *);
	const struct attribute_group___347 **groups;
	const struct dev_pm_ops___350 *pm;
	void (*coredump)(struct device___350 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___350 {
	const char *name;
	const struct attribute_group___347 **groups;
	int (*uevent)(struct device___350 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___350 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___350 *);
	const struct dev_pm_ops___350 *pm;
};

struct class___350 {
	const char *name;
	struct module___313 *owner;
	const struct attribute_group___347 **class_groups;
	const struct attribute_group___347 **dev_groups;
	struct kobject___370 *dev_kobj;
	int (*dev_uevent)(struct device___350 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___350 *, umode_t *);
	void (*class_release)(struct class___350 *);
	void (*dev_release)(struct device___350 *);
	int (*shutdown_pre)(struct device___350 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___350 *);
	const struct dev_pm_ops___350 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct fwnode_operations___272;

struct fwnode_handle___272 {
	struct fwnode_handle___272 *secondary;
	const struct fwnode_operations___272 *ops;
};

struct dentry_operations___382;

struct super_block___382;

struct dentry___382 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___382 *d_parent;
	struct qstr d_name;
	struct inode___383 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___382 *d_op;
	struct super_block___382 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___382;

struct address_space___382 {
	struct inode___383 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___384 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___382 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___382;

struct block_device___382;

struct cdev___95;

struct inode___383 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___382 *i_op;
	struct super_block___382 *i_sb;
	struct address_space___382 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___384 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___383 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___382 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___382 *i_bdev;
		struct cdev___95 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___382 {
	int (*d_revalidate)(struct dentry___382 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___382 *, unsigned int);
	int (*d_hash)(const struct dentry___382 *, struct qstr *);
	int (*d_compare)(const struct dentry___382 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___382 *);
	int (*d_init)(struct dentry___382 *);
	void (*d_release)(struct dentry___382 *);
	void (*d_prune)(struct dentry___382 *);
	void (*d_iput)(struct dentry___382 *, struct inode___383 *);
	char * (*d_dname)(struct dentry___382 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___383 *);
	int (*d_manage)(const struct path___383 *, bool);
	struct dentry___382 * (*d_real)(struct dentry___382 *, const struct inode___383 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___382;

struct mem_dqinfo___382 {
	struct quota_format_type___382 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___382;

struct quota_info___382 {
	unsigned int flags;
	struct rw_semaphore___384 dqio_sem;
	struct inode___383 *files[3];
	struct mem_dqinfo___382 info[3];
	const struct quota_format_ops___382 *ops[3];
};

struct rcuwait___382 {
	struct task_struct___384 *task;
};

struct percpu_rw_semaphore___382 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___384 rw_sem;
	struct rcuwait___382 writer;
	int readers_block;
};

struct sb_writers___382 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___382 rw_sem[3];
};

struct file_system_type___382;

struct super_operations___382;

struct dquot_operations___382;

struct quotactl_ops___382;

struct super_block___382 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___382 *s_type;
	const struct super_operations___382 *s_op;
	const struct dquot_operations___382 *dq_op;
	const struct quotactl_ops___382 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___382 *s_root;
	struct rw_semaphore___384 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___382 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___382 s_dquot;
	struct sb_writers___382 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___382 *s_d_op;
	int cleancache_poolid;
	struct shrinker___134 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___252 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

typedef int (*dev_page_fault_t___371)(struct vm_area_struct___384 *, long unsigned int, const struct page___384 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___371)(struct page___384 *, void *);

struct dev_pagemap___371 {
	dev_page_fault_t___371 page_fault;
	dev_page_free_t___371 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___350 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___383 {
	struct task_struct___384 *task;
	struct core_thread___383 *next;
};

struct core_state___383 {
	atomic_t nr_threads;
	struct core_thread___383 dumper;
	struct completion startup;
};

struct vm_fault___371 {
	struct vm_area_struct___384 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___384 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___384 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___383 prealloc_pte;
};

struct kiocb___383 {
	struct file___383 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___383 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___382 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___383 *ia_file;
};

struct dquot___382 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___382 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___382 {
	int qf_fmt_id;
	const struct quota_format_ops___382 *qf_ops;
	struct module___313 *qf_owner;
	struct quota_format_type___382 *qf_next;
};

struct quota_format_ops___382 {
	int (*check_quota_file)(struct super_block___382 *, int);
	int (*read_file_info)(struct super_block___382 *, int);
	int (*write_file_info)(struct super_block___382 *, int);
	int (*free_file_info)(struct super_block___382 *, int);
	int (*read_dqblk)(struct dquot___382 *);
	int (*commit_dqblk)(struct dquot___382 *);
	int (*release_dqblk)(struct dquot___382 *);
	int (*get_next_id)(struct super_block___382 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___382 {
	int (*write_dquot)(struct dquot___382 *);
	struct dquot___382 * (*alloc_dquot)(struct super_block___382 *, int);
	void (*destroy_dquot)(struct dquot___382 *);
	int (*acquire_dquot)(struct dquot___382 *);
	int (*release_dquot)(struct dquot___382 *);
	int (*mark_dirty)(struct dquot___382 *);
	int (*write_info)(struct super_block___382 *, int);
	qsize_t * (*get_reserved_space)(struct inode___383 *);
	int (*get_projid)(struct inode___383 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___383 *, qsize_t *);
	int (*get_next_id)(struct super_block___382 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___382 {
	int (*quota_on)(struct super_block___382 *, int, int, const struct path___383 *);
	int (*quota_off)(struct super_block___382 *, int);
	int (*quota_enable)(struct super_block___382 *, unsigned int);
	int (*quota_disable)(struct super_block___382 *, unsigned int);
	int (*quota_sync)(struct super_block___382 *, int);
	int (*set_info)(struct super_block___382 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___382 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___382 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___382 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___382 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___382 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___382 {
	int (*writepage)(struct page___384 *, struct writeback_control___3 *);
	int (*readpage)(struct file___383 *, struct page___384 *);
	int (*writepages)(struct address_space___382 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___384 *);
	int (*readpages)(struct file___383 *, struct address_space___382 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___383 *, struct address_space___382 *, loff_t, unsigned int, unsigned int, struct page___384 **, void **);
	int (*write_end)(struct file___383 *, struct address_space___382 *, loff_t, unsigned int, unsigned int, struct page___384 *, void *);
	sector_t (*bmap)(struct address_space___382 *, sector_t);
	void (*invalidatepage)(struct page___384 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___384 *, gfp_t);
	void (*freepage)(struct page___384 *);
	ssize_t (*direct_IO)(struct kiocb___383 *, struct iov_iter___2 *);
	int (*migratepage)(struct address_space___382 *, struct page___384 *, struct page___384 *, enum migrate_mode);
	bool (*isolate_page)(struct page___384 *, isolate_mode_t);
	void (*putback_page)(struct page___384 *);
	int (*launder_page)(struct page___384 *);
	int (*is_partially_uptodate)(struct page___384 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___384 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___382 *, struct page___384 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___383 *, sector_t *);
	void (*swap_deactivate)(struct file___383 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___382 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___383 *bd_inode;
	struct super_block___382 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___382 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___95 {
	struct kobject___370 kobj;
	struct module___313 *owner;
	const struct file_operations___383 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___382 {
	struct dentry___382 * (*lookup)(struct inode___383 *, struct dentry___382 *, unsigned int);
	const char * (*get_link)(struct dentry___382 *, struct inode___383 *, struct delayed_call *);
	int (*permission)(struct inode___383 *, int);
	struct posix_acl * (*get_acl)(struct inode___383 *, int);
	int (*readlink)(struct dentry___382 *, char *, int);
	int (*create)(struct inode___383 *, struct dentry___382 *, umode_t, bool);
	int (*link)(struct dentry___382 *, struct inode___383 *, struct dentry___382 *);
	int (*unlink)(struct inode___383 *, struct dentry___382 *);
	int (*symlink)(struct inode___383 *, struct dentry___382 *, const char *);
	int (*mkdir)(struct inode___383 *, struct dentry___382 *, umode_t);
	int (*rmdir)(struct inode___383 *, struct dentry___382 *);
	int (*mknod)(struct inode___383 *, struct dentry___382 *, umode_t, dev_t);
	int (*rename)(struct inode___383 *, struct dentry___382 *, struct inode___383 *, struct dentry___382 *, unsigned int);
	int (*setattr)(struct dentry___382 *, struct iattr___382 *);
	int (*getattr)(const struct path___383 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___382 *, char *, size_t);
	int (*fiemap)(struct inode___383 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___383 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___383 *, struct dentry___382 *, struct file___383 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___383 *, struct dentry___382 *, umode_t);
	int (*set_acl)(struct inode___383 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___382 {
	void (*fl_copy_lock)(struct file_lock___383 *, struct file_lock___383 *);
	void (*fl_release_private)(struct file_lock___383 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___382;

struct file_lock___383 {
	struct file_lock___383 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___383 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___382 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___382 *fl_ops;
	const struct lock_manager_operations___382 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___382 {
	int (*lm_compare_owner)(struct file_lock___383 *, struct file_lock___383 *);
	long unsigned int (*lm_owner_key)(struct file_lock___383 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___383 *);
	int (*lm_grant)(struct file_lock___383 *, int);
	bool (*lm_break)(struct file_lock___383 *);
	int (*lm_change)(struct file_lock___383 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___383 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___382 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___382 *fa_next;
	struct file___383 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___382 {
	const char *name;
	int fs_flags;
	struct dentry___382 * (*mount)(struct file_system_type___382 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___382 *);
	struct module___313 *owner;
	struct file_system_type___382 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___382 {
	struct inode___383 * (*alloc_inode)(struct super_block___382 *);
	void (*destroy_inode)(struct inode___383 *);
	void (*dirty_inode)(struct inode___383 *, int);
	int (*write_inode)(struct inode___383 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___383 *);
	void (*evict_inode)(struct inode___383 *);
	void (*put_super)(struct super_block___382 *);
	int (*sync_fs)(struct super_block___382 *, int);
	int (*freeze_super)(struct super_block___382 *);
	int (*freeze_fs)(struct super_block___382 *);
	int (*thaw_super)(struct super_block___382 *);
	int (*unfreeze_fs)(struct super_block___382 *);
	int (*statfs)(struct dentry___382 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___382 *, int *, char *);
	void (*umount_begin)(struct super_block___382 *);
	int (*show_options)(struct seq_file___325 *, struct dentry___382 *);
	int (*show_devname)(struct seq_file___325 *, struct dentry___382 *);
	int (*show_path)(struct seq_file___325 *, struct dentry___382 *);
	int (*show_stats)(struct seq_file___325 *, struct dentry___382 *);
	ssize_t (*quota_read)(struct super_block___382 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___382 *, int, const char *, size_t, loff_t);
	struct dquot___382 ** (*get_dquots)(struct inode___383 *);
	int (*bdev_try_to_free_page)(struct super_block___382 *, struct page___384 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___382 *, struct shrink_control___134 *);
	long int (*free_cached_objects)(struct super_block___382 *, struct shrink_control___134 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct usb_interface___15 {
	struct usb_host_interface *altsetting;
	struct usb_host_interface *cur_altsetting;
	unsigned int num_altsetting;
	struct usb_interface_assoc_descriptor *intf_assoc;
	int minor;
	enum usb_interface_condition condition;
	unsigned int sysfs_files_created: 1;
	unsigned int ep_devs_created: 1;
	unsigned int unregistering: 1;
	unsigned int needs_remote_wakeup: 1;
	unsigned int needs_altsetting0: 1;
	unsigned int needs_binding: 1;
	unsigned int resetting_device: 1;
	unsigned int authorized: 1;
	struct device___350 dev;
	struct device___350 *usb_dev;
	atomic_t pm_usage_cnt;
	struct work_struct reset_ws;
};

struct usb_host_config___15 {
	struct usb_config_descriptor desc;
	char *string;
	struct usb_interface_assoc_descriptor *intf_assoc[16];
	struct usb_interface___15 *interface[32];
	struct usb_interface_cache *intf_cache[32];
	unsigned char *extra;
	int extralen;
};

struct usb_device___16;

struct usb_bus___16 {
	struct device___350 *controller;
	struct device___350 *sysdev;
	int busnum;
	const char *bus_name;
	u8 uses_dma;
	u8 uses_pio_for_control;
	u8 otg_port;
	unsigned int is_b_host: 1;
	unsigned int b_hnp_enable: 1;
	unsigned int no_stop_on_short: 1;
	unsigned int no_sg_constraint: 1;
	unsigned int sg_tablesize;
	int devnum_next;
	struct mutex devnum_next_mutex;
	struct usb_devmap devmap;
	struct usb_device___16 *root_hub;
	struct usb_bus___16 *hs_companion;
	int bandwidth_allocated;
	int bandwidth_int_reqs;
	int bandwidth_isoc_reqs;
	unsigned int resuming_ports;
	struct mon_bus *mon_bus;
	int monitored;
};

struct usb_tt___13;

struct usb_device___16 {
	int devnum;
	char devpath[16];
	u32 route;
	enum usb_device_state state;
	enum usb_device_speed speed;
	unsigned int rx_lanes;
	unsigned int tx_lanes;
	struct usb_tt___13 *tt;
	int ttport;
	unsigned int toggle[2];
	struct usb_device___16 *parent;
	struct usb_bus___16 *bus;
	struct usb_host_endpoint ep0;
	struct device___350 dev;
	struct usb_device_descriptor descriptor;
	struct usb_host_bos *bos;
	struct usb_host_config___15 *config;
	struct usb_host_config___15 *actconfig;
	struct usb_host_endpoint *ep_in[16];
	struct usb_host_endpoint *ep_out[16];
	char **rawdescriptors;
	short unsigned int bus_mA;
	u8 portnum;
	u8 level;
	unsigned int can_submit: 1;
	unsigned int persist_enabled: 1;
	unsigned int have_langid: 1;
	unsigned int authorized: 1;
	unsigned int authenticated: 1;
	unsigned int wusb: 1;
	unsigned int lpm_capable: 1;
	unsigned int usb2_hw_lpm_capable: 1;
	unsigned int usb2_hw_lpm_besl_capable: 1;
	unsigned int usb2_hw_lpm_enabled: 1;
	unsigned int usb2_hw_lpm_allowed: 1;
	unsigned int usb3_lpm_u1_enabled: 1;
	unsigned int usb3_lpm_u2_enabled: 1;
	int string_langid;
	char *product;
	char *manufacturer;
	char *serial;
	struct list_head filelist;
	int maxchild;
	u32 quirks;
	atomic_t urbnum;
	long unsigned int active_duration;
	long unsigned int connect_time;
	unsigned int do_remote_wakeup: 1;
	unsigned int reset_resume: 1;
	unsigned int port_is_suspended: 1;
	struct wusb_dev *wusb_dev;
	int slot_id;
	enum usb_device_removable removable;
	struct usb2_lpm_parameters l1_params;
	struct usb3_lpm_parameters u1_params;
	struct usb3_lpm_parameters u2_params;
	unsigned int lpm_disable_count;
	u16 hub_delay;
};

struct usb_tt___13 {
	struct usb_device___16 *hub;
	int multi;
	unsigned int think_time;
	void *hcpriv;
	spinlock_t lock;
	struct list_head clear_list;
	struct work_struct clear_work;
};

struct urb___15;

typedef void (*usb_complete_t___15)(struct urb___15 *);

struct urb___15 {
	struct kref kref;
	void *hcpriv;
	atomic_t use_count;
	atomic_t reject;
	int unlinked;
	struct list_head urb_list;
	struct list_head anchor_list;
	struct usb_anchor *anchor;
	struct usb_device___16 *dev;
	struct usb_host_endpoint *ep;
	unsigned int pipe;
	unsigned int stream_id;
	int status;
	unsigned int transfer_flags;
	void *transfer_buffer;
	dma_addr_t transfer_dma;
	struct scatterlist *sg;
	int num_mapped_sgs;
	int num_sgs;
	u32 transfer_buffer_length;
	u32 actual_length;
	unsigned char *setup_packet;
	dma_addr_t setup_dma;
	int start_frame;
	int number_of_packets;
	int interval;
	int error_count;
	void *context;
	usb_complete_t___15 complete;
	struct usb_iso_packet_descriptor iso_frame_desc[0];
};

struct hc_driver___12;

struct usb_hcd___12 {
	struct usb_bus___16 self;
	struct kref kref;
	const char *product_desc;
	int speed;
	char irq_descr[24];
	struct timer_list rh_timer;
	struct urb___15 *status_urb;
	struct work_struct wakeup_work;
	const struct hc_driver___12 *driver;
	struct usb_phy___3 *usb_phy;
	struct usb_phy_roothub *phy_roothub;
	long unsigned int flags;
	unsigned int rh_registered: 1;
	unsigned int rh_pollable: 1;
	unsigned int msix_enabled: 1;
	unsigned int msi_enabled: 1;
	unsigned int skip_phy_initialization: 1;
	unsigned int uses_new_polling: 1;
	unsigned int wireless: 1;
	unsigned int has_tt: 1;
	unsigned int amd_resume_bug: 1;
	unsigned int can_do_streams: 1;
	unsigned int tpl_support: 1;
	unsigned int cant_recv_wakeups: 1;
	unsigned int irq;
	void *regs;
	resource_size_t rsrc_start;
	resource_size_t rsrc_len;
	unsigned int power_budget;
	struct giveback_urb_bh high_prio_bh;
	struct giveback_urb_bh low_prio_bh;
	struct mutex *address0_mutex;
	struct mutex *bandwidth_mutex;
	struct usb_hcd___12 *shared_hcd;
	struct usb_hcd___12 *primary_hcd;
	struct dma_pool___2 *pool[4];
	int state;
	long unsigned int hcd_priv[0];
};

struct hc_driver___12 {
	const char *description;
	const char *product_desc;
	size_t hcd_priv_size;
	irqreturn_t (*irq)(struct usb_hcd___12 *);
	int flags;
	int (*reset)(struct usb_hcd___12 *);
	int (*start)(struct usb_hcd___12 *);
	int (*pci_suspend)(struct usb_hcd___12 *, bool);
	int (*pci_resume)(struct usb_hcd___12 *, bool);
	void (*stop)(struct usb_hcd___12 *);
	void (*shutdown)(struct usb_hcd___12 *);
	int (*get_frame_number)(struct usb_hcd___12 *);
	int (*urb_enqueue)(struct usb_hcd___12 *, struct urb___15 *, gfp_t);
	int (*urb_dequeue)(struct usb_hcd___12 *, struct urb___15 *, int);
	int (*map_urb_for_dma)(struct usb_hcd___12 *, struct urb___15 *, gfp_t);
	void (*unmap_urb_for_dma)(struct usb_hcd___12 *, struct urb___15 *);
	void (*endpoint_disable)(struct usb_hcd___12 *, struct usb_host_endpoint *);
	void (*endpoint_reset)(struct usb_hcd___12 *, struct usb_host_endpoint *);
	int (*hub_status_data)(struct usb_hcd___12 *, char *);
	int (*hub_control)(struct usb_hcd___12 *, u16, u16, u16, char *, u16);
	int (*bus_suspend)(struct usb_hcd___12 *);
	int (*bus_resume)(struct usb_hcd___12 *);
	int (*start_port_reset)(struct usb_hcd___12 *, unsigned int);
	long unsigned int (*get_resuming_ports)(struct usb_hcd___12 *);
	void (*relinquish_port)(struct usb_hcd___12 *, int);
	int (*port_handed_over)(struct usb_hcd___12 *, int);
	void (*clear_tt_buffer_complete)(struct usb_hcd___12 *, struct usb_host_endpoint *);
	int (*alloc_dev)(struct usb_hcd___12 *, struct usb_device___16 *);
	void (*free_dev)(struct usb_hcd___12 *, struct usb_device___16 *);
	int (*alloc_streams)(struct usb_hcd___12 *, struct usb_device___16 *, struct usb_host_endpoint **, unsigned int, unsigned int, gfp_t);
	int (*free_streams)(struct usb_hcd___12 *, struct usb_device___16 *, struct usb_host_endpoint **, unsigned int, gfp_t);
	int (*add_endpoint)(struct usb_hcd___12 *, struct usb_device___16 *, struct usb_host_endpoint *);
	int (*drop_endpoint)(struct usb_hcd___12 *, struct usb_device___16 *, struct usb_host_endpoint *);
	int (*check_bandwidth)(struct usb_hcd___12 *, struct usb_device___16 *);
	void (*reset_bandwidth)(struct usb_hcd___12 *, struct usb_device___16 *);
	int (*address_device)(struct usb_hcd___12 *, struct usb_device___16 *);
	int (*enable_device)(struct usb_hcd___12 *, struct usb_device___16 *);
	int (*update_hub_device)(struct usb_hcd___12 *, struct usb_device___16 *, struct usb_tt___13 *, gfp_t);
	int (*reset_device)(struct usb_hcd___12 *, struct usb_device___16 *);
	int (*update_device)(struct usb_hcd___12 *, struct usb_device___16 *);
	int (*set_usb2_hw_lpm)(struct usb_hcd___12 *, struct usb_device___16 *, int);
	int (*enable_usb3_lpm_timeout)(struct usb_hcd___12 *, struct usb_device___16 *, enum usb3_link_state);
	int (*disable_usb3_lpm_timeout)(struct usb_hcd___12 *, struct usb_device___16 *, enum usb3_link_state);
	int (*find_raw_port_number)(struct usb_hcd___12 *, int);
	int (*port_power)(struct usb_hcd___12 *, int, bool);
};

struct usb_mon_operations___13 {
	void (*urb_submit)(struct usb_bus___16 *, struct urb___15 *);
	void (*urb_submit_error)(struct usb_bus___16 *, struct urb___15 *, int);
	void (*urb_complete)(struct usb_bus___16 *, struct urb___15 *, int);
};

struct fwnode_reference_args___272;

struct fwnode_endpoint___272;

struct fwnode_operations___272 {
	struct fwnode_handle___272 * (*get)(struct fwnode_handle___272 *);
	void (*put)(struct fwnode_handle___272 *);
	bool (*device_is_available)(const struct fwnode_handle___272 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___272 *, const struct device___350 *);
	bool (*property_present)(const struct fwnode_handle___272 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___272 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___272 *, const char *, const char **, size_t);
	struct fwnode_handle___272 * (*get_parent)(const struct fwnode_handle___272 *);
	struct fwnode_handle___272 * (*get_next_child_node)(const struct fwnode_handle___272 *, struct fwnode_handle___272 *);
	struct fwnode_handle___272 * (*get_named_child_node)(const struct fwnode_handle___272 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___272 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___272 *);
	struct fwnode_handle___272 * (*graph_get_next_endpoint)(const struct fwnode_handle___272 *, struct fwnode_handle___272 *);
	struct fwnode_handle___272 * (*graph_get_remote_endpoint)(const struct fwnode_handle___272 *);
	struct fwnode_handle___272 * (*graph_get_port_parent)(struct fwnode_handle___272 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___272 *, struct fwnode_endpoint___272 *);
};

struct fwnode_endpoint___272 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___272 *local_fwnode;
};

struct fwnode_reference_args___272 {
	struct fwnode_handle___272 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct xhci_hcd___4;

struct xhci_virt_ep___4 {
	struct xhci_ring *ring;
	struct xhci_stream_info *stream_info;
	struct xhci_ring *new_ring;
	unsigned int ep_state;
	struct list_head cancelled_td_list;
	struct timer_list stop_cmd_timer;
	struct xhci_hcd___4 *xhci;
	struct xhci_segment *queued_deq_seg;
	union xhci_trb *queued_deq_ptr;
	bool skip;
	struct xhci_bw_info bw_info;
	struct list_head bw_endpoint_list;
	int next_frame_id;
	bool use_extended_tbc;
};

struct xhci_port___4;

struct xhci_hub___4 {
	struct xhci_port___4 **ports;
	unsigned int num_ports;
	struct usb_hcd___12 *hcd;
	u8 maj_rev;
	u8 min_rev;
	u32 *psi;
	u8 psi_count;
	u8 psi_uid_count;
};

struct xhci_virt_device___4;

struct xhci_hcd___4 {
	struct usb_hcd___12 *main_hcd;
	struct usb_hcd___12 *shared_hcd;
	struct xhci_cap_regs *cap_regs;
	struct xhci_op_regs *op_regs;
	struct xhci_run_regs *run_regs;
	struct xhci_doorbell_array *dba;
	struct xhci_intr_reg *ir_set;
	__u32 hcs_params1;
	__u32 hcs_params2;
	__u32 hcs_params3;
	__u32 hcc_params;
	__u32 hcc_params2;
	spinlock_t lock;
	u8 sbrn;
	u16 hci_version;
	u8 max_slots;
	u8 max_interrupters;
	u8 max_ports;
	u8 isoc_threshold;
	u32 imod_interval;
	int event_ring_max;
	int page_size;
	int page_shift;
	int msix_count;
	struct clk *clk;
	struct clk *reg_clk;
	struct xhci_device_context_array *dcbaa;
	struct xhci_ring *cmd_ring;
	unsigned int cmd_ring_state;
	struct list_head cmd_list;
	unsigned int cmd_ring_reserved_trbs;
	struct delayed_work cmd_timer;
	struct completion cmd_ring_stop_completion;
	struct xhci_command *current_cmd;
	struct xhci_ring *event_ring;
	struct xhci_erst erst;
	struct xhci_scratchpad *scratchpad;
	struct list_head lpm_failed_devs;
	struct mutex mutex;
	struct xhci_command *lpm_command;
	struct xhci_virt_device___4 *devs[256];
	struct xhci_root_port_bw_info *rh_bw;
	struct dma_pool___2 *device_pool;
	struct dma_pool___2 *segment_pool;
	struct dma_pool___2 *small_streams_pool;
	struct dma_pool___2 *medium_streams_pool;
	unsigned int xhc_state;
	u32 command;
	struct s3_save s3;
	long long unsigned int quirks;
	unsigned int num_active_eps;
	unsigned int limit_active_eps;
	struct xhci_bus_state bus_state[2];
	struct xhci_port___4 *hw_ports;
	struct xhci_hub___4 usb2_rhub;
	struct xhci_hub___4 usb3_rhub;
	unsigned int sw_lpm_support: 1;
	unsigned int hw_lpm_support: 1;
	u32 *ext_caps;
	unsigned int num_ext_caps;
	struct timer_list comp_mode_recovery_timer;
	u32 port_status_u0;
	u16 test_mode;
	struct dentry___382 *debugfs_root;
	struct dentry___382 *debugfs_slots;
	struct list_head regset_list;
	void *dbc;
	long unsigned int priv[0];
};

struct xhci_virt_device___4 {
	struct usb_device___16 *udev;
	struct xhci_container_ctx *out_ctx;
	struct xhci_container_ctx *in_ctx;
	struct xhci_virt_ep___4 eps[31];
	u8 fake_port;
	u8 real_port;
	struct xhci_interval_bw_table *bw_table;
	struct xhci_tt_bw_info *tt_info;
	u16 current_mel;
	void *debugfs_private;
};

struct xhci_port___4 {
	__le32 *addr;
	int hw_portnum;
	int hcd_portnum;
	struct xhci_hub___4 *rhub;
};

typedef int (*key_restrict_link_func_t___353)(struct key___352 *, const struct key_type *, const union key_payload *, struct key___352 *);

struct key_restriction___352;

struct key___352 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___384 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___352 *restrict_link;
};

struct key_restriction___352 {
	key_restrict_link_func_t___353 check;
	struct key___352 *key;
	struct key_type *keytype;
};

struct seq_operations___324 {
	void * (*start)(struct seq_file___325 *, loff_t *);
	void (*stop)(struct seq_file___325 *, void *);
	void * (*next)(struct seq_file___325 *, void *, loff_t *);
	int (*show)(struct seq_file___325 *, void *);
};

struct tty_driver___37;

struct tty_operations___37 {
	struct tty_struct___37 * (*lookup)(struct tty_driver___37 *, struct file___383 *, int);
	int (*install)(struct tty_driver___37 *, struct tty_struct___37 *);
	void (*remove)(struct tty_driver___37 *, struct tty_struct___37 *);
	int (*open)(struct tty_struct___37 *, struct file___383 *);
	void (*close)(struct tty_struct___37 *, struct file___383 *);
	void (*shutdown)(struct tty_struct___37 *);
	void (*cleanup)(struct tty_struct___37 *);
	int (*write)(struct tty_struct___37 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___37 *, unsigned char);
	void (*flush_chars)(struct tty_struct___37 *);
	int (*write_room)(struct tty_struct___37 *);
	int (*chars_in_buffer)(struct tty_struct___37 *);
	int (*ioctl)(struct tty_struct___37 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___37 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___37 *, struct ktermios *);
	void (*throttle)(struct tty_struct___37 *);
	void (*unthrottle)(struct tty_struct___37 *);
	void (*stop)(struct tty_struct___37 *);
	void (*start)(struct tty_struct___37 *);
	void (*hangup)(struct tty_struct___37 *);
	int (*break_ctl)(struct tty_struct___37 *, int);
	void (*flush_buffer)(struct tty_struct___37 *);
	void (*set_ldisc)(struct tty_struct___37 *);
	void (*wait_until_sent)(struct tty_struct___37 *, int);
	void (*send_xchar)(struct tty_struct___37 *, char);
	int (*tiocmget)(struct tty_struct___37 *);
	int (*tiocmset)(struct tty_struct___37 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___37 *, struct winsize *);
	int (*set_termiox)(struct tty_struct___37 *, struct termiox *);
	int (*get_icount)(struct tty_struct___37 *, struct serial_icounter_struct *);
	void (*show_fdinfo)(struct tty_struct___37 *, struct seq_file___325 *);
	int (*poll_init)(struct tty_driver___37 *, int, char *);
	int (*poll_get_char)(struct tty_driver___37 *, int);
	void (*poll_put_char)(struct tty_driver___37 *, int, char);
	int (*proc_show)(struct seq_file___325 *, void *);
};

struct tty_ldisc___37;

struct tty_port___37;

struct tty_struct___37 {
	int magic;
	struct kref kref;
	struct device___350 *dev;
	struct tty_driver___37 *driver;
	const struct tty_operations___37 *ops;
	int index;
	struct ld_semaphore ldisc_sem;
	struct tty_ldisc___37 *ldisc;
	struct mutex atomic_write_lock;
	struct mutex legacy_mutex;
	struct mutex throttle_mutex;
	struct rw_semaphore___384 termios_rwsem;
	struct mutex winsize_mutex;
	spinlock_t ctrl_lock;
	spinlock_t flow_lock;
	struct ktermios termios;
	struct ktermios termios_locked;
	struct termiox *termiox;
	char name[64];
	struct pid___220 *pgrp;
	struct pid___220 *session;
	long unsigned int flags;
	int count;
	struct winsize winsize;
	long unsigned int stopped: 1;
	long unsigned int flow_stopped: 1;
	int: 30;
	long unsigned int unused: 62;
	int hw_stopped;
	long unsigned int ctrl_status: 8;
	long unsigned int packet: 1;
	int: 23;
	long unsigned int unused_ctrl: 55;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___37 *link;
	struct fasync_struct___382 *fasync;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	spinlock_t files_lock;
	struct list_head tty_files;
	int closing;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___37 *port;
};

struct tty_driver___37 {
	int magic;
	struct kref kref;
	struct cdev___95 **cdevs;
	struct module___313 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___37 *other;
	struct tty_struct___37 **ttys;
	struct tty_port___37 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___37 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___37;

struct tty_port_client_operations___37;

struct tty_port___37 {
	struct tty_bufhead buf;
	struct tty_struct___37 *tty;
	struct tty_struct___37 *itty;
	const struct tty_port_operations___37 *ops;
	const struct tty_port_client_operations___37 *client_ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	unsigned char low_latency: 1;
	struct mutex mutex;
	struct mutex buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
	void *client_data;
};

struct tty_ldisc_ops___37 {
	int magic;
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___37 *);
	void (*close)(struct tty_struct___37 *);
	void (*flush_buffer)(struct tty_struct___37 *);
	ssize_t (*read)(struct tty_struct___37 *, struct file___383 *, unsigned char *, size_t);
	ssize_t (*write)(struct tty_struct___37 *, struct file___383 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___37 *, struct file___383 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___37 *, struct file___383 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___37 *, struct ktermios *);
	__poll_t (*poll)(struct tty_struct___37 *, struct file___383 *, struct poll_table_struct___231 *);
	int (*hangup)(struct tty_struct___37 *);
	void (*receive_buf)(struct tty_struct___37 *, const unsigned char *, char *, int);
	void (*write_wakeup)(struct tty_struct___37 *);
	void (*dcd_change)(struct tty_struct___37 *, unsigned int);
	int (*receive_buf2)(struct tty_struct___37 *, const unsigned char *, char *, int);
	struct module___313 *owner;
	int refcount;
};

struct tty_ldisc___37 {
	struct tty_ldisc_ops___37 *ops;
	struct tty_struct___37 *tty;
};

struct tty_port_operations___37 {
	int (*carrier_raised)(struct tty_port___37 *);
	void (*dtr_rts)(struct tty_port___37 *, int);
	void (*shutdown)(struct tty_port___37 *);
	int (*activate)(struct tty_port___37 *, struct tty_struct___37 *);
	void (*destruct)(struct tty_port___37 *);
};

struct tty_port_client_operations___37 {
	int (*receive_buf)(struct tty_port___37 *, const unsigned char *, const unsigned char *, size_t);
	void (*write_wakeup)(struct tty_port___37 *);
};

typedef void compound_page_dtor___371(struct page___384 *);

struct kfifo {
	union {
		struct __kfifo kfifo;
		unsigned char *type;
		const unsigned char *const_type;
		char (*rectype)[0];
		void *ptr;
		const void *ptr_const;
	};
	unsigned char buf[0];
};

struct dbc_regs {
	__le32 capability;
	__le32 doorbell;
	__le32 ersts;
	__le32 __reserved_0;
	__le64 erstba;
	__le64 erdp;
	__le32 control;
	__le32 status;
	__le32 portsc;
	__le32 __reserved_1;
	__le64 dccp;
	__le32 devinfo1;
	__le32 devinfo2;
};

struct dbc_str_descs {
	char string0[64];
	char manufacturer[64];
	char product[64];
	char serial[64];
};

enum dbc_state {
	DS_DISABLED = 0,
	DS_INITIALIZED = 1,
	DS_ENABLED = 2,
	DS_CONNECTED = 3,
	DS_CONFIGURED = 4,
	DS_STALLED = 5,
};

struct dbc_ep;

struct dbc_request {
	void *buf;
	unsigned int length;
	dma_addr_t dma;
	void (*complete)(struct xhci_hcd___4 *, struct dbc_request *);
	struct list_head list_pool;
	int status;
	unsigned int actual;
	struct dbc_ep *dep;
	struct list_head list_pending;
	dma_addr_t trb_dma;
	union xhci_trb *trb;
	unsigned int direction: 1;
};

struct xhci_dbc;

struct dbc_ep {
	struct xhci_dbc *dbc;
	struct list_head list_pending;
	struct xhci_ring *ring;
	unsigned int direction: 1;
};

struct dbc_port {
	struct tty_port___37 port;
	spinlock_t port_lock;
	struct list_head read_pool;
	struct list_head read_queue;
	unsigned int n_read;
	struct tasklet_struct push;
	struct list_head write_pool;
	struct kfifo write_fifo;
	bool registered;
	struct dbc_ep *in;
	struct dbc_ep *out;
};

struct xhci_dbc {
	spinlock_t lock;
	struct xhci_hcd___4 *xhci;
	struct dbc_regs *regs;
	struct xhci_ring *ring_evt;
	struct xhci_ring *ring_in;
	struct xhci_ring *ring_out;
	struct xhci_erst erst;
	struct xhci_container_ctx *ctx;
	struct dbc_str_descs *string;
	dma_addr_t string_dma;
	size_t string_size;
	enum dbc_state state;
	struct delayed_work event_work;
	unsigned int resume_required: 1;
	struct dbc_ep eps[2];
	struct dbc_port port;
};

struct cgroup_namespace___236 {
	refcount_t count;
	struct ns_common___9 ns;
	struct user_namespace___252 *user_ns;
	struct ucounts___252 *ucounts;
	struct css_set___236 *root_cset;
};

struct ucounts___252 {
	struct hlist_node node;
	struct user_namespace___252 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct kernel_param_ops___310 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___310 *);
	int (*get)(char *, const struct kernel_param___310 *);
	void (*free)(void *);
};

struct kparam_array___310;

struct kernel_param___310 {
	const char *name;
	struct module___313 *mod;
	const struct kernel_param_ops___310 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___310 *arr;
	};
};

struct kparam_array___310 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___310 *ops;
	void *elem;
};

struct module_attribute___310 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___310 *, struct module_kobject___310 *, char *);
	ssize_t (*store)(struct module_attribute___310 *, struct module_kobject___310 *, const char *, size_t);
	void (*setup)(struct module___313 *, const char *);
	int (*test)(struct module___313 *);
	void (*free)(struct module___313 *);
};

struct trace_event_class___137;

struct trace_event_call___137 {
	struct list_head list;
	struct trace_event_class___137 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___13 event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___39 *prog_array;
	int (*perf_perm)(struct trace_event_call___137 *, struct perf_event___144 *);
};

struct node___210 {
	struct device___350 dev;
};

struct bpf_map___237;

struct bpf_map_ops___236 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___237 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___237 *, struct file___383 *);
	void (*map_free)(struct bpf_map___237 *);
	int (*map_get_next_key)(struct bpf_map___237 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___237 *);
	void * (*map_lookup_elem)(struct bpf_map___237 *, void *);
	int (*map_update_elem)(struct bpf_map___237 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___237 *, void *);
	int (*map_push_elem)(struct bpf_map___237 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___237 *, void *);
	int (*map_peek_elem)(struct bpf_map___237 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___237 *, struct file___383 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___237 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___237 *, void *, struct seq_file___325 *);
	int (*map_check_btf)(const struct bpf_map___237 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___237 {
	const struct bpf_map_ops___236 *ops;
	struct bpf_map___237 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___352 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___237;

typedef void (*kthread_work_func_t___237)(struct kthread_work___237 *);

struct kthread_worker___237;

struct kthread_work___237 {
	struct list_head node;
	kthread_work_func_t___237 func;
	struct kthread_worker___237 *worker;
	int canceling;
};

struct kthread_worker___237 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___384 *task;
	struct kthread_work___237 *current_work;
};

struct kthread_delayed_work___236 {
	struct kthread_work___237 work;
	struct timer_list timer;
};

struct psi_group___236 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___237 *poll_kworker;
	struct kthread_delayed_work___236 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___236 {
	struct kernfs_node___377 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___236;

struct cgroup_subsys_state___236 {
	struct cgroup___236 *cgroup;
	struct cgroup_subsys___236 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___236 *parent;
};

struct cgroup_root___236;

struct cgroup_rstat_cpu___236;

struct cgroup___236 {
	struct cgroup_subsys_state___236 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___377 *kn;
	struct cgroup_file___236 procs_file;
	struct cgroup_file___236 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___236 *subsys[13];
	struct cgroup_root___236 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___236 *dom_cgrp;
	struct cgroup_rstat_cpu___236 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___39 bpf;
	atomic_t congestion_count;
	struct cgroup___236 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___236 psi;
	int ancestor_ids[0];
};

struct cftype___236;

struct cgroup_subsys___236 {
	struct cgroup_subsys_state___236 * (*css_alloc)(struct cgroup_subsys_state___236 *);
	int (*css_online)(struct cgroup_subsys_state___236 *);
	void (*css_offline)(struct cgroup_subsys_state___236 *);
	void (*css_released)(struct cgroup_subsys_state___236 *);
	void (*css_free)(struct cgroup_subsys_state___236 *);
	void (*css_reset)(struct cgroup_subsys_state___236 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___236 *, int);
	int (*css_extra_stat_show)(struct seq_file___325 *, struct cgroup_subsys_state___236 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___384 *);
	void (*cancel_fork)(struct task_struct___384 *);
	void (*fork)(struct task_struct___384 *);
	void (*exit)(struct task_struct___384 *);
	void (*free)(struct task_struct___384 *);
	void (*bind)(struct cgroup_subsys_state___236 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___236 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___236 *dfl_cftypes;
	struct cftype___236 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___236 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___236 *updated_children;
	struct cgroup___236 *updated_next;
};

struct cgroup_root___236 {
	struct kernfs_root___376 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___236 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___236 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___236 *ss;
	struct list_head node;
	struct kernfs_ops___376 *kf_ops;
	int (*open)(struct kernfs_open_file___376 *);
	void (*release)(struct kernfs_open_file___376 *);
	u64 (*read_u64)(struct cgroup_subsys_state___236 *, struct cftype___236 *);
	s64 (*read_s64)(struct cgroup_subsys_state___236 *, struct cftype___236 *);
	int (*seq_show)(struct seq_file___325 *, void *);
	void * (*seq_start)(struct seq_file___325 *, loff_t *);
	void * (*seq_next)(struct seq_file___325 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___325 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___236 *, struct cftype___236 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___236 *, struct cftype___236 *, s64);
	ssize_t (*write)(struct kernfs_open_file___376 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___376 *, struct poll_table_struct___231 *);
};

struct perf_cpu_context___144;

struct pmu___144 {
	struct list_head entry;
	struct module___313 *module;
	struct device___350 *dev;
	const struct attribute_group___347 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___144 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___144 *);
	void (*pmu_disable)(struct pmu___144 *);
	int (*event_init)(struct perf_event___144 *);
	void (*event_mapped)(struct perf_event___144 *, struct mm_struct___383 *);
	void (*event_unmapped)(struct perf_event___144 *, struct mm_struct___383 *);
	int (*add)(struct perf_event___144 *, int);
	void (*del)(struct perf_event___144 *, int);
	void (*start)(struct perf_event___144 *, int);
	void (*stop)(struct perf_event___144 *, int);
	void (*read)(struct perf_event___144 *);
	void (*start_txn)(struct pmu___144 *, unsigned int);
	int (*commit_txn)(struct pmu___144 *);
	void (*cancel_txn)(struct pmu___144 *);
	int (*event_idx)(struct perf_event___144 *);
	void (*sched_task)(struct perf_event_context___144 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___144 *);
	int (*filter_match)(struct perf_event___144 *);
	int (*check_period)(struct perf_event___144 *, u64);
};

struct perf_cpu_context___144 {
	struct perf_event_context___144 ctx;
	struct perf_event_context___144 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___144 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___144 {
	struct cgroup_subsys_state___236 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___137 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___137 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___137 *);
	struct list_head * (*get_fields)(struct trace_event_call___137 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___137 *);
};

struct trace_event_file___56;

struct trace_event_buffer___48 {
	struct ring_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___56 *trace_file;
	void *entry;
	long unsigned int flags;
	int pc;
};

struct trace_event_file___56 {
	struct list_head list;
	struct trace_event_call___137 *event_call;
	struct event_filter *filter;
	struct dentry___382 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_xhci_log_msg {
	struct trace_entry ent;
	u32 __data_loc_msg;
	char __data[0];
};

struct trace_event_raw_xhci_log_ctx {
	struct trace_entry ent;
	int ctx_64;
	unsigned int ctx_type;
	dma_addr_t ctx_dma;
	u8 *ctx_va;
	unsigned int ctx_ep_num;
	int slot_id;
	u32 __data_loc_ctx_data;
	char __data[0];
};

struct trace_event_raw_xhci_log_trb {
	struct trace_entry ent;
	u32 type;
	u32 field0;
	u32 field1;
	u32 field2;
	u32 field3;
	char __data[0];
};

struct trace_event_raw_xhci_log_free_virt_dev {
	struct trace_entry ent;
	void *vdev;
	long long unsigned int out_ctx;
	long long unsigned int in_ctx;
	u8 fake_port;
	u8 real_port;
	u16 current_mel;
	char __data[0];
};

struct trace_event_raw_xhci_log_virt_dev {
	struct trace_entry ent;
	void *vdev;
	long long unsigned int out_ctx;
	long long unsigned int in_ctx;
	int devnum;
	int state;
	int speed;
	u8 portnum;
	u8 level;
	int slot_id;
	char __data[0];
};

struct trace_event_raw_xhci_log_urb {
	struct trace_entry ent;
	void *urb;
	unsigned int pipe;
	unsigned int stream;
	int status;
	unsigned int flags;
	int num_mapped_sgs;
	int num_sgs;
	int length;
	int actual;
	int epnum;
	int dir_in;
	int type;
	int slot_id;
	char __data[0];
};

struct trace_event_raw_xhci_log_ep_ctx {
	struct trace_entry ent;
	u32 info;
	u32 info2;
	u64 deq;
	u32 tx_info;
	char __data[0];
};

struct trace_event_raw_xhci_log_slot_ctx {
	struct trace_entry ent;
	u32 info;
	u32 info2;
	u32 tt_info;
	u32 state;
	char __data[0];
};

struct trace_event_raw_xhci_log_ring {
	struct trace_entry ent;
	u32 type;
	void *ring;
	dma_addr_t enq;
	dma_addr_t deq;
	dma_addr_t enq_seg;
	dma_addr_t deq_seg;
	unsigned int num_segs;
	unsigned int stream_id;
	unsigned int cycle_state;
	unsigned int num_trbs_free;
	unsigned int bounce_buf_len;
	char __data[0];
};

struct trace_event_raw_xhci_log_portsc {
	struct trace_entry ent;
	u32 portnum;
	u32 portsc;
	char __data[0];
};

struct trace_event_raw_xhci_dbc_log_request {
	struct trace_entry ent;
	struct dbc_request *req;
	bool dir;
	unsigned int actual;
	unsigned int length;
	int status;
	char __data[0];
};

struct trace_event_data_offsets_xhci_log_msg {
	u32 msg;
};

struct trace_event_data_offsets_xhci_log_ctx {
	u32 ctx_data;
};

struct trace_event_data_offsets_xhci_log_trb {};

struct trace_event_data_offsets_xhci_log_free_virt_dev {};

struct trace_event_data_offsets_xhci_log_virt_dev {};

struct trace_event_data_offsets_xhci_log_urb {};

struct trace_event_data_offsets_xhci_log_ep_ctx {};

struct trace_event_data_offsets_xhci_log_slot_ctx {};

struct trace_event_data_offsets_xhci_log_ring {};

struct trace_event_data_offsets_xhci_log_portsc {};

struct trace_event_data_offsets_xhci_dbc_log_request {};

struct xhci_hcd___5;

struct xhci_virt_ep___5 {
	struct xhci_ring *ring;
	struct xhci_stream_info *stream_info;
	struct xhci_ring *new_ring;
	unsigned int ep_state;
	struct list_head cancelled_td_list;
	struct timer_list stop_cmd_timer;
	struct xhci_hcd___5 *xhci;
	struct xhci_segment *queued_deq_seg;
	union xhci_trb *queued_deq_ptr;
	bool skip;
	struct xhci_bw_info bw_info;
	struct list_head bw_endpoint_list;
	int next_frame_id;
	bool use_extended_tbc;
};

struct xhci_port___5;

struct xhci_hub___5 {
	struct xhci_port___5 **ports;
	unsigned int num_ports;
	struct usb_hcd___8 *hcd;
	u8 maj_rev;
	u8 min_rev;
	u32 *psi;
	u8 psi_count;
	u8 psi_uid_count;
};

struct xhci_virt_device___5;

struct xhci_hcd___5 {
	struct usb_hcd___8 *main_hcd;
	struct usb_hcd___8 *shared_hcd;
	struct xhci_cap_regs *cap_regs;
	struct xhci_op_regs *op_regs;
	struct xhci_run_regs *run_regs;
	struct xhci_doorbell_array *dba;
	struct xhci_intr_reg *ir_set;
	__u32 hcs_params1;
	__u32 hcs_params2;
	__u32 hcs_params3;
	__u32 hcc_params;
	__u32 hcc_params2;
	spinlock_t lock;
	u8 sbrn;
	u16 hci_version;
	u8 max_slots;
	u8 max_interrupters;
	u8 max_ports;
	u8 isoc_threshold;
	u32 imod_interval;
	int event_ring_max;
	int page_size;
	int page_shift;
	int msix_count;
	struct clk *clk;
	struct clk *reg_clk;
	struct xhci_device_context_array *dcbaa;
	struct xhci_ring *cmd_ring;
	unsigned int cmd_ring_state;
	struct list_head cmd_list;
	unsigned int cmd_ring_reserved_trbs;
	struct delayed_work cmd_timer;
	struct completion cmd_ring_stop_completion;
	struct xhci_command *current_cmd;
	struct xhci_ring *event_ring;
	struct xhci_erst erst;
	struct xhci_scratchpad *scratchpad;
	struct list_head lpm_failed_devs;
	struct mutex mutex;
	struct xhci_command *lpm_command;
	struct xhci_virt_device___5 *devs[256];
	struct xhci_root_port_bw_info *rh_bw;
	struct dma_pool___2 *device_pool;
	struct dma_pool___2 *segment_pool;
	struct dma_pool___2 *small_streams_pool;
	struct dma_pool___2 *medium_streams_pool;
	unsigned int xhc_state;
	u32 command;
	struct s3_save s3;
	long long unsigned int quirks;
	unsigned int num_active_eps;
	unsigned int limit_active_eps;
	struct xhci_bus_state bus_state[2];
	struct xhci_port___5 *hw_ports;
	struct xhci_hub___5 usb2_rhub;
	struct xhci_hub___5 usb3_rhub;
	unsigned int sw_lpm_support: 1;
	unsigned int hw_lpm_support: 1;
	u32 *ext_caps;
	unsigned int num_ext_caps;
	struct timer_list comp_mode_recovery_timer;
	u32 port_status_u0;
	u16 test_mode;
	struct dentry___379 *debugfs_root;
	struct dentry___379 *debugfs_slots;
	struct list_head regset_list;
	void *dbc;
	long unsigned int priv[0];
};

struct xhci_virt_device___5 {
	struct usb_device___12 *udev;
	struct xhci_container_ctx *out_ctx;
	struct xhci_container_ctx *in_ctx;
	struct xhci_virt_ep___5 eps[31];
	u8 fake_port;
	u8 real_port;
	struct xhci_interval_bw_table *bw_table;
	struct xhci_tt_bw_info *tt_info;
	u16 current_mel;
	void *debugfs_private;
};

struct xhci_port___5 {
	__le32 *addr;
	int hw_portnum;
	int hcd_portnum;
	struct xhci_hub___5 *rhub;
};

struct xhci_regset {
	char name[32];
	struct debugfs_regset32 regset;
	size_t nregs;
	struct dentry___379 *parent;
	struct list_head list;
};

struct xhci_file_map {
	const char *name;
	int (*show)(struct seq_file___322 *, void *);
};

struct xhci_ep_priv {
	char name[32];
	struct dentry___379 *root;
};

struct xhci_slot_priv {
	char name[32];
	struct dentry___379 *root;
	struct xhci_ep_priv *eps[31];
	struct xhci_virt_device___5 *dev;
};

struct usb_interface___16 {
	struct usb_host_interface *altsetting;
	struct usb_host_interface *cur_altsetting;
	unsigned int num_altsetting;
	struct usb_interface_assoc_descriptor *intf_assoc;
	int minor;
	enum usb_interface_condition condition;
	unsigned int sysfs_files_created: 1;
	unsigned int ep_devs_created: 1;
	unsigned int unregistering: 1;
	unsigned int needs_remote_wakeup: 1;
	unsigned int needs_altsetting0: 1;
	unsigned int needs_binding: 1;
	unsigned int resetting_device: 1;
	unsigned int authorized: 1;
	struct device___260 dev;
	struct device___260 *usb_dev;
	atomic_t pm_usage_cnt;
	struct work_struct reset_ws;
};

struct usb_host_config___16 {
	struct usb_config_descriptor desc;
	char *string;
	struct usb_interface_assoc_descriptor *intf_assoc[16];
	struct usb_interface___16 *interface[32];
	struct usb_interface_cache *intf_cache[32];
	unsigned char *extra;
	int extralen;
};

struct usb_device___17;

struct usb_bus___17 {
	struct device___260 *controller;
	struct device___260 *sysdev;
	int busnum;
	const char *bus_name;
	u8 uses_dma;
	u8 uses_pio_for_control;
	u8 otg_port;
	unsigned int is_b_host: 1;
	unsigned int b_hnp_enable: 1;
	unsigned int no_stop_on_short: 1;
	unsigned int no_sg_constraint: 1;
	unsigned int sg_tablesize;
	int devnum_next;
	struct mutex devnum_next_mutex;
	struct usb_devmap devmap;
	struct usb_device___17 *root_hub;
	struct usb_bus___17 *hs_companion;
	int bandwidth_allocated;
	int bandwidth_int_reqs;
	int bandwidth_isoc_reqs;
	unsigned int resuming_ports;
	struct mon_bus *mon_bus;
	int monitored;
};

struct usb_tt___14;

struct usb_device___17 {
	int devnum;
	char devpath[16];
	u32 route;
	enum usb_device_state state;
	enum usb_device_speed speed;
	unsigned int rx_lanes;
	unsigned int tx_lanes;
	struct usb_tt___14 *tt;
	int ttport;
	unsigned int toggle[2];
	struct usb_device___17 *parent;
	struct usb_bus___17 *bus;
	struct usb_host_endpoint ep0;
	struct device___260 dev;
	struct usb_device_descriptor descriptor;
	struct usb_host_bos *bos;
	struct usb_host_config___16 *config;
	struct usb_host_config___16 *actconfig;
	struct usb_host_endpoint *ep_in[16];
	struct usb_host_endpoint *ep_out[16];
	char **rawdescriptors;
	short unsigned int bus_mA;
	u8 portnum;
	u8 level;
	unsigned int can_submit: 1;
	unsigned int persist_enabled: 1;
	unsigned int have_langid: 1;
	unsigned int authorized: 1;
	unsigned int authenticated: 1;
	unsigned int wusb: 1;
	unsigned int lpm_capable: 1;
	unsigned int usb2_hw_lpm_capable: 1;
	unsigned int usb2_hw_lpm_besl_capable: 1;
	unsigned int usb2_hw_lpm_enabled: 1;
	unsigned int usb2_hw_lpm_allowed: 1;
	unsigned int usb3_lpm_u1_enabled: 1;
	unsigned int usb3_lpm_u2_enabled: 1;
	int string_langid;
	char *product;
	char *manufacturer;
	char *serial;
	struct list_head filelist;
	int maxchild;
	u32 quirks;
	atomic_t urbnum;
	long unsigned int active_duration;
	long unsigned int connect_time;
	unsigned int do_remote_wakeup: 1;
	unsigned int reset_resume: 1;
	unsigned int port_is_suspended: 1;
	struct wusb_dev *wusb_dev;
	int slot_id;
	enum usb_device_removable removable;
	struct usb2_lpm_parameters l1_params;
	struct usb3_lpm_parameters u1_params;
	struct usb3_lpm_parameters u2_params;
	unsigned int lpm_disable_count;
	u16 hub_delay;
};

struct usb_tt___14 {
	struct usb_device___17 *hub;
	int multi;
	unsigned int think_time;
	void *hcpriv;
	spinlock_t lock;
	struct list_head clear_list;
	struct work_struct clear_work;
};

struct urb___16;

typedef void (*usb_complete_t___16)(struct urb___16 *);

struct urb___16 {
	struct kref kref;
	void *hcpriv;
	atomic_t use_count;
	atomic_t reject;
	int unlinked;
	struct list_head urb_list;
	struct list_head anchor_list;
	struct usb_anchor *anchor;
	struct usb_device___17 *dev;
	struct usb_host_endpoint *ep;
	unsigned int pipe;
	unsigned int stream_id;
	int status;
	unsigned int transfer_flags;
	void *transfer_buffer;
	dma_addr_t transfer_dma;
	struct scatterlist *sg;
	int num_mapped_sgs;
	int num_sgs;
	u32 transfer_buffer_length;
	u32 actual_length;
	unsigned char *setup_packet;
	dma_addr_t setup_dma;
	int start_frame;
	int number_of_packets;
	int interval;
	int error_count;
	void *context;
	usb_complete_t___16 complete;
	struct usb_iso_packet_descriptor iso_frame_desc[0];
};

struct usb_phy___5;

struct usb_phy_io_ops___5 {
	int (*read)(struct usb_phy___5 *, u32);
	int (*write)(struct usb_phy___5 *, u32, u32);
};

struct usb_otg___5;

struct usb_phy___5 {
	struct device___260 *dev;
	const char *label;
	unsigned int flags;
	enum usb_phy_type type;
	enum usb_phy_events last_event;
	struct usb_otg___5 *otg;
	struct device___260 *io_dev;
	struct usb_phy_io_ops___5 *io_ops;
	void *io_priv;
	struct extcon_dev *edev;
	struct extcon_dev *id_edev;
	struct notifier_block vbus_nb;
	struct notifier_block id_nb;
	struct notifier_block type_nb;
	enum usb_charger_type chg_type;
	enum usb_charger_state chg_state;
	struct usb_charger_current chg_cur;
	struct work_struct chg_work;
	struct atomic_notifier_head notifier;
	u16 port_status;
	u16 port_change;
	struct list_head head;
	int (*init)(struct usb_phy___5 *);
	void (*shutdown)(struct usb_phy___5 *);
	int (*set_vbus)(struct usb_phy___5 *, int);
	int (*set_power)(struct usb_phy___5 *, unsigned int);
	int (*set_suspend)(struct usb_phy___5 *, int);
	int (*set_wakeup)(struct usb_phy___5 *, bool);
	int (*notify_connect)(struct usb_phy___5 *, enum usb_device_speed);
	int (*notify_disconnect)(struct usb_phy___5 *, enum usb_device_speed);
	enum usb_charger_type (*charger_detect)(struct usb_phy___5 *);
};

struct hc_driver___13;

struct usb_hcd___13 {
	struct usb_bus___17 self;
	struct kref kref;
	const char *product_desc;
	int speed;
	char irq_descr[24];
	struct timer_list rh_timer;
	struct urb___16 *status_urb;
	struct work_struct wakeup_work;
	const struct hc_driver___13 *driver;
	struct usb_phy___5 *usb_phy;
	struct usb_phy_roothub *phy_roothub;
	long unsigned int flags;
	unsigned int rh_registered: 1;
	unsigned int rh_pollable: 1;
	unsigned int msix_enabled: 1;
	unsigned int msi_enabled: 1;
	unsigned int skip_phy_initialization: 1;
	unsigned int uses_new_polling: 1;
	unsigned int wireless: 1;
	unsigned int has_tt: 1;
	unsigned int amd_resume_bug: 1;
	unsigned int can_do_streams: 1;
	unsigned int tpl_support: 1;
	unsigned int cant_recv_wakeups: 1;
	unsigned int irq;
	void *regs;
	resource_size_t rsrc_start;
	resource_size_t rsrc_len;
	unsigned int power_budget;
	struct giveback_urb_bh high_prio_bh;
	struct giveback_urb_bh low_prio_bh;
	struct mutex *address0_mutex;
	struct mutex *bandwidth_mutex;
	struct usb_hcd___13 *shared_hcd;
	struct usb_hcd___13 *primary_hcd;
	struct dma_pool___2 *pool[4];
	int state;
	long unsigned int hcd_priv[0];
};

struct hc_driver___13 {
	const char *description;
	const char *product_desc;
	size_t hcd_priv_size;
	irqreturn_t (*irq)(struct usb_hcd___13 *);
	int flags;
	int (*reset)(struct usb_hcd___13 *);
	int (*start)(struct usb_hcd___13 *);
	int (*pci_suspend)(struct usb_hcd___13 *, bool);
	int (*pci_resume)(struct usb_hcd___13 *, bool);
	void (*stop)(struct usb_hcd___13 *);
	void (*shutdown)(struct usb_hcd___13 *);
	int (*get_frame_number)(struct usb_hcd___13 *);
	int (*urb_enqueue)(struct usb_hcd___13 *, struct urb___16 *, gfp_t);
	int (*urb_dequeue)(struct usb_hcd___13 *, struct urb___16 *, int);
	int (*map_urb_for_dma)(struct usb_hcd___13 *, struct urb___16 *, gfp_t);
	void (*unmap_urb_for_dma)(struct usb_hcd___13 *, struct urb___16 *);
	void (*endpoint_disable)(struct usb_hcd___13 *, struct usb_host_endpoint *);
	void (*endpoint_reset)(struct usb_hcd___13 *, struct usb_host_endpoint *);
	int (*hub_status_data)(struct usb_hcd___13 *, char *);
	int (*hub_control)(struct usb_hcd___13 *, u16, u16, u16, char *, u16);
	int (*bus_suspend)(struct usb_hcd___13 *);
	int (*bus_resume)(struct usb_hcd___13 *);
	int (*start_port_reset)(struct usb_hcd___13 *, unsigned int);
	long unsigned int (*get_resuming_ports)(struct usb_hcd___13 *);
	void (*relinquish_port)(struct usb_hcd___13 *, int);
	int (*port_handed_over)(struct usb_hcd___13 *, int);
	void (*clear_tt_buffer_complete)(struct usb_hcd___13 *, struct usb_host_endpoint *);
	int (*alloc_dev)(struct usb_hcd___13 *, struct usb_device___17 *);
	void (*free_dev)(struct usb_hcd___13 *, struct usb_device___17 *);
	int (*alloc_streams)(struct usb_hcd___13 *, struct usb_device___17 *, struct usb_host_endpoint **, unsigned int, unsigned int, gfp_t);
	int (*free_streams)(struct usb_hcd___13 *, struct usb_device___17 *, struct usb_host_endpoint **, unsigned int, gfp_t);
	int (*add_endpoint)(struct usb_hcd___13 *, struct usb_device___17 *, struct usb_host_endpoint *);
	int (*drop_endpoint)(struct usb_hcd___13 *, struct usb_device___17 *, struct usb_host_endpoint *);
	int (*check_bandwidth)(struct usb_hcd___13 *, struct usb_device___17 *);
	void (*reset_bandwidth)(struct usb_hcd___13 *, struct usb_device___17 *);
	int (*address_device)(struct usb_hcd___13 *, struct usb_device___17 *);
	int (*enable_device)(struct usb_hcd___13 *, struct usb_device___17 *);
	int (*update_hub_device)(struct usb_hcd___13 *, struct usb_device___17 *, struct usb_tt___14 *, gfp_t);
	int (*reset_device)(struct usb_hcd___13 *, struct usb_device___17 *);
	int (*update_device)(struct usb_hcd___13 *, struct usb_device___17 *);
	int (*set_usb2_hw_lpm)(struct usb_hcd___13 *, struct usb_device___17 *, int);
	int (*enable_usb3_lpm_timeout)(struct usb_hcd___13 *, struct usb_device___17 *, enum usb3_link_state);
	int (*disable_usb3_lpm_timeout)(struct usb_hcd___13 *, struct usb_device___17 *, enum usb3_link_state);
	int (*find_raw_port_number)(struct usb_hcd___13 *, int);
	int (*port_power)(struct usb_hcd___13 *, int, bool);
};

struct usb_mon_operations___14 {
	void (*urb_submit)(struct usb_bus___17 *, struct urb___16 *);
	void (*urb_submit_error)(struct usb_bus___17 *, struct urb___16 *, int);
	void (*urb_complete)(struct usb_bus___17 *, struct urb___16 *, int);
};

struct xhci_hcd___6;

struct xhci_virt_ep___6 {
	struct xhci_ring *ring;
	struct xhci_stream_info *stream_info;
	struct xhci_ring *new_ring;
	unsigned int ep_state;
	struct list_head cancelled_td_list;
	struct timer_list stop_cmd_timer;
	struct xhci_hcd___6 *xhci;
	struct xhci_segment *queued_deq_seg;
	union xhci_trb *queued_deq_ptr;
	bool skip;
	struct xhci_bw_info bw_info;
	struct list_head bw_endpoint_list;
	int next_frame_id;
	bool use_extended_tbc;
};

struct xhci_port___6;

struct xhci_hub___6 {
	struct xhci_port___6 **ports;
	unsigned int num_ports;
	struct usb_hcd___13 *hcd;
	u8 maj_rev;
	u8 min_rev;
	u32 *psi;
	u8 psi_count;
	u8 psi_uid_count;
};

struct xhci_virt_device___6;

struct xhci_hcd___6 {
	struct usb_hcd___13 *main_hcd;
	struct usb_hcd___13 *shared_hcd;
	struct xhci_cap_regs *cap_regs;
	struct xhci_op_regs *op_regs;
	struct xhci_run_regs *run_regs;
	struct xhci_doorbell_array *dba;
	struct xhci_intr_reg *ir_set;
	__u32 hcs_params1;
	__u32 hcs_params2;
	__u32 hcs_params3;
	__u32 hcc_params;
	__u32 hcc_params2;
	spinlock_t lock;
	u8 sbrn;
	u16 hci_version;
	u8 max_slots;
	u8 max_interrupters;
	u8 max_ports;
	u8 isoc_threshold;
	u32 imod_interval;
	int event_ring_max;
	int page_size;
	int page_shift;
	int msix_count;
	struct clk *clk;
	struct clk *reg_clk;
	struct xhci_device_context_array *dcbaa;
	struct xhci_ring *cmd_ring;
	unsigned int cmd_ring_state;
	struct list_head cmd_list;
	unsigned int cmd_ring_reserved_trbs;
	struct delayed_work cmd_timer;
	struct completion cmd_ring_stop_completion;
	struct xhci_command *current_cmd;
	struct xhci_ring *event_ring;
	struct xhci_erst erst;
	struct xhci_scratchpad *scratchpad;
	struct list_head lpm_failed_devs;
	struct mutex mutex;
	struct xhci_command *lpm_command;
	struct xhci_virt_device___6 *devs[256];
	struct xhci_root_port_bw_info *rh_bw;
	struct dma_pool___2 *device_pool;
	struct dma_pool___2 *segment_pool;
	struct dma_pool___2 *small_streams_pool;
	struct dma_pool___2 *medium_streams_pool;
	unsigned int xhc_state;
	u32 command;
	struct s3_save s3;
	long long unsigned int quirks;
	unsigned int num_active_eps;
	unsigned int limit_active_eps;
	struct xhci_bus_state bus_state[2];
	struct xhci_port___6 *hw_ports;
	struct xhci_hub___6 usb2_rhub;
	struct xhci_hub___6 usb3_rhub;
	unsigned int sw_lpm_support: 1;
	unsigned int hw_lpm_support: 1;
	u32 *ext_caps;
	unsigned int num_ext_caps;
	struct timer_list comp_mode_recovery_timer;
	u32 port_status_u0;
	u16 test_mode;
	struct dentry___295 *debugfs_root;
	struct dentry___295 *debugfs_slots;
	struct list_head regset_list;
	void *dbc;
	long unsigned int priv[0];
};

struct xhci_virt_device___6 {
	struct usb_device___17 *udev;
	struct xhci_container_ctx *out_ctx;
	struct xhci_container_ctx *in_ctx;
	struct xhci_virt_ep___6 eps[31];
	u8 fake_port;
	u8 real_port;
	struct xhci_interval_bw_table *bw_table;
	struct xhci_tt_bw_info *tt_info;
	u16 current_mel;
	void *debugfs_private;
};

struct xhci_port___6 {
	__le32 *addr;
	int hw_portnum;
	int hcd_portnum;
	struct xhci_hub___6 *rhub;
};

struct xhci_driver_overrides___2 {
	size_t extra_priv_size;
	int (*reset)(struct usb_hcd___13 *);
	int (*start)(struct usb_hcd___13 *);
};

struct xhci_plat_priv {
	const char *firmware_name;
	void (*plat_start)(struct usb_hcd___13 *);
	int (*init_quirk)(struct usb_hcd___13 *);
	int (*resume_quirk)(struct usb_hcd___13 *);
};

struct device_attribute___54 {
	struct attribute attr;
	ssize_t (*show)(struct device___276 *, struct device_attribute___54 *, char *);
	ssize_t (*store)(struct device___276 *, struct device_attribute___54 *, const char *, size_t);
};

struct async_icount {
	__u32 cts;
	__u32 dsr;
	__u32 rng;
	__u32 dcd;
	__u32 tx;
	__u32 rx;
	__u32 frame;
	__u32 parity;
	__u32 overrun;
	__u32 brk;
	__u32 buf_overrun;
};

struct usb_interface___17 {
	struct usb_host_interface *altsetting;
	struct usb_host_interface *cur_altsetting;
	unsigned int num_altsetting;
	struct usb_interface_assoc_descriptor *intf_assoc;
	int minor;
	enum usb_interface_condition condition;
	unsigned int sysfs_files_created: 1;
	unsigned int ep_devs_created: 1;
	unsigned int unregistering: 1;
	unsigned int needs_remote_wakeup: 1;
	unsigned int needs_altsetting0: 1;
	unsigned int needs_binding: 1;
	unsigned int resetting_device: 1;
	unsigned int authorized: 1;
	struct device___276 dev;
	struct device___276 *usb_dev;
	atomic_t pm_usage_cnt;
	struct work_struct reset_ws;
};

struct usb_host_config___17 {
	struct usb_config_descriptor desc;
	char *string;
	struct usb_interface_assoc_descriptor *intf_assoc[16];
	struct usb_interface___17 *interface[32];
	struct usb_interface_cache *intf_cache[32];
	unsigned char *extra;
	int extralen;
};

struct usb_device___18;

struct usb_bus___18 {
	struct device___276 *controller;
	struct device___276 *sysdev;
	int busnum;
	const char *bus_name;
	u8 uses_dma;
	u8 uses_pio_for_control;
	u8 otg_port;
	unsigned int is_b_host: 1;
	unsigned int b_hnp_enable: 1;
	unsigned int no_stop_on_short: 1;
	unsigned int no_sg_constraint: 1;
	unsigned int sg_tablesize;
	int devnum_next;
	struct mutex devnum_next_mutex;
	struct usb_devmap devmap;
	struct usb_device___18 *root_hub;
	struct usb_bus___18 *hs_companion;
	int bandwidth_allocated;
	int bandwidth_int_reqs;
	int bandwidth_isoc_reqs;
	unsigned int resuming_ports;
	struct mon_bus *mon_bus;
	int monitored;
};

struct usb_device___18 {
	int devnum;
	char devpath[16];
	u32 route;
	enum usb_device_state state;
	enum usb_device_speed speed;
	unsigned int rx_lanes;
	unsigned int tx_lanes;
	struct usb_tt___3 *tt;
	int ttport;
	unsigned int toggle[2];
	struct usb_device___18 *parent;
	struct usb_bus___18 *bus;
	struct usb_host_endpoint ep0;
	struct device___276 dev;
	struct usb_device_descriptor descriptor;
	struct usb_host_bos *bos;
	struct usb_host_config___17 *config;
	struct usb_host_config___17 *actconfig;
	struct usb_host_endpoint *ep_in[16];
	struct usb_host_endpoint *ep_out[16];
	char **rawdescriptors;
	short unsigned int bus_mA;
	u8 portnum;
	u8 level;
	unsigned int can_submit: 1;
	unsigned int persist_enabled: 1;
	unsigned int have_langid: 1;
	unsigned int authorized: 1;
	unsigned int authenticated: 1;
	unsigned int wusb: 1;
	unsigned int lpm_capable: 1;
	unsigned int usb2_hw_lpm_capable: 1;
	unsigned int usb2_hw_lpm_besl_capable: 1;
	unsigned int usb2_hw_lpm_enabled: 1;
	unsigned int usb2_hw_lpm_allowed: 1;
	unsigned int usb3_lpm_u1_enabled: 1;
	unsigned int usb3_lpm_u2_enabled: 1;
	int string_langid;
	char *product;
	char *manufacturer;
	char *serial;
	struct list_head filelist;
	int maxchild;
	u32 quirks;
	atomic_t urbnum;
	long unsigned int active_duration;
	long unsigned int connect_time;
	unsigned int do_remote_wakeup: 1;
	unsigned int reset_resume: 1;
	unsigned int port_is_suspended: 1;
	struct wusb_dev *wusb_dev;
	int slot_id;
	enum usb_device_removable removable;
	struct usb2_lpm_parameters l1_params;
	struct usb3_lpm_parameters u1_params;
	struct usb3_lpm_parameters u2_params;
	unsigned int lpm_disable_count;
	u16 hub_delay;
};

struct usbdrv_wrap___10 {
	struct device_driver___276 driver;
	int for_devices;
};

struct usb_driver___10 {
	const char *name;
	int (*probe)(struct usb_interface___17 *, const struct usb_device_id *);
	void (*disconnect)(struct usb_interface___17 *);
	int (*unlocked_ioctl)(struct usb_interface___17 *, unsigned int, void *);
	int (*suspend)(struct usb_interface___17 *, pm_message_t);
	int (*resume)(struct usb_interface___17 *);
	int (*reset_resume)(struct usb_interface___17 *);
	int (*pre_reset)(struct usb_interface___17 *);
	int (*post_reset)(struct usb_interface___17 *);
	const struct usb_device_id *id_table;
	struct usb_dynids dynids;
	struct usbdrv_wrap___10 drvwrap;
	unsigned int no_dynamic_id: 1;
	unsigned int supports_autosuspend: 1;
	unsigned int disable_hub_initiated_lpm: 1;
	unsigned int soft_unbind: 1;
};

struct urb___17;

typedef void (*usb_complete_t___17)(struct urb___17 *);

struct urb___17 {
	struct kref kref;
	void *hcpriv;
	atomic_t use_count;
	atomic_t reject;
	int unlinked;
	struct list_head urb_list;
	struct list_head anchor_list;
	struct usb_anchor *anchor;
	struct usb_device___18 *dev;
	struct usb_host_endpoint *ep;
	unsigned int pipe;
	unsigned int stream_id;
	int status;
	unsigned int transfer_flags;
	void *transfer_buffer;
	dma_addr_t transfer_dma;
	struct scatterlist *sg;
	int num_mapped_sgs;
	int num_sgs;
	u32 transfer_buffer_length;
	u32 actual_length;
	unsigned char *setup_packet;
	dma_addr_t setup_dma;
	int start_frame;
	int number_of_packets;
	int interval;
	int error_count;
	void *context;
	usb_complete_t___17 complete;
	struct usb_iso_packet_descriptor iso_frame_desc[0];
};

struct usb_serial;

struct usb_serial_port {
	struct usb_serial *serial;
	struct tty_port___31 port;
	spinlock_t lock;
	u32 minor;
	u8 port_number;
	unsigned char *interrupt_in_buffer;
	struct urb___17 *interrupt_in_urb;
	__u8 interrupt_in_endpointAddress;
	unsigned char *interrupt_out_buffer;
	int interrupt_out_size;
	struct urb___17 *interrupt_out_urb;
	__u8 interrupt_out_endpointAddress;
	unsigned char *bulk_in_buffer;
	int bulk_in_size;
	struct urb___17 *read_urb;
	__u8 bulk_in_endpointAddress;
	unsigned char *bulk_in_buffers[2];
	struct urb___17 *read_urbs[2];
	long unsigned int read_urbs_free;
	unsigned char *bulk_out_buffer;
	int bulk_out_size;
	struct urb___17 *write_urb;
	struct kfifo write_fifo;
	unsigned char *bulk_out_buffers[2];
	struct urb___17 *write_urbs[2];
	long unsigned int write_urbs_free;
	__u8 bulk_out_endpointAddress;
	struct async_icount icount;
	int tx_bytes;
	long unsigned int flags;
	wait_queue_head_t write_wait;
	struct work_struct work;
	char throttled;
	char throttle_req;
	long unsigned int sysrq;
	struct device___276 dev;
};

struct usb_serial_driver;

struct usb_serial {
	struct usb_device___18 *dev;
	struct usb_serial_driver *type;
	struct usb_interface___17 *interface;
	unsigned char disconnected: 1;
	unsigned char suspending: 1;
	unsigned char attached: 1;
	unsigned char minors_reserved: 1;
	unsigned char num_ports;
	unsigned char num_port_pointers;
	unsigned char num_interrupt_in;
	unsigned char num_interrupt_out;
	unsigned char num_bulk_in;
	unsigned char num_bulk_out;
	struct usb_serial_port *port[16];
	struct kref kref;
	struct mutex disc_mutex;
	void *private;
};

struct usb_serial_endpoints;

struct usb_serial_driver {
	const char *description;
	const struct usb_device_id *id_table;
	struct list_head driver_list;
	struct device_driver___276 driver;
	struct usb_driver___10 *usb_driver;
	struct usb_dynids dynids;
	unsigned char num_ports;
	unsigned char num_bulk_in;
	unsigned char num_bulk_out;
	unsigned char num_interrupt_in;
	unsigned char num_interrupt_out;
	size_t bulk_in_size;
	size_t bulk_out_size;
	int (*probe)(struct usb_serial *, const struct usb_device_id *);
	int (*attach)(struct usb_serial *);
	int (*calc_num_ports)(struct usb_serial *, struct usb_serial_endpoints *);
	void (*disconnect)(struct usb_serial *);
	void (*release)(struct usb_serial *);
	int (*port_probe)(struct usb_serial_port *);
	int (*port_remove)(struct usb_serial_port *);
	int (*suspend)(struct usb_serial *, pm_message_t);
	int (*resume)(struct usb_serial *);
	int (*reset_resume)(struct usb_serial *);
	int (*open)(struct tty_struct___31 *, struct usb_serial_port *);
	void (*close)(struct usb_serial_port *);
	int (*write)(struct tty_struct___31 *, struct usb_serial_port *, const unsigned char *, int);
	int (*write_room)(struct tty_struct___31 *);
	int (*ioctl)(struct tty_struct___31 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___31 *, struct usb_serial_port *, struct ktermios *);
	void (*break_ctl)(struct tty_struct___31 *, int);
	int (*chars_in_buffer)(struct tty_struct___31 *);
	void (*wait_until_sent)(struct tty_struct___31 *, long int);
	bool (*tx_empty)(struct usb_serial_port *);
	void (*throttle)(struct tty_struct___31 *);
	void (*unthrottle)(struct tty_struct___31 *);
	int (*tiocmget)(struct tty_struct___31 *);
	int (*tiocmset)(struct tty_struct___31 *, unsigned int, unsigned int);
	int (*tiocmiwait)(struct tty_struct___31 *, long unsigned int);
	int (*get_icount)(struct tty_struct___31 *, struct serial_icounter_struct *);
	void (*dtr_rts)(struct usb_serial_port *, int);
	int (*carrier_raised)(struct usb_serial_port *);
	void (*init_termios)(struct tty_struct___31 *);
	void (*read_int_callback)(struct urb___17 *);
	void (*write_int_callback)(struct urb___17 *);
	void (*read_bulk_callback)(struct urb___17 *);
	void (*write_bulk_callback)(struct urb___17 *);
	void (*process_read_urb)(struct urb___17 *);
	int (*prepare_write_buffer)(struct usb_serial_port *, void *, size_t);
};

struct usb_serial_endpoints {
	unsigned char num_bulk_in;
	unsigned char num_bulk_out;
	unsigned char num_interrupt_in;
	unsigned char num_interrupt_out;
	struct usb_endpoint_descriptor *bulk_in[16];
	struct usb_endpoint_descriptor *bulk_out[16];
	struct usb_endpoint_descriptor *interrupt_in[16];
	struct usb_endpoint_descriptor *interrupt_out[16];
};

struct usbdrv_wrap___11 {
	struct device_driver___27 driver;
	int for_devices;
};

struct usb_driver___11 {
	const char *name;
	int (*probe)(struct usb_interface___10 *, const struct usb_device_id *);
	void (*disconnect)(struct usb_interface___10 *);
	int (*unlocked_ioctl)(struct usb_interface___10 *, unsigned int, void *);
	int (*suspend)(struct usb_interface___10 *, pm_message_t);
	int (*resume)(struct usb_interface___10 *);
	int (*reset_resume)(struct usb_interface___10 *);
	int (*pre_reset)(struct usb_interface___10 *);
	int (*post_reset)(struct usb_interface___10 *);
	const struct usb_device_id *id_table;
	struct usb_dynids dynids;
	struct usbdrv_wrap___11 drvwrap;
	unsigned int no_dynamic_id: 1;
	unsigned int supports_autosuspend: 1;
	unsigned int disable_hub_initiated_lpm: 1;
	unsigned int soft_unbind: 1;
};

struct usb_serial___2;

struct usb_serial_port___2 {
	struct usb_serial___2 *serial;
	struct tty_port___3 port;
	spinlock_t lock;
	u32 minor;
	u8 port_number;
	unsigned char *interrupt_in_buffer;
	struct urb___10 *interrupt_in_urb;
	__u8 interrupt_in_endpointAddress;
	unsigned char *interrupt_out_buffer;
	int interrupt_out_size;
	struct urb___10 *interrupt_out_urb;
	__u8 interrupt_out_endpointAddress;
	unsigned char *bulk_in_buffer;
	int bulk_in_size;
	struct urb___10 *read_urb;
	__u8 bulk_in_endpointAddress;
	unsigned char *bulk_in_buffers[2];
	struct urb___10 *read_urbs[2];
	long unsigned int read_urbs_free;
	unsigned char *bulk_out_buffer;
	int bulk_out_size;
	struct urb___10 *write_urb;
	struct kfifo write_fifo;
	unsigned char *bulk_out_buffers[2];
	struct urb___10 *write_urbs[2];
	long unsigned int write_urbs_free;
	__u8 bulk_out_endpointAddress;
	struct async_icount icount;
	int tx_bytes;
	long unsigned int flags;
	wait_queue_head_t write_wait;
	struct work_struct work;
	char throttled;
	char throttle_req;
	long unsigned int sysrq;
	struct device___27 dev;
};

struct usb_serial_driver___2;

struct usb_serial___2 {
	struct usb_device___11 *dev;
	struct usb_serial_driver___2 *type;
	struct usb_interface___10 *interface;
	unsigned char disconnected: 1;
	unsigned char suspending: 1;
	unsigned char attached: 1;
	unsigned char minors_reserved: 1;
	unsigned char num_ports;
	unsigned char num_port_pointers;
	unsigned char num_interrupt_in;
	unsigned char num_interrupt_out;
	unsigned char num_bulk_in;
	unsigned char num_bulk_out;
	struct usb_serial_port___2 *port[16];
	struct kref kref;
	struct mutex disc_mutex;
	void *private;
};

struct usb_serial_driver___2 {
	const char *description;
	const struct usb_device_id *id_table;
	struct list_head driver_list;
	struct device_driver___27 driver;
	struct usb_driver___11 *usb_driver;
	struct usb_dynids dynids;
	unsigned char num_ports;
	unsigned char num_bulk_in;
	unsigned char num_bulk_out;
	unsigned char num_interrupt_in;
	unsigned char num_interrupt_out;
	size_t bulk_in_size;
	size_t bulk_out_size;
	int (*probe)(struct usb_serial___2 *, const struct usb_device_id *);
	int (*attach)(struct usb_serial___2 *);
	int (*calc_num_ports)(struct usb_serial___2 *, struct usb_serial_endpoints *);
	void (*disconnect)(struct usb_serial___2 *);
	void (*release)(struct usb_serial___2 *);
	int (*port_probe)(struct usb_serial_port___2 *);
	int (*port_remove)(struct usb_serial_port___2 *);
	int (*suspend)(struct usb_serial___2 *, pm_message_t);
	int (*resume)(struct usb_serial___2 *);
	int (*reset_resume)(struct usb_serial___2 *);
	int (*open)(struct tty_struct___3 *, struct usb_serial_port___2 *);
	void (*close)(struct usb_serial_port___2 *);
	int (*write)(struct tty_struct___3 *, struct usb_serial_port___2 *, const unsigned char *, int);
	int (*write_room)(struct tty_struct___3 *);
	int (*ioctl)(struct tty_struct___3 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___3 *, struct usb_serial_port___2 *, struct ktermios *);
	void (*break_ctl)(struct tty_struct___3 *, int);
	int (*chars_in_buffer)(struct tty_struct___3 *);
	void (*wait_until_sent)(struct tty_struct___3 *, long int);
	bool (*tx_empty)(struct usb_serial_port___2 *);
	void (*throttle)(struct tty_struct___3 *);
	void (*unthrottle)(struct tty_struct___3 *);
	int (*tiocmget)(struct tty_struct___3 *);
	int (*tiocmset)(struct tty_struct___3 *, unsigned int, unsigned int);
	int (*tiocmiwait)(struct tty_struct___3 *, long unsigned int);
	int (*get_icount)(struct tty_struct___3 *, struct serial_icounter_struct *);
	void (*dtr_rts)(struct usb_serial_port___2 *, int);
	int (*carrier_raised)(struct usb_serial_port___2 *);
	void (*init_termios)(struct tty_struct___3 *);
	void (*read_int_callback)(struct urb___10 *);
	void (*write_int_callback)(struct urb___10 *);
	void (*read_bulk_callback)(struct urb___10 *);
	void (*write_bulk_callback)(struct urb___10 *);
	void (*process_read_urb)(struct urb___10 *);
	int (*prepare_write_buffer)(struct usb_serial_port___2 *, void *, size_t);
};

struct driver_attribute___4 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___276 *, char *);
	ssize_t (*store)(struct device_driver___276 *, const char *, size_t);
};

struct usb_serial___3;

struct usb_serial_port___3 {
	struct usb_serial___3 *serial;
	struct tty_port___35 port;
	spinlock_t lock;
	u32 minor;
	u8 port_number;
	unsigned char *interrupt_in_buffer;
	struct urb___3 *interrupt_in_urb;
	__u8 interrupt_in_endpointAddress;
	unsigned char *interrupt_out_buffer;
	int interrupt_out_size;
	struct urb___3 *interrupt_out_urb;
	__u8 interrupt_out_endpointAddress;
	unsigned char *bulk_in_buffer;
	int bulk_in_size;
	struct urb___3 *read_urb;
	__u8 bulk_in_endpointAddress;
	unsigned char *bulk_in_buffers[2];
	struct urb___3 *read_urbs[2];
	long unsigned int read_urbs_free;
	unsigned char *bulk_out_buffer;
	int bulk_out_size;
	struct urb___3 *write_urb;
	struct kfifo write_fifo;
	unsigned char *bulk_out_buffers[2];
	struct urb___3 *write_urbs[2];
	long unsigned int write_urbs_free;
	__u8 bulk_out_endpointAddress;
	struct async_icount icount;
	int tx_bytes;
	long unsigned int flags;
	wait_queue_head_t write_wait;
	struct work_struct work;
	char throttled;
	char throttle_req;
	long unsigned int sysrq;
	struct device___345 dev;
};

struct usb_serial_driver___3;

struct usb_serial___3 {
	struct usb_device___3 *dev;
	struct usb_serial_driver___3 *type;
	struct usb_interface___3 *interface;
	unsigned char disconnected: 1;
	unsigned char suspending: 1;
	unsigned char attached: 1;
	unsigned char minors_reserved: 1;
	unsigned char num_ports;
	unsigned char num_port_pointers;
	unsigned char num_interrupt_in;
	unsigned char num_interrupt_out;
	unsigned char num_bulk_in;
	unsigned char num_bulk_out;
	struct usb_serial_port___3 *port[16];
	struct kref kref;
	struct mutex disc_mutex;
	void *private;
};

struct usb_serial_driver___3 {
	const char *description;
	const struct usb_device_id *id_table;
	struct list_head driver_list;
	struct device_driver___345 driver;
	struct usb_driver___3 *usb_driver;
	struct usb_dynids dynids;
	unsigned char num_ports;
	unsigned char num_bulk_in;
	unsigned char num_bulk_out;
	unsigned char num_interrupt_in;
	unsigned char num_interrupt_out;
	size_t bulk_in_size;
	size_t bulk_out_size;
	int (*probe)(struct usb_serial___3 *, const struct usb_device_id *);
	int (*attach)(struct usb_serial___3 *);
	int (*calc_num_ports)(struct usb_serial___3 *, struct usb_serial_endpoints *);
	void (*disconnect)(struct usb_serial___3 *);
	void (*release)(struct usb_serial___3 *);
	int (*port_probe)(struct usb_serial_port___3 *);
	int (*port_remove)(struct usb_serial_port___3 *);
	int (*suspend)(struct usb_serial___3 *, pm_message_t);
	int (*resume)(struct usb_serial___3 *);
	int (*reset_resume)(struct usb_serial___3 *);
	int (*open)(struct tty_struct___35 *, struct usb_serial_port___3 *);
	void (*close)(struct usb_serial_port___3 *);
	int (*write)(struct tty_struct___35 *, struct usb_serial_port___3 *, const unsigned char *, int);
	int (*write_room)(struct tty_struct___35 *);
	int (*ioctl)(struct tty_struct___35 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___35 *, struct usb_serial_port___3 *, struct ktermios *);
	void (*break_ctl)(struct tty_struct___35 *, int);
	int (*chars_in_buffer)(struct tty_struct___35 *);
	void (*wait_until_sent)(struct tty_struct___35 *, long int);
	bool (*tx_empty)(struct usb_serial_port___3 *);
	void (*throttle)(struct tty_struct___35 *);
	void (*unthrottle)(struct tty_struct___35 *);
	int (*tiocmget)(struct tty_struct___35 *);
	int (*tiocmset)(struct tty_struct___35 *, unsigned int, unsigned int);
	int (*tiocmiwait)(struct tty_struct___35 *, long unsigned int);
	int (*get_icount)(struct tty_struct___35 *, struct serial_icounter_struct *);
	void (*dtr_rts)(struct usb_serial_port___3 *, int);
	int (*carrier_raised)(struct usb_serial_port___3 *);
	void (*init_termios)(struct tty_struct___35 *);
	void (*read_int_callback)(struct urb___3 *);
	void (*write_int_callback)(struct urb___3 *);
	void (*read_bulk_callback)(struct urb___3 *);
	void (*write_bulk_callback)(struct urb___3 *);
	void (*process_read_urb)(struct urb___3 *);
	int (*prepare_write_buffer)(struct usb_serial_port___3 *, void *, size_t);
};

struct usbcons_info {
	int magic;
	int break_flag;
	struct usb_serial_port___3 *port;
};

struct usb_otg_caps {
	u16 otg_rev;
	bool hnp_support;
	bool srp_support;
	bool adp_support;
};

enum usb_dr_mode {
	USB_DR_MODE_UNKNOWN = 0,
	USB_DR_MODE_HOST = 1,
	USB_DR_MODE_PERIPHERAL = 2,
	USB_DR_MODE_OTG = 3,
};

enum usb_role {
	USB_ROLE_NONE = 0,
	USB_ROLE_HOST = 1,
	USB_ROLE_DEVICE = 2,
};

typedef int (*usb_role_switch_set_t)(struct device___349 *, enum usb_role);

typedef enum usb_role (*usb_role_switch_get_t)(struct device___349 *);

struct usb_role_switch_desc {
	struct device___349 *usb2_port;
	struct device___349 *usb3_port;
	struct device___349 *udc;
	usb_role_switch_set_t set;
	usb_role_switch_get_t get;
	bool allow_userspace_control;
};

struct usb_role_switch {
	struct device___349 dev;
	struct mutex lock;
	enum usb_role role;
	struct device___349 *usb2_port;
	struct device___349 *usb3_port;
	struct device___349 *udc;
	usb_role_switch_set_t set;
	usb_role_switch_get_t get;
	bool allow_userspace_control;
};

struct typec_device_id {
	__u16 svid;
	__u8 mode;
	kernel_ulong_t driver_data;
};

enum typec_port_type {
	TYPEC_PORT_SRC = 0,
	TYPEC_PORT_SNK = 1,
	TYPEC_PORT_DRP = 2,
};

enum typec_port_data {
	TYPEC_PORT_DFP = 0,
	TYPEC_PORT_UFP = 1,
	TYPEC_PORT_DRD = 2,
};

enum typec_plug_type {
	USB_PLUG_NONE = 0,
	USB_PLUG_TYPE_A = 1,
	USB_PLUG_TYPE_B = 2,
	USB_PLUG_TYPE_C = 3,
	USB_PLUG_CAPTIVE = 4,
};

enum typec_data_role {
	TYPEC_DEVICE = 0,
	TYPEC_HOST = 1,
};

enum typec_role {
	TYPEC_SINK = 0,
	TYPEC_SOURCE = 1,
};

enum typec_pwr_opmode {
	TYPEC_PWR_MODE_USB = 0,
	TYPEC_PWR_MODE_1_5A = 1,
	TYPEC_PWR_MODE_3_0A = 2,
	TYPEC_PWR_MODE_PD = 3,
};

enum typec_accessory {
	TYPEC_ACCESSORY_NONE = 0,
	TYPEC_ACCESSORY_AUDIO = 1,
	TYPEC_ACCESSORY_DEBUG = 2,
};

enum typec_orientation {
	TYPEC_ORIENTATION_NONE = 0,
	TYPEC_ORIENTATION_NORMAL = 1,
	TYPEC_ORIENTATION_REVERSE = 2,
};

struct usb_pd_identity {
	u32 id_header;
	u32 cert_stat;
	u32 product;
};

struct typec_altmode_desc {
	u16 svid;
	u8 mode;
	u32 vdo;
	enum typec_port_data roles;
};

enum typec_plug_index {
	TYPEC_PLUG_SOP_P = 0,
	TYPEC_PLUG_SOP_PP = 1,
};

struct typec_plug_desc {
	enum typec_plug_index index;
};

struct typec_cable_desc {
	enum typec_plug_type type;
	unsigned int active: 1;
	struct usb_pd_identity *identity;
};

struct typec_partner_desc {
	unsigned int usb_pd: 1;
	enum typec_accessory accessory;
	struct usb_pd_identity *identity;
};

struct typec_switch;

struct typec_mux;

struct typec_capability {
	enum typec_port_type type;
	enum typec_port_data data;
	u16 revision;
	u16 pd_revision;
	int prefer_role;
	enum typec_accessory accessory[3];
	struct typec_switch *sw;
	struct typec_mux *mux;
	struct fwnode_handle___4 *fwnode;
	int (*try_role)(const struct typec_capability *, int);
	int (*dr_set)(const struct typec_capability *, enum typec_data_role);
	int (*pr_set)(const struct typec_capability *, enum typec_role);
	int (*vconn_set)(const struct typec_capability *, enum typec_role);
	int (*port_type_set)(const struct typec_capability *, enum typec_port_type);
};

struct typec_switch {
	struct device___349 *dev;
	struct list_head entry;
	int (*set)(struct typec_switch *, enum typec_orientation);
};

struct typec_mux {
	struct device___349 *dev;
	struct list_head entry;
	int (*set)(struct typec_mux *, int);
};

struct typec_altmode_ops;

struct typec_altmode {
	struct device___349 dev;
	u16 svid;
	int mode;
	u32 vdo;
	unsigned int active: 1;
	char *desc;
	const struct typec_altmode_ops *ops;
};

struct typec_altmode_ops {
	int (*enter)(struct typec_altmode *);
	int (*exit)(struct typec_altmode *);
	void (*attention)(struct typec_altmode *, u32);
	int (*vdm)(struct typec_altmode *, const u32, const u32 *, int);
	int (*notify)(struct typec_altmode *, long unsigned int, void *);
	int (*activate)(struct typec_altmode *, int);
};

enum {
	TYPEC_STATE_SAFE = 0,
	TYPEC_STATE_USB = 1,
	TYPEC_STATE_MODAL = 2,
};

struct altmode {
	unsigned int id;
	struct typec_altmode adev;
	struct typec_mux *mux;
	enum typec_port_data roles;
	struct attribute *attrs[5];
	char group_name[6];
	struct attribute_group___347 group;
	const struct attribute_group___347 *groups[2];
	struct altmode *partner;
	struct altmode *plug[2];
	struct blocking_notifier_head___383 nh;
};

struct typec_plug {
	struct device___349 dev;
	enum typec_plug_index index;
	struct ida mode_ids;
};

struct typec_cable {
	struct device___349 dev;
	enum typec_plug_type type;
	struct usb_pd_identity *identity;
	unsigned int active: 1;
};

struct typec_partner {
	struct device___349 dev;
	unsigned int usb_pd: 1;
	struct usb_pd_identity *identity;
	enum typec_accessory accessory;
	struct ida mode_ids;
};

struct typec_port {
	unsigned int id;
	struct device___349 dev;
	struct ida mode_ids;
	int prefer_role;
	enum typec_data_role data_role;
	enum typec_role pwr_role;
	enum typec_role vconn_role;
	enum typec_pwr_opmode pwr_opmode;
	enum typec_port_type port_type;
	struct mutex port_type_lock;
	enum typec_orientation orientation;
	struct typec_switch *sw;
	struct typec_mux *mux;
	const struct typec_capability *cap;
};

struct typec_altmode_driver {
	const struct typec_device_id *id_table;
	int (*probe)(struct typec_altmode *);
	void (*remove)(struct typec_altmode *);
	struct device_driver___349 driver;
};

struct typec_altmode_ops___2;

struct typec_altmode___2 {
	struct device___345 dev;
	u16 svid;
	int mode;
	u32 vdo;
	unsigned int active: 1;
	char *desc;
	const struct typec_altmode_ops___2 *ops;
};

struct typec_altmode_ops___2 {
	int (*enter)(struct typec_altmode___2 *);
	int (*exit)(struct typec_altmode___2 *);
	void (*attention)(struct typec_altmode___2 *, u32);
	int (*vdm)(struct typec_altmode___2 *, const u32, const u32 *, int);
	int (*notify)(struct typec_altmode___2 *, long unsigned int, void *);
	int (*activate)(struct typec_altmode___2 *, int);
};

struct typec_altmode_driver___2 {
	const struct typec_device_id *id_table;
	int (*probe)(struct typec_altmode___2 *);
	void (*remove)(struct typec_altmode___2 *);
	struct device_driver___345 driver;
};

struct typec_displayport_data {
	u32 status;
	u32 conf;
};

enum {
	DP_PIN_ASSIGN_A = 0,
	DP_PIN_ASSIGN_B = 1,
	DP_PIN_ASSIGN_C = 2,
	DP_PIN_ASSIGN_D = 3,
	DP_PIN_ASSIGN_E = 4,
	DP_PIN_ASSIGN_F = 5,
};

enum {
	DP_CONF_USB = 0,
	DP_CONF_DFP_D = 1,
	DP_CONF_UFP_D = 2,
	DP_CONF_DUAL_D = 3,
};

enum dp_state {
	DP_STATE_IDLE = 0,
	DP_STATE_ENTER = 1,
	DP_STATE_UPDATE = 2,
	DP_STATE_CONFIGURE = 3,
	DP_STATE_EXIT = 4,
};

struct dp_altmode {
	struct typec_displayport_data data;
	enum dp_state state;
	struct mutex lock;
	struct work_struct work;
	struct typec_altmode___2 *alt;
	const struct typec_altmode___2 *port;
};

struct led_trigger___5;

struct led_classdev___5 {
	const char *name;
	enum led_brightness brightness;
	enum led_brightness max_brightness;
	int flags;
	long unsigned int work_flags;
	void (*brightness_set)(struct led_classdev___5 *, enum led_brightness);
	int (*brightness_set_blocking)(struct led_classdev___5 *, enum led_brightness);
	enum led_brightness (*brightness_get)(struct led_classdev___5 *);
	int (*blink_set)(struct led_classdev___5 *, long unsigned int *, long unsigned int *);
	int (*pattern_set)(struct led_classdev___5 *, struct led_pattern *, u32, int);
	int (*pattern_clear)(struct led_classdev___5 *);
	struct device___293 *dev;
	const struct attribute_group___291 **groups;
	struct list_head node;
	const char *default_trigger;
	long unsigned int blink_delay_on;
	long unsigned int blink_delay_off;
	struct timer_list blink_timer;
	int blink_brightness;
	int new_blink_brightness;
	void (*flash_resume)(struct led_classdev___5 *);
	struct work_struct set_brightness_work;
	int delayed_set_value;
	struct rw_semaphore___328 trigger_lock;
	struct led_trigger___5 *trigger;
	struct list_head trig_list;
	void *trigger_data;
	bool activated;
	struct mutex led_access;
};

struct led_trigger___5 {
	const char *name;
	void (*activate)(struct led_classdev___5 *);
	void (*deactivate)(struct led_classdev___5 *);
	rwlock_t leddev_list_lock;
	struct list_head led_cdevs;
	struct list_head next_trig;
};

enum power_supply_property {
	POWER_SUPPLY_PROP_STATUS = 0,
	POWER_SUPPLY_PROP_CHARGE_TYPE = 1,
	POWER_SUPPLY_PROP_HEALTH = 2,
	POWER_SUPPLY_PROP_PRESENT = 3,
	POWER_SUPPLY_PROP_ONLINE = 4,
	POWER_SUPPLY_PROP_AUTHENTIC = 5,
	POWER_SUPPLY_PROP_TECHNOLOGY = 6,
	POWER_SUPPLY_PROP_CYCLE_COUNT = 7,
	POWER_SUPPLY_PROP_VOLTAGE_MAX = 8,
	POWER_SUPPLY_PROP_VOLTAGE_MIN = 9,
	POWER_SUPPLY_PROP_VOLTAGE_MAX_DESIGN = 10,
	POWER_SUPPLY_PROP_VOLTAGE_MIN_DESIGN = 11,
	POWER_SUPPLY_PROP_VOLTAGE_NOW = 12,
	POWER_SUPPLY_PROP_VOLTAGE_AVG = 13,
	POWER_SUPPLY_PROP_VOLTAGE_OCV = 14,
	POWER_SUPPLY_PROP_VOLTAGE_BOOT = 15,
	POWER_SUPPLY_PROP_CURRENT_MAX = 16,
	POWER_SUPPLY_PROP_CURRENT_NOW = 17,
	POWER_SUPPLY_PROP_CURRENT_AVG = 18,
	POWER_SUPPLY_PROP_CURRENT_BOOT = 19,
	POWER_SUPPLY_PROP_POWER_NOW = 20,
	POWER_SUPPLY_PROP_POWER_AVG = 21,
	POWER_SUPPLY_PROP_CHARGE_FULL_DESIGN = 22,
	POWER_SUPPLY_PROP_CHARGE_EMPTY_DESIGN = 23,
	POWER_SUPPLY_PROP_CHARGE_FULL = 24,
	POWER_SUPPLY_PROP_CHARGE_EMPTY = 25,
	POWER_SUPPLY_PROP_CHARGE_NOW = 26,
	POWER_SUPPLY_PROP_CHARGE_AVG = 27,
	POWER_SUPPLY_PROP_CHARGE_COUNTER = 28,
	POWER_SUPPLY_PROP_CONSTANT_CHARGE_CURRENT = 29,
	POWER_SUPPLY_PROP_CONSTANT_CHARGE_CURRENT_MAX = 30,
	POWER_SUPPLY_PROP_CONSTANT_CHARGE_VOLTAGE = 31,
	POWER_SUPPLY_PROP_CONSTANT_CHARGE_VOLTAGE_MAX = 32,
	POWER_SUPPLY_PROP_CHARGE_CONTROL_LIMIT = 33,
	POWER_SUPPLY_PROP_CHARGE_CONTROL_LIMIT_MAX = 34,
	POWER_SUPPLY_PROP_INPUT_CURRENT_LIMIT = 35,
	POWER_SUPPLY_PROP_ENERGY_FULL_DESIGN = 36,
	POWER_SUPPLY_PROP_ENERGY_EMPTY_DESIGN = 37,
	POWER_SUPPLY_PROP_ENERGY_FULL = 38,
	POWER_SUPPLY_PROP_ENERGY_EMPTY = 39,
	POWER_SUPPLY_PROP_ENERGY_NOW = 40,
	POWER_SUPPLY_PROP_ENERGY_AVG = 41,
	POWER_SUPPLY_PROP_CAPACITY = 42,
	POWER_SUPPLY_PROP_CAPACITY_ALERT_MIN = 43,
	POWER_SUPPLY_PROP_CAPACITY_ALERT_MAX = 44,
	POWER_SUPPLY_PROP_CAPACITY_LEVEL = 45,
	POWER_SUPPLY_PROP_TEMP = 46,
	POWER_SUPPLY_PROP_TEMP_MAX = 47,
	POWER_SUPPLY_PROP_TEMP_MIN = 48,
	POWER_SUPPLY_PROP_TEMP_ALERT_MIN = 49,
	POWER_SUPPLY_PROP_TEMP_ALERT_MAX = 50,
	POWER_SUPPLY_PROP_TEMP_AMBIENT = 51,
	POWER_SUPPLY_PROP_TEMP_AMBIENT_ALERT_MIN = 52,
	POWER_SUPPLY_PROP_TEMP_AMBIENT_ALERT_MAX = 53,
	POWER_SUPPLY_PROP_TIME_TO_EMPTY_NOW = 54,
	POWER_SUPPLY_PROP_TIME_TO_EMPTY_AVG = 55,
	POWER_SUPPLY_PROP_TIME_TO_FULL_NOW = 56,
	POWER_SUPPLY_PROP_TIME_TO_FULL_AVG = 57,
	POWER_SUPPLY_PROP_TYPE = 58,
	POWER_SUPPLY_PROP_USB_TYPE = 59,
	POWER_SUPPLY_PROP_SCOPE = 60,
	POWER_SUPPLY_PROP_PRECHARGE_CURRENT = 61,
	POWER_SUPPLY_PROP_CHARGE_TERM_CURRENT = 62,
	POWER_SUPPLY_PROP_CALIBRATE = 63,
	POWER_SUPPLY_PROP_MODEL_NAME = 64,
	POWER_SUPPLY_PROP_MANUFACTURER = 65,
	POWER_SUPPLY_PROP_SERIAL_NUMBER = 66,
};

enum power_supply_type {
	POWER_SUPPLY_TYPE_UNKNOWN = 0,
	POWER_SUPPLY_TYPE_BATTERY = 1,
	POWER_SUPPLY_TYPE_UPS = 2,
	POWER_SUPPLY_TYPE_MAINS = 3,
	POWER_SUPPLY_TYPE_USB = 4,
	POWER_SUPPLY_TYPE_USB_DCP = 5,
	POWER_SUPPLY_TYPE_USB_CDP = 6,
	POWER_SUPPLY_TYPE_USB_ACA = 7,
	POWER_SUPPLY_TYPE_USB_TYPE_C = 8,
	POWER_SUPPLY_TYPE_USB_PD = 9,
	POWER_SUPPLY_TYPE_USB_PD_DRP = 10,
	POWER_SUPPLY_TYPE_APPLE_BRICK_ID = 11,
};

enum power_supply_usb_type {
	POWER_SUPPLY_USB_TYPE_UNKNOWN = 0,
	POWER_SUPPLY_USB_TYPE_SDP = 1,
	POWER_SUPPLY_USB_TYPE_DCP = 2,
	POWER_SUPPLY_USB_TYPE_CDP = 3,
	POWER_SUPPLY_USB_TYPE_ACA = 4,
	POWER_SUPPLY_USB_TYPE_C = 5,
	POWER_SUPPLY_USB_TYPE_PD = 6,
	POWER_SUPPLY_USB_TYPE_PD_DRP = 7,
	POWER_SUPPLY_USB_TYPE_PD_PPS = 8,
	POWER_SUPPLY_USB_TYPE_APPLE_BRICK_ID = 9,
};

union power_supply_propval {
	int intval;
	const char *strval;
};

struct power_supply_config {
	struct device_node___2 *of_node;
	struct fwnode_handle___222 *fwnode;
	void *drv_data;
	char **supplied_to;
	size_t num_supplicants;
};

struct power_supply;

struct power_supply_desc {
	const char *name;
	enum power_supply_type type;
	enum power_supply_usb_type *usb_types;
	size_t num_usb_types;
	enum power_supply_property *properties;
	size_t num_properties;
	int (*get_property)(struct power_supply *, enum power_supply_property, union power_supply_propval *);
	int (*set_property)(struct power_supply *, enum power_supply_property, const union power_supply_propval *);
	int (*property_is_writeable)(struct power_supply *, enum power_supply_property);
	void (*external_power_changed)(struct power_supply *);
	void (*set_charged)(struct power_supply *);
	bool no_thermal;
	int use_for_apm;
};

struct thermal_zone_device___5;

struct thermal_cooling_device___5;

struct power_supply {
	const struct power_supply_desc *desc;
	char **supplied_to;
	size_t num_supplicants;
	char **supplied_from;
	size_t num_supplies;
	struct device_node___2 *of_node;
	void *drv_data;
	struct device___293 dev;
	struct work_struct changed_work;
	struct delayed_work deferred_register_work;
	spinlock_t changed_lock;
	bool changed;
	bool initialized;
	bool removing;
	atomic_t use_cnt;
	struct thermal_zone_device___5 *tzd;
	struct thermal_cooling_device___5 *tcd;
	struct led_trigger___5 *charging_full_trig;
	char *charging_full_trig_name;
	struct led_trigger___5 *charging_trig;
	char *charging_trig_name;
	struct led_trigger___5 *full_trig;
	char *full_trig_name;
	struct led_trigger___5 *online_trig;
	char *online_trig_name;
	struct led_trigger___5 *charging_blink_full_solid_trig;
	char *charging_blink_full_solid_trig_name;
};

struct typec_switch___2;

struct typec_mux___2;

struct typec_capability___2 {
	enum typec_port_type type;
	enum typec_port_data data;
	u16 revision;
	u16 pd_revision;
	int prefer_role;
	enum typec_accessory accessory[3];
	struct typec_switch___2 *sw;
	struct typec_mux___2 *mux;
	struct fwnode_handle___222 *fwnode;
	int (*try_role)(const struct typec_capability___2 *, int);
	int (*dr_set)(const struct typec_capability___2 *, enum typec_data_role);
	int (*pr_set)(const struct typec_capability___2 *, enum typec_role);
	int (*vconn_set)(const struct typec_capability___2 *, enum typec_role);
	int (*port_type_set)(const struct typec_capability___2 *, enum typec_port_type);
};

enum pd_ctrl_msg_type {
	PD_CTRL_GOOD_CRC = 1,
	PD_CTRL_GOTO_MIN = 2,
	PD_CTRL_ACCEPT = 3,
	PD_CTRL_REJECT = 4,
	PD_CTRL_PING = 5,
	PD_CTRL_PS_RDY = 6,
	PD_CTRL_GET_SOURCE_CAP = 7,
	PD_CTRL_GET_SINK_CAP = 8,
	PD_CTRL_DR_SWAP = 9,
	PD_CTRL_PR_SWAP = 10,
	PD_CTRL_VCONN_SWAP = 11,
	PD_CTRL_WAIT = 12,
	PD_CTRL_SOFT_RESET = 13,
	PD_CTRL_NOT_SUPP = 16,
	PD_CTRL_GET_SOURCE_CAP_EXT = 17,
	PD_CTRL_GET_STATUS = 18,
	PD_CTRL_FR_SWAP = 19,
	PD_CTRL_GET_PPS_STATUS = 20,
	PD_CTRL_GET_COUNTRY_CODES = 21,
};

enum pd_data_msg_type {
	PD_DATA_SOURCE_CAP = 1,
	PD_DATA_REQUEST = 2,
	PD_DATA_BIST = 3,
	PD_DATA_SINK_CAP = 4,
	PD_DATA_BATT_STATUS = 5,
	PD_DATA_ALERT = 6,
	PD_DATA_GET_COUNTRY_INFO = 7,
	PD_DATA_VENDOR_DEF = 15,
};

enum pd_ext_msg_type {
	PD_EXT_SOURCE_CAP_EXT = 1,
	PD_EXT_STATUS = 2,
	PD_EXT_GET_BATT_CAP = 3,
	PD_EXT_GET_BATT_STATUS = 4,
	PD_EXT_BATT_CAP = 5,
	PD_EXT_GET_MANUFACTURER_INFO = 6,
	PD_EXT_MANUFACTURER_INFO = 7,
	PD_EXT_SECURITY_REQUEST = 8,
	PD_EXT_SECURITY_RESPONSE = 9,
	PD_EXT_FW_UPDATE_REQUEST = 10,
	PD_EXT_FW_UPDATE_RESPONSE = 11,
	PD_EXT_PPS_STATUS = 12,
	PD_EXT_COUNTRY_INFO = 13,
	PD_EXT_COUNTRY_CODES = 14,
};

struct pd_chunked_ext_message_data {
	__le16 header;
	u8 data[26];
};

struct pd_message {
	__le16 header;
	union {
		__le32 payload[7];
		struct pd_chunked_ext_message_data ext_msg;
	};
} __attribute__((packed));

enum pd_pdo_type {
	PDO_TYPE_FIXED = 0,
	PDO_TYPE_BATT = 1,
	PDO_TYPE_VAR = 2,
	PDO_TYPE_APDO = 3,
};

enum pd_apdo_type {
	APDO_TYPE_PPS = 0,
};

enum usb_pd_ext_sdb_fields {
	USB_PD_EXT_SDB_INTERNAL_TEMP = 0,
	USB_PD_EXT_SDB_PRESENT_INPUT = 1,
	USB_PD_EXT_SDB_PRESENT_BATT_INPUT = 2,
	USB_PD_EXT_SDB_EVENT_FLAGS = 3,
	USB_PD_EXT_SDB_TEMP_STATUS = 4,
	USB_PD_EXT_SDB_DATA_SIZE = 5,
};

enum typec_cc_status {
	TYPEC_CC_OPEN = 0,
	TYPEC_CC_RA = 1,
	TYPEC_CC_RD = 2,
	TYPEC_CC_RP_DEF = 3,
	TYPEC_CC_RP_1_5 = 4,
	TYPEC_CC_RP_3_0 = 5,
};

enum typec_cc_polarity {
	TYPEC_POLARITY_CC1 = 0,
	TYPEC_POLARITY_CC2 = 1,
};

enum tcpm_transmit_status {
	TCPC_TX_SUCCESS = 0,
	TCPC_TX_DISCARDED = 1,
	TCPC_TX_FAILED = 2,
};

enum tcpm_transmit_type {
	TCPC_TX_SOP = 0,
	TCPC_TX_SOP_PRIME = 1,
	TCPC_TX_SOP_PRIME_PRIME = 2,
	TCPC_TX_SOP_DEBUG_PRIME = 3,
	TCPC_TX_SOP_DEBUG_PRIME_PRIME = 4,
	TCPC_TX_HARD_RESET = 5,
	TCPC_TX_CABLE_RESET = 6,
	TCPC_TX_BIST_MODE_2 = 7,
};

struct tcpc_config {
	const u32 *src_pdo;
	unsigned int nr_src_pdo;
	const u32 *snk_pdo;
	unsigned int nr_snk_pdo;
	const u32 *snk_vdo;
	unsigned int nr_snk_vdo;
	unsigned int operating_snk_mw;
	enum typec_port_type type;
	enum typec_port_data data;
	enum typec_role default_role;
	bool try_role_hw;
	const struct typec_altmode_desc *alt_modes;
};

struct tcpc_dev {
	const struct tcpc_config *config;
	struct fwnode_handle___222 *fwnode;
	int (*init)(struct tcpc_dev *);
	int (*get_vbus)(struct tcpc_dev *);
	int (*get_current_limit)(struct tcpc_dev *);
	int (*set_cc)(struct tcpc_dev *, enum typec_cc_status);
	int (*get_cc)(struct tcpc_dev *, enum typec_cc_status *, enum typec_cc_status *);
	int (*set_polarity)(struct tcpc_dev *, enum typec_cc_polarity);
	int (*set_vconn)(struct tcpc_dev *, bool);
	int (*set_vbus)(struct tcpc_dev *, bool, bool);
	int (*set_current_limit)(struct tcpc_dev *, u32, u32);
	int (*set_pd_rx)(struct tcpc_dev *, bool);
	int (*set_roles)(struct tcpc_dev *, bool, enum typec_role, enum typec_data_role);
	int (*start_drp_toggling)(struct tcpc_dev *, enum typec_cc_status);
	int (*try_role)(struct tcpc_dev *, int);
	int (*pd_transmit)(struct tcpc_dev *, enum tcpm_transmit_type, const struct pd_message *);
};

struct typec_altmode_ops___3;

struct typec_altmode___3 {
	struct device___293 dev;
	u16 svid;
	int mode;
	u32 vdo;
	unsigned int active: 1;
	char *desc;
	const struct typec_altmode_ops___3 *ops;
};

struct typec_altmode_ops___3 {
	int (*enter)(struct typec_altmode___3 *);
	int (*exit)(struct typec_altmode___3 *);
	void (*attention)(struct typec_altmode___3 *, u32);
	int (*vdm)(struct typec_altmode___3 *, const u32, const u32 *, int);
	int (*notify)(struct typec_altmode___3 *, long unsigned int, void *);
	int (*activate)(struct typec_altmode___3 *, int);
};

enum tcpm_state {
	INVALID_STATE = 0,
	DRP_TOGGLING = 1,
	SRC_UNATTACHED = 2,
	SRC_ATTACH_WAIT = 3,
	SRC_ATTACHED = 4,
	SRC_STARTUP = 5,
	SRC_SEND_CAPABILITIES = 6,
	SRC_NEGOTIATE_CAPABILITIES = 7,
	SRC_TRANSITION_SUPPLY = 8,
	SRC_READY = 9,
	SRC_WAIT_NEW_CAPABILITIES = 10,
	SNK_UNATTACHED = 11,
	SNK_ATTACH_WAIT = 12,
	SNK_DEBOUNCED = 13,
	SNK_ATTACHED = 14,
	SNK_STARTUP = 15,
	SNK_DISCOVERY = 16,
	SNK_DISCOVERY_DEBOUNCE = 17,
	SNK_DISCOVERY_DEBOUNCE_DONE = 18,
	SNK_WAIT_CAPABILITIES = 19,
	SNK_NEGOTIATE_CAPABILITIES = 20,
	SNK_NEGOTIATE_PPS_CAPABILITIES = 21,
	SNK_TRANSITION_SINK = 22,
	SNK_TRANSITION_SINK_VBUS = 23,
	SNK_READY = 24,
	ACC_UNATTACHED = 25,
	DEBUG_ACC_ATTACHED = 26,
	AUDIO_ACC_ATTACHED = 27,
	AUDIO_ACC_DEBOUNCE = 28,
	HARD_RESET_SEND = 29,
	HARD_RESET_START = 30,
	SRC_HARD_RESET_VBUS_OFF = 31,
	SRC_HARD_RESET_VBUS_ON = 32,
	SNK_HARD_RESET_SINK_OFF = 33,
	SNK_HARD_RESET_WAIT_VBUS = 34,
	SNK_HARD_RESET_SINK_ON = 35,
	SOFT_RESET = 36,
	SOFT_RESET_SEND = 37,
	DR_SWAP_ACCEPT = 38,
	DR_SWAP_SEND = 39,
	DR_SWAP_SEND_TIMEOUT = 40,
	DR_SWAP_CANCEL = 41,
	DR_SWAP_CHANGE_DR = 42,
	PR_SWAP_ACCEPT = 43,
	PR_SWAP_SEND = 44,
	PR_SWAP_SEND_TIMEOUT = 45,
	PR_SWAP_CANCEL = 46,
	PR_SWAP_START = 47,
	PR_SWAP_SRC_SNK_TRANSITION_OFF = 48,
	PR_SWAP_SRC_SNK_SOURCE_OFF = 49,
	PR_SWAP_SRC_SNK_SOURCE_OFF_CC_DEBOUNCED = 50,
	PR_SWAP_SRC_SNK_SINK_ON = 51,
	PR_SWAP_SNK_SRC_SINK_OFF = 52,
	PR_SWAP_SNK_SRC_SOURCE_ON = 53,
	PR_SWAP_SNK_SRC_SOURCE_ON_VBUS_RAMPED_UP = 54,
	VCONN_SWAP_ACCEPT = 55,
	VCONN_SWAP_SEND = 56,
	VCONN_SWAP_SEND_TIMEOUT = 57,
	VCONN_SWAP_CANCEL = 58,
	VCONN_SWAP_START = 59,
	VCONN_SWAP_WAIT_FOR_VCONN = 60,
	VCONN_SWAP_TURN_ON_VCONN = 61,
	VCONN_SWAP_TURN_OFF_VCONN = 62,
	SNK_TRY = 63,
	SNK_TRY_WAIT = 64,
	SNK_TRY_WAIT_DEBOUNCE = 65,
	SNK_TRY_WAIT_DEBOUNCE_CHECK_VBUS = 66,
	SRC_TRYWAIT = 67,
	SRC_TRYWAIT_DEBOUNCE = 68,
	SRC_TRYWAIT_UNATTACHED = 69,
	SRC_TRY = 70,
	SRC_TRY_WAIT = 71,
	SRC_TRY_DEBOUNCE = 72,
	SNK_TRYWAIT = 73,
	SNK_TRYWAIT_DEBOUNCE = 74,
	SNK_TRYWAIT_VBUS = 75,
	BIST_RX = 76,
	GET_STATUS_SEND = 77,
	GET_STATUS_SEND_TIMEOUT = 78,
	GET_PPS_STATUS_SEND = 79,
	GET_PPS_STATUS_SEND_TIMEOUT = 80,
	ERROR_RECOVERY = 81,
	PORT_RESET = 82,
	PORT_RESET_WAIT_OFF = 83,
};

enum vdm_states {
	VDM_STATE_ERR_BUSY = 4294967293,
	VDM_STATE_ERR_SEND = 4294967294,
	VDM_STATE_ERR_TMOUT = 4294967295,
	VDM_STATE_DONE = 0,
	VDM_STATE_READY = 1,
	VDM_STATE_BUSY = 2,
	VDM_STATE_WAIT_RSP_BUSY = 3,
};

enum pd_msg_request {
	PD_MSG_NONE = 0,
	PD_MSG_CTRL_REJECT = 1,
	PD_MSG_CTRL_WAIT = 2,
	PD_MSG_CTRL_NOT_SUPP = 3,
	PD_MSG_DATA_SINK_CAP = 4,
	PD_MSG_DATA_SOURCE_CAP = 5,
};

struct pd_mode_data {
	int svid_index;
	int nsvids;
	u16 svids[16];
	int altmodes;
	struct typec_altmode_desc altmode_desc[96];
};

struct pd_pps_data {
	u32 min_volt;
	u32 max_volt;
	u32 max_curr;
	u32 out_volt;
	u32 op_curr;
	bool supported;
	bool active;
};

struct typec_port___2;

struct usb_role_switch___2;

struct typec_partner___2;

struct tcpm_port {
	struct device___293 *dev;
	struct mutex lock;
	struct workqueue_struct *wq;
	struct typec_capability___2 typec_caps;
	struct typec_port___2 *typec_port;
	struct tcpc_dev *tcpc;
	struct usb_role_switch___2 *role_sw;
	enum typec_role vconn_role;
	enum typec_role pwr_role;
	enum typec_data_role data_role;
	enum typec_pwr_opmode pwr_opmode;
	struct usb_pd_identity partner_ident;
	struct typec_partner_desc partner_desc;
	struct typec_partner___2 *partner;
	enum typec_cc_status cc_req;
	enum typec_cc_status cc1;
	enum typec_cc_status cc2;
	enum typec_cc_polarity polarity;
	bool attached;
	bool connected;
	enum typec_port_type port_type;
	bool vbus_present;
	bool vbus_never_low;
	bool vbus_source;
	bool vbus_charge;
	bool send_discover;
	bool op_vsafe5v;
	int try_role;
	int try_snk_count;
	int try_src_count;
	enum pd_msg_request queued_message;
	enum tcpm_state enter_state;
	enum tcpm_state prev_state;
	enum tcpm_state state;
	enum tcpm_state delayed_state;
	long unsigned int delayed_runtime;
	long unsigned int delay_ms;
	spinlock_t pd_event_lock;
	u32 pd_events;
	struct work_struct event_work;
	struct delayed_work state_machine;
	struct delayed_work vdm_state_machine;
	bool state_machine_running;
	struct completion tx_complete;
	enum tcpm_transmit_status tx_status;
	struct mutex swap_lock;
	bool swap_pending;
	bool non_pd_role_swap;
	struct completion swap_complete;
	int swap_status;
	unsigned int negotiated_rev;
	unsigned int message_id;
	unsigned int caps_count;
	unsigned int hard_reset_count;
	bool pd_capable;
	bool explicit_contract;
	unsigned int rx_msgid;
	u32 sink_request;
	u32 source_caps[7];
	unsigned int nr_source_caps;
	u32 sink_caps[7];
	unsigned int nr_sink_caps;
	u32 src_pdo[7];
	unsigned int nr_src_pdo;
	u32 snk_pdo[7];
	unsigned int nr_snk_pdo;
	u32 snk_vdo[6];
	unsigned int nr_snk_vdo;
	unsigned int operating_snk_mw;
	bool update_sink_caps;
	u32 current_limit;
	u32 supply_voltage;
	struct power_supply *psy;
	struct power_supply_desc psy_desc;
	enum power_supply_usb_type usb_type;
	u32 bist_request;
	enum vdm_states vdm_state;
	u32 vdm_retries;
	u32 vdo_data[7];
	u8 vdo_count;
	u32 vdo_retry;
	struct pd_pps_data pps_data;
	struct completion pps_complete;
	bool pps_pending;
	int pps_status;
	struct pd_mode_data mode_data;
	struct typec_altmode___3 *partner_altmode[96];
	struct typec_altmode___3 *port_altmode[96];
	long unsigned int max_wait;
	struct dentry___326 *dentry;
	struct mutex logbuffer_lock;
	int logbuffer_head;
	int logbuffer_tail;
	u8 *logbuffer[1024];
};

struct pd_rx_event {
	struct work_struct work;
	struct tcpm_port *port;
	struct pd_message msg;
};

enum pdo_err {
	PDO_NO_ERR = 0,
	PDO_ERR_NO_VSAFE5V = 1,
	PDO_ERR_VSAFE5V_NOT_FIRST = 2,
	PDO_ERR_PDO_TYPE_NOT_IN_ORDER = 3,
	PDO_ERR_FIXED_NOT_SORTED = 4,
	PDO_ERR_VARIABLE_BATT_NOT_SORTED = 5,
	PDO_ERR_DUPE_PDO = 6,
	PDO_ERR_PPS_APDO_NOT_SORTED = 7,
	PDO_ERR_DUPE_PPS_APDO = 8,
};

enum tcpm_psy_online_states {
	TCPM_PSY_OFFLINE = 0,
	TCPM_PSY_FIXED_ONLINE = 1,
	TCPM_PSY_PROG_ONLINE = 2,
};

struct typec_capability___3 {
	enum typec_port_type type;
	enum typec_port_data data;
	u16 revision;
	u16 pd_revision;
	int prefer_role;
	enum typec_accessory accessory[3];
	struct typec_switch___2 *sw;
	struct typec_mux___2 *mux;
	struct fwnode_handle___271 *fwnode;
	int (*try_role)(const struct typec_capability___3 *, int);
	int (*dr_set)(const struct typec_capability___3 *, enum typec_data_role);
	int (*pr_set)(const struct typec_capability___3 *, enum typec_role);
	int (*vconn_set)(const struct typec_capability___3 *, enum typec_role);
	int (*port_type_set)(const struct typec_capability___3 *, enum typec_port_type);
};

struct ucsi_cci {
	char: 1;
	u8 connector_change: 7;
	u8 data_length;
	short: 9;
	u16 not_supported: 1;
	u16 cancel_complete: 1;
	u16 reset_complete: 1;
	u16 busy: 1;
	u16 ack_complete: 1;
	u16 error: 1;
	u16 cmd_complete: 1;
};

struct ucsi_command {
	u8 cmd;
	u8 length;
	u64 data: 48;
};

struct ucsi_ack_cmd {
	u8 cmd;
	u8 length;
	u8 cci_ack: 1;
	u8 cmd_ack: 1;
};

struct ucsi_con_rst {
	u8 cmd;
	u8 length;
	u8 con_num: 7;
	u8 hard_reset: 1;
};

struct ucsi_uor_cmd {
	u8 cmd;
	u8 length;
	u16 con_num: 7;
	u16 role: 3;
};

struct ucsi_control {
	union {
		u64 raw_cmd;
		struct ucsi_command cmd;
		struct ucsi_uor_cmd uor;
		struct ucsi_ack_cmd ack;
		struct ucsi_con_rst con_rst;
	};
};

struct ucsi_capability {
	u32 attributes;
	u32 num_connectors: 8;
	u32 features: 24;
	u8 num_alt_modes;
	u8 reserved;
	u16 bc_version;
	u16 pd_version;
	u16 typec_version;
};

struct ucsi_connector_capability {
	u8 op_mode;
	u8 provider: 1;
	u8 consumer: 1;
};

struct ucsi_connector_status {
	u16 change;
	u16 pwr_op_mode: 3;
	u16 connected: 1;
	u16 pwr_dir: 1;
	u16 partner_flags: 8;
	u16 partner_type: 3;
	u32 request_data_obj;
	u8 bc_status: 2;
	u8 provider_cap_limit_reason: 4;
} __attribute__((packed));

struct ucsi_data {
	u16 version;
	u16 reserved;
	union {
		u32 raw_cci;
		struct ucsi_cci cci;
	};
	struct ucsi_control ctrl;
	u32 message_in[4];
	u32 message_out[4];
};

struct ucsi_ppm {
	struct ucsi_data *data;
	int (*cmd)(struct ucsi_ppm *, struct ucsi_control *);
	int (*sync)(struct ucsi_ppm *);
};

enum ucsi_status {
	UCSI_IDLE = 0,
	UCSI_BUSY = 1,
	UCSI_ERROR = 2,
};

struct ucsi;

struct ucsi_connector {
	int num;
	struct ucsi *ucsi;
	struct work_struct work;
	struct completion complete;
	struct typec_port___2 *port;
	struct typec_partner___2 *partner;
	struct typec_capability___3 typec_cap;
	struct ucsi_connector_status status;
	struct ucsi_connector_capability cap;
};

struct ucsi {
	struct device___349 *dev;
	struct ucsi_ppm *ppm;
	enum ucsi_status status;
	struct completion complete;
	struct ucsi_capability cap;
	struct ucsi_connector *connector;
	struct work_struct work;
	struct mutex ppm_lock;
	long unsigned int flags;
};

struct trace_event_raw_ucsi_log_ack {
	struct trace_entry ent;
	u8 ack;
	char __data[0];
};

struct trace_event_raw_ucsi_log_control {
	struct trace_entry ent;
	u64 ctrl;
	char __data[0];
};

struct trace_event_raw_ucsi_log_command {
	struct trace_entry ent;
	u64 ctrl;
	int ret;
	char __data[0];
};

struct trace_event_raw_ucsi_log_cci {
	struct trace_entry ent;
	u32 cci;
	char __data[0];
};

struct trace_event_raw_ucsi_log_connector_status {
	struct trace_entry ent;
	int port;
	u16 change;
	u8 opmode;
	u8 connected;
	u8 pwr_dir;
	u8 partner_flags;
	u8 partner_type;
	u32 request_data_obj;
	u8 bc_status;
	char __data[0];
};

struct trace_event_data_offsets_ucsi_log_ack {};

struct trace_event_data_offsets_ucsi_log_control {};

struct trace_event_data_offsets_ucsi_log_command {};

struct trace_event_data_offsets_ucsi_log_cci {};

struct trace_event_data_offsets_ucsi_log_connector_status {};

struct ucsi___2;

struct ucsi_acpi {
	struct device___12 *dev;
	struct ucsi___2 *ucsi;
	struct ucsi_ppm ppm;
	guid_t guid;
};

struct i2c_device_id {
	char name[20];
	kernel_ulong_t driver_data;
};

struct rt_mutex___5 {
	raw_spinlock_t wait_lock;
	struct rb_root_cached waiters;
	struct task_struct___379 *owner;
};

struct i2c_client___2;

typedef int (*i2c_slave_cb_t___2)(struct i2c_client___2 *, enum i2c_slave_event, u8 *);

struct i2c_adapter___2;

struct i2c_client___2 {
	short unsigned int flags;
	short unsigned int addr;
	char name[20];
	struct i2c_adapter___2 *adapter;
	struct device___344 dev;
	int irq;
	struct list_head detected;
	i2c_slave_cb_t___2 slave_cb;
};

enum i2c_alert_protocol {
	I2C_PROTOCOL_SMBUS_ALERT = 0,
	I2C_PROTOCOL_SMBUS_HOST_NOTIFY = 1,
};

struct i2c_board_info;

struct i2c_driver {
	unsigned int class;
	int (*attach_adapter)(struct i2c_adapter___2 *);
	int (*probe)(struct i2c_client___2 *, const struct i2c_device_id *);
	int (*remove)(struct i2c_client___2 *);
	int (*probe_new)(struct i2c_client___2 *);
	void (*shutdown)(struct i2c_client___2 *);
	void (*alert)(struct i2c_client___2 *, enum i2c_alert_protocol, unsigned int);
	int (*command)(struct i2c_client___2 *, unsigned int, void *);
	struct device_driver___344 driver;
	const struct i2c_device_id *id_table;
	int (*detect)(struct i2c_client___2 *, struct i2c_board_info *);
	const short unsigned int *address_list;
	struct list_head clients;
	bool disable_i2c_core_irq_mapping;
};

struct i2c_algorithm___2;

struct i2c_lock_operations___2;

struct i2c_bus_recovery_info___2;

struct i2c_adapter___2 {
	struct module___309 *owner;
	unsigned int class;
	const struct i2c_algorithm___2 *algo;
	void *algo_data;
	const struct i2c_lock_operations___2 *lock_ops;
	struct rt_mutex___5 bus_lock;
	struct rt_mutex___5 mux_lock;
	int timeout;
	int retries;
	struct device___344 dev;
	int nr;
	char name[48];
	struct completion dev_released;
	struct mutex userspace_clients_lock;
	struct list_head userspace_clients;
	struct i2c_bus_recovery_info___2 *bus_recovery_info;
	const struct i2c_adapter_quirks *quirks;
	struct irq_domain___29 *host_notify_domain;
};

struct i2c_board_info {
	char type[20];
	short unsigned int flags;
	short unsigned int addr;
	const char *dev_name;
	void *platform_data;
	struct device_node___87 *of_node;
	struct fwnode_handle___266 *fwnode;
	const struct property_entry___2 *properties;
	const struct resource *resources;
	unsigned int num_resources;
	int irq;
};

struct i2c_algorithm___2 {
	int (*master_xfer)(struct i2c_adapter___2 *, struct i2c_msg *, int);
	int (*smbus_xfer)(struct i2c_adapter___2 *, u16, short unsigned int, char, u8, int, union i2c_smbus_data *);
	u32 (*functionality)(struct i2c_adapter___2 *);
	int (*reg_slave)(struct i2c_client___2 *);
	int (*unreg_slave)(struct i2c_client___2 *);
};

struct i2c_lock_operations___2 {
	void (*lock_bus)(struct i2c_adapter___2 *, unsigned int);
	int (*trylock_bus)(struct i2c_adapter___2 *, unsigned int);
	void (*unlock_bus)(struct i2c_adapter___2 *, unsigned int);
};

struct i2c_bus_recovery_info___2 {
	int (*recover_bus)(struct i2c_adapter___2 *);
	int (*get_scl)(struct i2c_adapter___2 *);
	void (*set_scl)(struct i2c_adapter___2 *, int);
	int (*get_sda)(struct i2c_adapter___2 *);
	void (*set_sda)(struct i2c_adapter___2 *, int);
	void (*prepare_recovery)(struct i2c_adapter___2 *);
	void (*unprepare_recovery)(struct i2c_adapter___2 *);
	struct gpio_desc *scl_gpiod;
	struct gpio_desc *sda_gpiod;
};

struct regmap_config___6 {
	const char *name;
	int reg_bits;
	int reg_stride;
	int pad_bits;
	int val_bits;
	bool (*writeable_reg)(struct device___344 *, unsigned int);
	bool (*readable_reg)(struct device___344 *, unsigned int);
	bool (*volatile_reg)(struct device___344 *, unsigned int);
	bool (*precious_reg)(struct device___344 *, unsigned int);
	bool disable_locking;
	regmap_lock lock;
	regmap_unlock unlock;
	void *lock_arg;
	int (*reg_read)(void *, unsigned int, unsigned int *);
	int (*reg_write)(void *, unsigned int, unsigned int);
	bool fast_io;
	unsigned int max_register;
	const struct regmap_access_table *wr_table;
	const struct regmap_access_table *rd_table;
	const struct regmap_access_table *volatile_table;
	const struct regmap_access_table *precious_table;
	const struct reg_default *reg_defaults;
	unsigned int num_reg_defaults;
	enum regcache_type cache_type;
	const void *reg_defaults_raw;
	unsigned int num_reg_defaults_raw;
	long unsigned int read_flag_mask;
	long unsigned int write_flag_mask;
	bool zero_flag_mask;
	bool use_single_read;
	bool use_single_write;
	bool can_multi_write;
	enum regmap_endian reg_format_endian;
	enum regmap_endian val_format_endian;
	const struct regmap_range_cfg *ranges;
	unsigned int num_ranges;
	bool use_hwlock;
	unsigned int hwlock_id;
	unsigned int hwlock_mode;
};

struct tcpc_dev___2 {
	const struct tcpc_config *config;
	struct fwnode_handle___266 *fwnode;
	int (*init)(struct tcpc_dev___2 *);
	int (*get_vbus)(struct tcpc_dev___2 *);
	int (*get_current_limit)(struct tcpc_dev___2 *);
	int (*set_cc)(struct tcpc_dev___2 *, enum typec_cc_status);
	int (*get_cc)(struct tcpc_dev___2 *, enum typec_cc_status *, enum typec_cc_status *);
	int (*set_polarity)(struct tcpc_dev___2 *, enum typec_cc_polarity);
	int (*set_vconn)(struct tcpc_dev___2 *, bool);
	int (*set_vbus)(struct tcpc_dev___2 *, bool, bool);
	int (*set_current_limit)(struct tcpc_dev___2 *, u32, u32);
	int (*set_pd_rx)(struct tcpc_dev___2 *, bool);
	int (*set_roles)(struct tcpc_dev___2 *, bool, enum typec_role, enum typec_data_role);
	int (*start_drp_toggling)(struct tcpc_dev___2 *, enum typec_cc_status);
	int (*try_role)(struct tcpc_dev___2 *, int);
	int (*pd_transmit)(struct tcpc_dev___2 *, enum tcpm_transmit_type, const struct pd_message *);
};

struct tcpci;

struct tcpci_data {
	struct regmap *regmap;
	int (*init)(struct tcpci *, struct tcpci_data *);
	int (*set_vconn)(struct tcpci *, struct tcpci_data *, bool);
	int (*start_drp_toggling)(struct tcpci *, struct tcpci_data *, enum typec_cc_status);
};

struct tcpm_port___2;

struct tcpci {
	struct device___344 *dev;
	struct tcpm_port___2 *port;
	struct regmap *regmap;
	bool controls_vbus;
	struct tcpc_dev___2 tcpc;
	struct tcpci_data *data;
};

struct tcpci_chip {
	struct tcpci *tcpci;
	struct tcpci_data data;
};

struct rt1711h_chip {
	struct tcpci_data data;
	struct tcpci *tcpci;
	struct device___344 *dev;
};

struct driver_attribute___5 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___345 *, char *);
	ssize_t (*store)(struct device_driver___345 *, const char *, size_t);
};

struct serio_device_id {
	__u8 type;
	__u8 extra;
	__u8 id;
	__u8 proto;
};

struct serio_driver;

struct serio {
	void *port_data;
	char name[32];
	char phys[32];
	char firmware_id[128];
	bool manual_bind;
	struct serio_device_id id;
	spinlock_t lock;
	int (*write)(struct serio *, unsigned char);
	int (*open)(struct serio *);
	void (*close)(struct serio *);
	int (*start)(struct serio *);
	void (*stop)(struct serio *);
	struct serio *parent;
	struct list_head child_node;
	struct list_head children;
	unsigned int depth;
	struct serio_driver *drv;
	struct mutex drv_mutex;
	struct device___345 dev;
	struct list_head node;
	struct mutex *ps2_cmd_mutex;
};

struct serio_driver {
	const char *description;
	const struct serio_device_id *id_table;
	bool manual_bind;
	void (*write_wakeup)(struct serio *);
	irqreturn_t (*interrupt)(struct serio *, unsigned char, unsigned int);
	int (*connect)(struct serio *, struct serio_driver *);
	int (*reconnect)(struct serio *);
	int (*fast_reconnect)(struct serio *);
	void (*disconnect)(struct serio *);
	void (*cleanup)(struct serio *);
	struct device_driver___345 driver;
};

enum serio_event_type {
	SERIO_RESCAN_PORT = 0,
	SERIO_RECONNECT_PORT = 1,
	SERIO_RECONNECT_SUBTREE = 2,
	SERIO_REGISTER_PORT = 3,
	SERIO_ATTACH_DRIVER = 4,
};

struct serio_event {
	enum serio_event_type type;
	void *object;
	struct module___309 *owner;
	struct list_head node;
};

struct serio_driver___2;

struct serio___2 {
	void *port_data;
	char name[32];
	char phys[32];
	char firmware_id[128];
	bool manual_bind;
	struct serio_device_id id;
	spinlock_t lock;
	int (*write)(struct serio___2 *, unsigned char);
	int (*open)(struct serio___2 *);
	void (*close)(struct serio___2 *);
	int (*start)(struct serio___2 *);
	void (*stop)(struct serio___2 *);
	struct serio___2 *parent;
	struct list_head child_node;
	struct list_head children;
	unsigned int depth;
	struct serio_driver___2 *drv;
	struct mutex drv_mutex;
	struct device___276 dev;
	struct list_head node;
	struct mutex *ps2_cmd_mutex;
};

struct serio_driver___2 {
	const char *description;
	const struct serio_device_id *id_table;
	bool manual_bind;
	void (*write_wakeup)(struct serio___2 *);
	irqreturn_t (*interrupt)(struct serio___2 *, unsigned char, unsigned int);
	int (*connect)(struct serio___2 *, struct serio_driver___2 *);
	int (*reconnect)(struct serio___2 *);
	int (*fast_reconnect)(struct serio___2 *);
	void (*disconnect)(struct serio___2 *);
	void (*cleanup)(struct serio___2 *);
	struct device_driver___276 driver;
};

struct serport {
	struct tty_struct___31 *tty;
	wait_queue_head_t wait;
	struct serio___2 *serio;
	struct serio_device_id id;
	spinlock_t lock;
	long unsigned int flags;
};

struct amba_kmi_port {
	struct serio *io;
	struct clk *clk;
	void *base;
	unsigned int irq;
	unsigned int divisor;
	unsigned int open;
};

struct ps2dev {
	struct serio *serio;
	struct mutex cmd_mutex;
	wait_queue_head_t wait;
	long unsigned int flags;
	u8 cmdbuf[8];
	u8 cmdcnt;
	u8 nak;
};

typedef void (*dr_release_t___24)(struct device___349 *, void *);

struct ff_device___4;

struct input_handle___4;

struct input_dev___4 {
	const char *name;
	const char *phys;
	const char *uniq;
	struct input_id id;
	long unsigned int propbit[1];
	long unsigned int evbit[1];
	long unsigned int keybit[12];
	long unsigned int relbit[1];
	long unsigned int absbit[1];
	long unsigned int mscbit[1];
	long unsigned int ledbit[1];
	long unsigned int sndbit[1];
	long unsigned int ffbit[2];
	long unsigned int swbit[1];
	unsigned int hint_events_per_packet;
	unsigned int keycodemax;
	unsigned int keycodesize;
	void *keycode;
	int (*setkeycode)(struct input_dev___4 *, const struct input_keymap_entry *, unsigned int *);
	int (*getkeycode)(struct input_dev___4 *, struct input_keymap_entry *);
	struct ff_device___4 *ff;
	unsigned int repeat_key;
	struct timer_list timer;
	int rep[2];
	struct input_mt *mt;
	struct input_absinfo *absinfo;
	long unsigned int key[12];
	long unsigned int led[1];
	long unsigned int snd[1];
	long unsigned int sw[1];
	int (*open)(struct input_dev___4 *);
	void (*close)(struct input_dev___4 *);
	int (*flush)(struct input_dev___4 *, struct file___12 *);
	int (*event)(struct input_dev___4 *, unsigned int, unsigned int, int);
	struct input_handle___4 *grab;
	spinlock_t event_lock;
	struct mutex mutex;
	unsigned int users;
	bool going_away;
	struct device___349 dev;
	struct list_head h_list;
	struct list_head node;
	unsigned int num_vals;
	unsigned int max_vals;
	struct input_value *vals;
	bool devres_managed;
};

struct ff_device___4 {
	int (*upload)(struct input_dev___4 *, struct ff_effect *, struct ff_effect *);
	int (*erase)(struct input_dev___4 *, int);
	int (*playback)(struct input_dev___4 *, int, int);
	void (*set_gain)(struct input_dev___4 *, u16);
	void (*set_autocenter)(struct input_dev___4 *, u16);
	void (*destroy)(struct ff_device___4 *);
	void *private;
	long unsigned int ffbit[2];
	struct mutex mutex;
	int max_effects;
	struct ff_effect *effects;
	struct file___12 *effect_owners[0];
};

struct input_mt_slot {
	int abs[14];
	unsigned int frame;
	unsigned int key;
};

struct input_mt {
	int trkid;
	int num_slots;
	int slot;
	unsigned int flags;
	unsigned int frame;
	int *red;
	struct input_mt_slot slots[0];
};

struct input_handler___4;

struct input_handle___4 {
	void *private;
	int open;
	const char *name;
	struct input_dev___4 *dev;
	struct input_handler___4 *handler;
	struct list_head d_node;
	struct list_head h_node;
};

struct input_handler___4 {
	void *private;
	void (*event)(struct input_handle___4 *, unsigned int, unsigned int, int);
	void (*events)(struct input_handle___4 *, const struct input_value *, unsigned int);
	bool (*filter)(struct input_handle___4 *, unsigned int, unsigned int, int);
	bool (*match)(struct input_handler___4 *, struct input_dev___4 *);
	int (*connect)(struct input_handler___4 *, struct input_dev___4 *, const struct input_device_id *);
	void (*disconnect)(struct input_handle___4 *);
	void (*start)(struct input_handle___4 *);
	bool legacy_minors;
	int minor;
	const char *name;
	const struct input_device_id *id_table;
	struct list_head h_list;
	struct list_head node;
};

typedef struct poll_table_struct___6 poll_table___34;

union input_seq_state {
	struct {
		short unsigned int pos;
		bool mutex_acquired;
	};
	void *p;
};

struct input_devres {
	struct input_dev___4 *input;
};

struct input_event {
	struct timeval time;
	__u16 type;
	__u16 code;
	__s32 value;
};

struct input_mt_pos {
	s16 x;
	s16 y;
};

struct input_led {
	struct led_classdev cdev;
	struct input_handle___3 *handle;
	unsigned int code;
};

struct input_leds {
	struct input_handle___3 handle;
	unsigned int num_leds;
	struct input_led leds[0];
};

struct ff_device___5;

struct input_handle___5;

struct input_dev___5 {
	const char *name;
	const char *phys;
	const char *uniq;
	struct input_id id;
	long unsigned int propbit[1];
	long unsigned int evbit[1];
	long unsigned int keybit[12];
	long unsigned int relbit[1];
	long unsigned int absbit[1];
	long unsigned int mscbit[1];
	long unsigned int ledbit[1];
	long unsigned int sndbit[1];
	long unsigned int ffbit[2];
	long unsigned int swbit[1];
	unsigned int hint_events_per_packet;
	unsigned int keycodemax;
	unsigned int keycodesize;
	void *keycode;
	int (*setkeycode)(struct input_dev___5 *, const struct input_keymap_entry *, unsigned int *);
	int (*getkeycode)(struct input_dev___5 *, struct input_keymap_entry *);
	struct ff_device___5 *ff;
	unsigned int repeat_key;
	struct timer_list timer;
	int rep[2];
	struct input_mt *mt;
	struct input_absinfo *absinfo;
	long unsigned int key[12];
	long unsigned int led[1];
	long unsigned int snd[1];
	long unsigned int sw[1];
	int (*open)(struct input_dev___5 *);
	void (*close)(struct input_dev___5 *);
	int (*flush)(struct input_dev___5 *, struct file___311 *);
	int (*event)(struct input_dev___5 *, unsigned int, unsigned int, int);
	struct input_handle___5 *grab;
	spinlock_t event_lock;
	struct mutex mutex;
	unsigned int users;
	bool going_away;
	struct device___276 dev;
	struct list_head h_list;
	struct list_head node;
	unsigned int num_vals;
	unsigned int max_vals;
	struct input_value *vals;
	bool devres_managed;
};

struct ff_device___5 {
	int (*upload)(struct input_dev___5 *, struct ff_effect *, struct ff_effect *);
	int (*erase)(struct input_dev___5 *, int);
	int (*playback)(struct input_dev___5 *, int, int);
	void (*set_gain)(struct input_dev___5 *, u16);
	void (*set_autocenter)(struct input_dev___5 *, u16);
	void (*destroy)(struct ff_device___5 *);
	void *private;
	long unsigned int ffbit[2];
	struct mutex mutex;
	int max_effects;
	struct ff_effect *effects;
	struct file___311 *effect_owners[0];
};

struct input_handler___5;

struct input_handle___5 {
	void *private;
	int open;
	const char *name;
	struct input_dev___5 *dev;
	struct input_handler___5 *handler;
	struct list_head d_node;
	struct list_head h_node;
};

struct input_handler___5 {
	void *private;
	void (*event)(struct input_handle___5 *, unsigned int, unsigned int, int);
	void (*events)(struct input_handle___5 *, const struct input_value *, unsigned int);
	bool (*filter)(struct input_handle___5 *, unsigned int, unsigned int, int);
	bool (*match)(struct input_handler___5 *, struct input_dev___5 *);
	int (*connect)(struct input_handler___5 *, struct input_dev___5 *, const struct input_device_id *);
	void (*disconnect)(struct input_handle___5 *);
	void (*start)(struct input_handle___5 *);
	bool legacy_minors;
	int minor;
	const char *name;
	const struct input_device_id *id_table;
	struct list_head h_list;
	struct list_head node;
};

struct mousedev_hw_data {
	int dx;
	int dy;
	int dz;
	int x;
	int y;
	int abs_event;
	long unsigned int buttons;
};

struct mousedev {
	int open;
	struct input_handle___5 handle;
	wait_queue_head_t wait;
	struct list_head client_list;
	spinlock_t client_lock;
	struct mutex mutex;
	struct device___276 dev;
	struct cdev___61 cdev;
	bool exist;
	struct list_head mixdev_node;
	bool opened_by_mixdev;
	struct mousedev_hw_data packet;
	unsigned int pkt_count;
	int old_x[4];
	int old_y[4];
	int frac_dx;
	int frac_dy;
	long unsigned int touch;
	int (*open_device)(struct mousedev *);
	void (*close_device)(struct mousedev *);
};

enum mousedev_emul {
	MOUSEDEV_EMUL_PS2 = 0,
	MOUSEDEV_EMUL_IMPS = 1,
	MOUSEDEV_EMUL_EXPS = 2,
};

struct mousedev_motion {
	int dx;
	int dy;
	int dz;
	long unsigned int buttons;
};

struct mousedev_client {
	struct fasync_struct___310 *fasync;
	struct mousedev *mousedev;
	struct list_head node;
	struct mousedev_motion packets[16];
	unsigned int head;
	unsigned int tail;
	spinlock_t packet_lock;
	int pos_x;
	int pos_y;
	u8 ps2[6];
	unsigned char ready;
	unsigned char buffer;
	unsigned char bufsiz;
	unsigned char imexseq;
	unsigned char impsseq;
	enum mousedev_emul mode;
	long unsigned int last_buttons;
};

enum {
	FRACTION_DENOM = 128,
};

typedef struct poll_table_struct___13 poll_table___35;

struct input_mask {
	__u32 type;
	__u32 codes_size;
	__u64 codes_ptr;
};

struct ff_device___6;

struct input_handle___6;

struct input_dev___6 {
	const char *name;
	const char *phys;
	const char *uniq;
	struct input_id id;
	long unsigned int propbit[1];
	long unsigned int evbit[1];
	long unsigned int keybit[12];
	long unsigned int relbit[1];
	long unsigned int absbit[1];
	long unsigned int mscbit[1];
	long unsigned int ledbit[1];
	long unsigned int sndbit[1];
	long unsigned int ffbit[2];
	long unsigned int swbit[1];
	unsigned int hint_events_per_packet;
	unsigned int keycodemax;
	unsigned int keycodesize;
	void *keycode;
	int (*setkeycode)(struct input_dev___6 *, const struct input_keymap_entry *, unsigned int *);
	int (*getkeycode)(struct input_dev___6 *, struct input_keymap_entry *);
	struct ff_device___6 *ff;
	unsigned int repeat_key;
	struct timer_list timer;
	int rep[2];
	struct input_mt *mt;
	struct input_absinfo *absinfo;
	long unsigned int key[12];
	long unsigned int led[1];
	long unsigned int snd[1];
	long unsigned int sw[1];
	int (*open)(struct input_dev___6 *);
	void (*close)(struct input_dev___6 *);
	int (*flush)(struct input_dev___6 *, struct file___21 *);
	int (*event)(struct input_dev___6 *, unsigned int, unsigned int, int);
	struct input_handle___6 *grab;
	spinlock_t event_lock;
	struct mutex mutex;
	unsigned int users;
	bool going_away;
	struct device___17 dev;
	struct list_head h_list;
	struct list_head node;
	unsigned int num_vals;
	unsigned int max_vals;
	struct input_value *vals;
	bool devres_managed;
};

struct ff_device___6 {
	int (*upload)(struct input_dev___6 *, struct ff_effect *, struct ff_effect *);
	int (*erase)(struct input_dev___6 *, int);
	int (*playback)(struct input_dev___6 *, int, int);
	void (*set_gain)(struct input_dev___6 *, u16);
	void (*set_autocenter)(struct input_dev___6 *, u16);
	void (*destroy)(struct ff_device___6 *);
	void *private;
	long unsigned int ffbit[2];
	struct mutex mutex;
	int max_effects;
	struct ff_effect *effects;
	struct file___21 *effect_owners[0];
};

struct input_handler___6;

struct input_handle___6 {
	void *private;
	int open;
	const char *name;
	struct input_dev___6 *dev;
	struct input_handler___6 *handler;
	struct list_head d_node;
	struct list_head h_node;
};

struct input_handler___6 {
	void *private;
	void (*event)(struct input_handle___6 *, unsigned int, unsigned int, int);
	void (*events)(struct input_handle___6 *, const struct input_value *, unsigned int);
	bool (*filter)(struct input_handle___6 *, unsigned int, unsigned int, int);
	bool (*match)(struct input_handler___6 *, struct input_dev___6 *);
	int (*connect)(struct input_handler___6 *, struct input_dev___6 *, const struct input_device_id *);
	void (*disconnect)(struct input_handle___6 *);
	void (*start)(struct input_handle___6 *);
	bool legacy_minors;
	int minor;
	const char *name;
	const struct input_device_id *id_table;
	struct list_head h_list;
	struct list_head node;
};

enum evdev_clock_type {
	EV_CLK_REAL = 0,
	EV_CLK_MONO = 1,
	EV_CLK_BOOT = 2,
	EV_CLK_MAX = 3,
};

struct evdev_client;

struct evdev {
	int open;
	struct input_handle___6 handle;
	wait_queue_head_t wait;
	struct evdev_client *grab;
	struct list_head client_list;
	spinlock_t client_lock;
	struct mutex mutex;
	struct device___17 dev;
	struct cdev___7 cdev;
	bool exist;
};

struct evdev_client {
	unsigned int head;
	unsigned int tail;
	unsigned int packet_head;
	spinlock_t buffer_lock;
	struct fasync_struct___20 *fasync;
	struct evdev *evdev;
	struct list_head node;
	unsigned int clk_type;
	bool revoked;
	long unsigned int *evmasks[32];
	unsigned int bufsize;
	struct input_event buffer[0];
};

typedef void (*dr_release_t___25)(struct device___345 *, void *);

struct rtc_class_ops___2 {
	int (*ioctl)(struct device___345 *, unsigned int, long unsigned int);
	int (*read_time)(struct device___345 *, struct rtc_time *);
	int (*set_time)(struct device___345 *, struct rtc_time *);
	int (*read_alarm)(struct device___345 *, struct rtc_wkalrm *);
	int (*set_alarm)(struct device___345 *, struct rtc_wkalrm *);
	int (*proc)(struct device___345 *, struct seq_file___320 *);
	int (*set_mmss64)(struct device___345 *, time64_t);
	int (*set_mmss)(struct device___345 *, long unsigned int);
	int (*read_callback)(struct device___345 *, int);
	int (*alarm_irq_enable)(struct device___345 *, unsigned int);
	int (*read_offset)(struct device___345 *, long int *);
	int (*set_offset)(struct device___345 *, long int);
};

struct rtc_device___2 {
	struct device___345 dev;
	struct module___309 *owner;
	int id;
	const struct rtc_class_ops___2 *ops;
	struct mutex ops_lock;
	struct cdev___91 char_dev;
	long unsigned int flags;
	long unsigned int irq_data;
	spinlock_t irq_lock;
	wait_queue_head_t irq_queue;
	struct fasync_struct___377 *async_queue;
	struct rtc_task *irq_task;
	spinlock_t irq_task_lock;
	int irq_freq;
	int max_user_freq;
	struct timerqueue_head timerqueue;
	struct rtc_timer aie_timer;
	struct rtc_timer uie_rtctimer;
	struct hrtimer pie_timer;
	int pie_enabled;
	struct work_struct irqwork;
	int uie_unsupported;
	long int set_offset_nsec;
	bool registered;
	struct nvmem_device *nvmem;
	bool nvram_old_abi;
	struct bin_attribute___341 *nvram;
	time64_t range_min;
	timeu64_t range_max;
	time64_t start_secs;
	time64_t offset_secs;
	bool set_start_time;
};

struct rtc;

struct module___314;

struct file___384;

struct kiocb___384;

struct poll_table_struct___232;

struct vm_area_struct___385;

struct inode___384;

struct file_lock___384;

struct page___385;

struct seq_file___326;

struct file_operations___384 {
	struct module___314 *owner;
	loff_t (*llseek)(struct file___384 *, loff_t, int);
	ssize_t (*read)(struct file___384 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___384 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___384 *, struct iov_iter___2 *);
	ssize_t (*write_iter)(struct kiocb___384 *, struct iov_iter___2 *);
	int (*iopoll)(struct kiocb___384 *, bool);
	int (*iterate)(struct file___384 *, struct dir_context *);
	int (*iterate_shared)(struct file___384 *, struct dir_context *);
	__poll_t (*poll)(struct file___384 *, struct poll_table_struct___232 *);
	long int (*unlocked_ioctl)(struct file___384 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___384 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___384 *, struct vm_area_struct___385 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___384 *, struct file___384 *);
	int (*flush)(struct file___384 *, fl_owner_t);
	int (*release)(struct inode___384 *, struct file___384 *);
	int (*fsync)(struct file___384 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___384 *, int);
	int (*lock)(struct file___384 *, int, struct file_lock___384 *);
	ssize_t (*sendpage)(struct file___384 *, struct page___385 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___384 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___384 *, int, struct file_lock___384 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___384 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___384 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___384 *, long int, struct file_lock___384 **, void **);
	long int (*fallocate)(struct file___384 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___326 *, struct file___384 *);
	ssize_t (*copy_file_range)(struct file___384 *, loff_t, struct file___384 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___384 *, loff_t, struct file___384 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___384 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___384 {
	u64 seqnum;
	struct vm_area_struct___385 *vmas[4];
};

struct page_frag___384 {
	struct page___385 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___145;

struct debug_info___145 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___145 *hbp_break[16];
	struct perf_event___145 *hbp_watch[16];
};

struct thread_struct___145 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___145 debug;
	long: 64;
};

struct mm_struct___384;

struct pid___221;

struct cred___353;

struct nsproxy___282;

struct signal_struct___263;

struct css_set___237;

struct perf_event_context___145;

struct task_struct___385 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___385 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___384 *mm;
	struct mm_struct___384 *active_mm;
	struct vmacache___384 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___385 *real_parent;
	struct task_struct___385 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___385 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___221 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___221 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___221 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___353 *ptracer_cred;
	const struct cred___353 *real_cred;
	const struct cred___353 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___282 *nsproxy;
	struct signal_struct___263 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___385 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___107 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___237 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___145 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___384 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___385 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___145 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct secondary_data___385 {
	void *stack;
	struct task_struct___385 *task;
	long int status;
};

struct hw_perf_event___145 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___385 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___145)(struct perf_event___145 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___145;

struct fasync_struct___383;

struct pid_namespace___221;

struct trace_event_call___138;

struct perf_cgroup___145;

struct perf_event___145 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___145 *group_leader;
	struct pmu___145 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___145 hw;
	struct perf_event_context___145 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___145 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___385 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___383 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___145 *);
	struct callback_head callback_head;
	struct pid_namespace___221 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___145 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___145 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___138 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___145 *cgrp;
	struct list_head sb_list;
};

struct kset___370;

struct kobj_type___370;

struct kernfs_node___378;

struct kobject___371 {
	const char *name;
	struct list_head entry;
	struct kobject___371 *parent;
	struct kset___370 *kset;
	struct kobj_type___370 *ktype;
	struct kernfs_node___378 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___351;

struct dev_pm_info___351 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___6 *subsys_data;
	void (*set_latency_tolerance)(struct device___351 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___351;

struct bus_type___351;

struct device_driver___351;

struct dev_pm_domain___351;

struct class___351;

struct attribute_group___348;

struct device___351 {
	struct device___351 *parent;
	struct device_private *p;
	struct kobject___371 kobj;
	const char *init_name;
	const struct device_type___351 *type;
	struct mutex mutex;
	struct bus_type___351 *bus;
	struct device_driver___351 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___351 power;
	struct dev_pm_domain___351 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___351 *class;
	const struct attribute_group___348 **groups;
	void (*release)(struct device___351 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct module_kobject___311 {
	struct kobject___371 kobj;
	struct module___314 *mod;
	struct kobject___371 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___311 {
	struct module___314 *mod;
	struct latch_tree_node node;
};

struct module_layout___311 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___311 mtn;
};

struct module_attribute___311;

struct kernel_param___311;

struct module___314 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___311 mkobj;
	struct module_attribute___311 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___371 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___311 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___311 core_layout;
	struct module_layout___311 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___138 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___385 *pgtable_t___384;

struct address_space___383;

struct dev_pagemap___372;

struct page___385 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___383 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___385 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___384 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___384 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___372 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___384;

struct lruvec___384 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___384 *pgdat;
};

struct zone___384 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___384 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___384 {
	struct zone___384 *zone;
	int zone_idx;
};

struct zonelist___384 {
	struct zoneref___384 _zonerefs[25];
};

struct pglist_data___384 {
	struct zone___384 node_zones[3];
	struct zonelist___384 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___385 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___385 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___384 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___385 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___385 *owner;
};

struct blocking_notifier_head___384 {
	struct rw_semaphore___385 rwsem;
	struct notifier_block *head;
};

struct key___353;

struct ucounts___253;

struct user_namespace___253 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___253 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___9 ns;
	long unsigned int flags;
	struct key___353 *persistent_keyring_register;
	struct rw_semaphore___385 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___253 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_root___377;

struct kernfs_elem_dir___377 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___377 *root;
};

struct kernfs_syscall_ops___377;

struct kernfs_root___377 {
	struct kernfs_node___378 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___377 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___377 {
	struct kernfs_node___378 *target_kn;
};

struct kernfs_ops___377;

struct kernfs_elem_attr___377 {
	const struct kernfs_ops___377 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___378 *notify_next;
};

struct kernfs_node___378 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___378 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___377 dir;
		struct kernfs_elem_symlink___377 symlink;
		struct kernfs_elem_attr___377 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___377;

struct kernfs_ops___377 {
	int (*open)(struct kernfs_open_file___377 *);
	void (*release)(struct kernfs_open_file___377 *);
	int (*seq_show)(struct seq_file___326 *, void *);
	void * (*seq_start)(struct seq_file___326 *, loff_t *);
	void * (*seq_next)(struct seq_file___326 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___326 *, void *);
	ssize_t (*read)(struct kernfs_open_file___377 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___377 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___377 *, struct vm_area_struct___385 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___377 *, struct poll_table_struct___232 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___377 {
	int (*remount_fs)(struct kernfs_root___377 *, int *, char *);
	int (*show_options)(struct seq_file___326 *, struct kernfs_root___377 *);
	int (*mkdir)(struct kernfs_node___378 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___378 *);
	int (*rename)(struct kernfs_node___378 *, struct kernfs_node___378 *, const char *);
	int (*show_path)(struct seq_file___326 *, struct kernfs_node___378 *, struct kernfs_root___377 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___325;

struct seq_file___326 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___325 *op;
	int poll_event;
	const struct file___384 *file;
	void *private;
};

struct vm_operations_struct___372;

struct kernfs_open_file___377 {
	struct kernfs_node___378 *kn;
	struct file___384 *file;
	struct seq_file___326 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___372 *vm_ops;
};

struct dentry___383;

struct path___384 {
	struct vfsmount *mnt;
	struct dentry___383 *dentry;
};

struct fown_struct___221 {
	rwlock_t lock;
	struct pid___221 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___384 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___384 f_path;
	struct inode___384 *f_inode;
	const struct file_operations___384 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___221 f_owner;
	const struct cred___353 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___383 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___372;

struct vm_operations_struct___372 {
	void (*open)(struct vm_area_struct___385 *);
	void (*close)(struct vm_area_struct___385 *);
	int (*split)(struct vm_area_struct___385 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___385 *);
	vm_fault_t (*fault)(struct vm_fault___372 *);
	vm_fault_t (*huge_fault)(struct vm_fault___372 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___372 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___385 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___372 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___372 *);
	int (*access)(struct vm_area_struct___385 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___385 *);
	int (*set_policy)(struct vm_area_struct___385 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___385 *, long unsigned int);
	struct page___385 * (*find_special_page)(struct vm_area_struct___385 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___238)(struct file___384 *, wait_queue_head_t *, struct poll_table_struct___232 *);

struct poll_table_struct___232 {
	poll_queue_proc___238 _qproc;
	__poll_t _key;
};

struct vm_area_struct___385 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___385 *vm_next;
	struct vm_area_struct___385 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___384 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___372 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___384 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___347;

struct attribute_group___348 {
	const char *name;
	umode_t (*is_visible)(struct kobject___371 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___371 *, struct bin_attribute___347 *, int);
	struct attribute **attrs;
	struct bin_attribute___347 **bin_attrs;
};

struct bin_attribute___347 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___384 *, struct kobject___371 *, struct bin_attribute___347 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___384 *, struct kobject___371 *, struct bin_attribute___347 *, char *, loff_t, size_t);
	int (*mmap)(struct file___384 *, struct kobject___371 *, struct bin_attribute___347 *, struct vm_area_struct___385 *);
};

struct sysfs_ops___370 {
	ssize_t (*show)(struct kobject___371 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___371 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___370;

struct kset___370 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___371 kobj;
	const struct kset_uevent_ops___370 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___370 {
	void (*release)(struct kobject___371 *);
	const struct sysfs_ops___370 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___29 * (*child_ns_type)(struct kobject___371 *);
	const void * (*namespace)(struct kobject___371 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___370 {
	int (* const filter)(struct kset___370 *, struct kobject___371 *);
	const char * (* const name)(struct kset___370 *, struct kobject___371 *);
	int (* const uevent)(struct kset___370 *, struct kobject___371 *, struct kobj_uevent_env *);
};

struct kobj_attribute___362 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___371 *, struct kobj_attribute___362 *, char *);
	ssize_t (*store)(struct kobject___371 *, struct kobj_attribute___362 *, const char *, size_t);
};

struct dev_pm_ops___351 {
	int (*prepare)(struct device___351 *);
	void (*complete)(struct device___351 *);
	int (*suspend)(struct device___351 *);
	int (*resume)(struct device___351 *);
	int (*freeze)(struct device___351 *);
	int (*thaw)(struct device___351 *);
	int (*poweroff)(struct device___351 *);
	int (*restore)(struct device___351 *);
	int (*suspend_late)(struct device___351 *);
	int (*resume_early)(struct device___351 *);
	int (*freeze_late)(struct device___351 *);
	int (*thaw_early)(struct device___351 *);
	int (*poweroff_late)(struct device___351 *);
	int (*restore_early)(struct device___351 *);
	int (*suspend_noirq)(struct device___351 *);
	int (*resume_noirq)(struct device___351 *);
	int (*freeze_noirq)(struct device___351 *);
	int (*thaw_noirq)(struct device___351 *);
	int (*poweroff_noirq)(struct device___351 *);
	int (*restore_noirq)(struct device___351 *);
	int (*runtime_suspend)(struct device___351 *);
	int (*runtime_resume)(struct device___351 *);
	int (*runtime_idle)(struct device___351 *);
};

struct dev_pm_domain___351 {
	struct dev_pm_ops___351 ops;
	void (*detach)(struct device___351 *, bool);
	int (*activate)(struct device___351 *);
	void (*sync)(struct device___351 *);
	void (*dismiss)(struct device___351 *);
};

struct upid___221 {
	int nr;
	struct pid_namespace___221 *ns;
};

struct pid_namespace___221 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___385 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___221 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___383 *proc_self;
	struct dentry___383 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___253 *user_ns;
	struct ucounts___253 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___9 ns;
};

struct pid___221 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___221 numbers[1];
};

struct user_struct___353 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___353 *uid_keyring;
	struct key___353 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___384;

struct mm_struct___384 {
	struct {
		struct vm_area_struct___385 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___384 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___385 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___384 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___385 *owner;
		struct user_namespace___253 *user_ns;
		struct file___384 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___384 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___353 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___353 *session_keyring;
	struct key___353 *process_keyring;
	struct key___353 *thread_keyring;
	struct key___353 *request_key_auth;
	void *security;
	struct user_struct___353 *user;
	struct user_namespace___253 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___237;

struct nsproxy___282 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___221 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___237 *cgroup_ns;
};

struct signal_struct___263 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___385 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___385 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___221 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___221 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___384 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___221 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___237;

struct cgroup___237;

struct css_set___237 {
	struct cgroup_subsys_state___237 *subsys[13];
	refcount_t refcount;
	struct css_set___237 *dom_cset;
	struct cgroup___237 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___237 *mg_src_cgrp;
	struct cgroup___237 *mg_dst_cgrp;
	struct css_set___237 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___145 {
	struct pmu___145 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___385 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___145 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

union thread_union___275 {
	struct task_struct___385 task;
	long unsigned int stack[8192];
};

struct bus_type___351 {
	const char *name;
	const char *dev_name;
	struct device___351 *dev_root;
	const struct attribute_group___348 **bus_groups;
	const struct attribute_group___348 **dev_groups;
	const struct attribute_group___348 **drv_groups;
	int (*match)(struct device___351 *, struct device_driver___351 *);
	int (*uevent)(struct device___351 *, struct kobj_uevent_env *);
	int (*probe)(struct device___351 *);
	int (*remove)(struct device___351 *);
	void (*shutdown)(struct device___351 *);
	int (*online)(struct device___351 *);
	int (*offline)(struct device___351 *);
	int (*suspend)(struct device___351 *, pm_message_t);
	int (*resume)(struct device___351 *);
	int (*num_vf)(struct device___351 *);
	int (*dma_configure)(struct device___351 *);
	const struct dev_pm_ops___351 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___351 {
	const char *name;
	struct bus_type___351 *bus;
	struct module___314 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___351 *);
	int (*remove)(struct device___351 *);
	void (*shutdown)(struct device___351 *);
	int (*suspend)(struct device___351 *, pm_message_t);
	int (*resume)(struct device___351 *);
	const struct attribute_group___348 **groups;
	const struct dev_pm_ops___351 *pm;
	void (*coredump)(struct device___351 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___351 {
	const char *name;
	const struct attribute_group___348 **groups;
	int (*uevent)(struct device___351 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___351 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___351 *);
	const struct dev_pm_ops___351 *pm;
};

struct class___351 {
	const char *name;
	struct module___314 *owner;
	const struct attribute_group___348 **class_groups;
	const struct attribute_group___348 **dev_groups;
	struct kobject___371 *dev_kobj;
	int (*dev_uevent)(struct device___351 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___351 *, umode_t *);
	void (*class_release)(struct class___351 *);
	void (*dev_release)(struct device___351 *);
	int (*shutdown_pre)(struct device___351 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___351 *);
	const struct dev_pm_ops___351 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dentry_operations___383;

struct super_block___383;

struct dentry___383 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___383 *d_parent;
	struct qstr d_name;
	struct inode___384 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___383 *d_op;
	struct super_block___383 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___383;

struct address_space___383 {
	struct inode___384 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___385 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___383 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___383;

struct block_device___383;

struct cdev___96;

struct inode___384 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___383 *i_op;
	struct super_block___383 *i_sb;
	struct address_space___383 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___385 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___384 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___383 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___383 *i_bdev;
		struct cdev___96 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___383 {
	int (*d_revalidate)(struct dentry___383 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___383 *, unsigned int);
	int (*d_hash)(const struct dentry___383 *, struct qstr *);
	int (*d_compare)(const struct dentry___383 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___383 *);
	int (*d_init)(struct dentry___383 *);
	void (*d_release)(struct dentry___383 *);
	void (*d_prune)(struct dentry___383 *);
	void (*d_iput)(struct dentry___383 *, struct inode___384 *);
	char * (*d_dname)(struct dentry___383 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___384 *);
	int (*d_manage)(const struct path___384 *, bool);
	struct dentry___383 * (*d_real)(struct dentry___383 *, const struct inode___384 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___383;

struct mem_dqinfo___383 {
	struct quota_format_type___383 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___383;

struct quota_info___383 {
	unsigned int flags;
	struct rw_semaphore___385 dqio_sem;
	struct inode___384 *files[3];
	struct mem_dqinfo___383 info[3];
	const struct quota_format_ops___383 *ops[3];
};

struct rcuwait___383 {
	struct task_struct___385 *task;
};

struct percpu_rw_semaphore___383 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___385 rw_sem;
	struct rcuwait___383 writer;
	int readers_block;
};

struct sb_writers___383 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___383 rw_sem[3];
};

struct file_system_type___383;

struct super_operations___383;

struct dquot_operations___383;

struct quotactl_ops___383;

struct super_block___383 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___383 *s_type;
	const struct super_operations___383 *s_op;
	const struct dquot_operations___383 *dq_op;
	const struct quotactl_ops___383 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___383 *s_root;
	struct rw_semaphore___385 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___383 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___383 s_dquot;
	struct sb_writers___383 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___383 *s_d_op;
	int cleancache_poolid;
	struct shrinker___134 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___253 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

typedef int (*dev_page_fault_t___372)(struct vm_area_struct___385 *, long unsigned int, const struct page___385 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___372)(struct page___385 *, void *);

struct dev_pagemap___372 {
	dev_page_fault_t___372 page_fault;
	dev_page_free_t___372 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___351 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___384 {
	struct task_struct___385 *task;
	struct core_thread___384 *next;
};

struct core_state___384 {
	atomic_t nr_threads;
	struct core_thread___384 dumper;
	struct completion startup;
};

struct vm_fault___372 {
	struct vm_area_struct___385 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___385 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___385 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___384 prealloc_pte;
};

struct kiocb___384 {
	struct file___384 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___384 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___383 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___384 *ia_file;
};

struct dquot___383 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___383 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___383 {
	int qf_fmt_id;
	const struct quota_format_ops___383 *qf_ops;
	struct module___314 *qf_owner;
	struct quota_format_type___383 *qf_next;
};

struct quota_format_ops___383 {
	int (*check_quota_file)(struct super_block___383 *, int);
	int (*read_file_info)(struct super_block___383 *, int);
	int (*write_file_info)(struct super_block___383 *, int);
	int (*free_file_info)(struct super_block___383 *, int);
	int (*read_dqblk)(struct dquot___383 *);
	int (*commit_dqblk)(struct dquot___383 *);
	int (*release_dqblk)(struct dquot___383 *);
	int (*get_next_id)(struct super_block___383 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___383 {
	int (*write_dquot)(struct dquot___383 *);
	struct dquot___383 * (*alloc_dquot)(struct super_block___383 *, int);
	void (*destroy_dquot)(struct dquot___383 *);
	int (*acquire_dquot)(struct dquot___383 *);
	int (*release_dquot)(struct dquot___383 *);
	int (*mark_dirty)(struct dquot___383 *);
	int (*write_info)(struct super_block___383 *, int);
	qsize_t * (*get_reserved_space)(struct inode___384 *);
	int (*get_projid)(struct inode___384 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___384 *, qsize_t *);
	int (*get_next_id)(struct super_block___383 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___383 {
	int (*quota_on)(struct super_block___383 *, int, int, const struct path___384 *);
	int (*quota_off)(struct super_block___383 *, int);
	int (*quota_enable)(struct super_block___383 *, unsigned int);
	int (*quota_disable)(struct super_block___383 *, unsigned int);
	int (*quota_sync)(struct super_block___383 *, int);
	int (*set_info)(struct super_block___383 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___383 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___383 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___383 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___383 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___383 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___383 {
	int (*writepage)(struct page___385 *, struct writeback_control___3 *);
	int (*readpage)(struct file___384 *, struct page___385 *);
	int (*writepages)(struct address_space___383 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___385 *);
	int (*readpages)(struct file___384 *, struct address_space___383 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___384 *, struct address_space___383 *, loff_t, unsigned int, unsigned int, struct page___385 **, void **);
	int (*write_end)(struct file___384 *, struct address_space___383 *, loff_t, unsigned int, unsigned int, struct page___385 *, void *);
	sector_t (*bmap)(struct address_space___383 *, sector_t);
	void (*invalidatepage)(struct page___385 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___385 *, gfp_t);
	void (*freepage)(struct page___385 *);
	ssize_t (*direct_IO)(struct kiocb___384 *, struct iov_iter___2 *);
	int (*migratepage)(struct address_space___383 *, struct page___385 *, struct page___385 *, enum migrate_mode);
	bool (*isolate_page)(struct page___385 *, isolate_mode_t);
	void (*putback_page)(struct page___385 *);
	int (*launder_page)(struct page___385 *);
	int (*is_partially_uptodate)(struct page___385 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___385 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___383 *, struct page___385 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___384 *, sector_t *);
	void (*swap_deactivate)(struct file___384 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___383 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___384 *bd_inode;
	struct super_block___383 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___383 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___96 {
	struct kobject___371 kobj;
	struct module___314 *owner;
	const struct file_operations___384 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___383 {
	struct dentry___383 * (*lookup)(struct inode___384 *, struct dentry___383 *, unsigned int);
	const char * (*get_link)(struct dentry___383 *, struct inode___384 *, struct delayed_call *);
	int (*permission)(struct inode___384 *, int);
	struct posix_acl * (*get_acl)(struct inode___384 *, int);
	int (*readlink)(struct dentry___383 *, char *, int);
	int (*create)(struct inode___384 *, struct dentry___383 *, umode_t, bool);
	int (*link)(struct dentry___383 *, struct inode___384 *, struct dentry___383 *);
	int (*unlink)(struct inode___384 *, struct dentry___383 *);
	int (*symlink)(struct inode___384 *, struct dentry___383 *, const char *);
	int (*mkdir)(struct inode___384 *, struct dentry___383 *, umode_t);
	int (*rmdir)(struct inode___384 *, struct dentry___383 *);
	int (*mknod)(struct inode___384 *, struct dentry___383 *, umode_t, dev_t);
	int (*rename)(struct inode___384 *, struct dentry___383 *, struct inode___384 *, struct dentry___383 *, unsigned int);
	int (*setattr)(struct dentry___383 *, struct iattr___383 *);
	int (*getattr)(const struct path___384 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___383 *, char *, size_t);
	int (*fiemap)(struct inode___384 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___384 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___384 *, struct dentry___383 *, struct file___384 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___384 *, struct dentry___383 *, umode_t);
	int (*set_acl)(struct inode___384 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___383 {
	void (*fl_copy_lock)(struct file_lock___384 *, struct file_lock___384 *);
	void (*fl_release_private)(struct file_lock___384 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___383;

struct file_lock___384 {
	struct file_lock___384 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___384 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___383 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___383 *fl_ops;
	const struct lock_manager_operations___383 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___383 {
	int (*lm_compare_owner)(struct file_lock___384 *, struct file_lock___384 *);
	long unsigned int (*lm_owner_key)(struct file_lock___384 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___384 *);
	int (*lm_grant)(struct file_lock___384 *, int);
	bool (*lm_break)(struct file_lock___384 *);
	int (*lm_change)(struct file_lock___384 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___384 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___383 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___383 *fa_next;
	struct file___384 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___383 {
	const char *name;
	int fs_flags;
	struct dentry___383 * (*mount)(struct file_system_type___383 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___383 *);
	struct module___314 *owner;
	struct file_system_type___383 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___383 {
	struct inode___384 * (*alloc_inode)(struct super_block___383 *);
	void (*destroy_inode)(struct inode___384 *);
	void (*dirty_inode)(struct inode___384 *, int);
	int (*write_inode)(struct inode___384 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___384 *);
	void (*evict_inode)(struct inode___384 *);
	void (*put_super)(struct super_block___383 *);
	int (*sync_fs)(struct super_block___383 *, int);
	int (*freeze_super)(struct super_block___383 *);
	int (*freeze_fs)(struct super_block___383 *);
	int (*thaw_super)(struct super_block___383 *);
	int (*unfreeze_fs)(struct super_block___383 *);
	int (*statfs)(struct dentry___383 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___383 *, int *, char *);
	void (*umount_begin)(struct super_block___383 *);
	int (*show_options)(struct seq_file___326 *, struct dentry___383 *);
	int (*show_devname)(struct seq_file___326 *, struct dentry___383 *);
	int (*show_path)(struct seq_file___326 *, struct dentry___383 *);
	int (*show_stats)(struct seq_file___326 *, struct dentry___383 *);
	ssize_t (*quota_read)(struct super_block___383 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___383 *, int, const char *, size_t, loff_t);
	struct dquot___383 ** (*get_dquots)(struct inode___384 *);
	int (*bdev_try_to_free_page)(struct super_block___383 *, struct page___385 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___383 *, struct shrink_control___134 *);
	long int (*free_cached_objects)(struct super_block___383 *, struct shrink_control___134 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*key_restrict_link_func_t___354)(struct key___353 *, const struct key_type *, const union key_payload *, struct key___353 *);

struct key_restriction___353;

struct key___353 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___385 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___353 *restrict_link;
};

struct key_restriction___353 {
	key_restrict_link_func_t___354 check;
	struct key___353 *key;
	struct key_type *keytype;
};

struct seq_operations___325 {
	void * (*start)(struct seq_file___326 *, loff_t *);
	void (*stop)(struct seq_file___326 *, void *);
	void * (*next)(struct seq_file___326 *, void *, loff_t *);
	int (*show)(struct seq_file___326 *, void *);
};

struct rtc_class_ops___3 {
	int (*ioctl)(struct device___351 *, unsigned int, long unsigned int);
	int (*read_time)(struct device___351 *, struct rtc_time *);
	int (*set_time)(struct device___351 *, struct rtc_time *);
	int (*read_alarm)(struct device___351 *, struct rtc_wkalrm *);
	int (*set_alarm)(struct device___351 *, struct rtc_wkalrm *);
	int (*proc)(struct device___351 *, struct seq_file___326 *);
	int (*set_mmss64)(struct device___351 *, time64_t);
	int (*set_mmss)(struct device___351 *, long unsigned int);
	int (*read_callback)(struct device___351 *, int);
	int (*alarm_irq_enable)(struct device___351 *, unsigned int);
	int (*read_offset)(struct device___351 *, long int *);
	int (*set_offset)(struct device___351 *, long int);
};

struct rtc_device___3 {
	struct device___351 dev;
	struct module___314 *owner;
	int id;
	const struct rtc_class_ops___3 *ops;
	struct mutex ops_lock;
	struct cdev___96 char_dev;
	long unsigned int flags;
	long unsigned int irq_data;
	spinlock_t irq_lock;
	wait_queue_head_t irq_queue;
	struct fasync_struct___383 *async_queue;
	struct rtc_task *irq_task;
	spinlock_t irq_task_lock;
	int irq_freq;
	int max_user_freq;
	struct timerqueue_head timerqueue;
	struct rtc_timer aie_timer;
	struct rtc_timer uie_rtctimer;
	struct hrtimer pie_timer;
	int pie_enabled;
	struct work_struct irqwork;
	int uie_unsupported;
	long int set_offset_nsec;
	bool registered;
	struct nvmem_device *nvmem;
	bool nvram_old_abi;
	struct bin_attribute___347 *nvram;
	time64_t range_min;
	timeu64_t range_max;
	time64_t start_secs;
	time64_t offset_secs;
	bool set_start_time;
};

struct kernel_param_ops___311 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___311 *);
	int (*get)(char *, const struct kernel_param___311 *);
	void (*free)(void *);
};

struct kparam_array___311;

struct kernel_param___311 {
	const char *name;
	struct module___314 *mod;
	const struct kernel_param_ops___311 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___311 *arr;
	};
};

struct kparam_array___311 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___311 *ops;
	void *elem;
};

struct module_attribute___311 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___311 *, struct module_kobject___311 *, char *);
	ssize_t (*store)(struct module_attribute___311 *, struct module_kobject___311 *, const char *, size_t);
	void (*setup)(struct module___314 *, const char *);
	int (*test)(struct module___314 *);
	void (*free)(struct module___314 *);
};

struct trace_event_class___138;

struct trace_event_call___138 {
	struct list_head list;
	struct trace_event_class___138 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___13 event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___39 *prog_array;
	int (*perf_perm)(struct trace_event_call___138 *, struct perf_event___145 *);
};

typedef void compound_page_dtor___372(struct page___385 *);

struct cgroup_namespace___237 {
	refcount_t count;
	struct ns_common___9 ns;
	struct user_namespace___253 *user_ns;
	struct ucounts___253 *ucounts;
	struct css_set___237 *root_cset;
};

struct ucounts___253 {
	struct hlist_node node;
	struct user_namespace___253 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct node___211 {
	struct device___351 dev;
};

struct bpf_map___238;

struct bpf_map_ops___237 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___238 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___238 *, struct file___384 *);
	void (*map_free)(struct bpf_map___238 *);
	int (*map_get_next_key)(struct bpf_map___238 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___238 *);
	void * (*map_lookup_elem)(struct bpf_map___238 *, void *);
	int (*map_update_elem)(struct bpf_map___238 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___238 *, void *);
	int (*map_push_elem)(struct bpf_map___238 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___238 *, void *);
	int (*map_peek_elem)(struct bpf_map___238 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___238 *, struct file___384 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___238 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___238 *, void *, struct seq_file___326 *);
	int (*map_check_btf)(const struct bpf_map___238 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___238 {
	const struct bpf_map_ops___237 *ops;
	struct bpf_map___238 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___353 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___238;

typedef void (*kthread_work_func_t___238)(struct kthread_work___238 *);

struct kthread_worker___238;

struct kthread_work___238 {
	struct list_head node;
	kthread_work_func_t___238 func;
	struct kthread_worker___238 *worker;
	int canceling;
};

struct kthread_worker___238 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___385 *task;
	struct kthread_work___238 *current_work;
};

struct kthread_delayed_work___237 {
	struct kthread_work___238 work;
	struct timer_list timer;
};

struct psi_group___237 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___238 *poll_kworker;
	struct kthread_delayed_work___237 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___237 {
	struct kernfs_node___378 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___237;

struct cgroup_subsys_state___237 {
	struct cgroup___237 *cgroup;
	struct cgroup_subsys___237 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___237 *parent;
};

struct cgroup_root___237;

struct cgroup_rstat_cpu___237;

struct cgroup___237 {
	struct cgroup_subsys_state___237 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___378 *kn;
	struct cgroup_file___237 procs_file;
	struct cgroup_file___237 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___237 *subsys[13];
	struct cgroup_root___237 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___237 *dom_cgrp;
	struct cgroup_rstat_cpu___237 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___39 bpf;
	atomic_t congestion_count;
	struct cgroup___237 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___237 psi;
	int ancestor_ids[0];
};

struct cftype___237;

struct cgroup_subsys___237 {
	struct cgroup_subsys_state___237 * (*css_alloc)(struct cgroup_subsys_state___237 *);
	int (*css_online)(struct cgroup_subsys_state___237 *);
	void (*css_offline)(struct cgroup_subsys_state___237 *);
	void (*css_released)(struct cgroup_subsys_state___237 *);
	void (*css_free)(struct cgroup_subsys_state___237 *);
	void (*css_reset)(struct cgroup_subsys_state___237 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___237 *, int);
	int (*css_extra_stat_show)(struct seq_file___326 *, struct cgroup_subsys_state___237 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___385 *);
	void (*cancel_fork)(struct task_struct___385 *);
	void (*fork)(struct task_struct___385 *);
	void (*exit)(struct task_struct___385 *);
	void (*free)(struct task_struct___385 *);
	void (*bind)(struct cgroup_subsys_state___237 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___237 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___237 *dfl_cftypes;
	struct cftype___237 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___237 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___237 *updated_children;
	struct cgroup___237 *updated_next;
};

struct cgroup_root___237 {
	struct kernfs_root___377 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___237 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___237 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___237 *ss;
	struct list_head node;
	struct kernfs_ops___377 *kf_ops;
	int (*open)(struct kernfs_open_file___377 *);
	void (*release)(struct kernfs_open_file___377 *);
	u64 (*read_u64)(struct cgroup_subsys_state___237 *, struct cftype___237 *);
	s64 (*read_s64)(struct cgroup_subsys_state___237 *, struct cftype___237 *);
	int (*seq_show)(struct seq_file___326 *, void *);
	void * (*seq_start)(struct seq_file___326 *, loff_t *);
	void * (*seq_next)(struct seq_file___326 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___326 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___237 *, struct cftype___237 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___237 *, struct cftype___237 *, s64);
	ssize_t (*write)(struct kernfs_open_file___377 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___377 *, struct poll_table_struct___232 *);
};

struct perf_cpu_context___145;

struct pmu___145 {
	struct list_head entry;
	struct module___314 *module;
	struct device___351 *dev;
	const struct attribute_group___348 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___145 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___145 *);
	void (*pmu_disable)(struct pmu___145 *);
	int (*event_init)(struct perf_event___145 *);
	void (*event_mapped)(struct perf_event___145 *, struct mm_struct___384 *);
	void (*event_unmapped)(struct perf_event___145 *, struct mm_struct___384 *);
	int (*add)(struct perf_event___145 *, int);
	void (*del)(struct perf_event___145 *, int);
	void (*start)(struct perf_event___145 *, int);
	void (*stop)(struct perf_event___145 *, int);
	void (*read)(struct perf_event___145 *);
	void (*start_txn)(struct pmu___145 *, unsigned int);
	int (*commit_txn)(struct pmu___145 *);
	void (*cancel_txn)(struct pmu___145 *);
	int (*event_idx)(struct perf_event___145 *);
	void (*sched_task)(struct perf_event_context___145 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___145 *);
	int (*filter_match)(struct perf_event___145 *);
	int (*check_period)(struct perf_event___145 *, u64);
};

struct perf_cpu_context___145 {
	struct perf_event_context___145 ctx;
	struct perf_event_context___145 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___145 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___145 {
	struct cgroup_subsys_state___237 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___138 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___138 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___138 *);
	struct list_head * (*get_fields)(struct trace_event_call___138 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___138 *);
};

struct trace_event_file___57;

struct trace_event_buffer___49 {
	struct ring_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___57 *trace_file;
	void *entry;
	long unsigned int flags;
	int pc;
};

struct trace_event_file___57 {
	struct list_head list;
	struct trace_event_call___138 *event_call;
	struct event_filter *filter;
	struct dentry___383 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_rtc_time_alarm_class {
	struct trace_entry ent;
	time64_t secs;
	int err;
	char __data[0];
};

struct trace_event_raw_rtc_irq_set_freq {
	struct trace_entry ent;
	int freq;
	int err;
	char __data[0];
};

struct trace_event_raw_rtc_irq_set_state {
	struct trace_entry ent;
	int enabled;
	int err;
	char __data[0];
};

struct trace_event_raw_rtc_alarm_irq_enable {
	struct trace_entry ent;
	unsigned int enabled;
	int err;
	char __data[0];
};

struct trace_event_raw_rtc_offset_class {
	struct trace_entry ent;
	long int offset;
	int err;
	char __data[0];
};

struct trace_event_raw_rtc_timer_class {
	struct trace_entry ent;
	struct rtc_timer *timer;
	ktime_t expires;
	ktime_t period;
	char __data[0];
};

struct trace_event_data_offsets_rtc_time_alarm_class {};

struct trace_event_data_offsets_rtc_irq_set_freq {};

struct trace_event_data_offsets_rtc_irq_set_state {};

struct trace_event_data_offsets_rtc_alarm_irq_enable {};

struct trace_event_data_offsets_rtc_offset_class {};

struct trace_event_data_offsets_rtc_timer_class {};

enum {
	none = 0,
	day = 1,
	month = 2,
	year = 3,
};

struct nvmem_cell_info {
	const char *name;
	unsigned int offset;
	unsigned int bytes;
	unsigned int bit_offset;
	unsigned int nbits;
};

typedef int (*nvmem_reg_read_t)(void *, unsigned int, void *, size_t);

typedef int (*nvmem_reg_write_t)(void *, unsigned int, void *, size_t);

struct nvmem_config {
	struct device___351 *dev;
	const char *name;
	int id;
	struct module___11 *owner;
	const struct nvmem_cell_info *cells;
	int ncells;
	bool read_only;
	bool root_only;
	nvmem_reg_read_t reg_read;
	nvmem_reg_write_t reg_write;
	int size;
	int word_size;
	int stride;
	void *priv;
	bool compat;
	struct device___351 *base_dev;
};

typedef struct poll_table_struct___196 poll_table___36;

struct rtc_class_ops___4 {
	int (*ioctl)(struct device___288 *, unsigned int, long unsigned int);
	int (*read_time)(struct device___288 *, struct rtc_time *);
	int (*set_time)(struct device___288 *, struct rtc_time *);
	int (*read_alarm)(struct device___288 *, struct rtc_wkalrm *);
	int (*set_alarm)(struct device___288 *, struct rtc_wkalrm *);
	int (*proc)(struct device___288 *, struct seq_file___273 *);
	int (*set_mmss64)(struct device___288 *, time64_t);
	int (*set_mmss)(struct device___288 *, long unsigned int);
	int (*read_callback)(struct device___288 *, int);
	int (*alarm_irq_enable)(struct device___288 *, unsigned int);
	int (*read_offset)(struct device___288 *, long int *);
	int (*set_offset)(struct device___288 *, long int);
};

struct rtc_device___4 {
	struct device___288 dev;
	struct module___262 *owner;
	int id;
	const struct rtc_class_ops___4 *ops;
	struct mutex ops_lock;
	struct cdev___70 char_dev;
	long unsigned int flags;
	long unsigned int irq_data;
	spinlock_t irq_lock;
	wait_queue_head_t irq_queue;
	struct fasync_struct___321 *async_queue;
	struct rtc_task *irq_task;
	spinlock_t irq_task_lock;
	int irq_freq;
	int max_user_freq;
	struct timerqueue_head timerqueue;
	struct rtc_timer aie_timer;
	struct rtc_timer uie_rtctimer;
	struct hrtimer pie_timer;
	int pie_enabled;
	struct work_struct irqwork;
	int uie_unsupported;
	long int set_offset_nsec;
	bool registered;
	struct nvmem_device *nvmem;
	bool nvram_old_abi;
	struct bin_attribute___285 *nvram;
	time64_t range_min;
	timeu64_t range_max;
	time64_t start_secs;
	time64_t offset_secs;
	bool set_start_time;
};

struct pl031_vendor_data {
	struct rtc_class_ops___2 ops;
	bool clockwatch;
	bool st_weekday;
	long unsigned int irqflags;
};

struct pl031_local {
	struct pl031_vendor_data *vendor;
	struct rtc_device___2 *rtc;
	void *base;
};

struct i2c_devinfo {
	struct list_head list;
	int busnum;
	struct i2c_board_info board_info;
};

struct vmacache___385 {
	u64 seqnum;
	struct vm_area_struct___3 *vmas[4];
};

struct page_frag___385 {
	struct page___3 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___146;

struct debug_info___146 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___146 *hbp_break[16];
	struct perf_event___146 *hbp_watch[16];
};

struct thread_struct___146 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___146 debug;
	long: 64;
};

struct mm_struct___385;

struct pid___222;

struct cred___354;

struct nsproxy___283;

struct signal_struct___264;

struct css_set___238;

struct perf_event_context___146;

struct vm_struct___290;

struct task_struct___386 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___386 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___385 *mm;
	struct mm_struct___385 *active_mm;
	struct vmacache___385 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___386 *real_parent;
	struct task_struct___386 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___386 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___222 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___222 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___222 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___354 *ptracer_cred;
	const struct cred___354 *real_cred;
	const struct cred___354 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___283 *nsproxy;
	struct signal_struct___264 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___386 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___107 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___238 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___146 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___385 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___386 *oom_reaper_list;
	struct vm_struct___290 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___146 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___146 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___386 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___146)(struct perf_event___146 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___146;

struct fasync_struct___384;

struct pid_namespace___222;

struct trace_event_call___139;

struct perf_cgroup___146;

struct perf_event___146 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___146 *group_leader;
	struct pmu___146 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___146 hw;
	struct perf_event_context___146 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___146 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___386 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___384 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___146 *);
	struct callback_head callback_head;
	struct pid_namespace___222 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___146 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___146 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___139 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___146 *cgrp;
	struct list_head sb_list;
};

typedef struct page___3 *pgtable_t___385;

struct address_space___384;

struct dev_pagemap___373;

struct page___3 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___384 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___3 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___385 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___385 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___373 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___385;

struct lruvec___385 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___385 *pgdat;
};

struct zone___385 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___385 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___385 {
	struct zone___385 *zone;
	int zone_idx;
};

struct zonelist___385 {
	struct zoneref___385 _zonerefs[25];
};

struct pglist_data___385 {
	struct zone___385 node_zones[3];
	struct zonelist___385 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___386 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___386 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___385 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___386 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___386 *owner;
};

struct secondary_data___386 {
	void *stack;
	struct task_struct___386 *task;
	long int status;
};

struct blocking_notifier_head___385 {
	struct rw_semaphore___386 rwsem;
	struct notifier_block *head;
};

struct key___354;

struct ucounts___254;

struct user_namespace___254 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___254 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___9 ns;
	long unsigned int flags;
	struct key___354 *persistent_keyring_register;
	struct rw_semaphore___386 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___254 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_root___378;

struct kernfs_elem_dir___378 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___378 *root;
};

struct kernfs_node___379;

struct kernfs_syscall_ops___378;

struct kernfs_root___378 {
	struct kernfs_node___379 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___378 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___378 {
	struct kernfs_node___379 *target_kn;
};

struct kernfs_ops___378;

struct kernfs_elem_attr___378 {
	const struct kernfs_ops___378 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___379 *notify_next;
};

struct kernfs_node___379 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___379 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___378 dir;
		struct kernfs_elem_symlink___378 symlink;
		struct kernfs_elem_attr___378 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___378;

struct kernfs_ops___378 {
	int (*open)(struct kernfs_open_file___378 *);
	void (*release)(struct kernfs_open_file___378 *);
	int (*seq_show)(struct seq_file___5 *, void *);
	void * (*seq_start)(struct seq_file___5 *, loff_t *);
	void * (*seq_next)(struct seq_file___5 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___5 *, void *);
	ssize_t (*read)(struct kernfs_open_file___378 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___378 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___378 *, struct vm_area_struct___3 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___378 *, struct poll_table_struct___2 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___378 {
	int (*remount_fs)(struct kernfs_root___378 *, int *, char *);
	int (*show_options)(struct seq_file___5 *, struct kernfs_root___378 *);
	int (*mkdir)(struct kernfs_node___379 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___379 *);
	int (*rename)(struct kernfs_node___379 *, struct kernfs_node___379 *, const char *);
	int (*show_path)(struct seq_file___5 *, struct kernfs_node___379 *, struct kernfs_root___378 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___326;

struct seq_file___5 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___326 *op;
	int poll_event;
	const struct file___2 *file;
	void *private;
};

struct vm_operations_struct___373;

struct kernfs_open_file___378 {
	struct kernfs_node___379 *kn;
	struct file___2 *file;
	struct seq_file___5 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___373 *vm_ops;
};

struct dentry___384;

struct path___385 {
	struct vfsmount *mnt;
	struct dentry___384 *dentry;
};

struct fown_struct___222 {
	rwlock_t lock;
	struct pid___222 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___2 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___385 f_path;
	struct inode___3 *f_inode;
	const struct file_operations___2 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___222 f_owner;
	const struct cred___354 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___384 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___373;

struct vm_operations_struct___373 {
	void (*open)(struct vm_area_struct___3 *);
	void (*close)(struct vm_area_struct___3 *);
	int (*split)(struct vm_area_struct___3 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___3 *);
	vm_fault_t (*fault)(struct vm_fault___373 *);
	vm_fault_t (*huge_fault)(struct vm_fault___373 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___373 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___3 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___373 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___373 *);
	int (*access)(struct vm_area_struct___3 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___3 *);
	int (*set_policy)(struct vm_area_struct___3 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___3 *, long unsigned int);
	struct page___3 * (*find_special_page)(struct vm_area_struct___3 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___239)(struct file___2 *, wait_queue_head_t *, struct poll_table_struct___2 *);

struct poll_table_struct___2 {
	poll_queue_proc___239 _qproc;
	__poll_t _key;
};

struct vm_area_struct___3 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___3 *vm_next;
	struct vm_area_struct___3 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___385 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___373 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___2 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___372;

struct bin_attribute___348;

struct attribute_group___349 {
	const char *name;
	umode_t (*is_visible)(struct kobject___372 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___372 *, struct bin_attribute___348 *, int);
	struct attribute **attrs;
	struct bin_attribute___348 **bin_attrs;
};

struct kset___371;

struct kobj_type___371;

struct kobject___372 {
	const char *name;
	struct list_head entry;
	struct kobject___372 *parent;
	struct kset___371 *kset;
	struct kobj_type___371 *ktype;
	struct kernfs_node___379 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___348 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___2 *, struct kobject___372 *, struct bin_attribute___348 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___2 *, struct kobject___372 *, struct bin_attribute___348 *, char *, loff_t, size_t);
	int (*mmap)(struct file___2 *, struct kobject___372 *, struct bin_attribute___348 *, struct vm_area_struct___3 *);
};

struct sysfs_ops___371 {
	ssize_t (*show)(struct kobject___372 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___372 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___371;

struct kset___371 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___372 kobj;
	const struct kset_uevent_ops___371 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___371 {
	void (*release)(struct kobject___372 *);
	const struct sysfs_ops___371 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___29 * (*child_ns_type)(struct kobject___372 *);
	const void * (*namespace)(struct kobject___372 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___371 {
	int (* const filter)(struct kset___371 *, struct kobject___372 *);
	const char * (* const name)(struct kset___371 *, struct kobject___372 *);
	int (* const uevent)(struct kset___371 *, struct kobject___372 *, struct kobj_uevent_env *);
};

struct kobj_attribute___363 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___372 *, struct kobj_attribute___363 *, char *);
	ssize_t (*store)(struct kobject___372 *, struct kobj_attribute___363 *, const char *, size_t);
};

struct device___352;

struct dev_pm_ops___352 {
	int (*prepare)(struct device___352 *);
	void (*complete)(struct device___352 *);
	int (*suspend)(struct device___352 *);
	int (*resume)(struct device___352 *);
	int (*freeze)(struct device___352 *);
	int (*thaw)(struct device___352 *);
	int (*poweroff)(struct device___352 *);
	int (*restore)(struct device___352 *);
	int (*suspend_late)(struct device___352 *);
	int (*resume_early)(struct device___352 *);
	int (*freeze_late)(struct device___352 *);
	int (*thaw_early)(struct device___352 *);
	int (*poweroff_late)(struct device___352 *);
	int (*restore_early)(struct device___352 *);
	int (*suspend_noirq)(struct device___352 *);
	int (*resume_noirq)(struct device___352 *);
	int (*freeze_noirq)(struct device___352 *);
	int (*thaw_noirq)(struct device___352 *);
	int (*poweroff_noirq)(struct device___352 *);
	int (*restore_noirq)(struct device___352 *);
	int (*runtime_suspend)(struct device___352 *);
	int (*runtime_resume)(struct device___352 *);
	int (*runtime_idle)(struct device___352 *);
};

struct pm_subsys_data___7;

struct dev_pm_info___352 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___352 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___352;

struct bus_type___352;

struct device_driver___352;

struct dev_pm_domain___352;

struct irq_domain___30;

struct device_node___89;

struct fwnode_handle___273;

struct class___352;

struct device___352 {
	struct device___352 *parent;
	struct device_private *p;
	struct kobject___372 kobj;
	const char *init_name;
	const struct device_type___352 *type;
	struct mutex mutex;
	struct bus_type___352 *bus;
	struct device_driver___352 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___352 power;
	struct dev_pm_domain___352 *pm_domain;
	struct irq_domain___30 *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___89 *of_node;
	struct fwnode_handle___273 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___352 *class;
	const struct attribute_group___349 **groups;
	void (*release)(struct device___352 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct pm_domain_data___7;

struct pm_subsys_data___7 {
	spinlock_t lock;
	unsigned int refcount;
	struct list_head clock_list;
	struct pm_domain_data___7 *domain_data;
};

struct pm_domain_data___7 {
	struct list_head list_node;
	struct device___352 *dev;
};

struct dev_pm_domain___352 {
	struct dev_pm_ops___352 ops;
	void (*detach)(struct device___352 *, bool);
	int (*activate)(struct device___352 *);
	void (*sync)(struct device___352 *);
	void (*dismiss)(struct device___352 *);
};

struct upid___222 {
	int nr;
	struct pid_namespace___222 *ns;
};

struct pid_namespace___222 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___386 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___222 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___384 *proc_self;
	struct dentry___384 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___254 *user_ns;
	struct ucounts___254 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___9 ns;
};

struct pid___222 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___222 numbers[1];
};

struct user_struct___354 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___354 *uid_keyring;
	struct key___354 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___385;

struct mm_struct___385 {
	struct {
		struct vm_area_struct___3 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___2 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___386 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___385 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___386 *owner;
		struct user_namespace___254 *user_ns;
		struct file___2 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___385 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___354 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___354 *session_keyring;
	struct key___354 *process_keyring;
	struct key___354 *thread_keyring;
	struct key___354 *request_key_auth;
	void *security;
	struct user_struct___354 *user;
	struct user_namespace___254 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___238;

struct nsproxy___283 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___222 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___238 *cgroup_ns;
};

struct signal_struct___264 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___386 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___386 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___222 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___222 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___385 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___222 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___238;

struct cgroup___238;

struct css_set___238 {
	struct cgroup_subsys_state___238 *subsys[13];
	refcount_t refcount;
	struct css_set___238 *dom_cset;
	struct cgroup___238 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___238 *mg_src_cgrp;
	struct cgroup___238 *mg_dst_cgrp;
	struct css_set___238 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___146 {
	struct pmu___146 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___386 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___146 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___290 {
	struct vm_struct___290 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___3 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___276 {
	struct task_struct___386 task;
	long unsigned int stack[8192];
};

struct bus_type___352 {
	const char *name;
	const char *dev_name;
	struct device___352 *dev_root;
	const struct attribute_group___349 **bus_groups;
	const struct attribute_group___349 **dev_groups;
	const struct attribute_group___349 **drv_groups;
	int (*match)(struct device___352 *, struct device_driver___352 *);
	int (*uevent)(struct device___352 *, struct kobj_uevent_env *);
	int (*probe)(struct device___352 *);
	int (*remove)(struct device___352 *);
	void (*shutdown)(struct device___352 *);
	int (*online)(struct device___352 *);
	int (*offline)(struct device___352 *);
	int (*suspend)(struct device___352 *, pm_message_t);
	int (*resume)(struct device___352 *);
	int (*num_vf)(struct device___352 *);
	int (*dma_configure)(struct device___352 *);
	const struct dev_pm_ops___352 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___352 {
	const char *name;
	struct bus_type___352 *bus;
	struct module___2 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___352 *);
	int (*remove)(struct device___352 *);
	void (*shutdown)(struct device___352 *);
	int (*suspend)(struct device___352 *, pm_message_t);
	int (*resume)(struct device___352 *);
	const struct attribute_group___349 **groups;
	const struct dev_pm_ops___352 *pm;
	void (*coredump)(struct device___352 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___352 {
	const char *name;
	const struct attribute_group___349 **groups;
	int (*uevent)(struct device___352 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___352 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___352 *);
	const struct dev_pm_ops___352 *pm;
};

struct module_kobject___312 {
	struct kobject___372 kobj;
	struct module___2 *mod;
	struct kobject___372 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___312 {
	struct module___2 *mod;
	struct latch_tree_node node;
};

struct module_layout___312 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___312 mtn;
};

struct module_attribute___312;

struct kernel_param___312;

struct module___2 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___312 mkobj;
	struct module_attribute___312 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___372 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___312 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___312 core_layout;
	struct module_layout___312 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___139 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct class___352 {
	const char *name;
	struct module___2 *owner;
	const struct attribute_group___349 **class_groups;
	const struct attribute_group___349 **dev_groups;
	struct kobject___372 *dev_kobj;
	int (*dev_uevent)(struct device___352 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___352 *, umode_t *);
	void (*class_release)(struct class___352 *);
	void (*dev_release)(struct device___352 *);
	int (*shutdown_pre)(struct device___352 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___352 *);
	const struct dev_pm_ops___352 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct device_attribute___55 {
	struct attribute attr;
	ssize_t (*show)(struct device___352 *, struct device_attribute___55 *, char *);
	ssize_t (*store)(struct device___352 *, struct device_attribute___55 *, const char *, size_t);
};

struct irq_domain_ops___30;

struct irq_domain_chip_generic___18;

struct irq_domain___30 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___30 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___273 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___18 *gc;
	struct irq_domain___30 *parent;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_direct_max_irq;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_tree_mutex;
	unsigned int linear_revmap[0];
};

struct fwnode_operations___273;

struct fwnode_handle___273 {
	struct fwnode_handle___273 *secondary;
	const struct fwnode_operations___273 *ops;
};

struct property___85;

struct device_node___89 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___273 fwnode;
	struct property___85 *properties;
	struct property___85 *deadprops;
	struct device_node___89 *parent;
	struct device_node___89 *child;
	struct device_node___89 *sibling;
	struct kobject___372 kobj;
	long unsigned int _flags;
	void *data;
};

struct fwnode_reference_args___273;

struct fwnode_endpoint___273;

struct fwnode_operations___273 {
	struct fwnode_handle___273 * (*get)(struct fwnode_handle___273 *);
	void (*put)(struct fwnode_handle___273 *);
	bool (*device_is_available)(const struct fwnode_handle___273 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___273 *, const struct device___352 *);
	bool (*property_present)(const struct fwnode_handle___273 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___273 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___273 *, const char *, const char **, size_t);
	struct fwnode_handle___273 * (*get_parent)(const struct fwnode_handle___273 *);
	struct fwnode_handle___273 * (*get_next_child_node)(const struct fwnode_handle___273 *, struct fwnode_handle___273 *);
	struct fwnode_handle___273 * (*get_named_child_node)(const struct fwnode_handle___273 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___273 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___273 *);
	struct fwnode_handle___273 * (*graph_get_next_endpoint)(const struct fwnode_handle___273 *, struct fwnode_handle___273 *);
	struct fwnode_handle___273 * (*graph_get_remote_endpoint)(const struct fwnode_handle___273 *);
	struct fwnode_handle___273 * (*graph_get_port_parent)(struct fwnode_handle___273 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___273 *, struct fwnode_endpoint___273 *);
};

struct fwnode_endpoint___273 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___273 *local_fwnode;
};

struct fwnode_reference_args___273 {
	struct fwnode_handle___273 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct kernel_param_ops___312 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___312 *);
	int (*get)(char *, const struct kernel_param___312 *);
	void (*free)(void *);
};

struct kparam_array___312;

struct kernel_param___312 {
	const char *name;
	struct module___2 *mod;
	const struct kernel_param_ops___312 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___312 *arr;
	};
};

struct kparam_array___312 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___312 *ops;
	void *elem;
};

struct module_attribute___312 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___312 *, struct module_kobject___312 *, char *);
	ssize_t (*store)(struct module_attribute___312 *, struct module_kobject___312 *, const char *, size_t);
	void (*setup)(struct module___2 *, const char *);
	int (*test)(struct module___2 *);
	void (*free)(struct module___2 *);
};

struct trace_event_class___139;

struct trace_event_call___139 {
	struct list_head list;
	struct trace_event_class___139 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___13 event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___39 *prog_array;
	int (*perf_perm)(struct trace_event_call___139 *, struct perf_event___146 *);
};

struct dentry_operations___384;

struct super_block___384;

struct dentry___384 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___384 *d_parent;
	struct qstr d_name;
	struct inode___3 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___384 *d_op;
	struct super_block___384 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___384;

struct address_space___384 {
	struct inode___3 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___386 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___384 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___384;

struct block_device___384;

struct cdev___97;

struct inode___3 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___384 *i_op;
	struct super_block___384 *i_sb;
	struct address_space___384 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___386 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___2 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___384 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___384 *i_bdev;
		struct cdev___97 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___384 {
	int (*d_revalidate)(struct dentry___384 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___384 *, unsigned int);
	int (*d_hash)(const struct dentry___384 *, struct qstr *);
	int (*d_compare)(const struct dentry___384 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___384 *);
	int (*d_init)(struct dentry___384 *);
	void (*d_release)(struct dentry___384 *);
	void (*d_prune)(struct dentry___384 *);
	void (*d_iput)(struct dentry___384 *, struct inode___3 *);
	char * (*d_dname)(struct dentry___384 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___385 *);
	int (*d_manage)(const struct path___385 *, bool);
	struct dentry___384 * (*d_real)(struct dentry___384 *, const struct inode___3 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___384;

struct mem_dqinfo___384 {
	struct quota_format_type___384 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___384;

struct quota_info___384 {
	unsigned int flags;
	struct rw_semaphore___386 dqio_sem;
	struct inode___3 *files[3];
	struct mem_dqinfo___384 info[3];
	const struct quota_format_ops___384 *ops[3];
};

struct rcuwait___384 {
	struct task_struct___386 *task;
};

struct percpu_rw_semaphore___384 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___386 rw_sem;
	struct rcuwait___384 writer;
	int readers_block;
};

struct sb_writers___384 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___384 rw_sem[3];
};

struct file_system_type___384;

struct super_operations___384;

struct dquot_operations___384;

struct quotactl_ops___384;

struct super_block___384 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___384 *s_type;
	const struct super_operations___384 *s_op;
	const struct dquot_operations___384 *dq_op;
	const struct quotactl_ops___384 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___384 *s_root;
	struct rw_semaphore___386 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___384 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___384 s_dquot;
	struct sb_writers___384 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___384 *s_d_op;
	int cleancache_poolid;
	struct shrinker___134 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___254 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

typedef int (*dev_page_fault_t___373)(struct vm_area_struct___3 *, long unsigned int, const struct page___3 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___373)(struct page___3 *, void *);

struct dev_pagemap___373 {
	dev_page_fault_t___373 page_fault;
	dev_page_free_t___373 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___352 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___385 {
	struct task_struct___386 *task;
	struct core_thread___385 *next;
};

struct core_state___385 {
	atomic_t nr_threads;
	struct core_thread___385 dumper;
	struct completion startup;
};

struct vm_fault___373 {
	struct vm_area_struct___3 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___3 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___3 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___385 prealloc_pte;
};

struct kiocb___2 {
	struct file___2 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___2 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___384 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___2 *ia_file;
};

struct dquot___384 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___384 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___384 {
	int qf_fmt_id;
	const struct quota_format_ops___384 *qf_ops;
	struct module___2 *qf_owner;
	struct quota_format_type___384 *qf_next;
};

struct quota_format_ops___384 {
	int (*check_quota_file)(struct super_block___384 *, int);
	int (*read_file_info)(struct super_block___384 *, int);
	int (*write_file_info)(struct super_block___384 *, int);
	int (*free_file_info)(struct super_block___384 *, int);
	int (*read_dqblk)(struct dquot___384 *);
	int (*commit_dqblk)(struct dquot___384 *);
	int (*release_dqblk)(struct dquot___384 *);
	int (*get_next_id)(struct super_block___384 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___384 {
	int (*write_dquot)(struct dquot___384 *);
	struct dquot___384 * (*alloc_dquot)(struct super_block___384 *, int);
	void (*destroy_dquot)(struct dquot___384 *);
	int (*acquire_dquot)(struct dquot___384 *);
	int (*release_dquot)(struct dquot___384 *);
	int (*mark_dirty)(struct dquot___384 *);
	int (*write_info)(struct super_block___384 *, int);
	qsize_t * (*get_reserved_space)(struct inode___3 *);
	int (*get_projid)(struct inode___3 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___3 *, qsize_t *);
	int (*get_next_id)(struct super_block___384 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___384 {
	int (*quota_on)(struct super_block___384 *, int, int, const struct path___385 *);
	int (*quota_off)(struct super_block___384 *, int);
	int (*quota_enable)(struct super_block___384 *, unsigned int);
	int (*quota_disable)(struct super_block___384 *, unsigned int);
	int (*quota_sync)(struct super_block___384 *, int);
	int (*set_info)(struct super_block___384 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___384 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___384 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___384 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___384 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___384 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___384 {
	int (*writepage)(struct page___3 *, struct writeback_control___3 *);
	int (*readpage)(struct file___2 *, struct page___3 *);
	int (*writepages)(struct address_space___384 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___3 *);
	int (*readpages)(struct file___2 *, struct address_space___384 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___2 *, struct address_space___384 *, loff_t, unsigned int, unsigned int, struct page___3 **, void **);
	int (*write_end)(struct file___2 *, struct address_space___384 *, loff_t, unsigned int, unsigned int, struct page___3 *, void *);
	sector_t (*bmap)(struct address_space___384 *, sector_t);
	void (*invalidatepage)(struct page___3 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___3 *, gfp_t);
	void (*freepage)(struct page___3 *);
	ssize_t (*direct_IO)(struct kiocb___2 *, struct iov_iter___2 *);
	int (*migratepage)(struct address_space___384 *, struct page___3 *, struct page___3 *, enum migrate_mode);
	bool (*isolate_page)(struct page___3 *, isolate_mode_t);
	void (*putback_page)(struct page___3 *);
	int (*launder_page)(struct page___3 *);
	int (*is_partially_uptodate)(struct page___3 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___3 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___384 *, struct page___3 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___2 *, sector_t *);
	void (*swap_deactivate)(struct file___2 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___384 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___3 *bd_inode;
	struct super_block___384 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___384 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___97 {
	struct kobject___372 kobj;
	struct module___2 *owner;
	const struct file_operations___2 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___384 {
	struct dentry___384 * (*lookup)(struct inode___3 *, struct dentry___384 *, unsigned int);
	const char * (*get_link)(struct dentry___384 *, struct inode___3 *, struct delayed_call *);
	int (*permission)(struct inode___3 *, int);
	struct posix_acl * (*get_acl)(struct inode___3 *, int);
	int (*readlink)(struct dentry___384 *, char *, int);
	int (*create)(struct inode___3 *, struct dentry___384 *, umode_t, bool);
	int (*link)(struct dentry___384 *, struct inode___3 *, struct dentry___384 *);
	int (*unlink)(struct inode___3 *, struct dentry___384 *);
	int (*symlink)(struct inode___3 *, struct dentry___384 *, const char *);
	int (*mkdir)(struct inode___3 *, struct dentry___384 *, umode_t);
	int (*rmdir)(struct inode___3 *, struct dentry___384 *);
	int (*mknod)(struct inode___3 *, struct dentry___384 *, umode_t, dev_t);
	int (*rename)(struct inode___3 *, struct dentry___384 *, struct inode___3 *, struct dentry___384 *, unsigned int);
	int (*setattr)(struct dentry___384 *, struct iattr___384 *);
	int (*getattr)(const struct path___385 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___384 *, char *, size_t);
	int (*fiemap)(struct inode___3 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___3 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___3 *, struct dentry___384 *, struct file___2 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___3 *, struct dentry___384 *, umode_t);
	int (*set_acl)(struct inode___3 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___384 {
	void (*fl_copy_lock)(struct file_lock___2 *, struct file_lock___2 *);
	void (*fl_release_private)(struct file_lock___2 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___384;

struct file_lock___2 {
	struct file_lock___2 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___2 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___384 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___384 *fl_ops;
	const struct lock_manager_operations___384 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___384 {
	int (*lm_compare_owner)(struct file_lock___2 *, struct file_lock___2 *);
	long unsigned int (*lm_owner_key)(struct file_lock___2 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___2 *);
	int (*lm_grant)(struct file_lock___2 *, int);
	bool (*lm_break)(struct file_lock___2 *);
	int (*lm_change)(struct file_lock___2 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___2 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___384 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___384 *fa_next;
	struct file___2 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___384 {
	const char *name;
	int fs_flags;
	struct dentry___384 * (*mount)(struct file_system_type___384 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___384 *);
	struct module___2 *owner;
	struct file_system_type___384 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___384 {
	struct inode___3 * (*alloc_inode)(struct super_block___384 *);
	void (*destroy_inode)(struct inode___3 *);
	void (*dirty_inode)(struct inode___3 *, int);
	int (*write_inode)(struct inode___3 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___3 *);
	void (*evict_inode)(struct inode___3 *);
	void (*put_super)(struct super_block___384 *);
	int (*sync_fs)(struct super_block___384 *, int);
	int (*freeze_super)(struct super_block___384 *);
	int (*freeze_fs)(struct super_block___384 *);
	int (*thaw_super)(struct super_block___384 *);
	int (*unfreeze_fs)(struct super_block___384 *);
	int (*statfs)(struct dentry___384 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___384 *, int *, char *);
	void (*umount_begin)(struct super_block___384 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___384 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___384 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___384 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___384 *);
	ssize_t (*quota_read)(struct super_block___384 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___384 *, int, const char *, size_t, loff_t);
	struct dquot___384 ** (*get_dquots)(struct inode___3 *);
	int (*bdev_try_to_free_page)(struct super_block___384 *, struct page___3 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___384 *, struct shrink_control___134 *);
	long int (*free_cached_objects)(struct super_block___384 *, struct shrink_control___134 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct acpi_device___20;

struct acpi_hotplug_profile___20 {
	struct kobject___372 kobj;
	int (*scan_dependent)(struct acpi_device___20 *);
	void (*notify_online)(struct acpi_device___20 *);
	bool enabled: 1;
	bool demand_offline: 1;
};

struct acpi_device_wakeup_context___20 {
	void (*func)(struct acpi_device_wakeup_context___20 *);
	struct device___352 *dev;
};

struct acpi_device_wakeup___20 {
	acpi_handle gpe_device;
	u64 gpe_number;
	u64 sleep_state;
	struct list_head resources;
	struct acpi_device_wakeup_flags flags;
	struct acpi_device_wakeup_context___20 context;
	struct wakeup_source___8 *ws;
	int prepare_count;
	int enable_count;
};

struct acpi_scan_handler___20;

struct acpi_hotplug_context___20;

struct acpi_driver___20;

struct acpi_device___20 {
	int device_type;
	acpi_handle handle;
	struct fwnode_handle___273 fwnode;
	struct acpi_device___20 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup___20 wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_device_data data;
	struct acpi_scan_handler___20 *handler;
	struct acpi_hotplug_context___20 *hp;
	struct acpi_driver___20 *driver;
	const struct acpi_gpio_mapping *driver_gpios;
	void *driver_data;
	struct device___352 dev;
	unsigned int physical_node_count;
	unsigned int dep_unmet;
	struct list_head physical_node_list;
	struct mutex physical_node_lock;
	void (*remove)(struct acpi_device___20 *);
};

struct acpi_scan_handler___20 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	bool (*match)(const char *, const struct acpi_device_id **);
	int (*attach)(struct acpi_device___20 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___20 *);
	void (*bind)(struct device___352 *);
	void (*unbind)(struct device___352 *);
	struct acpi_hotplug_profile___20 hotplug;
};

struct acpi_hotplug_context___20 {
	struct acpi_device___20 *self;
	int (*notify)(struct acpi_device___20 *, u32);
	void (*uevent)(struct acpi_device___20 *, u32);
	void (*fixup)(struct acpi_device___20 *);
};

typedef int (*acpi_op_add___20)(struct acpi_device___20 *);

typedef int (*acpi_op_remove___20)(struct acpi_device___20 *);

typedef void (*acpi_op_notify___20)(struct acpi_device___20 *, u32);

struct acpi_device_ops___20 {
	acpi_op_add___20 add;
	acpi_op_remove___20 remove;
	acpi_op_notify___20 notify;
};

struct acpi_driver___20 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___20 ops;
	struct device_driver___352 drv;
	struct module___2 *owner;
};

struct irqaction___19 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___19 *next;
	irq_handler_t thread_fn;
	struct task_struct___386 *thread;
	struct irqaction___19 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef int (*key_restrict_link_func_t___355)(struct key___354 *, const struct key_type *, const union key_payload *, struct key___354 *);

struct key_restriction___354;

struct key___354 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___386 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___354 *restrict_link;
};

struct key_restriction___354 {
	key_restrict_link_func_t___355 check;
	struct key___354 *key;
	struct key_type *keytype;
};

struct seq_operations___326 {
	void * (*start)(struct seq_file___5 *, loff_t *);
	void (*stop)(struct seq_file___5 *, void *);
	void * (*next)(struct seq_file___5 *, void *, loff_t *);
	int (*show)(struct seq_file___5 *, void *);
};

typedef void compound_page_dtor___373(struct page___3 *);

struct rt_mutex___6 {
	raw_spinlock_t wait_lock;
	struct rb_root_cached waiters;
	struct task_struct___386 *owner;
};

struct irq_desc___23;

typedef void (*irq_flow_handler_t___23)(struct irq_desc___23 *);

struct irq_chip___31;

struct irq_data___31 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___11 *common;
	struct irq_chip___31 *chip;
	struct irq_domain___30 *domain;
	struct irq_data___31 *parent_data;
	void *chip_data;
};

struct irq_desc___23 {
	struct irq_common_data___11 irq_common_data;
	struct irq_data___31 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___23 handle_irq;
	struct irqaction___19 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int irq_count;
	unsigned int tot_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___372 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___2 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct property___85 {
	char *name;
	int length;
	void *value;
	struct property___85 *next;
	long unsigned int _flags;
	struct bin_attribute___348 attr;
};

struct irq_fwspec___30 {
	struct fwnode_handle___273 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___30 {
	int (*match)(struct irq_domain___30 *, struct device_node___89 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___30 *, struct irq_fwspec___30 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___30 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___30 *, unsigned int);
	int (*xlate)(struct irq_domain___30 *, struct device_node___89 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___30 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___30 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___30 *, struct irq_data___31 *, bool);
	void (*deactivate)(struct irq_domain___30 *, struct irq_data___31 *);
	int (*translate)(struct irq_domain___30 *, struct irq_fwspec___30 *, long unsigned int *, unsigned int *);
};

struct irq_chip_generic___19;

struct irq_domain_chip_generic___18 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___19 *gc[0];
};

struct i2c_client___3;

typedef int (*i2c_slave_cb_t___3)(struct i2c_client___3 *, enum i2c_slave_event, u8 *);

struct i2c_adapter___3;

struct i2c_client___3 {
	short unsigned int flags;
	short unsigned int addr;
	char name[20];
	struct i2c_adapter___3 *adapter;
	struct device___352 dev;
	int irq;
	struct list_head detected;
	i2c_slave_cb_t___3 slave_cb;
};

struct i2c_device_identity {
	u16 manufacturer_id;
	u16 part_id;
	u8 die_revision;
};

struct i2c_board_info___2;

struct i2c_driver___2 {
	unsigned int class;
	int (*attach_adapter)(struct i2c_adapter___3 *);
	int (*probe)(struct i2c_client___3 *, const struct i2c_device_id *);
	int (*remove)(struct i2c_client___3 *);
	int (*probe_new)(struct i2c_client___3 *);
	void (*shutdown)(struct i2c_client___3 *);
	void (*alert)(struct i2c_client___3 *, enum i2c_alert_protocol, unsigned int);
	int (*command)(struct i2c_client___3 *, unsigned int, void *);
	struct device_driver___352 driver;
	const struct i2c_device_id *id_table;
	int (*detect)(struct i2c_client___3 *, struct i2c_board_info___2 *);
	const short unsigned int *address_list;
	struct list_head clients;
	bool disable_i2c_core_irq_mapping;
};

struct i2c_algorithm___3;

struct i2c_lock_operations___3;

struct i2c_bus_recovery_info___3;

struct i2c_adapter___3 {
	struct module___2 *owner;
	unsigned int class;
	const struct i2c_algorithm___3 *algo;
	void *algo_data;
	const struct i2c_lock_operations___3 *lock_ops;
	struct rt_mutex___6 bus_lock;
	struct rt_mutex___6 mux_lock;
	int timeout;
	int retries;
	struct device___352 dev;
	int nr;
	char name[48];
	struct completion dev_released;
	struct mutex userspace_clients_lock;
	struct list_head userspace_clients;
	struct i2c_bus_recovery_info___3 *bus_recovery_info;
	const struct i2c_adapter_quirks *quirks;
	struct irq_domain___30 *host_notify_domain;
};

struct i2c_board_info___2 {
	char type[20];
	short unsigned int flags;
	short unsigned int addr;
	const char *dev_name;
	void *platform_data;
	struct device_node___89 *of_node;
	struct fwnode_handle___273 *fwnode;
	const struct property_entry___2 *properties;
	const struct resource *resources;
	unsigned int num_resources;
	int irq;
};

struct i2c_algorithm___3 {
	int (*master_xfer)(struct i2c_adapter___3 *, struct i2c_msg *, int);
	int (*smbus_xfer)(struct i2c_adapter___3 *, u16, short unsigned int, char, u8, int, union i2c_smbus_data *);
	u32 (*functionality)(struct i2c_adapter___3 *);
	int (*reg_slave)(struct i2c_client___3 *);
	int (*unreg_slave)(struct i2c_client___3 *);
};

struct i2c_lock_operations___3 {
	void (*lock_bus)(struct i2c_adapter___3 *, unsigned int);
	int (*trylock_bus)(struct i2c_adapter___3 *, unsigned int);
	void (*unlock_bus)(struct i2c_adapter___3 *, unsigned int);
};

struct i2c_timings {
	u32 bus_freq_hz;
	u32 scl_rise_ns;
	u32 scl_fall_ns;
	u32 scl_int_delay_ns;
	u32 sda_fall_ns;
};

struct i2c_bus_recovery_info___3 {
	int (*recover_bus)(struct i2c_adapter___3 *);
	int (*get_scl)(struct i2c_adapter___3 *);
	void (*set_scl)(struct i2c_adapter___3 *, int);
	int (*get_sda)(struct i2c_adapter___3 *);
	void (*set_sda)(struct i2c_adapter___3 *, int);
	void (*prepare_recovery)(struct i2c_adapter___3 *);
	void (*unprepare_recovery)(struct i2c_adapter___3 *);
	struct gpio_desc *scl_gpiod;
	struct gpio_desc *sda_gpiod;
};

struct node___212 {
	struct device___352 dev;
};

struct irq_chip___31 {
	struct device___352 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___31 *);
	void (*irq_shutdown)(struct irq_data___31 *);
	void (*irq_enable)(struct irq_data___31 *);
	void (*irq_disable)(struct irq_data___31 *);
	void (*irq_ack)(struct irq_data___31 *);
	void (*irq_mask)(struct irq_data___31 *);
	void (*irq_mask_ack)(struct irq_data___31 *);
	void (*irq_unmask)(struct irq_data___31 *);
	void (*irq_eoi)(struct irq_data___31 *);
	int (*irq_set_affinity)(struct irq_data___31 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___31 *);
	int (*irq_set_type)(struct irq_data___31 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___31 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___31 *);
	void (*irq_bus_sync_unlock)(struct irq_data___31 *);
	void (*irq_cpu_online)(struct irq_data___31 *);
	void (*irq_cpu_offline)(struct irq_data___31 *);
	void (*irq_suspend)(struct irq_data___31 *);
	void (*irq_resume)(struct irq_data___31 *);
	void (*irq_pm_shutdown)(struct irq_data___31 *);
	void (*irq_calc_mask)(struct irq_data___31 *);
	void (*irq_print_chip)(struct irq_data___31 *, struct seq_file___5 *);
	int (*irq_request_resources)(struct irq_data___31 *);
	void (*irq_release_resources)(struct irq_data___31 *);
	void (*irq_compose_msi_msg)(struct irq_data___31 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___31 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___31 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___31 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___31 *, void *);
	void (*ipi_send_single)(struct irq_data___31 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___31 *, const struct cpumask *);
	long unsigned int flags;
};

struct irq_chip_type___19 {
	struct irq_chip___31 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___23 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___19 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___19 *);
	void (*resume)(struct irq_chip_generic___19 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___30 *domain;
	struct list_head list;
	struct irq_chip_type___19 chip_types[0];
};

struct dev_power_governor___7 {
	bool (*power_down_ok)(struct dev_pm_domain___352 *);
	bool (*suspend_ok)(struct device___352 *);
};

struct i2c_devinfo___2 {
	struct list_head list;
	int busnum;
	struct i2c_board_info___2 board_info;
};

struct cgroup_namespace___238 {
	refcount_t count;
	struct ns_common___9 ns;
	struct user_namespace___254 *user_ns;
	struct ucounts___254 *ucounts;
	struct css_set___238 *root_cset;
};

struct ucounts___254 {
	struct hlist_node node;
	struct user_namespace___254 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___239;

struct bpf_map_ops___238 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___239 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___239 *, struct file___2 *);
	void (*map_free)(struct bpf_map___239 *);
	int (*map_get_next_key)(struct bpf_map___239 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___239 *);
	void * (*map_lookup_elem)(struct bpf_map___239 *, void *);
	int (*map_update_elem)(struct bpf_map___239 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___239 *, void *);
	int (*map_push_elem)(struct bpf_map___239 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___239 *, void *);
	int (*map_peek_elem)(struct bpf_map___239 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___239 *, struct file___2 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___239 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___239 *, void *, struct seq_file___5 *);
	int (*map_check_btf)(const struct bpf_map___239 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___239 {
	const struct bpf_map_ops___238 *ops;
	struct bpf_map___239 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___354 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___239;

typedef void (*kthread_work_func_t___239)(struct kthread_work___239 *);

struct kthread_worker___239;

struct kthread_work___239 {
	struct list_head node;
	kthread_work_func_t___239 func;
	struct kthread_worker___239 *worker;
	int canceling;
};

struct kthread_worker___239 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___386 *task;
	struct kthread_work___239 *current_work;
};

struct kthread_delayed_work___238 {
	struct kthread_work___239 work;
	struct timer_list timer;
};

struct psi_group___238 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___239 *poll_kworker;
	struct kthread_delayed_work___238 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___238 {
	struct kernfs_node___379 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___238;

struct cgroup_subsys_state___238 {
	struct cgroup___238 *cgroup;
	struct cgroup_subsys___238 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___238 *parent;
};

struct cgroup_root___238;

struct cgroup_rstat_cpu___238;

struct cgroup___238 {
	struct cgroup_subsys_state___238 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___379 *kn;
	struct cgroup_file___238 procs_file;
	struct cgroup_file___238 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___238 *subsys[13];
	struct cgroup_root___238 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___238 *dom_cgrp;
	struct cgroup_rstat_cpu___238 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___39 bpf;
	atomic_t congestion_count;
	struct cgroup___238 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___238 psi;
	int ancestor_ids[0];
};

struct cftype___238;

struct cgroup_subsys___238 {
	struct cgroup_subsys_state___238 * (*css_alloc)(struct cgroup_subsys_state___238 *);
	int (*css_online)(struct cgroup_subsys_state___238 *);
	void (*css_offline)(struct cgroup_subsys_state___238 *);
	void (*css_released)(struct cgroup_subsys_state___238 *);
	void (*css_free)(struct cgroup_subsys_state___238 *);
	void (*css_reset)(struct cgroup_subsys_state___238 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___238 *, int);
	int (*css_extra_stat_show)(struct seq_file___5 *, struct cgroup_subsys_state___238 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___386 *);
	void (*cancel_fork)(struct task_struct___386 *);
	void (*fork)(struct task_struct___386 *);
	void (*exit)(struct task_struct___386 *);
	void (*free)(struct task_struct___386 *);
	void (*bind)(struct cgroup_subsys_state___238 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___238 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___238 *dfl_cftypes;
	struct cftype___238 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___238 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___238 *updated_children;
	struct cgroup___238 *updated_next;
};

struct cgroup_root___238 {
	struct kernfs_root___378 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___238 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___238 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___238 *ss;
	struct list_head node;
	struct kernfs_ops___378 *kf_ops;
	int (*open)(struct kernfs_open_file___378 *);
	void (*release)(struct kernfs_open_file___378 *);
	u64 (*read_u64)(struct cgroup_subsys_state___238 *, struct cftype___238 *);
	s64 (*read_s64)(struct cgroup_subsys_state___238 *, struct cftype___238 *);
	int (*seq_show)(struct seq_file___5 *, void *);
	void * (*seq_start)(struct seq_file___5 *, loff_t *);
	void * (*seq_next)(struct seq_file___5 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___5 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___238 *, struct cftype___238 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___238 *, struct cftype___238 *, s64);
	ssize_t (*write)(struct kernfs_open_file___378 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___378 *, struct poll_table_struct___2 *);
};

struct perf_cpu_context___146;

struct pmu___146 {
	struct list_head entry;
	struct module___2 *module;
	struct device___352 *dev;
	const struct attribute_group___349 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___146 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___146 *);
	void (*pmu_disable)(struct pmu___146 *);
	int (*event_init)(struct perf_event___146 *);
	void (*event_mapped)(struct perf_event___146 *, struct mm_struct___385 *);
	void (*event_unmapped)(struct perf_event___146 *, struct mm_struct___385 *);
	int (*add)(struct perf_event___146 *, int);
	void (*del)(struct perf_event___146 *, int);
	void (*start)(struct perf_event___146 *, int);
	void (*stop)(struct perf_event___146 *, int);
	void (*read)(struct perf_event___146 *);
	void (*start_txn)(struct pmu___146 *, unsigned int);
	int (*commit_txn)(struct pmu___146 *);
	void (*cancel_txn)(struct pmu___146 *);
	int (*event_idx)(struct perf_event___146 *);
	void (*sched_task)(struct perf_event_context___146 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___146 *);
	int (*filter_match)(struct perf_event___146 *);
	int (*check_period)(struct perf_event___146 *, u64);
};

struct perf_cpu_context___146 {
	struct perf_event_context___146 ctx;
	struct perf_event_context___146 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___146 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___146 {
	struct cgroup_subsys_state___238 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___139 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___139 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___139 *);
	struct list_head * (*get_fields)(struct trace_event_call___139 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___139 *);
};

struct trace_event_file___58;

struct trace_event_buffer___50 {
	struct ring_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___58 *trace_file;
	void *entry;
	long unsigned int flags;
	int pc;
};

struct trace_event_file___58 {
	struct list_head list;
	struct trace_event_call___139 *event_call;
	struct event_filter *filter;
	struct dentry___384 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_i2c_write {
	struct trace_entry ent;
	int adapter_nr;
	__u16 msg_nr;
	__u16 addr;
	__u16 flags;
	__u16 len;
	u32 __data_loc_buf;
	char __data[0];
};

struct trace_event_raw_i2c_read {
	struct trace_entry ent;
	int adapter_nr;
	__u16 msg_nr;
	__u16 addr;
	__u16 flags;
	__u16 len;
	char __data[0];
};

struct trace_event_raw_i2c_reply {
	struct trace_entry ent;
	int adapter_nr;
	__u16 msg_nr;
	__u16 addr;
	__u16 flags;
	__u16 len;
	u32 __data_loc_buf;
	char __data[0];
};

struct trace_event_raw_i2c_result {
	struct trace_entry ent;
	int adapter_nr;
	__u16 nr_msgs;
	__s16 ret;
	char __data[0];
};

struct trace_event_data_offsets_i2c_write {
	u32 buf;
};

struct trace_event_data_offsets_i2c_read {};

struct trace_event_data_offsets_i2c_reply {
	u32 buf;
};

struct trace_event_data_offsets_i2c_result {};

struct class_compat___2;

struct i2c_cmd_arg {
	unsigned int cmd;
	void *arg;
};

struct module___315;

struct file___385;

struct kiocb___385;

struct poll_table_struct___233;

struct vm_area_struct___386;

struct inode___385;

struct file_lock___385;

struct page___386;

struct seq_file___327;

struct file_operations___385 {
	struct module___315 *owner;
	loff_t (*llseek)(struct file___385 *, loff_t, int);
	ssize_t (*read)(struct file___385 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___385 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___385 *, struct iov_iter___2 *);
	ssize_t (*write_iter)(struct kiocb___385 *, struct iov_iter___2 *);
	int (*iopoll)(struct kiocb___385 *, bool);
	int (*iterate)(struct file___385 *, struct dir_context *);
	int (*iterate_shared)(struct file___385 *, struct dir_context *);
	__poll_t (*poll)(struct file___385 *, struct poll_table_struct___233 *);
	long int (*unlocked_ioctl)(struct file___385 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___385 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___385 *, struct vm_area_struct___386 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___385 *, struct file___385 *);
	int (*flush)(struct file___385 *, fl_owner_t);
	int (*release)(struct inode___385 *, struct file___385 *);
	int (*fsync)(struct file___385 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___385 *, int);
	int (*lock)(struct file___385 *, int, struct file_lock___385 *);
	ssize_t (*sendpage)(struct file___385 *, struct page___386 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___385 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___385 *, int, struct file_lock___385 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___385 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___385 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___385 *, long int, struct file_lock___385 **, void **);
	long int (*fallocate)(struct file___385 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___327 *, struct file___385 *);
	ssize_t (*copy_file_range)(struct file___385 *, loff_t, struct file___385 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___385 *, loff_t, struct file___385 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___385 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct perf_event___147;

struct debug_info___147 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___147 *hbp_break[16];
	struct perf_event___147 *hbp_watch[16];
};

struct task_struct___387;

struct hw_perf_event___147 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___387 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___147)(struct perf_event___147 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___147;

struct perf_event_context___147;

struct fasync_struct___385;

struct pid_namespace___223;

struct trace_event_call___140;

struct perf_cgroup___147;

struct perf_event___147 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___147 *group_leader;
	struct pmu___147 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___147 hw;
	struct perf_event_context___147 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___147 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___387 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___385 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___147 *);
	struct callback_head callback_head;
	struct pid_namespace___223 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___147 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___147 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___140 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___147 *cgrp;
	struct list_head sb_list;
};

struct thread_struct___147 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___147 debug;
	long: 64;
};

struct vmacache___386 {
	u64 seqnum;
	struct vm_area_struct___386 *vmas[4];
};

struct page_frag___386 {
	struct page___386 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___386;

struct pid___223;

struct cred___355;

struct nsproxy___284;

struct signal_struct___265;

struct css_set___239;

struct task_struct___387 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___387 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___386 *mm;
	struct mm_struct___386 *active_mm;
	struct vmacache___386 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___387 *real_parent;
	struct task_struct___387 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___387 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___223 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___223 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___223 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___355 *ptracer_cred;
	const struct cred___355 *real_cred;
	const struct cred___355 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___284 *nsproxy;
	struct signal_struct___265 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___387 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___107 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___239 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___147 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___386 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___387 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___147 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___386 *pgtable_t___386;

struct address_space___385;

struct dev_pagemap___374;

struct page___386 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___385 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___386 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___386 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___386 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___374 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___386;

struct lruvec___386 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___386 *pgdat;
};

struct zone___386 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___386 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___386 {
	struct zone___386 *zone;
	int zone_idx;
};

struct zonelist___386 {
	struct zoneref___386 _zonerefs[25];
};

struct pglist_data___386 {
	struct zone___386 node_zones[3];
	struct zonelist___386 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___387 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___387 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___386 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___387 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___387 *owner;
};

struct secondary_data___387 {
	void *stack;
	struct task_struct___387 *task;
	long int status;
};

struct blocking_notifier_head___386 {
	struct rw_semaphore___387 rwsem;
	struct notifier_block *head;
};

struct key___355;

struct ucounts___255;

struct user_namespace___255 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___255 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___9 ns;
	long unsigned int flags;
	struct key___355 *persistent_keyring_register;
	struct rw_semaphore___387 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___255 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_root___379;

struct kernfs_elem_dir___379 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___379 *root;
};

struct kernfs_node___380;

struct kernfs_syscall_ops___379;

struct kernfs_root___379 {
	struct kernfs_node___380 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___379 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___379 {
	struct kernfs_node___380 *target_kn;
};

struct kernfs_ops___379;

struct kernfs_elem_attr___379 {
	const struct kernfs_ops___379 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___380 *notify_next;
};

struct kernfs_node___380 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___380 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___379 dir;
		struct kernfs_elem_symlink___379 symlink;
		struct kernfs_elem_attr___379 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___379;

struct kernfs_ops___379 {
	int (*open)(struct kernfs_open_file___379 *);
	void (*release)(struct kernfs_open_file___379 *);
	int (*seq_show)(struct seq_file___327 *, void *);
	void * (*seq_start)(struct seq_file___327 *, loff_t *);
	void * (*seq_next)(struct seq_file___327 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___327 *, void *);
	ssize_t (*read)(struct kernfs_open_file___379 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___379 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___379 *, struct vm_area_struct___386 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___379 *, struct poll_table_struct___233 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___379 {
	int (*remount_fs)(struct kernfs_root___379 *, int *, char *);
	int (*show_options)(struct seq_file___327 *, struct kernfs_root___379 *);
	int (*mkdir)(struct kernfs_node___380 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___380 *);
	int (*rename)(struct kernfs_node___380 *, struct kernfs_node___380 *, const char *);
	int (*show_path)(struct seq_file___327 *, struct kernfs_node___380 *, struct kernfs_root___379 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___327;

struct seq_file___327 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___327 *op;
	int poll_event;
	const struct file___385 *file;
	void *private;
};

struct vm_operations_struct___374;

struct kernfs_open_file___379 {
	struct kernfs_node___380 *kn;
	struct file___385 *file;
	struct seq_file___327 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___374 *vm_ops;
};

struct dentry___385;

struct path___386 {
	struct vfsmount *mnt;
	struct dentry___385 *dentry;
};

struct fown_struct___223 {
	rwlock_t lock;
	struct pid___223 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___385 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___386 f_path;
	struct inode___385 *f_inode;
	const struct file_operations___385 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___223 f_owner;
	const struct cred___355 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___385 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___374;

struct vm_operations_struct___374 {
	void (*open)(struct vm_area_struct___386 *);
	void (*close)(struct vm_area_struct___386 *);
	int (*split)(struct vm_area_struct___386 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___386 *);
	vm_fault_t (*fault)(struct vm_fault___374 *);
	vm_fault_t (*huge_fault)(struct vm_fault___374 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___374 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___386 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___374 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___374 *);
	int (*access)(struct vm_area_struct___386 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___386 *);
	int (*set_policy)(struct vm_area_struct___386 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___386 *, long unsigned int);
	struct page___386 * (*find_special_page)(struct vm_area_struct___386 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___240)(struct file___385 *, wait_queue_head_t *, struct poll_table_struct___233 *);

struct poll_table_struct___233 {
	poll_queue_proc___240 _qproc;
	__poll_t _key;
};

struct vm_area_struct___386 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___386 *vm_next;
	struct vm_area_struct___386 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___386 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___374 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___385 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___373;

struct bin_attribute___349;

struct attribute_group___350 {
	const char *name;
	umode_t (*is_visible)(struct kobject___373 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___373 *, struct bin_attribute___349 *, int);
	struct attribute **attrs;
	struct bin_attribute___349 **bin_attrs;
};

struct kset___372;

struct kobj_type___372;

struct kobject___373 {
	const char *name;
	struct list_head entry;
	struct kobject___373 *parent;
	struct kset___372 *kset;
	struct kobj_type___372 *ktype;
	struct kernfs_node___380 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___349 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___385 *, struct kobject___373 *, struct bin_attribute___349 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___385 *, struct kobject___373 *, struct bin_attribute___349 *, char *, loff_t, size_t);
	int (*mmap)(struct file___385 *, struct kobject___373 *, struct bin_attribute___349 *, struct vm_area_struct___386 *);
};

struct sysfs_ops___372 {
	ssize_t (*show)(struct kobject___373 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___373 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___372;

struct kset___372 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___373 kobj;
	const struct kset_uevent_ops___372 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___372 {
	void (*release)(struct kobject___373 *);
	const struct sysfs_ops___372 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___29 * (*child_ns_type)(struct kobject___373 *);
	const void * (*namespace)(struct kobject___373 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___372 {
	int (* const filter)(struct kset___372 *, struct kobject___373 *);
	const char * (* const name)(struct kset___372 *, struct kobject___373 *);
	int (* const uevent)(struct kset___372 *, struct kobject___373 *, struct kobj_uevent_env *);
};

struct kobj_attribute___364 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___373 *, struct kobj_attribute___364 *, char *);
	ssize_t (*store)(struct kobject___373 *, struct kobj_attribute___364 *, const char *, size_t);
};

struct device___353;

struct dev_pm_ops___353 {
	int (*prepare)(struct device___353 *);
	void (*complete)(struct device___353 *);
	int (*suspend)(struct device___353 *);
	int (*resume)(struct device___353 *);
	int (*freeze)(struct device___353 *);
	int (*thaw)(struct device___353 *);
	int (*poweroff)(struct device___353 *);
	int (*restore)(struct device___353 *);
	int (*suspend_late)(struct device___353 *);
	int (*resume_early)(struct device___353 *);
	int (*freeze_late)(struct device___353 *);
	int (*thaw_early)(struct device___353 *);
	int (*poweroff_late)(struct device___353 *);
	int (*restore_early)(struct device___353 *);
	int (*suspend_noirq)(struct device___353 *);
	int (*resume_noirq)(struct device___353 *);
	int (*freeze_noirq)(struct device___353 *);
	int (*thaw_noirq)(struct device___353 *);
	int (*poweroff_noirq)(struct device___353 *);
	int (*restore_noirq)(struct device___353 *);
	int (*runtime_suspend)(struct device___353 *);
	int (*runtime_resume)(struct device___353 *);
	int (*runtime_idle)(struct device___353 *);
};

struct dev_pm_info___353 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___353 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___353;

struct bus_type___353;

struct device_driver___353;

struct dev_pm_domain___353;

struct irq_domain___31;

struct device_node___90;

struct fwnode_handle___274;

struct class___353;

struct device___353 {
	struct device___353 *parent;
	struct device_private *p;
	struct kobject___373 kobj;
	const char *init_name;
	const struct device_type___353 *type;
	struct mutex mutex;
	struct bus_type___353 *bus;
	struct device_driver___353 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___353 power;
	struct dev_pm_domain___353 *pm_domain;
	struct irq_domain___31 *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___90 *of_node;
	struct fwnode_handle___274 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___353 *class;
	const struct attribute_group___350 **groups;
	void (*release)(struct device___353 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___353 {
	struct dev_pm_ops___353 ops;
	void (*detach)(struct device___353 *, bool);
	int (*activate)(struct device___353 *);
	void (*sync)(struct device___353 *);
	void (*dismiss)(struct device___353 *);
};

struct upid___223 {
	int nr;
	struct pid_namespace___223 *ns;
};

struct pid_namespace___223 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___387 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___223 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___385 *proc_self;
	struct dentry___385 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___255 *user_ns;
	struct ucounts___255 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___9 ns;
};

struct pid___223 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___223 numbers[1];
};

struct user_struct___355 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___355 *uid_keyring;
	struct key___355 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___386;

struct mm_struct___386 {
	struct {
		struct vm_area_struct___386 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___385 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___387 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___386 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___387 *owner;
		struct user_namespace___255 *user_ns;
		struct file___385 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___386 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___355 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___355 *session_keyring;
	struct key___355 *process_keyring;
	struct key___355 *thread_keyring;
	struct key___355 *request_key_auth;
	void *security;
	struct user_struct___355 *user;
	struct user_namespace___255 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___239;

struct nsproxy___284 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___223 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___239 *cgroup_ns;
};

struct signal_struct___265 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___387 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___387 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___223 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___223 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___386 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___223 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___239;

struct cgroup___239;

struct css_set___239 {
	struct cgroup_subsys_state___239 *subsys[13];
	refcount_t refcount;
	struct css_set___239 *dom_cset;
	struct cgroup___239 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___239 *mg_src_cgrp;
	struct cgroup___239 *mg_dst_cgrp;
	struct css_set___239 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___147 {
	struct pmu___147 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___387 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___147 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

union thread_union___277 {
	struct task_struct___387 task;
	long unsigned int stack[8192];
};

struct bus_type___353 {
	const char *name;
	const char *dev_name;
	struct device___353 *dev_root;
	const struct attribute_group___350 **bus_groups;
	const struct attribute_group___350 **dev_groups;
	const struct attribute_group___350 **drv_groups;
	int (*match)(struct device___353 *, struct device_driver___353 *);
	int (*uevent)(struct device___353 *, struct kobj_uevent_env *);
	int (*probe)(struct device___353 *);
	int (*remove)(struct device___353 *);
	void (*shutdown)(struct device___353 *);
	int (*online)(struct device___353 *);
	int (*offline)(struct device___353 *);
	int (*suspend)(struct device___353 *, pm_message_t);
	int (*resume)(struct device___353 *);
	int (*num_vf)(struct device___353 *);
	int (*dma_configure)(struct device___353 *);
	const struct dev_pm_ops___353 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___353 {
	const char *name;
	struct bus_type___353 *bus;
	struct module___315 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___353 *);
	int (*remove)(struct device___353 *);
	void (*shutdown)(struct device___353 *);
	int (*suspend)(struct device___353 *, pm_message_t);
	int (*resume)(struct device___353 *);
	const struct attribute_group___350 **groups;
	const struct dev_pm_ops___353 *pm;
	void (*coredump)(struct device___353 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___353 {
	const char *name;
	const struct attribute_group___350 **groups;
	int (*uevent)(struct device___353 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___353 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___353 *);
	const struct dev_pm_ops___353 *pm;
};

struct module_kobject___313 {
	struct kobject___373 kobj;
	struct module___315 *mod;
	struct kobject___373 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___313 {
	struct module___315 *mod;
	struct latch_tree_node node;
};

struct module_layout___313 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___313 mtn;
};

struct module_attribute___313;

struct kernel_param___313;

struct module___315 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___313 mkobj;
	struct module_attribute___313 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___373 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___313 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___313 core_layout;
	struct module_layout___313 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___140 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct class___353 {
	const char *name;
	struct module___315 *owner;
	const struct attribute_group___350 **class_groups;
	const struct attribute_group___350 **dev_groups;
	struct kobject___373 *dev_kobj;
	int (*dev_uevent)(struct device___353 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___353 *, umode_t *);
	void (*class_release)(struct class___353 *);
	void (*dev_release)(struct device___353 *);
	int (*shutdown_pre)(struct device___353 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___353 *);
	const struct dev_pm_ops___353 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct irq_domain_ops___31;

struct irq_domain___31 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___31 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___274 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___2 *gc;
	struct irq_domain___31 *parent;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_direct_max_irq;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_tree_mutex;
	unsigned int linear_revmap[0];
};

struct fwnode_operations___274;

struct fwnode_handle___274 {
	struct fwnode_handle___274 *secondary;
	const struct fwnode_operations___274 *ops;
};

struct property___86;

struct device_node___90 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___274 fwnode;
	struct property___86 *properties;
	struct property___86 *deadprops;
	struct device_node___90 *parent;
	struct device_node___90 *child;
	struct device_node___90 *sibling;
	struct kobject___373 kobj;
	long unsigned int _flags;
	void *data;
};

struct rt_mutex___7 {
	raw_spinlock_t wait_lock;
	struct rb_root_cached waiters;
	struct task_struct___387 *owner;
};

struct fwnode_reference_args___274;

struct fwnode_endpoint___274;

struct fwnode_operations___274 {
	struct fwnode_handle___274 * (*get)(struct fwnode_handle___274 *);
	void (*put)(struct fwnode_handle___274 *);
	bool (*device_is_available)(const struct fwnode_handle___274 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___274 *, const struct device___353 *);
	bool (*property_present)(const struct fwnode_handle___274 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___274 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___274 *, const char *, const char **, size_t);
	struct fwnode_handle___274 * (*get_parent)(const struct fwnode_handle___274 *);
	struct fwnode_handle___274 * (*get_next_child_node)(const struct fwnode_handle___274 *, struct fwnode_handle___274 *);
	struct fwnode_handle___274 * (*get_named_child_node)(const struct fwnode_handle___274 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___274 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___274 *);
	struct fwnode_handle___274 * (*graph_get_next_endpoint)(const struct fwnode_handle___274 *, struct fwnode_handle___274 *);
	struct fwnode_handle___274 * (*graph_get_remote_endpoint)(const struct fwnode_handle___274 *);
	struct fwnode_handle___274 * (*graph_get_port_parent)(struct fwnode_handle___274 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___274 *, struct fwnode_endpoint___274 *);
};

struct fwnode_endpoint___274 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___274 *local_fwnode;
};

struct fwnode_reference_args___274 {
	struct fwnode_handle___274 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct property___86 {
	char *name;
	int length;
	void *value;
	struct property___86 *next;
	long unsigned int _flags;
	struct bin_attribute___349 attr;
};

struct irq_fwspec___31 {
	struct fwnode_handle___274 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___31 {
	int (*match)(struct irq_domain___31 *, struct device_node___90 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___31 *, struct irq_fwspec___31 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___31 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___31 *, unsigned int);
	int (*xlate)(struct irq_domain___31 *, struct device_node___90 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___31 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___31 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___31 *, struct irq_data___5 *, bool);
	void (*deactivate)(struct irq_domain___31 *, struct irq_data___5 *);
	int (*translate)(struct irq_domain___31 *, struct irq_fwspec___31 *, long unsigned int *, unsigned int *);
};

struct i2c_client___4;

typedef int (*i2c_slave_cb_t___4)(struct i2c_client___4 *, enum i2c_slave_event, u8 *);

struct i2c_adapter___4;

struct i2c_client___4 {
	short unsigned int flags;
	short unsigned int addr;
	char name[20];
	struct i2c_adapter___4 *adapter;
	struct device___353 dev;
	int irq;
	struct list_head detected;
	i2c_slave_cb_t___4 slave_cb;
};

struct i2c_algorithm___4;

struct i2c_lock_operations___4;

struct i2c_bus_recovery_info___4;

struct i2c_adapter___4 {
	struct module___315 *owner;
	unsigned int class;
	const struct i2c_algorithm___4 *algo;
	void *algo_data;
	const struct i2c_lock_operations___4 *lock_ops;
	struct rt_mutex___7 bus_lock;
	struct rt_mutex___7 mux_lock;
	int timeout;
	int retries;
	struct device___353 dev;
	int nr;
	char name[48];
	struct completion dev_released;
	struct mutex userspace_clients_lock;
	struct list_head userspace_clients;
	struct i2c_bus_recovery_info___4 *bus_recovery_info;
	const struct i2c_adapter_quirks *quirks;
	struct irq_domain___31 *host_notify_domain;
};

struct i2c_board_info___3 {
	char type[20];
	short unsigned int flags;
	short unsigned int addr;
	const char *dev_name;
	void *platform_data;
	struct device_node___90 *of_node;
	struct fwnode_handle___274 *fwnode;
	const struct property_entry___2 *properties;
	const struct resource *resources;
	unsigned int num_resources;
	int irq;
};

struct i2c_algorithm___4 {
	int (*master_xfer)(struct i2c_adapter___4 *, struct i2c_msg *, int);
	int (*smbus_xfer)(struct i2c_adapter___4 *, u16, short unsigned int, char, u8, int, union i2c_smbus_data *);
	u32 (*functionality)(struct i2c_adapter___4 *);
	int (*reg_slave)(struct i2c_client___4 *);
	int (*unreg_slave)(struct i2c_client___4 *);
};

struct i2c_lock_operations___4 {
	void (*lock_bus)(struct i2c_adapter___4 *, unsigned int);
	int (*trylock_bus)(struct i2c_adapter___4 *, unsigned int);
	void (*unlock_bus)(struct i2c_adapter___4 *, unsigned int);
};

struct i2c_bus_recovery_info___4 {
	int (*recover_bus)(struct i2c_adapter___4 *);
	int (*get_scl)(struct i2c_adapter___4 *);
	void (*set_scl)(struct i2c_adapter___4 *, int);
	int (*get_sda)(struct i2c_adapter___4 *);
	void (*set_sda)(struct i2c_adapter___4 *, int);
	void (*prepare_recovery)(struct i2c_adapter___4 *);
	void (*unprepare_recovery)(struct i2c_adapter___4 *);
	struct gpio_desc *scl_gpiod;
	struct gpio_desc *sda_gpiod;
};

struct i2c_smbus_alert_setup {
	int irq;
};

struct address_space_operations___385;

struct address_space___385 {
	struct inode___385 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___387 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___385 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___374)(struct vm_area_struct___386 *, long unsigned int, const struct page___386 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___374)(struct page___386 *, void *);

struct dev_pagemap___374 {
	dev_page_fault_t___374 page_fault;
	dev_page_free_t___374 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___353 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___386 {
	struct task_struct___387 *task;
	struct core_thread___386 *next;
};

struct core_state___386 {
	atomic_t nr_threads;
	struct core_thread___386 dumper;
	struct completion startup;
};

struct vm_fault___374 {
	struct vm_area_struct___386 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___386 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___386 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___386 prealloc_pte;
};

struct dentry_operations___385;

struct super_block___385;

struct dentry___385 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___385 *d_parent;
	struct qstr d_name;
	struct inode___385 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___385 *d_op;
	struct super_block___385 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___385;

struct block_device___385;

struct inode___385 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___385 *i_op;
	struct super_block___385 *i_sb;
	struct address_space___385 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___387 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___385 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___385 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___385 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___385 {
	int (*d_revalidate)(struct dentry___385 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___385 *, unsigned int);
	int (*d_hash)(const struct dentry___385 *, struct qstr *);
	int (*d_compare)(const struct dentry___385 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___385 *);
	int (*d_init)(struct dentry___385 *);
	void (*d_release)(struct dentry___385 *);
	void (*d_prune)(struct dentry___385 *);
	void (*d_iput)(struct dentry___385 *, struct inode___385 *);
	char * (*d_dname)(struct dentry___385 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___386 *);
	int (*d_manage)(const struct path___386 *, bool);
	struct dentry___385 * (*d_real)(struct dentry___385 *, const struct inode___385 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___385;

struct mem_dqinfo___385 {
	struct quota_format_type___385 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___385;

struct quota_info___385 {
	unsigned int flags;
	struct rw_semaphore___387 dqio_sem;
	struct inode___385 *files[3];
	struct mem_dqinfo___385 info[3];
	const struct quota_format_ops___385 *ops[3];
};

struct rcuwait___385 {
	struct task_struct___387 *task;
};

struct percpu_rw_semaphore___385 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___387 rw_sem;
	struct rcuwait___385 writer;
	int readers_block;
};

struct sb_writers___385 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___385 rw_sem[3];
};

struct file_system_type___385;

struct super_operations___385;

struct dquot_operations___385;

struct quotactl_ops___385;

struct super_block___385 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___385 *s_type;
	const struct super_operations___385 *s_op;
	const struct dquot_operations___385 *dq_op;
	const struct quotactl_ops___385 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___385 *s_root;
	struct rw_semaphore___387 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___385 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___385 s_dquot;
	struct sb_writers___385 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___385 *s_d_op;
	int cleancache_poolid;
	struct shrinker___134 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___255 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___385 {
	struct file___385 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___385 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___385 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___385 *ia_file;
};

struct dquot___385 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___385 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___385 {
	int qf_fmt_id;
	const struct quota_format_ops___385 *qf_ops;
	struct module___315 *qf_owner;
	struct quota_format_type___385 *qf_next;
};

struct quota_format_ops___385 {
	int (*check_quota_file)(struct super_block___385 *, int);
	int (*read_file_info)(struct super_block___385 *, int);
	int (*write_file_info)(struct super_block___385 *, int);
	int (*free_file_info)(struct super_block___385 *, int);
	int (*read_dqblk)(struct dquot___385 *);
	int (*commit_dqblk)(struct dquot___385 *);
	int (*release_dqblk)(struct dquot___385 *);
	int (*get_next_id)(struct super_block___385 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___385 {
	int (*write_dquot)(struct dquot___385 *);
	struct dquot___385 * (*alloc_dquot)(struct super_block___385 *, int);
	void (*destroy_dquot)(struct dquot___385 *);
	int (*acquire_dquot)(struct dquot___385 *);
	int (*release_dquot)(struct dquot___385 *);
	int (*mark_dirty)(struct dquot___385 *);
	int (*write_info)(struct super_block___385 *, int);
	qsize_t * (*get_reserved_space)(struct inode___385 *);
	int (*get_projid)(struct inode___385 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___385 *, qsize_t *);
	int (*get_next_id)(struct super_block___385 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___385 {
	int (*quota_on)(struct super_block___385 *, int, int, const struct path___386 *);
	int (*quota_off)(struct super_block___385 *, int);
	int (*quota_enable)(struct super_block___385 *, unsigned int);
	int (*quota_disable)(struct super_block___385 *, unsigned int);
	int (*quota_sync)(struct super_block___385 *, int);
	int (*set_info)(struct super_block___385 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___385 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___385 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___385 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___385 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___385 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___385 {
	int (*writepage)(struct page___386 *, struct writeback_control___3 *);
	int (*readpage)(struct file___385 *, struct page___386 *);
	int (*writepages)(struct address_space___385 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___386 *);
	int (*readpages)(struct file___385 *, struct address_space___385 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___385 *, struct address_space___385 *, loff_t, unsigned int, unsigned int, struct page___386 **, void **);
	int (*write_end)(struct file___385 *, struct address_space___385 *, loff_t, unsigned int, unsigned int, struct page___386 *, void *);
	sector_t (*bmap)(struct address_space___385 *, sector_t);
	void (*invalidatepage)(struct page___386 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___386 *, gfp_t);
	void (*freepage)(struct page___386 *);
	ssize_t (*direct_IO)(struct kiocb___385 *, struct iov_iter___2 *);
	int (*migratepage)(struct address_space___385 *, struct page___386 *, struct page___386 *, enum migrate_mode);
	bool (*isolate_page)(struct page___386 *, isolate_mode_t);
	void (*putback_page)(struct page___386 *);
	int (*launder_page)(struct page___386 *);
	int (*is_partially_uptodate)(struct page___386 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___386 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___385 *, struct page___386 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___385 *, sector_t *);
	void (*swap_deactivate)(struct file___385 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___385 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___385 *bd_inode;
	struct super_block___385 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___385 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___385 {
	struct dentry___385 * (*lookup)(struct inode___385 *, struct dentry___385 *, unsigned int);
	const char * (*get_link)(struct dentry___385 *, struct inode___385 *, struct delayed_call *);
	int (*permission)(struct inode___385 *, int);
	struct posix_acl * (*get_acl)(struct inode___385 *, int);
	int (*readlink)(struct dentry___385 *, char *, int);
	int (*create)(struct inode___385 *, struct dentry___385 *, umode_t, bool);
	int (*link)(struct dentry___385 *, struct inode___385 *, struct dentry___385 *);
	int (*unlink)(struct inode___385 *, struct dentry___385 *);
	int (*symlink)(struct inode___385 *, struct dentry___385 *, const char *);
	int (*mkdir)(struct inode___385 *, struct dentry___385 *, umode_t);
	int (*rmdir)(struct inode___385 *, struct dentry___385 *);
	int (*mknod)(struct inode___385 *, struct dentry___385 *, umode_t, dev_t);
	int (*rename)(struct inode___385 *, struct dentry___385 *, struct inode___385 *, struct dentry___385 *, unsigned int);
	int (*setattr)(struct dentry___385 *, struct iattr___385 *);
	int (*getattr)(const struct path___386 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___385 *, char *, size_t);
	int (*fiemap)(struct inode___385 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___385 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___385 *, struct dentry___385 *, struct file___385 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___385 *, struct dentry___385 *, umode_t);
	int (*set_acl)(struct inode___385 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___385 {
	void (*fl_copy_lock)(struct file_lock___385 *, struct file_lock___385 *);
	void (*fl_release_private)(struct file_lock___385 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___385;

struct file_lock___385 {
	struct file_lock___385 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___385 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___385 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___385 *fl_ops;
	const struct lock_manager_operations___385 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___385 {
	int (*lm_compare_owner)(struct file_lock___385 *, struct file_lock___385 *);
	long unsigned int (*lm_owner_key)(struct file_lock___385 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___385 *);
	int (*lm_grant)(struct file_lock___385 *, int);
	bool (*lm_break)(struct file_lock___385 *);
	int (*lm_change)(struct file_lock___385 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___385 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___385 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___385 *fa_next;
	struct file___385 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___385 {
	const char *name;
	int fs_flags;
	struct dentry___385 * (*mount)(struct file_system_type___385 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___385 *);
	struct module___315 *owner;
	struct file_system_type___385 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___385 {
	struct inode___385 * (*alloc_inode)(struct super_block___385 *);
	void (*destroy_inode)(struct inode___385 *);
	void (*dirty_inode)(struct inode___385 *, int);
	int (*write_inode)(struct inode___385 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___385 *);
	void (*evict_inode)(struct inode___385 *);
	void (*put_super)(struct super_block___385 *);
	int (*sync_fs)(struct super_block___385 *, int);
	int (*freeze_super)(struct super_block___385 *);
	int (*freeze_fs)(struct super_block___385 *);
	int (*thaw_super)(struct super_block___385 *);
	int (*unfreeze_fs)(struct super_block___385 *);
	int (*statfs)(struct dentry___385 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___385 *, int *, char *);
	void (*umount_begin)(struct super_block___385 *);
	int (*show_options)(struct seq_file___327 *, struct dentry___385 *);
	int (*show_devname)(struct seq_file___327 *, struct dentry___385 *);
	int (*show_path)(struct seq_file___327 *, struct dentry___385 *);
	int (*show_stats)(struct seq_file___327 *, struct dentry___385 *);
	ssize_t (*quota_read)(struct super_block___385 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___385 *, int, const char *, size_t, loff_t);
	struct dquot___385 ** (*get_dquots)(struct inode___385 *);
	int (*bdev_try_to_free_page)(struct super_block___385 *, struct page___386 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___385 *, struct shrink_control___134 *);
	long int (*free_cached_objects)(struct super_block___385 *, struct shrink_control___134 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___374(struct page___386 *);

typedef int (*key_restrict_link_func_t___356)(struct key___355 *, const struct key_type *, const union key_payload *, struct key___355 *);

struct key_restriction___355;

struct key___355 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___387 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___355 *restrict_link;
};

struct key_restriction___355 {
	key_restrict_link_func_t___356 check;
	struct key___355 *key;
	struct key_type *keytype;
};

struct seq_operations___327 {
	void * (*start)(struct seq_file___327 *, loff_t *);
	void (*stop)(struct seq_file___327 *, void *);
	void * (*next)(struct seq_file___327 *, void *, loff_t *);
	int (*show)(struct seq_file___327 *, void *);
};

struct cgroup_namespace___239 {
	refcount_t count;
	struct ns_common___9 ns;
	struct user_namespace___255 *user_ns;
	struct ucounts___255 *ucounts;
	struct css_set___239 *root_cset;
};

struct ucounts___255 {
	struct hlist_node node;
	struct user_namespace___255 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct kernel_param_ops___313 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___313 *);
	int (*get)(char *, const struct kernel_param___313 *);
	void (*free)(void *);
};

struct kparam_array___313;

struct kernel_param___313 {
	const char *name;
	struct module___315 *mod;
	const struct kernel_param_ops___313 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___313 *arr;
	};
};

struct kparam_array___313 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___313 *ops;
	void *elem;
};

struct module_attribute___313 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___313 *, struct module_kobject___313 *, char *);
	ssize_t (*store)(struct module_attribute___313 *, struct module_kobject___313 *, const char *, size_t);
	void (*setup)(struct module___315 *, const char *);
	int (*test)(struct module___315 *);
	void (*free)(struct module___315 *);
};

struct trace_event_class___140;

struct trace_event_call___140 {
	struct list_head list;
	struct trace_event_class___140 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___13 event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___39 *prog_array;
	int (*perf_perm)(struct trace_event_call___140 *, struct perf_event___147 *);
};

struct node___213 {
	struct device___353 dev;
};

struct bpf_map___240;

struct bpf_map_ops___239 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___240 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___240 *, struct file___385 *);
	void (*map_free)(struct bpf_map___240 *);
	int (*map_get_next_key)(struct bpf_map___240 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___240 *);
	void * (*map_lookup_elem)(struct bpf_map___240 *, void *);
	int (*map_update_elem)(struct bpf_map___240 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___240 *, void *);
	int (*map_push_elem)(struct bpf_map___240 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___240 *, void *);
	int (*map_peek_elem)(struct bpf_map___240 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___240 *, struct file___385 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___240 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___240 *, void *, struct seq_file___327 *);
	int (*map_check_btf)(const struct bpf_map___240 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___240 {
	const struct bpf_map_ops___239 *ops;
	struct bpf_map___240 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___355 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___240;

typedef void (*kthread_work_func_t___240)(struct kthread_work___240 *);

struct kthread_worker___240;

struct kthread_work___240 {
	struct list_head node;
	kthread_work_func_t___240 func;
	struct kthread_worker___240 *worker;
	int canceling;
};

struct kthread_worker___240 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___387 *task;
	struct kthread_work___240 *current_work;
};

struct kthread_delayed_work___239 {
	struct kthread_work___240 work;
	struct timer_list timer;
};

struct psi_group___239 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___240 *poll_kworker;
	struct kthread_delayed_work___239 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___239 {
	struct kernfs_node___380 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___239;

struct cgroup_subsys_state___239 {
	struct cgroup___239 *cgroup;
	struct cgroup_subsys___239 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___239 *parent;
};

struct cgroup_root___239;

struct cgroup_rstat_cpu___239;

struct cgroup___239 {
	struct cgroup_subsys_state___239 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___380 *kn;
	struct cgroup_file___239 procs_file;
	struct cgroup_file___239 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___239 *subsys[13];
	struct cgroup_root___239 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___239 *dom_cgrp;
	struct cgroup_rstat_cpu___239 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___39 bpf;
	atomic_t congestion_count;
	struct cgroup___239 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___239 psi;
	int ancestor_ids[0];
};

struct cftype___239;

struct cgroup_subsys___239 {
	struct cgroup_subsys_state___239 * (*css_alloc)(struct cgroup_subsys_state___239 *);
	int (*css_online)(struct cgroup_subsys_state___239 *);
	void (*css_offline)(struct cgroup_subsys_state___239 *);
	void (*css_released)(struct cgroup_subsys_state___239 *);
	void (*css_free)(struct cgroup_subsys_state___239 *);
	void (*css_reset)(struct cgroup_subsys_state___239 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___239 *, int);
	int (*css_extra_stat_show)(struct seq_file___327 *, struct cgroup_subsys_state___239 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___387 *);
	void (*cancel_fork)(struct task_struct___387 *);
	void (*fork)(struct task_struct___387 *);
	void (*exit)(struct task_struct___387 *);
	void (*free)(struct task_struct___387 *);
	void (*bind)(struct cgroup_subsys_state___239 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___239 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___239 *dfl_cftypes;
	struct cftype___239 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___239 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___239 *updated_children;
	struct cgroup___239 *updated_next;
};

struct cgroup_root___239 {
	struct kernfs_root___379 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___239 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___239 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___239 *ss;
	struct list_head node;
	struct kernfs_ops___379 *kf_ops;
	int (*open)(struct kernfs_open_file___379 *);
	void (*release)(struct kernfs_open_file___379 *);
	u64 (*read_u64)(struct cgroup_subsys_state___239 *, struct cftype___239 *);
	s64 (*read_s64)(struct cgroup_subsys_state___239 *, struct cftype___239 *);
	int (*seq_show)(struct seq_file___327 *, void *);
	void * (*seq_start)(struct seq_file___327 *, loff_t *);
	void * (*seq_next)(struct seq_file___327 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___327 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___239 *, struct cftype___239 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___239 *, struct cftype___239 *, s64);
	ssize_t (*write)(struct kernfs_open_file___379 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___379 *, struct poll_table_struct___233 *);
};

struct perf_cpu_context___147;

struct pmu___147 {
	struct list_head entry;
	struct module___315 *module;
	struct device___353 *dev;
	const struct attribute_group___350 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___147 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___147 *);
	void (*pmu_disable)(struct pmu___147 *);
	int (*event_init)(struct perf_event___147 *);
	void (*event_mapped)(struct perf_event___147 *, struct mm_struct___386 *);
	void (*event_unmapped)(struct perf_event___147 *, struct mm_struct___386 *);
	int (*add)(struct perf_event___147 *, int);
	void (*del)(struct perf_event___147 *, int);
	void (*start)(struct perf_event___147 *, int);
	void (*stop)(struct perf_event___147 *, int);
	void (*read)(struct perf_event___147 *);
	void (*start_txn)(struct pmu___147 *, unsigned int);
	int (*commit_txn)(struct pmu___147 *);
	void (*cancel_txn)(struct pmu___147 *);
	int (*event_idx)(struct perf_event___147 *);
	void (*sched_task)(struct perf_event_context___147 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___147 *);
	int (*filter_match)(struct perf_event___147 *);
	int (*check_period)(struct perf_event___147 *, u64);
};

struct perf_cpu_context___147 {
	struct perf_event_context___147 ctx;
	struct perf_event_context___147 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___147 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___147 {
	struct cgroup_subsys_state___239 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___140 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___140 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___140 *);
	struct list_head * (*get_fields)(struct trace_event_call___140 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___140 *);
};

struct trace_event_file___59;

struct trace_event_buffer___51 {
	struct ring_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___59 *trace_file;
	void *entry;
	long unsigned int flags;
	int pc;
};

struct trace_event_file___59 {
	struct list_head list;
	struct trace_event_call___140 *event_call;
	struct event_filter *filter;
	struct dentry___385 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_smbus_write {
	struct trace_entry ent;
	int adapter_nr;
	__u16 addr;
	__u16 flags;
	__u8 command;
	__u8 len;
	__u32 protocol;
	__u8 buf[34];
	char __data[0];
};

struct trace_event_raw_smbus_read {
	struct trace_entry ent;
	int adapter_nr;
	__u16 flags;
	__u16 addr;
	__u8 command;
	__u32 protocol;
	__u8 buf[34];
	char __data[0];
};

struct trace_event_raw_smbus_reply {
	struct trace_entry ent;
	int adapter_nr;
	__u16 addr;
	__u16 flags;
	__u8 command;
	__u8 len;
	__u32 protocol;
	__u8 buf[34];
	char __data[0];
};

struct trace_event_raw_smbus_result {
	struct trace_entry ent;
	int adapter_nr;
	__u16 addr;
	__u16 flags;
	__u8 read_write;
	__u8 command;
	__s16 res;
	__u32 protocol;
	char __data[0];
};

struct trace_event_data_offsets_smbus_write {};

struct trace_event_data_offsets_smbus_read {};

struct trace_event_data_offsets_smbus_reply {};

struct trace_event_data_offsets_smbus_result {};

struct i2c_acpi_handler_data {
	struct acpi_connection_info info;
	struct i2c_adapter___3 *adapter;
};

struct gsb_buffer {
	u8 status;
	u8 len;
	union {
		u16 wdata;
		u8 bdata;
		u8 data[0];
	};
};

struct i2c_acpi_lookup {
	struct i2c_board_info___2 *info;
	acpi_handle adapter_handle;
	acpi_handle device_handle;
	acpi_handle search_handle;
	int n;
	int index;
	u32 speed;
	u32 min_speed;
};

struct of_reconfig_data___2 {
	struct device_node___89 *dn;
	struct property___85 *prop;
	struct property___85 *old_prop;
};

struct dma_router___9 {
	struct device___306 *dev;
	void (*route_free)(struct device___306 *, void *);
};

struct dma_device___9;

struct dma_chan_dev___9;

struct dma_chan___10 {
	struct dma_device___9 *device;
	dma_cookie_t cookie;
	dma_cookie_t completed_cookie;
	int chan_id;
	struct dma_chan_dev___9 *dev;
	struct list_head device_node;
	struct dma_chan_percpu *local;
	int client_count;
	int table_count;
	struct dma_router___9 *router;
	void *route_data;
	void *private;
};

typedef bool (*dma_filter_fn___9)(struct dma_chan___10 *, void *);

struct dma_filter___9 {
	dma_filter_fn___9 fn;
	int mapcnt;
	const struct dma_slave_map *map;
};

struct dma_async_tx_descriptor___9;

struct dma_device___9 {
	unsigned int chancnt;
	unsigned int privatecnt;
	struct list_head channels;
	struct list_head global_node;
	struct dma_filter___9 filter;
	dma_cap_mask_t cap_mask;
	short unsigned int max_xor;
	short unsigned int max_pq;
	enum dmaengine_alignment copy_align;
	enum dmaengine_alignment xor_align;
	enum dmaengine_alignment pq_align;
	enum dmaengine_alignment fill_align;
	int dev_id;
	struct device___306 *dev;
	u32 src_addr_widths;
	u32 dst_addr_widths;
	u32 directions;
	u32 max_burst;
	bool descriptor_reuse;
	enum dma_residue_granularity residue_granularity;
	int (*device_alloc_chan_resources)(struct dma_chan___10 *);
	void (*device_free_chan_resources)(struct dma_chan___10 *);
	struct dma_async_tx_descriptor___9 * (*device_prep_dma_memcpy)(struct dma_chan___10 *, dma_addr_t, dma_addr_t, size_t, long unsigned int);
	struct dma_async_tx_descriptor___9 * (*device_prep_dma_xor)(struct dma_chan___10 *, dma_addr_t, dma_addr_t *, unsigned int, size_t, long unsigned int);
	struct dma_async_tx_descriptor___9 * (*device_prep_dma_xor_val)(struct dma_chan___10 *, dma_addr_t *, unsigned int, size_t, enum sum_check_flags *, long unsigned int);
	struct dma_async_tx_descriptor___9 * (*device_prep_dma_pq)(struct dma_chan___10 *, dma_addr_t *, dma_addr_t *, unsigned int, const unsigned char *, size_t, long unsigned int);
	struct dma_async_tx_descriptor___9 * (*device_prep_dma_pq_val)(struct dma_chan___10 *, dma_addr_t *, dma_addr_t *, unsigned int, const unsigned char *, size_t, enum sum_check_flags *, long unsigned int);
	struct dma_async_tx_descriptor___9 * (*device_prep_dma_memset)(struct dma_chan___10 *, dma_addr_t, int, size_t, long unsigned int);
	struct dma_async_tx_descriptor___9 * (*device_prep_dma_memset_sg)(struct dma_chan___10 *, struct scatterlist *, unsigned int, int, long unsigned int);
	struct dma_async_tx_descriptor___9 * (*device_prep_dma_interrupt)(struct dma_chan___10 *, long unsigned int);
	struct dma_async_tx_descriptor___9 * (*device_prep_slave_sg)(struct dma_chan___10 *, struct scatterlist *, unsigned int, enum dma_transfer_direction, long unsigned int, void *);
	struct dma_async_tx_descriptor___9 * (*device_prep_dma_cyclic)(struct dma_chan___10 *, dma_addr_t, size_t, size_t, enum dma_transfer_direction, long unsigned int);
	struct dma_async_tx_descriptor___9 * (*device_prep_interleaved_dma)(struct dma_chan___10 *, struct dma_interleaved_template *, long unsigned int);
	struct dma_async_tx_descriptor___9 * (*device_prep_dma_imm_data)(struct dma_chan___10 *, dma_addr_t, u64, long unsigned int);
	int (*device_config)(struct dma_chan___10 *, struct dma_slave_config *);
	int (*device_pause)(struct dma_chan___10 *);
	int (*device_resume)(struct dma_chan___10 *);
	int (*device_terminate_all)(struct dma_chan___10 *);
	void (*device_synchronize)(struct dma_chan___10 *);
	enum dma_status (*device_tx_status)(struct dma_chan___10 *, dma_cookie_t, struct dma_tx_state *);
	void (*device_issue_pending)(struct dma_chan___10 *);
};

struct dma_chan_dev___9 {
	struct dma_chan___10 *chan;
	struct device___306 device;
	int dev_id;
	atomic_t *idr_ref;
};

struct dmaengine_unmap_data___9 {
	u8 map_cnt;
	u8 to_cnt;
	u8 from_cnt;
	u8 bidi_cnt;
	struct device___306 *dev;
	struct kref kref;
	size_t len;
	dma_addr_t addr[0];
};

struct dma_async_tx_descriptor___9 {
	dma_cookie_t cookie;
	enum dma_ctrl_flags flags;
	dma_addr_t phys;
	struct dma_chan___10 *chan;
	dma_cookie_t (*tx_submit)(struct dma_async_tx_descriptor___9 *);
	int (*desc_free)(struct dma_async_tx_descriptor___9 *);
	dma_async_tx_callback callback;
	dma_async_tx_callback_result callback_result;
	void *callback_param;
	struct dmaengine_unmap_data___9 *unmap;
};

struct rt_mutex___8 {
	raw_spinlock_t wait_lock;
	struct rb_root_cached waiters;
	struct task_struct___341 *owner;
};

struct i2c_client___5;

typedef int (*i2c_slave_cb_t___5)(struct i2c_client___5 *, enum i2c_slave_event, u8 *);

struct i2c_adapter___5;

struct i2c_client___5 {
	short unsigned int flags;
	short unsigned int addr;
	char name[20];
	struct i2c_adapter___5 *adapter;
	struct device___306 dev;
	int irq;
	struct list_head detected;
	i2c_slave_cb_t___5 slave_cb;
};

struct i2c_algorithm___5;

struct i2c_lock_operations___5;

struct i2c_bus_recovery_info___5;

struct i2c_adapter___5 {
	struct module___278 *owner;
	unsigned int class;
	const struct i2c_algorithm___5 *algo;
	void *algo_data;
	const struct i2c_lock_operations___5 *lock_ops;
	struct rt_mutex___8 bus_lock;
	struct rt_mutex___8 mux_lock;
	int timeout;
	int retries;
	struct device___306 dev;
	int nr;
	char name[48];
	struct completion dev_released;
	struct mutex userspace_clients_lock;
	struct list_head userspace_clients;
	struct i2c_bus_recovery_info___5 *bus_recovery_info;
	const struct i2c_adapter_quirks *quirks;
	struct irq_domain___26 *host_notify_domain;
};

struct i2c_algorithm___5 {
	int (*master_xfer)(struct i2c_adapter___5 *, struct i2c_msg *, int);
	int (*smbus_xfer)(struct i2c_adapter___5 *, u16, short unsigned int, char, u8, int, union i2c_smbus_data *);
	u32 (*functionality)(struct i2c_adapter___5 *);
	int (*reg_slave)(struct i2c_client___5 *);
	int (*unreg_slave)(struct i2c_client___5 *);
};

struct i2c_lock_operations___5 {
	void (*lock_bus)(struct i2c_adapter___5 *, unsigned int);
	int (*trylock_bus)(struct i2c_adapter___5 *, unsigned int);
	void (*unlock_bus)(struct i2c_adapter___5 *, unsigned int);
};

struct i2c_bus_recovery_info___5 {
	int (*recover_bus)(struct i2c_adapter___5 *);
	int (*get_scl)(struct i2c_adapter___5 *);
	void (*set_scl)(struct i2c_adapter___5 *, int);
	int (*get_sda)(struct i2c_adapter___5 *);
	void (*set_sda)(struct i2c_adapter___5 *, int);
	void (*prepare_recovery)(struct i2c_adapter___5 *);
	void (*unprepare_recovery)(struct i2c_adapter___5 *);
	struct gpio_desc *scl_gpiod;
	struct gpio_desc *sda_gpiod;
};

struct platform_device___23 {
	const char *name;
	int id;
	bool id_auto;
	struct device___306 dev;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct platform_driver___18 {
	int (*probe)(struct platform_device___23 *);
	int (*remove)(struct platform_device___23 *);
	void (*shutdown)(struct platform_device___23 *);
	int (*suspend)(struct platform_device___23 *, pm_message_t);
	int (*resume)(struct platform_device___23 *);
	struct device_driver___306 driver;
	const struct platform_device_id *id_table;
	bool prevent_deferred_probe;
};

struct qup_i2c_block {
	int count;
	int pos;
	int tx_tag_len;
	int rx_tag_len;
	int data_len;
	int cur_blk_len;
	int total_tx_len;
	int total_rx_len;
	int tx_fifo_data_pos;
	int tx_fifo_free;
	int rx_fifo_data_pos;
	int fifo_available;
	u32 tx_fifo_data;
	u32 rx_fifo_data;
	u8 *cur_data;
	u8 *cur_tx_tags;
	bool tx_tags_sent;
	bool send_last_word;
	bool rx_tags_fetched;
	bool rx_bytes_read;
	bool is_tx_blk_mode;
	bool is_rx_blk_mode;
	u8 tags[6];
};

struct qup_i2c_tag {
	u8 *start;
	dma_addr_t addr;
};

struct qup_i2c_bam {
	struct qup_i2c_tag tag;
	struct dma_chan___10 *dma;
	struct scatterlist *sg;
	unsigned int sg_cnt;
};

struct qup_i2c_dev {
	struct device___306 *dev;
	void *base;
	int irq;
	struct clk *clk;
	struct clk *pclk;
	struct i2c_adapter___5 adap;
	int clk_ctl;
	int out_fifo_sz;
	int in_fifo_sz;
	int out_blk_sz;
	int in_blk_sz;
	int blk_xfer_limit;
	long unsigned int one_byte_t;
	long unsigned int xfer_timeout;
	struct qup_i2c_block blk;
	struct i2c_msg *msg;
	int pos;
	u32 bus_err;
	u32 qup_err;
	bool is_last;
	bool is_smbus_read;
	u32 config_run;
	bool is_dma;
	bool use_dma;
	unsigned int max_xfer_sg_len;
	unsigned int tag_buf_pos;
	unsigned int blk_mode_threshold;
	struct dma_pool___2 *dpool;
	struct qup_i2c_tag start_tag;
	struct qup_i2c_bam brx;
	struct qup_i2c_bam btx;
	struct completion xfer;
	void (*write_tx_fifo)(struct qup_i2c_dev *);
	void (*read_rx_fifo)(struct qup_i2c_dev *);
	void (*write_rx_tags)(struct qup_i2c_dev *);
};

struct cec_msg {
	__u64 tx_ts;
	__u64 rx_ts;
	__u32 len;
	__u32 timeout;
	__u32 sequence;
	__u32 flags;
	__u8 msg[16];
	__u8 reply;
	__u8 rx_status;
	__u8 tx_status;
	__u8 tx_arb_lost_cnt;
	__u8 tx_nack_cnt;
	__u8 tx_low_drive_cnt;
	__u8 tx_error_cnt;
};

struct cec_log_addrs {
	__u8 log_addr[4];
	__u16 log_addr_mask;
	__u8 cec_version;
	__u8 num_log_addrs;
	__u32 vendor_id;
	__u32 flags;
	char osd_name[15];
	__u8 primary_device_type[4];
	__u8 log_addr_type[4];
	__u8 all_device_types[4];
	__u8 features[48];
};

struct cec_event_state_change {
	__u16 phys_addr;
	__u16 log_addr_mask;
};

struct cec_event_lost_msgs {
	__u32 lost_msgs;
};

struct cec_event {
	__u64 ts;
	__u32 event;
	__u32 flags;
	union {
		struct cec_event_state_change state_change;
		struct cec_event_lost_msgs lost_msgs;
		__u32 raw[16];
	};
};

enum rc_proto {
	RC_PROTO_UNKNOWN = 0,
	RC_PROTO_OTHER = 1,
	RC_PROTO_RC5 = 2,
	RC_PROTO_RC5X_20 = 3,
	RC_PROTO_RC5_SZ = 4,
	RC_PROTO_JVC = 5,
	RC_PROTO_SONY12 = 6,
	RC_PROTO_SONY15 = 7,
	RC_PROTO_SONY20 = 8,
	RC_PROTO_NEC = 9,
	RC_PROTO_NECX = 10,
	RC_PROTO_NEC32 = 11,
	RC_PROTO_SANYO = 12,
	RC_PROTO_MCIR2_KBD = 13,
	RC_PROTO_MCIR2_MSE = 14,
	RC_PROTO_RC6_0 = 15,
	RC_PROTO_RC6_6A_20 = 16,
	RC_PROTO_RC6_6A_24 = 17,
	RC_PROTO_RC6_6A_32 = 18,
	RC_PROTO_RC6_MCE = 19,
	RC_PROTO_SHARP = 20,
	RC_PROTO_XMP = 21,
	RC_PROTO_CEC = 22,
	RC_PROTO_IMON = 23,
};

struct rc_map_table {
	u32 scancode;
	u32 keycode;
};

struct rc_map {
	struct rc_map_table *scan;
	unsigned int size;
	unsigned int len;
	unsigned int alloc;
	enum rc_proto rc_proto;
	const char *name;
	spinlock_t lock;
};

enum rc_driver_type {
	RC_DRIVER_SCANCODE = 0,
	RC_DRIVER_IR_RAW = 1,
	RC_DRIVER_IR_RAW_TX = 2,
};

struct rc_scancode_filter {
	u32 data;
	u32 mask;
};

struct ir_raw_event_ctrl;

struct rc_dev {
	struct device___345 dev;
	bool managed_alloc;
	const struct attribute_group___342 *sysfs_groups[5];
	const char *device_name;
	const char *input_phys;
	struct input_id input_id;
	const char *driver_name;
	const char *map_name;
	struct rc_map rc_map;
	struct mutex lock;
	unsigned int minor;
	struct ir_raw_event_ctrl *raw;
	struct input_dev *input_dev;
	enum rc_driver_type driver_type;
	bool idle;
	bool encode_wakeup;
	u64 allowed_protocols;
	u64 enabled_protocols;
	u64 allowed_wakeup_protocols;
	enum rc_proto wakeup_protocol;
	struct rc_scancode_filter scancode_filter;
	struct rc_scancode_filter scancode_wakeup_filter;
	u32 scancode_mask;
	u32 users;
	void *priv;
	spinlock_t keylock;
	bool keypressed;
	long unsigned int keyup_jiffies;
	struct timer_list timer_keyup;
	struct timer_list timer_repeat;
	u32 last_keycode;
	enum rc_proto last_protocol;
	u32 last_scancode;
	u8 last_toggle;
	u32 timeout;
	u32 min_timeout;
	u32 max_timeout;
	u32 rx_resolution;
	u32 tx_resolution;
	bool registered;
	int (*change_protocol)(struct rc_dev *, u64 *);
	int (*open)(struct rc_dev *);
	void (*close)(struct rc_dev *);
	int (*s_tx_mask)(struct rc_dev *, u32);
	int (*s_tx_carrier)(struct rc_dev *, u32);
	int (*s_tx_duty_cycle)(struct rc_dev *, u32);
	int (*s_rx_carrier_range)(struct rc_dev *, u32, u32);
	int (*tx_ir)(struct rc_dev *, unsigned int *, unsigned int);
	void (*s_idle)(struct rc_dev *, bool);
	int (*s_learning_mode)(struct rc_dev *, int);
	int (*s_carrier_report)(struct rc_dev *, int);
	int (*s_filter)(struct rc_dev *, struct rc_scancode_filter *);
	int (*s_wakeup_filter)(struct rc_dev *, struct rc_scancode_filter *);
	int (*s_timeout)(struct rc_dev *, unsigned int);
};

struct cec_devnode {
	struct device___345 dev;
	struct cdev___91 cdev;
	int minor;
	bool registered;
	bool unregistered;
	struct list_head fhs;
	struct mutex lock;
};

struct cec_adapter;

struct cec_fh;

struct cec_data {
	struct list_head list;
	struct list_head xfer_list;
	struct cec_adapter *adap;
	struct cec_msg msg;
	struct cec_fh *fh;
	struct delayed_work work;
	struct completion c;
	u8 attempts;
	bool new_initiator;
	bool blocking;
	bool completed;
};

struct cec_adap_ops;

struct cec_adapter {
	struct module___309 *owner;
	char name[32];
	struct cec_devnode devnode;
	struct mutex lock;
	struct rc_dev *rc;
	struct list_head transmit_queue;
	unsigned int transmit_queue_sz;
	struct list_head wait_queue;
	struct cec_data *transmitting;
	struct task_struct___379 *kthread_config;
	struct completion config_completion;
	struct task_struct___379 *kthread;
	wait_queue_head_t kthread_waitq;
	wait_queue_head_t waitq;
	const struct cec_adap_ops *ops;
	void *priv;
	u32 capabilities;
	u8 available_log_addrs;
	u16 phys_addr;
	bool needs_hpd;
	bool is_configuring;
	bool is_configured;
	bool cec_pin_is_high;
	u32 monitor_all_cnt;
	u32 monitor_pin_cnt;
	u32 follower_cnt;
	struct cec_fh *cec_follower;
	struct cec_fh *cec_initiator;
	bool passthrough;
	struct cec_log_addrs log_addrs;
	u32 tx_timeouts;
	struct dentry___377 *cec_dir;
	struct dentry___377 *status_file;
	struct dentry___377 *error_inj_file;
	u16 phys_addrs[15];
	u32 sequence;
	char device_name[32];
	char input_phys[32];
	char input_drv[32];
};

struct cec_event_entry {
	struct list_head list;
	struct cec_event ev;
};

struct cec_fh {
	struct list_head list;
	struct list_head xfer_list;
	struct cec_adapter *adap;
	u8 mode_initiator;
	u8 mode_follower;
	wait_queue_head_t wait;
	struct mutex lock;
	struct list_head events[6];
	u16 queued_events[6];
	unsigned int total_queued_events;
	struct cec_event_entry core_events[2];
	struct list_head msgs;
	unsigned int queued_msgs;
};

struct cec_adap_ops {
	int (*adap_enable)(struct cec_adapter *, bool);
	int (*adap_monitor_all_enable)(struct cec_adapter *, bool);
	int (*adap_monitor_pin_enable)(struct cec_adapter *, bool);
	int (*adap_log_addr)(struct cec_adapter *, u8);
	int (*adap_transmit)(struct cec_adapter *, u8, u32, struct cec_msg *);
	void (*adap_status)(struct cec_adapter *, struct seq_file___320 *);
	void (*adap_free)(struct cec_adapter *);
	int (*error_inj_show)(struct cec_adapter *, struct seq_file___320 *);
	bool (*error_inj_parse_line)(struct cec_adapter *, char *);
	int (*received)(struct cec_adapter *, struct cec_msg *);
};

struct est_timings {
	u8 t1;
	u8 t2;
	u8 mfg_rsvd;
};

struct std_timing {
	u8 hsize;
	u8 vfreq_aspect;
};

struct detailed_pixel_timing {
	u8 hactive_lo;
	u8 hblank_lo;
	u8 hactive_hblank_hi;
	u8 vactive_lo;
	u8 vblank_lo;
	u8 vactive_vblank_hi;
	u8 hsync_offset_lo;
	u8 hsync_pulse_width_lo;
	u8 vsync_offset_pulse_width_lo;
	u8 hsync_vsync_offset_pulse_width_hi;
	u8 width_mm_lo;
	u8 height_mm_lo;
	u8 width_height_mm_hi;
	u8 hborder;
	u8 vborder;
	u8 misc;
};

struct detailed_data_string {
	u8 str[13];
};

struct detailed_data_monitor_range {
	u8 min_vfreq;
	u8 max_vfreq;
	u8 min_hfreq_khz;
	u8 max_hfreq_khz;
	u8 pixel_clock_mhz;
	u8 flags;
	union {
		struct {
			u8 reserved;
			u8 hfreq_start_khz;
			u8 c;
			__le16 m;
			u8 k;
			u8 j;
		} __attribute__((packed)) gtf2;
		struct {
			u8 version;
			u8 data1;
			u8 data2;
			u8 supported_aspects;
			u8 flags;
			u8 supported_scalings;
			u8 preferred_refresh;
		} cvt;
	} formula;
} __attribute__((packed));

struct detailed_data_wpindex {
	u8 white_yx_lo;
	u8 white_x_hi;
	u8 white_y_hi;
	u8 gamma;
};

struct cvt_timing {
	u8 code[3];
};

struct detailed_non_pixel {
	u8 pad1;
	u8 type;
	u8 pad2;
	union {
		struct detailed_data_string str;
		struct detailed_data_monitor_range range;
		struct detailed_data_wpindex color;
		struct std_timing timings[6];
		struct cvt_timing cvt[4];
	} data;
} __attribute__((packed));

struct detailed_timing {
	__le16 pixel_clock;
	union {
		struct detailed_pixel_timing pixel_data;
		struct detailed_non_pixel other_data;
	} data;
};

struct edid {
	u8 header[8];
	u8 mfg_id[2];
	u8 prod_code[2];
	u32 serial;
	u8 mfg_week;
	u8 mfg_year;
	u8 version;
	u8 revision;
	u8 input;
	u8 width_cm;
	u8 height_cm;
	u8 gamma;
	u8 features;
	u8 red_green_lo;
	u8 black_white_lo;
	u8 red_x;
	u8 red_y;
	u8 green_x;
	u8 green_y;
	u8 blue_x;
	u8 blue_y;
	u8 white_x;
	u8 white_y;
	struct est_timings established_timings;
	struct std_timing standard_timings[8];
	struct detailed_timing detailed_timings[4];
	u8 extensions;
	u8 checksum;
};

struct cec_msg_entry {
	struct list_head list;
	struct cec_msg msg;
};

typedef struct poll_table_struct___227 poll_table___37;

struct cec_caps {
	char driver[32];
	char name[32];
	__u32 available_log_addrs;
	__u32 capabilities;
	__u32 version;
};

struct pps_ktime {
	__s64 sec;
	__s32 nsec;
	__u32 flags;
};

struct pps_kinfo {
	__u32 assert_sequence;
	__u32 clear_sequence;
	struct pps_ktime assert_tu;
	struct pps_ktime clear_tu;
	int current_mode;
};

struct pps_kparams {
	int api_version;
	int mode;
	struct pps_ktime assert_off_tu;
	struct pps_ktime clear_off_tu;
};

struct pps_fdata {
	struct pps_kinfo info;
	struct pps_ktime timeout;
};

struct pps_bind_args {
	int tsformat;
	int edge;
	int consumer;
};

struct pps_device;

struct pps_source_info {
	char name[32];
	char path[32];
	int mode;
	void (*echo)(struct pps_device *, int, void *);
	struct module___309 *owner;
	struct device___345 *dev;
};

struct pps_device {
	struct pps_source_info info;
	struct pps_kparams params;
	__u32 assert_sequence;
	__u32 clear_sequence;
	struct pps_ktime assert_tu;
	struct pps_ktime clear_tu;
	int current_mode;
	unsigned int last_ev;
	wait_queue_head_t queue;
	unsigned int id;
	const void *lookup_cookie;
	struct cdev___91 cdev;
	struct device___345 *dev;
	struct fasync_struct___377 *async_queue;
	spinlock_t lock;
};

struct pps_event_time {
	struct timespec64 ts_real;
};

struct pps_device___2;

struct pps_source_info___2 {
	char name[32];
	char path[32];
	int mode;
	void (*echo)(struct pps_device___2 *, int, void *);
	struct module___2 *owner;
	struct device___352 *dev;
};

struct pps_device___2 {
	struct pps_source_info___2 info;
	struct pps_kparams params;
	__u32 assert_sequence;
	__u32 clear_sequence;
	struct pps_ktime assert_tu;
	struct pps_ktime clear_tu;
	int current_mode;
	unsigned int last_ev;
	wait_queue_head_t queue;
	unsigned int id;
	const void *lookup_cookie;
	struct cdev___97 cdev;
	struct device___352 *dev;
	struct fasync_struct___384 *async_queue;
	spinlock_t lock;
};

typedef struct poll_table_struct___2 poll_table___38;

struct posix_clock___2;

struct posix_clock_operations___2 {
	struct module___2 *owner;
	int (*clock_adjtime)(struct posix_clock___2 *, struct timex *);
	int (*clock_gettime)(struct posix_clock___2 *, struct timespec64 *);
	int (*clock_getres)(struct posix_clock___2 *, struct timespec64 *);
	int (*clock_settime)(struct posix_clock___2 *, const struct timespec64 *);
	long int (*ioctl)(struct posix_clock___2 *, unsigned int, long unsigned int);
	int (*open)(struct posix_clock___2 *, fmode_t);
	__poll_t (*poll)(struct posix_clock___2 *, struct file___2 *, poll_table___38 *);
	int (*release)(struct posix_clock___2 *);
	ssize_t (*read)(struct posix_clock___2 *, uint, char *, size_t);
};

struct posix_clock___2 {
	struct posix_clock_operations___2 ops;
	struct cdev___97 cdev;
	struct kref kref;
	struct rw_semaphore___386 rwsem;
	bool zombie;
	void (*release)(struct posix_clock___2 *);
};

struct ptp_extts_event {
	struct ptp_clock_time t;
	unsigned int index;
	unsigned int flags;
	unsigned int rsv[2];
};

struct ptp_clock_info___2 {
	struct module___2 *owner;
	char name[16];
	s32 max_adj;
	int n_alarm;
	int n_ext_ts;
	int n_per_out;
	int n_pins;
	int pps;
	struct ptp_pin_desc *pin_config;
	int (*adjfine)(struct ptp_clock_info___2 *, long int);
	int (*adjfreq)(struct ptp_clock_info___2 *, s32);
	int (*adjtime)(struct ptp_clock_info___2 *, s64);
	int (*gettime64)(struct ptp_clock_info___2 *, struct timespec64 *);
	int (*gettimex64)(struct ptp_clock_info___2 *, struct timespec64 *, struct ptp_system_timestamp *);
	int (*getcrosststamp)(struct ptp_clock_info___2 *, struct system_device_crosststamp *);
	int (*settime64)(struct ptp_clock_info___2 *, const struct timespec64 *);
	int (*enable)(struct ptp_clock_info___2 *, struct ptp_clock_request *, int);
	int (*verify)(struct ptp_clock_info___2 *, unsigned int, enum ptp_pin_function, unsigned int);
	long int (*do_aux_work)(struct ptp_clock_info___2 *);
};

enum ptp_clock_events {
	PTP_CLOCK_ALARM = 0,
	PTP_CLOCK_EXTTS = 1,
	PTP_CLOCK_PPS = 2,
	PTP_CLOCK_PPSUSR = 3,
};

struct ptp_clock_event {
	int type;
	int index;
	union {
		u64 timestamp;
		struct pps_event_time pps_times;
	};
};

struct timestamp_event_queue {
	struct ptp_extts_event buf[128];
	int head;
	int tail;
	spinlock_t lock;
};

struct ptp_clock___2 {
	struct posix_clock___2 clock;
	struct device___352 *dev;
	struct ptp_clock_info___2 *info;
	dev_t devid;
	int index;
	struct pps_device___2 *pps_source;
	long int dialed_frequency;
	struct timestamp_event_queue tsevq;
	struct mutex tsevq_mux;
	struct mutex pincfg_mux;
	wait_queue_head_t tsev_wq;
	int defunct;
	struct device_attribute___55 *pin_dev_attr;
	struct attribute **pin_attr;
	struct attribute_group___349 pin_attr_group;
	const struct attribute_group___349 *pin_attr_groups[2];
	struct kthread_worker___239 *kworker;
	struct kthread_delayed_work___238 aux_work;
};

struct posix_clock___3;

struct posix_clock_operations___3 {
	struct module___309 *owner;
	int (*clock_adjtime)(struct posix_clock___3 *, struct timex *);
	int (*clock_gettime)(struct posix_clock___3 *, struct timespec64 *);
	int (*clock_getres)(struct posix_clock___3 *, struct timespec64 *);
	int (*clock_settime)(struct posix_clock___3 *, const struct timespec64 *);
	long int (*ioctl)(struct posix_clock___3 *, unsigned int, long unsigned int);
	int (*open)(struct posix_clock___3 *, fmode_t);
	__poll_t (*poll)(struct posix_clock___3 *, struct file___378 *, poll_table___37 *);
	int (*release)(struct posix_clock___3 *);
	ssize_t (*read)(struct posix_clock___3 *, uint, char *, size_t);
};

struct posix_clock___3 {
	struct posix_clock_operations___3 ops;
	struct cdev___91 cdev;
	struct kref kref;
	struct rw_semaphore___379 rwsem;
	bool zombie;
	void (*release)(struct posix_clock___3 *);
};

struct ptp_clock_caps {
	int max_adj;
	int n_alarm;
	int n_ext_ts;
	int n_per_out;
	int pps;
	int n_pins;
	int cross_timestamping;
	int rsv[13];
};

struct ptp_sys_offset {
	unsigned int n_samples;
	unsigned int rsv[3];
	struct ptp_clock_time ts[51];
};

struct ptp_sys_offset_extended {
	unsigned int n_samples;
	unsigned int rsv[3];
	struct ptp_clock_time ts[75];
};

struct ptp_sys_offset_precise {
	struct ptp_clock_time device;
	struct ptp_clock_time sys_realtime;
	struct ptp_clock_time sys_monoraw;
	unsigned int rsv[4];
};

struct ptp_clock_info___3 {
	struct module___309 *owner;
	char name[16];
	s32 max_adj;
	int n_alarm;
	int n_ext_ts;
	int n_per_out;
	int n_pins;
	int pps;
	struct ptp_pin_desc *pin_config;
	int (*adjfine)(struct ptp_clock_info___3 *, long int);
	int (*adjfreq)(struct ptp_clock_info___3 *, s32);
	int (*adjtime)(struct ptp_clock_info___3 *, s64);
	int (*gettime64)(struct ptp_clock_info___3 *, struct timespec64 *);
	int (*gettimex64)(struct ptp_clock_info___3 *, struct timespec64 *, struct ptp_system_timestamp *);
	int (*getcrosststamp)(struct ptp_clock_info___3 *, struct system_device_crosststamp *);
	int (*settime64)(struct ptp_clock_info___3 *, const struct timespec64 *);
	int (*enable)(struct ptp_clock_info___3 *, struct ptp_clock_request *, int);
	int (*verify)(struct ptp_clock_info___3 *, unsigned int, enum ptp_pin_function, unsigned int);
	long int (*do_aux_work)(struct ptp_clock_info___3 *);
};

struct ptp_clock___3 {
	struct posix_clock___3 clock;
	struct device___345 *dev;
	struct ptp_clock_info___3 *info;
	dev_t devid;
	int index;
	struct pps_device *pps_source;
	long int dialed_frequency;
	struct timestamp_event_queue tsevq;
	struct mutex tsevq_mux;
	struct mutex pincfg_mux;
	wait_queue_head_t tsev_wq;
	int defunct;
	struct device_attribute___49 *pin_dev_attr;
	struct attribute **pin_attr;
	struct attribute_group___342 pin_attr_group;
	const struct attribute_group___342 *pin_attr_groups[2];
	struct kthread_worker___230 *kworker;
	struct kthread_delayed_work___230 aux_work;
};

typedef void (*poll_queue_proc___241)(struct file___385 *, wait_queue_head_t *, struct poll_table_struct___6 *);

struct pps_device___3;

struct pps_source_info___3 {
	char name[32];
	char path[32];
	int mode;
	void (*echo)(struct pps_device___3 *, int, void *);
	struct module___11 *owner;
	struct device___353 *dev;
};

struct pps_device___3 {
	struct pps_source_info___3 info;
	struct pps_kparams params;
	__u32 assert_sequence;
	__u32 clear_sequence;
	struct pps_ktime assert_tu;
	struct pps_ktime clear_tu;
	int current_mode;
	unsigned int last_ev;
	wait_queue_head_t queue;
	unsigned int id;
	const void *lookup_cookie;
	struct cdev___3 cdev;
	struct device___353 *dev;
	struct fasync_struct___11 *async_queue;
	spinlock_t lock;
};

struct gpio_restart {
	struct gpio_desc *reset_gpio;
	struct notifier_block restart_handler;
	u32 active_delay_ms;
	u32 inactive_delay_ms;
	u32 wait_delay_ms;
};

enum vexpress_reset_func {
	FUNC_RESET = 0,
	FUNC_SHUTDOWN = 1,
	FUNC_REBOOT = 2,
};

struct syscon_reboot_context {
	struct regmap *map;
	u32 offset;
	u32 mask;
	struct notifier_block restart_handler;
};

struct led_trigger___6;

struct led_classdev___6 {
	const char *name;
	enum led_brightness brightness;
	enum led_brightness max_brightness;
	int flags;
	long unsigned int work_flags;
	void (*brightness_set)(struct led_classdev___6 *, enum led_brightness);
	int (*brightness_set_blocking)(struct led_classdev___6 *, enum led_brightness);
	enum led_brightness (*brightness_get)(struct led_classdev___6 *);
	int (*blink_set)(struct led_classdev___6 *, long unsigned int *, long unsigned int *);
	int (*pattern_set)(struct led_classdev___6 *, struct led_pattern *, u32, int);
	int (*pattern_clear)(struct led_classdev___6 *);
	struct device___345 *dev;
	const struct attribute_group___350 **groups;
	struct list_head node;
	const char *default_trigger;
	long unsigned int blink_delay_on;
	long unsigned int blink_delay_off;
	struct timer_list blink_timer;
	int blink_brightness;
	int new_blink_brightness;
	void (*flash_resume)(struct led_classdev___6 *);
	struct work_struct set_brightness_work;
	int delayed_set_value;
	struct rw_semaphore___379 trigger_lock;
	struct led_trigger___6 *trigger;
	struct list_head trig_list;
	void *trigger_data;
	bool activated;
	struct mutex led_access;
};

struct led_trigger___6 {
	const char *name;
	void (*activate)(struct led_classdev___6 *);
	void (*deactivate)(struct led_classdev___6 *);
	rwlock_t leddev_list_lock;
	struct list_head led_cdevs;
	struct list_head next_trig;
};

enum power_supply_notifier_events {
	PSY_EVENT_PROP_CHANGED = 0,
};

struct power_supply_config___2 {
	struct device_node___88 *of_node;
	struct fwnode_handle___267 *fwnode;
	void *drv_data;
	char **supplied_to;
	size_t num_supplicants;
};

struct power_supply___2;

struct power_supply_desc___2 {
	const char *name;
	enum power_supply_type type;
	enum power_supply_usb_type *usb_types;
	size_t num_usb_types;
	enum power_supply_property *properties;
	size_t num_properties;
	int (*get_property)(struct power_supply___2 *, enum power_supply_property, union power_supply_propval *);
	int (*set_property)(struct power_supply___2 *, enum power_supply_property, const union power_supply_propval *);
	int (*property_is_writeable)(struct power_supply___2 *, enum power_supply_property);
	void (*external_power_changed)(struct power_supply___2 *);
	void (*set_charged)(struct power_supply___2 *);
	bool no_thermal;
	int use_for_apm;
};

struct power_supply___2 {
	const struct power_supply_desc___2 *desc;
	char **supplied_to;
	size_t num_supplicants;
	char **supplied_from;
	size_t num_supplies;
	struct device_node___88 *of_node;
	void *drv_data;
	struct device___345 dev;
	struct work_struct changed_work;
	struct delayed_work deferred_register_work;
	spinlock_t changed_lock;
	bool changed;
	bool initialized;
	bool removing;
	atomic_t use_cnt;
	struct thermal_zone_device___3 *tzd;
	struct thermal_cooling_device___3 *tcd;
	struct led_trigger___6 *charging_full_trig;
	char *charging_full_trig_name;
	struct led_trigger___6 *charging_trig;
	char *charging_trig_name;
	struct led_trigger___6 *full_trig;
	char *full_trig_name;
	struct led_trigger___6 *online_trig;
	char *online_trig_name;
	struct led_trigger___6 *charging_blink_full_solid_trig;
	char *charging_blink_full_solid_trig_name;
};

struct power_supply_battery_info {
	int energy_full_design_uwh;
	int charge_full_design_uah;
	int voltage_min_design_uv;
	int precharge_current_ua;
	int charge_term_current_ua;
	int constant_charge_current_max_ua;
	int constant_charge_voltage_max_uv;
};

struct psy_am_i_supplied_data {
	struct power_supply___2 *psy;
	unsigned int count;
};

struct power_supply___3;

struct power_supply_desc___3 {
	const char *name;
	enum power_supply_type type;
	enum power_supply_usb_type *usb_types;
	size_t num_usb_types;
	enum power_supply_property *properties;
	size_t num_properties;
	int (*get_property)(struct power_supply___3 *, enum power_supply_property, union power_supply_propval *);
	int (*set_property)(struct power_supply___3 *, enum power_supply_property, const union power_supply_propval *);
	int (*property_is_writeable)(struct power_supply___3 *, enum power_supply_property);
	void (*external_power_changed)(struct power_supply___3 *);
	void (*set_charged)(struct power_supply___3 *);
	bool no_thermal;
	int use_for_apm;
};

struct power_supply___3 {
	const struct power_supply_desc___3 *desc;
	char **supplied_to;
	size_t num_supplicants;
	char **supplied_from;
	size_t num_supplies;
	struct device_node___2 *of_node;
	void *drv_data;
	struct device___353 dev;
	struct work_struct changed_work;
	struct delayed_work deferred_register_work;
	spinlock_t changed_lock;
	bool changed;
	bool initialized;
	bool removing;
	atomic_t use_cnt;
	struct thermal_zone_device___5 *tzd;
	struct thermal_cooling_device___5 *tcd;
	struct led_trigger___4 *charging_full_trig;
	char *charging_full_trig_name;
	struct led_trigger___4 *charging_trig;
	char *charging_trig_name;
	struct led_trigger___4 *full_trig;
	char *full_trig_name;
	struct led_trigger___4 *online_trig;
	char *online_trig_name;
	struct led_trigger___4 *charging_blink_full_solid_trig;
	char *charging_blink_full_solid_trig_name;
};

enum {
	POWER_SUPPLY_STATUS_UNKNOWN = 0,
	POWER_SUPPLY_STATUS_CHARGING = 1,
	POWER_SUPPLY_STATUS_DISCHARGING = 2,
	POWER_SUPPLY_STATUS_NOT_CHARGING = 3,
	POWER_SUPPLY_STATUS_FULL = 4,
};

typedef void (*dr_release_t___26)(struct device___352 *, void *);

enum hwmon_sensor_types {
	hwmon_chip = 0,
	hwmon_temp = 1,
	hwmon_in = 2,
	hwmon_curr = 3,
	hwmon_power = 4,
	hwmon_energy = 5,
	hwmon_humidity = 6,
	hwmon_fan = 7,
	hwmon_pwm = 8,
	hwmon_max = 9,
};

enum hwmon_chip_attributes {
	hwmon_chip_temp_reset_history = 0,
	hwmon_chip_in_reset_history = 1,
	hwmon_chip_curr_reset_history = 2,
	hwmon_chip_power_reset_history = 3,
	hwmon_chip_register_tz = 4,
	hwmon_chip_update_interval = 5,
	hwmon_chip_alarms = 6,
};

enum hwmon_temp_attributes {
	hwmon_temp_input = 0,
	hwmon_temp_type = 1,
	hwmon_temp_lcrit = 2,
	hwmon_temp_lcrit_hyst = 3,
	hwmon_temp_min = 4,
	hwmon_temp_min_hyst = 5,
	hwmon_temp_max = 6,
	hwmon_temp_max_hyst = 7,
	hwmon_temp_crit = 8,
	hwmon_temp_crit_hyst = 9,
	hwmon_temp_emergency = 10,
	hwmon_temp_emergency_hyst = 11,
	hwmon_temp_alarm = 12,
	hwmon_temp_lcrit_alarm = 13,
	hwmon_temp_min_alarm = 14,
	hwmon_temp_max_alarm = 15,
	hwmon_temp_crit_alarm = 16,
	hwmon_temp_emergency_alarm = 17,
	hwmon_temp_fault = 18,
	hwmon_temp_offset = 19,
	hwmon_temp_label = 20,
	hwmon_temp_lowest = 21,
	hwmon_temp_highest = 22,
	hwmon_temp_reset_history = 23,
};

enum hwmon_in_attributes {
	hwmon_in_input = 0,
	hwmon_in_min = 1,
	hwmon_in_max = 2,
	hwmon_in_lcrit = 3,
	hwmon_in_crit = 4,
	hwmon_in_average = 5,
	hwmon_in_lowest = 6,
	hwmon_in_highest = 7,
	hwmon_in_reset_history = 8,
	hwmon_in_label = 9,
	hwmon_in_alarm = 10,
	hwmon_in_min_alarm = 11,
	hwmon_in_max_alarm = 12,
	hwmon_in_lcrit_alarm = 13,
	hwmon_in_crit_alarm = 14,
};

enum hwmon_curr_attributes {
	hwmon_curr_input = 0,
	hwmon_curr_min = 1,
	hwmon_curr_max = 2,
	hwmon_curr_lcrit = 3,
	hwmon_curr_crit = 4,
	hwmon_curr_average = 5,
	hwmon_curr_lowest = 6,
	hwmon_curr_highest = 7,
	hwmon_curr_reset_history = 8,
	hwmon_curr_label = 9,
	hwmon_curr_alarm = 10,
	hwmon_curr_min_alarm = 11,
	hwmon_curr_max_alarm = 12,
	hwmon_curr_lcrit_alarm = 13,
	hwmon_curr_crit_alarm = 14,
};

enum hwmon_power_attributes {
	hwmon_power_average = 0,
	hwmon_power_average_interval = 1,
	hwmon_power_average_interval_max = 2,
	hwmon_power_average_interval_min = 3,
	hwmon_power_average_highest = 4,
	hwmon_power_average_lowest = 5,
	hwmon_power_average_max = 6,
	hwmon_power_average_min = 7,
	hwmon_power_input = 8,
	hwmon_power_input_highest = 9,
	hwmon_power_input_lowest = 10,
	hwmon_power_reset_history = 11,
	hwmon_power_accuracy = 12,
	hwmon_power_cap = 13,
	hwmon_power_cap_hyst = 14,
	hwmon_power_cap_max = 15,
	hwmon_power_cap_min = 16,
	hwmon_power_max = 17,
	hwmon_power_crit = 18,
	hwmon_power_label = 19,
	hwmon_power_alarm = 20,
	hwmon_power_cap_alarm = 21,
	hwmon_power_max_alarm = 22,
	hwmon_power_crit_alarm = 23,
};

enum hwmon_energy_attributes {
	hwmon_energy_input = 0,
	hwmon_energy_label = 1,
};

enum hwmon_humidity_attributes {
	hwmon_humidity_input = 0,
	hwmon_humidity_label = 1,
	hwmon_humidity_min = 2,
	hwmon_humidity_min_hyst = 3,
	hwmon_humidity_max = 4,
	hwmon_humidity_max_hyst = 5,
	hwmon_humidity_alarm = 6,
	hwmon_humidity_fault = 7,
};

enum hwmon_fan_attributes {
	hwmon_fan_input = 0,
	hwmon_fan_label = 1,
	hwmon_fan_min = 2,
	hwmon_fan_max = 3,
	hwmon_fan_div = 4,
	hwmon_fan_pulses = 5,
	hwmon_fan_target = 6,
	hwmon_fan_alarm = 7,
	hwmon_fan_min_alarm = 8,
	hwmon_fan_max_alarm = 9,
	hwmon_fan_fault = 10,
};

enum hwmon_pwm_attributes {
	hwmon_pwm_input = 0,
	hwmon_pwm_enable = 1,
	hwmon_pwm_mode = 2,
	hwmon_pwm_freq = 3,
};

struct hwmon_ops {
	umode_t (*is_visible)(const void *, enum hwmon_sensor_types, u32, int);
	int (*read)(struct device___352 *, enum hwmon_sensor_types, u32, int, long int *);
	int (*read_string)(struct device___352 *, enum hwmon_sensor_types, u32, int, const char **);
	int (*write)(struct device___352 *, enum hwmon_sensor_types, u32, int, long int);
};

struct hwmon_channel_info {
	enum hwmon_sensor_types type;
	const u32 *config;
};

struct hwmon_chip_info {
	const struct hwmon_ops *ops;
	const struct hwmon_channel_info **info;
};

struct hwmon_device {
	const char *name;
	struct device___352 dev;
	const struct hwmon_chip_info *chip;
	struct attribute_group___349 group;
	const struct attribute_group___349 **groups;
};

struct hwmon_device_attribute {
	struct device_attribute___55 dev_attr;
	const struct hwmon_ops *ops;
	enum hwmon_sensor_types type;
	u32 attr;
	int index;
	char name[32];
};

struct sensor_device_attribute {
	struct device_attribute___49 dev_attr;
	int index;
};

struct acpi_power_meter_capabilities {
	u64 flags;
	u64 units;
	u64 type;
	u64 accuracy;
	u64 sampling_time;
	u64 min_avg_interval;
	u64 max_avg_interval;
	u64 hysteresis;
	u64 configurable_cap;
	u64 min_cap;
	u64 max_cap;
};

struct acpi_power_meter_resource {
	struct acpi_device___19 *acpi_dev;
	acpi_bus_id name;
	struct mutex lock;
	struct device___345 *hwmon_dev;
	struct acpi_power_meter_capabilities caps;
	acpi_string model_number;
	acpi_string serial_number;
	acpi_string oem_info;
	u64 power;
	u64 cap;
	u64 avg_interval;
	int sensors_valid;
	long unsigned int sensors_last_updated;
	struct sensor_device_attribute sensors[17];
	int num_sensors;
	s64 trip[2];
	int num_domain_devices;
	struct acpi_device___19 **domain_devices;
	struct kobject___365 *holders_dir;
};

struct sensor_template {
	char *label;
	ssize_t (*show)(struct device___345 *, struct device_attribute___49 *, char *);
	ssize_t (*set)(struct device___345 *, struct device_attribute___49 *, const char *, size_t);
	int index;
};

struct module___316;

struct file___386;

struct kiocb___386;

struct iov_iter___161;

struct poll_table_struct___234;

struct vm_area_struct___387;

struct inode___386;

struct file_lock___386;

struct page___387;

struct pipe_inode_info___80;

struct seq_file___328;

struct file_operations___386 {
	struct module___316 *owner;
	loff_t (*llseek)(struct file___386 *, loff_t, int);
	ssize_t (*read)(struct file___386 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___386 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___386 *, struct iov_iter___161 *);
	ssize_t (*write_iter)(struct kiocb___386 *, struct iov_iter___161 *);
	int (*iopoll)(struct kiocb___386 *, bool);
	int (*iterate)(struct file___386 *, struct dir_context *);
	int (*iterate_shared)(struct file___386 *, struct dir_context *);
	__poll_t (*poll)(struct file___386 *, struct poll_table_struct___234 *);
	long int (*unlocked_ioctl)(struct file___386 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___386 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___386 *, struct vm_area_struct___387 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___386 *, struct file___386 *);
	int (*flush)(struct file___386 *, fl_owner_t);
	int (*release)(struct inode___386 *, struct file___386 *);
	int (*fsync)(struct file___386 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___386 *, int);
	int (*lock)(struct file___386 *, int, struct file_lock___386 *);
	ssize_t (*sendpage)(struct file___386 *, struct page___387 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___386 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___386 *, int, struct file_lock___386 *);
	ssize_t (*splice_write)(struct pipe_inode_info___80 *, struct file___386 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___386 *, loff_t *, struct pipe_inode_info___80 *, size_t, unsigned int);
	int (*setlease)(struct file___386 *, long int, struct file_lock___386 **, void **);
	long int (*fallocate)(struct file___386 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___328 *, struct file___386 *);
	ssize_t (*copy_file_range)(struct file___386 *, loff_t, struct file___386 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___386 *, loff_t, struct file___386 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___386 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___387 {
	u64 seqnum;
	struct vm_area_struct___387 *vmas[4];
};

struct page_frag___387 {
	struct page___387 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___148;

struct debug_info___148 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___148 *hbp_break[16];
	struct perf_event___148 *hbp_watch[16];
};

struct thread_struct___148 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___148 debug;
	long: 64;
};

struct mm_struct___387;

struct mem_cgroup___135;

struct pid___224;

struct cred___356;

struct nsproxy___285;

struct signal_struct___266;

struct bio_list___189;

struct backing_dev_info___189;

struct css_set___240;

struct perf_event_context___148;

struct vm_struct___291;

struct task_struct___388 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___388 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___387 *mm;
	struct mm_struct___387 *active_mm;
	struct vmacache___387 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___388 *real_parent;
	struct task_struct___388 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___388 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___135 *active_memcg;
	long int rh_reserved2;
	struct pid___224 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___224 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___224 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___356 *ptracer_cred;
	const struct cred___356 *real_cred;
	const struct cred___356 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___285 *nsproxy;
	struct signal_struct___266 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___388 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___189 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___189 *backing_dev_info;
	struct io_context___107 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___240 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___148 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___80 *splice_pipe;
	struct page_frag___387 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___135 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___388 *oom_reaper_list;
	struct vm_struct___291 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___148 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___148 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___388 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___148)(struct perf_event___148 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___148;

struct fasync_struct___386;

struct pid_namespace___224;

struct trace_event_call___141;

struct perf_cgroup___148;

struct perf_event___148 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___148 *group_leader;
	struct pmu___148 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___148 hw;
	struct perf_event_context___148 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___148 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___388 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___386 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___148 *);
	struct callback_head callback_head;
	struct pid_namespace___224 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___148 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___148 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___141 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___148 *cgrp;
	struct list_head sb_list;
};

struct rw_semaphore___388 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___388 *owner;
};

struct key___356;

struct ucounts___256;

struct user_namespace___256 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___256 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___9 ns;
	long unsigned int flags;
	struct key___356 *persistent_keyring_register;
	struct rw_semaphore___388 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___256 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___387 *pgtable_t___387;

struct address_space___386;

struct dev_pagemap___375;

struct page___387 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___386 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___387 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___387 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___387 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___375 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___135 *mem_cgroup;
};

struct pglist_data___387;

struct lruvec___387 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___387 *pgdat;
};

struct zone___387 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___387 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___387 {
	struct zone___387 *zone;
	int zone_idx;
};

struct zonelist___387 {
	struct zoneref___387 _zonerefs[25];
};

struct pglist_data___387 {
	struct zone___387 node_zones[3];
	struct zonelist___387 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___388 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___388 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___387 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___388 {
	void *stack;
	struct task_struct___388 *task;
	long int status;
};

struct blocking_notifier_head___387 {
	struct rw_semaphore___388 rwsem;
	struct notifier_block *head;
};

struct dentry___386;

struct path___387 {
	struct vfsmount *mnt;
	struct dentry___386 *dentry;
};

struct fown_struct___224 {
	rwlock_t lock;
	struct pid___224 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___386 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___387 f_path;
	struct inode___386 *f_inode;
	const struct file_operations___386 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___224 f_owner;
	const struct cred___356 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___386 *f_mapping;
	errseq_t f_wb_err;
};

struct user_struct___356;

struct cred___356 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___356 *session_keyring;
	struct key___356 *process_keyring;
	struct key___356 *thread_keyring;
	struct key___356 *request_key_auth;
	void *security;
	struct user_struct___356 *user;
	struct user_namespace___256 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___380;

struct kernfs_elem_dir___380 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___380 *root;
};

struct kernfs_node___381;

struct kernfs_syscall_ops___380;

struct kernfs_root___380 {
	struct kernfs_node___381 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___380 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___380 {
	struct kernfs_node___381 *target_kn;
};

struct kernfs_ops___380;

struct kernfs_elem_attr___380 {
	const struct kernfs_ops___380 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___381 *notify_next;
};

struct kernfs_node___381 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___381 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___380 dir;
		struct kernfs_elem_symlink___380 symlink;
		struct kernfs_elem_attr___380 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___380;

struct kernfs_ops___380 {
	int (*open)(struct kernfs_open_file___380 *);
	void (*release)(struct kernfs_open_file___380 *);
	int (*seq_show)(struct seq_file___328 *, void *);
	void * (*seq_start)(struct seq_file___328 *, loff_t *);
	void * (*seq_next)(struct seq_file___328 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___328 *, void *);
	ssize_t (*read)(struct kernfs_open_file___380 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___380 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___380 *, struct vm_area_struct___387 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___380 *, struct poll_table_struct___234 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___380 {
	int (*remount_fs)(struct kernfs_root___380 *, int *, char *);
	int (*show_options)(struct seq_file___328 *, struct kernfs_root___380 *);
	int (*mkdir)(struct kernfs_node___381 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___381 *);
	int (*rename)(struct kernfs_node___381 *, struct kernfs_node___381 *, const char *);
	int (*show_path)(struct seq_file___328 *, struct kernfs_node___381 *, struct kernfs_root___380 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___328;

struct seq_file___328 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___328 *op;
	int poll_event;
	const struct file___386 *file;
	void *private;
};

struct vm_operations_struct___375;

struct kernfs_open_file___380 {
	struct kernfs_node___381 *kn;
	struct file___386 *file;
	struct seq_file___328 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___375 *vm_ops;
};

struct vm_fault___375;

struct vm_operations_struct___375 {
	void (*open)(struct vm_area_struct___387 *);
	void (*close)(struct vm_area_struct___387 *);
	int (*split)(struct vm_area_struct___387 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___387 *);
	vm_fault_t (*fault)(struct vm_fault___375 *);
	vm_fault_t (*huge_fault)(struct vm_fault___375 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___375 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___387 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___375 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___375 *);
	int (*access)(struct vm_area_struct___387 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___387 *);
	int (*set_policy)(struct vm_area_struct___387 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___387 *, long unsigned int);
	struct page___387 * (*find_special_page)(struct vm_area_struct___387 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___242)(struct file___386 *, wait_queue_head_t *, struct poll_table_struct___234 *);

struct poll_table_struct___234 {
	poll_queue_proc___242 _qproc;
	__poll_t _key;
};

struct vm_area_struct___387 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___387 *vm_next;
	struct vm_area_struct___387 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___387 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___375 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___386 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___374;

struct bin_attribute___350;

struct attribute_group___351 {
	const char *name;
	umode_t (*is_visible)(struct kobject___374 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___374 *, struct bin_attribute___350 *, int);
	struct attribute **attrs;
	struct bin_attribute___350 **bin_attrs;
};

struct kset___373;

struct kobj_type___373;

struct kobject___374 {
	const char *name;
	struct list_head entry;
	struct kobject___374 *parent;
	struct kset___373 *kset;
	struct kobj_type___373 *ktype;
	struct kernfs_node___381 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___350 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___386 *, struct kobject___374 *, struct bin_attribute___350 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___386 *, struct kobject___374 *, struct bin_attribute___350 *, char *, loff_t, size_t);
	int (*mmap)(struct file___386 *, struct kobject___374 *, struct bin_attribute___350 *, struct vm_area_struct___387 *);
};

struct sysfs_ops___373 {
	ssize_t (*show)(struct kobject___374 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___374 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___373;

struct kset___373 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___374 kobj;
	const struct kset_uevent_ops___373 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___373 {
	void (*release)(struct kobject___374 *);
	const struct sysfs_ops___373 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___29 * (*child_ns_type)(struct kobject___374 *);
	const void * (*namespace)(struct kobject___374 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___373 {
	int (* const filter)(struct kset___373 *, struct kobject___374 *);
	const char * (* const name)(struct kset___373 *, struct kobject___374 *);
	int (* const uevent)(struct kset___373 *, struct kobject___374 *, struct kobj_uevent_env *);
};

struct kobj_attribute___365 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___374 *, struct kobj_attribute___365 *, char *);
	ssize_t (*store)(struct kobject___374 *, struct kobj_attribute___365 *, const char *, size_t);
};

struct kernel_param___314;

struct kernel_param_ops___314 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___314 *);
	int (*get)(char *, const struct kernel_param___314 *);
	void (*free)(void *);
};

struct kparam_array___314;

struct kernel_param___314 {
	const char *name;
	struct module___316 *mod;
	const struct kernel_param_ops___314 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___314 *arr;
	};
};

struct kparam_array___314 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___314 *ops;
	void *elem;
};

struct module_kobject___314 {
	struct kobject___374 kobj;
	struct module___316 *mod;
	struct kobject___374 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___314 {
	struct module___316 *mod;
	struct latch_tree_node node;
};

struct module_layout___314 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___314 mtn;
};

struct module_attribute___314;

struct module___316 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___314 mkobj;
	struct module_attribute___314 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___374 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___314 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___314 core_layout;
	struct module_layout___314 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___141 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___314 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___314 *, struct module_kobject___314 *, char *);
	ssize_t (*store)(struct module_attribute___314 *, struct module_kobject___314 *, const char *, size_t);
	void (*setup)(struct module___316 *, const char *);
	int (*test)(struct module___316 *);
	void (*free)(struct module___316 *);
};

struct trace_event_class___141;

struct trace_event_call___141 {
	struct list_head list;
	struct trace_event_class___141 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___13 event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___39 *prog_array;
	int (*perf_perm)(struct trace_event_call___141 *, struct perf_event___148 *);
};

struct device___354;

struct dev_pm_ops___354 {
	int (*prepare)(struct device___354 *);
	void (*complete)(struct device___354 *);
	int (*suspend)(struct device___354 *);
	int (*resume)(struct device___354 *);
	int (*freeze)(struct device___354 *);
	int (*thaw)(struct device___354 *);
	int (*poweroff)(struct device___354 *);
	int (*restore)(struct device___354 *);
	int (*suspend_late)(struct device___354 *);
	int (*resume_early)(struct device___354 *);
	int (*freeze_late)(struct device___354 *);
	int (*thaw_early)(struct device___354 *);
	int (*poweroff_late)(struct device___354 *);
	int (*restore_early)(struct device___354 *);
	int (*suspend_noirq)(struct device___354 *);
	int (*resume_noirq)(struct device___354 *);
	int (*freeze_noirq)(struct device___354 *);
	int (*thaw_noirq)(struct device___354 *);
	int (*poweroff_noirq)(struct device___354 *);
	int (*restore_noirq)(struct device___354 *);
	int (*runtime_suspend)(struct device___354 *);
	int (*runtime_resume)(struct device___354 *);
	int (*runtime_idle)(struct device___354 *);
};

struct dev_pm_info___354 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___354 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___354;

struct bus_type___354;

struct device_driver___354;

struct dev_pm_domain___354;

struct dma_map_ops___135;

struct device_node___91;

struct fwnode_handle___275;

struct class___354;

struct device___354 {
	struct device___354 *parent;
	struct device_private *p;
	struct kobject___374 kobj;
	const char *init_name;
	const struct device_type___354 *type;
	struct mutex mutex;
	struct bus_type___354 *bus;
	struct device_driver___354 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___354 power;
	struct dev_pm_domain___354 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___135 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___91 *of_node;
	struct fwnode_handle___275 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___354 *class;
	const struct attribute_group___351 **groups;
	void (*release)(struct device___354 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___354 {
	struct dev_pm_ops___354 ops;
	void (*detach)(struct device___354 *, bool);
	int (*activate)(struct device___354 *);
	void (*sync)(struct device___354 *);
	void (*dismiss)(struct device___354 *);
};

struct upid___224 {
	int nr;
	struct pid_namespace___224 *ns;
};

struct pid_namespace___224 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___388 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___224 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___386 *proc_self;
	struct dentry___386 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___256 *user_ns;
	struct ucounts___256 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___9 ns;
};

struct pid___224 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___224 numbers[1];
};

struct user_struct___356 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___356 *uid_keyring;
	struct key___356 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___387;

struct mm_struct___387 {
	struct {
		struct vm_area_struct___387 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___386 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___388 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___387 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___388 *owner;
		struct user_namespace___256 *user_ns;
		struct file___386 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___387 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup___240;

struct cgroup_subsys___240;

struct cgroup_subsys_state___240 {
	struct cgroup___240 *cgroup;
	struct cgroup_subsys___240 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___240 *parent;
};

struct mem_cgroup_id___28 {
	int id;
	union {
		refcount_t ref;
		struct {
			atomic_t ref;
		} __UNIQUE_ID_rh_kabi_hide39;
		union {		};
	};
};

struct cgroup_file___240 {
	struct kernfs_node___381 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___135;

struct mem_cgroup___135 {
	struct cgroup_subsys_state___240 css;
	struct mem_cgroup_id___28 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___240 events_file;
	struct cgroup_file___240 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___388 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___135 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net___56;

struct cgroup_namespace___240;

struct nsproxy___285 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___224 *pid_ns_for_children;
	struct net___56 *net_ns;
	struct cgroup_namespace___240 *cgroup_ns;
};

struct signal_struct___266 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___388 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___388 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___224 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___224 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___387 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___224 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___189;

struct bio_list___189 {
	struct bio___189 *head;
	struct bio___189 *tail;
};

struct bdi_writeback_congested___189;

struct bdi_writeback___189 {
	struct backing_dev_info___189 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___189 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___240 *memcg_css;
	struct cgroup_subsys_state___240 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___189 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___189 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___354 *dev;
	struct device___354 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___386 *debug_dir;
	struct dentry___386 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___240 {
	struct cgroup_subsys_state___240 *subsys[13];
	refcount_t refcount;
	struct css_set___240 *dom_cset;
	struct cgroup___240 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___240 *mg_src_cgrp;
	struct cgroup___240 *mg_dst_cgrp;
	struct css_set___240 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___148 {
	struct pmu___148 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___388 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___148 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___80;

struct pipe_inode_info___80 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___387 *tmp_page;
	struct fasync_struct___386 *fasync_readers;
	struct fasync_struct___386 *fasync_writers;
	struct pipe_buffer___80 *bufs;
	struct user_struct___356 *user;
};

struct vm_struct___291 {
	struct vm_struct___291 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___387 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___278 {
	struct task_struct___388 task;
	long unsigned int stack[8192];
};

struct bus_type___354 {
	const char *name;
	const char *dev_name;
	struct device___354 *dev_root;
	const struct attribute_group___351 **bus_groups;
	const struct attribute_group___351 **dev_groups;
	const struct attribute_group___351 **drv_groups;
	int (*match)(struct device___354 *, struct device_driver___354 *);
	int (*uevent)(struct device___354 *, struct kobj_uevent_env *);
	int (*probe)(struct device___354 *);
	int (*remove)(struct device___354 *);
	void (*shutdown)(struct device___354 *);
	int (*online)(struct device___354 *);
	int (*offline)(struct device___354 *);
	int (*suspend)(struct device___354 *, pm_message_t);
	int (*resume)(struct device___354 *);
	int (*num_vf)(struct device___354 *);
	int (*dma_configure)(struct device___354 *);
	const struct dev_pm_ops___354 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___354 {
	const char *name;
	struct bus_type___354 *bus;
	struct module___316 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___354 *);
	int (*remove)(struct device___354 *);
	void (*shutdown)(struct device___354 *);
	int (*suspend)(struct device___354 *, pm_message_t);
	int (*resume)(struct device___354 *);
	const struct attribute_group___351 **groups;
	const struct dev_pm_ops___354 *pm;
	void (*coredump)(struct device___354 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___354 {
	const char *name;
	const struct attribute_group___351 **groups;
	int (*uevent)(struct device___354 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___354 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___354 *);
	const struct dev_pm_ops___354 *pm;
};

struct class___354 {
	const char *name;
	struct module___316 *owner;
	const struct attribute_group___351 **class_groups;
	const struct attribute_group___351 **dev_groups;
	struct kobject___374 *dev_kobj;
	int (*dev_uevent)(struct device___354 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___354 *, umode_t *);
	void (*class_release)(struct class___354 *);
	void (*dev_release)(struct device___354 *);
	int (*shutdown_pre)(struct device___354 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___354 *);
	const struct dev_pm_ops___354 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct device_attribute___56 {
	struct attribute attr;
	ssize_t (*show)(struct device___354 *, struct device_attribute___56 *, char *);
	ssize_t (*store)(struct device___354 *, struct device_attribute___56 *, const char *, size_t);
};

struct dma_map_ops___135 {
	void * (*alloc)(struct device___354 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___354 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___354 *, struct vm_area_struct___387 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___354 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___354 *, struct page___387 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___354 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___354 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___354 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___354 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___354 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___354 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___354 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___354 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___354 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___354 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___354 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___354 *, u64);
	u64 (*get_required_mask)(struct device___354 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___275;

struct fwnode_handle___275 {
	struct fwnode_handle___275 *secondary;
	const struct fwnode_operations___275 *ops;
};

struct property___87;

struct device_node___91 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___275 fwnode;
	struct property___87 *properties;
	struct property___87 *deadprops;
	struct device_node___91 *parent;
	struct device_node___91 *child;
	struct device_node___91 *sibling;
	struct kobject___374 kobj;
	long unsigned int _flags;
	void *data;
};

struct fwnode_reference_args___275;

struct fwnode_endpoint___275;

struct fwnode_operations___275 {
	struct fwnode_handle___275 * (*get)(struct fwnode_handle___275 *);
	void (*put)(struct fwnode_handle___275 *);
	bool (*device_is_available)(const struct fwnode_handle___275 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___275 *, const struct device___354 *);
	bool (*property_present)(const struct fwnode_handle___275 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___275 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___275 *, const char *, const char **, size_t);
	struct fwnode_handle___275 * (*get_parent)(const struct fwnode_handle___275 *);
	struct fwnode_handle___275 * (*get_next_child_node)(const struct fwnode_handle___275 *, struct fwnode_handle___275 *);
	struct fwnode_handle___275 * (*get_named_child_node)(const struct fwnode_handle___275 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___275 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___275 *);
	struct fwnode_handle___275 * (*graph_get_next_endpoint)(const struct fwnode_handle___275 *, struct fwnode_handle___275 *);
	struct fwnode_handle___275 * (*graph_get_remote_endpoint)(const struct fwnode_handle___275 *);
	struct fwnode_handle___275 * (*graph_get_port_parent)(struct fwnode_handle___275 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___275 *, struct fwnode_endpoint___275 *);
};

struct fwnode_endpoint___275 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___275 *local_fwnode;
};

struct fwnode_reference_args___275 {
	struct fwnode_handle___275 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct property___87 {
	char *name;
	int length;
	void *value;
	struct property___87 *next;
	long unsigned int _flags;
	struct bin_attribute___350 attr;
};

enum events {
	THERMAL_AUX0 = 0,
	THERMAL_AUX1 = 1,
	THERMAL_CRITICAL = 2,
	THERMAL_DEV_FAULT = 3,
};

enum {
	THERMAL_GENL_ATTR_UNSPEC = 0,
	THERMAL_GENL_ATTR_EVENT = 1,
	__THERMAL_GENL_ATTR_MAX = 2,
};

enum {
	THERMAL_GENL_CMD_UNSPEC = 0,
	THERMAL_GENL_CMD_EVENT = 1,
	__THERMAL_GENL_CMD_MAX = 2,
};

struct thermal_zone_device___6;

struct thermal_cooling_device___6;

struct thermal_zone_device_ops___5 {
	int (*bind)(struct thermal_zone_device___6 *, struct thermal_cooling_device___6 *);
	int (*unbind)(struct thermal_zone_device___6 *, struct thermal_cooling_device___6 *);
	int (*get_temp)(struct thermal_zone_device___6 *, int *);
	int (*set_trips)(struct thermal_zone_device___6 *, int, int);
	int (*get_mode)(struct thermal_zone_device___6 *, enum thermal_device_mode *);
	int (*set_mode)(struct thermal_zone_device___6 *, enum thermal_device_mode);
	int (*get_trip_type)(struct thermal_zone_device___6 *, int, enum thermal_trip_type *);
	int (*get_trip_temp)(struct thermal_zone_device___6 *, int, int *);
	int (*set_trip_temp)(struct thermal_zone_device___6 *, int, int);
	int (*get_trip_hyst)(struct thermal_zone_device___6 *, int, int *);
	int (*set_trip_hyst)(struct thermal_zone_device___6 *, int, int);
	int (*get_crit_temp)(struct thermal_zone_device___6 *, int *);
	int (*set_emul_temp)(struct thermal_zone_device___6 *, int);
	int (*get_trend)(struct thermal_zone_device___6 *, int, enum thermal_trend *);
	int (*notify)(struct thermal_zone_device___6 *, int, enum thermal_trip_type);
};

struct thermal_attr___5;

struct thermal_zone_params___5;

struct thermal_governor___5;

struct thermal_zone_device___6 {
	int id;
	char type[20];
	struct device___354 device;
	struct attribute_group___351 trips_attribute_group;
	struct thermal_attr___5 *trip_temp_attrs;
	struct thermal_attr___5 *trip_type_attrs;
	struct thermal_attr___5 *trip_hyst_attrs;
	void *devdata;
	int trips;
	long unsigned int trips_disabled;
	int passive_delay;
	int polling_delay;
	int temperature;
	int last_temperature;
	int emul_temperature;
	int passive;
	int prev_low_trip;
	int prev_high_trip;
	unsigned int forced_passive;
	atomic_t need_update;
	struct thermal_zone_device_ops___5 *ops;
	struct thermal_zone_params___5 *tzp;
	struct thermal_governor___5 *governor;
	void *governor_data;
	struct list_head thermal_instances;
	struct ida ida;
	struct mutex lock;
	struct list_head node;
	struct delayed_work poll_queue;
	enum thermal_notify_event notify_event;
};

struct thermal_cooling_device_ops___5;

struct thermal_cooling_device___6 {
	int id;
	char type[20];
	struct device___354 device;
	struct device_node___91 *np;
	void *devdata;
	void *stats;
	const struct thermal_cooling_device_ops___5 *ops;
	bool updated;
	struct mutex lock;
	struct list_head thermal_instances;
	struct list_head node;
};

struct thermal_cooling_device_ops___5 {
	int (*get_max_state)(struct thermal_cooling_device___6 *, long unsigned int *);
	int (*get_cur_state)(struct thermal_cooling_device___6 *, long unsigned int *);
	int (*set_cur_state)(struct thermal_cooling_device___6 *, long unsigned int);
	int (*get_requested_power)(struct thermal_cooling_device___6 *, struct thermal_zone_device___6 *, u32 *);
	int (*state2power)(struct thermal_cooling_device___6 *, struct thermal_zone_device___6 *, long unsigned int, u32 *);
	int (*power2state)(struct thermal_cooling_device___6 *, struct thermal_zone_device___6 *, u32, long unsigned int *);
};

struct thermal_attr___5 {
	struct device_attribute___56 attr;
	char name[20];
};

struct thermal_bind_params___5;

struct thermal_zone_params___5 {
	char governor_name[20];
	bool no_hwmon;
	int num_tbps;
	struct thermal_bind_params___5 *tbp;
	u32 sustainable_power;
	s32 k_po;
	s32 k_pu;
	s32 k_i;
	s32 k_d;
	s32 integral_cutoff;
	int slope;
	int offset;
};

struct thermal_governor___5 {
	char name[20];
	int (*bind_to_tz)(struct thermal_zone_device___6 *);
	void (*unbind_from_tz)(struct thermal_zone_device___6 *);
	int (*throttle)(struct thermal_zone_device___6 *, int);
	struct list_head governor_list;
};

struct thermal_bind_params___5 {
	struct thermal_cooling_device___6 *cdev;
	int weight;
	int trip_mask;
	long unsigned int *binding_limits;
	int (*match)(struct thermal_zone_device___6 *, struct thermal_cooling_device___6 *);
};

struct thermal_genl_event {
	u32 orig;
	enum events event;
};

struct address_space_operations___386;

struct address_space___386 {
	struct inode___386 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___388 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___386 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___375)(struct vm_area_struct___387 *, long unsigned int, const struct page___387 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___375)(struct page___387 *, void *);

struct dev_pagemap___375 {
	dev_page_fault_t___375 page_fault;
	dev_page_free_t___375 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___354 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___387 {
	struct task_struct___388 *task;
	struct core_thread___387 *next;
};

struct core_state___387 {
	atomic_t nr_threads;
	struct core_thread___387 dumper;
	struct completion startup;
};

struct vm_fault___375 {
	struct vm_area_struct___387 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___387 *cow_page;
	struct mem_cgroup___135 *memcg;
	struct page___387 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___387 prealloc_pte;
};

struct bio_vec___191 {
	struct page___387 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___161 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___191 *bvec;
		struct pipe_inode_info___80 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct kiocb___386 {
	struct file___386 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___386 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dentry_operations___386;

struct super_block___386;

struct dentry___386 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___386 *d_parent;
	struct qstr d_name;
	struct inode___386 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___386 *d_op;
	struct super_block___386 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___386;

struct block_device___386;

struct inode___386 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___386 *i_op;
	struct super_block___386 *i_sb;
	struct address_space___386 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___388 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___189 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___386 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___386 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___80 *i_pipe;
		struct block_device___386 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___386 {
	int (*d_revalidate)(struct dentry___386 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___386 *, unsigned int);
	int (*d_hash)(const struct dentry___386 *, struct qstr *);
	int (*d_compare)(const struct dentry___386 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___386 *);
	int (*d_init)(struct dentry___386 *);
	void (*d_release)(struct dentry___386 *);
	void (*d_prune)(struct dentry___386 *);
	void (*d_iput)(struct dentry___386 *, struct inode___386 *);
	char * (*d_dname)(struct dentry___386 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___387 *);
	int (*d_manage)(const struct path___387 *, bool);
	struct dentry___386 * (*d_real)(struct dentry___386 *, const struct inode___386 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___386;

struct mem_dqinfo___386 {
	struct quota_format_type___386 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___386;

struct quota_info___386 {
	unsigned int flags;
	struct rw_semaphore___388 dqio_sem;
	struct inode___386 *files[3];
	struct mem_dqinfo___386 info[3];
	const struct quota_format_ops___386 *ops[3];
};

struct rcuwait___386 {
	struct task_struct___388 *task;
};

struct percpu_rw_semaphore___386 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___388 rw_sem;
	struct rcuwait___386 writer;
	int readers_block;
};

struct sb_writers___386 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___386 rw_sem[3];
};

struct shrink_control___135;

struct shrinker___135 {
	long unsigned int (*count_objects)(struct shrinker___135 *, struct shrink_control___135 *);
	long unsigned int (*scan_objects)(struct shrinker___135 *, struct shrink_control___135 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___386;

struct super_operations___386;

struct dquot_operations___386;

struct quotactl_ops___386;

struct super_block___386 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___386 *s_type;
	const struct super_operations___386 *s_op;
	const struct dquot_operations___386 *dq_op;
	const struct quotactl_ops___386 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___386 *s_root;
	struct rw_semaphore___388 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___386 *s_bdev;
	struct backing_dev_info___189 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___386 s_dquot;
	struct sb_writers___386 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___386 *s_d_op;
	int cleancache_poolid;
	struct shrinker___135 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___256 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___135 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___135 *memcg;
};

struct iattr___386 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___386 *ia_file;
};

struct dquot___386 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___386 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___386 {
	int qf_fmt_id;
	const struct quota_format_ops___386 *qf_ops;
	struct module___316 *qf_owner;
	struct quota_format_type___386 *qf_next;
};

struct quota_format_ops___386 {
	int (*check_quota_file)(struct super_block___386 *, int);
	int (*read_file_info)(struct super_block___386 *, int);
	int (*write_file_info)(struct super_block___386 *, int);
	int (*free_file_info)(struct super_block___386 *, int);
	int (*read_dqblk)(struct dquot___386 *);
	int (*commit_dqblk)(struct dquot___386 *);
	int (*release_dqblk)(struct dquot___386 *);
	int (*get_next_id)(struct super_block___386 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___386 {
	int (*write_dquot)(struct dquot___386 *);
	struct dquot___386 * (*alloc_dquot)(struct super_block___386 *, int);
	void (*destroy_dquot)(struct dquot___386 *);
	int (*acquire_dquot)(struct dquot___386 *);
	int (*release_dquot)(struct dquot___386 *);
	int (*mark_dirty)(struct dquot___386 *);
	int (*write_info)(struct super_block___386 *, int);
	qsize_t * (*get_reserved_space)(struct inode___386 *);
	int (*get_projid)(struct inode___386 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___386 *, qsize_t *);
	int (*get_next_id)(struct super_block___386 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___386 {
	int (*quota_on)(struct super_block___386 *, int, int, const struct path___387 *);
	int (*quota_off)(struct super_block___386 *, int);
	int (*quota_enable)(struct super_block___386 *, unsigned int);
	int (*quota_disable)(struct super_block___386 *, unsigned int);
	int (*quota_sync)(struct super_block___386 *, int);
	int (*set_info)(struct super_block___386 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___386 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___386 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___386 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___386 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___386 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___152;

struct swap_info_struct___90;

struct address_space_operations___386 {
	int (*writepage)(struct page___387 *, struct writeback_control___152 *);
	int (*readpage)(struct file___386 *, struct page___387 *);
	int (*writepages)(struct address_space___386 *, struct writeback_control___152 *);
	int (*set_page_dirty)(struct page___387 *);
	int (*readpages)(struct file___386 *, struct address_space___386 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___386 *, struct address_space___386 *, loff_t, unsigned int, unsigned int, struct page___387 **, void **);
	int (*write_end)(struct file___386 *, struct address_space___386 *, loff_t, unsigned int, unsigned int, struct page___387 *, void *);
	sector_t (*bmap)(struct address_space___386 *, sector_t);
	void (*invalidatepage)(struct page___387 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___387 *, gfp_t);
	void (*freepage)(struct page___387 *);
	ssize_t (*direct_IO)(struct kiocb___386 *, struct iov_iter___161 *);
	int (*migratepage)(struct address_space___386 *, struct page___387 *, struct page___387 *, enum migrate_mode);
	bool (*isolate_page)(struct page___387 *, isolate_mode_t);
	void (*putback_page)(struct page___387 *);
	int (*launder_page)(struct page___387 *);
	int (*is_partially_uptodate)(struct page___387 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___387 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___386 *, struct page___387 *);
	int (*swap_activate)(struct swap_info_struct___90 *, struct file___386 *, sector_t *);
	void (*swap_deactivate)(struct file___386 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___152 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___189 *wb;
	struct inode___386 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct swap_info_struct___90 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___386 *bdev;
	struct file___386 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___386 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___386 *bd_inode;
	struct super_block___386 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___386 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___189 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___386 {
	struct dentry___386 * (*lookup)(struct inode___386 *, struct dentry___386 *, unsigned int);
	const char * (*get_link)(struct dentry___386 *, struct inode___386 *, struct delayed_call *);
	int (*permission)(struct inode___386 *, int);
	struct posix_acl * (*get_acl)(struct inode___386 *, int);
	int (*readlink)(struct dentry___386 *, char *, int);
	int (*create)(struct inode___386 *, struct dentry___386 *, umode_t, bool);
	int (*link)(struct dentry___386 *, struct inode___386 *, struct dentry___386 *);
	int (*unlink)(struct inode___386 *, struct dentry___386 *);
	int (*symlink)(struct inode___386 *, struct dentry___386 *, const char *);
	int (*mkdir)(struct inode___386 *, struct dentry___386 *, umode_t);
	int (*rmdir)(struct inode___386 *, struct dentry___386 *);
	int (*mknod)(struct inode___386 *, struct dentry___386 *, umode_t, dev_t);
	int (*rename)(struct inode___386 *, struct dentry___386 *, struct inode___386 *, struct dentry___386 *, unsigned int);
	int (*setattr)(struct dentry___386 *, struct iattr___386 *);
	int (*getattr)(const struct path___387 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___386 *, char *, size_t);
	int (*fiemap)(struct inode___386 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___386 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___386 *, struct dentry___386 *, struct file___386 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___386 *, struct dentry___386 *, umode_t);
	int (*set_acl)(struct inode___386 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___386 {
	void (*fl_copy_lock)(struct file_lock___386 *, struct file_lock___386 *);
	void (*fl_release_private)(struct file_lock___386 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___386;

struct file_lock___386 {
	struct file_lock___386 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___386 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___386 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___386 *fl_ops;
	const struct lock_manager_operations___386 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___386 {
	int (*lm_compare_owner)(struct file_lock___386 *, struct file_lock___386 *);
	long unsigned int (*lm_owner_key)(struct file_lock___386 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___386 *);
	int (*lm_grant)(struct file_lock___386 *, int);
	bool (*lm_break)(struct file_lock___386 *);
	int (*lm_change)(struct file_lock___386 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___386 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___386 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___386 *fa_next;
	struct file___386 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___386 {
	const char *name;
	int fs_flags;
	struct dentry___386 * (*mount)(struct file_system_type___386 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___386 *);
	struct module___316 *owner;
	struct file_system_type___386 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___386 {
	struct inode___386 * (*alloc_inode)(struct super_block___386 *);
	void (*destroy_inode)(struct inode___386 *);
	void (*dirty_inode)(struct inode___386 *, int);
	int (*write_inode)(struct inode___386 *, struct writeback_control___152 *);
	int (*drop_inode)(struct inode___386 *);
	void (*evict_inode)(struct inode___386 *);
	void (*put_super)(struct super_block___386 *);
	int (*sync_fs)(struct super_block___386 *, int);
	int (*freeze_super)(struct super_block___386 *);
	int (*freeze_fs)(struct super_block___386 *);
	int (*thaw_super)(struct super_block___386 *);
	int (*unfreeze_fs)(struct super_block___386 *);
	int (*statfs)(struct dentry___386 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___386 *, int *, char *);
	void (*umount_begin)(struct super_block___386 *);
	int (*show_options)(struct seq_file___328 *, struct dentry___386 *);
	int (*show_devname)(struct seq_file___328 *, struct dentry___386 *);
	int (*show_path)(struct seq_file___328 *, struct dentry___386 *);
	int (*show_stats)(struct seq_file___328 *, struct dentry___386 *);
	ssize_t (*quota_read)(struct super_block___386 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___386 *, int, const char *, size_t, loff_t);
	struct dquot___386 ** (*get_dquots)(struct inode___386 *);
	int (*bdev_try_to_free_page)(struct super_block___386 *, struct page___387 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___386 *, struct shrink_control___135 *);
	long int (*free_cached_objects)(struct super_block___386 *, struct shrink_control___135 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___189(struct bio___189 *);

struct bio_integrity_payload___189;

struct bio_set___189;

struct bio___189 {
	struct bio___189 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___189 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___189 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___191 *bi_io_vec;
	struct bio_set___189 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___191 bi_inline_vecs[0];
};

struct dst_ops___55 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___55 *);
	struct dst_entry___2 * (*check)(struct dst_entry___2 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___2 *);
	unsigned int (*mtu)(const struct dst_entry___2 *);
	u32 * (*cow_metrics)(struct dst_entry___2 *, long unsigned int);
	void (*destroy)(struct dst_entry___2 *);
	void (*ifdown)(struct dst_entry___2 *, struct net_device *, int);
	struct dst_entry___2 * (*negative_advice)(struct dst_entry___2 *);
	void (*link_failure)(struct sk_buff___46 *);
	void (*update_pmtu)(struct dst_entry___2 *, struct sock *, struct sk_buff___46 *, u32);
	void (*redirect)(struct dst_entry___2 *, struct sock *, struct sk_buff___46 *);
	int (*local_out)(struct net___56 *, struct sock *, struct sk_buff___46 *);
	struct neighbour___2 * (*neigh_lookup)(const struct dst_entry___2 *, struct sk_buff___46 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___2 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___55 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___44 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___55 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct sock *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops *notifier_ops;
	struct fib_notifier_ops *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_xfrm___55 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___55 xfrm4_dst_ops;
	struct dst_ops___55 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct net___56 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___256 *user_ns;
	struct ucounts___256 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___9 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___44 ipv4;
	struct netns_ipv6___55 ipv6;
	struct netns_sctp___30 sctp;
	struct netns_nf nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___44 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock *nfnl;
	struct sock *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___55 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef void compound_page_dtor___375(struct page___387 *);

struct pipe_buf_operations___80;

struct pipe_buffer___80 {
	struct page___387 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___80 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___80 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___80 *, struct pipe_buffer___80 *);
	void (*release)(struct pipe_inode_info___80 *, struct pipe_buffer___80 *);
	int (*steal)(struct pipe_inode_info___80 *, struct pipe_buffer___80 *);
	union {
		bool (*get)(struct pipe_inode_info___80 *, struct pipe_buffer___80 *);
		struct {
			void (*get)(struct pipe_inode_info___80 *, struct pipe_buffer___80 *);
		} __UNIQUE_ID_rh_kabi_hide21;
		union {		};
	};
};

typedef int (*key_restrict_link_func_t___357)(struct key___356 *, const struct key_type *, const union key_payload *, struct key___356 *);

struct key_restriction___356;

struct key___356 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___388 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___356 *restrict_link;
};

struct key_restriction___356 {
	key_restrict_link_func_t___357 check;
	struct key___356 *key;
	struct key_type *keytype;
};

struct cgroup_namespace___240 {
	refcount_t count;
	struct ns_common___9 ns;
	struct user_namespace___256 *user_ns;
	struct ucounts___256 *ucounts;
	struct css_set___240 *root_cset;
};

struct netlink_callback___46 {
	struct sk_buff___46 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___46 *);
	int (*dump)(struct sk_buff___46 *, struct netlink_callback___46 *);
	int (*done)(struct netlink_callback___46 *);
	void *data;
	struct module___316 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct ucounts___256 {
	struct hlist_node node;
	struct user_namespace___256 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct seq_operations___328 {
	void * (*start)(struct seq_file___328 *, loff_t *);
	void (*stop)(struct seq_file___328 *, void *);
	void * (*next)(struct seq_file___328 *, void *, loff_t *);
	int (*show)(struct seq_file___328 *, void *);
};

typedef struct {
	struct net___56 *net;
} possible_net_t___46;

struct genl_ops___3;

struct genl_info___2;

struct genl_family___3 {
	int id;
	unsigned int hdrsize;
	char name[16];
	unsigned int version;
	unsigned int maxattr;
	bool netnsok;
	bool parallel_ops;
	int (*pre_doit)(const struct genl_ops___3 *, struct sk_buff___46 *, struct genl_info___2 *);
	void (*post_doit)(const struct genl_ops___3 *, struct sk_buff___46 *, struct genl_info___2 *);
	int (*mcast_bind)(struct net___56 *, int);
	void (*mcast_unbind)(struct net___56 *, int);
	struct nlattr **attrbuf;
	const struct genl_ops___3 *ops;
	const struct genl_multicast_group *mcgrps;
	unsigned int n_ops;
	unsigned int n_mcgrps;
	unsigned int mcgrp_offset;
	struct module___316 *module;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct genl_ops___3 {
	const struct nla_policy *policy;
	int (*doit)(struct sk_buff___46 *, struct genl_info___2 *);
	int (*start)(struct netlink_callback___46 *);
	int (*dumpit)(struct sk_buff___46 *, struct netlink_callback___46 *);
	int (*done)(struct netlink_callback___46 *);
	u8 cmd;
	u8 internal_flags;
	u8 flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t genl_ops_extended_size_rh;
	struct genl_ops_extended_rh genl_ops_extended_rh;
};

struct genl_info___2 {
	u32 snd_seq;
	u32 snd_portid;
	struct nlmsghdr *nlhdr;
	struct genlmsghdr *genlhdr;
	void *userhdr;
	struct nlattr **attrs;
	possible_net_t___46 _net;
	void *user_ptr[2];
	struct netlink_ext_ack *extack;
};

struct bpf_map___241;

struct bpf_map_ops___240 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___241 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___241 *, struct file___386 *);
	void (*map_free)(struct bpf_map___241 *);
	int (*map_get_next_key)(struct bpf_map___241 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___241 *);
	void * (*map_lookup_elem)(struct bpf_map___241 *, void *);
	int (*map_update_elem)(struct bpf_map___241 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___241 *, void *);
	int (*map_push_elem)(struct bpf_map___241 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___241 *, void *);
	int (*map_peek_elem)(struct bpf_map___241 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___241 *, struct file___386 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___241 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___241 *, void *, struct seq_file___328 *);
	int (*map_check_btf)(const struct bpf_map___241 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___241 {
	const struct bpf_map_ops___240 *ops;
	struct bpf_map___241 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___356 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___241;

typedef void (*kthread_work_func_t___241)(struct kthread_work___241 *);

struct kthread_worker___241;

struct kthread_work___241 {
	struct list_head node;
	kthread_work_func_t___241 func;
	struct kthread_worker___241 *worker;
	int canceling;
};

struct kthread_worker___241 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___388 *task;
	struct kthread_work___241 *current_work;
};

struct kthread_delayed_work___240 {
	struct kthread_work___241 work;
	struct timer_list timer;
};

struct psi_group___240 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___241 *poll_kworker;
	struct kthread_delayed_work___240 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___240;

struct cgroup_rstat_cpu___240;

struct cgroup___240 {
	struct cgroup_subsys_state___240 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___381 *kn;
	struct cgroup_file___240 procs_file;
	struct cgroup_file___240 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___240 *subsys[13];
	struct cgroup_root___240 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___240 *dom_cgrp;
	struct cgroup_rstat_cpu___240 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___39 bpf;
	atomic_t congestion_count;
	struct cgroup___240 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___240 psi;
	int ancestor_ids[0];
};

struct cftype___240;

struct cgroup_subsys___240 {
	struct cgroup_subsys_state___240 * (*css_alloc)(struct cgroup_subsys_state___240 *);
	int (*css_online)(struct cgroup_subsys_state___240 *);
	void (*css_offline)(struct cgroup_subsys_state___240 *);
	void (*css_released)(struct cgroup_subsys_state___240 *);
	void (*css_free)(struct cgroup_subsys_state___240 *);
	void (*css_reset)(struct cgroup_subsys_state___240 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___240 *, int);
	int (*css_extra_stat_show)(struct seq_file___328 *, struct cgroup_subsys_state___240 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___388 *);
	void (*cancel_fork)(struct task_struct___388 *);
	void (*fork)(struct task_struct___388 *);
	void (*exit)(struct task_struct___388 *);
	void (*free)(struct task_struct___388 *);
	void (*bind)(struct cgroup_subsys_state___240 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___240 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___240 *dfl_cftypes;
	struct cftype___240 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___240 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___240 *updated_children;
	struct cgroup___240 *updated_next;
};

struct cgroup_root___240 {
	struct kernfs_root___380 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___240 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___240 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___240 *ss;
	struct list_head node;
	struct kernfs_ops___380 *kf_ops;
	int (*open)(struct kernfs_open_file___380 *);
	void (*release)(struct kernfs_open_file___380 *);
	u64 (*read_u64)(struct cgroup_subsys_state___240 *, struct cftype___240 *);
	s64 (*read_s64)(struct cgroup_subsys_state___240 *, struct cftype___240 *);
	int (*seq_show)(struct seq_file___328 *, void *);
	void * (*seq_start)(struct seq_file___328 *, loff_t *);
	void * (*seq_next)(struct seq_file___328 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___328 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___240 *, struct cftype___240 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___240 *, struct cftype___240 *, s64);
	ssize_t (*write)(struct kernfs_open_file___380 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___380 *, struct poll_table_struct___234 *);
};

struct bdi_writeback_congested___189 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___189 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___189 {
	struct bio___189 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___191 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___191 bip_inline_vecs[0];
};

struct bio_set___189 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___189 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___135 {
	struct mem_cgroup___135 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___135 {
	struct lruvec___387 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___135 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___135 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct node___214 {
	struct device___354 dev;
};

struct perf_cpu_context___148;

struct pmu___148 {
	struct list_head entry;
	struct module___316 *module;
	struct device___354 *dev;
	const struct attribute_group___351 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___148 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___148 *);
	void (*pmu_disable)(struct pmu___148 *);
	int (*event_init)(struct perf_event___148 *);
	void (*event_mapped)(struct perf_event___148 *, struct mm_struct___387 *);
	void (*event_unmapped)(struct perf_event___148 *, struct mm_struct___387 *);
	int (*add)(struct perf_event___148 *, int);
	void (*del)(struct perf_event___148 *, int);
	void (*start)(struct perf_event___148 *, int);
	void (*stop)(struct perf_event___148 *, int);
	void (*read)(struct perf_event___148 *);
	void (*start_txn)(struct pmu___148 *, unsigned int);
	int (*commit_txn)(struct pmu___148 *);
	void (*cancel_txn)(struct pmu___148 *);
	int (*event_idx)(struct perf_event___148 *);
	void (*sched_task)(struct perf_event_context___148 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___148 *);
	int (*filter_match)(struct perf_event___148 *);
	int (*check_period)(struct perf_event___148 *, u64);
};

struct perf_cpu_context___148 {
	struct perf_event_context___148 ctx;
	struct perf_event_context___148 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___148 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___148 {
	struct cgroup_subsys_state___240 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___141 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___141 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___141 *);
	struct list_head * (*get_fields)(struct trace_event_call___141 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___141 *);
};

struct trace_event_file___60;

struct trace_event_buffer___52 {
	struct ring_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___60 *trace_file;
	void *entry;
	long unsigned int flags;
	int pc;
};

struct trace_event_file___60 {
	struct list_head list;
	struct trace_event_call___141 *event_call;
	struct event_filter *filter;
	struct dentry___386 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_thermal_temperature {
	struct trace_entry ent;
	u32 __data_loc_thermal_zone;
	int id;
	int temp_prev;
	int temp;
	char __data[0];
};

struct trace_event_raw_cdev_update {
	struct trace_entry ent;
	u32 __data_loc_type;
	long unsigned int target;
	char __data[0];
};

struct trace_event_raw_thermal_zone_trip {
	struct trace_entry ent;
	u32 __data_loc_thermal_zone;
	int id;
	int trip;
	enum thermal_trip_type trip_type;
	char __data[0];
};

struct trace_event_data_offsets_thermal_temperature {
	u32 thermal_zone;
};

struct trace_event_data_offsets_cdev_update {
	u32 type;
};

struct trace_event_data_offsets_thermal_zone_trip {
	u32 thermal_zone;
};

struct thermal_instance {
	int id;
	char name[20];
	struct thermal_zone_device___6 *tz;
	struct thermal_cooling_device___6 *cdev;
	int trip;
	bool initialized;
	long unsigned int upper;
	long unsigned int lower;
	long unsigned int target;
	char attr_name[20];
	struct device_attribute___56 attr;
	char weight_attr_name[20];
	struct device_attribute___56 weight_attr;
	struct list_head tz_node;
	struct list_head cdev_node;
	unsigned int weight;
};

struct thermal_hwmon_device {
	char type[20];
	struct device___354 *device;
	int count;
	struct list_head tz_list;
	struct list_head node;
};

struct thermal_hwmon_attr {
	struct device_attribute___56 attr;
	char name[16];
};

struct thermal_hwmon_temp {
	struct list_head hwmon_node;
	struct thermal_zone_device___6 *tz;
	struct thermal_hwmon_attr temp_input;
	struct thermal_hwmon_attr temp_crit;
};

struct thermal_zone_of_device_ops {
	int (*get_temp)(void *, int *);
	int (*get_trend)(void *, int, enum thermal_trend *);
	int (*set_trips)(void *, int, int);
	int (*set_emul_temp)(void *, int);
	int (*set_trip_temp)(void *, int, int);
};

struct ns_thermal {
	struct thermal_zone_device___6 *tz;
	void *pvtmon;
};

typedef void (*dr_release_t___27)(struct device___354 *, void *);

struct watchdog_info {
	__u32 options;
	__u32 firmware_version;
	__u8 identity[32];
};

struct watchdog_device;

struct watchdog_ops {
	struct module___316 *owner;
	int (*start)(struct watchdog_device *);
	int (*stop)(struct watchdog_device *);
	int (*ping)(struct watchdog_device *);
	unsigned int (*status)(struct watchdog_device *);
	int (*set_timeout)(struct watchdog_device *, unsigned int);
	int (*set_pretimeout)(struct watchdog_device *, unsigned int);
	unsigned int (*get_timeleft)(struct watchdog_device *);
	int (*restart)(struct watchdog_device *, long unsigned int, void *);
	long int (*ioctl)(struct watchdog_device *, unsigned int, long unsigned int);
};

struct watchdog_governor;

struct watchdog_core_data;

struct watchdog_device {
	int id;
	struct device___354 *parent;
	const struct attribute_group___351 **groups;
	const struct watchdog_info *info;
	const struct watchdog_ops *ops;
	const struct watchdog_governor *gov;
	unsigned int bootstatus;
	unsigned int timeout;
	unsigned int pretimeout;
	unsigned int min_timeout;
	unsigned int max_timeout;
	unsigned int min_hw_heartbeat_ms;
	unsigned int max_hw_heartbeat_ms;
	struct notifier_block reboot_nb;
	struct notifier_block restart_nb;
	void *driver_data;
	struct watchdog_core_data *wd_data;
	long unsigned int status;
	struct list_head deferred;
};

struct miscdevice___8 {
	int minor;
	const char *name;
	const struct file_operations___2 *fops;
	struct list_head list;
	struct device___352 *parent;
	struct device___352 *this_device;
	const struct attribute_group___349 **groups;
	const char *nodename;
	umode_t mode;
};

struct watchdog_device___2;

struct watchdog_ops___2 {
	struct module___2 *owner;
	int (*start)(struct watchdog_device___2 *);
	int (*stop)(struct watchdog_device___2 *);
	int (*ping)(struct watchdog_device___2 *);
	unsigned int (*status)(struct watchdog_device___2 *);
	int (*set_timeout)(struct watchdog_device___2 *, unsigned int);
	int (*set_pretimeout)(struct watchdog_device___2 *, unsigned int);
	unsigned int (*get_timeleft)(struct watchdog_device___2 *);
	int (*restart)(struct watchdog_device___2 *, long unsigned int, void *);
	long int (*ioctl)(struct watchdog_device___2 *, unsigned int, long unsigned int);
};

struct watchdog_governor___2;

struct watchdog_core_data___2;

struct watchdog_device___2 {
	int id;
	struct device___352 *parent;
	const struct attribute_group___349 **groups;
	const struct watchdog_info *info;
	const struct watchdog_ops___2 *ops;
	const struct watchdog_governor___2 *gov;
	unsigned int bootstatus;
	unsigned int timeout;
	unsigned int pretimeout;
	unsigned int min_timeout;
	unsigned int max_timeout;
	unsigned int min_hw_heartbeat_ms;
	unsigned int max_hw_heartbeat_ms;
	struct notifier_block reboot_nb;
	struct notifier_block restart_nb;
	void *driver_data;
	struct watchdog_core_data___2 *wd_data;
	long unsigned int status;
	struct list_head deferred;
};

struct watchdog_governor___2 {
	const char name[20];
	void (*pretimeout)(struct watchdog_device___2 *);
};

struct watchdog_core_data___2 {
	struct kref kref;
	struct cdev___97 cdev;
	struct watchdog_device___2 *wdd;
	struct mutex lock;
	ktime_t last_keepalive;
	ktime_t last_hw_keepalive;
	struct hrtimer timer;
	struct kthread_work___239 work;
	long unsigned int status;
};

struct module___317;

struct file___387;

struct kiocb___387;

struct iov_iter___162;

struct poll_table_struct___235;

struct vm_area_struct___388;

struct inode___387;

struct file_lock___387;

struct page___388;

struct seq_file___329;

struct file_operations___387 {
	struct module___317 *owner;
	loff_t (*llseek)(struct file___387 *, loff_t, int);
	ssize_t (*read)(struct file___387 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___387 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___387 *, struct iov_iter___162 *);
	ssize_t (*write_iter)(struct kiocb___387 *, struct iov_iter___162 *);
	int (*iopoll)(struct kiocb___387 *, bool);
	int (*iterate)(struct file___387 *, struct dir_context *);
	int (*iterate_shared)(struct file___387 *, struct dir_context *);
	__poll_t (*poll)(struct file___387 *, struct poll_table_struct___235 *);
	long int (*unlocked_ioctl)(struct file___387 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___387 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___387 *, struct vm_area_struct___388 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___387 *, struct file___387 *);
	int (*flush)(struct file___387 *, fl_owner_t);
	int (*release)(struct inode___387 *, struct file___387 *);
	int (*fsync)(struct file___387 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___387 *, int);
	int (*lock)(struct file___387 *, int, struct file_lock___387 *);
	ssize_t (*sendpage)(struct file___387 *, struct page___388 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___387 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___387 *, int, struct file_lock___387 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___387 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___387 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___387 *, long int, struct file_lock___387 **, void **);
	long int (*fallocate)(struct file___387 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___329 *, struct file___387 *);
	ssize_t (*copy_file_range)(struct file___387 *, loff_t, struct file___387 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___387 *, loff_t, struct file___387 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___387 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___388 {
	u64 seqnum;
	struct vm_area_struct___388 *vmas[4];
};

struct page_frag___388 {
	struct page___388 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___388;

struct cred___357;

struct nsproxy___286;

struct signal_struct___267;

struct bio_list___190;

struct backing_dev_info___190;

struct io_context___108;

struct css_set___241;

struct request_queue___104;

struct vm_struct___292;

struct task_struct___389 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___389 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___388 *mm;
	struct mm_struct___388 *active_mm;
	struct vmacache___388 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___389 *real_parent;
	struct task_struct___389 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___389 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___224 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___224 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___224 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___357 *ptracer_cred;
	const struct cred___357 *real_cred;
	const struct cred___357 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___286 *nsproxy;
	struct signal_struct___267 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___389 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___190 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___190 *backing_dev_info;
	struct io_context___108 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___241 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___388 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___104 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___389 *oom_reaper_list;
	struct vm_struct___292 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___148 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rw_semaphore___389 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___389 *owner;
};

struct key___357;

struct ucounts___257;

struct user_namespace___257 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___257 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___9 ns;
	long unsigned int flags;
	struct key___357 *persistent_keyring_register;
	struct rw_semaphore___389 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___257 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct secondary_data___389 {
	void *stack;
	struct task_struct___389 *task;
	long int status;
};

typedef struct page___388 *pgtable_t___388;

struct address_space___387;

struct dev_pagemap___376;

struct page___388 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___387 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___388 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___388 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___388 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___376 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct user_struct___357 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___357 *uid_keyring;
	struct key___357 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___376;

struct vm_area_struct___388 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___388 *vm_next;
	struct vm_area_struct___388 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___388 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___376 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___387 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___388;

struct mm_struct___388 {
	struct {
		struct vm_area_struct___388 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___387 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___389 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___388 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___389 *owner;
		struct user_namespace___257 *user_ns;
		struct file___387 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___388 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___357 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___357 *session_keyring;
	struct key___357 *process_keyring;
	struct key___357 *thread_keyring;
	struct key___357 *request_key_auth;
	void *security;
	struct user_struct___357 *user;
	struct user_namespace___257 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___241;

struct nsproxy___286 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___241 *cgroup_ns;
};

struct signal_struct___267 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___389 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___389 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___224 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___224 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___388 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___224 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___190;

struct bio_list___190 {
	struct bio___190 *head;
	struct bio___190 *tail;
};

struct bdi_writeback_congested___190;

struct cgroup_subsys_state___241;

struct bdi_writeback___190 {
	struct backing_dev_info___190 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___190 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___241 *memcg_css;
	struct cgroup_subsys_state___241 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___355;

struct dentry___387;

struct backing_dev_info___190 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___190 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___355 *dev;
	struct device___355 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___387 *debug_dir;
	struct dentry___387 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___108;

struct io_context___108 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___108 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___241;

struct css_set___241 {
	struct cgroup_subsys_state___241 *subsys[13];
	refcount_t refcount;
	struct css_set___241 *dom_cset;
	struct cgroup___241 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___241 *mg_src_cgrp;
	struct cgroup___241 *mg_dst_cgrp;
	struct css_set___241 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

typedef blk_qc_t make_request_fn___104(struct request_queue___104 *, struct bio___190 *);

struct request___104;

typedef int dma_drain_needed_fn___104(struct request___104 *);

struct kset___374;

struct kobj_type___374;

struct kernfs_node___382;

struct kobject___375 {
	const char *name;
	struct list_head entry;
	struct kobject___375 *parent;
	struct kset___374 *kset;
	struct kobj_type___374 *ktype;
	struct kernfs_node___382 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___104;

struct bsg_class_device___104 {
	struct device___355 *class_dev;
	int minor;
	struct request_queue___104 *queue;
	const struct bsg_ops___104 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___190 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___190 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___104;

struct blkcg_gq___57;

struct blk_trace___10;

struct request_queue___104 {
	struct list_head queue_head;
	struct request___104 *last_merge;
	struct elevator_queue___104 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___104 *make_request_fn;
	dma_drain_needed_fn___104 *dma_drain_needed;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___190 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___375 kobj;
	struct kobject___375 *mq_kobj;
	struct blk_integrity integrity;
	struct device___355 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___57 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace___10 *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	struct bsg_class_device___104 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___190 bio_split;
	struct dentry___387 *debugfs_dir;
	struct dentry___387 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___292 {
	struct vm_struct___292 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___388 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___279 {
	struct task_struct___389 task;
	long unsigned int stack[8192];
};

struct address_space_operations___387;

struct address_space___387 {
	struct inode___387 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___389 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___387 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___376)(struct vm_area_struct___388 *, long unsigned int, const struct page___388 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___376)(struct page___388 *, void *);

struct dev_pagemap___376 {
	dev_page_fault_t___376 page_fault;
	dev_page_free_t___376 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___355 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___388 {
	struct vfsmount *mnt;
	struct dentry___387 *dentry;
};

struct file___387 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___388 f_path;
	struct inode___387 *f_inode;
	const struct file_operations___387 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___224 f_owner;
	const struct cred___357 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___387 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___376;

struct vm_operations_struct___376 {
	void (*open)(struct vm_area_struct___388 *);
	void (*close)(struct vm_area_struct___388 *);
	int (*split)(struct vm_area_struct___388 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___388 *);
	vm_fault_t (*fault)(struct vm_fault___376 *);
	vm_fault_t (*huge_fault)(struct vm_fault___376 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___376 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___388 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___376 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___376 *);
	int (*access)(struct vm_area_struct___388 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___388 *);
	int (*set_policy)(struct vm_area_struct___388 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___388 *, long unsigned int);
	struct page___388 * (*find_special_page)(struct vm_area_struct___388 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___388 {
	struct task_struct___389 *task;
	struct core_thread___388 *next;
};

struct core_state___388 {
	atomic_t nr_threads;
	struct core_thread___388 dumper;
	struct completion startup;
};

struct vm_fault___376 {
	struct vm_area_struct___388 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___388 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___388 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___388 prealloc_pte;
};

struct pglist_data___388;

struct lruvec___388 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___388 *pgdat;
};

struct zone___388 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___388 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___388 {
	struct zone___388 *zone;
	int zone_idx;
};

struct zonelist___388 {
	struct zoneref___388 _zonerefs[25];
};

struct pglist_data___388 {
	struct zone___388 node_zones[3];
	struct zonelist___388 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___389 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___389 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___388 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___388 {
	struct rw_semaphore___389 rwsem;
	struct notifier_block *head;
};

typedef int (*key_restrict_link_func_t___358)(struct key___357 *, const struct key_type *, const union key_payload *, struct key___357 *);

struct key_restriction___357;

struct key___357 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___389 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___357 *restrict_link;
};

struct key_restriction___357 {
	key_restrict_link_func_t___358 check;
	struct key___357 *key;
	struct key_type *keytype;
};

struct kthread_work___242;

typedef void (*kthread_work_func_t___242)(struct kthread_work___242 *);

struct kthread_worker___242;

struct kthread_work___242 {
	struct list_head node;
	kthread_work_func_t___242 func;
	struct kthread_worker___242 *worker;
	int canceling;
};

struct kthread_worker___242 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___389 *task;
	struct kthread_work___242 *current_work;
};

struct kthread_delayed_work___241 {
	struct kthread_work___242 work;
	struct timer_list timer;
};

struct bio_vec___192 {
	struct page___388 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

typedef void bio_end_io_t___190(struct bio___190 *);

struct gendisk___108;

struct bio_integrity_payload___190;

struct bio___190 {
	struct bio___190 *bi_next;
	struct gendisk___108 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___190 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___57 *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___190 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___192 *bi_io_vec;
	struct bio_set___190 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___192 bi_inline_vecs[0];
};

struct bio_integrity_payload___190 {
	struct bio___190 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___192 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___192 bip_inline_vecs[0];
};

struct dev_pm_info___355 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___355 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___355;

struct bus_type___355;

struct device_driver___355;

struct dev_pm_domain___355;

struct fwnode_handle___276;

struct class___355;

struct attribute_group___352;

struct device___355 {
	struct device___355 *parent;
	struct device_private *p;
	struct kobject___375 kobj;
	const char *init_name;
	const struct device_type___355 *type;
	struct mutex mutex;
	struct bus_type___355 *bus;
	struct device_driver___355 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___355 power;
	struct dev_pm_domain___355 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___276 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___355 *class;
	const struct attribute_group___352 **groups;
	void (*release)(struct device___355 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___108 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___355 __dev;
	struct kobject___375 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___108;

struct block_device_operations___105;

struct badblocks___4;

struct gendisk___108 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___108 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___108 *part_tbl;
	struct hd_struct___108 part0;
	const struct block_device_operations___105 *fops;
	struct request_queue___104 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___389 lookup_sem;
	struct kobject___375 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___375 integrity_kobj;
	int node_id;
	struct badblocks___4 *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct blkcg___57;

struct blkg_policy_data___57;

struct blkcg_gq___57 {
	struct request_queue___104 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___57 *blkcg;
	struct bdi_writeback_congested___190 *wb_congested;
	struct blkcg_gq___57 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_rwstat stat_bytes;
	struct blkg_rwstat stat_ios;
	struct blkg_policy_data___57 *pd[5];
	struct callback_head callback_head;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
};

struct dev_pm_ops___355;

struct device_type___355 {
	const char *name;
	const struct attribute_group___352 **groups;
	int (*uevent)(struct device___355 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___355 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___355 *);
	const struct dev_pm_ops___355 *pm;
};

struct class___355 {
	const char *name;
	struct module___317 *owner;
	const struct attribute_group___352 **class_groups;
	const struct attribute_group___352 **dev_groups;
	struct kobject___375 *dev_kobj;
	int (*dev_uevent)(struct device___355 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___355 *, umode_t *);
	void (*class_release)(struct class___355 *);
	void (*dev_release)(struct device___355 *);
	int (*shutdown_pre)(struct device___355 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___355 *);
	const struct dev_pm_ops___355 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct kernfs_root___381;

struct kernfs_elem_dir___381 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___381 *root;
};

struct kernfs_syscall_ops___381;

struct kernfs_root___381 {
	struct kernfs_node___382 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___381 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___381 {
	struct kernfs_node___382 *target_kn;
};

struct kernfs_ops___381;

struct kernfs_elem_attr___381 {
	const struct kernfs_ops___381 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___382 *notify_next;
};

struct kernfs_node___382 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___382 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___381 dir;
		struct kernfs_elem_symlink___381 symlink;
		struct kernfs_elem_attr___381 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___381;

struct kernfs_ops___381 {
	int (*open)(struct kernfs_open_file___381 *);
	void (*release)(struct kernfs_open_file___381 *);
	int (*seq_show)(struct seq_file___329 *, void *);
	void * (*seq_start)(struct seq_file___329 *, loff_t *);
	void * (*seq_next)(struct seq_file___329 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___329 *, void *);
	ssize_t (*read)(struct kernfs_open_file___381 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___381 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___381 *, struct vm_area_struct___388 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___381 *, struct poll_table_struct___235 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___381 {
	int (*remount_fs)(struct kernfs_root___381 *, int *, char *);
	int (*show_options)(struct seq_file___329 *, struct kernfs_root___381 *);
	int (*mkdir)(struct kernfs_node___382 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___382 *);
	int (*rename)(struct kernfs_node___382 *, struct kernfs_node___382 *, const char *);
	int (*show_path)(struct seq_file___329 *, struct kernfs_node___382 *, struct kernfs_root___381 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___329;

struct seq_file___329 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___329 *op;
	int poll_event;
	const struct file___387 *file;
	void *private;
};

struct kernfs_open_file___381 {
	struct kernfs_node___382 *kn;
	struct file___387 *file;
	struct seq_file___329 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___376 *vm_ops;
};

typedef void (*poll_queue_proc___243)(struct file___387 *, wait_queue_head_t *, struct poll_table_struct___235 *);

struct poll_table_struct___235 {
	poll_queue_proc___243 _qproc;
	__poll_t _key;
};

struct bin_attribute___351;

struct attribute_group___352 {
	const char *name;
	umode_t (*is_visible)(struct kobject___375 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___375 *, struct bin_attribute___351 *, int);
	struct attribute **attrs;
	struct bin_attribute___351 **bin_attrs;
};

struct bin_attribute___351 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___387 *, struct kobject___375 *, struct bin_attribute___351 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___387 *, struct kobject___375 *, struct bin_attribute___351 *, char *, loff_t, size_t);
	int (*mmap)(struct file___387 *, struct kobject___375 *, struct bin_attribute___351 *, struct vm_area_struct___388 *);
};

struct sysfs_ops___374 {
	ssize_t (*show)(struct kobject___375 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___375 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___374;

struct kset___374 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___375 kobj;
	const struct kset_uevent_ops___374 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___374 {
	void (*release)(struct kobject___375 *);
	const struct sysfs_ops___374 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___29 * (*child_ns_type)(struct kobject___375 *);
	const void * (*namespace)(struct kobject___375 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___374 {
	int (* const filter)(struct kset___374 *, struct kobject___375 *);
	const char * (* const name)(struct kset___374 *, struct kobject___375 *);
	int (* const uevent)(struct kset___374 *, struct kobject___375 *, struct kobj_uevent_env *);
};

struct kobj_attribute___366 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___375 *, struct kobj_attribute___366 *, char *);
	ssize_t (*store)(struct kobject___375 *, struct kobj_attribute___366 *, const char *, size_t);
};

struct dev_pm_ops___355 {
	int (*prepare)(struct device___355 *);
	void (*complete)(struct device___355 *);
	int (*suspend)(struct device___355 *);
	int (*resume)(struct device___355 *);
	int (*freeze)(struct device___355 *);
	int (*thaw)(struct device___355 *);
	int (*poweroff)(struct device___355 *);
	int (*restore)(struct device___355 *);
	int (*suspend_late)(struct device___355 *);
	int (*resume_early)(struct device___355 *);
	int (*freeze_late)(struct device___355 *);
	int (*thaw_early)(struct device___355 *);
	int (*poweroff_late)(struct device___355 *);
	int (*restore_early)(struct device___355 *);
	int (*suspend_noirq)(struct device___355 *);
	int (*resume_noirq)(struct device___355 *);
	int (*freeze_noirq)(struct device___355 *);
	int (*thaw_noirq)(struct device___355 *);
	int (*poweroff_noirq)(struct device___355 *);
	int (*restore_noirq)(struct device___355 *);
	int (*runtime_suspend)(struct device___355 *);
	int (*runtime_resume)(struct device___355 *);
	int (*runtime_idle)(struct device___355 *);
};

struct dev_pm_domain___355 {
	struct dev_pm_ops___355 ops;
	void (*detach)(struct device___355 *, bool);
	int (*activate)(struct device___355 *);
	void (*sync)(struct device___355 *);
	void (*dismiss)(struct device___355 *);
};

struct bus_type___355 {
	const char *name;
	const char *dev_name;
	struct device___355 *dev_root;
	const struct attribute_group___352 **bus_groups;
	const struct attribute_group___352 **dev_groups;
	const struct attribute_group___352 **drv_groups;
	int (*match)(struct device___355 *, struct device_driver___355 *);
	int (*uevent)(struct device___355 *, struct kobj_uevent_env *);
	int (*probe)(struct device___355 *);
	int (*remove)(struct device___355 *);
	void (*shutdown)(struct device___355 *);
	int (*online)(struct device___355 *);
	int (*offline)(struct device___355 *);
	int (*suspend)(struct device___355 *, pm_message_t);
	int (*resume)(struct device___355 *);
	int (*num_vf)(struct device___355 *);
	int (*dma_configure)(struct device___355 *);
	const struct dev_pm_ops___355 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___355 {
	const char *name;
	struct bus_type___355 *bus;
	struct module___317 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___355 *);
	int (*remove)(struct device___355 *);
	void (*shutdown)(struct device___355 *);
	int (*suspend)(struct device___355 *, pm_message_t);
	int (*resume)(struct device___355 *);
	const struct attribute_group___352 **groups;
	const struct dev_pm_ops___355 *pm;
	void (*coredump)(struct device___355 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct module_kobject___315 {
	struct kobject___375 kobj;
	struct module___317 *mod;
	struct kobject___375 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___315 {
	struct module___317 *mod;
	struct latch_tree_node node;
};

struct module_layout___315 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___315 mtn;
};

struct module_attribute___315;

struct kernel_param___315;

struct module___317 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___315 mkobj;
	struct module_attribute___315 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___375 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___315 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___315 core_layout;
	struct module_layout___315 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide41;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide42;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_operations___276;

struct fwnode_handle___276 {
	struct fwnode_handle___276 *secondary;
	const struct fwnode_operations___276 *ops;
};

struct dentry_operations___387;

struct super_block___387;

struct dentry___387 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___387 *d_parent;
	struct qstr d_name;
	struct inode___387 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___387 *d_op;
	struct super_block___387 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___387;

struct block_device___387;

struct inode___387 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___387 *i_op;
	struct super_block___387 *i_sb;
	struct address_space___387 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___389 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___190 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___387 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___387 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___387 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___387 {
	int (*d_revalidate)(struct dentry___387 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___387 *, unsigned int);
	int (*d_hash)(const struct dentry___387 *, struct qstr *);
	int (*d_compare)(const struct dentry___387 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___387 *);
	int (*d_init)(struct dentry___387 *);
	void (*d_release)(struct dentry___387 *);
	void (*d_prune)(struct dentry___387 *);
	void (*d_iput)(struct dentry___387 *, struct inode___387 *);
	char * (*d_dname)(struct dentry___387 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___388 *);
	int (*d_manage)(const struct path___388 *, bool);
	struct dentry___387 * (*d_real)(struct dentry___387 *, const struct inode___387 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___387;

struct mem_dqinfo___387 {
	struct quota_format_type___387 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___387;

struct quota_info___387 {
	unsigned int flags;
	struct rw_semaphore___389 dqio_sem;
	struct inode___387 *files[3];
	struct mem_dqinfo___387 info[3];
	const struct quota_format_ops___387 *ops[3];
};

struct rcuwait___387 {
	struct task_struct___389 *task;
};

struct percpu_rw_semaphore___387 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___389 rw_sem;
	struct rcuwait___387 writer;
	int readers_block;
};

struct sb_writers___387 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___387 rw_sem[3];
};

struct file_system_type___387;

struct super_operations___387;

struct dquot_operations___387;

struct quotactl_ops___387;

struct super_block___387 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___387 *s_type;
	const struct super_operations___387 *s_op;
	const struct dquot_operations___387 *dq_op;
	const struct quotactl_ops___387 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___387 *s_root;
	struct rw_semaphore___389 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___387 *s_bdev;
	struct backing_dev_info___190 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___387 s_dquot;
	struct sb_writers___387 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___387 *s_d_op;
	int cleancache_poolid;
	struct shrinker___135 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___257 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct io_cq___108 {
	struct request_queue___104 *q;
	struct io_context___108 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___387 {
	struct file___387 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___387 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___387 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___387 *ia_file;
};

struct dquot___387 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___387 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___387 {
	int qf_fmt_id;
	const struct quota_format_ops___387 *qf_ops;
	struct module___317 *qf_owner;
	struct quota_format_type___387 *qf_next;
};

struct quota_format_ops___387 {
	int (*check_quota_file)(struct super_block___387 *, int);
	int (*read_file_info)(struct super_block___387 *, int);
	int (*write_file_info)(struct super_block___387 *, int);
	int (*free_file_info)(struct super_block___387 *, int);
	int (*read_dqblk)(struct dquot___387 *);
	int (*commit_dqblk)(struct dquot___387 *);
	int (*release_dqblk)(struct dquot___387 *);
	int (*get_next_id)(struct super_block___387 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___387 {
	int (*write_dquot)(struct dquot___387 *);
	struct dquot___387 * (*alloc_dquot)(struct super_block___387 *, int);
	void (*destroy_dquot)(struct dquot___387 *);
	int (*acquire_dquot)(struct dquot___387 *);
	int (*release_dquot)(struct dquot___387 *);
	int (*mark_dirty)(struct dquot___387 *);
	int (*write_info)(struct super_block___387 *, int);
	qsize_t * (*get_reserved_space)(struct inode___387 *);
	int (*get_projid)(struct inode___387 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___387 *, qsize_t *);
	int (*get_next_id)(struct super_block___387 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___387 {
	int (*quota_on)(struct super_block___387 *, int, int, const struct path___388 *);
	int (*quota_off)(struct super_block___387 *, int);
	int (*quota_enable)(struct super_block___387 *, unsigned int);
	int (*quota_disable)(struct super_block___387 *, unsigned int);
	int (*quota_sync)(struct super_block___387 *, int);
	int (*set_info)(struct super_block___387 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___387 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___387 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___387 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___387 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___387 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___153;

struct address_space_operations___387 {
	int (*writepage)(struct page___388 *, struct writeback_control___153 *);
	int (*readpage)(struct file___387 *, struct page___388 *);
	int (*writepages)(struct address_space___387 *, struct writeback_control___153 *);
	int (*set_page_dirty)(struct page___388 *);
	int (*readpages)(struct file___387 *, struct address_space___387 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___387 *, struct address_space___387 *, loff_t, unsigned int, unsigned int, struct page___388 **, void **);
	int (*write_end)(struct file___387 *, struct address_space___387 *, loff_t, unsigned int, unsigned int, struct page___388 *, void *);
	sector_t (*bmap)(struct address_space___387 *, sector_t);
	void (*invalidatepage)(struct page___388 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___388 *, gfp_t);
	void (*freepage)(struct page___388 *);
	ssize_t (*direct_IO)(struct kiocb___387 *, struct iov_iter___162 *);
	int (*migratepage)(struct address_space___387 *, struct page___388 *, struct page___388 *, enum migrate_mode);
	bool (*isolate_page)(struct page___388 *, isolate_mode_t);
	void (*putback_page)(struct page___388 *);
	int (*launder_page)(struct page___388 *);
	int (*is_partially_uptodate)(struct page___388 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___388 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___387 *, struct page___388 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___387 *, sector_t *);
	void (*swap_deactivate)(struct file___387 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___153 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___190 *wb;
	struct inode___387 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct iov_iter___162 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___192 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___387 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___387 *bd_inode;
	struct super_block___387 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___387 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___108 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___108 *bd_disk;
	struct request_queue___104 *bd_queue;
	struct backing_dev_info___190 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___387 {
	struct dentry___387 * (*lookup)(struct inode___387 *, struct dentry___387 *, unsigned int);
	const char * (*get_link)(struct dentry___387 *, struct inode___387 *, struct delayed_call *);
	int (*permission)(struct inode___387 *, int);
	struct posix_acl * (*get_acl)(struct inode___387 *, int);
	int (*readlink)(struct dentry___387 *, char *, int);
	int (*create)(struct inode___387 *, struct dentry___387 *, umode_t, bool);
	int (*link)(struct dentry___387 *, struct inode___387 *, struct dentry___387 *);
	int (*unlink)(struct inode___387 *, struct dentry___387 *);
	int (*symlink)(struct inode___387 *, struct dentry___387 *, const char *);
	int (*mkdir)(struct inode___387 *, struct dentry___387 *, umode_t);
	int (*rmdir)(struct inode___387 *, struct dentry___387 *);
	int (*mknod)(struct inode___387 *, struct dentry___387 *, umode_t, dev_t);
	int (*rename)(struct inode___387 *, struct dentry___387 *, struct inode___387 *, struct dentry___387 *, unsigned int);
	int (*setattr)(struct dentry___387 *, struct iattr___387 *);
	int (*getattr)(const struct path___388 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___387 *, char *, size_t);
	int (*fiemap)(struct inode___387 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___387 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___387 *, struct dentry___387 *, struct file___387 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___387 *, struct dentry___387 *, umode_t);
	int (*set_acl)(struct inode___387 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___387 {
	void (*fl_copy_lock)(struct file_lock___387 *, struct file_lock___387 *);
	void (*fl_release_private)(struct file_lock___387 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___387;

struct lock_manager_operations___387;

struct file_lock___387 {
	struct file_lock___387 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___387 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___387 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___387 *fl_ops;
	const struct lock_manager_operations___387 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___387 {
	int (*lm_compare_owner)(struct file_lock___387 *, struct file_lock___387 *);
	long unsigned int (*lm_owner_key)(struct file_lock___387 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___387 *);
	int (*lm_grant)(struct file_lock___387 *, int);
	bool (*lm_break)(struct file_lock___387 *);
	int (*lm_change)(struct file_lock___387 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___387 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___387 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___387 *fa_next;
	struct file___387 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___387 {
	const char *name;
	int fs_flags;
	struct dentry___387 * (*mount)(struct file_system_type___387 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___387 *);
	struct module___317 *owner;
	struct file_system_type___387 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___387 {
	struct inode___387 * (*alloc_inode)(struct super_block___387 *);
	void (*destroy_inode)(struct inode___387 *);
	void (*dirty_inode)(struct inode___387 *, int);
	int (*write_inode)(struct inode___387 *, struct writeback_control___153 *);
	int (*drop_inode)(struct inode___387 *);
	void (*evict_inode)(struct inode___387 *);
	void (*put_super)(struct super_block___387 *);
	int (*sync_fs)(struct super_block___387 *, int);
	int (*freeze_super)(struct super_block___387 *);
	int (*freeze_fs)(struct super_block___387 *);
	int (*thaw_super)(struct super_block___387 *);
	int (*unfreeze_fs)(struct super_block___387 *);
	int (*statfs)(struct dentry___387 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___387 *, int *, char *);
	void (*umount_begin)(struct super_block___387 *);
	int (*show_options)(struct seq_file___329 *, struct dentry___387 *);
	int (*show_devname)(struct seq_file___329 *, struct dentry___387 *);
	int (*show_path)(struct seq_file___329 *, struct dentry___387 *);
	int (*show_stats)(struct seq_file___329 *, struct dentry___387 *);
	ssize_t (*quota_read)(struct super_block___387 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___387 *, int, const char *, size_t, loff_t);
	struct dquot___387 ** (*get_dquots)(struct inode___387 *);
	int (*bdev_try_to_free_page)(struct super_block___387 *, struct page___388 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___387 *, struct shrink_control___135 *);
	long int (*free_cached_objects)(struct super_block___387 *, struct shrink_control___135 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___108 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___108 *last_lookup;
	struct hd_struct___108 *part[0];
};

struct block_device_operations___105 {
	int (*open)(struct block_device___387 *, fmode_t);
	void (*release)(struct gendisk___108 *, fmode_t);
	int (*rw_page)(struct block_device___387 *, sector_t, struct page___388 *, unsigned int);
	int (*ioctl)(struct block_device___387 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___387 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___108 *, unsigned int);
	int (*media_changed)(struct gendisk___108 *);
	void (*unlock_native_capacity)(struct gendisk___108 *);
	int (*revalidate_disk)(struct gendisk___108 *);
	int (*getgeo)(struct block_device___387 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___387 *, long unsigned int);
	int (*report_zones)(struct gendisk___108 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___317 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct badblocks___4 {
	struct device___355 *dev;
	int count;
	int unacked_exist;
	int shift;
	u64 *page;
	int changed;
	seqlock_t lock;
	sector_t sector;
	sector_t size;
};

typedef void compound_page_dtor___376(struct page___388 *);

struct bdi_writeback_congested___190 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___190 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct cgroup_subsys___241;

struct cgroup_subsys_state___241 {
	struct cgroup___241 *cgroup;
	struct cgroup_subsys___241 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___241 *parent;
};

struct bsg_ops___104 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___104 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___104 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___104 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___104(struct request___104 *, blk_status_t);

struct request___104 {
	struct request_queue___104 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___190 *bio;
	struct bio___190 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___192 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___108 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___104 *saved_end_io;
		} flush;
	};
	struct gendisk___108 *rq_disk;
	struct hd_struct___108 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___104 *end_io;
	void *end_io_data;
	struct request___104 *next_rq;
};

struct fwnode_reference_args___276;

struct fwnode_endpoint___276;

struct fwnode_operations___276 {
	struct fwnode_handle___276 * (*get)(struct fwnode_handle___276 *);
	void (*put)(struct fwnode_handle___276 *);
	bool (*device_is_available)(const struct fwnode_handle___276 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___276 *, const struct device___355 *);
	bool (*property_present)(const struct fwnode_handle___276 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___276 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___276 *, const char *, const char **, size_t);
	struct fwnode_handle___276 * (*get_parent)(const struct fwnode_handle___276 *);
	struct fwnode_handle___276 * (*get_next_child_node)(const struct fwnode_handle___276 *, struct fwnode_handle___276 *);
	struct fwnode_handle___276 * (*get_named_child_node)(const struct fwnode_handle___276 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___276 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___276 *);
	struct fwnode_handle___276 * (*graph_get_next_endpoint)(const struct fwnode_handle___276 *, struct fwnode_handle___276 *);
	struct fwnode_handle___276 * (*graph_get_remote_endpoint)(const struct fwnode_handle___276 *);
	struct fwnode_handle___276 * (*graph_get_port_parent)(struct fwnode_handle___276 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___276 *, struct fwnode_endpoint___276 *);
};

struct fwnode_endpoint___276 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___276 *local_fwnode;
};

struct fwnode_reference_args___276 {
	struct fwnode_handle___276 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct elevator_type___104;

struct elevator_mq_ops___104 {
	int (*init_sched)(struct request_queue___104 *, struct elevator_type___104 *);
	void (*exit_sched)(struct elevator_queue___104 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	bool (*allow_merge)(struct request_queue___104 *, struct request___104 *, struct bio___190 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx *, struct bio___190 *);
	int (*request_merge)(struct request_queue___104 *, struct request___104 **, struct bio___190 *);
	void (*request_merged)(struct request_queue___104 *, struct request___104 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___104 *, struct request___104 *, struct request___104 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___104 *, struct bio___190 *);
	void (*finish_request)(struct request___104 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___104 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___104 *, u64);
	void (*started_request)(struct request___104 *);
	void (*requeue_request)(struct request___104 *);
	struct request___104 * (*former_request)(struct request_queue___104 *, struct request___104 *);
	struct request___104 * (*next_request)(struct request_queue___104 *, struct request___104 *);
	void (*init_icq)(struct io_cq___108 *);
	void (*exit_icq)(struct io_cq___108 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___104;

struct elevator_type___104 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___104 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___104 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___317 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___104 {
	struct elevator_type___104 *type;
	void *elevator_data;
	struct kobject___375 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___104 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___104 *, char *);
	ssize_t (*store)(struct elevator_queue___104 *, const char *, size_t);
};

struct rchan___11;

struct blk_trace___10 {
	int trace_state;
	struct rchan___11 *rchan;
	long unsigned int *sequence;
	unsigned char *msg_data;
	u16 act_mask;
	u64 start_lba;
	u64 end_lba;
	u32 pid;
	u32 dev;
	struct dentry___387 *dir;
	struct dentry___387 *dropped_file;
	struct dentry___387 *msg_file;
	struct list_head running_list;
	atomic_t dropped;
};

struct seq_operations___329 {
	void * (*start)(struct seq_file___329 *, loff_t *);
	void (*stop)(struct seq_file___329 *, void *);
	void * (*next)(struct seq_file___329 *, void *, loff_t *);
	int (*show)(struct seq_file___329 *, void *);
};

typedef struct poll_table_struct___235 poll_table___39;

struct kernel_param_ops___315 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___315 *);
	int (*get)(char *, const struct kernel_param___315 *);
	void (*free)(void *);
};

struct kparam_array___315;

struct kernel_param___315 {
	const char *name;
	struct module___317 *mod;
	const struct kernel_param_ops___315 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___315 *arr;
	};
};

struct kparam_array___315 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___315 *ops;
	void *elem;
};

struct module_attribute___315 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___315 *, struct module_kobject___315 *, char *);
	ssize_t (*store)(struct module_attribute___315 *, struct module_kobject___315 *, const char *, size_t);
	void (*setup)(struct module___317 *, const char *);
	int (*test)(struct module___317 *);
	void (*free)(struct module___317 *);
};

struct mdp_device_descriptor_s {
	__u32 number;
	__u32 major;
	__u32 minor;
	__u32 raid_disk;
	__u32 state;
	__u32 reserved[27];
};

typedef struct mdp_device_descriptor_s mdp_disk_t;

struct mdp_superblock_s {
	__u32 md_magic;
	__u32 major_version;
	__u32 minor_version;
	__u32 patch_version;
	__u32 gvalid_words;
	__u32 set_uuid0;
	__u32 ctime;
	__u32 level;
	__u32 size;
	__u32 nr_disks;
	__u32 raid_disks;
	__u32 md_minor;
	__u32 not_persistent;
	__u32 set_uuid1;
	__u32 set_uuid2;
	__u32 set_uuid3;
	__u32 gstate_creserved[16];
	__u32 utime;
	__u32 state;
	__u32 active_disks;
	__u32 working_disks;
	__u32 failed_disks;
	__u32 spare_disks;
	__u32 sb_csum;
	__u32 events_lo;
	__u32 events_hi;
	__u32 cp_events_lo;
	__u32 cp_events_hi;
	__u32 recovery_cp;
	__u64 reshape_position;
	__u32 new_level;
	__u32 delta_disks;
	__u32 new_layout;
	__u32 new_chunk;
	__u32 gstate_sreserved[14];
	__u32 layout;
	__u32 chunk_size;
	__u32 root_pv;
	__u32 root_block;
	__u32 pstate_reserved[60];
	mdp_disk_t disks[27];
	__u32 reserved[0];
	mdp_disk_t this_disk;
};

typedef struct mdp_superblock_s mdp_super_t;

struct mdp_superblock_1 {
	__le32 magic;
	__le32 major_version;
	__le32 feature_map;
	__le32 pad0;
	__u8 set_uuid[16];
	char set_name[32];
	__le64 ctime;
	__le32 level;
	__le32 layout;
	__le64 size;
	__le32 chunksize;
	__le32 raid_disks;
	union {
		__le32 bitmap_offset;
		struct {
			__le16 offset;
			__le16 size;
		} ppl;
	};
	__le32 new_level;
	__le64 reshape_position;
	__le32 delta_disks;
	__le32 new_layout;
	__le32 new_chunk;
	__le32 new_offset;
	__le64 data_offset;
	__le64 data_size;
	__le64 super_offset;
	union {
		__le64 recovery_offset;
		__le64 journal_tail;
	};
	__le32 dev_number;
	__le32 cnt_corrected_read;
	__u8 device_uuid[16];
	__u8 devflags;
	__u8 bblog_shift;
	__le16 bblog_size;
	__le32 bblog_offset;
	__le64 utime;
	__le64 events;
	__le64 resync_offset;
	__le32 sb_csum;
	__le32 max_dev;
	__u8 pad3[32];
	__le16 dev_roles[0];
};

struct mdu_version_s {
	int major;
	int minor;
	int patchlevel;
};

typedef struct mdu_version_s mdu_version_t;

struct mdu_bitmap_file_s {
	char pathname[4096];
};

typedef struct mdu_bitmap_file_s mdu_bitmap_file_t;

struct rchan_buf___11 {
	void *start;
	void *data;
	size_t offset;
	size_t subbufs_produced;
	size_t subbufs_consumed;
	struct rchan___11 *chan;
	wait_queue_head_t read_wait;
	struct irq_work wakeup_work;
	struct dentry___387 *dentry;
	struct kref kref;
	struct page___388 **page_array;
	unsigned int page_count;
	unsigned int finalized;
	size_t *padding;
	size_t prev_padding;
	size_t bytes_consumed;
	size_t early_bytes;
	unsigned int cpu;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
};

struct rchan_callbacks___11;

struct rchan___11 {
	u32 version;
	size_t subbuf_size;
	size_t n_subbufs;
	size_t alloc_size;
	struct rchan_callbacks___11 *cb;
	struct kref kref;
	void *private_data;
	size_t last_toobig;
	struct rchan_buf___11 **buf;
	int is_global;
	struct list_head list;
	struct dentry___387 *parent;
	int has_base_filename;
	char base_filename[255];
};

struct rchan_callbacks___11 {
	int (*subbuf_start)(struct rchan_buf___11 *, void *, void *, size_t);
	void (*buf_mapped)(struct rchan_buf___11 *, struct file___387 *);
	void (*buf_unmapped)(struct rchan_buf___11 *, struct file___387 *);
	struct dentry___387 * (*create_buf_file)(const char *, struct dentry___387 *, umode_t, struct rchan_buf___11 *, int *);
	int (*remove_buf_file)(struct dentry___387 *);
};

struct cgroup_namespace___241 {
	refcount_t count;
	struct ns_common___9 ns;
	struct user_namespace___257 *user_ns;
	struct ucounts___257 *ucounts;
	struct css_set___241 *root_cset;
};

struct ucounts___257 {
	struct hlist_node node;
	struct user_namespace___257 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___242;

struct bpf_map_ops___241 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___242 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___242 *, struct file___387 *);
	void (*map_free)(struct bpf_map___242 *);
	int (*map_get_next_key)(struct bpf_map___242 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___242 *);
	void * (*map_lookup_elem)(struct bpf_map___242 *, void *);
	int (*map_update_elem)(struct bpf_map___242 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___242 *, void *);
	int (*map_push_elem)(struct bpf_map___242 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___242 *, void *);
	int (*map_peek_elem)(struct bpf_map___242 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___242 *, struct file___387 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___242 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___242 *, void *, struct seq_file___329 *);
	int (*map_check_btf)(const struct bpf_map___242 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___242 {
	const struct bpf_map_ops___241 *ops;
	struct bpf_map___242 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___357 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct psi_group___241 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___242 *poll_kworker;
	struct kthread_delayed_work___241 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___241 {
	struct kernfs_node___382 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_root___241;

struct cgroup_rstat_cpu___241;

struct cgroup___241 {
	struct cgroup_subsys_state___241 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___382 *kn;
	struct cgroup_file___241 procs_file;
	struct cgroup_file___241 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___241 *subsys[13];
	struct cgroup_root___241 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___241 *dom_cgrp;
	struct cgroup_rstat_cpu___241 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___39 bpf;
	atomic_t congestion_count;
	struct cgroup___241 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___241 psi;
	int ancestor_ids[0];
};

struct cftype___241;

struct cgroup_subsys___241 {
	struct cgroup_subsys_state___241 * (*css_alloc)(struct cgroup_subsys_state___241 *);
	int (*css_online)(struct cgroup_subsys_state___241 *);
	void (*css_offline)(struct cgroup_subsys_state___241 *);
	void (*css_released)(struct cgroup_subsys_state___241 *);
	void (*css_free)(struct cgroup_subsys_state___241 *);
	void (*css_reset)(struct cgroup_subsys_state___241 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___241 *, int);
	int (*css_extra_stat_show)(struct seq_file___329 *, struct cgroup_subsys_state___241 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___389 *);
	void (*cancel_fork)(struct task_struct___389 *);
	void (*fork)(struct task_struct___389 *);
	void (*exit)(struct task_struct___389 *);
	void (*free)(struct task_struct___389 *);
	void (*bind)(struct cgroup_subsys_state___241 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___241 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___241 *dfl_cftypes;
	struct cftype___241 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___241 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___241 *updated_children;
	struct cgroup___241 *updated_next;
};

struct cgroup_root___241 {
	struct kernfs_root___381 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___241 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___241 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___241 *ss;
	struct list_head node;
	struct kernfs_ops___381 *kf_ops;
	int (*open)(struct kernfs_open_file___381 *);
	void (*release)(struct kernfs_open_file___381 *);
	u64 (*read_u64)(struct cgroup_subsys_state___241 *, struct cftype___241 *);
	s64 (*read_s64)(struct cgroup_subsys_state___241 *, struct cftype___241 *);
	int (*seq_show)(struct seq_file___329 *, void *);
	void * (*seq_start)(struct seq_file___329 *, loff_t *);
	void * (*seq_next)(struct seq_file___329 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___329 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___241 *, struct cftype___241 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___241 *, struct cftype___241 *, s64);
	ssize_t (*write)(struct kernfs_open_file___381 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___381 *, struct poll_table_struct___235 *);
};

struct blkcg_policy_data___57;

struct blkcg___57 {
	struct cgroup_subsys_state___241 css;
	spinlock_t lock;
	struct xarray blkg_tree;
	struct blkcg_gq___57 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___57 *cpd[5];
	struct list_head all_blkcgs_node;
	struct list_head cgwb_list;
	refcount_t cgwb_refcnt;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct blkcg_policy_data___57 {
	struct blkcg___57 *blkcg;
	int plid;
};

struct blkg_policy_data___57 {
	struct blkcg_gq___57 *blkg;
	int plid;
};

struct mddev;

struct md_rdev;

struct md_cluster_operations {
	int (*join)(struct mddev *, int);
	int (*leave)(struct mddev *);
	int (*slot_number)(struct mddev *);
	int (*resync_info_update)(struct mddev *, sector_t, sector_t);
	void (*resync_info_get)(struct mddev *, sector_t *, sector_t *);
	int (*metadata_update_start)(struct mddev *);
	int (*metadata_update_finish)(struct mddev *);
	void (*metadata_update_cancel)(struct mddev *);
	int (*resync_start)(struct mddev *);
	int (*resync_finish)(struct mddev *);
	int (*area_resyncing)(struct mddev *, int, sector_t, sector_t);
	int (*add_new_disk)(struct mddev *, struct md_rdev *);
	void (*add_new_disk_cancel)(struct mddev *);
	int (*new_disk_ack)(struct mddev *, bool);
	int (*remove_disk)(struct mddev *, struct md_rdev *);
	void (*load_bitmaps)(struct mddev *, int);
	int (*gather_bitmaps)(struct md_rdev *);
	int (*resize_bitmaps)(struct mddev *, sector_t, sector_t);
	int (*lock_all_bitmaps)(struct mddev *);
	void (*unlock_all_bitmaps)(struct mddev *);
	void (*update_size)(struct mddev *, sector_t);
};

struct md_cluster_info;

struct md_personality;

struct md_thread;

struct bitmap;

struct mddev {
	void *private;
	struct md_personality *pers;
	dev_t unit;
	int md_minor;
	struct list_head disks;
	long unsigned int flags;
	long unsigned int sb_flags;
	int suspended;
	atomic_t active_io;
	int ro;
	int sysfs_active;
	struct gendisk___108 *gendisk;
	struct kobject___375 kobj;
	int hold_active;
	int major_version;
	int minor_version;
	int patch_version;
	int persistent;
	int external;
	char metadata_type[17];
	int chunk_sectors;
	time64_t ctime;
	time64_t utime;
	int level;
	int layout;
	char clevel[16];
	int raid_disks;
	int max_disks;
	sector_t dev_sectors;
	sector_t array_sectors;
	int external_size;
	__u64 events;
	int can_decrease_events;
	char uuid[16];
	sector_t reshape_position;
	int delta_disks;
	int new_level;
	int new_layout;
	int new_chunk_sectors;
	int reshape_backwards;
	struct md_thread *thread;
	struct md_thread *sync_thread;
	char *last_sync_action;
	sector_t curr_resync;
	sector_t curr_resync_completed;
	long unsigned int resync_mark;
	sector_t resync_mark_cnt;
	sector_t curr_mark_cnt;
	sector_t resync_max_sectors;
	atomic64_t resync_mismatches;
	sector_t suspend_lo;
	sector_t suspend_hi;
	int sync_speed_min;
	int sync_speed_max;
	int parallel_resync;
	int ok_start_degraded;
	long unsigned int recovery;
	int recovery_disabled;
	int in_sync;
	struct mutex open_mutex;
	struct mutex reconfig_mutex;
	atomic_t active;
	atomic_t openers;
	int changed;
	int degraded;
	atomic_t recovery_active;
	wait_queue_head_t recovery_wait;
	sector_t recovery_cp;
	sector_t resync_min;
	sector_t resync_max;
	struct kernfs_node___382 *sysfs_state;
	struct kernfs_node___382 *sysfs_action;
	struct work_struct del_work;
	spinlock_t lock;
	wait_queue_head_t sb_wait;
	atomic_t pending_writes;
	unsigned int safemode;
	unsigned int safemode_delay;
	struct timer_list safemode_timer;
	struct percpu_ref writes_pending;
	int sync_checkers;
	struct request_queue___104 *queue;
	struct bitmap *bitmap;
	struct {
		struct file___387 *file;
		loff_t offset;
		long unsigned int space;
		loff_t default_offset;
		long unsigned int default_space;
		struct mutex mutex;
		long unsigned int chunksize;
		long unsigned int daemon_sleep;
		long unsigned int max_write_behind;
		int external;
		int nodes;
		char cluster_name[64];
	} bitmap_info;
	atomic_t max_corr_read_errors;
	struct list_head all_mddevs;
	struct attribute_group___352 *to_remove;
	struct bio_set___190 bio_set;
	struct bio_set___190 sync_set;
	struct bio___190 *flush_bio;
	atomic_t flush_pending;
	ktime_t start_flush;
	ktime_t last_flush;
	struct work_struct flush_work;
	struct work_struct event_work;
	mempool_t *wb_info_pool;
	void (*sync_super)(struct mddev *, struct md_rdev *);
	struct md_cluster_info *cluster_info;
	unsigned int good_device_nr;
	bool has_superblocks: 1;
};

struct md_rdev {
	struct list_head same_set;
	sector_t sectors;
	struct mddev *mddev;
	int last_events;
	struct block_device___387 *meta_bdev;
	struct block_device___387 *bdev;
	struct page___388 *sb_page;
	struct page___388 *bb_page;
	int sb_loaded;
	__u64 sb_events;
	sector_t data_offset;
	sector_t new_data_offset;
	sector_t sb_start;
	int sb_size;
	int preferred_minor;
	struct kobject___375 kobj;
	long unsigned int flags;
	wait_queue_head_t blocked_wait;
	int desc_nr;
	int raid_disk;
	int new_raid_disk;
	int saved_raid_disk;
	union {
		sector_t recovery_offset;
		sector_t journal_tail;
	};
	atomic_t nr_pending;
	atomic_t read_errors;
	time64_t last_read_error;
	atomic_t corrected_errors;
	struct list_head wb_list;
	spinlock_t wb_list_lock;
	wait_queue_head_t wb_io_wait;
	struct work_struct del_work;
	struct kernfs_node___382 *sysfs_state;
	struct badblocks___4 badblocks;
	struct {
		short int offset;
		unsigned int size;
		sector_t sector;
	} ppl;
};

enum flag_bits {
	Faulty = 0,
	In_sync = 1,
	Bitmap_sync = 2,
	WriteMostly = 3,
	AutoDetected = 4,
	Blocked = 5,
	WriteErrorSeen = 6,
	FaultRecorded = 7,
	BlockedBadBlocks = 8,
	WantReplacement = 9,
	Replacement = 10,
	Candidate = 11,
	Journal = 12,
	ClusterRemove = 13,
	RemoveSynchronized = 14,
	ExternalBbl = 15,
	FailFast = 16,
	LastDev = 17,
	WBCollisionCheck = 18,
};

enum mddev_flags {
	MD_ARRAY_FIRST_USE = 0,
	MD_CLOSING = 1,
	MD_JOURNAL_CLEAN = 2,
	MD_HAS_JOURNAL = 3,
	MD_CLUSTER_RESYNC_LOCKED = 4,
	MD_FAILFAST_SUPPORTED = 5,
	MD_HAS_PPL = 6,
	MD_HAS_MULTIPLE_PPLS = 7,
	MD_ALLOW_SB_UPDATE = 8,
	MD_UPDATING_SB = 9,
};

enum mddev_sb_flags {
	MD_SB_CHANGE_DEVS = 0,
	MD_SB_CHANGE_CLEAN = 1,
	MD_SB_CHANGE_PENDING = 2,
	MD_SB_NEED_REWRITE = 3,
};

struct md_personality {
	char *name;
	int level;
	struct list_head list;
	struct module___317 *owner;
	bool (*make_request)(struct mddev *, struct bio___190 *);
	int (*run)(struct mddev *);
	int (*start)(struct mddev *);
	void (*free)(struct mddev *, void *);
	void (*status)(struct seq_file___329 *, struct mddev *);
	void (*error_handler)(struct mddev *, struct md_rdev *);
	int (*hot_add_disk)(struct mddev *, struct md_rdev *);
	int (*hot_remove_disk)(struct mddev *, struct md_rdev *);
	int (*spare_active)(struct mddev *);
	sector_t (*sync_request)(struct mddev *, sector_t, int *);
	int (*resize)(struct mddev *, sector_t);
	sector_t (*size)(struct mddev *, sector_t, int);
	int (*check_reshape)(struct mddev *);
	int (*start_reshape)(struct mddev *);
	void (*finish_reshape)(struct mddev *);
	void (*update_reshape_pos)(struct mddev *);
	void (*quiesce)(struct mddev *, int);
	void * (*takeover)(struct mddev *);
	int (*congested)(struct mddev *, int);
	int (*change_consistency_policy)(struct mddev *, const char *);
};

struct md_thread {
	void (*run)(struct md_thread *);
	struct mddev *mddev;
	wait_queue_head_t wqueue;
	long unsigned int flags;
	struct task_struct___389 *tsk;
	long unsigned int timeout;
	void *private;
};

struct bitmap_page;

struct bitmap_counts {
	spinlock_t lock;
	struct bitmap_page *bp;
	long unsigned int pages;
	long unsigned int missing_pages;
	long unsigned int chunkshift;
	long unsigned int chunks;
};

struct bitmap_storage {
	struct file___387 *file;
	struct page___388 *sb_page;
	struct page___388 **filemap;
	long unsigned int *filemap_attr;
	long unsigned int file_pages;
	long unsigned int bytes;
};

struct bitmap {
	struct bitmap_counts counts;
	struct mddev *mddev;
	__u64 events_cleared;
	int need_sync;
	struct bitmap_storage storage;
	long unsigned int flags;
	int allclean;
	atomic_t behind_writes;
	long unsigned int behind_writes_used;
	long unsigned int daemon_lastrun;
	long unsigned int last_end_sync;
	atomic_t pending_writes;
	wait_queue_head_t write_wait;
	wait_queue_head_t overflow_wait;
	wait_queue_head_t behind_wait;
	struct kernfs_node___382 *sysfs_can_clear;
	int cluster_slot;
};

enum recovery_flags {
	MD_RECOVERY_RUNNING = 0,
	MD_RECOVERY_SYNC = 1,
	MD_RECOVERY_RECOVER = 2,
	MD_RECOVERY_INTR = 3,
	MD_RECOVERY_DONE = 4,
	MD_RECOVERY_NEEDED = 5,
	MD_RECOVERY_REQUESTED = 6,
	MD_RECOVERY_CHECK = 7,
	MD_RECOVERY_RESHAPE = 8,
	MD_RECOVERY_FROZEN = 9,
	MD_RECOVERY_ERROR = 10,
	MD_RECOVERY_WAIT = 11,
	MD_RESYNCING_REMOTE = 12,
};

struct md_sysfs_entry {
	struct attribute attr;
	ssize_t (*show)(struct mddev *, char *);
	ssize_t (*store)(struct mddev *, const char *, size_t);
};

struct bitmap_page {
	char *map;
	unsigned int hijacked: 1;
	unsigned int pending: 1;
	unsigned int count: 30;
};

struct super_type {
	char *name;
	struct module___317 *owner;
	int (*load_super)(struct md_rdev *, struct md_rdev *, int);
	int (*validate_super)(struct mddev *, struct md_rdev *);
	void (*sync_super)(struct mddev *, struct md_rdev *);
	long long unsigned int (*rdev_size_change)(struct md_rdev *, sector_t);
	int (*allow_new_offset)(struct md_rdev *, long long unsigned int);
};

struct rdev_sysfs_entry {
	struct attribute attr;
	ssize_t (*show)(struct md_rdev *, char *);
	ssize_t (*store)(struct md_rdev *, const char *, size_t);
};

enum array_state {
	clear = 0,
	inactive = 1,
	suspended = 2,
	readonly = 3,
	read_auto = 4,
	clean = 5,
	active = 6,
	write_pending = 7,
	active_idle = 8,
	bad_word = 9,
};

struct detected_devices_node {
	struct list_head list;
	dev_t dev;
};

struct module___318;

struct file___388;

struct kiocb___388;

struct iov_iter___163;

struct poll_table_struct___236;

struct vm_area_struct___389;

struct inode___388;

struct file_lock___388;

struct page___389;

struct seq_file___330;

struct file_operations___388 {
	struct module___318 *owner;
	loff_t (*llseek)(struct file___388 *, loff_t, int);
	ssize_t (*read)(struct file___388 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___388 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___388 *, struct iov_iter___163 *);
	ssize_t (*write_iter)(struct kiocb___388 *, struct iov_iter___163 *);
	int (*iopoll)(struct kiocb___388 *, bool);
	int (*iterate)(struct file___388 *, struct dir_context *);
	int (*iterate_shared)(struct file___388 *, struct dir_context *);
	__poll_t (*poll)(struct file___388 *, struct poll_table_struct___236 *);
	long int (*unlocked_ioctl)(struct file___388 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___388 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___388 *, struct vm_area_struct___389 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___388 *, struct file___388 *);
	int (*flush)(struct file___388 *, fl_owner_t);
	int (*release)(struct inode___388 *, struct file___388 *);
	int (*fsync)(struct file___388 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___388 *, int);
	int (*lock)(struct file___388 *, int, struct file_lock___388 *);
	ssize_t (*sendpage)(struct file___388 *, struct page___389 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___388 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___388 *, int, struct file_lock___388 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___388 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___388 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___388 *, long int, struct file_lock___388 **, void **);
	long int (*fallocate)(struct file___388 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___330 *, struct file___388 *);
	ssize_t (*copy_file_range)(struct file___388 *, loff_t, struct file___388 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___388 *, loff_t, struct file___388 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___388 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___389 {
	u64 seqnum;
	struct vm_area_struct___389 *vmas[4];
};

struct page_frag___389 {
	struct page___389 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___389;

struct cred___358;

struct nsproxy___287;

struct bio_list___191;

struct backing_dev_info___191;

struct io_context___109;

struct css_set___242;

struct request_queue___105;

struct vm_struct___293;

struct task_struct___390 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___390 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___389 *mm;
	struct mm_struct___389 *active_mm;
	struct vmacache___389 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___390 *real_parent;
	struct task_struct___390 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___390 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___224 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___224 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___224 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___358 *ptracer_cred;
	const struct cred___358 *real_cred;
	const struct cred___358 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___287 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___390 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___191 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___191 *backing_dev_info;
	struct io_context___109 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___242 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___389 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___105 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___390 *oom_reaper_list;
	struct vm_struct___293 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___148 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rw_semaphore___390 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___390 *owner;
};

struct key___358;

struct ucounts___258;

struct user_namespace___258 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___258 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___9 ns;
	long unsigned int flags;
	struct key___358 *persistent_keyring_register;
	struct rw_semaphore___390 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___258 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct secondary_data___390 {
	void *stack;
	struct task_struct___390 *task;
	long int status;
};

typedef struct page___389 *pgtable_t___389;

struct address_space___388;

struct dev_pagemap___377;

struct page___389 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___388 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___389 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___389 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___389 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___377 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct user_struct___358 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___358 *uid_keyring;
	struct key___358 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___377;

struct vm_area_struct___389 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___389 *vm_next;
	struct vm_area_struct___389 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___389 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___377 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___388 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___389;

struct mm_struct___389 {
	struct {
		struct vm_area_struct___389 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___388 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___390 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___389 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___390 *owner;
		struct user_namespace___258 *user_ns;
		struct file___388 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___389 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___358 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___358 *session_keyring;
	struct key___358 *process_keyring;
	struct key___358 *thread_keyring;
	struct key___358 *request_key_auth;
	void *security;
	struct user_struct___358 *user;
	struct user_namespace___258 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___242;

struct nsproxy___287 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___242 *cgroup_ns;
};

struct bio___191;

struct bio_list___191 {
	struct bio___191 *head;
	struct bio___191 *tail;
};

struct bdi_writeback_congested___191;

struct cgroup_subsys_state___242;

struct bdi_writeback___191 {
	struct backing_dev_info___191 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___191 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___242 *memcg_css;
	struct cgroup_subsys_state___242 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___356;

struct dentry___388;

struct backing_dev_info___191 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___191 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___356 *dev;
	struct device___356 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___388 *debug_dir;
	struct dentry___388 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___109;

struct io_context___109 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___109 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___242;

struct css_set___242 {
	struct cgroup_subsys_state___242 *subsys[13];
	refcount_t refcount;
	struct css_set___242 *dom_cset;
	struct cgroup___242 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___242 *mg_src_cgrp;
	struct cgroup___242 *mg_dst_cgrp;
	struct css_set___242 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

typedef blk_qc_t make_request_fn___105(struct request_queue___105 *, struct bio___191 *);

struct request___105;

typedef int dma_drain_needed_fn___105(struct request___105 *);

struct kset___375;

struct kobj_type___375;

struct kernfs_node___383;

struct kobject___376 {
	const char *name;
	struct list_head entry;
	struct kobject___376 *parent;
	struct kset___375 *kset;
	struct kobj_type___375 *ktype;
	struct kernfs_node___383 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___105;

struct bsg_class_device___105 {
	struct device___356 *class_dev;
	int minor;
	struct request_queue___105 *queue;
	const struct bsg_ops___105 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___191 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___191 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___105;

struct blkcg_gq___58;

struct blk_trace___11;

struct request_queue___105 {
	struct list_head queue_head;
	struct request___105 *last_merge;
	struct elevator_queue___105 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___105 *make_request_fn;
	dma_drain_needed_fn___105 *dma_drain_needed;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___191 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___376 kobj;
	struct kobject___376 *mq_kobj;
	struct blk_integrity integrity;
	struct device___356 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___58 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace___11 *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	struct bsg_class_device___105 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___191 bio_split;
	struct dentry___388 *debugfs_dir;
	struct dentry___388 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___293 {
	struct vm_struct___293 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___389 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct pglist_data___389;

struct lruvec___389 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___389 *pgdat;
};

struct zone___389 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___389 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___389 {
	struct zone___389 *zone;
	int zone_idx;
};

struct zonelist___389 {
	struct zoneref___389 _zonerefs[25];
};

struct pglist_data___389 {
	struct zone___389 node_zones[3];
	struct zonelist___389 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___390 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___390 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___389 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___389 {
	struct rw_semaphore___390 rwsem;
	struct notifier_block *head;
};

struct bio_vec___193 {
	struct page___389 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

typedef void bio_end_io_t___191(struct bio___191 *);

struct gendisk___109;

struct bio_integrity_payload___191;

struct bio___191 {
	struct bio___191 *bi_next;
	struct gendisk___109 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___191 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___58 *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___191 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___193 *bi_io_vec;
	struct bio_set___191 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___193 bi_inline_vecs[0];
};

struct bio_integrity_payload___191 {
	struct bio___191 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___193 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___193 bip_inline_vecs[0];
};

struct dev_pm_info___356 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___356 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___356;

struct bus_type___356;

struct device_driver___356;

struct dev_pm_domain___356;

struct fwnode_handle___277;

struct class___356;

struct attribute_group___353;

struct device___356 {
	struct device___356 *parent;
	struct device_private *p;
	struct kobject___376 kobj;
	const char *init_name;
	const struct device_type___356 *type;
	struct mutex mutex;
	struct bus_type___356 *bus;
	struct device_driver___356 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___356 power;
	struct dev_pm_domain___356 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___277 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___356 *class;
	const struct attribute_group___353 **groups;
	void (*release)(struct device___356 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___109 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___356 __dev;
	struct kobject___376 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___109;

struct block_device_operations___106;

struct badblocks___5;

struct gendisk___109 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___109 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___109 *part_tbl;
	struct hd_struct___109 part0;
	const struct block_device_operations___106 *fops;
	struct request_queue___105 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___390 lookup_sem;
	struct kobject___376 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___376 integrity_kobj;
	int node_id;
	struct badblocks___5 *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct blkcg___58;

struct blkg_policy_data___58;

struct blkcg_gq___58 {
	struct request_queue___105 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___58 *blkcg;
	struct bdi_writeback_congested___191 *wb_congested;
	struct blkcg_gq___58 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_rwstat stat_bytes;
	struct blkg_rwstat stat_ios;
	struct blkg_policy_data___58 *pd[5];
	struct callback_head callback_head;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
};

struct dev_pm_ops___356;

struct device_type___356 {
	const char *name;
	const struct attribute_group___353 **groups;
	int (*uevent)(struct device___356 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___356 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___356 *);
	const struct dev_pm_ops___356 *pm;
};

struct class___356 {
	const char *name;
	struct module___318 *owner;
	const struct attribute_group___353 **class_groups;
	const struct attribute_group___353 **dev_groups;
	struct kobject___376 *dev_kobj;
	int (*dev_uevent)(struct device___356 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___356 *, umode_t *);
	void (*class_release)(struct class___356 *);
	void (*dev_release)(struct device___356 *);
	int (*shutdown_pre)(struct device___356 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___356 *);
	const struct dev_pm_ops___356 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct kernfs_root___382;

struct kernfs_elem_dir___382 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___382 *root;
};

struct kernfs_syscall_ops___382;

struct kernfs_root___382 {
	struct kernfs_node___383 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___382 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___382 {
	struct kernfs_node___383 *target_kn;
};

struct kernfs_ops___382;

struct kernfs_elem_attr___382 {
	const struct kernfs_ops___382 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___383 *notify_next;
};

struct kernfs_node___383 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___383 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___382 dir;
		struct kernfs_elem_symlink___382 symlink;
		struct kernfs_elem_attr___382 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___382;

struct kernfs_ops___382 {
	int (*open)(struct kernfs_open_file___382 *);
	void (*release)(struct kernfs_open_file___382 *);
	int (*seq_show)(struct seq_file___330 *, void *);
	void * (*seq_start)(struct seq_file___330 *, loff_t *);
	void * (*seq_next)(struct seq_file___330 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___330 *, void *);
	ssize_t (*read)(struct kernfs_open_file___382 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___382 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___382 *, struct vm_area_struct___389 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___382 *, struct poll_table_struct___236 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___382 {
	int (*remount_fs)(struct kernfs_root___382 *, int *, char *);
	int (*show_options)(struct seq_file___330 *, struct kernfs_root___382 *);
	int (*mkdir)(struct kernfs_node___383 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___383 *);
	int (*rename)(struct kernfs_node___383 *, struct kernfs_node___383 *, const char *);
	int (*show_path)(struct seq_file___330 *, struct kernfs_node___383 *, struct kernfs_root___382 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___330;

struct seq_file___330 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___330 *op;
	int poll_event;
	const struct file___388 *file;
	void *private;
};

struct kernfs_open_file___382 {
	struct kernfs_node___383 *kn;
	struct file___388 *file;
	struct seq_file___330 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___377 *vm_ops;
};

struct vfsmount___71;

struct path___389 {
	struct vfsmount___71 *mnt;
	struct dentry___388 *dentry;
};

struct file___388 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___389 f_path;
	struct inode___388 *f_inode;
	const struct file_operations___388 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___224 f_owner;
	const struct cred___358 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___388 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___377;

struct vm_operations_struct___377 {
	void (*open)(struct vm_area_struct___389 *);
	void (*close)(struct vm_area_struct___389 *);
	int (*split)(struct vm_area_struct___389 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___389 *);
	vm_fault_t (*fault)(struct vm_fault___377 *);
	vm_fault_t (*huge_fault)(struct vm_fault___377 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___377 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___389 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___377 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___377 *);
	int (*access)(struct vm_area_struct___389 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___389 *);
	int (*set_policy)(struct vm_area_struct___389 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___389 *, long unsigned int);
	struct page___389 * (*find_special_page)(struct vm_area_struct___389 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___244)(struct file___388 *, wait_queue_head_t *, struct poll_table_struct___236 *);

struct poll_table_struct___236 {
	poll_queue_proc___244 _qproc;
	__poll_t _key;
};

struct bin_attribute___352;

struct attribute_group___353 {
	const char *name;
	umode_t (*is_visible)(struct kobject___376 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___376 *, struct bin_attribute___352 *, int);
	struct attribute **attrs;
	struct bin_attribute___352 **bin_attrs;
};

struct bin_attribute___352 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___388 *, struct kobject___376 *, struct bin_attribute___352 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___388 *, struct kobject___376 *, struct bin_attribute___352 *, char *, loff_t, size_t);
	int (*mmap)(struct file___388 *, struct kobject___376 *, struct bin_attribute___352 *, struct vm_area_struct___389 *);
};

struct sysfs_ops___375 {
	ssize_t (*show)(struct kobject___376 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___376 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___375;

struct kset___375 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___376 kobj;
	const struct kset_uevent_ops___375 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___375 {
	void (*release)(struct kobject___376 *);
	const struct sysfs_ops___375 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___29 * (*child_ns_type)(struct kobject___376 *);
	const void * (*namespace)(struct kobject___376 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___375 {
	int (* const filter)(struct kset___375 *, struct kobject___376 *);
	const char * (* const name)(struct kset___375 *, struct kobject___376 *);
	int (* const uevent)(struct kset___375 *, struct kobject___376 *, struct kobj_uevent_env *);
};

struct kobj_attribute___367 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___376 *, struct kobj_attribute___367 *, char *);
	ssize_t (*store)(struct kobject___376 *, struct kobj_attribute___367 *, const char *, size_t);
};

struct dev_pm_ops___356 {
	int (*prepare)(struct device___356 *);
	void (*complete)(struct device___356 *);
	int (*suspend)(struct device___356 *);
	int (*resume)(struct device___356 *);
	int (*freeze)(struct device___356 *);
	int (*thaw)(struct device___356 *);
	int (*poweroff)(struct device___356 *);
	int (*restore)(struct device___356 *);
	int (*suspend_late)(struct device___356 *);
	int (*resume_early)(struct device___356 *);
	int (*freeze_late)(struct device___356 *);
	int (*thaw_early)(struct device___356 *);
	int (*poweroff_late)(struct device___356 *);
	int (*restore_early)(struct device___356 *);
	int (*suspend_noirq)(struct device___356 *);
	int (*resume_noirq)(struct device___356 *);
	int (*freeze_noirq)(struct device___356 *);
	int (*thaw_noirq)(struct device___356 *);
	int (*poweroff_noirq)(struct device___356 *);
	int (*restore_noirq)(struct device___356 *);
	int (*runtime_suspend)(struct device___356 *);
	int (*runtime_resume)(struct device___356 *);
	int (*runtime_idle)(struct device___356 *);
};

struct dev_pm_domain___356 {
	struct dev_pm_ops___356 ops;
	void (*detach)(struct device___356 *, bool);
	int (*activate)(struct device___356 *);
	void (*sync)(struct device___356 *);
	void (*dismiss)(struct device___356 *);
};

struct bus_type___356 {
	const char *name;
	const char *dev_name;
	struct device___356 *dev_root;
	const struct attribute_group___353 **bus_groups;
	const struct attribute_group___353 **dev_groups;
	const struct attribute_group___353 **drv_groups;
	int (*match)(struct device___356 *, struct device_driver___356 *);
	int (*uevent)(struct device___356 *, struct kobj_uevent_env *);
	int (*probe)(struct device___356 *);
	int (*remove)(struct device___356 *);
	void (*shutdown)(struct device___356 *);
	int (*online)(struct device___356 *);
	int (*offline)(struct device___356 *);
	int (*suspend)(struct device___356 *, pm_message_t);
	int (*resume)(struct device___356 *);
	int (*num_vf)(struct device___356 *);
	int (*dma_configure)(struct device___356 *);
	const struct dev_pm_ops___356 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___356 {
	const char *name;
	struct bus_type___356 *bus;
	struct module___318 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___356 *);
	int (*remove)(struct device___356 *);
	void (*shutdown)(struct device___356 *);
	int (*suspend)(struct device___356 *, pm_message_t);
	int (*resume)(struct device___356 *);
	const struct attribute_group___353 **groups;
	const struct dev_pm_ops___356 *pm;
	void (*coredump)(struct device___356 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct module_kobject___316 {
	struct kobject___376 kobj;
	struct module___318 *mod;
	struct kobject___376 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___316 {
	struct module___318 *mod;
	struct latch_tree_node node;
};

struct module_layout___316 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___316 mtn;
};

struct module_attribute___316;

struct kernel_param___316;

struct module___318 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___316 mkobj;
	struct module_attribute___316 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___376 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___316 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___316 core_layout;
	struct module_layout___316 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide40;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide41;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_operations___277;

struct fwnode_handle___277 {
	struct fwnode_handle___277 *secondary;
	const struct fwnode_operations___277 *ops;
};

struct dentry_operations___388;

struct super_block___388;

struct dentry___388 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___388 *d_parent;
	struct qstr d_name;
	struct inode___388 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___388 *d_op;
	struct super_block___388 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___388;

struct address_space___388 {
	struct inode___388 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___390 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___388 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___388;

struct block_device___388;

struct inode___388 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___388 *i_op;
	struct super_block___388 *i_sb;
	struct address_space___388 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___390 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___191 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___388 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___388 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___388 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___388 {
	int (*d_revalidate)(struct dentry___388 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___388 *, unsigned int);
	int (*d_hash)(const struct dentry___388 *, struct qstr *);
	int (*d_compare)(const struct dentry___388 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___388 *);
	int (*d_init)(struct dentry___388 *);
	void (*d_release)(struct dentry___388 *);
	void (*d_prune)(struct dentry___388 *);
	void (*d_iput)(struct dentry___388 *, struct inode___388 *);
	char * (*d_dname)(struct dentry___388 *, char *, int);
	struct vfsmount___71 * (*d_automount)(struct path___389 *);
	int (*d_manage)(const struct path___389 *, bool);
	struct dentry___388 * (*d_real)(struct dentry___388 *, const struct inode___388 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___388;

struct mem_dqinfo___388 {
	struct quota_format_type___388 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___388;

struct quota_info___388 {
	unsigned int flags;
	struct rw_semaphore___390 dqio_sem;
	struct inode___388 *files[3];
	struct mem_dqinfo___388 info[3];
	const struct quota_format_ops___388 *ops[3];
};

struct rcuwait___388 {
	struct task_struct___390 *task;
};

struct percpu_rw_semaphore___388 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___390 rw_sem;
	struct rcuwait___388 writer;
	int readers_block;
};

struct sb_writers___388 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___388 rw_sem[3];
};

struct file_system_type___388;

struct super_operations___388;

struct dquot_operations___388;

struct quotactl_ops___388;

struct super_block___388 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___388 *s_type;
	const struct super_operations___388 *s_op;
	const struct dquot_operations___388 *dq_op;
	const struct quotactl_ops___388 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___388 *s_root;
	struct rw_semaphore___390 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___388 *s_bdev;
	struct backing_dev_info___191 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___388 s_dquot;
	struct sb_writers___388 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___388 *s_d_op;
	int cleancache_poolid;
	struct shrinker___135 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___258 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___71 {
	struct dentry___388 *mnt_root;
	struct super_block___388 *mnt_sb;
	int mnt_flags;
};

typedef int (*dev_page_fault_t___377)(struct vm_area_struct___389 *, long unsigned int, const struct page___389 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___377)(struct page___389 *, void *);

struct dev_pagemap___377 {
	dev_page_fault_t___377 page_fault;
	dev_page_free_t___377 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___356 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___389 {
	struct task_struct___390 *task;
	struct core_thread___389 *next;
};

struct core_state___389 {
	atomic_t nr_threads;
	struct core_thread___389 dumper;
	struct completion startup;
};

struct vm_fault___377 {
	struct vm_area_struct___389 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___389 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___389 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___389 prealloc_pte;
};

struct io_cq___109 {
	struct request_queue___105 *q;
	struct io_context___109 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct buffer_head___8;

typedef void bh_end_io_t___8(struct buffer_head___8 *, int);

struct buffer_head___8 {
	long unsigned int b_state;
	struct buffer_head___8 *b_this_page;
	struct page___389 *b_page;
	sector_t b_blocknr;
	size_t b_size;
	char *b_data;
	struct block_device___388 *b_bdev;
	bh_end_io_t___8 *b_end_io;
	void *b_private;
	struct list_head b_assoc_buffers;
	struct address_space___388 *b_assoc_map;
	atomic_t b_count;
};

struct kiocb___388 {
	struct file___388 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___388 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___388 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___388 *ia_file;
};

struct dquot___388 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___388 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___388 {
	int qf_fmt_id;
	const struct quota_format_ops___388 *qf_ops;
	struct module___318 *qf_owner;
	struct quota_format_type___388 *qf_next;
};

struct quota_format_ops___388 {
	int (*check_quota_file)(struct super_block___388 *, int);
	int (*read_file_info)(struct super_block___388 *, int);
	int (*write_file_info)(struct super_block___388 *, int);
	int (*free_file_info)(struct super_block___388 *, int);
	int (*read_dqblk)(struct dquot___388 *);
	int (*commit_dqblk)(struct dquot___388 *);
	int (*release_dqblk)(struct dquot___388 *);
	int (*get_next_id)(struct super_block___388 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___388 {
	int (*write_dquot)(struct dquot___388 *);
	struct dquot___388 * (*alloc_dquot)(struct super_block___388 *, int);
	void (*destroy_dquot)(struct dquot___388 *);
	int (*acquire_dquot)(struct dquot___388 *);
	int (*release_dquot)(struct dquot___388 *);
	int (*mark_dirty)(struct dquot___388 *);
	int (*write_info)(struct super_block___388 *, int);
	qsize_t * (*get_reserved_space)(struct inode___388 *);
	int (*get_projid)(struct inode___388 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___388 *, qsize_t *);
	int (*get_next_id)(struct super_block___388 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___388 {
	int (*quota_on)(struct super_block___388 *, int, int, const struct path___389 *);
	int (*quota_off)(struct super_block___388 *, int);
	int (*quota_enable)(struct super_block___388 *, unsigned int);
	int (*quota_disable)(struct super_block___388 *, unsigned int);
	int (*quota_sync)(struct super_block___388 *, int);
	int (*set_info)(struct super_block___388 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___388 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___388 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___388 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___388 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___388 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___154;

struct address_space_operations___388 {
	int (*writepage)(struct page___389 *, struct writeback_control___154 *);
	int (*readpage)(struct file___388 *, struct page___389 *);
	int (*writepages)(struct address_space___388 *, struct writeback_control___154 *);
	int (*set_page_dirty)(struct page___389 *);
	int (*readpages)(struct file___388 *, struct address_space___388 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___388 *, struct address_space___388 *, loff_t, unsigned int, unsigned int, struct page___389 **, void **);
	int (*write_end)(struct file___388 *, struct address_space___388 *, loff_t, unsigned int, unsigned int, struct page___389 *, void *);
	sector_t (*bmap)(struct address_space___388 *, sector_t);
	void (*invalidatepage)(struct page___389 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___389 *, gfp_t);
	void (*freepage)(struct page___389 *);
	ssize_t (*direct_IO)(struct kiocb___388 *, struct iov_iter___163 *);
	int (*migratepage)(struct address_space___388 *, struct page___389 *, struct page___389 *, enum migrate_mode);
	bool (*isolate_page)(struct page___389 *, isolate_mode_t);
	void (*putback_page)(struct page___389 *);
	int (*launder_page)(struct page___389 *);
	int (*is_partially_uptodate)(struct page___389 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___389 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___388 *, struct page___389 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___388 *, sector_t *);
	void (*swap_deactivate)(struct file___388 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___154 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___191 *wb;
	struct inode___388 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct iov_iter___163 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___193 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___388 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___388 *bd_inode;
	struct super_block___388 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___388 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___109 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___109 *bd_disk;
	struct request_queue___105 *bd_queue;
	struct backing_dev_info___191 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___388 {
	struct dentry___388 * (*lookup)(struct inode___388 *, struct dentry___388 *, unsigned int);
	const char * (*get_link)(struct dentry___388 *, struct inode___388 *, struct delayed_call *);
	int (*permission)(struct inode___388 *, int);
	struct posix_acl * (*get_acl)(struct inode___388 *, int);
	int (*readlink)(struct dentry___388 *, char *, int);
	int (*create)(struct inode___388 *, struct dentry___388 *, umode_t, bool);
	int (*link)(struct dentry___388 *, struct inode___388 *, struct dentry___388 *);
	int (*unlink)(struct inode___388 *, struct dentry___388 *);
	int (*symlink)(struct inode___388 *, struct dentry___388 *, const char *);
	int (*mkdir)(struct inode___388 *, struct dentry___388 *, umode_t);
	int (*rmdir)(struct inode___388 *, struct dentry___388 *);
	int (*mknod)(struct inode___388 *, struct dentry___388 *, umode_t, dev_t);
	int (*rename)(struct inode___388 *, struct dentry___388 *, struct inode___388 *, struct dentry___388 *, unsigned int);
	int (*setattr)(struct dentry___388 *, struct iattr___388 *);
	int (*getattr)(const struct path___389 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___388 *, char *, size_t);
	int (*fiemap)(struct inode___388 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___388 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___388 *, struct dentry___388 *, struct file___388 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___388 *, struct dentry___388 *, umode_t);
	int (*set_acl)(struct inode___388 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___388 {
	void (*fl_copy_lock)(struct file_lock___388 *, struct file_lock___388 *);
	void (*fl_release_private)(struct file_lock___388 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___388;

struct lock_manager_operations___388;

struct file_lock___388 {
	struct file_lock___388 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___388 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___388 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___388 *fl_ops;
	const struct lock_manager_operations___388 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___388 {
	int (*lm_compare_owner)(struct file_lock___388 *, struct file_lock___388 *);
	long unsigned int (*lm_owner_key)(struct file_lock___388 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___388 *);
	int (*lm_grant)(struct file_lock___388 *, int);
	bool (*lm_break)(struct file_lock___388 *);
	int (*lm_change)(struct file_lock___388 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___388 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___388 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___388 *fa_next;
	struct file___388 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___388 {
	const char *name;
	int fs_flags;
	struct dentry___388 * (*mount)(struct file_system_type___388 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___388 *);
	struct module___318 *owner;
	struct file_system_type___388 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___388 {
	struct inode___388 * (*alloc_inode)(struct super_block___388 *);
	void (*destroy_inode)(struct inode___388 *);
	void (*dirty_inode)(struct inode___388 *, int);
	int (*write_inode)(struct inode___388 *, struct writeback_control___154 *);
	int (*drop_inode)(struct inode___388 *);
	void (*evict_inode)(struct inode___388 *);
	void (*put_super)(struct super_block___388 *);
	int (*sync_fs)(struct super_block___388 *, int);
	int (*freeze_super)(struct super_block___388 *);
	int (*freeze_fs)(struct super_block___388 *);
	int (*thaw_super)(struct super_block___388 *);
	int (*unfreeze_fs)(struct super_block___388 *);
	int (*statfs)(struct dentry___388 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___388 *, int *, char *);
	void (*umount_begin)(struct super_block___388 *);
	int (*show_options)(struct seq_file___330 *, struct dentry___388 *);
	int (*show_devname)(struct seq_file___330 *, struct dentry___388 *);
	int (*show_path)(struct seq_file___330 *, struct dentry___388 *);
	int (*show_stats)(struct seq_file___330 *, struct dentry___388 *);
	ssize_t (*quota_read)(struct super_block___388 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___388 *, int, const char *, size_t, loff_t);
	struct dquot___388 ** (*get_dquots)(struct inode___388 *);
	int (*bdev_try_to_free_page)(struct super_block___388 *, struct page___389 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___388 *, struct shrink_control___135 *);
	long int (*free_cached_objects)(struct super_block___388 *, struct shrink_control___135 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___109 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___109 *last_lookup;
	struct hd_struct___109 *part[0];
};

struct block_device_operations___106 {
	int (*open)(struct block_device___388 *, fmode_t);
	void (*release)(struct gendisk___109 *, fmode_t);
	int (*rw_page)(struct block_device___388 *, sector_t, struct page___389 *, unsigned int);
	int (*ioctl)(struct block_device___388 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___388 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___109 *, unsigned int);
	int (*media_changed)(struct gendisk___109 *);
	void (*unlock_native_capacity)(struct gendisk___109 *);
	int (*revalidate_disk)(struct gendisk___109 *);
	int (*getgeo)(struct block_device___388 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___388 *, long unsigned int);
	int (*report_zones)(struct gendisk___109 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___318 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct badblocks___5 {
	struct device___356 *dev;
	int count;
	int unacked_exist;
	int shift;
	u64 *page;
	int changed;
	seqlock_t lock;
	sector_t sector;
	sector_t size;
};

typedef void compound_page_dtor___377(struct page___389 *);

struct bdi_writeback_congested___191 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___191 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct cgroup_subsys___242;

struct cgroup_subsys_state___242 {
	struct cgroup___242 *cgroup;
	struct cgroup_subsys___242 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___242 *parent;
};

struct bsg_ops___105 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___105 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___105 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___105 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___105(struct request___105 *, blk_status_t);

struct request___105 {
	struct request_queue___105 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___191 *bio;
	struct bio___191 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___193 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___109 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___105 *saved_end_io;
		} flush;
	};
	struct gendisk___109 *rq_disk;
	struct hd_struct___109 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___105 *end_io;
	void *end_io_data;
	struct request___105 *next_rq;
};

struct fwnode_reference_args___277;

struct fwnode_endpoint___277;

struct fwnode_operations___277 {
	struct fwnode_handle___277 * (*get)(struct fwnode_handle___277 *);
	void (*put)(struct fwnode_handle___277 *);
	bool (*device_is_available)(const struct fwnode_handle___277 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___277 *, const struct device___356 *);
	bool (*property_present)(const struct fwnode_handle___277 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___277 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___277 *, const char *, const char **, size_t);
	struct fwnode_handle___277 * (*get_parent)(const struct fwnode_handle___277 *);
	struct fwnode_handle___277 * (*get_next_child_node)(const struct fwnode_handle___277 *, struct fwnode_handle___277 *);
	struct fwnode_handle___277 * (*get_named_child_node)(const struct fwnode_handle___277 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___277 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___277 *);
	struct fwnode_handle___277 * (*graph_get_next_endpoint)(const struct fwnode_handle___277 *, struct fwnode_handle___277 *);
	struct fwnode_handle___277 * (*graph_get_remote_endpoint)(const struct fwnode_handle___277 *);
	struct fwnode_handle___277 * (*graph_get_port_parent)(struct fwnode_handle___277 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___277 *, struct fwnode_endpoint___277 *);
};

struct fwnode_endpoint___277 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___277 *local_fwnode;
};

struct fwnode_reference_args___277 {
	struct fwnode_handle___277 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct elevator_type___105;

struct elevator_mq_ops___105 {
	int (*init_sched)(struct request_queue___105 *, struct elevator_type___105 *);
	void (*exit_sched)(struct elevator_queue___105 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	bool (*allow_merge)(struct request_queue___105 *, struct request___105 *, struct bio___191 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx *, struct bio___191 *);
	int (*request_merge)(struct request_queue___105 *, struct request___105 **, struct bio___191 *);
	void (*request_merged)(struct request_queue___105 *, struct request___105 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___105 *, struct request___105 *, struct request___105 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___105 *, struct bio___191 *);
	void (*finish_request)(struct request___105 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___105 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___105 *, u64);
	void (*started_request)(struct request___105 *);
	void (*requeue_request)(struct request___105 *);
	struct request___105 * (*former_request)(struct request_queue___105 *, struct request___105 *);
	struct request___105 * (*next_request)(struct request_queue___105 *, struct request___105 *);
	void (*init_icq)(struct io_cq___109 *);
	void (*exit_icq)(struct io_cq___109 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx___34 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___105;

struct elevator_type___105 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___105 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___105 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___318 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___105 {
	struct elevator_type___105 *type;
	void *elevator_data;
	struct kobject___376 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___105 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___105 *, char *);
	ssize_t (*store)(struct elevator_queue___105 *, const char *, size_t);
};

struct rchan___12;

struct blk_trace___11 {
	int trace_state;
	struct rchan___12 *rchan;
	long unsigned int *sequence;
	unsigned char *msg_data;
	u16 act_mask;
	u64 start_lba;
	u64 end_lba;
	u32 pid;
	u32 dev;
	struct dentry___388 *dir;
	struct dentry___388 *dropped_file;
	struct dentry___388 *msg_file;
	struct list_head running_list;
	atomic_t dropped;
};

struct kernel_param_ops___316 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___316 *);
	int (*get)(char *, const struct kernel_param___316 *);
	void (*free)(void *);
};

struct kparam_array___316;

struct kernel_param___316 {
	const char *name;
	struct module___318 *mod;
	const struct kernel_param_ops___316 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___316 *arr;
	};
};

struct kparam_array___316 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___316 *ops;
	void *elem;
};

struct module_attribute___316 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___316 *, struct module_kobject___316 *, char *);
	ssize_t (*store)(struct module_attribute___316 *, struct module_kobject___316 *, const char *, size_t);
	void (*setup)(struct module___318 *, const char *);
	int (*test)(struct module___318 *);
	void (*free)(struct module___318 *);
};

typedef int (*key_restrict_link_func_t___359)(struct key___358 *, const struct key_type *, const union key_payload *, struct key___358 *);

struct key_restriction___358;

struct key___358 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___390 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___358 *restrict_link;
};

struct key_restriction___358 {
	key_restrict_link_func_t___359 check;
	struct key___358 *key;
	struct key_type *keytype;
};

struct seq_operations___330 {
	void * (*start)(struct seq_file___330 *, loff_t *);
	void (*stop)(struct seq_file___330 *, void *);
	void * (*next)(struct seq_file___330 *, void *, loff_t *);
	int (*show)(struct seq_file___330 *, void *);
};

struct rchan_buf___12 {
	void *start;
	void *data;
	size_t offset;
	size_t subbufs_produced;
	size_t subbufs_consumed;
	struct rchan___12 *chan;
	wait_queue_head_t read_wait;
	struct irq_work wakeup_work;
	struct dentry___388 *dentry;
	struct kref kref;
	struct page___389 **page_array;
	unsigned int page_count;
	unsigned int finalized;
	size_t *padding;
	size_t prev_padding;
	size_t bytes_consumed;
	size_t early_bytes;
	unsigned int cpu;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
};

struct rchan_callbacks___12;

struct rchan___12 {
	u32 version;
	size_t subbuf_size;
	size_t n_subbufs;
	size_t alloc_size;
	struct rchan_callbacks___12 *cb;
	struct kref kref;
	void *private_data;
	size_t last_toobig;
	struct rchan_buf___12 **buf;
	int is_global;
	struct list_head list;
	struct dentry___388 *parent;
	int has_base_filename;
	char base_filename[255];
};

struct rchan_callbacks___12 {
	int (*subbuf_start)(struct rchan_buf___12 *, void *, void *, size_t);
	void (*buf_mapped)(struct rchan_buf___12 *, struct file___388 *);
	void (*buf_unmapped)(struct rchan_buf___12 *, struct file___388 *);
	struct dentry___388 * (*create_buf_file)(const char *, struct dentry___388 *, umode_t, struct rchan_buf___12 *, int *);
	int (*remove_buf_file)(struct dentry___388 *);
};

struct cgroup_namespace___242 {
	refcount_t count;
	struct ns_common___9 ns;
	struct user_namespace___258 *user_ns;
	struct ucounts___258 *ucounts;
	struct css_set___242 *root_cset;
};

struct ucounts___258 {
	struct hlist_node node;
	struct user_namespace___258 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___243;

struct bpf_map_ops___242 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___243 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___243 *, struct file___388 *);
	void (*map_free)(struct bpf_map___243 *);
	int (*map_get_next_key)(struct bpf_map___243 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___243 *);
	void * (*map_lookup_elem)(struct bpf_map___243 *, void *);
	int (*map_update_elem)(struct bpf_map___243 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___243 *, void *);
	int (*map_push_elem)(struct bpf_map___243 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___243 *, void *);
	int (*map_peek_elem)(struct bpf_map___243 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___243 *, struct file___388 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___243 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___243 *, void *, struct seq_file___330 *);
	int (*map_check_btf)(const struct bpf_map___243 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___243 {
	const struct bpf_map_ops___242 *ops;
	struct bpf_map___243 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___358 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___243;

typedef void (*kthread_work_func_t___243)(struct kthread_work___243 *);

struct kthread_worker___243;

struct kthread_work___243 {
	struct list_head node;
	kthread_work_func_t___243 func;
	struct kthread_worker___243 *worker;
	int canceling;
};

struct kthread_worker___243 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___390 *task;
	struct kthread_work___243 *current_work;
};

struct kthread_delayed_work___242 {
	struct kthread_work___243 work;
	struct timer_list timer;
};

struct psi_group___242 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___243 *poll_kworker;
	struct kthread_delayed_work___242 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___242 {
	struct kernfs_node___383 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_root___242;

struct cgroup_rstat_cpu___242;

struct cgroup___242 {
	struct cgroup_subsys_state___242 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___383 *kn;
	struct cgroup_file___242 procs_file;
	struct cgroup_file___242 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___242 *subsys[13];
	struct cgroup_root___242 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___242 *dom_cgrp;
	struct cgroup_rstat_cpu___242 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___39 bpf;
	atomic_t congestion_count;
	struct cgroup___242 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___242 psi;
	int ancestor_ids[0];
};

struct cftype___242;

struct cgroup_subsys___242 {
	struct cgroup_subsys_state___242 * (*css_alloc)(struct cgroup_subsys_state___242 *);
	int (*css_online)(struct cgroup_subsys_state___242 *);
	void (*css_offline)(struct cgroup_subsys_state___242 *);
	void (*css_released)(struct cgroup_subsys_state___242 *);
	void (*css_free)(struct cgroup_subsys_state___242 *);
	void (*css_reset)(struct cgroup_subsys_state___242 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___242 *, int);
	int (*css_extra_stat_show)(struct seq_file___330 *, struct cgroup_subsys_state___242 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___390 *);
	void (*cancel_fork)(struct task_struct___390 *);
	void (*fork)(struct task_struct___390 *);
	void (*exit)(struct task_struct___390 *);
	void (*free)(struct task_struct___390 *);
	void (*bind)(struct cgroup_subsys_state___242 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___242 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___242 *dfl_cftypes;
	struct cftype___242 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___242 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___242 *updated_children;
	struct cgroup___242 *updated_next;
};

struct cgroup_root___242 {
	struct kernfs_root___382 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___242 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___242 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___242 *ss;
	struct list_head node;
	struct kernfs_ops___382 *kf_ops;
	int (*open)(struct kernfs_open_file___382 *);
	void (*release)(struct kernfs_open_file___382 *);
	u64 (*read_u64)(struct cgroup_subsys_state___242 *, struct cftype___242 *);
	s64 (*read_s64)(struct cgroup_subsys_state___242 *, struct cftype___242 *);
	int (*seq_show)(struct seq_file___330 *, void *);
	void * (*seq_start)(struct seq_file___330 *, loff_t *);
	void * (*seq_next)(struct seq_file___330 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___330 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___242 *, struct cftype___242 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___242 *, struct cftype___242 *, s64);
	ssize_t (*write)(struct kernfs_open_file___382 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___382 *, struct poll_table_struct___236 *);
};

struct blkcg_policy_data___58;

struct blkcg___58 {
	struct cgroup_subsys_state___242 css;
	spinlock_t lock;
	struct xarray blkg_tree;
	struct blkcg_gq___58 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___58 *cpd[5];
	struct list_head all_blkcgs_node;
	struct list_head cgwb_list;
	refcount_t cgwb_refcnt;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct blkcg_policy_data___58 {
	struct blkcg___58 *blkcg;
	int plid;
};

struct blkg_policy_data___58 {
	struct blkcg_gq___58 *blkg;
	int plid;
};

struct mddev___2;

struct md_rdev___2;

struct md_cluster_operations___2 {
	int (*join)(struct mddev___2 *, int);
	int (*leave)(struct mddev___2 *);
	int (*slot_number)(struct mddev___2 *);
	int (*resync_info_update)(struct mddev___2 *, sector_t, sector_t);
	void (*resync_info_get)(struct mddev___2 *, sector_t *, sector_t *);
	int (*metadata_update_start)(struct mddev___2 *);
	int (*metadata_update_finish)(struct mddev___2 *);
	void (*metadata_update_cancel)(struct mddev___2 *);
	int (*resync_start)(struct mddev___2 *);
	int (*resync_finish)(struct mddev___2 *);
	int (*area_resyncing)(struct mddev___2 *, int, sector_t, sector_t);
	int (*add_new_disk)(struct mddev___2 *, struct md_rdev___2 *);
	void (*add_new_disk_cancel)(struct mddev___2 *);
	int (*new_disk_ack)(struct mddev___2 *, bool);
	int (*remove_disk)(struct mddev___2 *, struct md_rdev___2 *);
	void (*load_bitmaps)(struct mddev___2 *, int);
	int (*gather_bitmaps)(struct md_rdev___2 *);
	int (*resize_bitmaps)(struct mddev___2 *, sector_t, sector_t);
	int (*lock_all_bitmaps)(struct mddev___2 *);
	void (*unlock_all_bitmaps)(struct mddev___2 *);
	void (*update_size)(struct mddev___2 *, sector_t);
};

struct md_personality___2;

struct md_thread___2;

struct bitmap___2;

struct mddev___2 {
	void *private;
	struct md_personality___2 *pers;
	dev_t unit;
	int md_minor;
	struct list_head disks;
	long unsigned int flags;
	long unsigned int sb_flags;
	int suspended;
	atomic_t active_io;
	int ro;
	int sysfs_active;
	struct gendisk___109 *gendisk;
	struct kobject___376 kobj;
	int hold_active;
	int major_version;
	int minor_version;
	int patch_version;
	int persistent;
	int external;
	char metadata_type[17];
	int chunk_sectors;
	time64_t ctime;
	time64_t utime;
	int level;
	int layout;
	char clevel[16];
	int raid_disks;
	int max_disks;
	sector_t dev_sectors;
	sector_t array_sectors;
	int external_size;
	__u64 events;
	int can_decrease_events;
	char uuid[16];
	sector_t reshape_position;
	int delta_disks;
	int new_level;
	int new_layout;
	int new_chunk_sectors;
	int reshape_backwards;
	struct md_thread___2 *thread;
	struct md_thread___2 *sync_thread;
	char *last_sync_action;
	sector_t curr_resync;
	sector_t curr_resync_completed;
	long unsigned int resync_mark;
	sector_t resync_mark_cnt;
	sector_t curr_mark_cnt;
	sector_t resync_max_sectors;
	atomic64_t resync_mismatches;
	sector_t suspend_lo;
	sector_t suspend_hi;
	int sync_speed_min;
	int sync_speed_max;
	int parallel_resync;
	int ok_start_degraded;
	long unsigned int recovery;
	int recovery_disabled;
	int in_sync;
	struct mutex open_mutex;
	struct mutex reconfig_mutex;
	atomic_t active;
	atomic_t openers;
	int changed;
	int degraded;
	atomic_t recovery_active;
	wait_queue_head_t recovery_wait;
	sector_t recovery_cp;
	sector_t resync_min;
	sector_t resync_max;
	struct kernfs_node___383 *sysfs_state;
	struct kernfs_node___383 *sysfs_action;
	struct work_struct del_work;
	spinlock_t lock;
	wait_queue_head_t sb_wait;
	atomic_t pending_writes;
	unsigned int safemode;
	unsigned int safemode_delay;
	struct timer_list safemode_timer;
	struct percpu_ref writes_pending;
	int sync_checkers;
	struct request_queue___105 *queue;
	struct bitmap___2 *bitmap;
	struct {
		struct file___388 *file;
		loff_t offset;
		long unsigned int space;
		loff_t default_offset;
		long unsigned int default_space;
		struct mutex mutex;
		long unsigned int chunksize;
		long unsigned int daemon_sleep;
		long unsigned int max_write_behind;
		int external;
		int nodes;
		char cluster_name[64];
	} bitmap_info;
	atomic_t max_corr_read_errors;
	struct list_head all_mddevs;
	struct attribute_group___353 *to_remove;
	struct bio_set___191 bio_set;
	struct bio_set___191 sync_set;
	struct bio___191 *flush_bio;
	atomic_t flush_pending;
	ktime_t start_flush;
	ktime_t last_flush;
	struct work_struct flush_work;
	struct work_struct event_work;
	mempool_t *wb_info_pool;
	void (*sync_super)(struct mddev___2 *, struct md_rdev___2 *);
	struct md_cluster_info *cluster_info;
	unsigned int good_device_nr;
	bool has_superblocks: 1;
};

struct md_rdev___2 {
	struct list_head same_set;
	sector_t sectors;
	struct mddev___2 *mddev;
	int last_events;
	struct block_device___388 *meta_bdev;
	struct block_device___388 *bdev;
	struct page___389 *sb_page;
	struct page___389 *bb_page;
	int sb_loaded;
	__u64 sb_events;
	sector_t data_offset;
	sector_t new_data_offset;
	sector_t sb_start;
	int sb_size;
	int preferred_minor;
	struct kobject___376 kobj;
	long unsigned int flags;
	wait_queue_head_t blocked_wait;
	int desc_nr;
	int raid_disk;
	int new_raid_disk;
	int saved_raid_disk;
	union {
		sector_t recovery_offset;
		sector_t journal_tail;
	};
	atomic_t nr_pending;
	atomic_t read_errors;
	time64_t last_read_error;
	atomic_t corrected_errors;
	struct list_head wb_list;
	spinlock_t wb_list_lock;
	wait_queue_head_t wb_io_wait;
	struct work_struct del_work;
	struct kernfs_node___383 *sysfs_state;
	struct badblocks___5 badblocks;
	struct {
		short int offset;
		unsigned int size;
		sector_t sector;
	} ppl;
};

struct md_personality___2 {
	char *name;
	int level;
	struct list_head list;
	struct module___318 *owner;
	bool (*make_request)(struct mddev___2 *, struct bio___191 *);
	int (*run)(struct mddev___2 *);
	int (*start)(struct mddev___2 *);
	void (*free)(struct mddev___2 *, void *);
	void (*status)(struct seq_file___330 *, struct mddev___2 *);
	void (*error_handler)(struct mddev___2 *, struct md_rdev___2 *);
	int (*hot_add_disk)(struct mddev___2 *, struct md_rdev___2 *);
	int (*hot_remove_disk)(struct mddev___2 *, struct md_rdev___2 *);
	int (*spare_active)(struct mddev___2 *);
	sector_t (*sync_request)(struct mddev___2 *, sector_t, int *);
	int (*resize)(struct mddev___2 *, sector_t);
	sector_t (*size)(struct mddev___2 *, sector_t, int);
	int (*check_reshape)(struct mddev___2 *);
	int (*start_reshape)(struct mddev___2 *);
	void (*finish_reshape)(struct mddev___2 *);
	void (*update_reshape_pos)(struct mddev___2 *);
	void (*quiesce)(struct mddev___2 *, int);
	void * (*takeover)(struct mddev___2 *);
	int (*congested)(struct mddev___2 *, int);
	int (*change_consistency_policy)(struct mddev___2 *, const char *);
};

struct md_thread___2 {
	void (*run)(struct md_thread___2 *);
	struct mddev___2 *mddev;
	wait_queue_head_t wqueue;
	long unsigned int flags;
	struct task_struct___390 *tsk;
	long unsigned int timeout;
	void *private;
};

struct bitmap_storage___2 {
	struct file___388 *file;
	struct page___389 *sb_page;
	struct page___389 **filemap;
	long unsigned int *filemap_attr;
	long unsigned int file_pages;
	long unsigned int bytes;
};

struct bitmap___2 {
	struct bitmap_counts counts;
	struct mddev___2 *mddev;
	__u64 events_cleared;
	int need_sync;
	struct bitmap_storage___2 storage;
	long unsigned int flags;
	int allclean;
	atomic_t behind_writes;
	long unsigned int behind_writes_used;
	long unsigned int daemon_lastrun;
	long unsigned int last_end_sync;
	atomic_t pending_writes;
	wait_queue_head_t write_wait;
	wait_queue_head_t overflow_wait;
	wait_queue_head_t behind_wait;
	struct kernfs_node___383 *sysfs_can_clear;
	int cluster_slot;
};

struct md_sysfs_entry___2 {
	struct attribute attr;
	ssize_t (*show)(struct mddev___2 *, char *);
	ssize_t (*store)(struct mddev___2 *, const char *, size_t);
};

typedef __u16 bitmap_counter_t;

enum bitmap_state {
	BITMAP_STALE = 1,
	BITMAP_WRITE_ERROR = 2,
	BITMAP_HOSTENDIAN = 15,
};

struct bitmap_super_s {
	__le32 magic;
	__le32 version;
	__u8 uuid[16];
	__le64 events;
	__le64 events_cleared;
	__le64 sync_size;
	__le32 state;
	__le32 chunksize;
	__le32 daemon_sleep;
	__le32 write_behind;
	__le32 sectors_reserved;
	__le32 nodes;
	__u8 cluster_name[64];
	__u8 pad[120];
};

typedef struct bitmap_super_s bitmap_super_t;

enum bitmap_page_attr {
	BITMAP_PAGE_DIRTY = 0,
	BITMAP_PAGE_PENDING = 1,
	BITMAP_PAGE_NEEDWRITE = 2,
};

struct file___389;

struct kiocb___389;

struct iov_iter___164;

struct poll_table_struct___237;

struct vm_area_struct___390;

struct inode___389;

struct file_lock___389;

struct page___390;

struct seq_file___331;

struct file_operations___389 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___389 *, loff_t, int);
	ssize_t (*read)(struct file___389 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___389 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___389 *, struct iov_iter___164 *);
	ssize_t (*write_iter)(struct kiocb___389 *, struct iov_iter___164 *);
	int (*iopoll)(struct kiocb___389 *, bool);
	int (*iterate)(struct file___389 *, struct dir_context *);
	int (*iterate_shared)(struct file___389 *, struct dir_context *);
	__poll_t (*poll)(struct file___389 *, struct poll_table_struct___237 *);
	long int (*unlocked_ioctl)(struct file___389 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___389 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___389 *, struct vm_area_struct___390 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___389 *, struct file___389 *);
	int (*flush)(struct file___389 *, fl_owner_t);
	int (*release)(struct inode___389 *, struct file___389 *);
	int (*fsync)(struct file___389 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___389 *, int);
	int (*lock)(struct file___389 *, int, struct file_lock___389 *);
	ssize_t (*sendpage)(struct file___389 *, struct page___390 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___389 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___389 *, int, struct file_lock___389 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___389 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___389 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___389 *, long int, struct file_lock___389 **, void **);
	long int (*fallocate)(struct file___389 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___331 *, struct file___389 *);
	ssize_t (*copy_file_range)(struct file___389 *, loff_t, struct file___389 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___389 *, loff_t, struct file___389 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___389 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___390 {
	u64 seqnum;
	struct vm_area_struct___390 *vmas[4];
};

struct page_frag___390 {
	struct page___390 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___390;

struct cred___359;

struct nsproxy___288;

struct bio_list___192;

struct backing_dev_info___192;

struct io_context___110;

struct css_set___243;

struct request_queue___106;

struct vm_struct___294;

struct task_struct___391 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___391 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___390 *mm;
	struct mm_struct___390 *active_mm;
	struct vmacache___390 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___391 *real_parent;
	struct task_struct___391 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___391 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___224 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___224 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___224 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___359 *ptracer_cred;
	const struct cred___359 *real_cred;
	const struct cred___359 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___288 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___391 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___192 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___192 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___243 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___390 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___106 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___391 *oom_reaper_list;
	struct vm_struct___294 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___148 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rw_semaphore___391 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___391 *owner;
};

struct key___359;

struct ucounts___259;

struct user_namespace___259 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___259 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___9 ns;
	long unsigned int flags;
	struct key___359 *persistent_keyring_register;
	struct rw_semaphore___391 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___259 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct secondary_data___391 {
	void *stack;
	struct task_struct___391 *task;
	long int status;
};

typedef struct page___390 *pgtable_t___390;

struct address_space___389;

struct dev_pagemap___378;

struct page___390 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___389 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___390 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___390 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___390 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___378 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct user_struct___359 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___359 *uid_keyring;
	struct key___359 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___378;

struct vm_area_struct___390 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___390 *vm_next;
	struct vm_area_struct___390 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___390 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___378 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___389 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___390;

struct mm_struct___390 {
	struct {
		struct vm_area_struct___390 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___389 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___391 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___390 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___391 *owner;
		struct user_namespace___259 *user_ns;
		struct file___389 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___390 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___359 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___359 *session_keyring;
	struct key___359 *process_keyring;
	struct key___359 *thread_keyring;
	struct key___359 *request_key_auth;
	void *security;
	struct user_struct___359 *user;
	struct user_namespace___259 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___243;

struct nsproxy___288 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___243 *cgroup_ns;
};

struct bio___192;

struct bio_list___192 {
	struct bio___192 *head;
	struct bio___192 *tail;
};

struct bdi_writeback_congested___192;

struct cgroup_subsys_state___243;

struct bdi_writeback___192 {
	struct backing_dev_info___192 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___192 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___243 *memcg_css;
	struct cgroup_subsys_state___243 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___357;

struct dentry___389;

struct backing_dev_info___192 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___192 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___357 *dev;
	struct device___357 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___389 *debug_dir;
	struct dentry___389 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___110;

struct io_context___110 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___110 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___243;

struct css_set___243 {
	struct cgroup_subsys_state___243 *subsys[13];
	refcount_t refcount;
	struct css_set___243 *dom_cset;
	struct cgroup___243 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___243 *mg_src_cgrp;
	struct cgroup___243 *mg_dst_cgrp;
	struct css_set___243 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

typedef blk_qc_t make_request_fn___106(struct request_queue___106 *, struct bio___192 *);

struct request___106;

typedef int dma_drain_needed_fn___106(struct request___106 *);

struct kset___376;

struct kobj_type___376;

struct kernfs_node___384;

struct kobject___377 {
	const char *name;
	struct list_head entry;
	struct kobject___377 *parent;
	struct kset___376 *kset;
	struct kobj_type___376 *ktype;
	struct kernfs_node___384 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___106;

struct bsg_class_device___106 {
	struct device___357 *class_dev;
	int minor;
	struct request_queue___106 *queue;
	const struct bsg_ops___106 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___192 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___192 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___106;

struct blk_mq_ops___41;

struct blk_mq_hw_ctx___41;

struct blkcg_gq___59;

struct blk_trace___12;

struct blk_mq_tag_set___41;

struct request_queue___106 {
	struct list_head queue_head;
	struct request___106 *last_merge;
	struct elevator_queue___106 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___106 *make_request_fn;
	dma_drain_needed_fn___106 *dma_drain_needed;
	const struct blk_mq_ops___41 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___41 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___192 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___377 kobj;
	struct kobject___377 *mq_kobj;
	struct blk_integrity integrity;
	struct device___357 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___59 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace___12 *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	struct bsg_class_device___106 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set___41 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___192 bio_split;
	struct dentry___389 *debugfs_dir;
	struct dentry___389 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___294 {
	struct vm_struct___294 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___390 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct kthread_work___244;

typedef void (*kthread_work_func_t___244)(struct kthread_work___244 *);

struct kthread_worker___244;

struct kthread_work___244 {
	struct list_head node;
	kthread_work_func_t___244 func;
	struct kthread_worker___244 *worker;
	int canceling;
};

struct kthread_worker___244 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___391 *task;
	struct kthread_work___244 *current_work;
};

struct kthread_delayed_work___243 {
	struct kthread_work___244 work;
	struct timer_list timer;
};

struct pglist_data___390;

struct lruvec___390 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___390 *pgdat;
};

struct zone___390 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___390 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___390 {
	struct zone___390 *zone;
	int zone_idx;
};

struct zonelist___390 {
	struct zoneref___390 _zonerefs[25];
};

struct pglist_data___390 {
	struct zone___390 node_zones[3];
	struct zonelist___390 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___391 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___391 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___390 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___390 {
	struct rw_semaphore___391 rwsem;
	struct notifier_block *head;
};

struct bio_vec___194 {
	struct page___390 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

typedef void bio_end_io_t___192(struct bio___192 *);

struct gendisk___110;

struct bio_integrity_payload___192;

struct bio___192 {
	struct bio___192 *bi_next;
	struct gendisk___110 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___192 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___59 *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___192 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___194 *bi_io_vec;
	struct bio_set___192 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___194 bi_inline_vecs[0];
};

struct bio_integrity_payload___192 {
	struct bio___192 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___194 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___194 bip_inline_vecs[0];
};

struct dev_pm_info___357 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___357 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___357;

struct bus_type___357;

struct device_driver___357;

struct dev_pm_domain___357;

struct fwnode_handle___278;

struct class___357;

struct attribute_group___354;

struct device___357 {
	struct device___357 *parent;
	struct device_private *p;
	struct kobject___377 kobj;
	const char *init_name;
	const struct device_type___357 *type;
	struct mutex mutex;
	struct bus_type___357 *bus;
	struct device_driver___357 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___357 power;
	struct dev_pm_domain___357 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___278 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___357 *class;
	const struct attribute_group___354 **groups;
	void (*release)(struct device___357 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct hd_struct___110 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___357 __dev;
	struct kobject___377 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___110;

struct block_device_operations___107;

struct gendisk___110 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___110 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___110 *part_tbl;
	struct hd_struct___110 part0;
	const struct block_device_operations___107 *fops;
	struct request_queue___106 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___391 lookup_sem;
	struct kobject___377 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___377 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct blkcg___59;

struct blkg_policy_data___59;

struct blkcg_gq___59 {
	struct request_queue___106 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___59 *blkcg;
	struct bdi_writeback_congested___192 *wb_congested;
	struct blkcg_gq___59 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_rwstat stat_bytes;
	struct blkg_rwstat stat_ios;
	struct blkg_policy_data___59 *pd[5];
	struct callback_head callback_head;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
};

struct dev_pm_ops___357;

struct device_type___357 {
	const char *name;
	const struct attribute_group___354 **groups;
	int (*uevent)(struct device___357 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___357 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___357 *);
	const struct dev_pm_ops___357 *pm;
};

struct class___357 {
	const char *name;
	struct module___11 *owner;
	const struct attribute_group___354 **class_groups;
	const struct attribute_group___354 **dev_groups;
	struct kobject___377 *dev_kobj;
	int (*dev_uevent)(struct device___357 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___357 *, umode_t *);
	void (*class_release)(struct class___357 *);
	void (*dev_release)(struct device___357 *);
	int (*shutdown_pre)(struct device___357 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___357 *);
	const struct dev_pm_ops___357 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct kernfs_root___383;

struct kernfs_elem_dir___383 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___383 *root;
};

struct kernfs_syscall_ops___383;

struct kernfs_root___383 {
	struct kernfs_node___384 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___383 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___383 {
	struct kernfs_node___384 *target_kn;
};

struct kernfs_ops___383;

struct kernfs_elem_attr___383 {
	const struct kernfs_ops___383 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___384 *notify_next;
};

struct kernfs_node___384 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___384 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___383 dir;
		struct kernfs_elem_symlink___383 symlink;
		struct kernfs_elem_attr___383 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___383;

struct kernfs_ops___383 {
	int (*open)(struct kernfs_open_file___383 *);
	void (*release)(struct kernfs_open_file___383 *);
	int (*seq_show)(struct seq_file___331 *, void *);
	void * (*seq_start)(struct seq_file___331 *, loff_t *);
	void * (*seq_next)(struct seq_file___331 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___331 *, void *);
	ssize_t (*read)(struct kernfs_open_file___383 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___383 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___383 *, struct vm_area_struct___390 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___383 *, struct poll_table_struct___237 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___383 {
	int (*remount_fs)(struct kernfs_root___383 *, int *, char *);
	int (*show_options)(struct seq_file___331 *, struct kernfs_root___383 *);
	int (*mkdir)(struct kernfs_node___384 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___384 *);
	int (*rename)(struct kernfs_node___384 *, struct kernfs_node___384 *, const char *);
	int (*show_path)(struct seq_file___331 *, struct kernfs_node___384 *, struct kernfs_root___383 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___331;

struct seq_file___331 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___331 *op;
	int poll_event;
	const struct file___389 *file;
	void *private;
};

struct kernfs_open_file___383 {
	struct kernfs_node___384 *kn;
	struct file___389 *file;
	struct seq_file___331 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___378 *vm_ops;
};

struct path___390 {
	struct vfsmount *mnt;
	struct dentry___389 *dentry;
};

struct file___389 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___390 f_path;
	struct inode___389 *f_inode;
	const struct file_operations___389 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___224 f_owner;
	const struct cred___359 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___389 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___378;

struct vm_operations_struct___378 {
	void (*open)(struct vm_area_struct___390 *);
	void (*close)(struct vm_area_struct___390 *);
	int (*split)(struct vm_area_struct___390 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___390 *);
	vm_fault_t (*fault)(struct vm_fault___378 *);
	vm_fault_t (*huge_fault)(struct vm_fault___378 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___378 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___390 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___378 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___378 *);
	int (*access)(struct vm_area_struct___390 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___390 *);
	int (*set_policy)(struct vm_area_struct___390 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___390 *, long unsigned int);
	struct page___390 * (*find_special_page)(struct vm_area_struct___390 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___245)(struct file___389 *, wait_queue_head_t *, struct poll_table_struct___237 *);

struct poll_table_struct___237 {
	poll_queue_proc___245 _qproc;
	__poll_t _key;
};

struct bin_attribute___353;

struct attribute_group___354 {
	const char *name;
	umode_t (*is_visible)(struct kobject___377 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___377 *, struct bin_attribute___353 *, int);
	struct attribute **attrs;
	struct bin_attribute___353 **bin_attrs;
};

struct bin_attribute___353 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___389 *, struct kobject___377 *, struct bin_attribute___353 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___389 *, struct kobject___377 *, struct bin_attribute___353 *, char *, loff_t, size_t);
	int (*mmap)(struct file___389 *, struct kobject___377 *, struct bin_attribute___353 *, struct vm_area_struct___390 *);
};

struct sysfs_ops___376 {
	ssize_t (*show)(struct kobject___377 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___377 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___376;

struct kset___376 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___377 kobj;
	const struct kset_uevent_ops___376 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___376 {
	void (*release)(struct kobject___377 *);
	const struct sysfs_ops___376 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___29 * (*child_ns_type)(struct kobject___377 *);
	const void * (*namespace)(struct kobject___377 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___376 {
	int (* const filter)(struct kset___376 *, struct kobject___377 *);
	const char * (* const name)(struct kset___376 *, struct kobject___377 *);
	int (* const uevent)(struct kset___376 *, struct kobject___377 *, struct kobj_uevent_env *);
};

struct kobj_attribute___368 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___377 *, struct kobj_attribute___368 *, char *);
	ssize_t (*store)(struct kobject___377 *, struct kobj_attribute___368 *, const char *, size_t);
};

struct dev_pm_ops___357 {
	int (*prepare)(struct device___357 *);
	void (*complete)(struct device___357 *);
	int (*suspend)(struct device___357 *);
	int (*resume)(struct device___357 *);
	int (*freeze)(struct device___357 *);
	int (*thaw)(struct device___357 *);
	int (*poweroff)(struct device___357 *);
	int (*restore)(struct device___357 *);
	int (*suspend_late)(struct device___357 *);
	int (*resume_early)(struct device___357 *);
	int (*freeze_late)(struct device___357 *);
	int (*thaw_early)(struct device___357 *);
	int (*poweroff_late)(struct device___357 *);
	int (*restore_early)(struct device___357 *);
	int (*suspend_noirq)(struct device___357 *);
	int (*resume_noirq)(struct device___357 *);
	int (*freeze_noirq)(struct device___357 *);
	int (*thaw_noirq)(struct device___357 *);
	int (*poweroff_noirq)(struct device___357 *);
	int (*restore_noirq)(struct device___357 *);
	int (*runtime_suspend)(struct device___357 *);
	int (*runtime_resume)(struct device___357 *);
	int (*runtime_idle)(struct device___357 *);
};

struct dev_pm_domain___357 {
	struct dev_pm_ops___357 ops;
	void (*detach)(struct device___357 *, bool);
	int (*activate)(struct device___357 *);
	void (*sync)(struct device___357 *);
	void (*dismiss)(struct device___357 *);
};

struct bus_type___357 {
	const char *name;
	const char *dev_name;
	struct device___357 *dev_root;
	const struct attribute_group___354 **bus_groups;
	const struct attribute_group___354 **dev_groups;
	const struct attribute_group___354 **drv_groups;
	int (*match)(struct device___357 *, struct device_driver___357 *);
	int (*uevent)(struct device___357 *, struct kobj_uevent_env *);
	int (*probe)(struct device___357 *);
	int (*remove)(struct device___357 *);
	void (*shutdown)(struct device___357 *);
	int (*online)(struct device___357 *);
	int (*offline)(struct device___357 *);
	int (*suspend)(struct device___357 *, pm_message_t);
	int (*resume)(struct device___357 *);
	int (*num_vf)(struct device___357 *);
	int (*dma_configure)(struct device___357 *);
	const struct dev_pm_ops___357 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___357 {
	const char *name;
	struct bus_type___357 *bus;
	struct module___11 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___357 *);
	int (*remove)(struct device___357 *);
	void (*shutdown)(struct device___357 *);
	int (*suspend)(struct device___357 *, pm_message_t);
	int (*resume)(struct device___357 *);
	const struct attribute_group___354 **groups;
	const struct dev_pm_ops___357 *pm;
	void (*coredump)(struct device___357 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct fwnode_operations___278;

struct fwnode_handle___278 {
	struct fwnode_handle___278 *secondary;
	const struct fwnode_operations___278 *ops;
};

struct dentry_operations___389;

struct super_block___389;

struct dentry___389 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___389 *d_parent;
	struct qstr d_name;
	struct inode___389 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___389 *d_op;
	struct super_block___389 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___389;

struct address_space___389 {
	struct inode___389 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___391 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___389 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___389;

struct block_device___389;

struct inode___389 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___389 *i_op;
	struct super_block___389 *i_sb;
	struct address_space___389 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___391 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___192 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___389 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___389 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___389 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___389 {
	int (*d_revalidate)(struct dentry___389 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___389 *, unsigned int);
	int (*d_hash)(const struct dentry___389 *, struct qstr *);
	int (*d_compare)(const struct dentry___389 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___389 *);
	int (*d_init)(struct dentry___389 *);
	void (*d_release)(struct dentry___389 *);
	void (*d_prune)(struct dentry___389 *);
	void (*d_iput)(struct dentry___389 *, struct inode___389 *);
	char * (*d_dname)(struct dentry___389 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___390 *);
	int (*d_manage)(const struct path___390 *, bool);
	struct dentry___389 * (*d_real)(struct dentry___389 *, const struct inode___389 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___389;

struct mem_dqinfo___389 {
	struct quota_format_type___389 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___389;

struct quota_info___389 {
	unsigned int flags;
	struct rw_semaphore___391 dqio_sem;
	struct inode___389 *files[3];
	struct mem_dqinfo___389 info[3];
	const struct quota_format_ops___389 *ops[3];
};

struct rcuwait___389 {
	struct task_struct___391 *task;
};

struct percpu_rw_semaphore___389 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___391 rw_sem;
	struct rcuwait___389 writer;
	int readers_block;
};

struct sb_writers___389 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___389 rw_sem[3];
};

struct file_system_type___389;

struct super_operations___389;

struct dquot_operations___389;

struct quotactl_ops___389;

struct super_block___389 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___389 *s_type;
	const struct super_operations___389 *s_op;
	const struct dquot_operations___389 *dq_op;
	const struct quotactl_ops___389 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___389 *s_root;
	struct rw_semaphore___391 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___389 *s_bdev;
	struct backing_dev_info___192 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___389 s_dquot;
	struct sb_writers___389 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___389 *s_d_op;
	int cleancache_poolid;
	struct shrinker___135 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___259 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

typedef int (*dev_page_fault_t___378)(struct vm_area_struct___390 *, long unsigned int, const struct page___390 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___378)(struct page___390 *, void *);

struct dev_pagemap___378 {
	dev_page_fault_t___378 page_fault;
	dev_page_free_t___378 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___357 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___390 {
	struct task_struct___391 *task;
	struct core_thread___390 *next;
};

struct core_state___390 {
	atomic_t nr_threads;
	struct core_thread___390 dumper;
	struct completion startup;
};

struct vm_fault___378 {
	struct vm_area_struct___390 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___390 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___390 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___390 prealloc_pte;
};

struct io_cq___110 {
	struct request_queue___106 *q;
	struct io_context___110 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___389 {
	struct file___389 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___389 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___389 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___389 *ia_file;
};

struct dquot___389 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___389 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___389 {
	int qf_fmt_id;
	const struct quota_format_ops___389 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___389 *qf_next;
};

struct quota_format_ops___389 {
	int (*check_quota_file)(struct super_block___389 *, int);
	int (*read_file_info)(struct super_block___389 *, int);
	int (*write_file_info)(struct super_block___389 *, int);
	int (*free_file_info)(struct super_block___389 *, int);
	int (*read_dqblk)(struct dquot___389 *);
	int (*commit_dqblk)(struct dquot___389 *);
	int (*release_dqblk)(struct dquot___389 *);
	int (*get_next_id)(struct super_block___389 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___389 {
	int (*write_dquot)(struct dquot___389 *);
	struct dquot___389 * (*alloc_dquot)(struct super_block___389 *, int);
	void (*destroy_dquot)(struct dquot___389 *);
	int (*acquire_dquot)(struct dquot___389 *);
	int (*release_dquot)(struct dquot___389 *);
	int (*mark_dirty)(struct dquot___389 *);
	int (*write_info)(struct super_block___389 *, int);
	qsize_t * (*get_reserved_space)(struct inode___389 *);
	int (*get_projid)(struct inode___389 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___389 *, qsize_t *);
	int (*get_next_id)(struct super_block___389 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___389 {
	int (*quota_on)(struct super_block___389 *, int, int, const struct path___390 *);
	int (*quota_off)(struct super_block___389 *, int);
	int (*quota_enable)(struct super_block___389 *, unsigned int);
	int (*quota_disable)(struct super_block___389 *, unsigned int);
	int (*quota_sync)(struct super_block___389 *, int);
	int (*set_info)(struct super_block___389 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___389 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___389 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___389 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___389 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___389 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___155;

struct address_space_operations___389 {
	int (*writepage)(struct page___390 *, struct writeback_control___155 *);
	int (*readpage)(struct file___389 *, struct page___390 *);
	int (*writepages)(struct address_space___389 *, struct writeback_control___155 *);
	int (*set_page_dirty)(struct page___390 *);
	int (*readpages)(struct file___389 *, struct address_space___389 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___389 *, struct address_space___389 *, loff_t, unsigned int, unsigned int, struct page___390 **, void **);
	int (*write_end)(struct file___389 *, struct address_space___389 *, loff_t, unsigned int, unsigned int, struct page___390 *, void *);
	sector_t (*bmap)(struct address_space___389 *, sector_t);
	void (*invalidatepage)(struct page___390 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___390 *, gfp_t);
	void (*freepage)(struct page___390 *);
	ssize_t (*direct_IO)(struct kiocb___389 *, struct iov_iter___164 *);
	int (*migratepage)(struct address_space___389 *, struct page___390 *, struct page___390 *, enum migrate_mode);
	bool (*isolate_page)(struct page___390 *, isolate_mode_t);
	void (*putback_page)(struct page___390 *);
	int (*launder_page)(struct page___390 *);
	int (*is_partially_uptodate)(struct page___390 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___390 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___389 *, struct page___390 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___389 *, sector_t *);
	void (*swap_deactivate)(struct file___389 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___155 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___192 *wb;
	struct inode___389 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct iov_iter___164 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___194 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___389 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___389 *bd_inode;
	struct super_block___389 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___389 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___110 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___110 *bd_disk;
	struct request_queue___106 *bd_queue;
	struct backing_dev_info___192 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___389 {
	struct dentry___389 * (*lookup)(struct inode___389 *, struct dentry___389 *, unsigned int);
	const char * (*get_link)(struct dentry___389 *, struct inode___389 *, struct delayed_call *);
	int (*permission)(struct inode___389 *, int);
	struct posix_acl * (*get_acl)(struct inode___389 *, int);
	int (*readlink)(struct dentry___389 *, char *, int);
	int (*create)(struct inode___389 *, struct dentry___389 *, umode_t, bool);
	int (*link)(struct dentry___389 *, struct inode___389 *, struct dentry___389 *);
	int (*unlink)(struct inode___389 *, struct dentry___389 *);
	int (*symlink)(struct inode___389 *, struct dentry___389 *, const char *);
	int (*mkdir)(struct inode___389 *, struct dentry___389 *, umode_t);
	int (*rmdir)(struct inode___389 *, struct dentry___389 *);
	int (*mknod)(struct inode___389 *, struct dentry___389 *, umode_t, dev_t);
	int (*rename)(struct inode___389 *, struct dentry___389 *, struct inode___389 *, struct dentry___389 *, unsigned int);
	int (*setattr)(struct dentry___389 *, struct iattr___389 *);
	int (*getattr)(const struct path___390 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___389 *, char *, size_t);
	int (*fiemap)(struct inode___389 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___389 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___389 *, struct dentry___389 *, struct file___389 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___389 *, struct dentry___389 *, umode_t);
	int (*set_acl)(struct inode___389 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___389 {
	void (*fl_copy_lock)(struct file_lock___389 *, struct file_lock___389 *);
	void (*fl_release_private)(struct file_lock___389 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___389;

struct lock_manager_operations___389;

struct file_lock___389 {
	struct file_lock___389 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___389 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___389 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___389 *fl_ops;
	const struct lock_manager_operations___389 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___389 {
	int (*lm_compare_owner)(struct file_lock___389 *, struct file_lock___389 *);
	long unsigned int (*lm_owner_key)(struct file_lock___389 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___389 *);
	int (*lm_grant)(struct file_lock___389 *, int);
	bool (*lm_break)(struct file_lock___389 *);
	int (*lm_change)(struct file_lock___389 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___389 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___389 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___389 *fa_next;
	struct file___389 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___389 {
	const char *name;
	int fs_flags;
	struct dentry___389 * (*mount)(struct file_system_type___389 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___389 *);
	struct module___11 *owner;
	struct file_system_type___389 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___389 {
	struct inode___389 * (*alloc_inode)(struct super_block___389 *);
	void (*destroy_inode)(struct inode___389 *);
	void (*dirty_inode)(struct inode___389 *, int);
	int (*write_inode)(struct inode___389 *, struct writeback_control___155 *);
	int (*drop_inode)(struct inode___389 *);
	void (*evict_inode)(struct inode___389 *);
	void (*put_super)(struct super_block___389 *);
	int (*sync_fs)(struct super_block___389 *, int);
	int (*freeze_super)(struct super_block___389 *);
	int (*freeze_fs)(struct super_block___389 *);
	int (*thaw_super)(struct super_block___389 *);
	int (*unfreeze_fs)(struct super_block___389 *);
	int (*statfs)(struct dentry___389 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___389 *, int *, char *);
	void (*umount_begin)(struct super_block___389 *);
	int (*show_options)(struct seq_file___331 *, struct dentry___389 *);
	int (*show_devname)(struct seq_file___331 *, struct dentry___389 *);
	int (*show_path)(struct seq_file___331 *, struct dentry___389 *);
	int (*show_stats)(struct seq_file___331 *, struct dentry___389 *);
	ssize_t (*quota_read)(struct super_block___389 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___389 *, int, const char *, size_t, loff_t);
	struct dquot___389 ** (*get_dquots)(struct inode___389 *);
	int (*bdev_try_to_free_page)(struct super_block___389 *, struct page___390 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___389 *, struct shrink_control___135 *);
	long int (*free_cached_objects)(struct super_block___389 *, struct shrink_control___135 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___110 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___110 *last_lookup;
	struct hd_struct___110 *part[0];
};

struct block_device_operations___107 {
	int (*open)(struct block_device___389 *, fmode_t);
	void (*release)(struct gendisk___110 *, fmode_t);
	int (*rw_page)(struct block_device___389 *, sector_t, struct page___390 *, unsigned int);
	int (*ioctl)(struct block_device___389 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___389 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___110 *, unsigned int);
	int (*media_changed)(struct gendisk___110 *);
	void (*unlock_native_capacity)(struct gendisk___110 *);
	int (*revalidate_disk)(struct gendisk___110 *);
	int (*getgeo)(struct block_device___389 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___389 *, long unsigned int);
	int (*report_zones)(struct gendisk___110 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___11 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___378(struct page___390 *);

struct bdi_writeback_congested___192 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___192 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct cgroup_subsys___243;

struct cgroup_subsys_state___243 {
	struct cgroup___243 *cgroup;
	struct cgroup_subsys___243 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___243 *parent;
};

struct bsg_ops___106 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___106 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___106 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___106 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___106(struct request___106 *, blk_status_t);

struct request___106 {
	struct request_queue___106 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___41 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___192 *bio;
	struct bio___192 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___194 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___110 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___106 *saved_end_io;
		} flush;
	};
	struct gendisk___110 *rq_disk;
	struct hd_struct___110 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___106 *end_io;
	void *end_io_data;
	struct request___106 *next_rq;
};

struct fwnode_reference_args___278;

struct fwnode_endpoint___278;

struct fwnode_operations___278 {
	struct fwnode_handle___278 * (*get)(struct fwnode_handle___278 *);
	void (*put)(struct fwnode_handle___278 *);
	bool (*device_is_available)(const struct fwnode_handle___278 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___278 *, const struct device___357 *);
	bool (*property_present)(const struct fwnode_handle___278 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___278 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___278 *, const char *, const char **, size_t);
	struct fwnode_handle___278 * (*get_parent)(const struct fwnode_handle___278 *);
	struct fwnode_handle___278 * (*get_next_child_node)(const struct fwnode_handle___278 *, struct fwnode_handle___278 *);
	struct fwnode_handle___278 * (*get_named_child_node)(const struct fwnode_handle___278 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___278 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___278 *);
	struct fwnode_handle___278 * (*graph_get_next_endpoint)(const struct fwnode_handle___278 *, struct fwnode_handle___278 *);
	struct fwnode_handle___278 * (*graph_get_remote_endpoint)(const struct fwnode_handle___278 *);
	struct fwnode_handle___278 * (*graph_get_port_parent)(struct fwnode_handle___278 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___278 *, struct fwnode_endpoint___278 *);
};

struct fwnode_endpoint___278 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___278 *local_fwnode;
};

struct fwnode_reference_args___278 {
	struct fwnode_handle___278 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct blk_mq_hw_ctx___41 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___106 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags___4 *tags;
	struct blk_mq_tags___4 *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	unsigned int rh_reserved_nr_expired;
	struct hlist_node cpuhp_dead;
	struct kobject___377 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___389 *debugfs_dir;
	struct dentry___389 *sched_debugfs_dir;
	struct list_head hctx_list;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___106;

struct elevator_mq_ops___106 {
	int (*init_sched)(struct request_queue___106 *, struct elevator_type___106 *);
	void (*exit_sched)(struct elevator_queue___106 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___41 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___41 *, unsigned int);
	bool (*allow_merge)(struct request_queue___106 *, struct request___106 *, struct bio___192 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx___41 *, struct bio___192 *);
	int (*request_merge)(struct request_queue___106 *, struct request___106 **, struct bio___192 *);
	void (*request_merged)(struct request_queue___106 *, struct request___106 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___106 *, struct request___106 *, struct request___106 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___106 *, struct bio___192 *);
	void (*finish_request)(struct request___106 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___41 *, struct list_head *, bool);
	struct request___106 * (*dispatch_request)(struct blk_mq_hw_ctx___41 *);
	bool (*has_work)(struct blk_mq_hw_ctx___41 *);
	void (*completed_request)(struct request___106 *, u64);
	void (*started_request)(struct request___106 *);
	void (*requeue_request)(struct request___106 *);
	struct request___106 * (*former_request)(struct request_queue___106 *, struct request___106 *);
	struct request___106 * (*next_request)(struct request_queue___106 *, struct request___106 *);
	void (*init_icq)(struct io_cq___110 *);
	void (*exit_icq)(struct io_cq___110 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx___41 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___106;

struct elevator_type___106 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___106 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___106 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___11 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___106 {
	struct elevator_type___106 *type;
	void *elevator_data;
	struct kobject___377 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___106 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___106 *, char *);
	ssize_t (*store)(struct elevator_queue___106 *, const char *, size_t);
};

struct blk_mq_queue_data___41;

typedef blk_status_t queue_rq_fn___41(struct blk_mq_hw_ctx___41 *, const struct blk_mq_queue_data___41 *);

typedef void commit_rqs_fn___41(struct blk_mq_hw_ctx___41 *);

typedef bool get_budget_fn___41(struct blk_mq_hw_ctx___41 *);

typedef void put_budget_fn___41(struct blk_mq_hw_ctx___41 *);

typedef enum blk_eh_timer_return timeout_fn___41(struct request___106 *, bool);

typedef int poll_fn___41(struct blk_mq_hw_ctx___41 *);

typedef void complete_fn___41(struct request___106 *);

typedef int init_hctx_fn___41(struct blk_mq_hw_ctx___41 *, void *, unsigned int);

typedef void exit_hctx_fn___41(struct blk_mq_hw_ctx___41 *, unsigned int);

typedef int init_request_fn___41(struct blk_mq_tag_set___41 *, struct request___106 *, unsigned int, unsigned int);

typedef void exit_request_fn___41(struct blk_mq_tag_set___41 *, struct request___106 *, unsigned int);

typedef bool busy_fn___41(struct request_queue___106 *);

typedef int map_queues_fn___41(struct blk_mq_tag_set___41 *);

typedef void cleanup_rq_fn___41(struct request___106 *);

struct blk_mq_ops___41 {
	queue_rq_fn___41 *queue_rq;
	commit_rqs_fn___41 *commit_rqs;
	get_budget_fn___41 *get_budget;
	put_budget_fn___41 *put_budget;
	timeout_fn___41 *timeout;
	poll_fn___41 *poll;
	complete_fn___41 *complete;
	init_hctx_fn___41 *init_hctx;
	exit_hctx_fn___41 *exit_hctx;
	init_request_fn___41 *init_request;
	exit_request_fn___41 *exit_request;
	void (*initialize_rq_fn)(struct request___106 *);
	busy_fn___41 *busy;
	map_queues_fn___41 *map_queues;
	void (*show_rq)(struct seq_file___331 *, struct request___106 *);
	union {
		cleanup_rq_fn___41 *cleanup_rq;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide42;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct rchan___13;

struct blk_trace___12 {
	int trace_state;
	struct rchan___13 *rchan;
	long unsigned int *sequence;
	unsigned char *msg_data;
	u16 act_mask;
	u64 start_lba;
	u64 end_lba;
	u32 pid;
	u32 dev;
	struct dentry___389 *dir;
	struct dentry___389 *dropped_file;
	struct dentry___389 *msg_file;
	struct list_head running_list;
	atomic_t dropped;
};

struct blk_mq_tag_set___41 {
	struct blk_mq_queue_map map[6];
	unsigned int nr_maps;
	const struct blk_mq_ops___41 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	struct blk_mq_tags___4 **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct blk_mq_queue_data___41 {
	struct request___106 *rq;
	bool last;
	long unsigned int rh_reserved1;
};

struct rchan_buf___13 {
	void *start;
	void *data;
	size_t offset;
	size_t subbufs_produced;
	size_t subbufs_consumed;
	struct rchan___13 *chan;
	wait_queue_head_t read_wait;
	struct irq_work wakeup_work;
	struct dentry___389 *dentry;
	struct kref kref;
	struct page___390 **page_array;
	unsigned int page_count;
	unsigned int finalized;
	size_t *padding;
	size_t prev_padding;
	size_t bytes_consumed;
	size_t early_bytes;
	unsigned int cpu;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
};

struct rchan_callbacks___13;

struct rchan___13 {
	u32 version;
	size_t subbuf_size;
	size_t n_subbufs;
	size_t alloc_size;
	struct rchan_callbacks___13 *cb;
	struct kref kref;
	void *private_data;
	size_t last_toobig;
	struct rchan_buf___13 **buf;
	int is_global;
	struct list_head list;
	struct dentry___389 *parent;
	int has_base_filename;
	char base_filename[255];
};

struct rchan_callbacks___13 {
	int (*subbuf_start)(struct rchan_buf___13 *, void *, void *, size_t);
	void (*buf_mapped)(struct rchan_buf___13 *, struct file___389 *);
	void (*buf_unmapped)(struct rchan_buf___13 *, struct file___389 *);
	struct dentry___389 * (*create_buf_file)(const char *, struct dentry___389 *, umode_t, struct rchan_buf___13 *, int *);
	int (*remove_buf_file)(struct dentry___389 *);
};

typedef int (*key_restrict_link_func_t___360)(struct key___359 *, const struct key_type *, const union key_payload *, struct key___359 *);

struct key_restriction___359;

struct key___359 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___391 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___359 *restrict_link;
};

struct key_restriction___359 {
	key_restrict_link_func_t___360 check;
	struct key___359 *key;
	struct key_type *keytype;
};

struct seq_operations___331 {
	void * (*start)(struct seq_file___331 *, loff_t *);
	void (*stop)(struct seq_file___331 *, void *);
	void * (*next)(struct seq_file___331 *, void *, loff_t *);
	int (*show)(struct seq_file___331 *, void *);
};

struct cgroup_namespace___243 {
	refcount_t count;
	struct ns_common___9 ns;
	struct user_namespace___259 *user_ns;
	struct ucounts___259 *ucounts;
	struct css_set___243 *root_cset;
};

struct ucounts___259 {
	struct hlist_node node;
	struct user_namespace___259 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___244;

struct bpf_map_ops___243 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___244 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___244 *, struct file___389 *);
	void (*map_free)(struct bpf_map___244 *);
	int (*map_get_next_key)(struct bpf_map___244 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___244 *);
	void * (*map_lookup_elem)(struct bpf_map___244 *, void *);
	int (*map_update_elem)(struct bpf_map___244 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___244 *, void *);
	int (*map_push_elem)(struct bpf_map___244 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___244 *, void *);
	int (*map_peek_elem)(struct bpf_map___244 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___244 *, struct file___389 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___244 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___244 *, void *, struct seq_file___331 *);
	int (*map_check_btf)(const struct bpf_map___244 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___244 {
	const struct bpf_map_ops___243 *ops;
	struct bpf_map___244 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___359 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct psi_group___243 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___244 *poll_kworker;
	struct kthread_delayed_work___243 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___243 {
	struct kernfs_node___384 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_root___243;

struct cgroup_rstat_cpu___243;

struct cgroup___243 {
	struct cgroup_subsys_state___243 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___384 *kn;
	struct cgroup_file___243 procs_file;
	struct cgroup_file___243 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___243 *subsys[13];
	struct cgroup_root___243 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___243 *dom_cgrp;
	struct cgroup_rstat_cpu___243 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___39 bpf;
	atomic_t congestion_count;
	struct cgroup___243 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___243 psi;
	int ancestor_ids[0];
};

struct cftype___243;

struct cgroup_subsys___243 {
	struct cgroup_subsys_state___243 * (*css_alloc)(struct cgroup_subsys_state___243 *);
	int (*css_online)(struct cgroup_subsys_state___243 *);
	void (*css_offline)(struct cgroup_subsys_state___243 *);
	void (*css_released)(struct cgroup_subsys_state___243 *);
	void (*css_free)(struct cgroup_subsys_state___243 *);
	void (*css_reset)(struct cgroup_subsys_state___243 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___243 *, int);
	int (*css_extra_stat_show)(struct seq_file___331 *, struct cgroup_subsys_state___243 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___391 *);
	void (*cancel_fork)(struct task_struct___391 *);
	void (*fork)(struct task_struct___391 *);
	void (*exit)(struct task_struct___391 *);
	void (*free)(struct task_struct___391 *);
	void (*bind)(struct cgroup_subsys_state___243 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___243 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___243 *dfl_cftypes;
	struct cftype___243 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___243 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___243 *updated_children;
	struct cgroup___243 *updated_next;
};

struct cgroup_root___243 {
	struct kernfs_root___383 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___243 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___243 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___243 *ss;
	struct list_head node;
	struct kernfs_ops___383 *kf_ops;
	int (*open)(struct kernfs_open_file___383 *);
	void (*release)(struct kernfs_open_file___383 *);
	u64 (*read_u64)(struct cgroup_subsys_state___243 *, struct cftype___243 *);
	s64 (*read_s64)(struct cgroup_subsys_state___243 *, struct cftype___243 *);
	int (*seq_show)(struct seq_file___331 *, void *);
	void * (*seq_start)(struct seq_file___331 *, loff_t *);
	void * (*seq_next)(struct seq_file___331 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___331 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___243 *, struct cftype___243 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___243 *, struct cftype___243 *, s64);
	ssize_t (*write)(struct kernfs_open_file___383 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___383 *, struct poll_table_struct___237 *);
};

struct blkcg_policy_data___59;

struct blkcg___59 {
	struct cgroup_subsys_state___243 css;
	spinlock_t lock;
	struct xarray blkg_tree;
	struct blkcg_gq___59 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___59 *cpd[5];
	struct list_head all_blkcgs_node;
	struct list_head cgwb_list;
	refcount_t cgwb_refcnt;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct blkcg_policy_data___59 {
	struct blkcg___59 *blkcg;
	int plid;
};

struct blkg_policy_data___59 {
	struct blkcg_gq___59 *blkg;
	int plid;
};

struct dm_kobject_holder {
	struct kobject___377 kobj;
	struct completion completion;
};

enum {
	EDAC_REPORTING_ENABLED = 0,
	EDAC_REPORTING_DISABLED = 1,
	EDAC_REPORTING_FORCE = 2,
};

enum dev_type {
	DEV_UNKNOWN = 0,
	DEV_X1 = 1,
	DEV_X2 = 2,
	DEV_X4 = 3,
	DEV_X8 = 4,
	DEV_X16 = 5,
	DEV_X32 = 6,
	DEV_X64 = 7,
};

enum hw_event_mc_err_type {
	HW_EVENT_ERR_CORRECTED = 0,
	HW_EVENT_ERR_UNCORRECTED = 1,
	HW_EVENT_ERR_DEFERRED = 2,
	HW_EVENT_ERR_FATAL = 3,
	HW_EVENT_ERR_INFO = 4,
};

enum mem_type {
	MEM_EMPTY = 0,
	MEM_RESERVED = 1,
	MEM_UNKNOWN = 2,
	MEM_FPM = 3,
	MEM_EDO = 4,
	MEM_BEDO = 5,
	MEM_SDR = 6,
	MEM_RDR = 7,
	MEM_DDR = 8,
	MEM_RDDR = 9,
	MEM_RMBS = 10,
	MEM_DDR2 = 11,
	MEM_FB_DDR2 = 12,
	MEM_RDDR2 = 13,
	MEM_XDR = 14,
	MEM_DDR3 = 15,
	MEM_RDDR3 = 16,
	MEM_LRDDR3 = 17,
	MEM_DDR4 = 18,
	MEM_RDDR4 = 19,
	MEM_LRDDR4 = 20,
	MEM_NVDIMM = 21,
};

enum edac_type {
	EDAC_UNKNOWN = 0,
	EDAC_NONE = 1,
	EDAC_RESERVED = 2,
	EDAC_PARITY = 3,
	EDAC_EC = 4,
	EDAC_SECDED = 5,
	EDAC_S2ECD2ED = 6,
	EDAC_S4ECD4ED = 7,
	EDAC_S8ECD8ED = 8,
	EDAC_S16ECD16ED = 9,
};

enum scrub_type {
	SCRUB_UNKNOWN = 0,
	SCRUB_NONE = 1,
	SCRUB_SW_PROG = 2,
	SCRUB_SW_SRC = 3,
	SCRUB_SW_PROG_SRC = 4,
	SCRUB_SW_TUNABLE = 5,
	SCRUB_HW_PROG = 6,
	SCRUB_HW_SRC = 7,
	SCRUB_HW_PROG_SRC = 8,
	SCRUB_HW_TUNABLE = 9,
};

enum edac_mc_layer_type {
	EDAC_MC_LAYER_BRANCH = 0,
	EDAC_MC_LAYER_CHANNEL = 1,
	EDAC_MC_LAYER_SLOT = 2,
	EDAC_MC_LAYER_CHIP_SELECT = 3,
	EDAC_MC_LAYER_ALL_MEM = 4,
};

struct edac_mc_layer {
	enum edac_mc_layer_type type;
	unsigned int size;
	bool is_virt_csrow;
};

struct mem_ctl_info;

struct dimm_info {
	struct device___336 dev;
	char label[32];
	unsigned int location[3];
	struct mem_ctl_info *mci;
	u32 grain;
	enum dev_type dtype;
	enum mem_type mtype;
	enum edac_type edac_mode;
	u32 nr_pages;
	unsigned int csrow;
	unsigned int cschannel;
};

struct mcidev_sysfs_attribute;

struct edac_raw_error_desc {
	char location[256];
	char label[296];
	long int grain;
	u16 error_count;
	int top_layer;
	int mid_layer;
	int low_layer;
	long unsigned int page_frame_number;
	long unsigned int offset_in_page;
	long unsigned int syndrome;
	const char *msg;
	const char *other_detail;
	bool enable_per_layer_report;
};

struct csrow_info;

struct mem_ctl_info {
	struct device___336 dev;
	struct bus_type___336 *bus;
	struct list_head link;
	struct module___300 *owner;
	long unsigned int mtype_cap;
	long unsigned int edac_ctl_cap;
	long unsigned int edac_cap;
	long unsigned int scrub_cap;
	enum scrub_type scrub_mode;
	int (*set_sdram_scrub_rate)(struct mem_ctl_info *, u32);
	int (*get_sdram_scrub_rate)(struct mem_ctl_info *);
	void (*edac_check)(struct mem_ctl_info *);
	long unsigned int (*ctl_page_to_phys)(struct mem_ctl_info *, long unsigned int);
	int mc_idx;
	struct csrow_info **csrows;
	unsigned int nr_csrows;
	unsigned int num_cschannel;
	unsigned int n_layers;
	struct edac_mc_layer *layers;
	bool csbased;
	unsigned int tot_dimms;
	struct dimm_info **dimms;
	struct device___336 *pdev;
	const char *mod_name;
	const char *ctl_name;
	const char *dev_name;
	void *pvt_info;
	long unsigned int start_time;
	u32 ce_noinfo_count;
	u32 ue_noinfo_count;
	u32 ue_mc;
	u32 ce_mc;
	u32 *ce_per_layer[3];
	u32 *ue_per_layer[3];
	struct completion complete;
	const struct mcidev_sysfs_attribute *mc_driver_sysfs_attributes;
	struct delayed_work work;
	struct edac_raw_error_desc error_desc;
	int op_state;
	struct dentry___368 *debugfs;
	u8 fake_inject_layer[3];
	bool fake_inject_ue;
	u16 fake_inject_count;
};

struct rank_info {
	int chan_idx;
	struct csrow_info *csrow;
	struct dimm_info *dimm;
	u32 ce_count;
};

struct csrow_info {
	struct device___336 dev;
	long unsigned int first_page;
	long unsigned int last_page;
	long unsigned int page_mask;
	int csrow_idx;
	u32 ue_count;
	u32 ce_count;
	struct mem_ctl_info *mci;
	u32 nr_channels;
	struct rank_info **channels;
};

struct page___391;

typedef struct page___391 *pgtable_t___391;

struct address_space___390;

struct mm_struct___391;

struct dev_pagemap___379;

struct page___391 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___390 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___391 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___391 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___391 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___379 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct module___319;

struct file___390;

struct kiocb___390;

struct vm_area_struct___391;

struct inode___390;

struct file_lock___390;

struct seq_file___332;

struct file_operations___390 {
	struct module___319 *owner;
	loff_t (*llseek)(struct file___390 *, loff_t, int);
	ssize_t (*read)(struct file___390 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___390 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___390 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___390 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___390 *, bool);
	int (*iterate)(struct file___390 *, struct dir_context *);
	int (*iterate_shared)(struct file___390 *, struct dir_context *);
	__poll_t (*poll)(struct file___390 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___390 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___390 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___390 *, struct vm_area_struct___391 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___390 *, struct file___390 *);
	int (*flush)(struct file___390 *, fl_owner_t);
	int (*release)(struct inode___390 *, struct file___390 *);
	int (*fsync)(struct file___390 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___390 *, int);
	int (*lock)(struct file___390 *, int, struct file_lock___390 *);
	ssize_t (*sendpage)(struct file___390 *, struct page___391 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___390 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___390 *, int, struct file_lock___390 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___390 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___390 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___390 *, long int, struct file_lock___390 **, void **);
	long int (*fallocate)(struct file___390 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___332 *, struct file___390 *);
	ssize_t (*copy_file_range)(struct file___390 *, loff_t, struct file___390 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___390 *, loff_t, struct file___390 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___390 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___391 {
	u64 seqnum;
	struct vm_area_struct___391 *vmas[4];
};

struct page_frag___391 {
	struct page___391 *page;
	__u32 offset;
	__u32 size;
};

struct cred___360;

struct vm_struct___295;

struct task_struct___392 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___392 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___391 *mm;
	struct mm_struct___391 *active_mm;
	struct vmacache___391 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___392 *real_parent;
	struct task_struct___392 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___392 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___224 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___224 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___224 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___360 *ptracer_cred;
	const struct cred___360 *real_cred;
	const struct cred___360 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___392 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___391 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___392 *oom_reaper_list;
	struct vm_struct___295 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___148 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct secondary_data___392 {
	void *stack;
	struct task_struct___392 *task;
	long int status;
};

struct key___360;

struct user_struct___360 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___360 *uid_keyring;
	struct key___360 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___379;

struct vm_area_struct___391 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___391 *vm_next;
	struct vm_area_struct___391 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___391 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___379 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___390 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct rw_semaphore___392 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___392 *owner;
};

struct core_state___391;

struct mm_struct___391 {
	struct {
		struct vm_area_struct___391 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___390 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___392 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___391 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___392 *owner;
		struct user_namespace___3 *user_ns;
		struct file___390 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___391 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___360 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___360 *session_keyring;
	struct key___360 *process_keyring;
	struct key___360 *thread_keyring;
	struct key___360 *request_key_auth;
	void *security;
	struct user_struct___360 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct vm_struct___295 {
	struct vm_struct___295 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___391 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___390;

struct address_space___390 {
	struct inode___390 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___392 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___390 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___379)(struct vm_area_struct___391 *, long unsigned int, const struct page___391 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___379)(struct page___391 *, void *);

struct device___358;

struct dev_pagemap___379 {
	dev_page_fault_t___379 page_fault;
	dev_page_free_t___379 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___358 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct dentry___390;

struct path___391 {
	struct vfsmount *mnt;
	struct dentry___390 *dentry;
};

struct file___390 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___391 f_path;
	struct inode___390 *f_inode;
	const struct file_operations___390 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___224 f_owner;
	const struct cred___360 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___390 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___379;

struct vm_operations_struct___379 {
	void (*open)(struct vm_area_struct___391 *);
	void (*close)(struct vm_area_struct___391 *);
	int (*split)(struct vm_area_struct___391 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___391 *);
	vm_fault_t (*fault)(struct vm_fault___379 *);
	vm_fault_t (*huge_fault)(struct vm_fault___379 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___379 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___391 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___379 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___379 *);
	int (*access)(struct vm_area_struct___391 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___391 *);
	int (*set_policy)(struct vm_area_struct___391 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___391 *, long unsigned int);
	struct page___391 * (*find_special_page)(struct vm_area_struct___391 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___391 {
	struct task_struct___392 *task;
	struct core_thread___391 *next;
};

struct core_state___391 {
	atomic_t nr_threads;
	struct core_thread___391 dumper;
	struct completion startup;
};

struct vm_fault___379 {
	struct vm_area_struct___391 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___391 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___391 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___391 prealloc_pte;
};

struct dentry_operations___390;

struct super_block___390;

struct dentry___390 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___390 *d_parent;
	struct qstr d_name;
	struct inode___390 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___390 *d_op;
	struct super_block___390 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___390;

struct block_device___390;

struct inode___390 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___390 *i_op;
	struct super_block___390 *i_sb;
	struct address_space___390 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___392 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___390 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___390 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___390 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___390 {
	int (*d_revalidate)(struct dentry___390 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___390 *, unsigned int);
	int (*d_hash)(const struct dentry___390 *, struct qstr *);
	int (*d_compare)(const struct dentry___390 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___390 *);
	int (*d_init)(struct dentry___390 *);
	void (*d_release)(struct dentry___390 *);
	void (*d_prune)(struct dentry___390 *);
	void (*d_iput)(struct dentry___390 *, struct inode___390 *);
	char * (*d_dname)(struct dentry___390 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___391 *);
	int (*d_manage)(const struct path___391 *, bool);
	struct dentry___390 * (*d_real)(struct dentry___390 *, const struct inode___390 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___390;

struct mem_dqinfo___390 {
	struct quota_format_type___390 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___390;

struct quota_info___390 {
	unsigned int flags;
	struct rw_semaphore___392 dqio_sem;
	struct inode___390 *files[3];
	struct mem_dqinfo___390 info[3];
	const struct quota_format_ops___390 *ops[3];
};

struct rcuwait___390 {
	struct task_struct___392 *task;
};

struct percpu_rw_semaphore___390 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___392 rw_sem;
	struct rcuwait___390 writer;
	int readers_block;
};

struct sb_writers___390 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___390 rw_sem[3];
};

struct file_system_type___390;

struct super_operations___390;

struct dquot_operations___390;

struct quotactl_ops___390;

struct super_block___390 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___390 *s_type;
	const struct super_operations___390 *s_op;
	const struct dquot_operations___390 *dq_op;
	const struct quotactl_ops___390 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___390 *s_root;
	struct rw_semaphore___392 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___390 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___390 s_dquot;
	struct sb_writers___390 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___390 *s_d_op;
	int cleancache_poolid;
	struct shrinker___135 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct pglist_data___391;

struct lruvec___391 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___391 *pgdat;
};

struct zone___391 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___391 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___391 {
	struct zone___391 *zone;
	int zone_idx;
};

struct zonelist___391 {
	struct zoneref___391 _zonerefs[25];
};

struct pglist_data___391 {
	struct zone___391 node_zones[3];
	struct zonelist___391 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___392 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___392 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___391 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___391 {
	struct rw_semaphore___392 rwsem;
	struct notifier_block *head;
};

struct kiocb___390 {
	struct file___390 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___390 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___390 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___390 *ia_file;
};

struct dquot___390 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___390 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___390 {
	int qf_fmt_id;
	const struct quota_format_ops___390 *qf_ops;
	struct module___319 *qf_owner;
	struct quota_format_type___390 *qf_next;
};

struct quota_format_ops___390 {
	int (*check_quota_file)(struct super_block___390 *, int);
	int (*read_file_info)(struct super_block___390 *, int);
	int (*write_file_info)(struct super_block___390 *, int);
	int (*free_file_info)(struct super_block___390 *, int);
	int (*read_dqblk)(struct dquot___390 *);
	int (*commit_dqblk)(struct dquot___390 *);
	int (*release_dqblk)(struct dquot___390 *);
	int (*get_next_id)(struct super_block___390 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___390 {
	int (*write_dquot)(struct dquot___390 *);
	struct dquot___390 * (*alloc_dquot)(struct super_block___390 *, int);
	void (*destroy_dquot)(struct dquot___390 *);
	int (*acquire_dquot)(struct dquot___390 *);
	int (*release_dquot)(struct dquot___390 *);
	int (*mark_dirty)(struct dquot___390 *);
	int (*write_info)(struct super_block___390 *, int);
	qsize_t * (*get_reserved_space)(struct inode___390 *);
	int (*get_projid)(struct inode___390 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___390 *, qsize_t *);
	int (*get_next_id)(struct super_block___390 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___390 {
	int (*quota_on)(struct super_block___390 *, int, int, const struct path___391 *);
	int (*quota_off)(struct super_block___390 *, int);
	int (*quota_enable)(struct super_block___390 *, unsigned int);
	int (*quota_disable)(struct super_block___390 *, unsigned int);
	int (*quota_sync)(struct super_block___390 *, int);
	int (*set_info)(struct super_block___390 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___390 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___390 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___390 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___390 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___390 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___377;

struct kobj_type___377;

struct kernfs_node___385;

struct kobject___378 {
	const char *name;
	struct list_head entry;
	struct kobject___378 *parent;
	struct kset___377 *kset;
	struct kobj_type___377 *ktype;
	struct kernfs_node___385 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___317 {
	struct kobject___378 kobj;
	struct module___319 *mod;
	struct kobject___378 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___317 {
	struct module___319 *mod;
	struct latch_tree_node node;
};

struct module_layout___317 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___317 mtn;
};

struct module_attribute___317;

struct kernel_param___317;

struct module___319 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___317 mkobj;
	struct module_attribute___317 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___378 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___317 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___317 core_layout;
	struct module_layout___317 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___390 {
	int (*writepage)(struct page___391 *, struct writeback_control___3 *);
	int (*readpage)(struct file___390 *, struct page___391 *);
	int (*writepages)(struct address_space___390 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___391 *);
	int (*readpages)(struct file___390 *, struct address_space___390 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___390 *, struct address_space___390 *, loff_t, unsigned int, unsigned int, struct page___391 **, void **);
	int (*write_end)(struct file___390 *, struct address_space___390 *, loff_t, unsigned int, unsigned int, struct page___391 *, void *);
	sector_t (*bmap)(struct address_space___390 *, sector_t);
	void (*invalidatepage)(struct page___391 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___391 *, gfp_t);
	void (*freepage)(struct page___391 *);
	ssize_t (*direct_IO)(struct kiocb___390 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___390 *, struct page___391 *, struct page___391 *, enum migrate_mode);
	bool (*isolate_page)(struct page___391 *, isolate_mode_t);
	void (*putback_page)(struct page___391 *);
	int (*launder_page)(struct page___391 *);
	int (*is_partially_uptodate)(struct page___391 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___391 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___390 *, struct page___391 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___390 *, sector_t *);
	void (*swap_deactivate)(struct file___390 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___390 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___390 *bd_inode;
	struct super_block___390 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___390 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___390 {
	struct dentry___390 * (*lookup)(struct inode___390 *, struct dentry___390 *, unsigned int);
	const char * (*get_link)(struct dentry___390 *, struct inode___390 *, struct delayed_call *);
	int (*permission)(struct inode___390 *, int);
	struct posix_acl * (*get_acl)(struct inode___390 *, int);
	int (*readlink)(struct dentry___390 *, char *, int);
	int (*create)(struct inode___390 *, struct dentry___390 *, umode_t, bool);
	int (*link)(struct dentry___390 *, struct inode___390 *, struct dentry___390 *);
	int (*unlink)(struct inode___390 *, struct dentry___390 *);
	int (*symlink)(struct inode___390 *, struct dentry___390 *, const char *);
	int (*mkdir)(struct inode___390 *, struct dentry___390 *, umode_t);
	int (*rmdir)(struct inode___390 *, struct dentry___390 *);
	int (*mknod)(struct inode___390 *, struct dentry___390 *, umode_t, dev_t);
	int (*rename)(struct inode___390 *, struct dentry___390 *, struct inode___390 *, struct dentry___390 *, unsigned int);
	int (*setattr)(struct dentry___390 *, struct iattr___390 *);
	int (*getattr)(const struct path___391 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___390 *, char *, size_t);
	int (*fiemap)(struct inode___390 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___390 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___390 *, struct dentry___390 *, struct file___390 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___390 *, struct dentry___390 *, umode_t);
	int (*set_acl)(struct inode___390 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___390 {
	void (*fl_copy_lock)(struct file_lock___390 *, struct file_lock___390 *);
	void (*fl_release_private)(struct file_lock___390 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___390;

struct lock_manager_operations___390;

struct file_lock___390 {
	struct file_lock___390 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___390 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___390 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___390 *fl_ops;
	const struct lock_manager_operations___390 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___390 {
	int (*lm_compare_owner)(struct file_lock___390 *, struct file_lock___390 *);
	long unsigned int (*lm_owner_key)(struct file_lock___390 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___390 *);
	int (*lm_grant)(struct file_lock___390 *, int);
	bool (*lm_break)(struct file_lock___390 *);
	int (*lm_change)(struct file_lock___390 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___390 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___390 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___390 *fa_next;
	struct file___390 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___390 {
	const char *name;
	int fs_flags;
	struct dentry___390 * (*mount)(struct file_system_type___390 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___390 *);
	struct module___319 *owner;
	struct file_system_type___390 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___390 {
	struct inode___390 * (*alloc_inode)(struct super_block___390 *);
	void (*destroy_inode)(struct inode___390 *);
	void (*dirty_inode)(struct inode___390 *, int);
	int (*write_inode)(struct inode___390 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___390 *);
	void (*evict_inode)(struct inode___390 *);
	void (*put_super)(struct super_block___390 *);
	int (*sync_fs)(struct super_block___390 *, int);
	int (*freeze_super)(struct super_block___390 *);
	int (*freeze_fs)(struct super_block___390 *);
	int (*thaw_super)(struct super_block___390 *);
	int (*unfreeze_fs)(struct super_block___390 *);
	int (*statfs)(struct dentry___390 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___390 *, int *, char *);
	void (*umount_begin)(struct super_block___390 *);
	int (*show_options)(struct seq_file___332 *, struct dentry___390 *);
	int (*show_devname)(struct seq_file___332 *, struct dentry___390 *);
	int (*show_path)(struct seq_file___332 *, struct dentry___390 *);
	int (*show_stats)(struct seq_file___332 *, struct dentry___390 *);
	ssize_t (*quota_read)(struct super_block___390 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___390 *, int, const char *, size_t, loff_t);
	struct dquot___390 ** (*get_dquots)(struct inode___390 *);
	int (*bdev_try_to_free_page)(struct super_block___390 *, struct page___391 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___390 *, struct shrink_control___135 *);
	long int (*free_cached_objects)(struct super_block___390 *, struct shrink_control___135 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___332;

struct seq_file___332 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___332 *op;
	int poll_event;
	const struct file___390 *file;
	void *private;
};

struct dev_pm_info___358 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___358 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___358;

struct bus_type___358;

struct device_driver___358;

struct dev_pm_domain___358;

struct dma_map_ops___136;

struct fwnode_handle___279;

struct class___358;

struct attribute_group___355;

struct device___358 {
	struct device___358 *parent;
	struct device_private *p;
	struct kobject___378 kobj;
	const char *init_name;
	const struct device_type___358 *type;
	struct mutex mutex;
	struct bus_type___358 *bus;
	struct device_driver___358 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___358 power;
	struct dev_pm_domain___358 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___136 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___279 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___358 *class;
	const struct attribute_group___355 **groups;
	void (*release)(struct device___358 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct kobj_attribute___369 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___378 *, struct kobj_attribute___369 *, char *);
	ssize_t (*store)(struct kobject___378 *, struct kobj_attribute___369 *, const char *, size_t);
};

typedef void compound_page_dtor___379(struct page___391 *);

struct kernfs_root___384;

struct kernfs_elem_dir___384 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___384 *root;
};

struct kernfs_syscall_ops___384;

struct kernfs_root___384 {
	struct kernfs_node___385 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___384 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___384 {
	struct kernfs_node___385 *target_kn;
};

struct kernfs_ops___384;

struct kernfs_elem_attr___384 {
	const struct kernfs_ops___384 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___385 *notify_next;
};

struct kernfs_node___385 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___385 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___384 dir;
		struct kernfs_elem_symlink___384 symlink;
		struct kernfs_elem_attr___384 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___384;

struct kernfs_ops___384 {
	int (*open)(struct kernfs_open_file___384 *);
	void (*release)(struct kernfs_open_file___384 *);
	int (*seq_show)(struct seq_file___332 *, void *);
	void * (*seq_start)(struct seq_file___332 *, loff_t *);
	void * (*seq_next)(struct seq_file___332 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___332 *, void *);
	ssize_t (*read)(struct kernfs_open_file___384 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___384 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___384 *, struct vm_area_struct___391 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___384 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___384 {
	int (*remount_fs)(struct kernfs_root___384 *, int *, char *);
	int (*show_options)(struct seq_file___332 *, struct kernfs_root___384 *);
	int (*mkdir)(struct kernfs_node___385 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___385 *);
	int (*rename)(struct kernfs_node___385 *, struct kernfs_node___385 *, const char *);
	int (*show_path)(struct seq_file___332 *, struct kernfs_node___385 *, struct kernfs_root___384 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___384 {
	struct kernfs_node___385 *kn;
	struct file___390 *file;
	struct seq_file___332 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___379 *vm_ops;
};

struct bin_attribute___354;

struct attribute_group___355 {
	const char *name;
	umode_t (*is_visible)(struct kobject___378 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___378 *, struct bin_attribute___354 *, int);
	struct attribute **attrs;
	struct bin_attribute___354 **bin_attrs;
};

struct bin_attribute___354 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___390 *, struct kobject___378 *, struct bin_attribute___354 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___390 *, struct kobject___378 *, struct bin_attribute___354 *, char *, loff_t, size_t);
	int (*mmap)(struct file___390 *, struct kobject___378 *, struct bin_attribute___354 *, struct vm_area_struct___391 *);
};

struct sysfs_ops___377 {
	ssize_t (*show)(struct kobject___378 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___378 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___377;

struct kset___377 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___378 kobj;
	const struct kset_uevent_ops___377 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___377 {
	void (*release)(struct kobject___378 *);
	const struct sysfs_ops___377 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___29 * (*child_ns_type)(struct kobject___378 *);
	const void * (*namespace)(struct kobject___378 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___377 {
	int (* const filter)(struct kset___377 *, struct kobject___378 *);
	const char * (* const name)(struct kset___377 *, struct kobject___378 *);
	int (* const uevent)(struct kset___377 *, struct kobject___378 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___317 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___317 *);
	int (*get)(char *, const struct kernel_param___317 *);
	void (*free)(void *);
};

struct kparam_array___317;

struct kernel_param___317 {
	const char *name;
	struct module___319 *mod;
	const struct kernel_param_ops___317 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___317 *arr;
	};
};

struct kparam_array___317 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___317 *ops;
	void *elem;
};

struct module_attribute___317 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___317 *, struct module_kobject___317 *, char *);
	ssize_t (*store)(struct module_attribute___317 *, struct module_kobject___317 *, const char *, size_t);
	void (*setup)(struct module___319 *, const char *);
	int (*test)(struct module___319 *);
	void (*free)(struct module___319 *);
};

struct dev_pm_ops___358 {
	int (*prepare)(struct device___358 *);
	void (*complete)(struct device___358 *);
	int (*suspend)(struct device___358 *);
	int (*resume)(struct device___358 *);
	int (*freeze)(struct device___358 *);
	int (*thaw)(struct device___358 *);
	int (*poweroff)(struct device___358 *);
	int (*restore)(struct device___358 *);
	int (*suspend_late)(struct device___358 *);
	int (*resume_early)(struct device___358 *);
	int (*freeze_late)(struct device___358 *);
	int (*thaw_early)(struct device___358 *);
	int (*poweroff_late)(struct device___358 *);
	int (*restore_early)(struct device___358 *);
	int (*suspend_noirq)(struct device___358 *);
	int (*resume_noirq)(struct device___358 *);
	int (*freeze_noirq)(struct device___358 *);
	int (*thaw_noirq)(struct device___358 *);
	int (*poweroff_noirq)(struct device___358 *);
	int (*restore_noirq)(struct device___358 *);
	int (*runtime_suspend)(struct device___358 *);
	int (*runtime_resume)(struct device___358 *);
	int (*runtime_idle)(struct device___358 *);
};

struct dev_pm_domain___358 {
	struct dev_pm_ops___358 ops;
	void (*detach)(struct device___358 *, bool);
	int (*activate)(struct device___358 *);
	void (*sync)(struct device___358 *);
	void (*dismiss)(struct device___358 *);
};

struct bus_type___358 {
	const char *name;
	const char *dev_name;
	struct device___358 *dev_root;
	const struct attribute_group___355 **bus_groups;
	const struct attribute_group___355 **dev_groups;
	const struct attribute_group___355 **drv_groups;
	int (*match)(struct device___358 *, struct device_driver___358 *);
	int (*uevent)(struct device___358 *, struct kobj_uevent_env *);
	int (*probe)(struct device___358 *);
	int (*remove)(struct device___358 *);
	void (*shutdown)(struct device___358 *);
	int (*online)(struct device___358 *);
	int (*offline)(struct device___358 *);
	int (*suspend)(struct device___358 *, pm_message_t);
	int (*resume)(struct device___358 *);
	int (*num_vf)(struct device___358 *);
	int (*dma_configure)(struct device___358 *);
	const struct dev_pm_ops___358 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___358 {
	const char *name;
	struct bus_type___358 *bus;
	struct module___319 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___358 *);
	int (*remove)(struct device___358 *);
	void (*shutdown)(struct device___358 *);
	int (*suspend)(struct device___358 *, pm_message_t);
	int (*resume)(struct device___358 *);
	const struct attribute_group___355 **groups;
	const struct dev_pm_ops___358 *pm;
	void (*coredump)(struct device___358 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___358 {
	const char *name;
	const struct attribute_group___355 **groups;
	int (*uevent)(struct device___358 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___358 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___358 *);
	const struct dev_pm_ops___358 *pm;
};

struct class___358 {
	const char *name;
	struct module___319 *owner;
	const struct attribute_group___355 **class_groups;
	const struct attribute_group___355 **dev_groups;
	struct kobject___378 *dev_kobj;
	int (*dev_uevent)(struct device___358 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___358 *, umode_t *);
	void (*class_release)(struct class___358 *);
	void (*dev_release)(struct device___358 *);
	int (*shutdown_pre)(struct device___358 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___358 *);
	const struct dev_pm_ops___358 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___136 {
	void * (*alloc)(struct device___358 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___358 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___358 *, struct vm_area_struct___391 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___358 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___358 *, struct page___391 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___358 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___358 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___358 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___358 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___358 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___358 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___358 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___358 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___358 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___358 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___358 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___358 *, u64);
	u64 (*get_required_mask)(struct device___358 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___279;

struct fwnode_handle___279 {
	struct fwnode_handle___279 *secondary;
	const struct fwnode_operations___279 *ops;
};

typedef int (*key_restrict_link_func_t___361)(struct key___360 *, const struct key_type *, const union key_payload *, struct key___360 *);

struct key_restriction___360;

struct key___360 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___392 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___360 *restrict_link;
};

struct key_restriction___360 {
	key_restrict_link_func_t___361 check;
	struct key___360 *key;
	struct key_type *keytype;
};

struct seq_operations___332 {
	void * (*start)(struct seq_file___332 *, loff_t *);
	void (*stop)(struct seq_file___332 *, void *);
	void * (*next)(struct seq_file___332 *, void *, loff_t *);
	int (*show)(struct seq_file___332 *, void *);
};

struct edac_device_counter {
	u32 ue_count;
	u32 ce_count;
};

struct edac_device_ctl_info;

struct edac_dev_sysfs_attribute {
	struct attribute attr;
	ssize_t (*show)(struct edac_device_ctl_info *, char *);
	ssize_t (*store)(struct edac_device_ctl_info *, const char *, size_t);
};

struct edac_device_instance;

struct edac_device_ctl_info {
	struct list_head link;
	struct module___319 *owner;
	int dev_idx;
	int log_ue;
	int log_ce;
	int panic_on_ue;
	unsigned int poll_msec;
	long unsigned int delay;
	struct edac_dev_sysfs_attribute *sysfs_attributes;
	struct bus_type___358 *edac_subsys;
	int op_state;
	struct delayed_work work;
	void (*edac_check)(struct edac_device_ctl_info *);
	struct device___358 *dev;
	const char *mod_name;
	const char *ctl_name;
	const char *dev_name;
	void *pvt_info;
	long unsigned int start_time;
	struct completion removal_complete;
	char name[32];
	u32 nr_instances;
	struct edac_device_instance *instances;
	struct edac_device_counter counters;
	struct kobject___378 kobj;
};

struct edac_device_block;

struct edac_dev_sysfs_block_attribute {
	struct attribute attr;
	ssize_t (*show)(struct kobject___378 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___378 *, struct attribute *, const char *, size_t);
	struct edac_device_block *block;
	unsigned int value;
};

struct edac_device_block {
	struct edac_device_instance *instance;
	char name[32];
	struct edac_device_counter counters;
	int nr_attribs;
	struct edac_dev_sysfs_block_attribute *block_attributes;
	struct kobject___378 kobj;
};

struct edac_device_instance {
	struct edac_device_ctl_info *ctl;
	char name[35];
	struct edac_device_counter counters;
	u32 nr_blocks;
	struct edac_device_block *blocks;
	struct kobject___378 kobj;
};

struct fwnode_reference_args___279;

struct fwnode_endpoint___279;

struct fwnode_operations___279 {
	struct fwnode_handle___279 * (*get)(struct fwnode_handle___279 *);
	void (*put)(struct fwnode_handle___279 *);
	bool (*device_is_available)(const struct fwnode_handle___279 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___279 *, const struct device___358 *);
	bool (*property_present)(const struct fwnode_handle___279 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___279 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___279 *, const char *, const char **, size_t);
	struct fwnode_handle___279 * (*get_parent)(const struct fwnode_handle___279 *);
	struct fwnode_handle___279 * (*get_next_child_node)(const struct fwnode_handle___279 *, struct fwnode_handle___279 *);
	struct fwnode_handle___279 * (*get_named_child_node)(const struct fwnode_handle___279 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___279 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___279 *);
	struct fwnode_handle___279 * (*graph_get_next_endpoint)(const struct fwnode_handle___279 *, struct fwnode_handle___279 *);
	struct fwnode_handle___279 * (*graph_get_remote_endpoint)(const struct fwnode_handle___279 *);
	struct fwnode_handle___279 * (*graph_get_port_parent)(struct fwnode_handle___279 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___279 *, struct fwnode_endpoint___279 *);
};

struct fwnode_endpoint___279 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___279 *local_fwnode;
};

struct fwnode_reference_args___279 {
	struct fwnode_handle___279 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct mem_ctl_info___2;

struct dimm_info___2 {
	struct device___352 dev;
	char label[32];
	unsigned int location[3];
	struct mem_ctl_info___2 *mci;
	u32 grain;
	enum dev_type dtype;
	enum mem_type mtype;
	enum edac_type edac_mode;
	u32 nr_pages;
	unsigned int csrow;
	unsigned int cschannel;
};

struct csrow_info___2;

struct mem_ctl_info___2 {
	struct device___352 dev;
	struct bus_type___352 *bus;
	struct list_head link;
	struct module___2 *owner;
	long unsigned int mtype_cap;
	long unsigned int edac_ctl_cap;
	long unsigned int edac_cap;
	long unsigned int scrub_cap;
	enum scrub_type scrub_mode;
	int (*set_sdram_scrub_rate)(struct mem_ctl_info___2 *, u32);
	int (*get_sdram_scrub_rate)(struct mem_ctl_info___2 *);
	void (*edac_check)(struct mem_ctl_info___2 *);
	long unsigned int (*ctl_page_to_phys)(struct mem_ctl_info___2 *, long unsigned int);
	int mc_idx;
	struct csrow_info___2 **csrows;
	unsigned int nr_csrows;
	unsigned int num_cschannel;
	unsigned int n_layers;
	struct edac_mc_layer *layers;
	bool csbased;
	unsigned int tot_dimms;
	struct dimm_info___2 **dimms;
	struct device___352 *pdev;
	const char *mod_name;
	const char *ctl_name;
	const char *dev_name;
	void *pvt_info;
	long unsigned int start_time;
	u32 ce_noinfo_count;
	u32 ue_noinfo_count;
	u32 ue_mc;
	u32 ce_mc;
	u32 *ce_per_layer[3];
	u32 *ue_per_layer[3];
	struct completion complete;
	const struct mcidev_sysfs_attribute *mc_driver_sysfs_attributes;
	struct delayed_work work;
	struct edac_raw_error_desc error_desc;
	int op_state;
	struct dentry___384 *debugfs;
	u8 fake_inject_layer[3];
	bool fake_inject_ue;
	u16 fake_inject_count;
};

struct rank_info___2 {
	int chan_idx;
	struct csrow_info___2 *csrow;
	struct dimm_info___2 *dimm;
	u32 ce_count;
};

struct csrow_info___2 {
	struct device___352 dev;
	long unsigned int first_page;
	long unsigned int last_page;
	long unsigned int page_mask;
	int csrow_idx;
	u32 ue_count;
	u32 ce_count;
	struct mem_ctl_info___2 *mci;
	u32 nr_channels;
	struct rank_info___2 **channels;
};

struct dev_ch_attribute {
	struct device_attribute___55 attr;
	int channel;
};

struct edac_device_ctl_info___2;

struct edac_dev_sysfs_attribute___2 {
	struct attribute attr;
	ssize_t (*show)(struct edac_device_ctl_info___2 *, char *);
	ssize_t (*store)(struct edac_device_ctl_info___2 *, const char *, size_t);
};

struct edac_device_instance___2;

struct edac_device_ctl_info___2 {
	struct list_head link;
	struct module___300 *owner;
	int dev_idx;
	int log_ue;
	int log_ce;
	int panic_on_ue;
	unsigned int poll_msec;
	long unsigned int delay;
	struct edac_dev_sysfs_attribute___2 *sysfs_attributes;
	struct bus_type___336 *edac_subsys;
	int op_state;
	struct delayed_work work;
	void (*edac_check)(struct edac_device_ctl_info___2 *);
	struct device___336 *dev;
	const char *mod_name;
	const char *ctl_name;
	const char *dev_name;
	void *pvt_info;
	long unsigned int start_time;
	struct completion removal_complete;
	char name[32];
	u32 nr_instances;
	struct edac_device_instance___2 *instances;
	struct edac_device_counter counters;
	struct kobject___356 kobj;
};

struct edac_device_block___2;

struct edac_dev_sysfs_block_attribute___2 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___356 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___356 *, struct attribute *, const char *, size_t);
	struct edac_device_block___2 *block;
	unsigned int value;
};

struct edac_device_block___2 {
	struct edac_device_instance___2 *instance;
	char name[32];
	struct edac_device_counter counters;
	int nr_attribs;
	struct edac_dev_sysfs_block_attribute___2 *block_attributes;
	struct kobject___356 kobj;
};

struct edac_device_instance___2 {
	struct edac_device_ctl_info___2 *ctl;
	char name[35];
	struct edac_device_counter counters;
	u32 nr_blocks;
	struct edac_device_block___2 *blocks;
	struct kobject___356 kobj;
};

struct ctl_info_attribute {
	struct attribute attr;
	ssize_t (*show)(struct edac_device_ctl_info___2 *, char *);
	ssize_t (*store)(struct edac_device_ctl_info___2 *, const char *, size_t);
};

struct instance_attribute {
	struct attribute attr;
	ssize_t (*show)(struct edac_device_instance___2 *, char *);
	ssize_t (*store)(struct edac_device_instance___2 *, const char *, size_t);
};

struct pci_bus___36;

struct pci_slot___36 {
	struct pci_bus___36 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject___378 kobj;
};

struct pci_dev___36;

struct pci_ops___36;

struct pci_bus___36 {
	struct list_head node;
	struct pci_bus___36 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___36 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___36 *ops;
	struct msi_controller___2 *msi;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	int domain_nr;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___358 *bridge;
	struct device___358 dev;
	struct bin_attribute___354 *legacy_io;
	struct bin_attribute___354 *legacy_mem;
	unsigned int is_added: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
};

struct pci_driver___36;

struct pci_dev___36 {
	struct list_head bus_list;
	struct pci_bus___36 *bus;
	struct pci_bus___36 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___36 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u16 aer_cap;
	struct aer_stats *aer_stats;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	long unsigned int *dma_alias_mask;
	struct pci_driver___36 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	unsigned int imm_ready: 1;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int bridge_d3: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int hotplug_user_indicators: 1;
	unsigned int clear_retrain_link: 1;
	unsigned int d3_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	unsigned int ltr_path: 1;
	unsigned int eetlp_prefix_path: 1;
	pci_channel_state_t error_state;
	struct device___358 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int multifunction: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int ats_enabled: 1;
	unsigned int pasid_enabled: 1;
	unsigned int pri_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int reset_fn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int shpc_managed: 1;
	unsigned int is_thunderbolt: 1;
	unsigned int __aer_firmware_first_valid: 1;
	unsigned int __aer_firmware_first: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int irq_managed: 1;
	unsigned int has_secondary_link: 1;
	unsigned int non_compliant_bars: 1;
	unsigned int is_probed: 1;
	unsigned int link_active_reporting: 1;
	unsigned int untrusted: 1;
	unsigned int no_vf_scan: 1;
	unsigned int io_window: 1;
	unsigned int pref_window: 1;
	unsigned int pref_64_window: 1;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	struct bin_attribute___354 *rom_attr;
	int rom_attr_enabled;
	struct bin_attribute___354 *res_attr[17];
	struct bin_attribute___354 *res_attr_wc[17];
	unsigned int broken_cmd_compl: 1;
	const struct attribute_group___355 **msi_irq_groups;
	struct pci_vpd *vpd;
	union {
		struct pci_sriov *sriov;
		struct pci_dev___36 *physfn;
	};
	u16 ats_cap;
	u8 ats_stu;
	atomic_t ats_ref_cnt;
	u32 pri_reqs_alloc;
	u16 pasid_features;
	struct pci_p2pdma *p2pdma;
	phys_addr_t rom;
	size_t romlen;
	char *driver_override;
	long unsigned int priv_flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t pci_dev_extended_size_rh;
	struct pci_dev_extended_rh pci_dev_extended_rh;
};

struct pci_error_handlers___36;

struct pci_driver___36 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___36 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___36 *);
	int (*suspend)(struct pci_dev___36 *, pm_message_t);
	int (*suspend_late)(struct pci_dev___36 *, pm_message_t);
	int (*resume_early)(struct pci_dev___36 *);
	int (*resume)(struct pci_dev___36 *);
	void (*shutdown)(struct pci_dev___36 *);
	int (*sriov_configure)(struct pci_dev___36 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	const struct pci_error_handlers___36 *err_handler;
	const struct attribute_group___355 **groups;
	struct device_driver___358 driver;
	struct pci_dynids dynids;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct pci_ops___36 {
	int (*add_bus)(struct pci_bus___36 *);
	void (*remove_bus)(struct pci_bus___36 *);
	void * (*map_bus)(struct pci_bus___36 *, unsigned int, int);
	int (*read)(struct pci_bus___36 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___36 *, unsigned int, int, int, u32);
};

struct pci_error_handlers___36 {
	pci_ers_result_t (*error_detected)(struct pci_dev___36 *, enum pci_channel_state);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___36 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___36 *);
	void (*reset_prepare)(struct pci_dev___36 *);
	void (*reset_done)(struct pci_dev___36 *);
	void (*resume)(struct pci_dev___36 *);
};

struct edac_pci_counter {
	atomic_t pe_count;
	atomic_t npe_count;
};

struct edac_pci_ctl_info {
	struct list_head link;
	int pci_idx;
	struct bus_type___358 *edac_subsys;
	int op_state;
	struct delayed_work work;
	void (*edac_check)(struct edac_pci_ctl_info *);
	struct device___358 *dev;
	const char *mod_name;
	const char *ctl_name;
	const char *dev_name;
	void *pvt_info;
	long unsigned int start_time;
	struct completion complete;
	char name[32];
	struct edac_pci_counter counters;
	struct kobject___378 kobj;
};

struct edac_pci_gen_data {
	int edac_idx;
};

struct edac_pci_ctl_info___2 {
	struct list_head link;
	int pci_idx;
	struct bus_type___336 *edac_subsys;
	int op_state;
	struct delayed_work work;
	void (*edac_check)(struct edac_pci_ctl_info___2 *);
	struct device___336 *dev;
	const char *mod_name;
	const char *ctl_name;
	const char *dev_name;
	void *pvt_info;
	long unsigned int start_time;
	struct completion complete;
	char name[32];
	struct edac_pci_counter counters;
	struct kobject___356 kobj;
};

struct instance_attribute___2 {
	struct attribute attr;
	ssize_t (*show)(struct edac_pci_ctl_info___2 *, char *);
	ssize_t (*store)(struct edac_pci_ctl_info___2 *, const char *, size_t);
};

struct edac_pci_dev_attribute {
	struct attribute attr;
	void *value;
	ssize_t (*show)(void *, char *);
	ssize_t (*store)(void *, const char *, size_t);
};

typedef void (*pci_parity_check_fn_t)(struct pci_dev___33 *);

struct mem_ctl_info___3;

struct dimm_info___3 {
	struct device___306 dev;
	char label[32];
	unsigned int location[3];
	struct mem_ctl_info___3 *mci;
	u32 grain;
	enum dev_type dtype;
	enum mem_type mtype;
	enum edac_type edac_mode;
	u32 nr_pages;
	unsigned int csrow;
	unsigned int cschannel;
};

struct csrow_info___3;

struct mem_ctl_info___3 {
	struct device___306 dev;
	struct bus_type___306 *bus;
	struct list_head link;
	struct module___278 *owner;
	long unsigned int mtype_cap;
	long unsigned int edac_ctl_cap;
	long unsigned int edac_cap;
	long unsigned int scrub_cap;
	enum scrub_type scrub_mode;
	int (*set_sdram_scrub_rate)(struct mem_ctl_info___3 *, u32);
	int (*get_sdram_scrub_rate)(struct mem_ctl_info___3 *);
	void (*edac_check)(struct mem_ctl_info___3 *);
	long unsigned int (*ctl_page_to_phys)(struct mem_ctl_info___3 *, long unsigned int);
	int mc_idx;
	struct csrow_info___3 **csrows;
	unsigned int nr_csrows;
	unsigned int num_cschannel;
	unsigned int n_layers;
	struct edac_mc_layer *layers;
	bool csbased;
	unsigned int tot_dimms;
	struct dimm_info___3 **dimms;
	struct device___306 *pdev;
	const char *mod_name;
	const char *ctl_name;
	const char *dev_name;
	void *pvt_info;
	long unsigned int start_time;
	u32 ce_noinfo_count;
	u32 ue_noinfo_count;
	u32 ue_mc;
	u32 ce_mc;
	u32 *ce_per_layer[3];
	u32 *ue_per_layer[3];
	struct completion complete;
	const struct mcidev_sysfs_attribute *mc_driver_sysfs_attributes;
	struct delayed_work work;
	struct edac_raw_error_desc error_desc;
	int op_state;
	struct dentry___339 *debugfs;
	u8 fake_inject_layer[3];
	bool fake_inject_ue;
	u16 fake_inject_count;
};

struct rank_info___3 {
	int chan_idx;
	struct csrow_info___3 *csrow;
	struct dimm_info___3 *dimm;
	u32 ce_count;
};

struct csrow_info___3 {
	struct device___306 dev;
	long unsigned int first_page;
	long unsigned int last_page;
	long unsigned int page_mask;
	int csrow_idx;
	u32 ue_count;
	u32 ce_count;
	struct mem_ctl_info___3 *mci;
	u32 nr_channels;
	struct rank_info___3 **channels;
};

enum dmi_entry_type {
	DMI_ENTRY_BIOS = 0,
	DMI_ENTRY_SYSTEM = 1,
	DMI_ENTRY_BASEBOARD = 2,
	DMI_ENTRY_CHASSIS = 3,
	DMI_ENTRY_PROCESSOR = 4,
	DMI_ENTRY_MEM_CONTROLLER = 5,
	DMI_ENTRY_MEM_MODULE = 6,
	DMI_ENTRY_CACHE = 7,
	DMI_ENTRY_PORT_CONNECTOR = 8,
	DMI_ENTRY_SYSTEM_SLOT = 9,
	DMI_ENTRY_ONBOARD_DEVICE = 10,
	DMI_ENTRY_OEMSTRINGS = 11,
	DMI_ENTRY_SYSCONF = 12,
	DMI_ENTRY_BIOS_LANG = 13,
	DMI_ENTRY_GROUP_ASSOC = 14,
	DMI_ENTRY_SYSTEM_EVENT_LOG = 15,
	DMI_ENTRY_PHYS_MEM_ARRAY = 16,
	DMI_ENTRY_MEM_DEVICE = 17,
	DMI_ENTRY_32_MEM_ERROR = 18,
	DMI_ENTRY_MEM_ARRAY_MAPPED_ADDR = 19,
	DMI_ENTRY_MEM_DEV_MAPPED_ADDR = 20,
	DMI_ENTRY_BUILTIN_POINTING_DEV = 21,
	DMI_ENTRY_PORTABLE_BATTERY = 22,
	DMI_ENTRY_SYSTEM_RESET = 23,
	DMI_ENTRY_HW_SECURITY = 24,
	DMI_ENTRY_SYSTEM_POWER_CONTROLS = 25,
	DMI_ENTRY_VOLTAGE_PROBE = 26,
	DMI_ENTRY_COOLING_DEV = 27,
	DMI_ENTRY_TEMP_PROBE = 28,
	DMI_ENTRY_ELECTRICAL_CURRENT_PROBE = 29,
	DMI_ENTRY_OOB_REMOTE_ACCESS = 30,
	DMI_ENTRY_BIS_ENTRY = 31,
	DMI_ENTRY_SYSTEM_BOOT = 32,
	DMI_ENTRY_MGMT_DEV = 33,
	DMI_ENTRY_MGMT_DEV_COMPONENT = 34,
	DMI_ENTRY_MGMT_DEV_THRES = 35,
	DMI_ENTRY_MEM_CHANNEL = 36,
	DMI_ENTRY_IPMI_DEV = 37,
	DMI_ENTRY_SYS_POWER_SUPPLY = 38,
	DMI_ENTRY_ADDITIONAL = 39,
	DMI_ENTRY_ONBOARD_DEV_EXT = 40,
	DMI_ENTRY_MGMT_CONTROLLER_HOST = 41,
	DMI_ENTRY_INACTIVE = 126,
	DMI_ENTRY_END_OF_TABLE = 127,
};

struct ghes_edac_pvt {
	struct list_head list;
	struct ghes *ghes;
	struct mem_ctl_info___3 *mci;
	char detail_location[240];
	char other_detail[160];
	char msg[80];
};

struct memdev_dmi_entry {
	u8 type;
	u8 length;
	u16 handle;
	u16 phys_mem_array_handle;
	u16 mem_err_info_handle;
	u16 total_width;
	u16 data_width;
	u16 size;
	u8 form_factor;
	u8 device_set;
	u8 device_locator;
	u8 bank_locator;
	u8 memory_type;
	u16 type_detail;
	u16 speed;
	u8 manufacturer;
	u8 serial_number;
	u8 asset_tag;
	u8 part_number;
	u8 attributes;
	u32 extended_size;
	u16 conf_mem_clk_speed;
} __attribute__((packed));

struct ghes_edac_dimm_fill {
	struct mem_ctl_info___3 *mci;
	unsigned int count;
};

struct module___320;

struct file___391;

struct kiocb___391;

struct iov_iter___165;

struct poll_table_struct___238;

struct vm_area_struct___392;

struct inode___391;

struct file_lock___391;

struct page___392;

struct seq_file___333;

struct file_operations___391 {
	struct module___320 *owner;
	loff_t (*llseek)(struct file___391 *, loff_t, int);
	ssize_t (*read)(struct file___391 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___391 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___391 *, struct iov_iter___165 *);
	ssize_t (*write_iter)(struct kiocb___391 *, struct iov_iter___165 *);
	int (*iopoll)(struct kiocb___391 *, bool);
	int (*iterate)(struct file___391 *, struct dir_context *);
	int (*iterate_shared)(struct file___391 *, struct dir_context *);
	__poll_t (*poll)(struct file___391 *, struct poll_table_struct___238 *);
	long int (*unlocked_ioctl)(struct file___391 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___391 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___391 *, struct vm_area_struct___392 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___391 *, struct file___391 *);
	int (*flush)(struct file___391 *, fl_owner_t);
	int (*release)(struct inode___391 *, struct file___391 *);
	int (*fsync)(struct file___391 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___391 *, int);
	int (*lock)(struct file___391 *, int, struct file_lock___391 *);
	ssize_t (*sendpage)(struct file___391 *, struct page___392 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___391 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___391 *, int, struct file_lock___391 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___391 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___391 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___391 *, long int, struct file_lock___391 **, void **);
	long int (*fallocate)(struct file___391 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___333 *, struct file___391 *);
	ssize_t (*copy_file_range)(struct file___391 *, loff_t, struct file___391 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___391 *, loff_t, struct file___391 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___391 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct perf_event___149;

struct debug_info___149 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___149 *hbp_break[16];
	struct perf_event___149 *hbp_watch[16];
};

struct task_struct___393;

struct hw_perf_event___149 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___393 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___149)(struct perf_event___149 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___149;

struct perf_event_context___149;

struct fasync_struct___391;

struct pid_namespace___225;

struct trace_event_call___142;

struct perf_cgroup___149;

struct perf_event___149 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___149 *group_leader;
	struct pmu___149 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___149 hw;
	struct perf_event_context___149 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___149 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___393 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___391 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___149 *);
	struct callback_head callback_head;
	struct pid_namespace___225 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___149 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___149 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___142 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___149 *cgrp;
	struct list_head sb_list;
};

struct thread_struct___149 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___149 debug;
	long: 64;
};

struct vmacache___392 {
	u64 seqnum;
	struct vm_area_struct___392 *vmas[4];
};

struct page_frag___392 {
	struct page___392 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___392;

struct mem_cgroup___136;

struct pid___225;

struct cred___361;

struct nsproxy___289;

struct signal_struct___268;

struct bio_list___193;

struct backing_dev_info___193;

struct css_set___244;

struct vm_struct___296;

struct task_struct___393 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___393 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___392 *mm;
	struct mm_struct___392 *active_mm;
	struct vmacache___392 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___393 *real_parent;
	struct task_struct___393 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___393 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___136 *active_memcg;
	long int rh_reserved2;
	struct pid___225 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___225 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___225 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___361 *ptracer_cred;
	const struct cred___361 *real_cred;
	const struct cred___361 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___289 *nsproxy;
	struct signal_struct___268 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___393 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___193 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___193 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___244 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___149 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___392 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___136 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___393 *oom_reaper_list;
	struct vm_struct___296 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___149 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___392 *pgtable_t___392;

struct address_space___391;

struct dev_pagemap___380;

struct page___392 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___391 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___392 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___392 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___392 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___380 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___136 *mem_cgroup;
};

struct pglist_data___392;

struct lruvec___392 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___392 *pgdat;
};

struct zone___392 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___392 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___392 {
	struct zone___392 *zone;
	int zone_idx;
};

struct zonelist___392 {
	struct zoneref___392 _zonerefs[25];
};

struct pglist_data___392 {
	struct zone___392 node_zones[3];
	struct zonelist___392 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___393 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___393 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___392 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___393 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___393 *owner;
};

struct secondary_data___393 {
	void *stack;
	struct task_struct___393 *task;
	long int status;
};

struct clock_event_device___18;

struct arch_timer_erratum_workaround___18 {
	enum arch_timer_erratum_match_type match_type;
	const void *id;
	const char *desc;
	u32 (*read_cntp_tval_el0)();
	u32 (*read_cntv_tval_el0)();
	u64 (*read_cntpct_el0)();
	u64 (*read_cntvct_el0)();
	int (*set_next_event_phys)(long unsigned int, struct clock_event_device___18 *);
	int (*set_next_event_virt)(long unsigned int, struct clock_event_device___18 *);
};

struct clock_event_device___18 {
	void (*event_handler)(struct clock_event_device___18 *);
	int (*set_next_event)(long unsigned int, struct clock_event_device___18 *);
	int (*set_next_ktime)(ktime_t, struct clock_event_device___18 *);
	ktime_t next_event;
	u64 max_delta_ns;
	u64 min_delta_ns;
	u32 mult;
	u32 shift;
	enum clock_event_state state_use_accessors;
	unsigned int features;
	long unsigned int retries;
	int (*set_state_periodic)(struct clock_event_device___18 *);
	int (*set_state_oneshot)(struct clock_event_device___18 *);
	int (*set_state_oneshot_stopped)(struct clock_event_device___18 *);
	int (*set_state_shutdown)(struct clock_event_device___18 *);
	int (*tick_resume)(struct clock_event_device___18 *);
	void (*broadcast)(const struct cpumask *);
	void (*suspend)(struct clock_event_device___18 *);
	void (*resume)(struct clock_event_device___18 *);
	long unsigned int min_delta_ticks;
	long unsigned int max_delta_ticks;
	const char *name;
	int rating;
	int irq;
	int bound_on;
	const struct cpumask *cpumask;
	struct list_head list;
	struct module___320 *owner;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct blocking_notifier_head___392 {
	struct rw_semaphore___393 rwsem;
	struct notifier_block *head;
};

struct key___361;

struct ucounts___260;

struct user_namespace___260 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___260 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___9 ns;
	long unsigned int flags;
	struct key___361 *persistent_keyring_register;
	struct rw_semaphore___393 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___260 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_root___385;

struct kernfs_elem_dir___385 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___385 *root;
};

struct kernfs_node___386;

struct kernfs_syscall_ops___385;

struct kernfs_root___385 {
	struct kernfs_node___386 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___385 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___385 {
	struct kernfs_node___386 *target_kn;
};

struct kernfs_ops___385;

struct kernfs_elem_attr___385 {
	const struct kernfs_ops___385 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___386 *notify_next;
};

struct kernfs_node___386 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___386 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___385 dir;
		struct kernfs_elem_symlink___385 symlink;
		struct kernfs_elem_attr___385 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___385;

struct kernfs_ops___385 {
	int (*open)(struct kernfs_open_file___385 *);
	void (*release)(struct kernfs_open_file___385 *);
	int (*seq_show)(struct seq_file___333 *, void *);
	void * (*seq_start)(struct seq_file___333 *, loff_t *);
	void * (*seq_next)(struct seq_file___333 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___333 *, void *);
	ssize_t (*read)(struct kernfs_open_file___385 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___385 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___385 *, struct vm_area_struct___392 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___385 *, struct poll_table_struct___238 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___385 {
	int (*remount_fs)(struct kernfs_root___385 *, int *, char *);
	int (*show_options)(struct seq_file___333 *, struct kernfs_root___385 *);
	int (*mkdir)(struct kernfs_node___386 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___386 *);
	int (*rename)(struct kernfs_node___386 *, struct kernfs_node___386 *, const char *);
	int (*show_path)(struct seq_file___333 *, struct kernfs_node___386 *, struct kernfs_root___385 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___333;

struct seq_file___333 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___333 *op;
	int poll_event;
	const struct file___391 *file;
	void *private;
};

struct vm_operations_struct___380;

struct kernfs_open_file___385 {
	struct kernfs_node___386 *kn;
	struct file___391 *file;
	struct seq_file___333 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___380 *vm_ops;
};

struct dentry___391;

struct path___392 {
	struct vfsmount *mnt;
	struct dentry___391 *dentry;
};

struct fown_struct___225 {
	rwlock_t lock;
	struct pid___225 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___391 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___392 f_path;
	struct inode___391 *f_inode;
	const struct file_operations___391 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___225 f_owner;
	const struct cred___361 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___391 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___380;

struct vm_operations_struct___380 {
	void (*open)(struct vm_area_struct___392 *);
	void (*close)(struct vm_area_struct___392 *);
	int (*split)(struct vm_area_struct___392 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___392 *);
	vm_fault_t (*fault)(struct vm_fault___380 *);
	vm_fault_t (*huge_fault)(struct vm_fault___380 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___380 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___392 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___380 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___380 *);
	int (*access)(struct vm_area_struct___392 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___392 *);
	int (*set_policy)(struct vm_area_struct___392 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___392 *, long unsigned int);
	struct page___392 * (*find_special_page)(struct vm_area_struct___392 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___246)(struct file___391 *, wait_queue_head_t *, struct poll_table_struct___238 *);

struct poll_table_struct___238 {
	poll_queue_proc___246 _qproc;
	__poll_t _key;
};

struct vm_area_struct___392 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___392 *vm_next;
	struct vm_area_struct___392 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___392 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___380 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___391 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___379;

struct bin_attribute___355;

struct attribute_group___356 {
	const char *name;
	umode_t (*is_visible)(struct kobject___379 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___379 *, struct bin_attribute___355 *, int);
	struct attribute **attrs;
	struct bin_attribute___355 **bin_attrs;
};

struct kset___378;

struct kobj_type___378;

struct kobject___379 {
	const char *name;
	struct list_head entry;
	struct kobject___379 *parent;
	struct kset___378 *kset;
	struct kobj_type___378 *ktype;
	struct kernfs_node___386 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___355 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___391 *, struct kobject___379 *, struct bin_attribute___355 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___391 *, struct kobject___379 *, struct bin_attribute___355 *, char *, loff_t, size_t);
	int (*mmap)(struct file___391 *, struct kobject___379 *, struct bin_attribute___355 *, struct vm_area_struct___392 *);
};

struct sysfs_ops___378 {
	ssize_t (*show)(struct kobject___379 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___379 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___378;

struct kset___378 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___379 kobj;
	const struct kset_uevent_ops___378 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___378 {
	void (*release)(struct kobject___379 *);
	const struct sysfs_ops___378 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___29 * (*child_ns_type)(struct kobject___379 *);
	const void * (*namespace)(struct kobject___379 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___378 {
	int (* const filter)(struct kset___378 *, struct kobject___379 *);
	const char * (* const name)(struct kset___378 *, struct kobject___379 *);
	int (* const uevent)(struct kset___378 *, struct kobject___379 *, struct kobj_uevent_env *);
};

struct kobj_attribute___370 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___379 *, struct kobj_attribute___370 *, char *);
	ssize_t (*store)(struct kobject___379 *, struct kobj_attribute___370 *, const char *, size_t);
};

struct device___359;

struct dev_pm_ops___359 {
	int (*prepare)(struct device___359 *);
	void (*complete)(struct device___359 *);
	int (*suspend)(struct device___359 *);
	int (*resume)(struct device___359 *);
	int (*freeze)(struct device___359 *);
	int (*thaw)(struct device___359 *);
	int (*poweroff)(struct device___359 *);
	int (*restore)(struct device___359 *);
	int (*suspend_late)(struct device___359 *);
	int (*resume_early)(struct device___359 *);
	int (*freeze_late)(struct device___359 *);
	int (*thaw_early)(struct device___359 *);
	int (*poweroff_late)(struct device___359 *);
	int (*restore_early)(struct device___359 *);
	int (*suspend_noirq)(struct device___359 *);
	int (*resume_noirq)(struct device___359 *);
	int (*freeze_noirq)(struct device___359 *);
	int (*thaw_noirq)(struct device___359 *);
	int (*poweroff_noirq)(struct device___359 *);
	int (*restore_noirq)(struct device___359 *);
	int (*runtime_suspend)(struct device___359 *);
	int (*runtime_resume)(struct device___359 *);
	int (*runtime_idle)(struct device___359 *);
};

struct dev_pm_qos___23;

struct dev_pm_info___359 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___359 *, s32);
	struct dev_pm_qos___23 *qos;
};

struct device_type___359;

struct bus_type___359;

struct device_driver___359;

struct dev_pm_domain___359;

struct device_node___92;

struct fwnode_handle___280;

struct class___359;

struct device___359 {
	struct device___359 *parent;
	struct device_private *p;
	struct kobject___379 kobj;
	const char *init_name;
	const struct device_type___359 *type;
	struct mutex mutex;
	struct bus_type___359 *bus;
	struct device_driver___359 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___359 power;
	struct dev_pm_domain___359 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___92 *of_node;
	struct fwnode_handle___280 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___359 *class;
	const struct attribute_group___356 **groups;
	void (*release)(struct device___359 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct pm_qos_constraints___22 {
	struct plist_head list;
	s32 target_value;
	s32 default_value;
	s32 no_constraint_value;
	enum pm_qos_type type;
	struct blocking_notifier_head___392 *notifiers;
};

struct dev_pm_qos_request___24;

struct dev_pm_qos___23 {
	struct pm_qos_constraints___22 resume_latency;
	struct pm_qos_constraints___22 latency_tolerance;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___24 *resume_latency_req;
	struct dev_pm_qos_request___24 *latency_tolerance_req;
	struct dev_pm_qos_request___24 *flags_req;
};

struct dev_pm_domain___359 {
	struct dev_pm_ops___359 ops;
	void (*detach)(struct device___359 *, bool);
	int (*activate)(struct device___359 *);
	void (*sync)(struct device___359 *);
	void (*dismiss)(struct device___359 *);
};

struct upid___225 {
	int nr;
	struct pid_namespace___225 *ns;
};

struct pid_namespace___225 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___393 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___225 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___391 *proc_self;
	struct dentry___391 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___260 *user_ns;
	struct ucounts___260 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___9 ns;
};

struct pid___225 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___225 numbers[1];
};

struct user_struct___361 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___361 *uid_keyring;
	struct key___361 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___392;

struct mm_struct___392 {
	struct {
		struct vm_area_struct___392 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___391 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___393 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___392 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___393 *owner;
		struct user_namespace___260 *user_ns;
		struct file___391 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___392 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup___244;

struct cgroup_subsys___244;

struct cgroup_subsys_state___244 {
	struct cgroup___244 *cgroup;
	struct cgroup_subsys___244 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___244 *parent;
};

struct cgroup_file___244 {
	struct kernfs_node___386 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___136;

struct mem_cgroup___136 {
	struct cgroup_subsys_state___244 css;
	struct mem_cgroup_id___12 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___244 events_file;
	struct cgroup_file___244 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___393 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___136 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cred___361 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___361 *session_keyring;
	struct key___361 *process_keyring;
	struct key___361 *thread_keyring;
	struct key___361 *request_key_auth;
	void *security;
	struct user_struct___361 *user;
	struct user_namespace___260 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___244;

struct nsproxy___289 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___225 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___244 *cgroup_ns;
};

struct signal_struct___268 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___393 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___393 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___225 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___225 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___392 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___225 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide45;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___193;

struct bio_list___193 {
	struct bio___193 *head;
	struct bio___193 *tail;
};

struct bdi_writeback_congested___193;

struct bdi_writeback___193 {
	struct backing_dev_info___193 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___193 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___244 *memcg_css;
	struct cgroup_subsys_state___244 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___193 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___193 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___359 *dev;
	struct device___359 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___391 *debug_dir;
	struct dentry___391 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___244 {
	struct cgroup_subsys_state___244 *subsys[13];
	refcount_t refcount;
	struct css_set___244 *dom_cset;
	struct cgroup___244 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___244 *mg_src_cgrp;
	struct cgroup___244 *mg_dst_cgrp;
	struct css_set___244 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___149 {
	struct pmu___149 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___393 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___149 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___296 {
	struct vm_struct___296 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___392 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___280 {
	struct task_struct___393 task;
	long unsigned int stack[8192];
};

struct bus_type___359 {
	const char *name;
	const char *dev_name;
	struct device___359 *dev_root;
	const struct attribute_group___356 **bus_groups;
	const struct attribute_group___356 **dev_groups;
	const struct attribute_group___356 **drv_groups;
	int (*match)(struct device___359 *, struct device_driver___359 *);
	int (*uevent)(struct device___359 *, struct kobj_uevent_env *);
	int (*probe)(struct device___359 *);
	int (*remove)(struct device___359 *);
	void (*shutdown)(struct device___359 *);
	int (*online)(struct device___359 *);
	int (*offline)(struct device___359 *);
	int (*suspend)(struct device___359 *, pm_message_t);
	int (*resume)(struct device___359 *);
	int (*num_vf)(struct device___359 *);
	int (*dma_configure)(struct device___359 *);
	const struct dev_pm_ops___359 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___359 {
	const char *name;
	struct bus_type___359 *bus;
	struct module___320 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___359 *);
	int (*remove)(struct device___359 *);
	void (*shutdown)(struct device___359 *);
	int (*suspend)(struct device___359 *, pm_message_t);
	int (*resume)(struct device___359 *);
	const struct attribute_group___356 **groups;
	const struct dev_pm_ops___359 *pm;
	void (*coredump)(struct device___359 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___359 {
	const char *name;
	const struct attribute_group___356 **groups;
	int (*uevent)(struct device___359 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___359 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___359 *);
	const struct dev_pm_ops___359 *pm;
};

struct module_kobject___318 {
	struct kobject___379 kobj;
	struct module___320 *mod;
	struct kobject___379 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___318 {
	struct module___320 *mod;
	struct latch_tree_node node;
};

struct module_layout___318 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___318 mtn;
};

struct module_attribute___318;

struct kernel_param___318;

struct module___320 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___318 mkobj;
	struct module_attribute___318 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___379 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___318 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___318 core_layout;
	struct module_layout___318 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___142 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct subsys_interface___2 {
	const char *name;
	struct bus_type___359 *subsys;
	struct list_head node;
	int (*add_dev)(struct device___359 *, struct subsys_interface___2 *);
	void (*remove_dev)(struct device___359 *, struct subsys_interface___2 *);
};

struct class___359 {
	const char *name;
	struct module___320 *owner;
	const struct attribute_group___356 **class_groups;
	const struct attribute_group___356 **dev_groups;
	struct kobject___379 *dev_kobj;
	int (*dev_uevent)(struct device___359 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___359 *, umode_t *);
	void (*class_release)(struct class___359 *);
	void (*dev_release)(struct device___359 *);
	int (*shutdown_pre)(struct device___359 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___359 *);
	const struct dev_pm_ops___359 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct fwnode_operations___280;

struct fwnode_handle___280 {
	struct fwnode_handle___280 *secondary;
	const struct fwnode_operations___280 *ops;
};

struct property___88;

struct device_node___92 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___280 fwnode;
	struct property___88 *properties;
	struct property___88 *deadprops;
	struct device_node___92 *parent;
	struct device_node___92 *child;
	struct device_node___92 *sibling;
	struct kobject___379 kobj;
	long unsigned int _flags;
	void *data;
};

struct node___215 {
	struct device___359 dev;
};

struct cpufreq_freqs {
	unsigned int cpu;
	unsigned int old;
	unsigned int new;
	u8 flags;
};

struct cpufreq_governor___8;

struct cpufreq_policy___8 {
	cpumask_var_t cpus;
	cpumask_var_t related_cpus;
	cpumask_var_t real_cpus;
	unsigned int shared_type;
	unsigned int cpu;
	struct clk *clk;
	struct cpufreq_cpuinfo cpuinfo;
	unsigned int min;
	unsigned int max;
	unsigned int cur;
	unsigned int restore_freq;
	unsigned int suspend_freq;
	unsigned int policy;
	unsigned int last_policy;
	struct cpufreq_governor___8 *governor;
	void *governor_data;
	char last_governor[16];
	struct work_struct update;
	struct cpufreq_user_policy user_policy;
	struct cpufreq_frequency_table *freq_table;
	enum cpufreq_table_sorting freq_table_sorted;
	struct list_head policy_list;
	struct kobject___379 kobj;
	struct completion kobj_unregister;
	struct rw_semaphore___393 rwsem;
	bool fast_switch_possible;
	bool fast_switch_enabled;
	unsigned int transition_delay_us;
	bool dvfs_possible_from_any_cpu;
	unsigned int cached_target_freq;
	int cached_resolved_idx;
	bool transition_ongoing;
	spinlock_t transition_lock;
	wait_queue_head_t transition_wait;
	struct task_struct___393 *transition_task;
	struct cpufreq_stats *stats;
	void *driver_data;
};

struct cpufreq_governor___8 {
	char name[16];
	int (*init)(struct cpufreq_policy___8 *);
	void (*exit)(struct cpufreq_policy___8 *);
	int (*start)(struct cpufreq_policy___8 *);
	void (*stop)(struct cpufreq_policy___8 *);
	void (*limits)(struct cpufreq_policy___8 *);
	ssize_t (*show_setspeed)(struct cpufreq_policy___8 *, char *);
	int (*store_setspeed)(struct cpufreq_policy___8 *, unsigned int);
	bool dynamic_switching;
	struct list_head governor_list;
	struct module___320 *owner;
};

struct freq_attr___8 {
	struct attribute attr;
	ssize_t (*show)(struct cpufreq_policy___8 *, char *);
	ssize_t (*store)(struct cpufreq_policy___8 *, const char *, size_t);
};

struct global_attr {
	struct attribute attr;
	ssize_t (*show)(struct kobject___379 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___379 *, struct attribute *, const char *, size_t);
};

struct cpufreq_driver {
	char name[16];
	u8 flags;
	void *driver_data;
	int (*init)(struct cpufreq_policy___8 *);
	int (*verify)(struct cpufreq_policy___8 *);
	int (*setpolicy)(struct cpufreq_policy___8 *);
	int (*target)(struct cpufreq_policy___8 *, unsigned int, unsigned int);
	int (*target_index)(struct cpufreq_policy___8 *, unsigned int);
	unsigned int (*fast_switch)(struct cpufreq_policy___8 *, unsigned int);
	unsigned int (*resolve_freq)(struct cpufreq_policy___8 *, unsigned int);
	unsigned int (*get_intermediate)(struct cpufreq_policy___8 *, unsigned int);
	int (*target_intermediate)(struct cpufreq_policy___8 *, unsigned int);
	unsigned int (*get)(unsigned int);
	int (*bios_limit)(int, unsigned int *);
	int (*exit)(struct cpufreq_policy___8 *);
	void (*stop_cpu)(struct cpufreq_policy___8 *);
	int (*suspend)(struct cpufreq_policy___8 *);
	int (*resume)(struct cpufreq_policy___8 *);
	void (*ready)(struct cpufreq_policy___8 *);
	struct freq_attr___8 **attr;
	bool boost_enabled;
	int (*set_boost)(int);
};

struct kernel_param_ops___318 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___318 *);
	int (*get)(char *, const struct kernel_param___318 *);
	void (*free)(void *);
};

struct kparam_array___318;

struct kernel_param___318 {
	const char *name;
	struct module___320 *mod;
	const struct kernel_param_ops___318 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___318 *arr;
	};
};

struct kparam_array___318 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___318 *ops;
	void *elem;
};

struct module_attribute___318 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___318 *, struct module_kobject___318 *, char *);
	ssize_t (*store)(struct module_attribute___318 *, struct module_kobject___318 *, const char *, size_t);
	void (*setup)(struct module___320 *, const char *);
	int (*test)(struct module___320 *);
	void (*free)(struct module___320 *);
};

struct trace_event_class___142;

struct trace_event_call___142 {
	struct list_head list;
	struct trace_event_class___142 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___13 event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___39 *prog_array;
	int (*perf_perm)(struct trace_event_call___142 *, struct perf_event___149 *);
};

struct dentry_operations___391;

struct super_block___391;

struct dentry___391 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___391 *d_parent;
	struct qstr d_name;
	struct inode___391 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___391 *d_op;
	struct super_block___391 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___391;

struct address_space___391 {
	struct inode___391 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___393 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___391 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___391;

struct block_device___391;

struct inode___391 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___391 *i_op;
	struct super_block___391 *i_sb;
	struct address_space___391 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___393 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___193 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___391 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___391 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___391 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___391 {
	int (*d_revalidate)(struct dentry___391 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___391 *, unsigned int);
	int (*d_hash)(const struct dentry___391 *, struct qstr *);
	int (*d_compare)(const struct dentry___391 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___391 *);
	int (*d_init)(struct dentry___391 *);
	void (*d_release)(struct dentry___391 *);
	void (*d_prune)(struct dentry___391 *);
	void (*d_iput)(struct dentry___391 *, struct inode___391 *);
	char * (*d_dname)(struct dentry___391 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___392 *);
	int (*d_manage)(const struct path___392 *, bool);
	struct dentry___391 * (*d_real)(struct dentry___391 *, const struct inode___391 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___391;

struct mem_dqinfo___391 {
	struct quota_format_type___391 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___391;

struct quota_info___391 {
	unsigned int flags;
	struct rw_semaphore___393 dqio_sem;
	struct inode___391 *files[3];
	struct mem_dqinfo___391 info[3];
	const struct quota_format_ops___391 *ops[3];
};

struct rcuwait___391 {
	struct task_struct___393 *task;
};

struct percpu_rw_semaphore___391 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___393 rw_sem;
	struct rcuwait___391 writer;
	int readers_block;
};

struct sb_writers___391 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___391 rw_sem[3];
};

struct shrink_control___136;

struct shrinker___136 {
	long unsigned int (*count_objects)(struct shrinker___136 *, struct shrink_control___136 *);
	long unsigned int (*scan_objects)(struct shrinker___136 *, struct shrink_control___136 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___391;

struct super_operations___391;

struct dquot_operations___391;

struct quotactl_ops___391;

struct super_block___391 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___391 *s_type;
	const struct super_operations___391 *s_op;
	const struct dquot_operations___391 *dq_op;
	const struct quotactl_ops___391 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___391 *s_root;
	struct rw_semaphore___393 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___391 *s_bdev;
	struct backing_dev_info___193 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___391 s_dquot;
	struct sb_writers___391 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___391 *s_d_op;
	int cleancache_poolid;
	struct shrinker___136 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___260 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___136 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___136 *memcg;
};

typedef int (*dev_page_fault_t___380)(struct vm_area_struct___392 *, long unsigned int, const struct page___392 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___380)(struct page___392 *, void *);

struct dev_pagemap___380 {
	dev_page_fault_t___380 page_fault;
	dev_page_free_t___380 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___359 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___392 {
	struct task_struct___393 *task;
	struct core_thread___392 *next;
};

struct core_state___392 {
	atomic_t nr_threads;
	struct core_thread___392 dumper;
	struct completion startup;
};

struct vm_fault___380 {
	struct vm_area_struct___392 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___392 *cow_page;
	struct mem_cgroup___136 *memcg;
	struct page___392 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___392 prealloc_pte;
};

struct kiocb___391 {
	struct file___391 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___391 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___391 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___391 *ia_file;
};

struct dquot___391 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___391 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___391 {
	int qf_fmt_id;
	const struct quota_format_ops___391 *qf_ops;
	struct module___320 *qf_owner;
	struct quota_format_type___391 *qf_next;
};

struct quota_format_ops___391 {
	int (*check_quota_file)(struct super_block___391 *, int);
	int (*read_file_info)(struct super_block___391 *, int);
	int (*write_file_info)(struct super_block___391 *, int);
	int (*free_file_info)(struct super_block___391 *, int);
	int (*read_dqblk)(struct dquot___391 *);
	int (*commit_dqblk)(struct dquot___391 *);
	int (*release_dqblk)(struct dquot___391 *);
	int (*get_next_id)(struct super_block___391 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___391 {
	int (*write_dquot)(struct dquot___391 *);
	struct dquot___391 * (*alloc_dquot)(struct super_block___391 *, int);
	void (*destroy_dquot)(struct dquot___391 *);
	int (*acquire_dquot)(struct dquot___391 *);
	int (*release_dquot)(struct dquot___391 *);
	int (*mark_dirty)(struct dquot___391 *);
	int (*write_info)(struct super_block___391 *, int);
	qsize_t * (*get_reserved_space)(struct inode___391 *);
	int (*get_projid)(struct inode___391 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___391 *, qsize_t *);
	int (*get_next_id)(struct super_block___391 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___391 {
	int (*quota_on)(struct super_block___391 *, int, int, const struct path___392 *);
	int (*quota_off)(struct super_block___391 *, int);
	int (*quota_enable)(struct super_block___391 *, unsigned int);
	int (*quota_disable)(struct super_block___391 *, unsigned int);
	int (*quota_sync)(struct super_block___391 *, int);
	int (*set_info)(struct super_block___391 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___391 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___391 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___391 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___391 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___391 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___156;

struct swap_info_struct___91;

struct address_space_operations___391 {
	int (*writepage)(struct page___392 *, struct writeback_control___156 *);
	int (*readpage)(struct file___391 *, struct page___392 *);
	int (*writepages)(struct address_space___391 *, struct writeback_control___156 *);
	int (*set_page_dirty)(struct page___392 *);
	int (*readpages)(struct file___391 *, struct address_space___391 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___391 *, struct address_space___391 *, loff_t, unsigned int, unsigned int, struct page___392 **, void **);
	int (*write_end)(struct file___391 *, struct address_space___391 *, loff_t, unsigned int, unsigned int, struct page___392 *, void *);
	sector_t (*bmap)(struct address_space___391 *, sector_t);
	void (*invalidatepage)(struct page___392 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___392 *, gfp_t);
	void (*freepage)(struct page___392 *);
	ssize_t (*direct_IO)(struct kiocb___391 *, struct iov_iter___165 *);
	int (*migratepage)(struct address_space___391 *, struct page___392 *, struct page___392 *, enum migrate_mode);
	bool (*isolate_page)(struct page___392 *, isolate_mode_t);
	void (*putback_page)(struct page___392 *);
	int (*launder_page)(struct page___392 *);
	int (*is_partially_uptodate)(struct page___392 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___392 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___391 *, struct page___392 *);
	int (*swap_activate)(struct swap_info_struct___91 *, struct file___391 *, sector_t *);
	void (*swap_deactivate)(struct file___391 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___156 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___193 *wb;
	struct inode___391 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___195;

struct iov_iter___165 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___195 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct swap_info_struct___91 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___391 *bdev;
	struct file___391 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___391 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___391 *bd_inode;
	struct super_block___391 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___391 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___193 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___391 {
	struct dentry___391 * (*lookup)(struct inode___391 *, struct dentry___391 *, unsigned int);
	const char * (*get_link)(struct dentry___391 *, struct inode___391 *, struct delayed_call *);
	int (*permission)(struct inode___391 *, int);
	struct posix_acl * (*get_acl)(struct inode___391 *, int);
	int (*readlink)(struct dentry___391 *, char *, int);
	int (*create)(struct inode___391 *, struct dentry___391 *, umode_t, bool);
	int (*link)(struct dentry___391 *, struct inode___391 *, struct dentry___391 *);
	int (*unlink)(struct inode___391 *, struct dentry___391 *);
	int (*symlink)(struct inode___391 *, struct dentry___391 *, const char *);
	int (*mkdir)(struct inode___391 *, struct dentry___391 *, umode_t);
	int (*rmdir)(struct inode___391 *, struct dentry___391 *);
	int (*mknod)(struct inode___391 *, struct dentry___391 *, umode_t, dev_t);
	int (*rename)(struct inode___391 *, struct dentry___391 *, struct inode___391 *, struct dentry___391 *, unsigned int);
	int (*setattr)(struct dentry___391 *, struct iattr___391 *);
	int (*getattr)(const struct path___392 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___391 *, char *, size_t);
	int (*fiemap)(struct inode___391 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___391 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___391 *, struct dentry___391 *, struct file___391 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___391 *, struct dentry___391 *, umode_t);
	int (*set_acl)(struct inode___391 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___391 {
	void (*fl_copy_lock)(struct file_lock___391 *, struct file_lock___391 *);
	void (*fl_release_private)(struct file_lock___391 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___391;

struct file_lock___391 {
	struct file_lock___391 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___391 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___391 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___391 *fl_ops;
	const struct lock_manager_operations___391 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___391 {
	int (*lm_compare_owner)(struct file_lock___391 *, struct file_lock___391 *);
	long unsigned int (*lm_owner_key)(struct file_lock___391 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___391 *);
	int (*lm_grant)(struct file_lock___391 *, int);
	bool (*lm_break)(struct file_lock___391 *);
	int (*lm_change)(struct file_lock___391 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___391 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___391 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___391 *fa_next;
	struct file___391 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___391 {
	const char *name;
	int fs_flags;
	struct dentry___391 * (*mount)(struct file_system_type___391 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___391 *);
	struct module___320 *owner;
	struct file_system_type___391 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___391 {
	struct inode___391 * (*alloc_inode)(struct super_block___391 *);
	void (*destroy_inode)(struct inode___391 *);
	void (*dirty_inode)(struct inode___391 *, int);
	int (*write_inode)(struct inode___391 *, struct writeback_control___156 *);
	int (*drop_inode)(struct inode___391 *);
	void (*evict_inode)(struct inode___391 *);
	void (*put_super)(struct super_block___391 *);
	int (*sync_fs)(struct super_block___391 *, int);
	int (*freeze_super)(struct super_block___391 *);
	int (*freeze_fs)(struct super_block___391 *);
	int (*thaw_super)(struct super_block___391 *);
	int (*unfreeze_fs)(struct super_block___391 *);
	int (*statfs)(struct dentry___391 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___391 *, int *, char *);
	void (*umount_begin)(struct super_block___391 *);
	int (*show_options)(struct seq_file___333 *, struct dentry___391 *);
	int (*show_devname)(struct seq_file___333 *, struct dentry___391 *);
	int (*show_path)(struct seq_file___333 *, struct dentry___391 *);
	int (*show_stats)(struct seq_file___333 *, struct dentry___391 *);
	ssize_t (*quota_read)(struct super_block___391 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___391 *, int, const char *, size_t, loff_t);
	struct dquot___391 ** (*get_dquots)(struct inode___391 *);
	int (*bdev_try_to_free_page)(struct super_block___391 *, struct page___392 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___391 *, struct shrink_control___136 *);
	long int (*free_cached_objects)(struct super_block___391 *, struct shrink_control___136 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___193(struct bio___193 *);

struct bio_vec___195 {
	struct page___392 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___193;

struct bio_set___193;

struct bio___193 {
	struct bio___193 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___193 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___193 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___195 *bi_io_vec;
	struct bio_set___193 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___195 bi_inline_vecs[0];
};

typedef int (*key_restrict_link_func_t___362)(struct key___361 *, const struct key_type *, const union key_payload *, struct key___361 *);

struct key_restriction___361;

struct key___361 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___393 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___361 *restrict_link;
};

struct key_restriction___361 {
	key_restrict_link_func_t___362 check;
	struct key___361 *key;
	struct key_type *keytype;
};

struct seq_operations___333 {
	void * (*start)(struct seq_file___333 *, loff_t *);
	void (*stop)(struct seq_file___333 *, void *);
	void * (*next)(struct seq_file___333 *, void *, loff_t *);
	int (*show)(struct seq_file___333 *, void *);
};

struct cgroup_namespace___244 {
	refcount_t count;
	struct ns_common___9 ns;
	struct user_namespace___260 *user_ns;
	struct ucounts___260 *ucounts;
	struct css_set___244 *root_cset;
};

struct ucounts___260 {
	struct hlist_node node;
	struct user_namespace___260 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___245;

struct bpf_map_ops___244 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___245 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___245 *, struct file___391 *);
	void (*map_free)(struct bpf_map___245 *);
	int (*map_get_next_key)(struct bpf_map___245 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___245 *);
	void * (*map_lookup_elem)(struct bpf_map___245 *, void *);
	int (*map_update_elem)(struct bpf_map___245 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___245 *, void *);
	int (*map_push_elem)(struct bpf_map___245 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___245 *, void *);
	int (*map_peek_elem)(struct bpf_map___245 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___245 *, struct file___391 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___245 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___245 *, void *, struct seq_file___333 *);
	int (*map_check_btf)(const struct bpf_map___245 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___245 {
	const struct bpf_map_ops___244 *ops;
	struct bpf_map___245 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___361 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___245;

typedef void (*kthread_work_func_t___245)(struct kthread_work___245 *);

struct kthread_worker___245;

struct kthread_work___245 {
	struct list_head node;
	kthread_work_func_t___245 func;
	struct kthread_worker___245 *worker;
	int canceling;
};

struct kthread_worker___245 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___393 *task;
	struct kthread_work___245 *current_work;
};

struct kthread_delayed_work___244 {
	struct kthread_work___245 work;
	struct timer_list timer;
};

struct psi_group___244 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___245 *poll_kworker;
	struct kthread_delayed_work___244 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___244;

struct cgroup_rstat_cpu___244;

struct cgroup___244 {
	struct cgroup_subsys_state___244 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___386 *kn;
	struct cgroup_file___244 procs_file;
	struct cgroup_file___244 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___244 *subsys[13];
	struct cgroup_root___244 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___244 *dom_cgrp;
	struct cgroup_rstat_cpu___244 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___39 bpf;
	atomic_t congestion_count;
	struct cgroup___244 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___244 psi;
	int ancestor_ids[0];
};

struct cftype___244;

struct cgroup_subsys___244 {
	struct cgroup_subsys_state___244 * (*css_alloc)(struct cgroup_subsys_state___244 *);
	int (*css_online)(struct cgroup_subsys_state___244 *);
	void (*css_offline)(struct cgroup_subsys_state___244 *);
	void (*css_released)(struct cgroup_subsys_state___244 *);
	void (*css_free)(struct cgroup_subsys_state___244 *);
	void (*css_reset)(struct cgroup_subsys_state___244 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___244 *, int);
	int (*css_extra_stat_show)(struct seq_file___333 *, struct cgroup_subsys_state___244 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___393 *);
	void (*cancel_fork)(struct task_struct___393 *);
	void (*fork)(struct task_struct___393 *);
	void (*exit)(struct task_struct___393 *);
	void (*free)(struct task_struct___393 *);
	void (*bind)(struct cgroup_subsys_state___244 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___244 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___244 *dfl_cftypes;
	struct cftype___244 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___244 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___244 *updated_children;
	struct cgroup___244 *updated_next;
};

struct cgroup_root___244 {
	struct kernfs_root___385 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___244 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___244 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___244 *ss;
	struct list_head node;
	struct kernfs_ops___385 *kf_ops;
	int (*open)(struct kernfs_open_file___385 *);
	void (*release)(struct kernfs_open_file___385 *);
	u64 (*read_u64)(struct cgroup_subsys_state___244 *, struct cftype___244 *);
	s64 (*read_s64)(struct cgroup_subsys_state___244 *, struct cftype___244 *);
	int (*seq_show)(struct seq_file___333 *, void *);
	void * (*seq_start)(struct seq_file___333 *, loff_t *);
	void * (*seq_next)(struct seq_file___333 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___333 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___244 *, struct cftype___244 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___244 *, struct cftype___244 *, s64);
	ssize_t (*write)(struct kernfs_open_file___385 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___385 *, struct poll_table_struct___238 *);
};

typedef void compound_page_dtor___380(struct page___392 *);

struct bdi_writeback_congested___193 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___193 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___193 {
	struct bio___193 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___195 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___195 bip_inline_vecs[0];
};

struct bio_set___193 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___193 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___136 {
	struct mem_cgroup___136 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___136 {
	struct lruvec___392 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___136 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___136 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct fwnode_reference_args___280;

struct fwnode_endpoint___280;

struct fwnode_operations___280 {
	struct fwnode_handle___280 * (*get)(struct fwnode_handle___280 *);
	void (*put)(struct fwnode_handle___280 *);
	bool (*device_is_available)(const struct fwnode_handle___280 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___280 *, const struct device___359 *);
	bool (*property_present)(const struct fwnode_handle___280 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___280 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___280 *, const char *, const char **, size_t);
	struct fwnode_handle___280 * (*get_parent)(const struct fwnode_handle___280 *);
	struct fwnode_handle___280 * (*get_next_child_node)(const struct fwnode_handle___280 *, struct fwnode_handle___280 *);
	struct fwnode_handle___280 * (*get_named_child_node)(const struct fwnode_handle___280 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___280 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___280 *);
	struct fwnode_handle___280 * (*graph_get_next_endpoint)(const struct fwnode_handle___280 *, struct fwnode_handle___280 *);
	struct fwnode_handle___280 * (*graph_get_remote_endpoint)(const struct fwnode_handle___280 *);
	struct fwnode_handle___280 * (*graph_get_port_parent)(struct fwnode_handle___280 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___280 *, struct fwnode_endpoint___280 *);
};

struct fwnode_endpoint___280 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___280 *local_fwnode;
};

struct fwnode_reference_args___280 {
	struct fwnode_handle___280 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct property___88 {
	char *name;
	int length;
	void *value;
	struct property___88 *next;
	long unsigned int _flags;
	struct bin_attribute___355 attr;
};

struct dev_pm_qos_request___24 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___359 *dev;
};

struct perf_cpu_context___149;

struct pmu___149 {
	struct list_head entry;
	struct module___320 *module;
	struct device___359 *dev;
	const struct attribute_group___356 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___149 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___149 *);
	void (*pmu_disable)(struct pmu___149 *);
	int (*event_init)(struct perf_event___149 *);
	void (*event_mapped)(struct perf_event___149 *, struct mm_struct___392 *);
	void (*event_unmapped)(struct perf_event___149 *, struct mm_struct___392 *);
	int (*add)(struct perf_event___149 *, int);
	void (*del)(struct perf_event___149 *, int);
	void (*start)(struct perf_event___149 *, int);
	void (*stop)(struct perf_event___149 *, int);
	void (*read)(struct perf_event___149 *);
	void (*start_txn)(struct pmu___149 *, unsigned int);
	int (*commit_txn)(struct pmu___149 *);
	void (*cancel_txn)(struct pmu___149 *);
	int (*event_idx)(struct perf_event___149 *);
	void (*sched_task)(struct perf_event_context___149 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___149 *);
	int (*filter_match)(struct perf_event___149 *);
	int (*check_period)(struct perf_event___149 *, u64);
};

struct perf_cpu_context___149 {
	struct perf_event_context___149 ctx;
	struct perf_event_context___149 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___149 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___149 {
	struct cgroup_subsys_state___244 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___142 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___142 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___142 *);
	struct list_head * (*get_fields)(struct trace_event_call___142 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___142 *);
};

struct cpufreq_governor___9;

struct cpufreq_policy___9 {
	cpumask_var_t cpus;
	cpumask_var_t related_cpus;
	cpumask_var_t real_cpus;
	unsigned int shared_type;
	unsigned int cpu;
	struct clk *clk;
	struct cpufreq_cpuinfo cpuinfo;
	unsigned int min;
	unsigned int max;
	unsigned int cur;
	unsigned int restore_freq;
	unsigned int suspend_freq;
	unsigned int policy;
	unsigned int last_policy;
	struct cpufreq_governor___9 *governor;
	void *governor_data;
	char last_governor[16];
	struct work_struct update;
	struct cpufreq_user_policy user_policy;
	struct cpufreq_frequency_table *freq_table;
	enum cpufreq_table_sorting freq_table_sorted;
	struct list_head policy_list;
	struct kobject___379 kobj;
	struct completion kobj_unregister;
	struct rw_semaphore___393 rwsem;
	bool fast_switch_possible;
	bool fast_switch_enabled;
	unsigned int transition_delay_us;
	bool dvfs_possible_from_any_cpu;
	unsigned int cached_target_freq;
	int cached_resolved_idx;
	bool transition_ongoing;
	spinlock_t transition_lock;
	wait_queue_head_t transition_wait;
	struct task_struct___6 *transition_task;
	struct cpufreq_stats *stats;
	void *driver_data;
};

struct cpufreq_governor___9 {
	char name[16];
	int (*init)(struct cpufreq_policy___9 *);
	void (*exit)(struct cpufreq_policy___9 *);
	int (*start)(struct cpufreq_policy___9 *);
	void (*stop)(struct cpufreq_policy___9 *);
	void (*limits)(struct cpufreq_policy___9 *);
	ssize_t (*show_setspeed)(struct cpufreq_policy___9 *, char *);
	int (*store_setspeed)(struct cpufreq_policy___9 *, unsigned int);
	bool dynamic_switching;
	struct list_head governor_list;
	struct module___302 *owner;
};

struct freq_attr___9 {
	struct attribute attr;
	ssize_t (*show)(struct cpufreq_policy___9 *, char *);
	ssize_t (*store)(struct cpufreq_policy___9 *, const char *, size_t);
};

struct cpufreq_stats {
	unsigned int total_trans;
	long long unsigned int last_time;
	unsigned int max_state;
	unsigned int state_num;
	unsigned int last_index;
	u64 *time_in_state;
	unsigned int *freq_table;
	unsigned int *trans_table;
};

struct gov_attr_set {
	struct kobject___379 kobj;
	struct list_head policy_list;
	struct mutex update_lock;
	int usage_count;
};

struct governor_attr {
	struct attribute attr;
	ssize_t (*show)(struct gov_attr_set *, char *);
	ssize_t (*store)(struct gov_attr_set *, const char *, size_t);
};

enum {
	OD_NORMAL_SAMPLE = 0,
	OD_SUB_SAMPLE = 1,
};

struct dbs_data {
	struct gov_attr_set attr_set;
	void *tuners;
	unsigned int ignore_nice_load;
	unsigned int sampling_rate;
	unsigned int sampling_down_factor;
	unsigned int up_threshold;
	unsigned int io_is_busy;
};

struct policy_dbs_info {
	struct cpufreq_policy___8 *policy;
	struct mutex update_mutex;
	u64 last_sample_time;
	s64 sample_delay_ns;
	atomic_t work_count;
	struct irq_work irq_work;
	struct work_struct work;
	struct dbs_data *dbs_data;
	struct list_head list;
	unsigned int rate_mult;
	unsigned int idle_periods;
	bool is_shared;
	bool work_in_progress;
};

struct dbs_governor {
	struct cpufreq_governor___8 gov;
	struct kobj_type___378 kobj_type;
	struct dbs_data *gdbs_data;
	unsigned int (*gov_dbs_update)(struct cpufreq_policy___8 *);
	struct policy_dbs_info * (*alloc)();
	void (*free)(struct policy_dbs_info *);
	int (*init)(struct dbs_data *);
	void (*exit)(struct dbs_data *);
	void (*start)(struct cpufreq_policy___8 *);
};

struct od_ops {
	unsigned int (*powersave_bias_target)(struct cpufreq_policy___8 *, unsigned int, unsigned int);
};

struct od_policy_dbs_info {
	struct policy_dbs_info policy_dbs;
	unsigned int freq_lo;
	unsigned int freq_lo_delay_us;
	unsigned int freq_hi_delay_us;
	unsigned int sample_type: 1;
};

struct od_dbs_tuners {
	unsigned int powersave_bias;
};

struct policy_dbs_info___2 {
	struct cpufreq_policy___5 *policy;
	struct mutex update_mutex;
	u64 last_sample_time;
	s64 sample_delay_ns;
	atomic_t work_count;
	struct irq_work irq_work;
	struct work_struct work;
	struct dbs_data *dbs_data;
	struct list_head list;
	unsigned int rate_mult;
	unsigned int idle_periods;
	bool is_shared;
	bool work_in_progress;
};

struct dbs_governor___2 {
	struct cpufreq_governor___5 gov;
	struct kobj_type___378 kobj_type;
	struct dbs_data *gdbs_data;
	unsigned int (*gov_dbs_update)(struct cpufreq_policy___5 *);
	struct policy_dbs_info___2 * (*alloc)();
	void (*free)(struct policy_dbs_info___2 *);
	int (*init)(struct dbs_data *);
	void (*exit)(struct dbs_data *);
	void (*start)(struct cpufreq_policy___5 *);
};

struct cs_policy_dbs_info {
	struct policy_dbs_info___2 policy_dbs;
	unsigned int down_skip;
	unsigned int requested_freq;
};

struct cs_dbs_tuners {
	unsigned int down_threshold;
	unsigned int freq_step;
};

struct cpufreq_governor___10;

struct cpufreq_policy___10 {
	cpumask_var_t cpus;
	cpumask_var_t related_cpus;
	cpumask_var_t real_cpus;
	unsigned int shared_type;
	unsigned int cpu;
	struct clk *clk;
	struct cpufreq_cpuinfo cpuinfo;
	unsigned int min;
	unsigned int max;
	unsigned int cur;
	unsigned int restore_freq;
	unsigned int suspend_freq;
	unsigned int policy;
	unsigned int last_policy;
	struct cpufreq_governor___10 *governor;
	void *governor_data;
	char last_governor[16];
	struct work_struct update;
	struct cpufreq_user_policy user_policy;
	struct cpufreq_frequency_table *freq_table;
	enum cpufreq_table_sorting freq_table_sorted;
	struct list_head policy_list;
	struct kobject___359 kobj;
	struct completion kobj_unregister;
	struct rw_semaphore___392 rwsem;
	bool fast_switch_possible;
	bool fast_switch_enabled;
	unsigned int transition_delay_us;
	bool dvfs_possible_from_any_cpu;
	unsigned int cached_target_freq;
	int cached_resolved_idx;
	bool transition_ongoing;
	spinlock_t transition_lock;
	wait_queue_head_t transition_wait;
	struct task_struct___392 *transition_task;
	struct cpufreq_stats *stats;
	void *driver_data;
};

struct module___321;

struct cpufreq_governor___10 {
	char name[16];
	int (*init)(struct cpufreq_policy___10 *);
	void (*exit)(struct cpufreq_policy___10 *);
	int (*start)(struct cpufreq_policy___10 *);
	void (*stop)(struct cpufreq_policy___10 *);
	void (*limits)(struct cpufreq_policy___10 *);
	ssize_t (*show_setspeed)(struct cpufreq_policy___10 *, char *);
	int (*store_setspeed)(struct cpufreq_policy___10 *, unsigned int);
	bool dynamic_switching;
	struct list_head governor_list;
	struct module___321 *owner;
};

struct freq_attr___10 {
	struct attribute attr;
	ssize_t (*show)(struct cpufreq_policy___10 *, char *);
	ssize_t (*store)(struct cpufreq_policy___10 *, const char *, size_t);
};

struct module_kobject___319 {
	struct kobject___359 kobj;
	struct module___321 *mod;
	struct kobject___359 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___319 {
	struct module___321 *mod;
	struct latch_tree_node node;
};

struct module_layout___319 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___319 mtn;
};

struct module_attribute___319;

struct kernel_param___319;

struct module___321 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___319 mkobj;
	struct module_attribute___319 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___359 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___319 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___319 core_layout;
	struct module_layout___319 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct gov_attr_set___2 {
	struct kobject___359 kobj;
	struct list_head policy_list;
	struct mutex update_lock;
	int usage_count;
};

struct kernel_param_ops___319 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___319 *);
	int (*get)(char *, const struct kernel_param___319 *);
	void (*free)(void *);
};

struct kparam_array___319;

struct kernel_param___319 {
	const char *name;
	struct module___321 *mod;
	const struct kernel_param_ops___319 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___319 *arr;
	};
};

struct kparam_array___319 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___319 *ops;
	void *elem;
};

struct module_attribute___319 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___319 *, struct module_kobject___319 *, char *);
	ssize_t (*store)(struct module_attribute___319 *, struct module_kobject___319 *, const char *, size_t);
	void (*setup)(struct module___321 *, const char *);
	int (*test)(struct module___321 *);
	void (*free)(struct module___321 *);
};

struct dbs_data___2 {
	struct gov_attr_set___2 attr_set;
	void *tuners;
	unsigned int ignore_nice_load;
	unsigned int sampling_rate;
	unsigned int sampling_down_factor;
	unsigned int up_threshold;
	unsigned int io_is_busy;
};

struct policy_dbs_info___3 {
	struct cpufreq_policy___10 *policy;
	struct mutex update_mutex;
	u64 last_sample_time;
	s64 sample_delay_ns;
	atomic_t work_count;
	struct irq_work irq_work;
	struct work_struct work;
	struct dbs_data___2 *dbs_data;
	struct list_head list;
	unsigned int rate_mult;
	unsigned int idle_periods;
	bool is_shared;
	bool work_in_progress;
};

struct cpu_dbs_info {
	u64 prev_cpu_idle;
	u64 prev_update_time;
	u64 prev_cpu_nice;
	unsigned int prev_load;
	struct update_util_data update_util;
	struct policy_dbs_info___3 *policy_dbs;
};

struct dbs_governor___3 {
	struct cpufreq_governor___10 gov;
	struct kobj_type___358 kobj_type;
	struct dbs_data___2 *gdbs_data;
	unsigned int (*gov_dbs_update)(struct cpufreq_policy___10 *);
	struct policy_dbs_info___3 * (*alloc)();
	void (*free)(struct policy_dbs_info___3 *);
	int (*init)(struct dbs_data___2 *);
	void (*exit)(struct dbs_data___2 *);
	void (*start)(struct cpufreq_policy___10 *);
};

struct cpufreq_governor___11;

struct cpufreq_policy___11 {
	cpumask_var_t cpus;
	cpumask_var_t related_cpus;
	cpumask_var_t real_cpus;
	unsigned int shared_type;
	unsigned int cpu;
	struct clk *clk;
	struct cpufreq_cpuinfo cpuinfo;
	unsigned int min;
	unsigned int max;
	unsigned int cur;
	unsigned int restore_freq;
	unsigned int suspend_freq;
	unsigned int policy;
	unsigned int last_policy;
	struct cpufreq_governor___11 *governor;
	void *governor_data;
	char last_governor[16];
	struct work_struct update;
	struct cpufreq_user_policy user_policy;
	struct cpufreq_frequency_table *freq_table;
	enum cpufreq_table_sorting freq_table_sorted;
	struct list_head policy_list;
	struct kobject___365 kobj;
	struct completion kobj_unregister;
	struct rw_semaphore___379 rwsem;
	bool fast_switch_possible;
	bool fast_switch_enabled;
	unsigned int transition_delay_us;
	bool dvfs_possible_from_any_cpu;
	unsigned int cached_target_freq;
	int cached_resolved_idx;
	bool transition_ongoing;
	spinlock_t transition_lock;
	wait_queue_head_t transition_wait;
	struct task_struct___379 *transition_task;
	struct cpufreq_stats *stats;
	void *driver_data;
};

struct cpufreq_governor___11 {
	char name[16];
	int (*init)(struct cpufreq_policy___11 *);
	void (*exit)(struct cpufreq_policy___11 *);
	int (*start)(struct cpufreq_policy___11 *);
	void (*stop)(struct cpufreq_policy___11 *);
	void (*limits)(struct cpufreq_policy___11 *);
	ssize_t (*show_setspeed)(struct cpufreq_policy___11 *, char *);
	int (*store_setspeed)(struct cpufreq_policy___11 *, unsigned int);
	bool dynamic_switching;
	struct list_head governor_list;
	struct module___309 *owner;
};

struct freq_attr___11 {
	struct attribute attr;
	ssize_t (*show)(struct cpufreq_policy___11 *, char *);
	ssize_t (*store)(struct cpufreq_policy___11 *, const char *, size_t);
};

struct cpufreq_driver___2 {
	char name[16];
	u8 flags;
	void *driver_data;
	int (*init)(struct cpufreq_policy___11 *);
	int (*verify)(struct cpufreq_policy___11 *);
	int (*setpolicy)(struct cpufreq_policy___11 *);
	int (*target)(struct cpufreq_policy___11 *, unsigned int, unsigned int);
	int (*target_index)(struct cpufreq_policy___11 *, unsigned int);
	unsigned int (*fast_switch)(struct cpufreq_policy___11 *, unsigned int);
	unsigned int (*resolve_freq)(struct cpufreq_policy___11 *, unsigned int);
	unsigned int (*get_intermediate)(struct cpufreq_policy___11 *, unsigned int);
	int (*target_intermediate)(struct cpufreq_policy___11 *, unsigned int);
	unsigned int (*get)(unsigned int);
	int (*bios_limit)(int, unsigned int *);
	int (*exit)(struct cpufreq_policy___11 *);
	void (*stop_cpu)(struct cpufreq_policy___11 *);
	int (*suspend)(struct cpufreq_policy___11 *);
	int (*resume)(struct cpufreq_policy___11 *);
	void (*ready)(struct cpufreq_policy___11 *);
	struct freq_attr___11 **attr;
	bool boost_enabled;
	int (*set_boost)(int);
};

struct cppc_cpudata___2 {
	int cpu;
	struct cppc_perf_caps perf_caps;
	struct cppc_perf_ctrls perf_ctrls;
	struct cppc_perf_fb_ctrs perf_fb_ctrs;
	struct cpufreq_policy___11 *cur_policy;
	unsigned int shared_type;
	cpumask_var_t shared_cpu_map;
};

struct module___322;

struct file___392;

struct kiocb___392;

struct iov_iter___166;

struct poll_table_struct___239;

struct vm_area_struct___393;

struct inode___392;

struct file_lock___392;

struct page___393;

struct seq_file___334;

struct file_operations___392 {
	struct module___322 *owner;
	loff_t (*llseek)(struct file___392 *, loff_t, int);
	ssize_t (*read)(struct file___392 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___392 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___392 *, struct iov_iter___166 *);
	ssize_t (*write_iter)(struct kiocb___392 *, struct iov_iter___166 *);
	int (*iopoll)(struct kiocb___392 *, bool);
	int (*iterate)(struct file___392 *, struct dir_context *);
	int (*iterate_shared)(struct file___392 *, struct dir_context *);
	__poll_t (*poll)(struct file___392 *, struct poll_table_struct___239 *);
	long int (*unlocked_ioctl)(struct file___392 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___392 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___392 *, struct vm_area_struct___393 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___392 *, struct file___392 *);
	int (*flush)(struct file___392 *, fl_owner_t);
	int (*release)(struct inode___392 *, struct file___392 *);
	int (*fsync)(struct file___392 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___392 *, int);
	int (*lock)(struct file___392 *, int, struct file_lock___392 *);
	ssize_t (*sendpage)(struct file___392 *, struct page___393 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___392 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___392 *, int, struct file_lock___392 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___392 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___392 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___392 *, long int, struct file_lock___392 **, void **);
	long int (*fallocate)(struct file___392 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___334 *, struct file___392 *);
	ssize_t (*copy_file_range)(struct file___392 *, loff_t, struct file___392 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___392 *, loff_t, struct file___392 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___392 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___393 {
	u64 seqnum;
	struct vm_area_struct___393 *vmas[4];
};

struct page_frag___393 {
	struct page___393 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___150;

struct debug_info___150 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___150 *hbp_break[16];
	struct perf_event___150 *hbp_watch[16];
};

struct thread_struct___150 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___150 debug;
	long: 64;
};

struct mm_struct___393;

struct mem_cgroup___137;

struct pid___226;

struct cred___362;

struct nsproxy___290;

struct signal_struct___269;

struct bio_list___194;

struct backing_dev_info___194;

struct css_set___245;

struct perf_event_context___150;

struct vm_struct___297;

struct task_struct___394 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___394 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___393 *mm;
	struct mm_struct___393 *active_mm;
	struct vmacache___393 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___394 *real_parent;
	struct task_struct___394 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___394 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___137 *active_memcg;
	long int rh_reserved2;
	struct pid___226 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___226 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___226 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___362 *ptracer_cred;
	const struct cred___362 *real_cred;
	const struct cred___362 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___290 *nsproxy;
	struct signal_struct___269 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___394 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___194 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___194 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___245 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___150 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___393 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___137 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___394 *oom_reaper_list;
	struct vm_struct___297 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___150 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___150 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___394 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___150)(struct perf_event___150 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___150;

struct fasync_struct___392;

struct pid_namespace___226;

struct trace_event_call___143;

struct perf_cgroup___150;

struct perf_event___150 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___150 *group_leader;
	struct pmu___150 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___150 hw;
	struct perf_event_context___150 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___150 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___394 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___392 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___150 *);
	struct callback_head callback_head;
	struct pid_namespace___226 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___150 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___150 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___143 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___150 *cgrp;
	struct list_head sb_list;
};

struct secondary_data___394 {
	void *stack;
	struct task_struct___394 *task;
	long int status;
};

struct clock_event_device___19;

struct arch_timer_erratum_workaround___19 {
	enum arch_timer_erratum_match_type match_type;
	const void *id;
	const char *desc;
	u32 (*read_cntp_tval_el0)();
	u32 (*read_cntv_tval_el0)();
	u64 (*read_cntpct_el0)();
	u64 (*read_cntvct_el0)();
	int (*set_next_event_phys)(long unsigned int, struct clock_event_device___19 *);
	int (*set_next_event_virt)(long unsigned int, struct clock_event_device___19 *);
};

struct clock_event_device___19 {
	void (*event_handler)(struct clock_event_device___19 *);
	int (*set_next_event)(long unsigned int, struct clock_event_device___19 *);
	int (*set_next_ktime)(ktime_t, struct clock_event_device___19 *);
	ktime_t next_event;
	u64 max_delta_ns;
	u64 min_delta_ns;
	u32 mult;
	u32 shift;
	enum clock_event_state state_use_accessors;
	unsigned int features;
	long unsigned int retries;
	int (*set_state_periodic)(struct clock_event_device___19 *);
	int (*set_state_oneshot)(struct clock_event_device___19 *);
	int (*set_state_oneshot_stopped)(struct clock_event_device___19 *);
	int (*set_state_shutdown)(struct clock_event_device___19 *);
	int (*tick_resume)(struct clock_event_device___19 *);
	void (*broadcast)(const struct cpumask *);
	void (*suspend)(struct clock_event_device___19 *);
	void (*resume)(struct clock_event_device___19 *);
	long unsigned int min_delta_ticks;
	long unsigned int max_delta_ticks;
	const char *name;
	int rating;
	int irq;
	int bound_on;
	const struct cpumask *cpumask;
	struct list_head list;
	struct module___322 *owner;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___393 *pgtable_t___393;

struct address_space___392;

struct dev_pagemap___381;

struct page___393 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___392 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___393 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___393 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___393 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___381 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___137 *mem_cgroup;
};

struct pglist_data___393;

struct lruvec___393 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___393 *pgdat;
};

struct zone___393 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___393 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___393 {
	struct zone___393 *zone;
	int zone_idx;
};

struct zonelist___393 {
	struct zoneref___393 _zonerefs[25];
};

struct pglist_data___393 {
	struct zone___393 node_zones[3];
	struct zonelist___393 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___394 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___394 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___393 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___394 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___394 *owner;
};

struct blocking_notifier_head___393 {
	struct rw_semaphore___394 rwsem;
	struct notifier_block *head;
};

struct key___362;

struct ucounts___261;

struct user_namespace___261 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___261 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___9 ns;
	long unsigned int flags;
	struct key___362 *persistent_keyring_register;
	struct rw_semaphore___394 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___261 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_root___386;

struct kernfs_elem_dir___386 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___386 *root;
};

struct kernfs_node___387;

struct kernfs_syscall_ops___386;

struct kernfs_root___386 {
	struct kernfs_node___387 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___386 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___386 {
	struct kernfs_node___387 *target_kn;
};

struct kernfs_ops___386;

struct kernfs_elem_attr___386 {
	const struct kernfs_ops___386 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___387 *notify_next;
};

struct kernfs_node___387 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___387 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___386 dir;
		struct kernfs_elem_symlink___386 symlink;
		struct kernfs_elem_attr___386 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___386;

struct kernfs_ops___386 {
	int (*open)(struct kernfs_open_file___386 *);
	void (*release)(struct kernfs_open_file___386 *);
	int (*seq_show)(struct seq_file___334 *, void *);
	void * (*seq_start)(struct seq_file___334 *, loff_t *);
	void * (*seq_next)(struct seq_file___334 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___334 *, void *);
	ssize_t (*read)(struct kernfs_open_file___386 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___386 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___386 *, struct vm_area_struct___393 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___386 *, struct poll_table_struct___239 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___386 {
	int (*remount_fs)(struct kernfs_root___386 *, int *, char *);
	int (*show_options)(struct seq_file___334 *, struct kernfs_root___386 *);
	int (*mkdir)(struct kernfs_node___387 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___387 *);
	int (*rename)(struct kernfs_node___387 *, struct kernfs_node___387 *, const char *);
	int (*show_path)(struct seq_file___334 *, struct kernfs_node___387 *, struct kernfs_root___386 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___334;

struct seq_file___334 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___334 *op;
	int poll_event;
	const struct file___392 *file;
	void *private;
};

struct vm_operations_struct___381;

struct kernfs_open_file___386 {
	struct kernfs_node___387 *kn;
	struct file___392 *file;
	struct seq_file___334 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___381 *vm_ops;
};

struct dentry___392;

struct path___393 {
	struct vfsmount *mnt;
	struct dentry___392 *dentry;
};

struct fown_struct___226 {
	rwlock_t lock;
	struct pid___226 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___392 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___393 f_path;
	struct inode___392 *f_inode;
	const struct file_operations___392 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___226 f_owner;
	const struct cred___362 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___392 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___381;

struct vm_operations_struct___381 {
	void (*open)(struct vm_area_struct___393 *);
	void (*close)(struct vm_area_struct___393 *);
	int (*split)(struct vm_area_struct___393 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___393 *);
	vm_fault_t (*fault)(struct vm_fault___381 *);
	vm_fault_t (*huge_fault)(struct vm_fault___381 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___381 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___393 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___381 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___381 *);
	int (*access)(struct vm_area_struct___393 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___393 *);
	int (*set_policy)(struct vm_area_struct___393 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___393 *, long unsigned int);
	struct page___393 * (*find_special_page)(struct vm_area_struct___393 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___247)(struct file___392 *, wait_queue_head_t *, struct poll_table_struct___239 *);

struct poll_table_struct___239 {
	poll_queue_proc___247 _qproc;
	__poll_t _key;
};

struct vm_area_struct___393 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___393 *vm_next;
	struct vm_area_struct___393 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___393 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___381 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___392 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___380;

struct bin_attribute___356;

struct attribute_group___357 {
	const char *name;
	umode_t (*is_visible)(struct kobject___380 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___380 *, struct bin_attribute___356 *, int);
	struct attribute **attrs;
	struct bin_attribute___356 **bin_attrs;
};

struct kset___379;

struct kobj_type___379;

struct kobject___380 {
	const char *name;
	struct list_head entry;
	struct kobject___380 *parent;
	struct kset___379 *kset;
	struct kobj_type___379 *ktype;
	struct kernfs_node___387 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___356 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___392 *, struct kobject___380 *, struct bin_attribute___356 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___392 *, struct kobject___380 *, struct bin_attribute___356 *, char *, loff_t, size_t);
	int (*mmap)(struct file___392 *, struct kobject___380 *, struct bin_attribute___356 *, struct vm_area_struct___393 *);
};

struct sysfs_ops___379 {
	ssize_t (*show)(struct kobject___380 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___380 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___379;

struct kset___379 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___380 kobj;
	const struct kset_uevent_ops___379 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___379 {
	void (*release)(struct kobject___380 *);
	const struct sysfs_ops___379 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___29 * (*child_ns_type)(struct kobject___380 *);
	const void * (*namespace)(struct kobject___380 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___379 {
	int (* const filter)(struct kset___379 *, struct kobject___380 *);
	const char * (* const name)(struct kset___379 *, struct kobject___380 *);
	int (* const uevent)(struct kset___379 *, struct kobject___380 *, struct kobj_uevent_env *);
};

struct kobj_attribute___371 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___380 *, struct kobj_attribute___371 *, char *);
	ssize_t (*store)(struct kobject___380 *, struct kobj_attribute___371 *, const char *, size_t);
};

struct fwnode_operations___281;

struct fwnode_handle___281 {
	struct fwnode_handle___281 *secondary;
	const struct fwnode_operations___281 *ops;
};

struct device___360;

struct fwnode_reference_args___281;

struct fwnode_endpoint___281;

struct fwnode_operations___281 {
	struct fwnode_handle___281 * (*get)(struct fwnode_handle___281 *);
	void (*put)(struct fwnode_handle___281 *);
	bool (*device_is_available)(const struct fwnode_handle___281 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___281 *, const struct device___360 *);
	bool (*property_present)(const struct fwnode_handle___281 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___281 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___281 *, const char *, const char **, size_t);
	struct fwnode_handle___281 * (*get_parent)(const struct fwnode_handle___281 *);
	struct fwnode_handle___281 * (*get_next_child_node)(const struct fwnode_handle___281 *, struct fwnode_handle___281 *);
	struct fwnode_handle___281 * (*get_named_child_node)(const struct fwnode_handle___281 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___281 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___281 *);
	struct fwnode_handle___281 * (*graph_get_next_endpoint)(const struct fwnode_handle___281 *, struct fwnode_handle___281 *);
	struct fwnode_handle___281 * (*graph_get_remote_endpoint)(const struct fwnode_handle___281 *);
	struct fwnode_handle___281 * (*graph_get_port_parent)(struct fwnode_handle___281 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___281 *, struct fwnode_endpoint___281 *);
};

struct fwnode_endpoint___281 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___281 *local_fwnode;
};

struct fwnode_reference_args___281 {
	struct fwnode_handle___281 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct dev_pm_qos___24;

struct dev_pm_info___360 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___360 *, s32);
	struct dev_pm_qos___24 *qos;
};

struct device_type___360;

struct bus_type___360;

struct device_driver___360;

struct dev_pm_domain___360;

struct device_node___93;

struct class___360;

struct device___360 {
	struct device___360 *parent;
	struct device_private *p;
	struct kobject___380 kobj;
	const char *init_name;
	const struct device_type___360 *type;
	struct mutex mutex;
	struct bus_type___360 *bus;
	struct device_driver___360 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___360 power;
	struct dev_pm_domain___360 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___93 *of_node;
	struct fwnode_handle___281 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___360 *class;
	const struct attribute_group___357 **groups;
	void (*release)(struct device___360 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct property___89 {
	char *name;
	int length;
	void *value;
	struct property___89 *next;
	long unsigned int _flags;
	struct bin_attribute___356 attr;
};

struct device_node___93 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___281 fwnode;
	struct property___89 *properties;
	struct property___89 *deadprops;
	struct device_node___93 *parent;
	struct device_node___93 *child;
	struct device_node___93 *sibling;
	struct kobject___380 kobj;
	long unsigned int _flags;
	void *data;
};

struct core_state___393;

struct mm_struct___393 {
	struct {
		struct vm_area_struct___393 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___392 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___394 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___393 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___394 *owner;
		struct user_namespace___261 *user_ns;
		struct file___392 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___393 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___392;

struct address_space___392 {
	struct inode___392 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___394 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___392 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___381)(struct vm_area_struct___393 *, long unsigned int, const struct page___393 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___381)(struct page___393 *, void *);

struct dev_pagemap___381 {
	dev_page_fault_t___381 page_fault;
	dev_page_free_t___381 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___360 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct cgroup___245;

struct cgroup_subsys___245;

struct cgroup_subsys_state___245 {
	struct cgroup___245 *cgroup;
	struct cgroup_subsys___245 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___245 *parent;
};

struct cgroup_file___245 {
	struct kernfs_node___387 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___137;

struct mem_cgroup___137 {
	struct cgroup_subsys_state___245 css;
	struct mem_cgroup_id___2 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___245 events_file;
	struct cgroup_file___245 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___394 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___137 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct core_thread___393 {
	struct task_struct___394 *task;
	struct core_thread___393 *next;
};

struct core_state___393 {
	atomic_t nr_threads;
	struct core_thread___393 dumper;
	struct completion startup;
};

struct vm_fault___381 {
	struct vm_area_struct___393 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___393 *cow_page;
	struct mem_cgroup___137 *memcg;
	struct page___393 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___393 prealloc_pte;
};

struct upid___226 {
	int nr;
	struct pid_namespace___226 *ns;
};

struct pid_namespace___226 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___394 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___226 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___392 *proc_self;
	struct dentry___392 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___261 *user_ns;
	struct ucounts___261 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___9 ns;
};

struct pid___226 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___226 numbers[1];
};

struct user_struct___362 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___362 *uid_keyring;
	struct key___362 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___362 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___362 *session_keyring;
	struct key___362 *process_keyring;
	struct key___362 *thread_keyring;
	struct key___362 *request_key_auth;
	void *security;
	struct user_struct___362 *user;
	struct user_namespace___261 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___245;

struct nsproxy___290 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___226 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___245 *cgroup_ns;
};

struct signal_struct___269 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___394 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___394 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___226 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___226 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___393 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___226 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___194;

struct bio_list___194 {
	struct bio___194 *head;
	struct bio___194 *tail;
};

struct bdi_writeback_congested___194;

struct bdi_writeback___194 {
	struct backing_dev_info___194 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___194 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___245 *memcg_css;
	struct cgroup_subsys_state___245 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___194 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___194 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___360 *dev;
	struct device___360 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___392 *debug_dir;
	struct dentry___392 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___245 {
	struct cgroup_subsys_state___245 *subsys[13];
	refcount_t refcount;
	struct css_set___245 *dom_cset;
	struct cgroup___245 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___245 *mg_src_cgrp;
	struct cgroup___245 *mg_dst_cgrp;
	struct css_set___245 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___150 {
	struct pmu___150 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___394 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___150 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___297 {
	struct vm_struct___297 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___393 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___281 {
	struct task_struct___394 task;
	long unsigned int stack[8192];
};

struct module_kobject___320 {
	struct kobject___380 kobj;
	struct module___322 *mod;
	struct kobject___380 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___320 {
	struct module___322 *mod;
	struct latch_tree_node node;
};

struct module_layout___320 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___320 mtn;
};

struct module_attribute___320;

struct kernel_param___320;

struct module___322 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___320 mkobj;
	struct module_attribute___320 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___380 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___320 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___320 core_layout;
	struct module_layout___320 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___143 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___360 {
	int (*prepare)(struct device___360 *);
	void (*complete)(struct device___360 *);
	int (*suspend)(struct device___360 *);
	int (*resume)(struct device___360 *);
	int (*freeze)(struct device___360 *);
	int (*thaw)(struct device___360 *);
	int (*poweroff)(struct device___360 *);
	int (*restore)(struct device___360 *);
	int (*suspend_late)(struct device___360 *);
	int (*resume_early)(struct device___360 *);
	int (*freeze_late)(struct device___360 *);
	int (*thaw_early)(struct device___360 *);
	int (*poweroff_late)(struct device___360 *);
	int (*restore_early)(struct device___360 *);
	int (*suspend_noirq)(struct device___360 *);
	int (*resume_noirq)(struct device___360 *);
	int (*freeze_noirq)(struct device___360 *);
	int (*thaw_noirq)(struct device___360 *);
	int (*poweroff_noirq)(struct device___360 *);
	int (*restore_noirq)(struct device___360 *);
	int (*runtime_suspend)(struct device___360 *);
	int (*runtime_resume)(struct device___360 *);
	int (*runtime_idle)(struct device___360 *);
};

struct pm_qos_constraints___23 {
	struct plist_head list;
	s32 target_value;
	s32 default_value;
	s32 no_constraint_value;
	enum pm_qos_type type;
	struct blocking_notifier_head___393 *notifiers;
};

struct dev_pm_qos_request___25;

struct dev_pm_qos___24 {
	struct pm_qos_constraints___23 resume_latency;
	struct pm_qos_constraints___23 latency_tolerance;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___25 *resume_latency_req;
	struct dev_pm_qos_request___25 *latency_tolerance_req;
	struct dev_pm_qos_request___25 *flags_req;
};

struct dev_pm_domain___360 {
	struct dev_pm_ops___360 ops;
	void (*detach)(struct device___360 *, bool);
	int (*activate)(struct device___360 *);
	void (*sync)(struct device___360 *);
	void (*dismiss)(struct device___360 *);
};

struct bus_type___360 {
	const char *name;
	const char *dev_name;
	struct device___360 *dev_root;
	const struct attribute_group___357 **bus_groups;
	const struct attribute_group___357 **dev_groups;
	const struct attribute_group___357 **drv_groups;
	int (*match)(struct device___360 *, struct device_driver___360 *);
	int (*uevent)(struct device___360 *, struct kobj_uevent_env *);
	int (*probe)(struct device___360 *);
	int (*remove)(struct device___360 *);
	void (*shutdown)(struct device___360 *);
	int (*online)(struct device___360 *);
	int (*offline)(struct device___360 *);
	int (*suspend)(struct device___360 *, pm_message_t);
	int (*resume)(struct device___360 *);
	int (*num_vf)(struct device___360 *);
	int (*dma_configure)(struct device___360 *);
	const struct dev_pm_ops___360 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___360 {
	const char *name;
	struct bus_type___360 *bus;
	struct module___322 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___360 *);
	int (*remove)(struct device___360 *);
	void (*shutdown)(struct device___360 *);
	int (*suspend)(struct device___360 *, pm_message_t);
	int (*resume)(struct device___360 *);
	const struct attribute_group___357 **groups;
	const struct dev_pm_ops___360 *pm;
	void (*coredump)(struct device___360 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___360 {
	const char *name;
	const struct attribute_group___357 **groups;
	int (*uevent)(struct device___360 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___360 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___360 *);
	const struct dev_pm_ops___360 *pm;
};

struct class___360 {
	const char *name;
	struct module___322 *owner;
	const struct attribute_group___357 **class_groups;
	const struct attribute_group___357 **dev_groups;
	struct kobject___380 *dev_kobj;
	int (*dev_uevent)(struct device___360 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___360 *, umode_t *);
	void (*class_release)(struct class___360 *);
	void (*dev_release)(struct device___360 *);
	int (*shutdown_pre)(struct device___360 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___360 *);
	const struct dev_pm_ops___360 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dev_pm_qos_request___25 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
	} data;
	struct device___360 *dev;
};

struct node___216 {
	struct device___360 dev;
};

struct cpuidle_driver___7;

struct cpuidle_state___6 {
	char name[16];
	char desc[32];
	unsigned int flags;
	unsigned int exit_latency;
	int power_usage;
	unsigned int target_residency;
	bool disabled;
	int (*enter)(struct cpuidle_device *, struct cpuidle_driver___7 *, int);
	int (*enter_dead)(struct cpuidle_device *, int);
	void (*enter_s2idle)(struct cpuidle_device *, struct cpuidle_driver___7 *, int);
};

struct cpuidle_driver___7 {
	const char *name;
	struct module___322 *owner;
	int refcnt;
	unsigned int bctimer: 1;
	struct cpuidle_state___6 states[10];
	int state_count;
	int safe_state_index;
	struct cpumask *cpumask;
};

struct cpuidle_governor {
	char name[16];
	struct list_head governor_list;
	unsigned int rating;
	int (*enable)(struct cpuidle_driver___7 *, struct cpuidle_device *);
	void (*disable)(struct cpuidle_driver___7 *, struct cpuidle_device *);
	int (*select)(struct cpuidle_driver___7 *, struct cpuidle_device *, bool *);
	void (*reflect)(struct cpuidle_device *, int);
};

struct kernel_param_ops___320 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___320 *);
	int (*get)(char *, const struct kernel_param___320 *);
	void (*free)(void *);
};

struct kparam_array___320;

struct kernel_param___320 {
	const char *name;
	struct module___322 *mod;
	const struct kernel_param_ops___320 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___320 *arr;
	};
};

struct kparam_array___320 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___320 *ops;
	void *elem;
};

struct module_attribute___320 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___320 *, struct module_kobject___320 *, char *);
	ssize_t (*store)(struct module_attribute___320 *, struct module_kobject___320 *, const char *, size_t);
	void (*setup)(struct module___322 *, const char *);
	int (*test)(struct module___322 *);
	void (*free)(struct module___322 *);
};

struct trace_event_class___143;

struct trace_event_call___143 {
	struct list_head list;
	struct trace_event_class___143 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___13 event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___39 *prog_array;
	int (*perf_perm)(struct trace_event_call___143 *, struct perf_event___150 *);
};

struct dentry_operations___392;

struct super_block___392;

struct dentry___392 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___392 *d_parent;
	struct qstr d_name;
	struct inode___392 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___392 *d_op;
	struct super_block___392 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___392;

struct block_device___392;

struct inode___392 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___392 *i_op;
	struct super_block___392 *i_sb;
	struct address_space___392 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___394 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___194 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___392 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___392 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___392 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___392 {
	int (*d_revalidate)(struct dentry___392 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___392 *, unsigned int);
	int (*d_hash)(const struct dentry___392 *, struct qstr *);
	int (*d_compare)(const struct dentry___392 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___392 *);
	int (*d_init)(struct dentry___392 *);
	void (*d_release)(struct dentry___392 *);
	void (*d_prune)(struct dentry___392 *);
	void (*d_iput)(struct dentry___392 *, struct inode___392 *);
	char * (*d_dname)(struct dentry___392 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___393 *);
	int (*d_manage)(const struct path___393 *, bool);
	struct dentry___392 * (*d_real)(struct dentry___392 *, const struct inode___392 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___392;

struct mem_dqinfo___392 {
	struct quota_format_type___392 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___392;

struct quota_info___392 {
	unsigned int flags;
	struct rw_semaphore___394 dqio_sem;
	struct inode___392 *files[3];
	struct mem_dqinfo___392 info[3];
	const struct quota_format_ops___392 *ops[3];
};

struct rcuwait___392 {
	struct task_struct___394 *task;
};

struct percpu_rw_semaphore___392 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___394 rw_sem;
	struct rcuwait___392 writer;
	int readers_block;
};

struct sb_writers___392 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___392 rw_sem[3];
};

struct shrink_control___137;

struct shrinker___137 {
	long unsigned int (*count_objects)(struct shrinker___137 *, struct shrink_control___137 *);
	long unsigned int (*scan_objects)(struct shrinker___137 *, struct shrink_control___137 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___392;

struct super_operations___392;

struct dquot_operations___392;

struct quotactl_ops___392;

struct super_block___392 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___392 *s_type;
	const struct super_operations___392 *s_op;
	const struct dquot_operations___392 *dq_op;
	const struct quotactl_ops___392 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___392 *s_root;
	struct rw_semaphore___394 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___392 *s_bdev;
	struct backing_dev_info___194 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___392 s_dquot;
	struct sb_writers___392 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___392 *s_d_op;
	int cleancache_poolid;
	struct shrinker___137 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___261 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___137 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___137 *memcg;
};

struct kiocb___392 {
	struct file___392 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___392 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___392 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___392 *ia_file;
};

struct dquot___392 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___392 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___392 {
	int qf_fmt_id;
	const struct quota_format_ops___392 *qf_ops;
	struct module___322 *qf_owner;
	struct quota_format_type___392 *qf_next;
};

struct quota_format_ops___392 {
	int (*check_quota_file)(struct super_block___392 *, int);
	int (*read_file_info)(struct super_block___392 *, int);
	int (*write_file_info)(struct super_block___392 *, int);
	int (*free_file_info)(struct super_block___392 *, int);
	int (*read_dqblk)(struct dquot___392 *);
	int (*commit_dqblk)(struct dquot___392 *);
	int (*release_dqblk)(struct dquot___392 *);
	int (*get_next_id)(struct super_block___392 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___392 {
	int (*write_dquot)(struct dquot___392 *);
	struct dquot___392 * (*alloc_dquot)(struct super_block___392 *, int);
	void (*destroy_dquot)(struct dquot___392 *);
	int (*acquire_dquot)(struct dquot___392 *);
	int (*release_dquot)(struct dquot___392 *);
	int (*mark_dirty)(struct dquot___392 *);
	int (*write_info)(struct super_block___392 *, int);
	qsize_t * (*get_reserved_space)(struct inode___392 *);
	int (*get_projid)(struct inode___392 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___392 *, qsize_t *);
	int (*get_next_id)(struct super_block___392 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___392 {
	int (*quota_on)(struct super_block___392 *, int, int, const struct path___393 *);
	int (*quota_off)(struct super_block___392 *, int);
	int (*quota_enable)(struct super_block___392 *, unsigned int);
	int (*quota_disable)(struct super_block___392 *, unsigned int);
	int (*quota_sync)(struct super_block___392 *, int);
	int (*set_info)(struct super_block___392 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___392 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___392 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___392 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___392 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___392 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___157;

struct swap_info_struct___92;

struct address_space_operations___392 {
	int (*writepage)(struct page___393 *, struct writeback_control___157 *);
	int (*readpage)(struct file___392 *, struct page___393 *);
	int (*writepages)(struct address_space___392 *, struct writeback_control___157 *);
	int (*set_page_dirty)(struct page___393 *);
	int (*readpages)(struct file___392 *, struct address_space___392 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___392 *, struct address_space___392 *, loff_t, unsigned int, unsigned int, struct page___393 **, void **);
	int (*write_end)(struct file___392 *, struct address_space___392 *, loff_t, unsigned int, unsigned int, struct page___393 *, void *);
	sector_t (*bmap)(struct address_space___392 *, sector_t);
	void (*invalidatepage)(struct page___393 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___393 *, gfp_t);
	void (*freepage)(struct page___393 *);
	ssize_t (*direct_IO)(struct kiocb___392 *, struct iov_iter___166 *);
	int (*migratepage)(struct address_space___392 *, struct page___393 *, struct page___393 *, enum migrate_mode);
	bool (*isolate_page)(struct page___393 *, isolate_mode_t);
	void (*putback_page)(struct page___393 *);
	int (*launder_page)(struct page___393 *);
	int (*is_partially_uptodate)(struct page___393 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___393 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___392 *, struct page___393 *);
	int (*swap_activate)(struct swap_info_struct___92 *, struct file___392 *, sector_t *);
	void (*swap_deactivate)(struct file___392 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___157 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___194 *wb;
	struct inode___392 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___196;

struct iov_iter___166 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___196 *bvec;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct swap_info_struct___92 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___392 *bdev;
	struct file___392 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___392 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___392 *bd_inode;
	struct super_block___392 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___392 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___194 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___392 {
	struct dentry___392 * (*lookup)(struct inode___392 *, struct dentry___392 *, unsigned int);
	const char * (*get_link)(struct dentry___392 *, struct inode___392 *, struct delayed_call *);
	int (*permission)(struct inode___392 *, int);
	struct posix_acl * (*get_acl)(struct inode___392 *, int);
	int (*readlink)(struct dentry___392 *, char *, int);
	int (*create)(struct inode___392 *, struct dentry___392 *, umode_t, bool);
	int (*link)(struct dentry___392 *, struct inode___392 *, struct dentry___392 *);
	int (*unlink)(struct inode___392 *, struct dentry___392 *);
	int (*symlink)(struct inode___392 *, struct dentry___392 *, const char *);
	int (*mkdir)(struct inode___392 *, struct dentry___392 *, umode_t);
	int (*rmdir)(struct inode___392 *, struct dentry___392 *);
	int (*mknod)(struct inode___392 *, struct dentry___392 *, umode_t, dev_t);
	int (*rename)(struct inode___392 *, struct dentry___392 *, struct inode___392 *, struct dentry___392 *, unsigned int);
	int (*setattr)(struct dentry___392 *, struct iattr___392 *);
	int (*getattr)(const struct path___393 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___392 *, char *, size_t);
	int (*fiemap)(struct inode___392 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___392 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___392 *, struct dentry___392 *, struct file___392 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___392 *, struct dentry___392 *, umode_t);
	int (*set_acl)(struct inode___392 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___392 {
	void (*fl_copy_lock)(struct file_lock___392 *, struct file_lock___392 *);
	void (*fl_release_private)(struct file_lock___392 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___392;

struct file_lock___392 {
	struct file_lock___392 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___392 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___392 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___392 *fl_ops;
	const struct lock_manager_operations___392 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___392 {
	int (*lm_compare_owner)(struct file_lock___392 *, struct file_lock___392 *);
	long unsigned int (*lm_owner_key)(struct file_lock___392 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___392 *);
	int (*lm_grant)(struct file_lock___392 *, int);
	bool (*lm_break)(struct file_lock___392 *);
	int (*lm_change)(struct file_lock___392 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___392 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___392 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___392 *fa_next;
	struct file___392 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___392 {
	const char *name;
	int fs_flags;
	struct dentry___392 * (*mount)(struct file_system_type___392 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___392 *);
	struct module___322 *owner;
	struct file_system_type___392 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___392 {
	struct inode___392 * (*alloc_inode)(struct super_block___392 *);
	void (*destroy_inode)(struct inode___392 *);
	void (*dirty_inode)(struct inode___392 *, int);
	int (*write_inode)(struct inode___392 *, struct writeback_control___157 *);
	int (*drop_inode)(struct inode___392 *);
	void (*evict_inode)(struct inode___392 *);
	void (*put_super)(struct super_block___392 *);
	int (*sync_fs)(struct super_block___392 *, int);
	int (*freeze_super)(struct super_block___392 *);
	int (*freeze_fs)(struct super_block___392 *);
	int (*thaw_super)(struct super_block___392 *);
	int (*unfreeze_fs)(struct super_block___392 *);
	int (*statfs)(struct dentry___392 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___392 *, int *, char *);
	void (*umount_begin)(struct super_block___392 *);
	int (*show_options)(struct seq_file___334 *, struct dentry___392 *);
	int (*show_devname)(struct seq_file___334 *, struct dentry___392 *);
	int (*show_path)(struct seq_file___334 *, struct dentry___392 *);
	int (*show_stats)(struct seq_file___334 *, struct dentry___392 *);
	ssize_t (*quota_read)(struct super_block___392 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___392 *, int, const char *, size_t, loff_t);
	struct dquot___392 ** (*get_dquots)(struct inode___392 *);
	int (*bdev_try_to_free_page)(struct super_block___392 *, struct page___393 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___392 *, struct shrink_control___137 *);
	long int (*free_cached_objects)(struct super_block___392 *, struct shrink_control___137 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___194(struct bio___194 *);

struct bio_vec___196 {
	struct page___393 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___194;

struct bio_set___194;

struct bio___194 {
	struct bio___194 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___194 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___194 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___196 *bi_io_vec;
	struct bio_set___194 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___196 bi_inline_vecs[0];
};

typedef int (*key_restrict_link_func_t___363)(struct key___362 *, const struct key_type *, const union key_payload *, struct key___362 *);

struct key_restriction___362;

struct key___362 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___394 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___362 *restrict_link;
};

struct key_restriction___362 {
	key_restrict_link_func_t___363 check;
	struct key___362 *key;
	struct key_type *keytype;
};

struct seq_operations___334 {
	void * (*start)(struct seq_file___334 *, loff_t *);
	void (*stop)(struct seq_file___334 *, void *);
	void * (*next)(struct seq_file___334 *, void *, loff_t *);
	int (*show)(struct seq_file___334 *, void *);
};

struct cgroup_namespace___245 {
	refcount_t count;
	struct ns_common___9 ns;
	struct user_namespace___261 *user_ns;
	struct ucounts___261 *ucounts;
	struct css_set___245 *root_cset;
};

struct ucounts___261 {
	struct hlist_node node;
	struct user_namespace___261 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___246;

struct bpf_map_ops___245 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___246 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___246 *, struct file___392 *);
	void (*map_free)(struct bpf_map___246 *);
	int (*map_get_next_key)(struct bpf_map___246 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___246 *);
	void * (*map_lookup_elem)(struct bpf_map___246 *, void *);
	int (*map_update_elem)(struct bpf_map___246 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___246 *, void *);
	int (*map_push_elem)(struct bpf_map___246 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___246 *, void *);
	int (*map_peek_elem)(struct bpf_map___246 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___246 *, struct file___392 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___246 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___246 *, void *, struct seq_file___334 *);
	int (*map_check_btf)(const struct bpf_map___246 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___246 {
	const struct bpf_map_ops___245 *ops;
	struct bpf_map___246 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___362 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___246;

typedef void (*kthread_work_func_t___246)(struct kthread_work___246 *);

struct kthread_worker___246;

struct kthread_work___246 {
	struct list_head node;
	kthread_work_func_t___246 func;
	struct kthread_worker___246 *worker;
	int canceling;
};

struct kthread_worker___246 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___394 *task;
	struct kthread_work___246 *current_work;
};

struct kthread_delayed_work___245 {
	struct kthread_work___246 work;
	struct timer_list timer;
};

struct psi_group___245 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___246 *poll_kworker;
	struct kthread_delayed_work___245 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___245;

struct cgroup_rstat_cpu___245;

struct cgroup___245 {
	struct cgroup_subsys_state___245 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___387 *kn;
	struct cgroup_file___245 procs_file;
	struct cgroup_file___245 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___245 *subsys[13];
	struct cgroup_root___245 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___245 *dom_cgrp;
	struct cgroup_rstat_cpu___245 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___39 bpf;
	atomic_t congestion_count;
	struct cgroup___245 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___245 psi;
	int ancestor_ids[0];
};

struct cftype___245;

struct cgroup_subsys___245 {
	struct cgroup_subsys_state___245 * (*css_alloc)(struct cgroup_subsys_state___245 *);
	int (*css_online)(struct cgroup_subsys_state___245 *);
	void (*css_offline)(struct cgroup_subsys_state___245 *);
	void (*css_released)(struct cgroup_subsys_state___245 *);
	void (*css_free)(struct cgroup_subsys_state___245 *);
	void (*css_reset)(struct cgroup_subsys_state___245 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___245 *, int);
	int (*css_extra_stat_show)(struct seq_file___334 *, struct cgroup_subsys_state___245 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___394 *);
	void (*cancel_fork)(struct task_struct___394 *);
	void (*fork)(struct task_struct___394 *);
	void (*exit)(struct task_struct___394 *);
	void (*free)(struct task_struct___394 *);
	void (*bind)(struct cgroup_subsys_state___245 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___245 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___245 *dfl_cftypes;
	struct cftype___245 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___245 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___245 *updated_children;
	struct cgroup___245 *updated_next;
};

struct cgroup_root___245 {
	struct kernfs_root___386 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___245 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___245 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___245 *ss;
	struct list_head node;
	struct kernfs_ops___386 *kf_ops;
	int (*open)(struct kernfs_open_file___386 *);
	void (*release)(struct kernfs_open_file___386 *);
	u64 (*read_u64)(struct cgroup_subsys_state___245 *, struct cftype___245 *);
	s64 (*read_s64)(struct cgroup_subsys_state___245 *, struct cftype___245 *);
	int (*seq_show)(struct seq_file___334 *, void *);
	void * (*seq_start)(struct seq_file___334 *, loff_t *);
	void * (*seq_next)(struct seq_file___334 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___334 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___245 *, struct cftype___245 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___245 *, struct cftype___245 *, s64);
	ssize_t (*write)(struct kernfs_open_file___386 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___386 *, struct poll_table_struct___239 *);
};

typedef void compound_page_dtor___381(struct page___393 *);

struct bdi_writeback_congested___194 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___194 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___194 {
	struct bio___194 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___196 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___196 bip_inline_vecs[0];
};

struct bio_set___194 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___194 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___137 {
	struct mem_cgroup___137 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___137 {
	struct lruvec___393 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___137 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___137 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct perf_cpu_context___150;

struct pmu___150 {
	struct list_head entry;
	struct module___322 *module;
	struct device___360 *dev;
	const struct attribute_group___357 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___150 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___150 *);
	void (*pmu_disable)(struct pmu___150 *);
	int (*event_init)(struct perf_event___150 *);
	void (*event_mapped)(struct perf_event___150 *, struct mm_struct___393 *);
	void (*event_unmapped)(struct perf_event___150 *, struct mm_struct___393 *);
	int (*add)(struct perf_event___150 *, int);
	void (*del)(struct perf_event___150 *, int);
	void (*start)(struct perf_event___150 *, int);
	void (*stop)(struct perf_event___150 *, int);
	void (*read)(struct perf_event___150 *);
	void (*start_txn)(struct pmu___150 *, unsigned int);
	int (*commit_txn)(struct pmu___150 *);
	void (*cancel_txn)(struct pmu___150 *);
	int (*event_idx)(struct perf_event___150 *);
	void (*sched_task)(struct perf_event_context___150 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___150 *);
	int (*filter_match)(struct perf_event___150 *);
	int (*check_period)(struct perf_event___150 *, u64);
};

struct perf_cpu_context___150 {
	struct perf_event_context___150 ctx;
	struct perf_event_context___150 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___150 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___150 {
	struct cgroup_subsys_state___245 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___143 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___143 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___143 *);
	struct list_head * (*get_fields)(struct trace_event_call___143 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___143 *);
};

struct cpuidle_governor___2 {
	char name[16];
	struct list_head governor_list;
	unsigned int rating;
	int (*enable)(struct cpuidle_driver___6 *, struct cpuidle_device *);
	void (*disable)(struct cpuidle_driver___6 *, struct cpuidle_device *);
	int (*select)(struct cpuidle_driver___6 *, struct cpuidle_device *, bool *);
	void (*reflect)(struct cpuidle_device *, int);
};

struct cpuidle_state_kobj {
	struct cpuidle_state___6 *state;
	struct cpuidle_state_usage *state_usage;
	struct completion kobj_unregister;
	struct kobject___380 kobj;
	struct cpuidle_device *device;
};

struct cpuidle_driver_kobj {
	struct cpuidle_driver___7 *drv;
	struct completion kobj_unregister;
	struct kobject___380 kobj;
};

struct cpuidle_device_kobj {
	struct cpuidle_device *dev;
	struct completion kobj_unregister;
	struct kobject___380 kobj;
};

struct cpuidle_attr {
	struct attribute attr;
	ssize_t (*show)(struct cpuidle_device *, char *);
	ssize_t (*store)(struct cpuidle_device *, const char *, size_t);
};

struct cpuidle_state_attr {
	struct attribute attr;
	ssize_t (*show)(struct cpuidle_state___6 *, struct cpuidle_state_usage *, char *);
	ssize_t (*store)(struct cpuidle_state___6 *, struct cpuidle_state_usage *, const char *, size_t);
};

struct cpuidle_driver_attr {
	struct attribute attr;
	ssize_t (*show)(struct cpuidle_driver___7 *, char *);
	ssize_t (*store)(struct cpuidle_driver___7 *, const char *, size_t);
};

struct menu_device {
	int needs_update;
	int tick_wakeup;
	unsigned int next_timer_us;
	unsigned int predicted_us;
	unsigned int bucket;
	unsigned int correction_factor[12];
	unsigned int intervals[8];
	int interval_ptr;
};

struct pci_dev___37;

struct sdhci_pci_data {
	struct pci_dev___37 *pdev;
	int slotno;
	int rst_n_gpio;
	int cd_gpio;
	int (*setup)(struct sdhci_pci_data *);
	void (*cleanup)(struct sdhci_pci_data *);
};

struct led_trigger___7;

struct led_classdev___7 {
	const char *name;
	enum led_brightness brightness;
	enum led_brightness max_brightness;
	int flags;
	long unsigned int work_flags;
	void (*brightness_set)(struct led_classdev___7 *, enum led_brightness);
	int (*brightness_set_blocking)(struct led_classdev___7 *, enum led_brightness);
	enum led_brightness (*brightness_get)(struct led_classdev___7 *);
	int (*blink_set)(struct led_classdev___7 *, long unsigned int *, long unsigned int *);
	int (*pattern_set)(struct led_classdev___7 *, struct led_pattern *, u32, int);
	int (*pattern_clear)(struct led_classdev___7 *);
	struct device___360 *dev;
	const struct attribute_group___357 **groups;
	struct list_head node;
	const char *default_trigger;
	long unsigned int blink_delay_on;
	long unsigned int blink_delay_off;
	struct timer_list blink_timer;
	int blink_brightness;
	int new_blink_brightness;
	void (*flash_resume)(struct led_classdev___7 *);
	struct work_struct set_brightness_work;
	int delayed_set_value;
	struct rw_semaphore___394 trigger_lock;
	struct led_trigger___7 *trigger;
	struct list_head trig_list;
	void *trigger_data;
	bool activated;
	struct mutex led_access;
};

struct led_trigger___7 {
	const char *name;
	void (*activate)(struct led_classdev___7 *);
	void (*deactivate)(struct led_classdev___7 *);
	rwlock_t leddev_list_lock;
	struct list_head led_cdevs;
	struct list_head next_trig;
};

typedef void (*dr_release_t___28)(struct device___360 *, void *);

struct led_cdev;

struct device_attribute___57 {
	struct attribute attr;
	ssize_t (*show)(struct device___272 *, struct device_attribute___57 *, char *);
	ssize_t (*store)(struct device___272 *, struct device_attribute___57 *, const char *, size_t);
};

struct cpuidle_driver___8;

struct cpuidle_state___7 {
	char name[16];
	char desc[32];
	unsigned int flags;
	unsigned int exit_latency;
	int power_usage;
	unsigned int target_residency;
	bool disabled;
	int (*enter)(struct cpuidle_device *, struct cpuidle_driver___8 *, int);
	int (*enter_dead)(struct cpuidle_device *, int);
	void (*enter_s2idle)(struct cpuidle_device *, struct cpuidle_driver___8 *, int);
};

struct cpuidle_driver___8 {
	const char *name;
	struct module___247 *owner;
	int refcnt;
	unsigned int bctimer: 1;
	struct cpuidle_state___7 states[10];
	int state_count;
	int safe_state_index;
	struct cpumask *cpumask;
};

typedef long unsigned int psci_fn(long unsigned int, long unsigned int, long unsigned int, long unsigned int);

enum psci_function {
	PSCI_FN_CPU_SUSPEND = 0,
	PSCI_FN_CPU_ON = 1,
	PSCI_FN_CPU_OFF = 2,
	PSCI_FN_MIGRATE = 3,
	PSCI_FN_MAX = 4,
};

struct thermal_zone_device___7;

struct thermal_cooling_device___7;

struct thermal_zone_device_ops___6 {
	int (*bind)(struct thermal_zone_device___7 *, struct thermal_cooling_device___7 *);
	int (*unbind)(struct thermal_zone_device___7 *, struct thermal_cooling_device___7 *);
	int (*get_temp)(struct thermal_zone_device___7 *, int *);
	int (*set_trips)(struct thermal_zone_device___7 *, int, int);
	int (*get_mode)(struct thermal_zone_device___7 *, enum thermal_device_mode *);
	int (*set_mode)(struct thermal_zone_device___7 *, enum thermal_device_mode);
	int (*get_trip_type)(struct thermal_zone_device___7 *, int, enum thermal_trip_type *);
	int (*get_trip_temp)(struct thermal_zone_device___7 *, int, int *);
	int (*set_trip_temp)(struct thermal_zone_device___7 *, int, int);
	int (*get_trip_hyst)(struct thermal_zone_device___7 *, int, int *);
	int (*set_trip_hyst)(struct thermal_zone_device___7 *, int, int);
	int (*get_crit_temp)(struct thermal_zone_device___7 *, int *);
	int (*set_emul_temp)(struct thermal_zone_device___7 *, int);
	int (*get_trend)(struct thermal_zone_device___7 *, int, enum thermal_trend *);
	int (*notify)(struct thermal_zone_device___7 *, int, enum thermal_trip_type);
};

struct thermal_attr___6;

struct thermal_zone_params___6;

struct thermal_governor___6;

struct thermal_zone_device___7 {
	int id;
	char type[20];
	struct device___272 device;
	struct attribute_group___271 trips_attribute_group;
	struct thermal_attr___6 *trip_temp_attrs;
	struct thermal_attr___6 *trip_type_attrs;
	struct thermal_attr___6 *trip_hyst_attrs;
	void *devdata;
	int trips;
	long unsigned int trips_disabled;
	int passive_delay;
	int polling_delay;
	int temperature;
	int last_temperature;
	int emul_temperature;
	int passive;
	int prev_low_trip;
	int prev_high_trip;
	unsigned int forced_passive;
	atomic_t need_update;
	struct thermal_zone_device_ops___6 *ops;
	struct thermal_zone_params___6 *tzp;
	struct thermal_governor___6 *governor;
	void *governor_data;
	struct list_head thermal_instances;
	struct ida ida;
	struct mutex lock;
	struct list_head node;
	struct delayed_work poll_queue;
	enum thermal_notify_event notify_event;
};

struct thermal_cooling_device_ops___6;

struct thermal_cooling_device___7 {
	int id;
	char type[20];
	struct device___272 device;
	struct device_node___64 *np;
	void *devdata;
	void *stats;
	const struct thermal_cooling_device_ops___6 *ops;
	bool updated;
	struct mutex lock;
	struct list_head thermal_instances;
	struct list_head node;
};

struct thermal_cooling_device_ops___6 {
	int (*get_max_state)(struct thermal_cooling_device___7 *, long unsigned int *);
	int (*get_cur_state)(struct thermal_cooling_device___7 *, long unsigned int *);
	int (*set_cur_state)(struct thermal_cooling_device___7 *, long unsigned int);
	int (*get_requested_power)(struct thermal_cooling_device___7 *, struct thermal_zone_device___7 *, u32 *);
	int (*state2power)(struct thermal_cooling_device___7 *, struct thermal_zone_device___7 *, long unsigned int, u32 *);
	int (*power2state)(struct thermal_cooling_device___7 *, struct thermal_zone_device___7 *, u32, long unsigned int *);
};

struct thermal_attr___6 {
	struct device_attribute___57 attr;
	char name[20];
};

struct thermal_bind_params___6;

struct thermal_zone_params___6 {
	char governor_name[20];
	bool no_hwmon;
	int num_tbps;
	struct thermal_bind_params___6 *tbp;
	u32 sustainable_power;
	s32 k_po;
	s32 k_pu;
	s32 k_i;
	s32 k_d;
	s32 integral_cutoff;
	int slope;
	int offset;
};

struct thermal_governor___6 {
	char name[20];
	int (*bind_to_tz)(struct thermal_zone_device___7 *);
	void (*unbind_from_tz)(struct thermal_zone_device___7 *);
	int (*throttle)(struct thermal_zone_device___7 *, int);
	struct list_head governor_list;
};

struct thermal_bind_params___6 {
	struct thermal_cooling_device___7 *cdev;
	int weight;
	int trip_mask;
	long unsigned int *binding_limits;
	int (*match)(struct thermal_zone_device___7 *, struct thermal_cooling_device___7 *);
};

struct acpi_processor___5;

struct acpi_processor_throttling___5 {
	unsigned int state;
	unsigned int platform_limit;
	struct acpi_pct_register control_register;
	struct acpi_pct_register status_register;
	short: 16;
	unsigned int state_count;
	int: 32;
	struct acpi_processor_tx_tss *states_tss;
	struct acpi_tsd_package domain_info;
	cpumask_var_t shared_cpu_map;
	int (*acpi_processor_get_throttling)(struct acpi_processor___5 *);
	int (*acpi_processor_set_throttling)(struct acpi_processor___5 *, int, bool);
	u32 address;
	u8 duty_offset;
	u8 duty_width;
	u8 tsd_valid_flag;
	char: 8;
	unsigned int shared_type;
	struct acpi_processor_tx states[16];
	int: 32;
} __attribute__((packed));

struct acpi_processor___5 {
	acpi_handle handle;
	u32 acpi_id;
	phys_cpuid_t phys_id;
	u32 id;
	u32 pblk;
	int performance_platform_limit;
	int throttling_platform_limit;
	struct acpi_processor_flags flags;
	struct acpi_processor_power power;
	struct acpi_processor_performance *performance;
	struct acpi_processor_throttling___5 throttling;
	struct acpi_processor_limit limit;
	struct thermal_cooling_device___7 *cdev;
	struct device___272 *dev;
};

typedef int (*psci_initcall_t)(const struct device_node___64 *);

struct preempt_notifier___8;

struct preempt_ops___8 {
	void (*sched_in)(struct preempt_notifier___8 *, int);
	void (*sched_out)(struct preempt_notifier___8 *, struct task_struct___17 *);
};

struct preempt_notifier___8 {
	struct hlist_node link;
	struct preempt_ops___8 *ops;
};

struct mmu_notifier___7;

struct mmu_notifier_ops___7 {
	int flags;
	void (*release)(struct mmu_notifier___7 *, struct mm_struct___16 *);
	int (*clear_flush_young)(struct mmu_notifier___7 *, struct mm_struct___16 *, long unsigned int, long unsigned int);
	int (*clear_young)(struct mmu_notifier___7 *, struct mm_struct___16 *, long unsigned int, long unsigned int);
	int (*test_young)(struct mmu_notifier___7 *, struct mm_struct___16 *, long unsigned int);
	void (*change_pte)(struct mmu_notifier___7 *, struct mm_struct___16 *, long unsigned int, pte_t);
	void (*invalidate_range_start)(struct mmu_notifier___7 *, struct mm_struct___16 *, long unsigned int, long unsigned int);
	void (*invalidate_range_end)(struct mmu_notifier___7 *, struct mm_struct___16 *, long unsigned int, long unsigned int);
	void (*invalidate_range)(struct mmu_notifier___7 *, struct mm_struct___16 *, long unsigned int, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mmu_notifier___7 {
	struct hlist_node hlist;
	const struct mmu_notifier_ops___7 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct kvm_vcpu___8;

struct kvm_io_device___8;

struct kvm_io_device_ops___8 {
	int (*read)(struct kvm_vcpu___8 *, struct kvm_io_device___8 *, gpa_t, int, void *);
	int (*write)(struct kvm_vcpu___8 *, struct kvm_io_device___8 *, gpa_t, int, const void *);
	void (*destructor)(struct kvm_io_device___8 *);
};

struct kvm_cpu_context___8 {
	struct kvm_regs gp_regs;
	union {
		u64 sys_regs[101];
		u32 copro[202];
	};
	struct kvm_vcpu___8 *__hyp_running_vcpu;
};

typedef struct kvm_cpu_context___8 kvm_cpu_context_t___8;

struct its_vm___8;

struct its_vpe___8 {
	struct page___2 *vpt_page;
	struct its_vm___8 *its_vm;
	int irq;
	irq_hw_number_t vpe_db_lpi;
	int vpe_proxy_event;
	u16 col_idx;
	u16 vpe_id;
	bool idai;
	bool pending_last;
};

struct vgic_v3_cpu_if___7 {
	u32 vgic_hcr;
	u32 vgic_vmcr;
	u32 vgic_sre;
	u32 vgic_ap0r[4];
	u32 vgic_ap1r[4];
	u64 vgic_lr[16];
	struct its_vpe___8 its_vpe;
};

struct vgic_irq___8 {
	raw_spinlock_t irq_lock;
	struct list_head lpi_list;
	struct list_head ap_list;
	struct kvm_vcpu___8 *vcpu;
	struct kvm_vcpu___8 *target_vcpu;
	u32 intid;
	bool line_level;
	bool pending_latch;
	bool active;
	bool enabled;
	bool hw;
	struct kref refcount;
	u32 hwintid;
	unsigned int host_irq;
	union {
		u8 targets;
		u32 mpidr;
	};
	u8 source;
	u8 active_source;
	u8 priority;
	u8 group;
	enum vgic_irq_config config;
	bool (*get_input_level)(int);
	void *owner;
};

struct kvm_io_device___8 {
	const struct kvm_io_device_ops___8 *ops;
};

struct vgic_its___8;

struct vgic_io_device___8 {
	gpa_t base_addr;
	union {
		struct kvm_vcpu___8 *redist_vcpu;
		struct vgic_its___8 *its;
	};
	const struct vgic_register_region *regions;
	enum iodev_type iodev_type;
	int nr_regions;
	struct kvm_io_device___8 dev;
};

struct vgic_cpu___8 {
	union {
		struct vgic_v2_cpu_if vgic_v2;
		struct vgic_v3_cpu_if___7 vgic_v3;
	};
	unsigned int used_lrs;
	struct vgic_irq___8 private_irqs[32];
	raw_spinlock_t ap_list_lock;
	struct list_head ap_list_head;
	struct vgic_io_device___8 rd_iodev;
	struct vgic_io_device___8 sgi_iodev;
	struct vgic_redist_region *rdreg;
	u64 pendbaser;
	bool lpis_enabled;
	u32 num_pri_bits;
	u32 num_id_bits;
};

struct arch_timer_context___8 {
	struct kvm_vcpu___8 *vcpu;
	u32 cnt_ctl;
	u64 cnt_cval;
	struct kvm_irq_level irq;
	u64 cntvoff;
	struct hrtimer hrtimer;
	bool loaded;
	u32 host_timer_irq;
	u32 host_timer_irq_flags;
};

struct arch_timer_cpu___8 {
	struct arch_timer_context___8 timers[2];
	struct hrtimer bg_timer;
	bool enabled;
};

struct kvm_pmc___7 {
	u8 idx;
	struct perf_event___9 *perf_event;
	u64 bitmask;
};

struct kvm_pmu___7 {
	int irq_num;
	struct kvm_pmc___7 pmc[32];
	bool ready;
	bool created;
	bool irq_level;
};

struct kvm_vcpu_arch___8 {
	struct kvm_cpu_context___8 ctxt;
	void *sve_state;
	unsigned int sve_max_vl;
	u64 hcr_el2;
	u32 mdcr_el2;
	struct kvm_vcpu_fault_info fault;
	u64 workaround_flags;
	u64 flags;
	struct kvm_guest_debug_arch *debug_ptr;
	struct kvm_guest_debug_arch vcpu_debug_state;
	struct kvm_guest_debug_arch external_debug_state;
	kvm_cpu_context_t___8 *host_cpu_context;
	struct thread_info *host_thread_info;
	struct user_fpsimd_state *host_fpsimd_state;
	struct {
		struct kvm_guest_debug_arch regs;
		u64 pmscr_el1;
	} host_debug_state;
	struct vgic_cpu___8 vgic_cpu;
	struct arch_timer_cpu___8 timer_cpu;
	struct kvm_pmu___7 pmu;
	struct {
		u32 mdscr_el1;
	} guest_debug_preserved;
	bool power_off;
	bool pause;
	struct kvm_decode mmio_decode;
	struct kvm_mmu_memory_cache mmu_page_cache;
	int target;
	long unsigned int features[1];
	bool has_run_once;
	u64 vsesr_el2;
	struct vcpu_reset_state reset_state;
	bool sysregs_loaded_on_cpu;
};

struct kvm___8;

struct kvm_vcpu___8 {
	struct kvm___8 *kvm;
	struct preempt_notifier___8 preempt_notifier;
	int cpu;
	int vcpu_id;
	int srcu_idx;
	int mode;
	u64 requests;
	long unsigned int guest_debug;
	int pre_pcpu;
	struct list_head blocked_vcpu_list;
	struct mutex mutex;
	struct kvm_run *run;
	int guest_xcr0_loaded;
	struct swait_queue_head wq;
	struct pid___14 *pid;
	int sigset_active;
	sigset_t sigset;
	struct kvm_vcpu_stat stat;
	unsigned int halt_poll_ns;
	bool valid_wakeup;
	int mmio_needed;
	int mmio_read_completed;
	int mmio_is_write;
	int mmio_cur_fragment;
	int mmio_nr_fragments;
	struct kvm_mmio_fragment mmio_fragments[2];
	struct {
		bool in_spin_loop;
		bool dy_eligible;
	} spin_loop;
	bool preempted;
	struct kvm_vcpu_arch___8 arch;
	struct dentry___17 *debugfs_dentry;
	long: 64;
};

struct its_vm___8 {
	struct fwnode_handle___12 *fwnode;
	struct irq_domain *domain;
	struct page___2 *vprop_page;
	struct its_vpe___8 **vpes;
	int nr_vpes;
	irq_hw_number_t db_lpi_base;
	long unsigned int *db_bitmap;
	int nr_db_lpis;
	u32 vlpi_count[16];
};

struct kvm_device___8;

struct vgic_its___8 {
	gpa_t vgic_its_base;
	bool enabled;
	struct vgic_io_device___8 iodev;
	struct kvm_device___8 *dev;
	u64 baser_device_table;
	u64 baser_coll_table;
	struct mutex cmd_lock;
	u64 cbaser;
	u32 creadr;
	u32 cwriter;
	u32 abi_rev;
	struct mutex its_lock;
	struct list_head device_list;
	struct list_head collection_list;
};

struct kvm_device_ops___8;

struct kvm_device___8 {
	struct kvm_device_ops___8 *ops;
	struct kvm___8 *kvm;
	void *private;
	struct list_head vm_node;
};

struct vgic_dist___8 {
	bool in_kernel;
	bool ready;
	bool initialized;
	u32 vgic_model;
	u32 implementation_rev;
	bool v2_groups_user_writable;
	bool msis_require_devid;
	int nr_spis;
	gpa_t vgic_dist_base;
	union {
		gpa_t vgic_cpu_base;
		struct list_head rd_regions;
	};
	bool enabled;
	struct vgic_irq___8 *spis;
	struct vgic_io_device___8 dist_iodev;
	bool has_its;
	u64 propbaser;
	raw_spinlock_t lpi_list_lock;
	struct list_head lpi_list_head;
	int lpi_list_count;
	struct vgic_state_iter *iter;
	struct its_vm___8 its_vm;
};

struct kvm_arch___8 {
	struct kvm_vmid vmid;
	pgd_t *pgd;
	phys_addr_t pgd_phys;
	u64 vtcr;
	int *last_vcpu_ran;
	int max_vcpus;
	struct vgic_dist___8 vgic;
	u32 psci_version;
};

struct kvm_io_range___8 {
	gpa_t addr;
	int len;
	struct kvm_io_device___8 *dev;
};

struct kvm_io_bus___8 {
	int dev_count;
	int ioeventfd_count;
	struct kvm_io_range___8 range[0];
};

struct kvm_stat_data___8;

struct kvm___8 {
	spinlock_t mmu_lock;
	struct mutex slots_lock;
	struct mm_struct___16 *mm;
	struct kvm_memslots *memslots[1];
	struct kvm_vcpu___8 *vcpus[512];
	atomic_t online_vcpus;
	int created_vcpus;
	int last_boosted_vcpu;
	struct list_head vm_list;
	struct mutex lock;
	struct kvm_io_bus___8 *buses[4];
	struct {
		spinlock_t lock;
		struct list_head items;
		struct list_head resampler_list;
		struct mutex resampler_lock;
	} irqfds;
	struct list_head ioeventfds;
	struct kvm_vm_stat stat;
	struct kvm_arch___8 arch;
	refcount_t users_count;
	struct kvm_coalesced_mmio_ring *coalesced_mmio_ring;
	spinlock_t ring_lock;
	struct list_head coalesced_zones;
	struct mutex irq_lock;
	struct kvm_irq_routing_table *irq_routing;
	struct hlist_head irq_ack_notifier_list;
	struct mmu_notifier___7 mmu_notifier;
	long unsigned int mmu_notifier_seq;
	long int mmu_notifier_count;
	long int tlbs_dirty;
	struct list_head devices;
	bool manual_dirty_log_protect;
	struct dentry___17 *debugfs_dentry;
	struct kvm_stat_data___8 **debugfs_stat_data;
	struct srcu_struct srcu;
	struct srcu_struct irq_srcu;
	pid_t userspace_pid;
};

struct kvm_stat_data___8 {
	int offset;
	int mode;
	struct kvm___8 *kvm;
};

struct kvm_device_ops___8 {
	const char *name;
	int (*create)(struct kvm_device___8 *, u32);
	void (*init)(struct kvm_device___8 *);
	void (*destroy)(struct kvm_device___8 *);
	void (*release)(struct kvm_device___8 *);
	int (*set_attr)(struct kvm_device___8 *, struct kvm_device_attr *);
	int (*get_attr)(struct kvm_device___8 *, struct kvm_device_attr *);
	int (*has_attr)(struct kvm_device___8 *, struct kvm_device_attr *);
	long int (*ioctl)(struct kvm_device___8 *, unsigned int, long unsigned int);
	int (*mmap)(struct kvm_device___8 *, struct vm_area_struct___2 *);
};

struct platform_device_info___6 {
	struct device___2 *parent;
	struct fwnode_handle___12 *fwnode;
	const char *name;
	int id;
	const struct resource *res;
	unsigned int num_res;
	const void *data;
	size_t size_data;
	u64 dma_mask;
	struct property_entry___2 *properties;
};

struct sdei_event {
	struct list_head list;
	bool reregister;
	bool reenable;
	u32 event_num;
	u8 type;
	u8 priority;
	union {
		struct sdei_registered_event *registered;
		struct sdei_registered_event *private_registered;
	};
};

struct sdei_crosscall_args {
	struct sdei_event *event;
	atomic_t errors;
	int first_error;
};

struct dmi_memdev_info {
	const char *device;
	const char *bank;
	u64 size;
	u16 handle;
};

struct dmi_sysfs_entry {
	struct dmi_header dh;
	struct kobject___374 kobj;
	int instance;
	int position;
	struct list_head list;
	struct kobject___374 *child;
};

struct dmi_sysfs_attribute {
	struct attribute attr;
	ssize_t (*show)(struct dmi_sysfs_entry *, char *);
};

struct dmi_sysfs_mapped_attribute {
	struct attribute attr;
	ssize_t (*show)(struct dmi_sysfs_entry *, const struct dmi_header *, char *);
};

typedef ssize_t (*dmi_callback)(struct dmi_sysfs_entry *, const struct dmi_header *, void *);

struct find_dmi_data {
	struct dmi_sysfs_entry *entry;
	dmi_callback callback;
	void *private;
	int instance_countdown;
	ssize_t ret;
};

struct dmi_read_state {
	char *buf;
	loff_t pos;
	size_t count;
};

struct dmi_entry_attr_show_data {
	struct attribute *attr;
	char *buf;
};

struct dmi_system_event_log {
	struct dmi_header header;
	u16 area_length;
	u16 header_start_offset;
	u16 data_start_offset;
	u8 access_method;
	u8 status;
	u32 change_token;
	union {
		struct {
			u16 index_addr;
			u16 data_addr;
		} io;
		u32 phys_addr32;
		u16 gpnv_handle;
		u32 access_method_address;
	};
	u8 header_format;
	u8 type_descriptors_supported_count;
	u8 per_log_type_descriptor_length;
	u8 supported_log_type_descriptos[0];
} __attribute__((packed));

typedef u8 (*sel_io_reader)(const struct dmi_system_event_log *, loff_t);

struct dmi_device_attribute {
	struct device_attribute___56 dev_attr;
	int field;
};

struct mafield {
	const char *prefix;
	int field;
};

struct platform_device___24 {
	const char *name;
	int id;
	bool id_auto;
	struct device___305 dev;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct platform_driver___19 {
	int (*probe)(struct platform_device___24 *);
	int (*remove)(struct platform_device___24 *);
	void (*shutdown)(struct platform_device___24 *);
	int (*suspend)(struct platform_device___24 *, pm_message_t);
	int (*resume)(struct platform_device___24 *);
	struct device_driver___305 driver;
	const struct platform_device_id *id_table;
	bool prevent_deferred_probe;
};

struct fw_cfg_file {
	__be32 size;
	__be16 select;
	__u16 reserved;
	char name[56];
};

struct fw_cfg_dma_access {
	__be32 control;
	__be32 length;
	__be64 address;
};

struct fw_cfg_vmcoreinfo {
	__le16 host_format;
	__le16 guest_format;
	__le32 size;
	__le64 paddr;
};

struct fw_cfg_sysfs_entry {
	struct kobject___326 kobj;
	u32 size;
	u16 select;
	char name[56];
	struct list_head list;
};

struct fw_cfg_sysfs_attribute {
	struct attribute attr;
	ssize_t (*show)(struct fw_cfg_sysfs_entry *, char *);
};

struct module___323;

struct file___393;

struct kiocb___393;

struct poll_table_struct___240;

struct vm_area_struct___394;

struct inode___393;

struct file_lock___393;

struct page___394;

struct seq_file___335;

struct file_operations___393 {
	struct module___323 *owner;
	loff_t (*llseek)(struct file___393 *, loff_t, int);
	ssize_t (*read)(struct file___393 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___393 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___393 *, struct iov_iter___166 *);
	ssize_t (*write_iter)(struct kiocb___393 *, struct iov_iter___166 *);
	int (*iopoll)(struct kiocb___393 *, bool);
	int (*iterate)(struct file___393 *, struct dir_context *);
	int (*iterate_shared)(struct file___393 *, struct dir_context *);
	__poll_t (*poll)(struct file___393 *, struct poll_table_struct___240 *);
	long int (*unlocked_ioctl)(struct file___393 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___393 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___393 *, struct vm_area_struct___394 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___393 *, struct file___393 *);
	int (*flush)(struct file___393 *, fl_owner_t);
	int (*release)(struct inode___393 *, struct file___393 *);
	int (*fsync)(struct file___393 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___393 *, int);
	int (*lock)(struct file___393 *, int, struct file_lock___393 *);
	ssize_t (*sendpage)(struct file___393 *, struct page___394 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___393 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___393 *, int, struct file_lock___393 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___393 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___393 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___393 *, long int, struct file_lock___393 **, void **);
	long int (*fallocate)(struct file___393 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___335 *, struct file___393 *);
	ssize_t (*copy_file_range)(struct file___393 *, loff_t, struct file___393 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___393 *, loff_t, struct file___393 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___393 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___394 {
	u64 seqnum;
	struct vm_area_struct___394 *vmas[4];
};

struct page_frag___394 {
	struct page___394 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___394;

struct pid___227;

struct cred___363;

struct nsproxy___291;

struct signal_struct___270;

struct vm_struct___298;

struct task_struct___395 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___395 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___394 *mm;
	struct mm_struct___394 *active_mm;
	struct vmacache___394 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___395 *real_parent;
	struct task_struct___395 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___395 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___227 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___227 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___227 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___363 *ptracer_cred;
	const struct cred___363 *real_cred;
	const struct cred___363 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___291 *nsproxy;
	struct signal_struct___270 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___395 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___394 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___395 *oom_reaper_list;
	struct vm_struct___298 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___150 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___394 *pgtable_t___394;

struct address_space___393;

struct dev_pagemap___382;

struct page___394 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___393 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___394 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___394 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___394 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___382 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___394;

struct lruvec___394 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___394 *pgdat;
};

struct zone___394 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___394 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___394 {
	struct zone___394 *zone;
	int zone_idx;
};

struct zonelist___394 {
	struct zoneref___394 _zonerefs[25];
};

struct pglist_data___394 {
	struct zone___394 node_zones[3];
	struct zonelist___394 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___395 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___395 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___394 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___395 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___395 *owner;
};

struct secondary_data___395 {
	void *stack;
	struct task_struct___395 *task;
	long int status;
};

struct blocking_notifier_head___394 {
	struct rw_semaphore___395 rwsem;
	struct notifier_block *head;
};

struct kernfs_root___387;

struct kernfs_elem_dir___387 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___387 *root;
};

struct kernfs_node___388;

struct kernfs_syscall_ops___387;

struct kernfs_root___387 {
	struct kernfs_node___388 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___387 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___387 {
	struct kernfs_node___388 *target_kn;
};

struct kernfs_ops___387;

struct kernfs_elem_attr___387 {
	const struct kernfs_ops___387 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___388 *notify_next;
};

struct kernfs_node___388 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___388 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___387 dir;
		struct kernfs_elem_symlink___387 symlink;
		struct kernfs_elem_attr___387 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___387;

struct kernfs_ops___387 {
	int (*open)(struct kernfs_open_file___387 *);
	void (*release)(struct kernfs_open_file___387 *);
	int (*seq_show)(struct seq_file___335 *, void *);
	void * (*seq_start)(struct seq_file___335 *, loff_t *);
	void * (*seq_next)(struct seq_file___335 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___335 *, void *);
	ssize_t (*read)(struct kernfs_open_file___387 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___387 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___387 *, struct vm_area_struct___394 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___387 *, struct poll_table_struct___240 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___387 {
	int (*remount_fs)(struct kernfs_root___387 *, int *, char *);
	int (*show_options)(struct seq_file___335 *, struct kernfs_root___387 *);
	int (*mkdir)(struct kernfs_node___388 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___388 *);
	int (*rename)(struct kernfs_node___388 *, struct kernfs_node___388 *, const char *);
	int (*show_path)(struct seq_file___335 *, struct kernfs_node___388 *, struct kernfs_root___387 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___335;

struct seq_file___335 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___335 *op;
	int poll_event;
	const struct file___393 *file;
	void *private;
};

struct vm_operations_struct___382;

struct kernfs_open_file___387 {
	struct kernfs_node___388 *kn;
	struct file___393 *file;
	struct seq_file___335 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___382 *vm_ops;
};

struct dentry___393;

struct path___394 {
	struct vfsmount *mnt;
	struct dentry___393 *dentry;
};

struct fown_struct___227 {
	rwlock_t lock;
	struct pid___227 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___393 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___394 f_path;
	struct inode___393 *f_inode;
	const struct file_operations___393 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___227 f_owner;
	const struct cred___363 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___393 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___382;

struct vm_operations_struct___382 {
	void (*open)(struct vm_area_struct___394 *);
	void (*close)(struct vm_area_struct___394 *);
	int (*split)(struct vm_area_struct___394 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___394 *);
	vm_fault_t (*fault)(struct vm_fault___382 *);
	vm_fault_t (*huge_fault)(struct vm_fault___382 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___382 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___394 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___382 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___382 *);
	int (*access)(struct vm_area_struct___394 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___394 *);
	int (*set_policy)(struct vm_area_struct___394 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___394 *, long unsigned int);
	struct page___394 * (*find_special_page)(struct vm_area_struct___394 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___248)(struct file___393 *, wait_queue_head_t *, struct poll_table_struct___240 *);

struct poll_table_struct___240 {
	poll_queue_proc___248 _qproc;
	__poll_t _key;
};

struct vm_area_struct___394 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___394 *vm_next;
	struct vm_area_struct___394 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___394 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___382 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___393 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___381;

struct bin_attribute___357;

struct attribute_group___358 {
	const char *name;
	umode_t (*is_visible)(struct kobject___381 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___381 *, struct bin_attribute___357 *, int);
	struct attribute **attrs;
	struct bin_attribute___357 **bin_attrs;
};

struct kset___380;

struct kobj_type___380;

struct kobject___381 {
	const char *name;
	struct list_head entry;
	struct kobject___381 *parent;
	struct kset___380 *kset;
	struct kobj_type___380 *ktype;
	struct kernfs_node___388 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___357 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___393 *, struct kobject___381 *, struct bin_attribute___357 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___393 *, struct kobject___381 *, struct bin_attribute___357 *, char *, loff_t, size_t);
	int (*mmap)(struct file___393 *, struct kobject___381 *, struct bin_attribute___357 *, struct vm_area_struct___394 *);
};

struct sysfs_ops___380 {
	ssize_t (*show)(struct kobject___381 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___381 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___380;

struct kset___380 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___381 kobj;
	const struct kset_uevent_ops___380 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___380 {
	void (*release)(struct kobject___381 *);
	const struct sysfs_ops___380 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___29 * (*child_ns_type)(struct kobject___381 *);
	const void * (*namespace)(struct kobject___381 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___380 {
	int (* const filter)(struct kset___380 *, struct kobject___381 *);
	const char * (* const name)(struct kset___380 *, struct kobject___381 *);
	int (* const uevent)(struct kset___380 *, struct kobject___381 *, struct kobj_uevent_env *);
};

struct kobj_attribute___372 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___381 *, struct kobj_attribute___372 *, char *);
	ssize_t (*store)(struct kobject___381 *, struct kobj_attribute___372 *, const char *, size_t);
};

struct key___363;

struct user_struct___363;

struct cred___363 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___363 *session_keyring;
	struct key___363 *process_keyring;
	struct key___363 *thread_keyring;
	struct key___363 *request_key_auth;
	void *security;
	struct user_struct___363 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernel_param___321;

struct kernel_param_ops___321 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___321 *);
	int (*get)(char *, const struct kernel_param___321 *);
	void (*free)(void *);
};

struct kparam_array___321;

struct kernel_param___321 {
	const char *name;
	struct module___323 *mod;
	const struct kernel_param_ops___321 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___321 *arr;
	};
};

struct kparam_array___321 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___321 *ops;
	void *elem;
};

struct module_kobject___321 {
	struct kobject___381 kobj;
	struct module___323 *mod;
	struct kobject___381 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___321 {
	struct module___323 *mod;
	struct latch_tree_node node;
};

struct module_layout___321 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___321 mtn;
};

struct module_attribute___321;

struct module___323 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___321 mkobj;
	struct module_attribute___321 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___381 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___321 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___321 core_layout;
	struct module_layout___321 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___321 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___321 *, struct module_kobject___321 *, char *);
	ssize_t (*store)(struct module_attribute___321 *, struct module_kobject___321 *, const char *, size_t);
	void (*setup)(struct module___323 *, const char *);
	int (*test)(struct module___323 *);
	void (*free)(struct module___323 *);
};

struct device___361;

struct dev_pm_ops___361 {
	int (*prepare)(struct device___361 *);
	void (*complete)(struct device___361 *);
	int (*suspend)(struct device___361 *);
	int (*resume)(struct device___361 *);
	int (*freeze)(struct device___361 *);
	int (*thaw)(struct device___361 *);
	int (*poweroff)(struct device___361 *);
	int (*restore)(struct device___361 *);
	int (*suspend_late)(struct device___361 *);
	int (*resume_early)(struct device___361 *);
	int (*freeze_late)(struct device___361 *);
	int (*thaw_early)(struct device___361 *);
	int (*poweroff_late)(struct device___361 *);
	int (*restore_early)(struct device___361 *);
	int (*suspend_noirq)(struct device___361 *);
	int (*resume_noirq)(struct device___361 *);
	int (*freeze_noirq)(struct device___361 *);
	int (*thaw_noirq)(struct device___361 *);
	int (*poweroff_noirq)(struct device___361 *);
	int (*restore_noirq)(struct device___361 *);
	int (*runtime_suspend)(struct device___361 *);
	int (*runtime_resume)(struct device___361 *);
	int (*runtime_idle)(struct device___361 *);
};

struct dev_pm_info___361 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___361 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___361;

struct bus_type___361;

struct device_driver___361;

struct dev_pm_domain___361;

struct device_node___94;

struct fwnode_handle___282;

struct class___361;

struct device___361 {
	struct device___361 *parent;
	struct device_private *p;
	struct kobject___381 kobj;
	const char *init_name;
	const struct device_type___361 *type;
	struct mutex mutex;
	struct bus_type___361 *bus;
	struct device_driver___361 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___361 power;
	struct dev_pm_domain___361 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___94 *of_node;
	struct fwnode_handle___282 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___361 *class;
	const struct attribute_group___358 **groups;
	void (*release)(struct device___361 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___361 {
	struct dev_pm_ops___361 ops;
	void (*detach)(struct device___361 *, bool);
	int (*activate)(struct device___361 *);
	void (*sync)(struct device___361 *);
	void (*dismiss)(struct device___361 *);
};

struct pid_namespace___227;

struct upid___227 {
	int nr;
	struct pid_namespace___227 *ns;
};

struct pid_namespace___227 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___395 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___227 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___393 *proc_self;
	struct dentry___393 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___3 *user_ns;
	struct ucounts___2 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___9 ns;
};

struct pid___227 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___227 numbers[1];
};

struct user_struct___363 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___363 *uid_keyring;
	struct key___363 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___394;

struct mm_struct___394 {
	struct {
		struct vm_area_struct___394 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___393 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___395 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___394 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___395 *owner;
		struct user_namespace___3 *user_ns;
		struct file___393 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___394 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct nsproxy___291 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___227 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct signal_struct___270 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___395 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___395 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___227 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___227 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___394 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___227 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_struct___298 {
	struct vm_struct___298 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___394 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___282 {
	struct task_struct___395 task;
	long unsigned int stack[8192];
};

struct bus_type___361 {
	const char *name;
	const char *dev_name;
	struct device___361 *dev_root;
	const struct attribute_group___358 **bus_groups;
	const struct attribute_group___358 **dev_groups;
	const struct attribute_group___358 **drv_groups;
	int (*match)(struct device___361 *, struct device_driver___361 *);
	int (*uevent)(struct device___361 *, struct kobj_uevent_env *);
	int (*probe)(struct device___361 *);
	int (*remove)(struct device___361 *);
	void (*shutdown)(struct device___361 *);
	int (*online)(struct device___361 *);
	int (*offline)(struct device___361 *);
	int (*suspend)(struct device___361 *, pm_message_t);
	int (*resume)(struct device___361 *);
	int (*num_vf)(struct device___361 *);
	int (*dma_configure)(struct device___361 *);
	const struct dev_pm_ops___361 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___361 {
	const char *name;
	struct bus_type___361 *bus;
	struct module___323 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___361 *);
	int (*remove)(struct device___361 *);
	void (*shutdown)(struct device___361 *);
	int (*suspend)(struct device___361 *, pm_message_t);
	int (*resume)(struct device___361 *);
	const struct attribute_group___358 **groups;
	const struct dev_pm_ops___361 *pm;
	void (*coredump)(struct device___361 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___361 {
	const char *name;
	const struct attribute_group___358 **groups;
	int (*uevent)(struct device___361 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___361 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___361 *);
	const struct dev_pm_ops___361 *pm;
};

struct class___361 {
	const char *name;
	struct module___323 *owner;
	const struct attribute_group___358 **class_groups;
	const struct attribute_group___358 **dev_groups;
	struct kobject___381 *dev_kobj;
	int (*dev_uevent)(struct device___361 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___361 *, umode_t *);
	void (*class_release)(struct class___361 *);
	void (*dev_release)(struct device___361 *);
	int (*shutdown_pre)(struct device___361 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___361 *);
	const struct dev_pm_ops___361 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct fwnode_operations___282;

struct fwnode_handle___282 {
	struct fwnode_handle___282 *secondary;
	const struct fwnode_operations___282 *ops;
};

struct property___90;

struct device_node___94 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___282 fwnode;
	struct property___90 *properties;
	struct property___90 *deadprops;
	struct device_node___94 *parent;
	struct device_node___94 *child;
	struct device_node___94 *sibling;
	struct kobject___381 kobj;
	long unsigned int _flags;
	void *data;
};

struct dentry_operations___393;

struct super_block___393;

struct dentry___393 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___393 *d_parent;
	struct qstr d_name;
	struct inode___393 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___393 *d_op;
	struct super_block___393 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___393;

struct address_space___393 {
	struct inode___393 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___395 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___393 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___393;

struct block_device___393;

struct cdev___98;

struct inode___393 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___393 *i_op;
	struct super_block___393 *i_sb;
	struct address_space___393 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___395 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___393 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___393 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___393 *i_bdev;
		struct cdev___98 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___393 {
	int (*d_revalidate)(struct dentry___393 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___393 *, unsigned int);
	int (*d_hash)(const struct dentry___393 *, struct qstr *);
	int (*d_compare)(const struct dentry___393 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___393 *);
	int (*d_init)(struct dentry___393 *);
	void (*d_release)(struct dentry___393 *);
	void (*d_prune)(struct dentry___393 *);
	void (*d_iput)(struct dentry___393 *, struct inode___393 *);
	char * (*d_dname)(struct dentry___393 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___394 *);
	int (*d_manage)(const struct path___394 *, bool);
	struct dentry___393 * (*d_real)(struct dentry___393 *, const struct inode___393 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___393;

struct mem_dqinfo___393 {
	struct quota_format_type___393 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___393;

struct quota_info___393 {
	unsigned int flags;
	struct rw_semaphore___395 dqio_sem;
	struct inode___393 *files[3];
	struct mem_dqinfo___393 info[3];
	const struct quota_format_ops___393 *ops[3];
};

struct rcuwait___393 {
	struct task_struct___395 *task;
};

struct percpu_rw_semaphore___393 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___395 rw_sem;
	struct rcuwait___393 writer;
	int readers_block;
};

struct sb_writers___393 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___393 rw_sem[3];
};

struct file_system_type___393;

struct super_operations___393;

struct dquot_operations___393;

struct quotactl_ops___393;

struct super_block___393 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___393 *s_type;
	const struct super_operations___393 *s_op;
	const struct dquot_operations___393 *dq_op;
	const struct quotactl_ops___393 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___393 *s_root;
	struct rw_semaphore___395 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___393 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___393 s_dquot;
	struct sb_writers___393 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___393 *s_d_op;
	int cleancache_poolid;
	struct shrinker___137 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

typedef int (*dev_page_fault_t___382)(struct vm_area_struct___394 *, long unsigned int, const struct page___394 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___382)(struct page___394 *, void *);

struct dev_pagemap___382 {
	dev_page_fault_t___382 page_fault;
	dev_page_free_t___382 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___361 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___394 {
	struct task_struct___395 *task;
	struct core_thread___394 *next;
};

struct core_state___394 {
	atomic_t nr_threads;
	struct core_thread___394 dumper;
	struct completion startup;
};

struct vm_fault___382 {
	struct vm_area_struct___394 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___394 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___394 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___394 prealloc_pte;
};

struct kiocb___393 {
	struct file___393 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___393 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___393 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___393 *ia_file;
};

struct dquot___393 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___393 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___393 {
	int qf_fmt_id;
	const struct quota_format_ops___393 *qf_ops;
	struct module___323 *qf_owner;
	struct quota_format_type___393 *qf_next;
};

struct quota_format_ops___393 {
	int (*check_quota_file)(struct super_block___393 *, int);
	int (*read_file_info)(struct super_block___393 *, int);
	int (*write_file_info)(struct super_block___393 *, int);
	int (*free_file_info)(struct super_block___393 *, int);
	int (*read_dqblk)(struct dquot___393 *);
	int (*commit_dqblk)(struct dquot___393 *);
	int (*release_dqblk)(struct dquot___393 *);
	int (*get_next_id)(struct super_block___393 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___393 {
	int (*write_dquot)(struct dquot___393 *);
	struct dquot___393 * (*alloc_dquot)(struct super_block___393 *, int);
	void (*destroy_dquot)(struct dquot___393 *);
	int (*acquire_dquot)(struct dquot___393 *);
	int (*release_dquot)(struct dquot___393 *);
	int (*mark_dirty)(struct dquot___393 *);
	int (*write_info)(struct super_block___393 *, int);
	qsize_t * (*get_reserved_space)(struct inode___393 *);
	int (*get_projid)(struct inode___393 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___393 *, qsize_t *);
	int (*get_next_id)(struct super_block___393 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___393 {
	int (*quota_on)(struct super_block___393 *, int, int, const struct path___394 *);
	int (*quota_off)(struct super_block___393 *, int);
	int (*quota_enable)(struct super_block___393 *, unsigned int);
	int (*quota_disable)(struct super_block___393 *, unsigned int);
	int (*quota_sync)(struct super_block___393 *, int);
	int (*set_info)(struct super_block___393 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___393 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___393 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___393 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___393 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___393 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___393 {
	int (*writepage)(struct page___394 *, struct writeback_control___3 *);
	int (*readpage)(struct file___393 *, struct page___394 *);
	int (*writepages)(struct address_space___393 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___394 *);
	int (*readpages)(struct file___393 *, struct address_space___393 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___393 *, struct address_space___393 *, loff_t, unsigned int, unsigned int, struct page___394 **, void **);
	int (*write_end)(struct file___393 *, struct address_space___393 *, loff_t, unsigned int, unsigned int, struct page___394 *, void *);
	sector_t (*bmap)(struct address_space___393 *, sector_t);
	void (*invalidatepage)(struct page___394 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___394 *, gfp_t);
	void (*freepage)(struct page___394 *);
	ssize_t (*direct_IO)(struct kiocb___393 *, struct iov_iter___166 *);
	int (*migratepage)(struct address_space___393 *, struct page___394 *, struct page___394 *, enum migrate_mode);
	bool (*isolate_page)(struct page___394 *, isolate_mode_t);
	void (*putback_page)(struct page___394 *);
	int (*launder_page)(struct page___394 *);
	int (*is_partially_uptodate)(struct page___394 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___394 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___393 *, struct page___394 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___393 *, sector_t *);
	void (*swap_deactivate)(struct file___393 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___393 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___393 *bd_inode;
	struct super_block___393 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___393 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___98 {
	struct kobject___381 kobj;
	struct module___323 *owner;
	const struct file_operations___393 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___393 {
	struct dentry___393 * (*lookup)(struct inode___393 *, struct dentry___393 *, unsigned int);
	const char * (*get_link)(struct dentry___393 *, struct inode___393 *, struct delayed_call *);
	int (*permission)(struct inode___393 *, int);
	struct posix_acl * (*get_acl)(struct inode___393 *, int);
	int (*readlink)(struct dentry___393 *, char *, int);
	int (*create)(struct inode___393 *, struct dentry___393 *, umode_t, bool);
	int (*link)(struct dentry___393 *, struct inode___393 *, struct dentry___393 *);
	int (*unlink)(struct inode___393 *, struct dentry___393 *);
	int (*symlink)(struct inode___393 *, struct dentry___393 *, const char *);
	int (*mkdir)(struct inode___393 *, struct dentry___393 *, umode_t);
	int (*rmdir)(struct inode___393 *, struct dentry___393 *);
	int (*mknod)(struct inode___393 *, struct dentry___393 *, umode_t, dev_t);
	int (*rename)(struct inode___393 *, struct dentry___393 *, struct inode___393 *, struct dentry___393 *, unsigned int);
	int (*setattr)(struct dentry___393 *, struct iattr___393 *);
	int (*getattr)(const struct path___394 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___393 *, char *, size_t);
	int (*fiemap)(struct inode___393 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___393 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___393 *, struct dentry___393 *, struct file___393 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___393 *, struct dentry___393 *, umode_t);
	int (*set_acl)(struct inode___393 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___393 {
	void (*fl_copy_lock)(struct file_lock___393 *, struct file_lock___393 *);
	void (*fl_release_private)(struct file_lock___393 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___393;

struct lock_manager_operations___393;

struct file_lock___393 {
	struct file_lock___393 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___393 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___393 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___393 *fl_ops;
	const struct lock_manager_operations___393 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___393 {
	int (*lm_compare_owner)(struct file_lock___393 *, struct file_lock___393 *);
	long unsigned int (*lm_owner_key)(struct file_lock___393 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___393 *);
	int (*lm_grant)(struct file_lock___393 *, int);
	bool (*lm_break)(struct file_lock___393 *);
	int (*lm_change)(struct file_lock___393 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___393 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___393 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___393 *fa_next;
	struct file___393 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___393 {
	const char *name;
	int fs_flags;
	struct dentry___393 * (*mount)(struct file_system_type___393 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___393 *);
	struct module___323 *owner;
	struct file_system_type___393 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___393 {
	struct inode___393 * (*alloc_inode)(struct super_block___393 *);
	void (*destroy_inode)(struct inode___393 *);
	void (*dirty_inode)(struct inode___393 *, int);
	int (*write_inode)(struct inode___393 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___393 *);
	void (*evict_inode)(struct inode___393 *);
	void (*put_super)(struct super_block___393 *);
	int (*sync_fs)(struct super_block___393 *, int);
	int (*freeze_super)(struct super_block___393 *);
	int (*freeze_fs)(struct super_block___393 *);
	int (*thaw_super)(struct super_block___393 *);
	int (*unfreeze_fs)(struct super_block___393 *);
	int (*statfs)(struct dentry___393 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___393 *, int *, char *);
	void (*umount_begin)(struct super_block___393 *);
	int (*show_options)(struct seq_file___335 *, struct dentry___393 *);
	int (*show_devname)(struct seq_file___335 *, struct dentry___393 *);
	int (*show_path)(struct seq_file___335 *, struct dentry___393 *);
	int (*show_stats)(struct seq_file___335 *, struct dentry___393 *);
	ssize_t (*quota_read)(struct super_block___393 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___393 *, int, const char *, size_t, loff_t);
	struct dquot___393 ** (*get_dquots)(struct inode___393 *);
	int (*bdev_try_to_free_page)(struct super_block___393 *, struct page___394 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___393 *, struct shrink_control___137 *);
	long int (*free_cached_objects)(struct super_block___393 *, struct shrink_control___137 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*key_restrict_link_func_t___364)(struct key___363 *, const struct key_type *, const union key_payload *, struct key___363 *);

struct key_restriction___363;

struct key___363 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___395 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___363 *restrict_link;
};

struct key_restriction___363 {
	key_restrict_link_func_t___364 check;
	struct key___363 *key;
	struct key_type *keytype;
};

struct seq_operations___335 {
	void * (*start)(struct seq_file___335 *, loff_t *);
	void (*stop)(struct seq_file___335 *, void *);
	void * (*next)(struct seq_file___335 *, void *, loff_t *);
	int (*show)(struct seq_file___335 *, void *);
};

typedef efi_status_t efi_query_variable_store_t(u32, long unsigned int, bool);

typedef struct {
	efi_guid_t guid;
	u64 table;
} efi_config_table_64_t;

typedef struct {
	efi_guid_t guid;
	u32 table;
} efi_config_table_32_t;

typedef struct {
	efi_guid_t guid;
	const char *name;
	long unsigned int *ptr;
} efi_config_table_type_t;

struct efi_fdt_params {
	u64 system_table;
	u64 mmap;
	u32 mmap_size;
	u32 desc_size;
	u32 desc_ver;
};

typedef struct {
	u32 version;
	u32 length;
	u64 memory_protection_attribute;
} efi_properties_table_t;

struct efivar_operations {
	efi_get_variable_t *get_variable;
	efi_get_next_variable_t *get_next_variable;
	efi_set_variable_t *set_variable;
	efi_set_variable_t *set_variable_nonblocking;
	efi_query_variable_store_t *query_variable_store;
};

struct efivars {
	struct kset___380 *kset;
	struct kobject___381 *kobject;
	const struct efivar_operations *ops;
};

struct efivar_entry___3 {
	struct efi_variable var;
	struct list_head list;
	struct kobject___381 kobj;
	bool scanning;
	bool deleting;
};

struct fwnode_reference_args___282;

struct fwnode_endpoint___282;

struct fwnode_operations___282 {
	struct fwnode_handle___282 * (*get)(struct fwnode_handle___282 *);
	void (*put)(struct fwnode_handle___282 *);
	bool (*device_is_available)(const struct fwnode_handle___282 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___282 *, const struct device___361 *);
	bool (*property_present)(const struct fwnode_handle___282 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___282 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___282 *, const char *, const char **, size_t);
	struct fwnode_handle___282 * (*get_parent)(const struct fwnode_handle___282 *);
	struct fwnode_handle___282 * (*get_next_child_node)(const struct fwnode_handle___282 *, struct fwnode_handle___282 *);
	struct fwnode_handle___282 * (*get_named_child_node)(const struct fwnode_handle___282 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___282 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___282 *);
	struct fwnode_handle___282 * (*graph_get_next_endpoint)(const struct fwnode_handle___282 *, struct fwnode_handle___282 *);
	struct fwnode_handle___282 * (*graph_get_remote_endpoint)(const struct fwnode_handle___282 *);
	struct fwnode_handle___282 * (*graph_get_port_parent)(struct fwnode_handle___282 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___282 *, struct fwnode_endpoint___282 *);
};

struct fwnode_endpoint___282 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___282 *local_fwnode;
};

struct fwnode_reference_args___282 {
	struct fwnode_handle___282 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct property___90 {
	char *name;
	int length;
	void *value;
	struct property___90 *next;
	long unsigned int _flags;
	struct bin_attribute___357 attr;
};

typedef void compound_page_dtor___382(struct page___394 *);

struct kimage___23;

typedef void *kexec_load_t___23(struct kimage___23 *, char *, long unsigned int, char *, long unsigned int, char *, long unsigned int);

struct kexec_file_ops___24 {
	kexec_probe_t *probe;
	kexec_load_t___23 *load;
	kexec_cleanup_t *cleanup;
};

struct kimage___23 {
	kimage_entry_t head;
	kimage_entry_t *entry;
	kimage_entry_t *last_entry;
	long unsigned int start;
	struct page___394 *control_code_page;
	struct page___394 *swap_page;
	void *vmcoreinfo_data_copy;
	long unsigned int nr_segments;
	struct kexec_segment segment[16];
	struct list_head control_pages;
	struct list_head dest_pages;
	struct list_head unusable_pages;
	long unsigned int control_page;
	unsigned int type: 1;
	unsigned int preserve_context: 1;
	unsigned int file_mode: 1;
	struct kimage_arch arch;
	void *kernel_buf;
	long unsigned int kernel_buf_len;
	void *initrd_buf;
	long unsigned int initrd_buf_len;
	char *cmdline_buf;
	long unsigned int cmdline_buf_len;
	const struct kexec_file_ops___24 *fops;
	void *image_loader_data;
	struct purgatory_info purgatory_info;
};

struct params {
	const char name[32];
	const char propname[32];
	int offset;
	int size;
};

struct param_info {
	int found;
	void *params;
	const char *missing;
};

struct efi_generic_dev_path {
	u8 type;
	u8 sub_type;
	u16 length;
};

struct efivars___2 {
	struct kset___55 *kset;
	struct kobject___56 *kobject;
	const struct efivar_operations *ops;
};

struct efivar_entry___4 {
	struct efi_variable var;
	struct list_head list;
	struct kobject___56 kobj;
	bool scanning;
	bool deleting;
};

struct variable_validate {
	efi_guid_t vendor;
	char *name;
	bool (*validate)(efi_char16_t *, int, u8 *, long unsigned int);
};

typedef struct {
	u32 version;
	u32 num_entries;
	u32 desc_size;
	u32 reserved;
	efi_memory_desc_t entry[0];
} efi_memory_attributes_table_t;

typedef int (*efi_memattr_perm_setter)(struct mm_struct___329 *, efi_memory_desc_t *);

typedef struct {
	u64 length;
	u64 data;
} efi_capsule_block_desc_t;

struct efi_memory_map_data {
	phys_addr_t phys_map;
	long unsigned int size;
	long unsigned int desc_version;
	long unsigned int desc_size;
};

struct efi_mem_range {
	struct range range;
	u64 attribute;
};

struct efivar_entry___5 {
	struct efi_variable var;
	struct list_head list;
	struct kobject___298 kobj;
	bool scanning;
	bool deleting;
};

struct compat_efi_variable {
	efi_char16_t VariableName[512];
	efi_guid_t VendorGuid;
	__u32 DataSize;
	__u8 Data[1024];
	__u32 Status;
	__u32 Attributes;
};

struct efivar_attribute {
	struct attribute attr;
	ssize_t (*show)(struct efivar_entry___5 *, char *);
	ssize_t (*store)(struct efivar_entry___5 *, const char *, size_t);
};

struct efi_system_resource_entry_v1 {
	efi_guid_t fw_class;
	u32 fw_type;
	u32 fw_version;
	u32 lowest_supported_fw_version;
	u32 capsule_flags;
	u32 last_attempt_version;
	u32 last_attempt_status;
};

struct efi_system_resource_table {
	u32 fw_resource_count;
	u32 fw_resource_count_max;
	u64 fw_resource_version;
	u8 entries[0];
};

struct esre_entry {
	union {
		struct efi_system_resource_entry_v1 *esre1;
	} esre;
	struct kobject___380 kobj;
	struct list_head list;
};

struct esre_attribute {
	struct attribute attr;
	ssize_t (*show)(struct esre_entry *, char *);
	ssize_t (*store)(struct esre_entry *, const char *, size_t);
};

struct pstore_info___3;

struct pstore_record___3 {
	struct pstore_info___3 *psi;
	enum pstore_type_id type;
	u64 id;
	struct timespec64 time;
	char *buf;
	ssize_t size;
	ssize_t ecc_notice_size;
	int count;
	enum kmsg_dump_reason reason;
	unsigned int part;
	bool compressed;
};

struct pstore_info___3 {
	struct module___251 *owner;
	char *name;
	spinlock_t buf_lock;
	char *buf;
	size_t bufsize;
	struct mutex read_mutex;
	int flags;
	void *data;
	int (*open)(struct pstore_info___3 *);
	int (*close)(struct pstore_info___3 *);
	ssize_t (*read)(struct pstore_record___3 *);
	int (*write)(struct pstore_record___3 *);
	int (*write_user)(struct pstore_record___3 *, const char *);
	int (*erase)(struct pstore_record___3 *);
};

struct cper_sec_proc_generic {
	__u64 validation_bits;
	__u8 proc_type;
	__u8 proc_isa;
	__u8 proc_error_type;
	__u8 operation;
	__u8 flags;
	__u8 level;
	__u16 reserved;
	__u64 cpu_version;
	char cpu_brand[128];
	__u64 proc_id;
	__u64 target_addr;
	__u64 requestor_id;
	__u64 responder_id;
	__u64 ip;
};

struct cper_mem_err_compact {
	__u64 validation_bits;
	__u16 node;
	__u16 card;
	__u16 module;
	__u16 bank;
	__u16 device;
	__u16 row;
	__u16 column;
	__u16 bit_pos;
	__u64 requestor_id;
	__u64 responder_id;
	__u64 target_id;
	__u16 rank;
	__u16 mem_array_handle;
	__u16 mem_dev_handle;
} __attribute__((packed));

struct platform_device_info___7 {
	struct device___275 *parent;
	struct fwnode_handle___209 *fwnode;
	const char *name;
	int id;
	const struct resource *res;
	unsigned int num_res;
	const void *data;
	size_t size_data;
	u64 dma_mask;
	struct property_entry___2 *properties;
};

struct cper_arm_err_info {
	__u8 version;
	__u8 length;
	__u16 validation_bits;
	__u8 type;
	__u16 multiple_error;
	__u8 flags;
	__u64 error_info;
	__u64 virt_fault_addr;
	__u64 physical_fault_addr;
} __attribute__((packed));

struct cper_arm_ctx_info {
	__u16 version;
	__u16 type;
	__u32 size;
};

struct of_timer_irq {
	int irq;
	int index;
	int percpu;
	const char *name;
	long unsigned int flags;
	irq_handler_t handler;
};

struct of_timer_base {
	void *base;
	const char *name;
	int index;
};

struct of_timer_clk {
	struct clk *clk;
	const char *name;
	int index;
	long unsigned int rate;
	long unsigned int period;
};

struct timer_of {
	unsigned int flags;
	struct device_node___93 *np;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct clock_event_device___19 clkevt;
	struct of_timer_base of_base;
	struct of_timer_irq of_irq;
	struct of_timer_clk of_clk;
	void *private_data;
	long: 64;
	long: 64;
};

typedef void (*poll_queue_proc___249)(struct file___392 *, wait_queue_head_t *, struct poll_table_struct___6 *);

typedef int (*of_init_fn_1_ret)(struct device_node___93 *);

struct clocksource_mmio {
	void *reg;
	struct clocksource___2 clksrc;
};

enum arch_timer_reg {
	ARCH_TIMER_REG_CTRL = 0,
	ARCH_TIMER_REG_TVAL = 1,
};

enum arch_timer_spi_nr {
	ARCH_TIMER_PHYS_SPI = 0,
	ARCH_TIMER_VIRT_SPI = 1,
	ARCH_TIMER_MAX_TIMER_SPI = 2,
};

typedef int (*of_init_fn_1_ret___2)(struct device_node___5 *);

typedef void (*poll_queue_proc___250)(struct file___392 *, wait_queue_head_t *, struct poll_table_struct___12 *);

struct arch_timer {
	void *base;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct clock_event_device___19 evt;
};

struct ate_acpi_oem_info {
	char oem_id[7];
	char oem_table_id[9];
	u32 oem_revision;
};

typedef bool (*ate_match_fn_t)(const struct arch_timer_erratum_workaround___19 *, const void *);

struct driver_attribute___6 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___361 *, char *);
	ssize_t (*store)(struct device_driver___361 *, const char *, size_t);
};

struct hid_device_id {
	__u16 bus;
	__u16 group;
	__u32 vendor;
	__u32 product;
	kernel_ulong_t driver_data;
};

struct led_trigger___8;

struct led_classdev___8 {
	const char *name;
	enum led_brightness brightness;
	enum led_brightness max_brightness;
	int flags;
	long unsigned int work_flags;
	void (*brightness_set)(struct led_classdev___8 *, enum led_brightness);
	int (*brightness_set_blocking)(struct led_classdev___8 *, enum led_brightness);
	enum led_brightness (*brightness_get)(struct led_classdev___8 *);
	int (*blink_set)(struct led_classdev___8 *, long unsigned int *, long unsigned int *);
	int (*pattern_set)(struct led_classdev___8 *, struct led_pattern *, u32, int);
	int (*pattern_clear)(struct led_classdev___8 *);
	struct device___361 *dev;
	const struct attribute_group___358 **groups;
	struct list_head node;
	const char *default_trigger;
	long unsigned int blink_delay_on;
	long unsigned int blink_delay_off;
	struct timer_list blink_timer;
	int blink_brightness;
	int new_blink_brightness;
	void (*flash_resume)(struct led_classdev___8 *);
	struct work_struct set_brightness_work;
	int delayed_set_value;
	struct rw_semaphore___395 trigger_lock;
	struct led_trigger___8 *trigger;
	struct list_head trig_list;
	void *trigger_data;
	bool activated;
	struct mutex led_access;
};

struct led_trigger___8 {
	const char *name;
	void (*activate)(struct led_classdev___8 *);
	void (*deactivate)(struct led_classdev___8 *);
	rwlock_t leddev_list_lock;
	struct list_head led_cdevs;
	struct list_head next_trig;
};

struct power_supply___4;

struct power_supply_desc___4 {
	const char *name;
	enum power_supply_type type;
	enum power_supply_usb_type *usb_types;
	size_t num_usb_types;
	enum power_supply_property *properties;
	size_t num_properties;
	int (*get_property)(struct power_supply___4 *, enum power_supply_property, union power_supply_propval *);
	int (*set_property)(struct power_supply___4 *, enum power_supply_property, const union power_supply_propval *);
	int (*property_is_writeable)(struct power_supply___4 *, enum power_supply_property);
	void (*external_power_changed)(struct power_supply___4 *);
	void (*set_charged)(struct power_supply___4 *);
	bool no_thermal;
	int use_for_apm;
};

struct power_supply___4 {
	const struct power_supply_desc___4 *desc;
	char **supplied_to;
	size_t num_supplicants;
	char **supplied_from;
	size_t num_supplies;
	struct device_node___2 *of_node;
	void *drv_data;
	struct device___361 dev;
	struct work_struct changed_work;
	struct delayed_work deferred_register_work;
	spinlock_t changed_lock;
	bool changed;
	bool initialized;
	bool removing;
	atomic_t use_cnt;
	struct thermal_zone_device___5 *tzd;
	struct thermal_cooling_device___5 *tcd;
	struct led_trigger___8 *charging_full_trig;
	char *charging_full_trig_name;
	struct led_trigger___8 *charging_trig;
	char *charging_trig_name;
	struct led_trigger___8 *full_trig;
	char *full_trig_name;
	struct led_trigger___8 *online_trig;
	char *online_trig_name;
	struct led_trigger___8 *charging_blink_full_solid_trig;
	char *charging_blink_full_solid_trig_name;
};

struct hid_item {
	unsigned int format;
	__u8 size;
	__u8 type;
	__u8 tag;
	union {
		__u8 u8;
		__s8 s8;
		__u16 u16;
		__s16 s16;
		__u32 u32;
		__s32 s32;
		__u8 *longdata;
	} data;
};

struct hid_global {
	unsigned int usage_page;
	__s32 logical_minimum;
	__s32 logical_maximum;
	__s32 physical_minimum;
	__s32 physical_maximum;
	__s32 unit_exponent;
	unsigned int unit;
	unsigned int report_id;
	unsigned int report_size;
	unsigned int report_count;
};

struct hid_local {
	unsigned int usage[12288];
	unsigned int collection_index[12288];
	unsigned int usage_index;
	unsigned int usage_minimum;
	unsigned int delimiter_depth;
	unsigned int delimiter_branch;
};

struct hid_collection {
	unsigned int type;
	unsigned int usage;
	unsigned int level;
};

struct hid_usage {
	unsigned int hid;
	unsigned int collection_index;
	unsigned int usage_index;
	__u16 code;
	__u8 type;
	__s8 hat_min;
	__s8 hat_max;
	__s8 hat_dir;
};

struct hid_report;

struct hid_input;

struct hid_field {
	unsigned int physical;
	unsigned int logical;
	unsigned int application;
	struct hid_usage *usage;
	unsigned int maxusage;
	unsigned int flags;
	unsigned int report_offset;
	unsigned int report_size;
	unsigned int report_count;
	unsigned int report_type;
	__s32 *value;
	__s32 logical_minimum;
	__s32 logical_maximum;
	__s32 physical_minimum;
	__s32 physical_maximum;
	__s32 unit_exponent;
	unsigned int unit;
	struct hid_report *report;
	unsigned int index;
	struct hid_input *hidinput;
	__u16 dpad;
};

struct hid_device;

struct hid_report {
	struct list_head list;
	struct list_head hidinput_list;
	unsigned int id;
	unsigned int type;
	unsigned int application;
	struct hid_field *field[256];
	unsigned int maxfield;
	unsigned int size;
	struct hid_device *device;
};

struct hid_input {
	struct list_head list;
	struct hid_report *report;
	struct input_dev *input;
	const char *name;
	bool registered;
	struct list_head reports;
	unsigned int application;
};

enum hid_type {
	HID_TYPE_OTHER = 0,
	HID_TYPE_USBMOUSE = 1,
	HID_TYPE_USBNONE = 2,
};

struct hid_report_enum {
	unsigned int numbered;
	struct list_head report_list;
	struct hid_report *report_id_hash[256];
};

enum hid_battery_status {
	HID_BATTERY_UNKNOWN = 0,
	HID_BATTERY_QUERIED = 1,
	HID_BATTERY_REPORTED = 2,
};

struct hid_driver;

struct hid_ll_driver;

struct hid_device {
	__u8 *dev_rdesc;
	unsigned int dev_rsize;
	__u8 *rdesc;
	unsigned int rsize;
	struct hid_collection *collection;
	unsigned int collection_size;
	unsigned int maxcollection;
	unsigned int maxapplication;
	__u16 bus;
	__u16 group;
	__u32 vendor;
	__u32 product;
	__u32 version;
	enum hid_type type;
	unsigned int country;
	struct hid_report_enum report_enum[3];
	struct work_struct led_work;
	struct semaphore driver_input_lock;
	struct device___361 dev;
	struct hid_driver *driver;
	struct hid_ll_driver *ll_driver;
	struct mutex ll_open_lock;
	unsigned int ll_open_count;
	struct power_supply___4 *battery;
	__s32 battery_capacity;
	__s32 battery_min;
	__s32 battery_max;
	__s32 battery_report_type;
	__s32 battery_report_id;
	enum hid_battery_status battery_status;
	bool battery_avoid_query;
	long unsigned int status;
	unsigned int claimed;
	unsigned int quirks;
	bool io_started;
	struct list_head inputs;
	void *hiddev;
	void *hidraw;
	char name[128];
	char phys[64];
	char uniq[64];
	void *driver_data;
	int (*ff_init)(struct hid_device *);
	int (*hiddev_connect)(struct hid_device *, unsigned int);
	void (*hiddev_disconnect)(struct hid_device *);
	void (*hiddev_hid_event)(struct hid_device *, struct hid_field *, struct hid_usage *, __s32);
	void (*hiddev_report_event)(struct hid_device *, struct hid_report *);
	short unsigned int debug;
	struct dentry___393 *debug_dir;
	struct dentry___393 *debug_rdesc;
	struct dentry___393 *debug_events;
	struct list_head debug_list;
	spinlock_t debug_list_lock;
	wait_queue_head_t debug_wait;
};

struct hid_report_id;

struct hid_usage_id;

struct hid_driver {
	char *name;
	const struct hid_device_id *id_table;
	struct list_head dyn_list;
	spinlock_t dyn_lock;
	bool (*match)(struct hid_device *, bool);
	int (*probe)(struct hid_device *, const struct hid_device_id *);
	void (*remove)(struct hid_device *);
	const struct hid_report_id *report_table;
	int (*raw_event)(struct hid_device *, struct hid_report *, u8 *, int);
	const struct hid_usage_id *usage_table;
	int (*event)(struct hid_device *, struct hid_field *, struct hid_usage *, __s32);
	void (*report)(struct hid_device *, struct hid_report *);
	__u8 * (*report_fixup)(struct hid_device *, __u8 *, unsigned int *);
	int (*input_mapping)(struct hid_device *, struct hid_input *, struct hid_field *, struct hid_usage *, long unsigned int **, int *);
	int (*input_mapped)(struct hid_device *, struct hid_input *, struct hid_field *, struct hid_usage *, long unsigned int **, int *);
	int (*input_configured)(struct hid_device *, struct hid_input *);
	void (*feature_mapping)(struct hid_device *, struct hid_field *, struct hid_usage *);
	int (*suspend)(struct hid_device *, pm_message_t);
	int (*resume)(struct hid_device *);
	int (*reset_resume)(struct hid_device *);
	struct device_driver___361 driver;
};

struct hid_ll_driver {
	int (*start)(struct hid_device *);
	void (*stop)(struct hid_device *);
	int (*open)(struct hid_device *);
	void (*close)(struct hid_device *);
	int (*power)(struct hid_device *, int);
	int (*parse)(struct hid_device *);
	void (*request)(struct hid_device *, struct hid_report *, int);
	int (*wait)(struct hid_device *);
	int (*raw_request)(struct hid_device *, unsigned char, __u8 *, size_t, unsigned char, int);
	int (*output_report)(struct hid_device *, __u8 *, size_t);
	int (*idle)(struct hid_device *, int, int, int);
};

struct hid_parser {
	struct hid_global global;
	struct hid_global global_stack[4];
	unsigned int global_stack_ptr;
	struct hid_local local;
	unsigned int collection_stack[4];
	unsigned int collection_stack_ptr;
	struct hid_device *device;
	unsigned int scan_flags;
};

struct hid_report_id {
	__u32 report_type;
};

struct hid_usage_id {
	__u32 usage_hid;
	__u32 usage_type;
	__u32 usage_code;
};

struct hiddev {
	int minor;
	int exist;
	int open;
	struct mutex existancelock;
	wait_queue_head_t wait;
	struct hid_device *hid;
	struct list_head list;
	spinlock_t list_lock;
	bool initialized;
};

struct hidraw {
	unsigned int minor;
	int exist;
	int open;
	wait_queue_head_t wait;
	struct hid_device *hid;
	struct device___361 *dev;
	spinlock_t list_lock;
	struct list_head list;
};

struct hid_dynid {
	struct list_head list;
	struct hid_device_id id;
};

enum {
	POWER_SUPPLY_SCOPE_UNKNOWN = 0,
	POWER_SUPPLY_SCOPE_SYSTEM = 1,
	POWER_SUPPLY_SCOPE_DEVICE = 2,
};

struct power_supply_config___3 {
	struct device_node___2 *of_node;
	struct fwnode_handle___282 *fwnode;
	void *drv_data;
	char **supplied_to;
	size_t num_supplicants;
};

typedef bool (*hid_usage_cmp_t)(struct hid_usage *, unsigned int, unsigned int);

struct power_supply___5;

struct power_supply_desc___5 {
	const char *name;
	enum power_supply_type type;
	enum power_supply_usb_type *usb_types;
	size_t num_usb_types;
	enum power_supply_property *properties;
	size_t num_properties;
	int (*get_property)(struct power_supply___5 *, enum power_supply_property, union power_supply_propval *);
	int (*set_property)(struct power_supply___5 *, enum power_supply_property, const union power_supply_propval *);
	int (*property_is_writeable)(struct power_supply___5 *, enum power_supply_property);
	void (*external_power_changed)(struct power_supply___5 *);
	void (*set_charged)(struct power_supply___5 *);
	bool no_thermal;
	int use_for_apm;
};

struct power_supply___5 {
	const struct power_supply_desc___5 *desc;
	char **supplied_to;
	size_t num_supplicants;
	char **supplied_from;
	size_t num_supplies;
	struct device_node___2 *of_node;
	void *drv_data;
	struct device___360 dev;
	struct work_struct changed_work;
	struct delayed_work deferred_register_work;
	spinlock_t changed_lock;
	bool changed;
	bool initialized;
	bool removing;
	atomic_t use_cnt;
	struct thermal_zone_device___5 *tzd;
	struct thermal_cooling_device___5 *tcd;
	struct led_trigger___7 *charging_full_trig;
	char *charging_full_trig_name;
	struct led_trigger___7 *charging_trig;
	char *charging_trig_name;
	struct led_trigger___7 *full_trig;
	char *full_trig_name;
	struct led_trigger___7 *online_trig;
	char *online_trig_name;
	struct led_trigger___7 *charging_blink_full_solid_trig;
	char *charging_blink_full_solid_trig_name;
};

struct hid_report___2;

struct hid_input___2;

struct hid_field___2 {
	unsigned int physical;
	unsigned int logical;
	unsigned int application;
	struct hid_usage *usage;
	unsigned int maxusage;
	unsigned int flags;
	unsigned int report_offset;
	unsigned int report_size;
	unsigned int report_count;
	unsigned int report_type;
	__s32 *value;
	__s32 logical_minimum;
	__s32 logical_maximum;
	__s32 physical_minimum;
	__s32 physical_maximum;
	__s32 unit_exponent;
	unsigned int unit;
	struct hid_report___2 *report;
	unsigned int index;
	struct hid_input___2 *hidinput;
	__u16 dpad;
};

struct hid_device___2;

struct hid_report___2 {
	struct list_head list;
	struct list_head hidinput_list;
	unsigned int id;
	unsigned int type;
	unsigned int application;
	struct hid_field___2 *field[256];
	unsigned int maxfield;
	unsigned int size;
	struct hid_device___2 *device;
};

struct hid_input___2 {
	struct list_head list;
	struct hid_report___2 *report;
	struct input_dev___4 *input;
	const char *name;
	bool registered;
	struct list_head reports;
	unsigned int application;
};

struct hid_report_enum___2 {
	unsigned int numbered;
	struct list_head report_list;
	struct hid_report___2 *report_id_hash[256];
};

struct hid_driver___2;

struct hid_ll_driver___2;

struct hid_device___2 {
	__u8 *dev_rdesc;
	unsigned int dev_rsize;
	__u8 *rdesc;
	unsigned int rsize;
	struct hid_collection *collection;
	unsigned int collection_size;
	unsigned int maxcollection;
	unsigned int maxapplication;
	__u16 bus;
	__u16 group;
	__u32 vendor;
	__u32 product;
	__u32 version;
	enum hid_type type;
	unsigned int country;
	struct hid_report_enum___2 report_enum[3];
	struct work_struct led_work;
	struct semaphore driver_input_lock;
	struct device___360 dev;
	struct hid_driver___2 *driver;
	struct hid_ll_driver___2 *ll_driver;
	struct mutex ll_open_lock;
	unsigned int ll_open_count;
	struct power_supply___5 *battery;
	__s32 battery_capacity;
	__s32 battery_min;
	__s32 battery_max;
	__s32 battery_report_type;
	__s32 battery_report_id;
	enum hid_battery_status battery_status;
	bool battery_avoid_query;
	long unsigned int status;
	unsigned int claimed;
	unsigned int quirks;
	bool io_started;
	struct list_head inputs;
	void *hiddev;
	void *hidraw;
	char name[128];
	char phys[64];
	char uniq[64];
	void *driver_data;
	int (*ff_init)(struct hid_device___2 *);
	int (*hiddev_connect)(struct hid_device___2 *, unsigned int);
	void (*hiddev_disconnect)(struct hid_device___2 *);
	void (*hiddev_hid_event)(struct hid_device___2 *, struct hid_field___2 *, struct hid_usage *, __s32);
	void (*hiddev_report_event)(struct hid_device___2 *, struct hid_report___2 *);
	short unsigned int debug;
	struct dentry___392 *debug_dir;
	struct dentry___392 *debug_rdesc;
	struct dentry___392 *debug_events;
	struct list_head debug_list;
	spinlock_t debug_list_lock;
	wait_queue_head_t debug_wait;
};

struct hid_driver___2 {
	char *name;
	const struct hid_device_id *id_table;
	struct list_head dyn_list;
	spinlock_t dyn_lock;
	bool (*match)(struct hid_device___2 *, bool);
	int (*probe)(struct hid_device___2 *, const struct hid_device_id *);
	void (*remove)(struct hid_device___2 *);
	const struct hid_report_id *report_table;
	int (*raw_event)(struct hid_device___2 *, struct hid_report___2 *, u8 *, int);
	const struct hid_usage_id *usage_table;
	int (*event)(struct hid_device___2 *, struct hid_field___2 *, struct hid_usage *, __s32);
	void (*report)(struct hid_device___2 *, struct hid_report___2 *);
	__u8 * (*report_fixup)(struct hid_device___2 *, __u8 *, unsigned int *);
	int (*input_mapping)(struct hid_device___2 *, struct hid_input___2 *, struct hid_field___2 *, struct hid_usage *, long unsigned int **, int *);
	int (*input_mapped)(struct hid_device___2 *, struct hid_input___2 *, struct hid_field___2 *, struct hid_usage *, long unsigned int **, int *);
	int (*input_configured)(struct hid_device___2 *, struct hid_input___2 *);
	void (*feature_mapping)(struct hid_device___2 *, struct hid_field___2 *, struct hid_usage *);
	int (*suspend)(struct hid_device___2 *, pm_message_t);
	int (*resume)(struct hid_device___2 *);
	int (*reset_resume)(struct hid_device___2 *);
	struct device_driver___360 driver;
};

struct hid_ll_driver___2 {
	int (*start)(struct hid_device___2 *);
	void (*stop)(struct hid_device___2 *);
	int (*open)(struct hid_device___2 *);
	void (*close)(struct hid_device___2 *);
	int (*power)(struct hid_device___2 *, int);
	int (*parse)(struct hid_device___2 *);
	void (*request)(struct hid_device___2 *, struct hid_report___2 *, int);
	int (*wait)(struct hid_device___2 *);
	int (*raw_request)(struct hid_device___2 *, unsigned char, __u8 *, size_t, unsigned char, int);
	int (*output_report)(struct hid_device___2 *, __u8 *, size_t);
	int (*idle)(struct hid_device___2 *, int, int, int);
};

struct quirks_list_struct {
	struct hid_device_id hid_bl_item;
	struct list_head node;
};

struct ff_device___7;

struct input_handle___7;

struct input_dev___7 {
	const char *name;
	const char *phys;
	const char *uniq;
	struct input_id id;
	long unsigned int propbit[1];
	long unsigned int evbit[1];
	long unsigned int keybit[12];
	long unsigned int relbit[1];
	long unsigned int absbit[1];
	long unsigned int mscbit[1];
	long unsigned int ledbit[1];
	long unsigned int sndbit[1];
	long unsigned int ffbit[2];
	long unsigned int swbit[1];
	unsigned int hint_events_per_packet;
	unsigned int keycodemax;
	unsigned int keycodesize;
	void *keycode;
	int (*setkeycode)(struct input_dev___7 *, const struct input_keymap_entry *, unsigned int *);
	int (*getkeycode)(struct input_dev___7 *, struct input_keymap_entry *);
	struct ff_device___7 *ff;
	unsigned int repeat_key;
	struct timer_list timer;
	int rep[2];
	struct input_mt *mt;
	struct input_absinfo *absinfo;
	long unsigned int key[12];
	long unsigned int led[1];
	long unsigned int snd[1];
	long unsigned int sw[1];
	int (*open)(struct input_dev___7 *);
	void (*close)(struct input_dev___7 *);
	int (*flush)(struct input_dev___7 *, struct file___379 *);
	int (*event)(struct input_dev___7 *, unsigned int, unsigned int, int);
	struct input_handle___7 *grab;
	spinlock_t event_lock;
	struct mutex mutex;
	unsigned int users;
	bool going_away;
	struct device___346 dev;
	struct list_head h_list;
	struct list_head node;
	unsigned int num_vals;
	unsigned int max_vals;
	struct input_value *vals;
	bool devres_managed;
};

struct ff_device___7 {
	int (*upload)(struct input_dev___7 *, struct ff_effect *, struct ff_effect *);
	int (*erase)(struct input_dev___7 *, int);
	int (*playback)(struct input_dev___7 *, int, int);
	void (*set_gain)(struct input_dev___7 *, u16);
	void (*set_autocenter)(struct input_dev___7 *, u16);
	void (*destroy)(struct ff_device___7 *);
	void *private;
	long unsigned int ffbit[2];
	struct mutex mutex;
	int max_effects;
	struct ff_effect *effects;
	struct file___379 *effect_owners[0];
};

struct input_handler___7;

struct input_handle___7 {
	void *private;
	int open;
	const char *name;
	struct input_dev___7 *dev;
	struct input_handler___7 *handler;
	struct list_head d_node;
	struct list_head h_node;
};

struct input_handler___7 {
	void *private;
	void (*event)(struct input_handle___7 *, unsigned int, unsigned int, int);
	void (*events)(struct input_handle___7 *, const struct input_value *, unsigned int);
	bool (*filter)(struct input_handle___7 *, unsigned int, unsigned int, int);
	bool (*match)(struct input_handler___7 *, struct input_dev___7 *);
	int (*connect)(struct input_handler___7 *, struct input_dev___7 *, const struct input_device_id *);
	void (*disconnect)(struct input_handle___7 *);
	void (*start)(struct input_handle___7 *);
	bool legacy_minors;
	int minor;
	const char *name;
	const struct input_device_id *id_table;
	struct list_head h_list;
	struct list_head node;
};

struct led_trigger___9;

struct led_classdev___9 {
	const char *name;
	enum led_brightness brightness;
	enum led_brightness max_brightness;
	int flags;
	long unsigned int work_flags;
	void (*brightness_set)(struct led_classdev___9 *, enum led_brightness);
	int (*brightness_set_blocking)(struct led_classdev___9 *, enum led_brightness);
	enum led_brightness (*brightness_get)(struct led_classdev___9 *);
	int (*blink_set)(struct led_classdev___9 *, long unsigned int *, long unsigned int *);
	int (*pattern_set)(struct led_classdev___9 *, struct led_pattern *, u32, int);
	int (*pattern_clear)(struct led_classdev___9 *);
	struct device___346 *dev;
	const struct attribute_group___343 **groups;
	struct list_head node;
	const char *default_trigger;
	long unsigned int blink_delay_on;
	long unsigned int blink_delay_off;
	struct timer_list blink_timer;
	int blink_brightness;
	int new_blink_brightness;
	void (*flash_resume)(struct led_classdev___9 *);
	struct work_struct set_brightness_work;
	int delayed_set_value;
	struct rw_semaphore___380 trigger_lock;
	struct led_trigger___9 *trigger;
	struct list_head trig_list;
	void *trigger_data;
	bool activated;
	struct mutex led_access;
};

struct led_trigger___9 {
	const char *name;
	void (*activate)(struct led_classdev___9 *);
	void (*deactivate)(struct led_classdev___9 *);
	rwlock_t leddev_list_lock;
	struct list_head led_cdevs;
	struct list_head next_trig;
};

struct power_supply___6;

struct power_supply_desc___6 {
	const char *name;
	enum power_supply_type type;
	enum power_supply_usb_type *usb_types;
	size_t num_usb_types;
	enum power_supply_property *properties;
	size_t num_properties;
	int (*get_property)(struct power_supply___6 *, enum power_supply_property, union power_supply_propval *);
	int (*set_property)(struct power_supply___6 *, enum power_supply_property, const union power_supply_propval *);
	int (*property_is_writeable)(struct power_supply___6 *, enum power_supply_property);
	void (*external_power_changed)(struct power_supply___6 *);
	void (*set_charged)(struct power_supply___6 *);
	bool no_thermal;
	int use_for_apm;
};

struct power_supply___6 {
	const struct power_supply_desc___6 *desc;
	char **supplied_to;
	size_t num_supplicants;
	char **supplied_from;
	size_t num_supplies;
	struct device_node___2 *of_node;
	void *drv_data;
	struct device___346 dev;
	struct work_struct changed_work;
	struct delayed_work deferred_register_work;
	spinlock_t changed_lock;
	bool changed;
	bool initialized;
	bool removing;
	atomic_t use_cnt;
	struct thermal_zone_device___5 *tzd;
	struct thermal_cooling_device___5 *tcd;
	struct led_trigger___9 *charging_full_trig;
	char *charging_full_trig_name;
	struct led_trigger___9 *charging_trig;
	char *charging_trig_name;
	struct led_trigger___9 *full_trig;
	char *full_trig_name;
	struct led_trigger___9 *online_trig;
	char *online_trig_name;
	struct led_trigger___9 *charging_blink_full_solid_trig;
	char *charging_blink_full_solid_trig_name;
};

struct hid_report___3;

struct hid_input___3;

struct hid_field___3 {
	unsigned int physical;
	unsigned int logical;
	unsigned int application;
	struct hid_usage *usage;
	unsigned int maxusage;
	unsigned int flags;
	unsigned int report_offset;
	unsigned int report_size;
	unsigned int report_count;
	unsigned int report_type;
	__s32 *value;
	__s32 logical_minimum;
	__s32 logical_maximum;
	__s32 physical_minimum;
	__s32 physical_maximum;
	__s32 unit_exponent;
	unsigned int unit;
	struct hid_report___3 *report;
	unsigned int index;
	struct hid_input___3 *hidinput;
	__u16 dpad;
};

struct hid_device___3;

struct hid_report___3 {
	struct list_head list;
	struct list_head hidinput_list;
	unsigned int id;
	unsigned int type;
	unsigned int application;
	struct hid_field___3 *field[256];
	unsigned int maxfield;
	unsigned int size;
	struct hid_device___3 *device;
};

struct hid_input___3 {
	struct list_head list;
	struct hid_report___3 *report;
	struct input_dev___7 *input;
	const char *name;
	bool registered;
	struct list_head reports;
	unsigned int application;
};

struct hid_report_enum___3 {
	unsigned int numbered;
	struct list_head report_list;
	struct hid_report___3 *report_id_hash[256];
};

struct hid_driver___3;

struct hid_ll_driver___3;

struct hid_device___3 {
	__u8 *dev_rdesc;
	unsigned int dev_rsize;
	__u8 *rdesc;
	unsigned int rsize;
	struct hid_collection *collection;
	unsigned int collection_size;
	unsigned int maxcollection;
	unsigned int maxapplication;
	__u16 bus;
	__u16 group;
	__u32 vendor;
	__u32 product;
	__u32 version;
	enum hid_type type;
	unsigned int country;
	struct hid_report_enum___3 report_enum[3];
	struct work_struct led_work;
	struct semaphore driver_input_lock;
	struct device___346 dev;
	struct hid_driver___3 *driver;
	struct hid_ll_driver___3 *ll_driver;
	struct mutex ll_open_lock;
	unsigned int ll_open_count;
	struct power_supply___6 *battery;
	__s32 battery_capacity;
	__s32 battery_min;
	__s32 battery_max;
	__s32 battery_report_type;
	__s32 battery_report_id;
	enum hid_battery_status battery_status;
	bool battery_avoid_query;
	long unsigned int status;
	unsigned int claimed;
	unsigned int quirks;
	bool io_started;
	struct list_head inputs;
	void *hiddev;
	void *hidraw;
	char name[128];
	char phys[64];
	char uniq[64];
	void *driver_data;
	int (*ff_init)(struct hid_device___3 *);
	int (*hiddev_connect)(struct hid_device___3 *, unsigned int);
	void (*hiddev_disconnect)(struct hid_device___3 *);
	void (*hiddev_hid_event)(struct hid_device___3 *, struct hid_field___3 *, struct hid_usage *, __s32);
	void (*hiddev_report_event)(struct hid_device___3 *, struct hid_report___3 *);
	short unsigned int debug;
	struct dentry___378 *debug_dir;
	struct dentry___378 *debug_rdesc;
	struct dentry___378 *debug_events;
	struct list_head debug_list;
	spinlock_t debug_list_lock;
	wait_queue_head_t debug_wait;
};

struct hid_driver___3 {
	char *name;
	const struct hid_device_id *id_table;
	struct list_head dyn_list;
	spinlock_t dyn_lock;
	bool (*match)(struct hid_device___3 *, bool);
	int (*probe)(struct hid_device___3 *, const struct hid_device_id *);
	void (*remove)(struct hid_device___3 *);
	const struct hid_report_id *report_table;
	int (*raw_event)(struct hid_device___3 *, struct hid_report___3 *, u8 *, int);
	const struct hid_usage_id *usage_table;
	int (*event)(struct hid_device___3 *, struct hid_field___3 *, struct hid_usage *, __s32);
	void (*report)(struct hid_device___3 *, struct hid_report___3 *);
	__u8 * (*report_fixup)(struct hid_device___3 *, __u8 *, unsigned int *);
	int (*input_mapping)(struct hid_device___3 *, struct hid_input___3 *, struct hid_field___3 *, struct hid_usage *, long unsigned int **, int *);
	int (*input_mapped)(struct hid_device___3 *, struct hid_input___3 *, struct hid_field___3 *, struct hid_usage *, long unsigned int **, int *);
	int (*input_configured)(struct hid_device___3 *, struct hid_input___3 *);
	void (*feature_mapping)(struct hid_device___3 *, struct hid_field___3 *, struct hid_usage *);
	int (*suspend)(struct hid_device___3 *, pm_message_t);
	int (*resume)(struct hid_device___3 *);
	int (*reset_resume)(struct hid_device___3 *);
	struct device_driver___346 driver;
};

struct hid_ll_driver___3 {
	int (*start)(struct hid_device___3 *);
	void (*stop)(struct hid_device___3 *);
	int (*open)(struct hid_device___3 *);
	void (*close)(struct hid_device___3 *);
	int (*power)(struct hid_device___3 *, int);
	int (*parse)(struct hid_device___3 *);
	void (*request)(struct hid_device___3 *, struct hid_report___3 *, int);
	int (*wait)(struct hid_device___3 *);
	int (*raw_request)(struct hid_device___3 *, unsigned char, __u8 *, size_t, unsigned char, int);
	int (*output_report)(struct hid_device___3 *, __u8 *, size_t);
	int (*idle)(struct hid_device___3 *, int, int, int);
};

struct hid_debug_list {
	struct {
		union {
			struct __kfifo kfifo;
			char *type;
			const char *const_type;
			char (*rectype)[0];
			char *ptr;
			const char *ptr_const;
		};
		char buf[0];
	} hid_debug_fifo;
	struct fasync_struct___378 *fasync;
	struct hid_device___3 *hdev;
	struct list_head node;
	struct mutex read_mutex;
};

struct hid_usage_entry {
	unsigned int page;
	unsigned int usage;
	const char *description;
};

struct module___324;

struct file___394;

struct kiocb___394;

struct poll_table_struct___241;

struct vm_area_struct___395;

struct inode___394;

struct file_lock___394;

struct page___395;

struct file_operations___394 {
	struct module___324 *owner;
	loff_t (*llseek)(struct file___394 *, loff_t, int);
	ssize_t (*read)(struct file___394 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___394 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___394 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___394 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___394 *, bool);
	int (*iterate)(struct file___394 *, struct dir_context *);
	int (*iterate_shared)(struct file___394 *, struct dir_context *);
	__poll_t (*poll)(struct file___394 *, struct poll_table_struct___241 *);
	long int (*unlocked_ioctl)(struct file___394 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___394 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___394 *, struct vm_area_struct___395 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___394 *, struct file___394 *);
	int (*flush)(struct file___394 *, fl_owner_t);
	int (*release)(struct inode___394 *, struct file___394 *);
	int (*fsync)(struct file___394 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___394 *, int);
	int (*lock)(struct file___394 *, int, struct file_lock___394 *);
	ssize_t (*sendpage)(struct file___394 *, struct page___395 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___394 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___394 *, int, struct file_lock___394 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___394 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___394 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___394 *, long int, struct file_lock___394 **, void **);
	long int (*fallocate)(struct file___394 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___394 *);
	ssize_t (*copy_file_range)(struct file___394 *, loff_t, struct file___394 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___394 *, loff_t, struct file___394 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___394 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___395 {
	u64 seqnum;
	struct vm_area_struct___395 *vmas[4];
};

struct page_frag___395 {
	struct page___395 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___395;

struct cred___364;

struct signal_struct___271;

struct task_struct___396 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___396 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___395 *mm;
	struct mm_struct___395 *active_mm;
	struct vmacache___395 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___396 *real_parent;
	struct task_struct___396 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___396 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___227 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___227 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___227 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___364 *ptracer_cred;
	const struct cred___364 *real_cred;
	const struct cred___364 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___271 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___396 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___395 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___396 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___150 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___394;

struct super_block___394;

struct dentry___394 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___394 *d_parent;
	struct qstr d_name;
	struct inode___394 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___394 *d_op;
	struct super_block___394 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct rw_semaphore___396 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___396 *owner;
};

struct address_space_operations___394;

struct address_space___394 {
	struct inode___394 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___396 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___394 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___394;

struct block_device___394;

struct cdev___99;

struct inode___394 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___394 *i_op;
	struct super_block___394 *i_sb;
	struct address_space___394 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___396 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___394 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___394 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___394 *i_bdev;
		struct cdev___99 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___395;

struct dentry_operations___394 {
	int (*d_revalidate)(struct dentry___394 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___394 *, unsigned int);
	int (*d_hash)(const struct dentry___394 *, struct qstr *);
	int (*d_compare)(const struct dentry___394 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___394 *);
	int (*d_init)(struct dentry___394 *);
	void (*d_release)(struct dentry___394 *);
	void (*d_prune)(struct dentry___394 *);
	void (*d_iput)(struct dentry___394 *, struct inode___394 *);
	char * (*d_dname)(struct dentry___394 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___395 *);
	int (*d_manage)(const struct path___395 *, bool);
	struct dentry___394 * (*d_real)(struct dentry___394 *, const struct inode___394 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___394;

struct mem_dqinfo___394 {
	struct quota_format_type___394 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___394;

struct quota_info___394 {
	unsigned int flags;
	struct rw_semaphore___396 dqio_sem;
	struct inode___394 *files[3];
	struct mem_dqinfo___394 info[3];
	const struct quota_format_ops___394 *ops[3];
};

struct rcuwait___394 {
	struct task_struct___396 *task;
};

struct percpu_rw_semaphore___394 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___396 rw_sem;
	struct rcuwait___394 writer;
	int readers_block;
};

struct sb_writers___394 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___394 rw_sem[3];
};

struct file_system_type___394;

struct super_operations___394;

struct dquot_operations___394;

struct quotactl_ops___394;

struct super_block___394 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___394 *s_type;
	const struct super_operations___394 *s_op;
	const struct dquot_operations___394 *dq_op;
	const struct quotactl_ops___394 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___394 *s_root;
	struct rw_semaphore___396 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___394 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___394 s_dquot;
	struct sb_writers___394 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___394 *s_d_op;
	int cleancache_poolid;
	struct shrinker___137 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct path___395 {
	struct vfsmount *mnt;
	struct dentry___394 *dentry;
};

typedef struct page___395 *pgtable_t___395;

struct page___395 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___394 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___395 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___395 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___395 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___382 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___395;

struct lruvec___395 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___395 *pgdat;
};

struct zone___395 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___395 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___395 {
	struct zone___395 *zone;
	int zone_idx;
};

struct zonelist___395 {
	struct zoneref___395 _zonerefs[25];
};

struct pglist_data___395 {
	struct zone___395 node_zones[3];
	struct zonelist___395 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___396 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___396 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___395 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___396 {
	void *stack;
	struct task_struct___396 *task;
	long int status;
};

struct blocking_notifier_head___395 {
	struct rw_semaphore___396 rwsem;
	struct notifier_block *head;
};

struct vm_area_struct___395 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___395 *vm_next;
	struct vm_area_struct___395 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___395 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___13 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___394 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___395;

struct mm_struct___395 {
	struct {
		struct vm_area_struct___395 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___394 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___396 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___395 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___396 *owner;
		struct user_namespace___3 *user_ns;
		struct file___394 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___395 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct file___394 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___395 f_path;
	struct inode___394 *f_inode;
	const struct file_operations___394 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___227 f_owner;
	const struct cred___364 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___394 *f_mapping;
	errseq_t f_wb_err;
};

struct core_thread___395 {
	struct task_struct___396 *task;
	struct core_thread___395 *next;
};

struct core_state___395 {
	atomic_t nr_threads;
	struct core_thread___395 dumper;
	struct completion startup;
};

struct key___364;

struct user_struct___364 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___364 *uid_keyring;
	struct key___364 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___364 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___364 *session_keyring;
	struct key___364 *process_keyring;
	struct key___364 *thread_keyring;
	struct key___364 *request_key_auth;
	void *security;
	struct user_struct___364 *user;
	struct user_namespace___3 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct signal_struct___271 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___396 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___396 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___227 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___227 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___395 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___227 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

union thread_union___283 {
	struct task_struct___396 task;
	long unsigned int stack[8192];
};

struct kiocb___394 {
	struct file___394 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___394 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___394 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___394 *ia_file;
};

struct dquot___394 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___394 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___394 {
	int qf_fmt_id;
	const struct quota_format_ops___394 *qf_ops;
	struct module___324 *qf_owner;
	struct quota_format_type___394 *qf_next;
};

struct quota_format_ops___394 {
	int (*check_quota_file)(struct super_block___394 *, int);
	int (*read_file_info)(struct super_block___394 *, int);
	int (*write_file_info)(struct super_block___394 *, int);
	int (*free_file_info)(struct super_block___394 *, int);
	int (*read_dqblk)(struct dquot___394 *);
	int (*commit_dqblk)(struct dquot___394 *);
	int (*release_dqblk)(struct dquot___394 *);
	int (*get_next_id)(struct super_block___394 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___394 {
	int (*write_dquot)(struct dquot___394 *);
	struct dquot___394 * (*alloc_dquot)(struct super_block___394 *, int);
	void (*destroy_dquot)(struct dquot___394 *);
	int (*acquire_dquot)(struct dquot___394 *);
	int (*release_dquot)(struct dquot___394 *);
	int (*mark_dirty)(struct dquot___394 *);
	int (*write_info)(struct super_block___394 *, int);
	qsize_t * (*get_reserved_space)(struct inode___394 *);
	int (*get_projid)(struct inode___394 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___394 *, qsize_t *);
	int (*get_next_id)(struct super_block___394 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___394 {
	int (*quota_on)(struct super_block___394 *, int, int, const struct path___395 *);
	int (*quota_off)(struct super_block___394 *, int);
	int (*quota_enable)(struct super_block___394 *, unsigned int);
	int (*quota_disable)(struct super_block___394 *, unsigned int);
	int (*quota_sync)(struct super_block___394 *, int);
	int (*set_info)(struct super_block___394 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___394 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___394 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___394 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___394 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___394 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___381;

struct kobj_type___381;

struct kernfs_node___389;

struct kobject___382 {
	const char *name;
	struct list_head entry;
	struct kobject___382 *parent;
	struct kset___381 *kset;
	struct kobj_type___381 *ktype;
	struct kernfs_node___389 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___322 {
	struct kobject___382 kobj;
	struct module___324 *mod;
	struct kobject___382 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___322 {
	struct module___324 *mod;
	struct latch_tree_node node;
};

struct module_layout___322 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___322 mtn;
};

struct module_attribute___322;

struct kernel_param___322;

struct module___324 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___322 mkobj;
	struct module_attribute___322 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___382 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___322 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___322 core_layout;
	struct module_layout___322 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___394 {
	int (*writepage)(struct page___395 *, struct writeback_control___3 *);
	int (*readpage)(struct file___394 *, struct page___395 *);
	int (*writepages)(struct address_space___394 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___395 *);
	int (*readpages)(struct file___394 *, struct address_space___394 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___394 *, struct address_space___394 *, loff_t, unsigned int, unsigned int, struct page___395 **, void **);
	int (*write_end)(struct file___394 *, struct address_space___394 *, loff_t, unsigned int, unsigned int, struct page___395 *, void *);
	sector_t (*bmap)(struct address_space___394 *, sector_t);
	void (*invalidatepage)(struct page___395 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___395 *, gfp_t);
	void (*freepage)(struct page___395 *);
	ssize_t (*direct_IO)(struct kiocb___394 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___394 *, struct page___395 *, struct page___395 *, enum migrate_mode);
	bool (*isolate_page)(struct page___395 *, isolate_mode_t);
	void (*putback_page)(struct page___395 *);
	int (*launder_page)(struct page___395 *);
	int (*is_partially_uptodate)(struct page___395 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___395 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___394 *, struct page___395 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___394 *, sector_t *);
	void (*swap_deactivate)(struct file___394 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___394 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___394 *bd_inode;
	struct super_block___394 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___394 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___99 {
	struct kobject___382 kobj;
	struct module___324 *owner;
	const struct file_operations___394 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___394 {
	struct dentry___394 * (*lookup)(struct inode___394 *, struct dentry___394 *, unsigned int);
	const char * (*get_link)(struct dentry___394 *, struct inode___394 *, struct delayed_call *);
	int (*permission)(struct inode___394 *, int);
	struct posix_acl * (*get_acl)(struct inode___394 *, int);
	int (*readlink)(struct dentry___394 *, char *, int);
	int (*create)(struct inode___394 *, struct dentry___394 *, umode_t, bool);
	int (*link)(struct dentry___394 *, struct inode___394 *, struct dentry___394 *);
	int (*unlink)(struct inode___394 *, struct dentry___394 *);
	int (*symlink)(struct inode___394 *, struct dentry___394 *, const char *);
	int (*mkdir)(struct inode___394 *, struct dentry___394 *, umode_t);
	int (*rmdir)(struct inode___394 *, struct dentry___394 *);
	int (*mknod)(struct inode___394 *, struct dentry___394 *, umode_t, dev_t);
	int (*rename)(struct inode___394 *, struct dentry___394 *, struct inode___394 *, struct dentry___394 *, unsigned int);
	int (*setattr)(struct dentry___394 *, struct iattr___394 *);
	int (*getattr)(const struct path___395 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___394 *, char *, size_t);
	int (*fiemap)(struct inode___394 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___394 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___394 *, struct dentry___394 *, struct file___394 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___394 *, struct dentry___394 *, umode_t);
	int (*set_acl)(struct inode___394 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___394 {
	void (*fl_copy_lock)(struct file_lock___394 *, struct file_lock___394 *);
	void (*fl_release_private)(struct file_lock___394 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___394;

struct lock_manager_operations___394;

struct file_lock___394 {
	struct file_lock___394 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___394 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___394 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___394 *fl_ops;
	const struct lock_manager_operations___394 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___394 {
	int (*lm_compare_owner)(struct file_lock___394 *, struct file_lock___394 *);
	long unsigned int (*lm_owner_key)(struct file_lock___394 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___394 *);
	int (*lm_grant)(struct file_lock___394 *, int);
	bool (*lm_break)(struct file_lock___394 *);
	int (*lm_change)(struct file_lock___394 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___394 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___394 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___394 *fa_next;
	struct file___394 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___394 {
	const char *name;
	int fs_flags;
	struct dentry___394 * (*mount)(struct file_system_type___394 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___394 *);
	struct module___324 *owner;
	struct file_system_type___394 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___394 {
	struct inode___394 * (*alloc_inode)(struct super_block___394 *);
	void (*destroy_inode)(struct inode___394 *);
	void (*dirty_inode)(struct inode___394 *, int);
	int (*write_inode)(struct inode___394 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___394 *);
	void (*evict_inode)(struct inode___394 *);
	void (*put_super)(struct super_block___394 *);
	int (*sync_fs)(struct super_block___394 *, int);
	int (*freeze_super)(struct super_block___394 *);
	int (*freeze_fs)(struct super_block___394 *);
	int (*thaw_super)(struct super_block___394 *);
	int (*unfreeze_fs)(struct super_block___394 *);
	int (*statfs)(struct dentry___394 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___394 *, int *, char *);
	void (*umount_begin)(struct super_block___394 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___394 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___394 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___394 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___394 *);
	ssize_t (*quota_read)(struct super_block___394 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___394 *, int, const char *, size_t, loff_t);
	struct dquot___394 ** (*get_dquots)(struct inode___394 *);
	int (*bdev_try_to_free_page)(struct super_block___394 *, struct page___395 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___394 *, struct shrink_control___137 *);
	long int (*free_cached_objects)(struct super_block___394 *, struct shrink_control___137 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___251)(struct file___394 *, wait_queue_head_t *, struct poll_table_struct___241 *);

struct poll_table_struct___241 {
	poll_queue_proc___251 _qproc;
	__poll_t _key;
};

struct kernfs_root___388;

struct kernfs_elem_dir___388 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___388 *root;
};

struct kernfs_syscall_ops___388;

struct kernfs_root___388 {
	struct kernfs_node___389 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___388 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___388 {
	struct kernfs_node___389 *target_kn;
};

struct kernfs_ops___388;

struct kernfs_elem_attr___388 {
	const struct kernfs_ops___388 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___389 *notify_next;
};

struct kernfs_node___389 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___389 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___388 dir;
		struct kernfs_elem_symlink___388 symlink;
		struct kernfs_elem_attr___388 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___388;

struct kernfs_ops___388 {
	int (*open)(struct kernfs_open_file___388 *);
	void (*release)(struct kernfs_open_file___388 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___388 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___388 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___388 *, struct vm_area_struct___395 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___388 *, struct poll_table_struct___241 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___388 {
	int (*remount_fs)(struct kernfs_root___388 *, int *, char *);
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___388 *);
	int (*mkdir)(struct kernfs_node___389 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___389 *);
	int (*rename)(struct kernfs_node___389 *, struct kernfs_node___389 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___389 *, struct kernfs_root___388 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___388 {
	struct kernfs_node___389 *kn;
	struct file___394 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___13 *vm_ops;
};

struct bin_attribute___358;

struct attribute_group___359 {
	const char *name;
	umode_t (*is_visible)(struct kobject___382 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___382 *, struct bin_attribute___358 *, int);
	struct attribute **attrs;
	struct bin_attribute___358 **bin_attrs;
};

struct bin_attribute___358 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___394 *, struct kobject___382 *, struct bin_attribute___358 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___394 *, struct kobject___382 *, struct bin_attribute___358 *, char *, loff_t, size_t);
	int (*mmap)(struct file___394 *, struct kobject___382 *, struct bin_attribute___358 *, struct vm_area_struct___395 *);
};

struct sysfs_ops___381 {
	ssize_t (*show)(struct kobject___382 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___382 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___381;

struct kset___381 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___382 kobj;
	const struct kset_uevent_ops___381 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___381 {
	void (*release)(struct kobject___382 *);
	const struct sysfs_ops___381 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___29 * (*child_ns_type)(struct kobject___382 *);
	const void * (*namespace)(struct kobject___382 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___381 {
	int (* const filter)(struct kset___381 *, struct kobject___382 *);
	const char * (* const name)(struct kset___381 *, struct kobject___382 *);
	int (* const uevent)(struct kset___381 *, struct kobject___382 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___322 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___322 *);
	int (*get)(char *, const struct kernel_param___322 *);
	void (*free)(void *);
};

struct kparam_array___322;

struct kernel_param___322 {
	const char *name;
	struct module___324 *mod;
	const struct kernel_param_ops___322 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___322 *arr;
	};
};

struct kparam_array___322 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___322 *ops;
	void *elem;
};

struct module_attribute___322 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___322 *, struct module_kobject___322 *, char *);
	ssize_t (*store)(struct module_attribute___322 *, struct module_kobject___322 *, const char *, size_t);
	void (*setup)(struct module___324 *, const char *);
	int (*test)(struct module___324 *);
	void (*free)(struct module___324 *);
};

struct device___362;

struct dev_pm_ops___362 {
	int (*prepare)(struct device___362 *);
	void (*complete)(struct device___362 *);
	int (*suspend)(struct device___362 *);
	int (*resume)(struct device___362 *);
	int (*freeze)(struct device___362 *);
	int (*thaw)(struct device___362 *);
	int (*poweroff)(struct device___362 *);
	int (*restore)(struct device___362 *);
	int (*suspend_late)(struct device___362 *);
	int (*resume_early)(struct device___362 *);
	int (*freeze_late)(struct device___362 *);
	int (*thaw_early)(struct device___362 *);
	int (*poweroff_late)(struct device___362 *);
	int (*restore_early)(struct device___362 *);
	int (*suspend_noirq)(struct device___362 *);
	int (*resume_noirq)(struct device___362 *);
	int (*freeze_noirq)(struct device___362 *);
	int (*thaw_noirq)(struct device___362 *);
	int (*poweroff_noirq)(struct device___362 *);
	int (*restore_noirq)(struct device___362 *);
	int (*runtime_suspend)(struct device___362 *);
	int (*runtime_resume)(struct device___362 *);
	int (*runtime_idle)(struct device___362 *);
};

struct dev_pm_info___362 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___362 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___362;

struct bus_type___362;

struct device_driver___362;

struct dev_pm_domain___362;

struct class___362;

struct device___362 {
	struct device___362 *parent;
	struct device_private *p;
	struct kobject___382 kobj;
	const char *init_name;
	const struct device_type___362 *type;
	struct mutex mutex;
	struct bus_type___362 *bus;
	struct device_driver___362 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___362 power;
	struct dev_pm_domain___362 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___362 *class;
	const struct attribute_group___359 **groups;
	void (*release)(struct device___362 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___362 {
	struct dev_pm_ops___362 ops;
	void (*detach)(struct device___362 *, bool);
	int (*activate)(struct device___362 *);
	void (*sync)(struct device___362 *);
	void (*dismiss)(struct device___362 *);
};

struct bus_type___362 {
	const char *name;
	const char *dev_name;
	struct device___362 *dev_root;
	const struct attribute_group___359 **bus_groups;
	const struct attribute_group___359 **dev_groups;
	const struct attribute_group___359 **drv_groups;
	int (*match)(struct device___362 *, struct device_driver___362 *);
	int (*uevent)(struct device___362 *, struct kobj_uevent_env *);
	int (*probe)(struct device___362 *);
	int (*remove)(struct device___362 *);
	void (*shutdown)(struct device___362 *);
	int (*online)(struct device___362 *);
	int (*offline)(struct device___362 *);
	int (*suspend)(struct device___362 *, pm_message_t);
	int (*resume)(struct device___362 *);
	int (*num_vf)(struct device___362 *);
	int (*dma_configure)(struct device___362 *);
	const struct dev_pm_ops___362 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___362 {
	const char *name;
	struct bus_type___362 *bus;
	struct module___324 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___362 *);
	int (*remove)(struct device___362 *);
	void (*shutdown)(struct device___362 *);
	int (*suspend)(struct device___362 *, pm_message_t);
	int (*resume)(struct device___362 *);
	const struct attribute_group___359 **groups;
	const struct dev_pm_ops___362 *pm;
	void (*coredump)(struct device___362 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___362 {
	const char *name;
	const struct attribute_group___359 **groups;
	int (*uevent)(struct device___362 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___362 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___362 *);
	const struct dev_pm_ops___362 *pm;
};

struct class___362 {
	const char *name;
	struct module___324 *owner;
	const struct attribute_group___359 **class_groups;
	const struct attribute_group___359 **dev_groups;
	struct kobject___382 *dev_kobj;
	int (*dev_uevent)(struct device___362 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___362 *, umode_t *);
	void (*class_release)(struct class___362 *);
	void (*dev_release)(struct device___362 *);
	int (*shutdown_pre)(struct device___362 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___362 *);
	const struct dev_pm_ops___362 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

typedef struct poll_table_struct___241 poll_table___40;

struct ff_device___8;

struct input_handle___8;

struct input_dev___8 {
	const char *name;
	const char *phys;
	const char *uniq;
	struct input_id id;
	long unsigned int propbit[1];
	long unsigned int evbit[1];
	long unsigned int keybit[12];
	long unsigned int relbit[1];
	long unsigned int absbit[1];
	long unsigned int mscbit[1];
	long unsigned int ledbit[1];
	long unsigned int sndbit[1];
	long unsigned int ffbit[2];
	long unsigned int swbit[1];
	unsigned int hint_events_per_packet;
	unsigned int keycodemax;
	unsigned int keycodesize;
	void *keycode;
	int (*setkeycode)(struct input_dev___8 *, const struct input_keymap_entry *, unsigned int *);
	int (*getkeycode)(struct input_dev___8 *, struct input_keymap_entry *);
	struct ff_device___8 *ff;
	unsigned int repeat_key;
	struct timer_list timer;
	int rep[2];
	struct input_mt *mt;
	struct input_absinfo *absinfo;
	long unsigned int key[12];
	long unsigned int led[1];
	long unsigned int snd[1];
	long unsigned int sw[1];
	int (*open)(struct input_dev___8 *);
	void (*close)(struct input_dev___8 *);
	int (*flush)(struct input_dev___8 *, struct file___394 *);
	int (*event)(struct input_dev___8 *, unsigned int, unsigned int, int);
	struct input_handle___8 *grab;
	spinlock_t event_lock;
	struct mutex mutex;
	unsigned int users;
	bool going_away;
	struct device___362 dev;
	struct list_head h_list;
	struct list_head node;
	unsigned int num_vals;
	unsigned int max_vals;
	struct input_value *vals;
	bool devres_managed;
};

struct ff_device___8 {
	int (*upload)(struct input_dev___8 *, struct ff_effect *, struct ff_effect *);
	int (*erase)(struct input_dev___8 *, int);
	int (*playback)(struct input_dev___8 *, int, int);
	void (*set_gain)(struct input_dev___8 *, u16);
	void (*set_autocenter)(struct input_dev___8 *, u16);
	void (*destroy)(struct ff_device___8 *);
	void *private;
	long unsigned int ffbit[2];
	struct mutex mutex;
	int max_effects;
	struct ff_effect *effects;
	struct file___394 *effect_owners[0];
};

struct input_handler___8;

struct input_handle___8 {
	void *private;
	int open;
	const char *name;
	struct input_dev___8 *dev;
	struct input_handler___8 *handler;
	struct list_head d_node;
	struct list_head h_node;
};

struct input_handler___8 {
	void *private;
	void (*event)(struct input_handle___8 *, unsigned int, unsigned int, int);
	void (*events)(struct input_handle___8 *, const struct input_value *, unsigned int);
	bool (*filter)(struct input_handle___8 *, unsigned int, unsigned int, int);
	bool (*match)(struct input_handler___8 *, struct input_dev___8 *);
	int (*connect)(struct input_handler___8 *, struct input_dev___8 *, const struct input_device_id *);
	void (*disconnect)(struct input_handle___8 *);
	void (*start)(struct input_handle___8 *);
	bool legacy_minors;
	int minor;
	const char *name;
	const struct input_device_id *id_table;
	struct list_head h_list;
	struct list_head node;
};

struct led_trigger___10;

struct led_classdev___10 {
	const char *name;
	enum led_brightness brightness;
	enum led_brightness max_brightness;
	int flags;
	long unsigned int work_flags;
	void (*brightness_set)(struct led_classdev___10 *, enum led_brightness);
	int (*brightness_set_blocking)(struct led_classdev___10 *, enum led_brightness);
	enum led_brightness (*brightness_get)(struct led_classdev___10 *);
	int (*blink_set)(struct led_classdev___10 *, long unsigned int *, long unsigned int *);
	int (*pattern_set)(struct led_classdev___10 *, struct led_pattern *, u32, int);
	int (*pattern_clear)(struct led_classdev___10 *);
	struct device___362 *dev;
	const struct attribute_group___359 **groups;
	struct list_head node;
	const char *default_trigger;
	long unsigned int blink_delay_on;
	long unsigned int blink_delay_off;
	struct timer_list blink_timer;
	int blink_brightness;
	int new_blink_brightness;
	void (*flash_resume)(struct led_classdev___10 *);
	struct work_struct set_brightness_work;
	int delayed_set_value;
	struct rw_semaphore___396 trigger_lock;
	struct led_trigger___10 *trigger;
	struct list_head trig_list;
	void *trigger_data;
	bool activated;
	struct mutex led_access;
};

struct led_trigger___10 {
	const char *name;
	void (*activate)(struct led_classdev___10 *);
	void (*deactivate)(struct led_classdev___10 *);
	rwlock_t leddev_list_lock;
	struct list_head led_cdevs;
	struct list_head next_trig;
};

struct power_supply___7;

struct power_supply_desc___7 {
	const char *name;
	enum power_supply_type type;
	enum power_supply_usb_type *usb_types;
	size_t num_usb_types;
	enum power_supply_property *properties;
	size_t num_properties;
	int (*get_property)(struct power_supply___7 *, enum power_supply_property, union power_supply_propval *);
	int (*set_property)(struct power_supply___7 *, enum power_supply_property, const union power_supply_propval *);
	int (*property_is_writeable)(struct power_supply___7 *, enum power_supply_property);
	void (*external_power_changed)(struct power_supply___7 *);
	void (*set_charged)(struct power_supply___7 *);
	bool no_thermal;
	int use_for_apm;
};

struct power_supply___7 {
	const struct power_supply_desc___7 *desc;
	char **supplied_to;
	size_t num_supplicants;
	char **supplied_from;
	size_t num_supplies;
	struct device_node___2 *of_node;
	void *drv_data;
	struct device___362 dev;
	struct work_struct changed_work;
	struct delayed_work deferred_register_work;
	spinlock_t changed_lock;
	bool changed;
	bool initialized;
	bool removing;
	atomic_t use_cnt;
	struct thermal_zone_device___5 *tzd;
	struct thermal_cooling_device___5 *tcd;
	struct led_trigger___10 *charging_full_trig;
	char *charging_full_trig_name;
	struct led_trigger___10 *charging_trig;
	char *charging_trig_name;
	struct led_trigger___10 *full_trig;
	char *full_trig_name;
	struct led_trigger___10 *online_trig;
	char *online_trig_name;
	struct led_trigger___10 *charging_blink_full_solid_trig;
	char *charging_blink_full_solid_trig_name;
};

struct hid_report___4;

struct hid_input___4;

struct hid_field___4 {
	unsigned int physical;
	unsigned int logical;
	unsigned int application;
	struct hid_usage *usage;
	unsigned int maxusage;
	unsigned int flags;
	unsigned int report_offset;
	unsigned int report_size;
	unsigned int report_count;
	unsigned int report_type;
	__s32 *value;
	__s32 logical_minimum;
	__s32 logical_maximum;
	__s32 physical_minimum;
	__s32 physical_maximum;
	__s32 unit_exponent;
	unsigned int unit;
	struct hid_report___4 *report;
	unsigned int index;
	struct hid_input___4 *hidinput;
	__u16 dpad;
};

struct hid_device___4;

struct hid_report___4 {
	struct list_head list;
	struct list_head hidinput_list;
	unsigned int id;
	unsigned int type;
	unsigned int application;
	struct hid_field___4 *field[256];
	unsigned int maxfield;
	unsigned int size;
	struct hid_device___4 *device;
};

struct hid_input___4 {
	struct list_head list;
	struct hid_report___4 *report;
	struct input_dev___8 *input;
	const char *name;
	bool registered;
	struct list_head reports;
	unsigned int application;
};

struct hid_report_enum___4 {
	unsigned int numbered;
	struct list_head report_list;
	struct hid_report___4 *report_id_hash[256];
};

struct hid_driver___4;

struct hid_ll_driver___4;

struct hid_device___4 {
	__u8 *dev_rdesc;
	unsigned int dev_rsize;
	__u8 *rdesc;
	unsigned int rsize;
	struct hid_collection *collection;
	unsigned int collection_size;
	unsigned int maxcollection;
	unsigned int maxapplication;
	__u16 bus;
	__u16 group;
	__u32 vendor;
	__u32 product;
	__u32 version;
	enum hid_type type;
	unsigned int country;
	struct hid_report_enum___4 report_enum[3];
	struct work_struct led_work;
	struct semaphore driver_input_lock;
	struct device___362 dev;
	struct hid_driver___4 *driver;
	struct hid_ll_driver___4 *ll_driver;
	struct mutex ll_open_lock;
	unsigned int ll_open_count;
	struct power_supply___7 *battery;
	__s32 battery_capacity;
	__s32 battery_min;
	__s32 battery_max;
	__s32 battery_report_type;
	__s32 battery_report_id;
	enum hid_battery_status battery_status;
	bool battery_avoid_query;
	long unsigned int status;
	unsigned int claimed;
	unsigned int quirks;
	bool io_started;
	struct list_head inputs;
	void *hiddev;
	void *hidraw;
	char name[128];
	char phys[64];
	char uniq[64];
	void *driver_data;
	int (*ff_init)(struct hid_device___4 *);
	int (*hiddev_connect)(struct hid_device___4 *, unsigned int);
	void (*hiddev_disconnect)(struct hid_device___4 *);
	void (*hiddev_hid_event)(struct hid_device___4 *, struct hid_field___4 *, struct hid_usage *, __s32);
	void (*hiddev_report_event)(struct hid_device___4 *, struct hid_report___4 *);
	short unsigned int debug;
	struct dentry___394 *debug_dir;
	struct dentry___394 *debug_rdesc;
	struct dentry___394 *debug_events;
	struct list_head debug_list;
	spinlock_t debug_list_lock;
	wait_queue_head_t debug_wait;
};

struct hid_driver___4 {
	char *name;
	const struct hid_device_id *id_table;
	struct list_head dyn_list;
	spinlock_t dyn_lock;
	bool (*match)(struct hid_device___4 *, bool);
	int (*probe)(struct hid_device___4 *, const struct hid_device_id *);
	void (*remove)(struct hid_device___4 *);
	const struct hid_report_id *report_table;
	int (*raw_event)(struct hid_device___4 *, struct hid_report___4 *, u8 *, int);
	const struct hid_usage_id *usage_table;
	int (*event)(struct hid_device___4 *, struct hid_field___4 *, struct hid_usage *, __s32);
	void (*report)(struct hid_device___4 *, struct hid_report___4 *);
	__u8 * (*report_fixup)(struct hid_device___4 *, __u8 *, unsigned int *);
	int (*input_mapping)(struct hid_device___4 *, struct hid_input___4 *, struct hid_field___4 *, struct hid_usage *, long unsigned int **, int *);
	int (*input_mapped)(struct hid_device___4 *, struct hid_input___4 *, struct hid_field___4 *, struct hid_usage *, long unsigned int **, int *);
	int (*input_configured)(struct hid_device___4 *, struct hid_input___4 *);
	void (*feature_mapping)(struct hid_device___4 *, struct hid_field___4 *, struct hid_usage *);
	int (*suspend)(struct hid_device___4 *, pm_message_t);
	int (*resume)(struct hid_device___4 *);
	int (*reset_resume)(struct hid_device___4 *);
	struct device_driver___362 driver;
};

struct hid_ll_driver___4 {
	int (*start)(struct hid_device___4 *);
	void (*stop)(struct hid_device___4 *);
	int (*open)(struct hid_device___4 *);
	void (*close)(struct hid_device___4 *);
	int (*power)(struct hid_device___4 *, int);
	int (*parse)(struct hid_device___4 *);
	void (*request)(struct hid_device___4 *, struct hid_report___4 *, int);
	int (*wait)(struct hid_device___4 *);
	int (*raw_request)(struct hid_device___4 *, unsigned char, __u8 *, size_t, unsigned char, int);
	int (*output_report)(struct hid_device___4 *, __u8 *, size_t);
	int (*idle)(struct hid_device___4 *, int, int, int);
};

typedef int (*key_restrict_link_func_t___365)(struct key___364 *, const struct key_type *, const union key_payload *, struct key___364 *);

struct key_restriction___364;

struct key___364 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___396 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___364 *restrict_link;
};

struct key_restriction___364 {
	key_restrict_link_func_t___365 check;
	struct key___364 *key;
	struct key_type *keytype;
};

struct hidraw_devinfo {
	__u32 bustype;
	__s16 vendor;
	__s16 product;
};

struct hidraw___2 {
	unsigned int minor;
	int exist;
	int open;
	wait_queue_head_t wait;
	struct hid_device___4 *hid;
	struct device___362 *dev;
	spinlock_t list_lock;
	struct list_head list;
};

struct hidraw_report {
	__u8 *value;
	int len;
};

struct hidraw_list {
	struct hidraw_report buffer[64];
	int head;
	int tail;
	struct fasync_struct___394 *fasync;
	struct hidraw___2 *hidraw;
	struct list_head node;
	struct mutex read_mutex;
};

struct magicmouse_sc {
	struct input_dev___4 *input;
	long unsigned int quirks;
	int ntouches;
	int scroll_accel;
	long unsigned int scroll_jiffies;
	struct {
		short int x;
		short int y;
		short int scroll_x;
		short int scroll_y;
		u8 size;
	} touches[16];
	int tracking_ids[16];
};

struct ff_device___9;

struct input_handle___9;

struct input_dev___9 {
	const char *name;
	const char *phys;
	const char *uniq;
	struct input_id id;
	long unsigned int propbit[1];
	long unsigned int evbit[1];
	long unsigned int keybit[12];
	long unsigned int relbit[1];
	long unsigned int absbit[1];
	long unsigned int mscbit[1];
	long unsigned int ledbit[1];
	long unsigned int sndbit[1];
	long unsigned int ffbit[2];
	long unsigned int swbit[1];
	unsigned int hint_events_per_packet;
	unsigned int keycodemax;
	unsigned int keycodesize;
	void *keycode;
	int (*setkeycode)(struct input_dev___9 *, const struct input_keymap_entry *, unsigned int *);
	int (*getkeycode)(struct input_dev___9 *, struct input_keymap_entry *);
	struct ff_device___9 *ff;
	unsigned int repeat_key;
	struct timer_list timer;
	int rep[2];
	struct input_mt *mt;
	struct input_absinfo *absinfo;
	long unsigned int key[12];
	long unsigned int led[1];
	long unsigned int snd[1];
	long unsigned int sw[1];
	int (*open)(struct input_dev___9 *);
	void (*close)(struct input_dev___9 *);
	int (*flush)(struct input_dev___9 *, struct file___381 *);
	int (*event)(struct input_dev___9 *, unsigned int, unsigned int, int);
	struct input_handle___9 *grab;
	spinlock_t event_lock;
	struct mutex mutex;
	unsigned int users;
	bool going_away;
	struct device___348 dev;
	struct list_head h_list;
	struct list_head node;
	unsigned int num_vals;
	unsigned int max_vals;
	struct input_value *vals;
	bool devres_managed;
};

struct ff_device___9 {
	int (*upload)(struct input_dev___9 *, struct ff_effect *, struct ff_effect *);
	int (*erase)(struct input_dev___9 *, int);
	int (*playback)(struct input_dev___9 *, int, int);
	void (*set_gain)(struct input_dev___9 *, u16);
	void (*set_autocenter)(struct input_dev___9 *, u16);
	void (*destroy)(struct ff_device___9 *);
	void *private;
	long unsigned int ffbit[2];
	struct mutex mutex;
	int max_effects;
	struct ff_effect *effects;
	struct file___381 *effect_owners[0];
};

struct input_handler___9;

struct input_handle___9 {
	void *private;
	int open;
	const char *name;
	struct input_dev___9 *dev;
	struct input_handler___9 *handler;
	struct list_head d_node;
	struct list_head h_node;
};

struct input_handler___9 {
	void *private;
	void (*event)(struct input_handle___9 *, unsigned int, unsigned int, int);
	void (*events)(struct input_handle___9 *, const struct input_value *, unsigned int);
	bool (*filter)(struct input_handle___9 *, unsigned int, unsigned int, int);
	bool (*match)(struct input_handler___9 *, struct input_dev___9 *);
	int (*connect)(struct input_handler___9 *, struct input_dev___9 *, const struct input_device_id *);
	void (*disconnect)(struct input_handle___9 *);
	void (*start)(struct input_handle___9 *);
	bool legacy_minors;
	int minor;
	const char *name;
	const struct input_device_id *id_table;
	struct list_head h_list;
	struct list_head node;
};

struct led_trigger___11;

struct led_classdev___11 {
	const char *name;
	enum led_brightness brightness;
	enum led_brightness max_brightness;
	int flags;
	long unsigned int work_flags;
	void (*brightness_set)(struct led_classdev___11 *, enum led_brightness);
	int (*brightness_set_blocking)(struct led_classdev___11 *, enum led_brightness);
	enum led_brightness (*brightness_get)(struct led_classdev___11 *);
	int (*blink_set)(struct led_classdev___11 *, long unsigned int *, long unsigned int *);
	int (*pattern_set)(struct led_classdev___11 *, struct led_pattern *, u32, int);
	int (*pattern_clear)(struct led_classdev___11 *);
	struct device___348 *dev;
	const struct attribute_group___345 **groups;
	struct list_head node;
	const char *default_trigger;
	long unsigned int blink_delay_on;
	long unsigned int blink_delay_off;
	struct timer_list blink_timer;
	int blink_brightness;
	int new_blink_brightness;
	void (*flash_resume)(struct led_classdev___11 *);
	struct work_struct set_brightness_work;
	int delayed_set_value;
	struct rw_semaphore___382 trigger_lock;
	struct led_trigger___11 *trigger;
	struct list_head trig_list;
	void *trigger_data;
	bool activated;
	struct mutex led_access;
};

struct led_trigger___11 {
	const char *name;
	void (*activate)(struct led_classdev___11 *);
	void (*deactivate)(struct led_classdev___11 *);
	rwlock_t leddev_list_lock;
	struct list_head led_cdevs;
	struct list_head next_trig;
};

struct power_supply___8;

struct power_supply_desc___8 {
	const char *name;
	enum power_supply_type type;
	enum power_supply_usb_type *usb_types;
	size_t num_usb_types;
	enum power_supply_property *properties;
	size_t num_properties;
	int (*get_property)(struct power_supply___8 *, enum power_supply_property, union power_supply_propval *);
	int (*set_property)(struct power_supply___8 *, enum power_supply_property, const union power_supply_propval *);
	int (*property_is_writeable)(struct power_supply___8 *, enum power_supply_property);
	void (*external_power_changed)(struct power_supply___8 *);
	void (*set_charged)(struct power_supply___8 *);
	bool no_thermal;
	int use_for_apm;
};

struct power_supply___8 {
	const struct power_supply_desc___8 *desc;
	char **supplied_to;
	size_t num_supplicants;
	char **supplied_from;
	size_t num_supplies;
	struct device_node___2 *of_node;
	void *drv_data;
	struct device___348 dev;
	struct work_struct changed_work;
	struct delayed_work deferred_register_work;
	spinlock_t changed_lock;
	bool changed;
	bool initialized;
	bool removing;
	atomic_t use_cnt;
	struct thermal_zone_device___5 *tzd;
	struct thermal_cooling_device___5 *tcd;
	struct led_trigger___11 *charging_full_trig;
	char *charging_full_trig_name;
	struct led_trigger___11 *charging_trig;
	char *charging_trig_name;
	struct led_trigger___11 *full_trig;
	char *full_trig_name;
	struct led_trigger___11 *online_trig;
	char *online_trig_name;
	struct led_trigger___11 *charging_blink_full_solid_trig;
	char *charging_blink_full_solid_trig_name;
};

struct hid_report___5;

struct hid_input___5;

struct hid_field___5 {
	unsigned int physical;
	unsigned int logical;
	unsigned int application;
	struct hid_usage *usage;
	unsigned int maxusage;
	unsigned int flags;
	unsigned int report_offset;
	unsigned int report_size;
	unsigned int report_count;
	unsigned int report_type;
	__s32 *value;
	__s32 logical_minimum;
	__s32 logical_maximum;
	__s32 physical_minimum;
	__s32 physical_maximum;
	__s32 unit_exponent;
	unsigned int unit;
	struct hid_report___5 *report;
	unsigned int index;
	struct hid_input___5 *hidinput;
	__u16 dpad;
};

struct hid_device___5;

struct hid_report___5 {
	struct list_head list;
	struct list_head hidinput_list;
	unsigned int id;
	unsigned int type;
	unsigned int application;
	struct hid_field___5 *field[256];
	unsigned int maxfield;
	unsigned int size;
	struct hid_device___5 *device;
};

struct hid_input___5 {
	struct list_head list;
	struct hid_report___5 *report;
	struct input_dev___9 *input;
	const char *name;
	bool registered;
	struct list_head reports;
	unsigned int application;
};

struct hid_report_enum___5 {
	unsigned int numbered;
	struct list_head report_list;
	struct hid_report___5 *report_id_hash[256];
};

struct hid_driver___5;

struct hid_ll_driver___5;

struct hid_device___5 {
	__u8 *dev_rdesc;
	unsigned int dev_rsize;
	__u8 *rdesc;
	unsigned int rsize;
	struct hid_collection *collection;
	unsigned int collection_size;
	unsigned int maxcollection;
	unsigned int maxapplication;
	__u16 bus;
	__u16 group;
	__u32 vendor;
	__u32 product;
	__u32 version;
	enum hid_type type;
	unsigned int country;
	struct hid_report_enum___5 report_enum[3];
	struct work_struct led_work;
	struct semaphore driver_input_lock;
	struct device___348 dev;
	struct hid_driver___5 *driver;
	struct hid_ll_driver___5 *ll_driver;
	struct mutex ll_open_lock;
	unsigned int ll_open_count;
	struct power_supply___8 *battery;
	__s32 battery_capacity;
	__s32 battery_min;
	__s32 battery_max;
	__s32 battery_report_type;
	__s32 battery_report_id;
	enum hid_battery_status battery_status;
	bool battery_avoid_query;
	long unsigned int status;
	unsigned int claimed;
	unsigned int quirks;
	bool io_started;
	struct list_head inputs;
	void *hiddev;
	void *hidraw;
	char name[128];
	char phys[64];
	char uniq[64];
	void *driver_data;
	int (*ff_init)(struct hid_device___5 *);
	int (*hiddev_connect)(struct hid_device___5 *, unsigned int);
	void (*hiddev_disconnect)(struct hid_device___5 *);
	void (*hiddev_hid_event)(struct hid_device___5 *, struct hid_field___5 *, struct hid_usage *, __s32);
	void (*hiddev_report_event)(struct hid_device___5 *, struct hid_report___5 *);
	short unsigned int debug;
	struct dentry___380 *debug_dir;
	struct dentry___380 *debug_rdesc;
	struct dentry___380 *debug_events;
	struct list_head debug_list;
	spinlock_t debug_list_lock;
	wait_queue_head_t debug_wait;
};

struct hid_driver___5 {
	char *name;
	const struct hid_device_id *id_table;
	struct list_head dyn_list;
	spinlock_t dyn_lock;
	bool (*match)(struct hid_device___5 *, bool);
	int (*probe)(struct hid_device___5 *, const struct hid_device_id *);
	void (*remove)(struct hid_device___5 *);
	const struct hid_report_id *report_table;
	int (*raw_event)(struct hid_device___5 *, struct hid_report___5 *, u8 *, int);
	const struct hid_usage_id *usage_table;
	int (*event)(struct hid_device___5 *, struct hid_field___5 *, struct hid_usage *, __s32);
	void (*report)(struct hid_device___5 *, struct hid_report___5 *);
	__u8 * (*report_fixup)(struct hid_device___5 *, __u8 *, unsigned int *);
	int (*input_mapping)(struct hid_device___5 *, struct hid_input___5 *, struct hid_field___5 *, struct hid_usage *, long unsigned int **, int *);
	int (*input_mapped)(struct hid_device___5 *, struct hid_input___5 *, struct hid_field___5 *, struct hid_usage *, long unsigned int **, int *);
	int (*input_configured)(struct hid_device___5 *, struct hid_input___5 *);
	void (*feature_mapping)(struct hid_device___5 *, struct hid_field___5 *, struct hid_usage *);
	int (*suspend)(struct hid_device___5 *, pm_message_t);
	int (*resume)(struct hid_device___5 *);
	int (*reset_resume)(struct hid_device___5 *);
	struct device_driver___348 driver;
};

struct hid_ll_driver___5 {
	int (*start)(struct hid_device___5 *);
	void (*stop)(struct hid_device___5 *);
	int (*open)(struct hid_device___5 *);
	void (*close)(struct hid_device___5 *);
	int (*power)(struct hid_device___5 *, int);
	int (*parse)(struct hid_device___5 *);
	void (*request)(struct hid_device___5 *, struct hid_report___5 *, int);
	int (*wait)(struct hid_device___5 *);
	int (*raw_request)(struct hid_device___5 *, unsigned char, __u8 *, size_t, unsigned char, int);
	int (*output_report)(struct hid_device___5 *, __u8 *, size_t);
	int (*idle)(struct hid_device___5 *, int, int, int);
};

struct ntrig_data {
	__u16 x;
	__u16 y;
	__u16 w;
	__u16 h;
	__u16 id;
	bool tipswitch;
	bool confidence;
	bool first_contact_touch;
	bool reading_mt;
	__u8 mt_footer[4];
	__u8 mt_foot_count;
	__s8 act_state;
	__s8 deactivate_slack;
	__s8 activate_slack;
	__u16 min_width;
	__u16 min_height;
	__u16 activation_width;
	__u16 activation_height;
	__u16 sensor_logical_width;
	__u16 sensor_logical_height;
	__u16 sensor_physical_width;
	__u16 sensor_physical_height;
};

struct hid_control_fifo {
	unsigned char dir;
	struct hid_report *report;
	char *raw_report;
};

struct hid_output_fifo {
	struct hid_report *report;
	char *raw_report;
};

struct hid_class_descriptor {
	__u8 bDescriptorType;
	__le16 wDescriptorLength;
} __attribute__((packed));

struct hid_descriptor {
	__u8 bLength;
	__u8 bDescriptorType;
	__le16 bcdHID;
	__u8 bCountryCode;
	__u8 bNumDescriptors;
	struct hid_class_descriptor desc[1];
} __attribute__((packed));

struct usbhid_device {
	struct hid_device *hid;
	struct usb_interface___3 *intf;
	int ifnum;
	unsigned int bufsize;
	struct urb___3 *urbin;
	char *inbuf;
	dma_addr_t inbuf_dma;
	struct urb___3 *urbctrl;
	struct usb_ctrlrequest *cr;
	struct hid_control_fifo ctrl[256];
	unsigned char ctrlhead;
	unsigned char ctrltail;
	char *ctrlbuf;
	dma_addr_t ctrlbuf_dma;
	long unsigned int last_ctrl;
	struct urb___3 *urbout;
	struct hid_output_fifo out[256];
	unsigned char outhead;
	unsigned char outtail;
	char *outbuf;
	dma_addr_t outbuf_dma;
	long unsigned int last_out;
	spinlock_t lock;
	long unsigned int iofl;
	struct timer_list io_retry;
	long unsigned int stop_retry;
	unsigned int retry_delay;
	struct work_struct reset_work;
	wait_queue_head_t wait;
};

struct ff_device___10;

struct input_handle___10;

struct input_dev___10 {
	const char *name;
	const char *phys;
	const char *uniq;
	struct input_id id;
	long unsigned int propbit[1];
	long unsigned int evbit[1];
	long unsigned int keybit[12];
	long unsigned int relbit[1];
	long unsigned int absbit[1];
	long unsigned int mscbit[1];
	long unsigned int ledbit[1];
	long unsigned int sndbit[1];
	long unsigned int ffbit[2];
	long unsigned int swbit[1];
	unsigned int hint_events_per_packet;
	unsigned int keycodemax;
	unsigned int keycodesize;
	void *keycode;
	int (*setkeycode)(struct input_dev___10 *, const struct input_keymap_entry *, unsigned int *);
	int (*getkeycode)(struct input_dev___10 *, struct input_keymap_entry *);
	struct ff_device___10 *ff;
	unsigned int repeat_key;
	struct timer_list timer;
	int rep[2];
	struct input_mt *mt;
	struct input_absinfo *absinfo;
	long unsigned int key[12];
	long unsigned int led[1];
	long unsigned int snd[1];
	long unsigned int sw[1];
	int (*open)(struct input_dev___10 *);
	void (*close)(struct input_dev___10 *);
	int (*flush)(struct input_dev___10 *, struct file___32 *);
	int (*event)(struct input_dev___10 *, unsigned int, unsigned int, int);
	struct input_handle___10 *grab;
	spinlock_t event_lock;
	struct mutex mutex;
	unsigned int users;
	bool going_away;
	struct device___27 dev;
	struct list_head h_list;
	struct list_head node;
	unsigned int num_vals;
	unsigned int max_vals;
	struct input_value *vals;
	bool devres_managed;
};

struct ff_device___10 {
	int (*upload)(struct input_dev___10 *, struct ff_effect *, struct ff_effect *);
	int (*erase)(struct input_dev___10 *, int);
	int (*playback)(struct input_dev___10 *, int, int);
	void (*set_gain)(struct input_dev___10 *, u16);
	void (*set_autocenter)(struct input_dev___10 *, u16);
	void (*destroy)(struct ff_device___10 *);
	void *private;
	long unsigned int ffbit[2];
	struct mutex mutex;
	int max_effects;
	struct ff_effect *effects;
	struct file___32 *effect_owners[0];
};

struct input_handler___10;

struct input_handle___10 {
	void *private;
	int open;
	const char *name;
	struct input_dev___10 *dev;
	struct input_handler___10 *handler;
	struct list_head d_node;
	struct list_head h_node;
};

struct input_handler___10 {
	void *private;
	void (*event)(struct input_handle___10 *, unsigned int, unsigned int, int);
	void (*events)(struct input_handle___10 *, const struct input_value *, unsigned int);
	bool (*filter)(struct input_handle___10 *, unsigned int, unsigned int, int);
	bool (*match)(struct input_handler___10 *, struct input_dev___10 *);
	int (*connect)(struct input_handler___10 *, struct input_dev___10 *, const struct input_device_id *);
	void (*disconnect)(struct input_handle___10 *);
	void (*start)(struct input_handle___10 *);
	bool legacy_minors;
	int minor;
	const char *name;
	const struct input_device_id *id_table;
	struct list_head h_list;
	struct list_head node;
};

struct usb_class_driver___2 {
	char *name;
	char * (*devnode)(struct device___27 *, umode_t *);
	const struct file_operations___32 *fops;
	int minor_base;
};

struct led_trigger___12;

struct led_classdev___12 {
	const char *name;
	enum led_brightness brightness;
	enum led_brightness max_brightness;
	int flags;
	long unsigned int work_flags;
	void (*brightness_set)(struct led_classdev___12 *, enum led_brightness);
	int (*brightness_set_blocking)(struct led_classdev___12 *, enum led_brightness);
	enum led_brightness (*brightness_get)(struct led_classdev___12 *);
	int (*blink_set)(struct led_classdev___12 *, long unsigned int *, long unsigned int *);
	int (*pattern_set)(struct led_classdev___12 *, struct led_pattern *, u32, int);
	int (*pattern_clear)(struct led_classdev___12 *);
	struct device___27 *dev;
	const struct attribute_group___27 **groups;
	struct list_head node;
	const char *default_trigger;
	long unsigned int blink_delay_on;
	long unsigned int blink_delay_off;
	struct timer_list blink_timer;
	int blink_brightness;
	int new_blink_brightness;
	void (*flash_resume)(struct led_classdev___12 *);
	struct work_struct set_brightness_work;
	int delayed_set_value;
	struct rw_semaphore___32 trigger_lock;
	struct led_trigger___12 *trigger;
	struct list_head trig_list;
	void *trigger_data;
	bool activated;
	struct mutex led_access;
};

struct led_trigger___12 {
	const char *name;
	void (*activate)(struct led_classdev___12 *);
	void (*deactivate)(struct led_classdev___12 *);
	rwlock_t leddev_list_lock;
	struct list_head led_cdevs;
	struct list_head next_trig;
};

struct power_supply___9;

struct power_supply_desc___9 {
	const char *name;
	enum power_supply_type type;
	enum power_supply_usb_type *usb_types;
	size_t num_usb_types;
	enum power_supply_property *properties;
	size_t num_properties;
	int (*get_property)(struct power_supply___9 *, enum power_supply_property, union power_supply_propval *);
	int (*set_property)(struct power_supply___9 *, enum power_supply_property, const union power_supply_propval *);
	int (*property_is_writeable)(struct power_supply___9 *, enum power_supply_property);
	void (*external_power_changed)(struct power_supply___9 *);
	void (*set_charged)(struct power_supply___9 *);
	bool no_thermal;
	int use_for_apm;
};

struct power_supply___9 {
	const struct power_supply_desc___9 *desc;
	char **supplied_to;
	size_t num_supplicants;
	char **supplied_from;
	size_t num_supplies;
	struct device_node___2 *of_node;
	void *drv_data;
	struct device___27 dev;
	struct work_struct changed_work;
	struct delayed_work deferred_register_work;
	spinlock_t changed_lock;
	bool changed;
	bool initialized;
	bool removing;
	atomic_t use_cnt;
	struct thermal_zone_device___5 *tzd;
	struct thermal_cooling_device___5 *tcd;
	struct led_trigger___12 *charging_full_trig;
	char *charging_full_trig_name;
	struct led_trigger___12 *charging_trig;
	char *charging_trig_name;
	struct led_trigger___12 *full_trig;
	char *full_trig_name;
	struct led_trigger___12 *online_trig;
	char *online_trig_name;
	struct led_trigger___12 *charging_blink_full_solid_trig;
	char *charging_blink_full_solid_trig_name;
};

struct hid_report___6;

struct hid_input___6;

struct hid_field___6 {
	unsigned int physical;
	unsigned int logical;
	unsigned int application;
	struct hid_usage *usage;
	unsigned int maxusage;
	unsigned int flags;
	unsigned int report_offset;
	unsigned int report_size;
	unsigned int report_count;
	unsigned int report_type;
	__s32 *value;
	__s32 logical_minimum;
	__s32 logical_maximum;
	__s32 physical_minimum;
	__s32 physical_maximum;
	__s32 unit_exponent;
	unsigned int unit;
	struct hid_report___6 *report;
	unsigned int index;
	struct hid_input___6 *hidinput;
	__u16 dpad;
};

struct hid_device___6;

struct hid_report___6 {
	struct list_head list;
	struct list_head hidinput_list;
	unsigned int id;
	unsigned int type;
	unsigned int application;
	struct hid_field___6 *field[256];
	unsigned int maxfield;
	unsigned int size;
	struct hid_device___6 *device;
};

struct hid_input___6 {
	struct list_head list;
	struct hid_report___6 *report;
	struct input_dev___10 *input;
	const char *name;
	bool registered;
	struct list_head reports;
	unsigned int application;
};

struct hid_report_enum___6 {
	unsigned int numbered;
	struct list_head report_list;
	struct hid_report___6 *report_id_hash[256];
};

struct hid_driver___6;

struct hid_ll_driver___6;

struct hid_device___6 {
	__u8 *dev_rdesc;
	unsigned int dev_rsize;
	__u8 *rdesc;
	unsigned int rsize;
	struct hid_collection *collection;
	unsigned int collection_size;
	unsigned int maxcollection;
	unsigned int maxapplication;
	__u16 bus;
	__u16 group;
	__u32 vendor;
	__u32 product;
	__u32 version;
	enum hid_type type;
	unsigned int country;
	struct hid_report_enum___6 report_enum[3];
	struct work_struct led_work;
	struct semaphore driver_input_lock;
	struct device___27 dev;
	struct hid_driver___6 *driver;
	struct hid_ll_driver___6 *ll_driver;
	struct mutex ll_open_lock;
	unsigned int ll_open_count;
	struct power_supply___9 *battery;
	__s32 battery_capacity;
	__s32 battery_min;
	__s32 battery_max;
	__s32 battery_report_type;
	__s32 battery_report_id;
	enum hid_battery_status battery_status;
	bool battery_avoid_query;
	long unsigned int status;
	unsigned int claimed;
	unsigned int quirks;
	bool io_started;
	struct list_head inputs;
	void *hiddev;
	void *hidraw;
	char name[128];
	char phys[64];
	char uniq[64];
	void *driver_data;
	int (*ff_init)(struct hid_device___6 *);
	int (*hiddev_connect)(struct hid_device___6 *, unsigned int);
	void (*hiddev_disconnect)(struct hid_device___6 *);
	void (*hiddev_hid_event)(struct hid_device___6 *, struct hid_field___6 *, struct hid_usage *, __s32);
	void (*hiddev_report_event)(struct hid_device___6 *, struct hid_report___6 *);
	short unsigned int debug;
	struct dentry___33 *debug_dir;
	struct dentry___33 *debug_rdesc;
	struct dentry___33 *debug_events;
	struct list_head debug_list;
	spinlock_t debug_list_lock;
	wait_queue_head_t debug_wait;
};

struct hid_control_fifo___2 {
	unsigned char dir;
	struct hid_report___6 *report;
	char *raw_report;
};

struct hid_output_fifo___2 {
	struct hid_report___6 *report;
	char *raw_report;
};

struct hid_driver___6 {
	char *name;
	const struct hid_device_id *id_table;
	struct list_head dyn_list;
	spinlock_t dyn_lock;
	bool (*match)(struct hid_device___6 *, bool);
	int (*probe)(struct hid_device___6 *, const struct hid_device_id *);
	void (*remove)(struct hid_device___6 *);
	const struct hid_report_id *report_table;
	int (*raw_event)(struct hid_device___6 *, struct hid_report___6 *, u8 *, int);
	const struct hid_usage_id *usage_table;
	int (*event)(struct hid_device___6 *, struct hid_field___6 *, struct hid_usage *, __s32);
	void (*report)(struct hid_device___6 *, struct hid_report___6 *);
	__u8 * (*report_fixup)(struct hid_device___6 *, __u8 *, unsigned int *);
	int (*input_mapping)(struct hid_device___6 *, struct hid_input___6 *, struct hid_field___6 *, struct hid_usage *, long unsigned int **, int *);
	int (*input_mapped)(struct hid_device___6 *, struct hid_input___6 *, struct hid_field___6 *, struct hid_usage *, long unsigned int **, int *);
	int (*input_configured)(struct hid_device___6 *, struct hid_input___6 *);
	void (*feature_mapping)(struct hid_device___6 *, struct hid_field___6 *, struct hid_usage *);
	int (*suspend)(struct hid_device___6 *, pm_message_t);
	int (*resume)(struct hid_device___6 *);
	int (*reset_resume)(struct hid_device___6 *);
	struct device_driver___27 driver;
};

struct hid_ll_driver___6 {
	int (*start)(struct hid_device___6 *);
	void (*stop)(struct hid_device___6 *);
	int (*open)(struct hid_device___6 *);
	void (*close)(struct hid_device___6 *);
	int (*power)(struct hid_device___6 *, int);
	int (*parse)(struct hid_device___6 *);
	void (*request)(struct hid_device___6 *, struct hid_report___6 *, int);
	int (*wait)(struct hid_device___6 *);
	int (*raw_request)(struct hid_device___6 *, unsigned char, __u8 *, size_t, unsigned char, int);
	int (*output_report)(struct hid_device___6 *, __u8 *, size_t);
	int (*idle)(struct hid_device___6 *, int, int, int);
};

struct hiddev_event {
	unsigned int hid;
	int value;
};

struct hiddev_devinfo {
	__u32 bustype;
	__u32 busnum;
	__u32 devnum;
	__u32 ifnum;
	__s16 vendor;
	__s16 product;
	__s16 version;
	__u32 num_applications;
};

struct hiddev_collection_info {
	__u32 index;
	__u32 type;
	__u32 usage;
	__u32 level;
};

struct hiddev_report_info {
	__u32 report_type;
	__u32 report_id;
	__u32 num_fields;
};

struct hiddev_field_info {
	__u32 report_type;
	__u32 report_id;
	__u32 field_index;
	__u32 maxusage;
	__u32 flags;
	__u32 physical;
	__u32 logical;
	__u32 application;
	__s32 logical_minimum;
	__s32 logical_maximum;
	__s32 physical_minimum;
	__s32 physical_maximum;
	__u32 unit_exponent;
	__u32 unit;
};

struct hiddev_usage_ref {
	__u32 report_type;
	__u32 report_id;
	__u32 field_index;
	__u32 usage_index;
	__u32 usage_code;
	__s32 value;
};

struct hiddev_usage_ref_multi {
	struct hiddev_usage_ref uref;
	__u32 num_values;
	__s32 values[1024];
};

struct hiddev___2 {
	int minor;
	int exist;
	int open;
	struct mutex existancelock;
	wait_queue_head_t wait;
	struct hid_device___6 *hid;
	struct list_head list;
	spinlock_t list_lock;
	bool initialized;
};

struct usbhid_device___2 {
	struct hid_device___6 *hid;
	struct usb_interface___10 *intf;
	int ifnum;
	unsigned int bufsize;
	struct urb___10 *urbin;
	char *inbuf;
	dma_addr_t inbuf_dma;
	struct urb___10 *urbctrl;
	struct usb_ctrlrequest *cr;
	struct hid_control_fifo___2 ctrl[256];
	unsigned char ctrlhead;
	unsigned char ctrltail;
	char *ctrlbuf;
	dma_addr_t ctrlbuf_dma;
	long unsigned int last_ctrl;
	struct urb___10 *urbout;
	struct hid_output_fifo___2 out[256];
	unsigned char outhead;
	unsigned char outtail;
	char *outbuf;
	dma_addr_t outbuf_dma;
	long unsigned int last_out;
	spinlock_t lock;
	long unsigned int iofl;
	struct timer_list io_retry;
	long unsigned int stop_retry;
	unsigned int retry_delay;
	struct work_struct reset_work;
	wait_queue_head_t wait;
};

struct hiddev_list {
	struct hiddev_usage_ref buffer[2048];
	int head;
	int tail;
	unsigned int flags;
	struct fasync_struct___31 *fasync;
	struct hiddev___2 *hiddev;
	struct list_head node;
	struct mutex thread_lock;
};

struct pidff_usage {
	struct hid_field___5 *field;
	s32 *value;
};

struct pidff_device {
	struct hid_device___5 *hid;
	struct hid_report___5 *reports[13];
	struct pidff_usage set_effect[7];
	struct pidff_usage set_envelope[5];
	struct pidff_usage set_condition[8];
	struct pidff_usage set_periodic[5];
	struct pidff_usage set_constant[2];
	struct pidff_usage set_ramp[3];
	struct pidff_usage device_gain[1];
	struct pidff_usage block_load[2];
	struct pidff_usage pool[3];
	struct pidff_usage effect_operation[2];
	struct pidff_usage block_free[1];
	struct hid_field___5 *create_new_effect_type;
	struct hid_field___5 *set_effect_type;
	struct hid_field___5 *effect_direction;
	struct hid_field___5 *device_control;
	struct hid_field___5 *block_load_status;
	struct hid_field___5 *effect_operation_status;
	int control_id[2];
	int type_id[11];
	int status_id[2];
	int operation_id[2];
	int pid_id[64];
};

struct alias_prop {
	struct list_head link;
	const char *alias;
	struct device_node___93 *np;
	int id;
	char stem[0];
};

struct module___325;

struct file___395;

struct kiocb___395;

struct vm_area_struct___396;

struct inode___395;

struct file_lock___395;

struct page___396;

struct file_operations___395 {
	struct module___325 *owner;
	loff_t (*llseek)(struct file___395 *, loff_t, int);
	ssize_t (*read)(struct file___395 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___395 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___395 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___395 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___395 *, bool);
	int (*iterate)(struct file___395 *, struct dir_context *);
	int (*iterate_shared)(struct file___395 *, struct dir_context *);
	__poll_t (*poll)(struct file___395 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___395 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___395 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___395 *, struct vm_area_struct___396 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___395 *, struct file___395 *);
	int (*flush)(struct file___395 *, fl_owner_t);
	int (*release)(struct inode___395 *, struct file___395 *);
	int (*fsync)(struct file___395 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___395 *, int);
	int (*lock)(struct file___395 *, int, struct file_lock___395 *);
	ssize_t (*sendpage)(struct file___395 *, struct page___396 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___395 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___395 *, int, struct file_lock___395 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___395 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___395 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___395 *, long int, struct file_lock___395 **, void **);
	long int (*fallocate)(struct file___395 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___395 *);
	ssize_t (*copy_file_range)(struct file___395 *, loff_t, struct file___395 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___395 *, loff_t, struct file___395 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___395 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___396 {
	u64 seqnum;
	struct vm_area_struct___396 *vmas[4];
};

struct page_frag___396 {
	struct page___396 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___396;

struct vm_struct___299;

struct task_struct___397 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___397 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___396 *mm;
	struct mm_struct___396 *active_mm;
	struct vmacache___396 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___397 *real_parent;
	struct task_struct___397 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___397 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___227 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___227 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___227 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___2 *ptracer_cred;
	const struct cred___2 *real_cred;
	const struct cred___2 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___397 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___396 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___397 *oom_reaper_list;
	struct vm_struct___299 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___150 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___396 *pgtable_t___396;

struct address_space___395;

struct dev_pagemap___383;

struct page___396 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___395 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___396 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___396 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___396 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___383 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___396;

struct lruvec___396 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___396 *pgdat;
};

struct zone___396 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___396 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___396 {
	struct zone___396 *zone;
	int zone_idx;
};

struct zonelist___396 {
	struct zoneref___396 _zonerefs[25];
};

struct pglist_data___396 {
	struct zone___396 node_zones[3];
	struct zonelist___396 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___397 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___397 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___396 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___397 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___397 *owner;
};

struct secondary_data___397 {
	void *stack;
	struct task_struct___397 *task;
	long int status;
};

struct blocking_notifier_head___396 {
	struct rw_semaphore___397 rwsem;
	struct notifier_block *head;
};

struct kernfs_root___389;

struct kernfs_elem_dir___389 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___389 *root;
};

struct kernfs_node___390;

struct kernfs_syscall_ops___389;

struct kernfs_root___389 {
	struct kernfs_node___390 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___389 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___389 {
	struct kernfs_node___390 *target_kn;
};

struct kernfs_ops___389;

struct kernfs_elem_attr___389 {
	const struct kernfs_ops___389 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___390 *notify_next;
};

struct kernfs_node___390 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___390 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___389 dir;
		struct kernfs_elem_symlink___389 symlink;
		struct kernfs_elem_attr___389 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___389;

struct kernfs_ops___389 {
	int (*open)(struct kernfs_open_file___389 *);
	void (*release)(struct kernfs_open_file___389 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___389 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___389 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___389 *, struct vm_area_struct___396 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___389 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___389 {
	int (*remount_fs)(struct kernfs_root___389 *, int *, char *);
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___389 *);
	int (*mkdir)(struct kernfs_node___390 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___390 *);
	int (*rename)(struct kernfs_node___390 *, struct kernfs_node___390 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___390 *, struct kernfs_root___389 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_operations_struct___383;

struct kernfs_open_file___389 {
	struct kernfs_node___390 *kn;
	struct file___395 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___383 *vm_ops;
};

struct dentry___395;

struct path___396 {
	struct vfsmount *mnt;
	struct dentry___395 *dentry;
};

struct file___395 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___396 f_path;
	struct inode___395 *f_inode;
	const struct file_operations___395 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___227 f_owner;
	const struct cred___2 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___395 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___383;

struct vm_operations_struct___383 {
	void (*open)(struct vm_area_struct___396 *);
	void (*close)(struct vm_area_struct___396 *);
	int (*split)(struct vm_area_struct___396 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___396 *);
	vm_fault_t (*fault)(struct vm_fault___383 *);
	vm_fault_t (*huge_fault)(struct vm_fault___383 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___383 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___396 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___383 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___383 *);
	int (*access)(struct vm_area_struct___396 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___396 *);
	int (*set_policy)(struct vm_area_struct___396 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___396 *, long unsigned int);
	struct page___396 * (*find_special_page)(struct vm_area_struct___396 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_area_struct___396 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___396 *vm_next;
	struct vm_area_struct___396 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___396 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___383 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___395 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___383;

struct bin_attribute___359;

struct attribute_group___360 {
	const char *name;
	umode_t (*is_visible)(struct kobject___383 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___383 *, struct bin_attribute___359 *, int);
	struct attribute **attrs;
	struct bin_attribute___359 **bin_attrs;
};

struct kset___382;

struct kobj_type___382;

struct kobject___383 {
	const char *name;
	struct list_head entry;
	struct kobject___383 *parent;
	struct kset___382 *kset;
	struct kobj_type___382 *ktype;
	struct kernfs_node___390 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___359 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___395 *, struct kobject___383 *, struct bin_attribute___359 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___395 *, struct kobject___383 *, struct bin_attribute___359 *, char *, loff_t, size_t);
	int (*mmap)(struct file___395 *, struct kobject___383 *, struct bin_attribute___359 *, struct vm_area_struct___396 *);
};

struct sysfs_ops___382 {
	ssize_t (*show)(struct kobject___383 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___383 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___382;

struct kset___382 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___383 kobj;
	const struct kset_uevent_ops___382 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___382 {
	void (*release)(struct kobject___383 *);
	const struct sysfs_ops___382 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___29 * (*child_ns_type)(struct kobject___383 *);
	const void * (*namespace)(struct kobject___383 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___382 {
	int (* const filter)(struct kset___382 *, struct kobject___383 *);
	const char * (* const name)(struct kset___382 *, struct kobject___383 *);
	int (* const uevent)(struct kset___382 *, struct kobject___383 *, struct kobj_uevent_env *);
};

struct kobj_attribute___373 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___383 *, struct kobj_attribute___373 *, char *);
	ssize_t (*store)(struct kobject___383 *, struct kobj_attribute___373 *, const char *, size_t);
};

struct fwnode_operations___283;

struct fwnode_handle___283 {
	struct fwnode_handle___283 *secondary;
	const struct fwnode_operations___283 *ops;
};

struct device___363;

struct fwnode_reference_args___283;

struct fwnode_endpoint___283;

struct fwnode_operations___283 {
	struct fwnode_handle___283 * (*get)(struct fwnode_handle___283 *);
	void (*put)(struct fwnode_handle___283 *);
	bool (*device_is_available)(const struct fwnode_handle___283 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___283 *, const struct device___363 *);
	bool (*property_present)(const struct fwnode_handle___283 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___283 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___283 *, const char *, const char **, size_t);
	struct fwnode_handle___283 * (*get_parent)(const struct fwnode_handle___283 *);
	struct fwnode_handle___283 * (*get_next_child_node)(const struct fwnode_handle___283 *, struct fwnode_handle___283 *);
	struct fwnode_handle___283 * (*get_named_child_node)(const struct fwnode_handle___283 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___283 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___283 *);
	struct fwnode_handle___283 * (*graph_get_next_endpoint)(const struct fwnode_handle___283 *, struct fwnode_handle___283 *);
	struct fwnode_handle___283 * (*graph_get_remote_endpoint)(const struct fwnode_handle___283 *);
	struct fwnode_handle___283 * (*graph_get_port_parent)(struct fwnode_handle___283 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___283 *, struct fwnode_endpoint___283 *);
};

struct fwnode_endpoint___283 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___283 *local_fwnode;
};

struct fwnode_reference_args___283 {
	struct fwnode_handle___283 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct dev_pm_info___363 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___363 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___363;

struct bus_type___363;

struct device_driver___363;

struct dev_pm_domain___363;

struct dma_map_ops___137;

struct device_node___95;

struct class___363;

struct iommu_fwspec___8;

struct device___363 {
	struct device___363 *parent;
	struct device_private *p;
	struct kobject___383 kobj;
	const char *init_name;
	const struct device_type___363 *type;
	struct mutex mutex;
	struct bus_type___363 *bus;
	struct device_driver___363 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___363 power;
	struct dev_pm_domain___363 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___137 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___95 *of_node;
	struct fwnode_handle___283 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___363 *class;
	const struct attribute_group___360 **groups;
	void (*release)(struct device___363 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec___8 *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct property___91 {
	char *name;
	int length;
	void *value;
	struct property___91 *next;
	long unsigned int _flags;
	struct bin_attribute___359 attr;
};

struct device_node___95 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___283 fwnode;
	struct property___91 *properties;
	struct property___91 *deadprops;
	struct device_node___95 *parent;
	struct device_node___95 *child;
	struct device_node___95 *sibling;
	struct kobject___383 kobj;
	long unsigned int _flags;
	void *data;
};

struct of_phandle_args___15 {
	struct device_node___95 *np;
	int args_count;
	uint32_t args[16];
};

struct dev_pm_ops___363 {
	int (*prepare)(struct device___363 *);
	void (*complete)(struct device___363 *);
	int (*suspend)(struct device___363 *);
	int (*resume)(struct device___363 *);
	int (*freeze)(struct device___363 *);
	int (*thaw)(struct device___363 *);
	int (*poweroff)(struct device___363 *);
	int (*restore)(struct device___363 *);
	int (*suspend_late)(struct device___363 *);
	int (*resume_early)(struct device___363 *);
	int (*freeze_late)(struct device___363 *);
	int (*thaw_early)(struct device___363 *);
	int (*poweroff_late)(struct device___363 *);
	int (*restore_early)(struct device___363 *);
	int (*suspend_noirq)(struct device___363 *);
	int (*resume_noirq)(struct device___363 *);
	int (*freeze_noirq)(struct device___363 *);
	int (*thaw_noirq)(struct device___363 *);
	int (*poweroff_noirq)(struct device___363 *);
	int (*restore_noirq)(struct device___363 *);
	int (*runtime_suspend)(struct device___363 *);
	int (*runtime_resume)(struct device___363 *);
	int (*runtime_idle)(struct device___363 *);
};

struct dev_pm_domain___363 {
	struct dev_pm_ops___363 ops;
	void (*detach)(struct device___363 *, bool);
	int (*activate)(struct device___363 *);
	void (*sync)(struct device___363 *);
	void (*dismiss)(struct device___363 *);
};

struct core_state___396;

struct mm_struct___396 {
	struct {
		struct vm_area_struct___396 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___395 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___397 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___396 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___397 *owner;
		struct user_namespace___3 *user_ns;
		struct file___395 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___396 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct vm_struct___299 {
	struct vm_struct___299 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___396 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct iommu_ops___8;

struct bus_type___363 {
	const char *name;
	const char *dev_name;
	struct device___363 *dev_root;
	const struct attribute_group___360 **bus_groups;
	const struct attribute_group___360 **dev_groups;
	const struct attribute_group___360 **drv_groups;
	int (*match)(struct device___363 *, struct device_driver___363 *);
	int (*uevent)(struct device___363 *, struct kobj_uevent_env *);
	int (*probe)(struct device___363 *);
	int (*remove)(struct device___363 *);
	void (*shutdown)(struct device___363 *);
	int (*online)(struct device___363 *);
	int (*offline)(struct device___363 *);
	int (*suspend)(struct device___363 *, pm_message_t);
	int (*resume)(struct device___363 *);
	int (*num_vf)(struct device___363 *);
	int (*dma_configure)(struct device___363 *);
	const struct dev_pm_ops___363 *pm;
	const struct iommu_ops___8 *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___363 {
	const char *name;
	struct bus_type___363 *bus;
	struct module___325 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___363 *);
	int (*remove)(struct device___363 *);
	void (*shutdown)(struct device___363 *);
	int (*suspend)(struct device___363 *, pm_message_t);
	int (*resume)(struct device___363 *);
	const struct attribute_group___360 **groups;
	const struct dev_pm_ops___363 *pm;
	void (*coredump)(struct device___363 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct iommu_domain___8;

struct iommu_ops___8 {
	bool (*capable)(enum iommu_cap);
	struct iommu_domain___8 * (*domain_alloc)(unsigned int);
	void (*domain_free)(struct iommu_domain___8 *);
	int (*attach_dev)(struct iommu_domain___8 *, struct device___363 *);
	void (*detach_dev)(struct iommu_domain___8 *, struct device___363 *);
	int (*map)(struct iommu_domain___8 *, long unsigned int, phys_addr_t, size_t, int);
	size_t (*unmap)(struct iommu_domain___8 *, long unsigned int, size_t);
	void (*flush_iotlb_all)(struct iommu_domain___8 *);
	void (*iotlb_range_add)(struct iommu_domain___8 *, long unsigned int, size_t);
	void (*iotlb_sync)(struct iommu_domain___8 *);
	phys_addr_t (*iova_to_phys)(struct iommu_domain___8 *, dma_addr_t);
	int (*add_device)(struct device___363 *);
	void (*remove_device)(struct device___363 *);
	struct iommu_group * (*device_group)(struct device___363 *);
	int (*domain_get_attr)(struct iommu_domain___8 *, enum iommu_attr, void *);
	int (*domain_set_attr)(struct iommu_domain___8 *, enum iommu_attr, void *);
	void (*get_resv_regions)(struct device___363 *, struct list_head *);
	void (*put_resv_regions)(struct device___363 *, struct list_head *);
	void (*apply_resv_region)(struct device___363 *, struct iommu_domain___8 *, struct iommu_resv_region *);
	int (*domain_window_enable)(struct iommu_domain___8 *, u32, phys_addr_t, u64, int);
	void (*domain_window_disable)(struct iommu_domain___8 *, u32);
	int (*domain_set_windows)(struct iommu_domain___8 *, u32);
	u32 (*domain_get_windows)(struct iommu_domain___8 *);
	int (*of_xlate)(struct device___363 *, struct of_phandle_args___15 *);
	bool (*is_attach_deferred)(struct iommu_domain___8 *, struct device___363 *);
	long unsigned int pgsize_bitmap;
};

struct device_type___363 {
	const char *name;
	const struct attribute_group___360 **groups;
	int (*uevent)(struct device___363 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___363 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___363 *);
	const struct dev_pm_ops___363 *pm;
};

struct module_kobject___323 {
	struct kobject___383 kobj;
	struct module___325 *mod;
	struct kobject___383 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___323 {
	struct module___325 *mod;
	struct latch_tree_node node;
};

struct module_layout___323 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___323 mtn;
};

struct module_attribute___323;

struct kernel_param___323;

struct module___325 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___323 mkobj;
	struct module_attribute___323 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___383 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___323 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___323 core_layout;
	struct module_layout___323 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct class___363 {
	const char *name;
	struct module___325 *owner;
	const struct attribute_group___360 **class_groups;
	const struct attribute_group___360 **dev_groups;
	struct kobject___383 *dev_kobj;
	int (*dev_uevent)(struct device___363 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___363 *, umode_t *);
	void (*class_release)(struct class___363 *);
	void (*dev_release)(struct device___363 *);
	int (*shutdown_pre)(struct device___363 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___363 *);
	const struct dev_pm_ops___363 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___137 {
	void * (*alloc)(struct device___363 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___363 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___363 *, struct vm_area_struct___396 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___363 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___363 *, struct page___396 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___363 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___363 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___363 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___363 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___363 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___363 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___363 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___363 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___363 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___363 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___363 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___363 *, u64);
	u64 (*get_required_mask)(struct device___363 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct iommu_fwspec___8 {
	const struct iommu_ops___8 *ops;
	struct fwnode_handle___283 *iommu_fwnode;
	void *iommu_priv;
	unsigned int num_ids;
	u32 ids[1];
};

struct node___217 {
	struct device___363 dev;
};

struct platform_device___25 {
	const char *name;
	int id;
	bool id_auto;
	struct device___363 dev;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct address_space_operations___395;

struct address_space___395 {
	struct inode___395 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___397 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___395 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___383)(struct vm_area_struct___396 *, long unsigned int, const struct page___396 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___383)(struct page___396 *, void *);

struct dev_pagemap___383 {
	dev_page_fault_t___383 page_fault;
	dev_page_free_t___383 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___363 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___396 {
	struct task_struct___397 *task;
	struct core_thread___396 *next;
};

struct core_state___396 {
	atomic_t nr_threads;
	struct core_thread___396 dumper;
	struct completion startup;
};

struct vm_fault___383 {
	struct vm_area_struct___396 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___396 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___396 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___396 prealloc_pte;
};

struct dentry_operations___395;

struct super_block___395;

struct dentry___395 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___395 *d_parent;
	struct qstr d_name;
	struct inode___395 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___395 *d_op;
	struct super_block___395 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___395;

struct block_device___395;

struct inode___395 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___395 *i_op;
	struct super_block___395 *i_sb;
	struct address_space___395 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___397 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___395 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___395 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___395 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___395 {
	int (*d_revalidate)(struct dentry___395 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___395 *, unsigned int);
	int (*d_hash)(const struct dentry___395 *, struct qstr *);
	int (*d_compare)(const struct dentry___395 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___395 *);
	int (*d_init)(struct dentry___395 *);
	void (*d_release)(struct dentry___395 *);
	void (*d_prune)(struct dentry___395 *);
	void (*d_iput)(struct dentry___395 *, struct inode___395 *);
	char * (*d_dname)(struct dentry___395 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___396 *);
	int (*d_manage)(const struct path___396 *, bool);
	struct dentry___395 * (*d_real)(struct dentry___395 *, const struct inode___395 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___395;

struct mem_dqinfo___395 {
	struct quota_format_type___395 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___395;

struct quota_info___395 {
	unsigned int flags;
	struct rw_semaphore___397 dqio_sem;
	struct inode___395 *files[3];
	struct mem_dqinfo___395 info[3];
	const struct quota_format_ops___395 *ops[3];
};

struct rcuwait___395 {
	struct task_struct___397 *task;
};

struct percpu_rw_semaphore___395 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___397 rw_sem;
	struct rcuwait___395 writer;
	int readers_block;
};

struct sb_writers___395 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___395 rw_sem[3];
};

struct file_system_type___395;

struct super_operations___395;

struct dquot_operations___395;

struct quotactl_ops___395;

struct super_block___395 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___395 *s_type;
	const struct super_operations___395 *s_op;
	const struct dquot_operations___395 *dq_op;
	const struct quotactl_ops___395 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___395 *s_root;
	struct rw_semaphore___397 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___395 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___395 s_dquot;
	struct sb_writers___395 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___395 *s_d_op;
	int cleancache_poolid;
	struct shrinker___137 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___395 {
	struct file___395 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___395 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___395 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___395 *ia_file;
};

struct dquot___395 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___395 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___395 {
	int qf_fmt_id;
	const struct quota_format_ops___395 *qf_ops;
	struct module___325 *qf_owner;
	struct quota_format_type___395 *qf_next;
};

struct quota_format_ops___395 {
	int (*check_quota_file)(struct super_block___395 *, int);
	int (*read_file_info)(struct super_block___395 *, int);
	int (*write_file_info)(struct super_block___395 *, int);
	int (*free_file_info)(struct super_block___395 *, int);
	int (*read_dqblk)(struct dquot___395 *);
	int (*commit_dqblk)(struct dquot___395 *);
	int (*release_dqblk)(struct dquot___395 *);
	int (*get_next_id)(struct super_block___395 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___395 {
	int (*write_dquot)(struct dquot___395 *);
	struct dquot___395 * (*alloc_dquot)(struct super_block___395 *, int);
	void (*destroy_dquot)(struct dquot___395 *);
	int (*acquire_dquot)(struct dquot___395 *);
	int (*release_dquot)(struct dquot___395 *);
	int (*mark_dirty)(struct dquot___395 *);
	int (*write_info)(struct super_block___395 *, int);
	qsize_t * (*get_reserved_space)(struct inode___395 *);
	int (*get_projid)(struct inode___395 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___395 *, qsize_t *);
	int (*get_next_id)(struct super_block___395 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___395 {
	int (*quota_on)(struct super_block___395 *, int, int, const struct path___396 *);
	int (*quota_off)(struct super_block___395 *, int);
	int (*quota_enable)(struct super_block___395 *, unsigned int);
	int (*quota_disable)(struct super_block___395 *, unsigned int);
	int (*quota_sync)(struct super_block___395 *, int);
	int (*set_info)(struct super_block___395 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___395 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___395 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___395 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___395 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___395 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___395 {
	int (*writepage)(struct page___396 *, struct writeback_control___3 *);
	int (*readpage)(struct file___395 *, struct page___396 *);
	int (*writepages)(struct address_space___395 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___396 *);
	int (*readpages)(struct file___395 *, struct address_space___395 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___395 *, struct address_space___395 *, loff_t, unsigned int, unsigned int, struct page___396 **, void **);
	int (*write_end)(struct file___395 *, struct address_space___395 *, loff_t, unsigned int, unsigned int, struct page___396 *, void *);
	sector_t (*bmap)(struct address_space___395 *, sector_t);
	void (*invalidatepage)(struct page___396 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___396 *, gfp_t);
	void (*freepage)(struct page___396 *);
	ssize_t (*direct_IO)(struct kiocb___395 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___395 *, struct page___396 *, struct page___396 *, enum migrate_mode);
	bool (*isolate_page)(struct page___396 *, isolate_mode_t);
	void (*putback_page)(struct page___396 *);
	int (*launder_page)(struct page___396 *);
	int (*is_partially_uptodate)(struct page___396 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___396 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___395 *, struct page___396 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___395 *, sector_t *);
	void (*swap_deactivate)(struct file___395 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___395 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___395 *bd_inode;
	struct super_block___395 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___395 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___395 {
	struct dentry___395 * (*lookup)(struct inode___395 *, struct dentry___395 *, unsigned int);
	const char * (*get_link)(struct dentry___395 *, struct inode___395 *, struct delayed_call *);
	int (*permission)(struct inode___395 *, int);
	struct posix_acl * (*get_acl)(struct inode___395 *, int);
	int (*readlink)(struct dentry___395 *, char *, int);
	int (*create)(struct inode___395 *, struct dentry___395 *, umode_t, bool);
	int (*link)(struct dentry___395 *, struct inode___395 *, struct dentry___395 *);
	int (*unlink)(struct inode___395 *, struct dentry___395 *);
	int (*symlink)(struct inode___395 *, struct dentry___395 *, const char *);
	int (*mkdir)(struct inode___395 *, struct dentry___395 *, umode_t);
	int (*rmdir)(struct inode___395 *, struct dentry___395 *);
	int (*mknod)(struct inode___395 *, struct dentry___395 *, umode_t, dev_t);
	int (*rename)(struct inode___395 *, struct dentry___395 *, struct inode___395 *, struct dentry___395 *, unsigned int);
	int (*setattr)(struct dentry___395 *, struct iattr___395 *);
	int (*getattr)(const struct path___396 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___395 *, char *, size_t);
	int (*fiemap)(struct inode___395 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___395 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___395 *, struct dentry___395 *, struct file___395 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___395 *, struct dentry___395 *, umode_t);
	int (*set_acl)(struct inode___395 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___395 {
	void (*fl_copy_lock)(struct file_lock___395 *, struct file_lock___395 *);
	void (*fl_release_private)(struct file_lock___395 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___395;

struct lock_manager_operations___395;

struct file_lock___395 {
	struct file_lock___395 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___395 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___395 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___395 *fl_ops;
	const struct lock_manager_operations___395 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___395 {
	int (*lm_compare_owner)(struct file_lock___395 *, struct file_lock___395 *);
	long unsigned int (*lm_owner_key)(struct file_lock___395 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___395 *);
	int (*lm_grant)(struct file_lock___395 *, int);
	bool (*lm_break)(struct file_lock___395 *);
	int (*lm_change)(struct file_lock___395 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___395 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___395 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___395 *fa_next;
	struct file___395 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___395 {
	const char *name;
	int fs_flags;
	struct dentry___395 * (*mount)(struct file_system_type___395 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___395 *);
	struct module___325 *owner;
	struct file_system_type___395 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___395 {
	struct inode___395 * (*alloc_inode)(struct super_block___395 *);
	void (*destroy_inode)(struct inode___395 *);
	void (*dirty_inode)(struct inode___395 *, int);
	int (*write_inode)(struct inode___395 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___395 *);
	void (*evict_inode)(struct inode___395 *);
	void (*put_super)(struct super_block___395 *);
	int (*sync_fs)(struct super_block___395 *, int);
	int (*freeze_super)(struct super_block___395 *);
	int (*freeze_fs)(struct super_block___395 *);
	int (*thaw_super)(struct super_block___395 *);
	int (*unfreeze_fs)(struct super_block___395 *);
	int (*statfs)(struct dentry___395 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___395 *, int *, char *);
	void (*umount_begin)(struct super_block___395 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___395 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___395 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___395 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___395 *);
	ssize_t (*quota_read)(struct super_block___395 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___395 *, int, const char *, size_t, loff_t);
	struct dquot___395 ** (*get_dquots)(struct inode___395 *);
	int (*bdev_try_to_free_page)(struct super_block___395 *, struct page___396 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___395 *, struct shrink_control___137 *);
	long int (*free_cached_objects)(struct super_block___395 *, struct shrink_control___137 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___383(struct page___396 *);

typedef int (*iommu_fault_handler_t___9)(struct iommu_domain___8 *, struct device___363 *, long unsigned int, int, void *);

struct iommu_domain___8 {
	unsigned int type;
	const struct iommu_ops___8 *ops;
	long unsigned int pgsize_bitmap;
	iommu_fault_handler_t___9 handler;
	void *handler_token;
	struct iommu_domain_geometry geometry;
	void *iova_cookie;
};

struct kernel_param_ops___323 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___323 *);
	int (*get)(char *, const struct kernel_param___323 *);
	void (*free)(void *);
};

struct kparam_array___323;

struct kernel_param___323 {
	const char *name;
	struct module___325 *mod;
	const struct kernel_param_ops___323 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___323 *arr;
	};
};

struct kparam_array___323 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___323 *ops;
	void *elem;
};

struct module_attribute___323 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___323 *, struct module_kobject___323 *, char *);
	ssize_t (*store)(struct module_attribute___323 *, struct module_kobject___323 *, const char *, size_t);
	void (*setup)(struct module___325 *, const char *);
	int (*test)(struct module___325 *);
	void (*free)(struct module___325 *);
};

struct alias_prop___2 {
	struct list_head link;
	const char *alias;
	struct device_node___95 *np;
	int id;
	char stem[0];
};

struct module___326;

struct file___396;

struct kiocb___396;

struct vm_area_struct___397;

struct inode___396;

struct file_lock___396;

struct page___397;

struct file_operations___396 {
	struct module___326 *owner;
	loff_t (*llseek)(struct file___396 *, loff_t, int);
	ssize_t (*read)(struct file___396 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___396 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___396 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___396 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___396 *, bool);
	int (*iterate)(struct file___396 *, struct dir_context *);
	int (*iterate_shared)(struct file___396 *, struct dir_context *);
	__poll_t (*poll)(struct file___396 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___396 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___396 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___396 *, struct vm_area_struct___397 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___396 *, struct file___396 *);
	int (*flush)(struct file___396 *, fl_owner_t);
	int (*release)(struct inode___396 *, struct file___396 *);
	int (*fsync)(struct file___396 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___396 *, int);
	int (*lock)(struct file___396 *, int, struct file_lock___396 *);
	ssize_t (*sendpage)(struct file___396 *, struct page___397 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___396 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___396 *, int, struct file_lock___396 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___396 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___396 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___396 *, long int, struct file_lock___396 **, void **);
	long int (*fallocate)(struct file___396 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___396 *);
	ssize_t (*copy_file_range)(struct file___396 *, loff_t, struct file___396 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___396 *, loff_t, struct file___396 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___396 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___397 {
	u64 seqnum;
	struct vm_area_struct___397 *vmas[4];
};

struct page_frag___397 {
	struct page___397 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___397;

struct vm_struct___300;

struct task_struct___398 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___398 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___397 *mm;
	struct mm_struct___397 *active_mm;
	struct vmacache___397 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___398 *real_parent;
	struct task_struct___398 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___398 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___227 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___227 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___227 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___2 *ptracer_cred;
	const struct cred___2 *real_cred;
	const struct cred___2 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___398 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___397 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___398 *oom_reaper_list;
	struct vm_struct___300 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___150 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___397 *pgtable_t___397;

struct address_space___396;

struct dev_pagemap___384;

struct page___397 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___396 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___397 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___397 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___397 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___384 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___397;

struct lruvec___397 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___397 *pgdat;
};

struct zone___397 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___397 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___397 {
	struct zone___397 *zone;
	int zone_idx;
};

struct zonelist___397 {
	struct zoneref___397 _zonerefs[25];
};

struct pglist_data___397 {
	struct zone___397 node_zones[3];
	struct zonelist___397 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___398 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___398 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___397 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___398 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___398 *owner;
};

struct secondary_data___398 {
	void *stack;
	struct task_struct___398 *task;
	long int status;
};

struct blocking_notifier_head___397 {
	struct rw_semaphore___398 rwsem;
	struct notifier_block *head;
};

struct dentry___396;

struct path___397 {
	struct vfsmount *mnt;
	struct dentry___396 *dentry;
};

struct file___396 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___397 f_path;
	struct inode___396 *f_inode;
	const struct file_operations___396 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___227 f_owner;
	const struct cred___2 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___396 *f_mapping;
	errseq_t f_wb_err;
};

struct kernfs_root___390;

struct kernfs_elem_dir___390 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___390 *root;
};

struct kernfs_node___391;

struct kernfs_syscall_ops___390;

struct kernfs_root___390 {
	struct kernfs_node___391 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___390 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___390 {
	struct kernfs_node___391 *target_kn;
};

struct kernfs_ops___390;

struct kernfs_elem_attr___390 {
	const struct kernfs_ops___390 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___391 *notify_next;
};

struct kernfs_node___391 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___391 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___390 dir;
		struct kernfs_elem_symlink___390 symlink;
		struct kernfs_elem_attr___390 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___390;

struct kernfs_ops___390 {
	int (*open)(struct kernfs_open_file___390 *);
	void (*release)(struct kernfs_open_file___390 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___390 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___390 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___390 *, struct vm_area_struct___397 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___390 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___390 {
	int (*remount_fs)(struct kernfs_root___390 *, int *, char *);
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___390 *);
	int (*mkdir)(struct kernfs_node___391 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___391 *);
	int (*rename)(struct kernfs_node___391 *, struct kernfs_node___391 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___391 *, struct kernfs_root___390 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_operations_struct___384;

struct kernfs_open_file___390 {
	struct kernfs_node___391 *kn;
	struct file___396 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___384 *vm_ops;
};

struct vm_fault___384;

struct vm_operations_struct___384 {
	void (*open)(struct vm_area_struct___397 *);
	void (*close)(struct vm_area_struct___397 *);
	int (*split)(struct vm_area_struct___397 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___397 *);
	vm_fault_t (*fault)(struct vm_fault___384 *);
	vm_fault_t (*huge_fault)(struct vm_fault___384 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___384 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___397 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___384 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___384 *);
	int (*access)(struct vm_area_struct___397 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___397 *);
	int (*set_policy)(struct vm_area_struct___397 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___397 *, long unsigned int);
	struct page___397 * (*find_special_page)(struct vm_area_struct___397 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_area_struct___397 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___397 *vm_next;
	struct vm_area_struct___397 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___397 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___384 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___396 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___384;

struct bin_attribute___360;

struct attribute_group___361 {
	const char *name;
	umode_t (*is_visible)(struct kobject___384 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___384 *, struct bin_attribute___360 *, int);
	struct attribute **attrs;
	struct bin_attribute___360 **bin_attrs;
};

struct kset___383;

struct kobj_type___383;

struct kobject___384 {
	const char *name;
	struct list_head entry;
	struct kobject___384 *parent;
	struct kset___383 *kset;
	struct kobj_type___383 *ktype;
	struct kernfs_node___391 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___360 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___396 *, struct kobject___384 *, struct bin_attribute___360 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___396 *, struct kobject___384 *, struct bin_attribute___360 *, char *, loff_t, size_t);
	int (*mmap)(struct file___396 *, struct kobject___384 *, struct bin_attribute___360 *, struct vm_area_struct___397 *);
};

struct sysfs_ops___383 {
	ssize_t (*show)(struct kobject___384 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___384 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___383;

struct kset___383 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___384 kobj;
	const struct kset_uevent_ops___383 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___383 {
	void (*release)(struct kobject___384 *);
	const struct sysfs_ops___383 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___29 * (*child_ns_type)(struct kobject___384 *);
	const void * (*namespace)(struct kobject___384 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___383 {
	int (* const filter)(struct kset___383 *, struct kobject___384 *);
	const char * (* const name)(struct kset___383 *, struct kobject___384 *);
	int (* const uevent)(struct kset___383 *, struct kobject___384 *, struct kobj_uevent_env *);
};

struct kobj_attribute___374 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___384 *, struct kobj_attribute___374 *, char *);
	ssize_t (*store)(struct kobject___384 *, struct kobj_attribute___374 *, const char *, size_t);
};

struct kernel_param___324;

struct kernel_param_ops___324 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___324 *);
	int (*get)(char *, const struct kernel_param___324 *);
	void (*free)(void *);
};

struct kparam_array___324;

struct kernel_param___324 {
	const char *name;
	struct module___326 *mod;
	const struct kernel_param_ops___324 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___324 *arr;
	};
};

struct kparam_array___324 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___324 *ops;
	void *elem;
};

struct module_kobject___324 {
	struct kobject___384 kobj;
	struct module___326 *mod;
	struct kobject___384 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___324 {
	struct module___326 *mod;
	struct latch_tree_node node;
};

struct module_layout___324 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___324 mtn;
};

struct module_attribute___324;

struct module___326 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___324 mkobj;
	struct module_attribute___324 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___384 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___324 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___324 core_layout;
	struct module_layout___324 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___324 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___324 *, struct module_kobject___324 *, char *);
	ssize_t (*store)(struct module_attribute___324 *, struct module_kobject___324 *, const char *, size_t);
	void (*setup)(struct module___326 *, const char *);
	int (*test)(struct module___326 *);
	void (*free)(struct module___326 *);
};

struct device___364;

struct dev_pm_ops___364 {
	int (*prepare)(struct device___364 *);
	void (*complete)(struct device___364 *);
	int (*suspend)(struct device___364 *);
	int (*resume)(struct device___364 *);
	int (*freeze)(struct device___364 *);
	int (*thaw)(struct device___364 *);
	int (*poweroff)(struct device___364 *);
	int (*restore)(struct device___364 *);
	int (*suspend_late)(struct device___364 *);
	int (*resume_early)(struct device___364 *);
	int (*freeze_late)(struct device___364 *);
	int (*thaw_early)(struct device___364 *);
	int (*poweroff_late)(struct device___364 *);
	int (*restore_early)(struct device___364 *);
	int (*suspend_noirq)(struct device___364 *);
	int (*resume_noirq)(struct device___364 *);
	int (*freeze_noirq)(struct device___364 *);
	int (*thaw_noirq)(struct device___364 *);
	int (*poweroff_noirq)(struct device___364 *);
	int (*restore_noirq)(struct device___364 *);
	int (*runtime_suspend)(struct device___364 *);
	int (*runtime_resume)(struct device___364 *);
	int (*runtime_idle)(struct device___364 *);
};

struct dev_pm_info___364 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___364 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___364;

struct bus_type___364;

struct device_driver___364;

struct dev_pm_domain___364;

struct irq_domain___32;

struct dma_map_ops___138;

struct device_node___96;

struct fwnode_handle___284;

struct class___364;

struct iommu_fwspec___9;

struct device___364 {
	struct device___364 *parent;
	struct device_private *p;
	struct kobject___384 kobj;
	const char *init_name;
	const struct device_type___364 *type;
	struct mutex mutex;
	struct bus_type___364 *bus;
	struct device_driver___364 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___364 power;
	struct dev_pm_domain___364 *pm_domain;
	struct irq_domain___32 *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___138 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___96 *of_node;
	struct fwnode_handle___284 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___364 *class;
	const struct attribute_group___361 **groups;
	void (*release)(struct device___364 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec___9 *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___364 {
	struct dev_pm_ops___364 ops;
	void (*detach)(struct device___364 *, bool);
	int (*activate)(struct device___364 *);
	void (*sync)(struct device___364 *);
	void (*dismiss)(struct device___364 *);
};

struct core_state___397;

struct mm_struct___397 {
	struct {
		struct vm_area_struct___397 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___396 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___398 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___397 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___398 *owner;
		struct user_namespace___3 *user_ns;
		struct file___396 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___397 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct vm_struct___300 {
	struct vm_struct___300 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___397 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct iommu_ops___9;

struct bus_type___364 {
	const char *name;
	const char *dev_name;
	struct device___364 *dev_root;
	const struct attribute_group___361 **bus_groups;
	const struct attribute_group___361 **dev_groups;
	const struct attribute_group___361 **drv_groups;
	int (*match)(struct device___364 *, struct device_driver___364 *);
	int (*uevent)(struct device___364 *, struct kobj_uevent_env *);
	int (*probe)(struct device___364 *);
	int (*remove)(struct device___364 *);
	void (*shutdown)(struct device___364 *);
	int (*online)(struct device___364 *);
	int (*offline)(struct device___364 *);
	int (*suspend)(struct device___364 *, pm_message_t);
	int (*resume)(struct device___364 *);
	int (*num_vf)(struct device___364 *);
	int (*dma_configure)(struct device___364 *);
	const struct dev_pm_ops___364 *pm;
	const struct iommu_ops___9 *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___364 {
	const char *name;
	struct bus_type___364 *bus;
	struct module___326 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___364 *);
	int (*remove)(struct device___364 *);
	void (*shutdown)(struct device___364 *);
	int (*suspend)(struct device___364 *, pm_message_t);
	int (*resume)(struct device___364 *);
	const struct attribute_group___361 **groups;
	const struct dev_pm_ops___364 *pm;
	void (*coredump)(struct device___364 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct iommu_domain___9;

struct of_phandle_args___16;

struct iommu_ops___9 {
	bool (*capable)(enum iommu_cap);
	struct iommu_domain___9 * (*domain_alloc)(unsigned int);
	void (*domain_free)(struct iommu_domain___9 *);
	int (*attach_dev)(struct iommu_domain___9 *, struct device___364 *);
	void (*detach_dev)(struct iommu_domain___9 *, struct device___364 *);
	int (*map)(struct iommu_domain___9 *, long unsigned int, phys_addr_t, size_t, int);
	size_t (*unmap)(struct iommu_domain___9 *, long unsigned int, size_t);
	void (*flush_iotlb_all)(struct iommu_domain___9 *);
	void (*iotlb_range_add)(struct iommu_domain___9 *, long unsigned int, size_t);
	void (*iotlb_sync)(struct iommu_domain___9 *);
	phys_addr_t (*iova_to_phys)(struct iommu_domain___9 *, dma_addr_t);
	int (*add_device)(struct device___364 *);
	void (*remove_device)(struct device___364 *);
	struct iommu_group * (*device_group)(struct device___364 *);
	int (*domain_get_attr)(struct iommu_domain___9 *, enum iommu_attr, void *);
	int (*domain_set_attr)(struct iommu_domain___9 *, enum iommu_attr, void *);
	void (*get_resv_regions)(struct device___364 *, struct list_head *);
	void (*put_resv_regions)(struct device___364 *, struct list_head *);
	void (*apply_resv_region)(struct device___364 *, struct iommu_domain___9 *, struct iommu_resv_region *);
	int (*domain_window_enable)(struct iommu_domain___9 *, u32, phys_addr_t, u64, int);
	void (*domain_window_disable)(struct iommu_domain___9 *, u32);
	int (*domain_set_windows)(struct iommu_domain___9 *, u32);
	u32 (*domain_get_windows)(struct iommu_domain___9 *);
	int (*of_xlate)(struct device___364 *, struct of_phandle_args___16 *);
	bool (*is_attach_deferred)(struct iommu_domain___9 *, struct device___364 *);
	long unsigned int pgsize_bitmap;
};

struct device_type___364 {
	const char *name;
	const struct attribute_group___361 **groups;
	int (*uevent)(struct device___364 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___364 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___364 *);
	const struct dev_pm_ops___364 *pm;
};

struct class___364 {
	const char *name;
	struct module___326 *owner;
	const struct attribute_group___361 **class_groups;
	const struct attribute_group___361 **dev_groups;
	struct kobject___384 *dev_kobj;
	int (*dev_uevent)(struct device___364 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___364 *, umode_t *);
	void (*class_release)(struct class___364 *);
	void (*dev_release)(struct device___364 *);
	int (*shutdown_pre)(struct device___364 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___364 *);
	const struct dev_pm_ops___364 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

typedef void (*dr_release_t___29)(struct device___364 *, void *);

struct irq_domain_ops___32;

struct irq_domain_chip_generic___19;

struct irq_domain___32 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___32 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___284 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___19 *gc;
	struct irq_domain___32 *parent;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_direct_max_irq;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_tree_mutex;
	unsigned int linear_revmap[0];
};

struct dma_map_ops___138 {
	void * (*alloc)(struct device___364 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___364 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___364 *, struct vm_area_struct___397 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___364 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___364 *, struct page___397 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___364 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___364 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___364 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___364 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___364 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___364 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___364 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___364 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___364 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___364 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___364 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___364 *, u64);
	u64 (*get_required_mask)(struct device___364 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___284;

struct fwnode_handle___284 {
	struct fwnode_handle___284 *secondary;
	const struct fwnode_operations___284 *ops;
};

struct property___92;

struct device_node___96 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___284 fwnode;
	struct property___92 *properties;
	struct property___92 *deadprops;
	struct device_node___96 *parent;
	struct device_node___96 *child;
	struct device_node___96 *sibling;
	struct kobject___384 kobj;
	long unsigned int _flags;
	void *data;
};

struct iommu_fwspec___9 {
	const struct iommu_ops___9 *ops;
	struct fwnode_handle___284 *iommu_fwnode;
	void *iommu_priv;
	unsigned int num_ids;
	u32 ids[1];
};

struct amba_device___6 {
	struct device___364 dev;
	struct resource res;
	struct clk *pclk;
	unsigned int periphid;
	unsigned int irq[9];
	char *driver_override;
};

struct address_space_operations___396;

struct address_space___396 {
	struct inode___396 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___398 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___396 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___384)(struct vm_area_struct___397 *, long unsigned int, const struct page___397 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___384)(struct page___397 *, void *);

struct dev_pagemap___384 {
	dev_page_fault_t___384 page_fault;
	dev_page_free_t___384 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___364 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___397 {
	struct task_struct___398 *task;
	struct core_thread___397 *next;
};

struct core_state___397 {
	atomic_t nr_threads;
	struct core_thread___397 dumper;
	struct completion startup;
};

struct vm_fault___384 {
	struct vm_area_struct___397 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___397 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___397 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___397 prealloc_pte;
};

struct dentry_operations___396;

struct super_block___396;

struct dentry___396 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___396 *d_parent;
	struct qstr d_name;
	struct inode___396 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___396 *d_op;
	struct super_block___396 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___396;

struct block_device___396;

struct inode___396 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___396 *i_op;
	struct super_block___396 *i_sb;
	struct address_space___396 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___398 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___396 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___396 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___396 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___396 {
	int (*d_revalidate)(struct dentry___396 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___396 *, unsigned int);
	int (*d_hash)(const struct dentry___396 *, struct qstr *);
	int (*d_compare)(const struct dentry___396 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___396 *);
	int (*d_init)(struct dentry___396 *);
	void (*d_release)(struct dentry___396 *);
	void (*d_prune)(struct dentry___396 *);
	void (*d_iput)(struct dentry___396 *, struct inode___396 *);
	char * (*d_dname)(struct dentry___396 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___397 *);
	int (*d_manage)(const struct path___397 *, bool);
	struct dentry___396 * (*d_real)(struct dentry___396 *, const struct inode___396 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___396;

struct mem_dqinfo___396 {
	struct quota_format_type___396 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___396;

struct quota_info___396 {
	unsigned int flags;
	struct rw_semaphore___398 dqio_sem;
	struct inode___396 *files[3];
	struct mem_dqinfo___396 info[3];
	const struct quota_format_ops___396 *ops[3];
};

struct rcuwait___396 {
	struct task_struct___398 *task;
};

struct percpu_rw_semaphore___396 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___398 rw_sem;
	struct rcuwait___396 writer;
	int readers_block;
};

struct sb_writers___396 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___396 rw_sem[3];
};

struct file_system_type___396;

struct super_operations___396;

struct dquot_operations___396;

struct quotactl_ops___396;

struct super_block___396 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___396 *s_type;
	const struct super_operations___396 *s_op;
	const struct dquot_operations___396 *dq_op;
	const struct quotactl_ops___396 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___396 *s_root;
	struct rw_semaphore___398 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___396 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___396 s_dquot;
	struct sb_writers___396 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___396 *s_d_op;
	int cleancache_poolid;
	struct shrinker___137 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___396 {
	struct file___396 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___396 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___396 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___396 *ia_file;
};

struct dquot___396 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___396 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___396 {
	int qf_fmt_id;
	const struct quota_format_ops___396 *qf_ops;
	struct module___326 *qf_owner;
	struct quota_format_type___396 *qf_next;
};

struct quota_format_ops___396 {
	int (*check_quota_file)(struct super_block___396 *, int);
	int (*read_file_info)(struct super_block___396 *, int);
	int (*write_file_info)(struct super_block___396 *, int);
	int (*free_file_info)(struct super_block___396 *, int);
	int (*read_dqblk)(struct dquot___396 *);
	int (*commit_dqblk)(struct dquot___396 *);
	int (*release_dqblk)(struct dquot___396 *);
	int (*get_next_id)(struct super_block___396 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___396 {
	int (*write_dquot)(struct dquot___396 *);
	struct dquot___396 * (*alloc_dquot)(struct super_block___396 *, int);
	void (*destroy_dquot)(struct dquot___396 *);
	int (*acquire_dquot)(struct dquot___396 *);
	int (*release_dquot)(struct dquot___396 *);
	int (*mark_dirty)(struct dquot___396 *);
	int (*write_info)(struct super_block___396 *, int);
	qsize_t * (*get_reserved_space)(struct inode___396 *);
	int (*get_projid)(struct inode___396 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___396 *, qsize_t *);
	int (*get_next_id)(struct super_block___396 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___396 {
	int (*quota_on)(struct super_block___396 *, int, int, const struct path___397 *);
	int (*quota_off)(struct super_block___396 *, int);
	int (*quota_enable)(struct super_block___396 *, unsigned int);
	int (*quota_disable)(struct super_block___396 *, unsigned int);
	int (*quota_sync)(struct super_block___396 *, int);
	int (*set_info)(struct super_block___396 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___396 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___396 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___396 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___396 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___396 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___396 {
	int (*writepage)(struct page___397 *, struct writeback_control___3 *);
	int (*readpage)(struct file___396 *, struct page___397 *);
	int (*writepages)(struct address_space___396 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___397 *);
	int (*readpages)(struct file___396 *, struct address_space___396 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___396 *, struct address_space___396 *, loff_t, unsigned int, unsigned int, struct page___397 **, void **);
	int (*write_end)(struct file___396 *, struct address_space___396 *, loff_t, unsigned int, unsigned int, struct page___397 *, void *);
	sector_t (*bmap)(struct address_space___396 *, sector_t);
	void (*invalidatepage)(struct page___397 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___397 *, gfp_t);
	void (*freepage)(struct page___397 *);
	ssize_t (*direct_IO)(struct kiocb___396 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___396 *, struct page___397 *, struct page___397 *, enum migrate_mode);
	bool (*isolate_page)(struct page___397 *, isolate_mode_t);
	void (*putback_page)(struct page___397 *);
	int (*launder_page)(struct page___397 *);
	int (*is_partially_uptodate)(struct page___397 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___397 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___396 *, struct page___397 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___396 *, sector_t *);
	void (*swap_deactivate)(struct file___396 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___396 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___396 *bd_inode;
	struct super_block___396 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___396 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___396 {
	struct dentry___396 * (*lookup)(struct inode___396 *, struct dentry___396 *, unsigned int);
	const char * (*get_link)(struct dentry___396 *, struct inode___396 *, struct delayed_call *);
	int (*permission)(struct inode___396 *, int);
	struct posix_acl * (*get_acl)(struct inode___396 *, int);
	int (*readlink)(struct dentry___396 *, char *, int);
	int (*create)(struct inode___396 *, struct dentry___396 *, umode_t, bool);
	int (*link)(struct dentry___396 *, struct inode___396 *, struct dentry___396 *);
	int (*unlink)(struct inode___396 *, struct dentry___396 *);
	int (*symlink)(struct inode___396 *, struct dentry___396 *, const char *);
	int (*mkdir)(struct inode___396 *, struct dentry___396 *, umode_t);
	int (*rmdir)(struct inode___396 *, struct dentry___396 *);
	int (*mknod)(struct inode___396 *, struct dentry___396 *, umode_t, dev_t);
	int (*rename)(struct inode___396 *, struct dentry___396 *, struct inode___396 *, struct dentry___396 *, unsigned int);
	int (*setattr)(struct dentry___396 *, struct iattr___396 *);
	int (*getattr)(const struct path___397 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___396 *, char *, size_t);
	int (*fiemap)(struct inode___396 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___396 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___396 *, struct dentry___396 *, struct file___396 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___396 *, struct dentry___396 *, umode_t);
	int (*set_acl)(struct inode___396 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___396 {
	void (*fl_copy_lock)(struct file_lock___396 *, struct file_lock___396 *);
	void (*fl_release_private)(struct file_lock___396 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___396;

struct lock_manager_operations___396;

struct file_lock___396 {
	struct file_lock___396 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___396 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___396 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___396 *fl_ops;
	const struct lock_manager_operations___396 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___396 {
	int (*lm_compare_owner)(struct file_lock___396 *, struct file_lock___396 *);
	long unsigned int (*lm_owner_key)(struct file_lock___396 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___396 *);
	int (*lm_grant)(struct file_lock___396 *, int);
	bool (*lm_break)(struct file_lock___396 *);
	int (*lm_change)(struct file_lock___396 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___396 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___396 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___396 *fa_next;
	struct file___396 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___396 {
	const char *name;
	int fs_flags;
	struct dentry___396 * (*mount)(struct file_system_type___396 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___396 *);
	struct module___326 *owner;
	struct file_system_type___396 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___396 {
	struct inode___396 * (*alloc_inode)(struct super_block___396 *);
	void (*destroy_inode)(struct inode___396 *);
	void (*dirty_inode)(struct inode___396 *, int);
	int (*write_inode)(struct inode___396 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___396 *);
	void (*evict_inode)(struct inode___396 *);
	void (*put_super)(struct super_block___396 *);
	int (*sync_fs)(struct super_block___396 *, int);
	int (*freeze_super)(struct super_block___396 *);
	int (*freeze_fs)(struct super_block___396 *);
	int (*thaw_super)(struct super_block___396 *);
	int (*unfreeze_fs)(struct super_block___396 *);
	int (*statfs)(struct dentry___396 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___396 *, int *, char *);
	void (*umount_begin)(struct super_block___396 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___396 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___396 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___396 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___396 *);
	ssize_t (*quota_read)(struct super_block___396 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___396 *, int, const char *, size_t, loff_t);
	struct dquot___396 ** (*get_dquots)(struct inode___396 *);
	int (*bdev_try_to_free_page)(struct super_block___396 *, struct page___397 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___396 *, struct shrink_control___137 *);
	long int (*free_cached_objects)(struct super_block___396 *, struct shrink_control___137 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___384(struct page___397 *);

struct fwnode_reference_args___284;

struct fwnode_endpoint___284;

struct fwnode_operations___284 {
	struct fwnode_handle___284 * (*get)(struct fwnode_handle___284 *);
	void (*put)(struct fwnode_handle___284 *);
	bool (*device_is_available)(const struct fwnode_handle___284 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___284 *, const struct device___364 *);
	bool (*property_present)(const struct fwnode_handle___284 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___284 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___284 *, const char *, const char **, size_t);
	struct fwnode_handle___284 * (*get_parent)(const struct fwnode_handle___284 *);
	struct fwnode_handle___284 * (*get_next_child_node)(const struct fwnode_handle___284 *, struct fwnode_handle___284 *);
	struct fwnode_handle___284 * (*get_named_child_node)(const struct fwnode_handle___284 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___284 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___284 *);
	struct fwnode_handle___284 * (*graph_get_next_endpoint)(const struct fwnode_handle___284 *, struct fwnode_handle___284 *);
	struct fwnode_handle___284 * (*graph_get_remote_endpoint)(const struct fwnode_handle___284 *);
	struct fwnode_handle___284 * (*graph_get_port_parent)(struct fwnode_handle___284 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___284 *, struct fwnode_endpoint___284 *);
};

struct fwnode_endpoint___284 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___284 *local_fwnode;
};

struct fwnode_reference_args___284 {
	struct fwnode_handle___284 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct property___92 {
	char *name;
	int length;
	void *value;
	struct property___92 *next;
	long unsigned int _flags;
	struct bin_attribute___360 attr;
};

struct of_phandle_args___16 {
	struct device_node___96 *np;
	int args_count;
	uint32_t args[16];
};

struct of_reconfig_data___3 {
	struct device_node___96 *dn;
	struct property___92 *prop;
	struct property___92 *old_prop;
};

struct node___218 {
	struct device___364 dev;
};

struct platform_device___26 {
	const char *name;
	int id;
	bool id_auto;
	struct device___364 dev;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct of_dev_auxdata {
	char *compatible;
	resource_size_t phys_addr;
	char *name;
	void *platform_data;
};

typedef int (*iommu_fault_handler_t___10)(struct iommu_domain___9 *, struct device___364 *, long unsigned int, int, void *);

struct iommu_domain___9 {
	unsigned int type;
	const struct iommu_ops___9 *ops;
	long unsigned int pgsize_bitmap;
	iommu_fault_handler_t___10 handler;
	void *handler_token;
	struct iommu_domain_geometry geometry;
	void *iova_cookie;
};

struct irq_desc___24;

typedef void (*irq_flow_handler_t___24)(struct irq_desc___24 *);

struct irq_chip___32;

struct irq_data___32 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___11 *common;
	struct irq_chip___32 *chip;
	struct irq_domain___32 *domain;
	struct irq_data___32 *parent_data;
	void *chip_data;
};

struct irq_desc___24 {
	struct irq_common_data___11 irq_common_data;
	struct irq_data___32 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___24 handle_irq;
	struct irqaction___11 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int irq_count;
	unsigned int tot_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___384 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___326 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip___32 {
	struct device___364 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___32 *);
	void (*irq_shutdown)(struct irq_data___32 *);
	void (*irq_enable)(struct irq_data___32 *);
	void (*irq_disable)(struct irq_data___32 *);
	void (*irq_ack)(struct irq_data___32 *);
	void (*irq_mask)(struct irq_data___32 *);
	void (*irq_mask_ack)(struct irq_data___32 *);
	void (*irq_unmask)(struct irq_data___32 *);
	void (*irq_eoi)(struct irq_data___32 *);
	int (*irq_set_affinity)(struct irq_data___32 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___32 *);
	int (*irq_set_type)(struct irq_data___32 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___32 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___32 *);
	void (*irq_bus_sync_unlock)(struct irq_data___32 *);
	void (*irq_cpu_online)(struct irq_data___32 *);
	void (*irq_cpu_offline)(struct irq_data___32 *);
	void (*irq_suspend)(struct irq_data___32 *);
	void (*irq_resume)(struct irq_data___32 *);
	void (*irq_pm_shutdown)(struct irq_data___32 *);
	void (*irq_calc_mask)(struct irq_data___32 *);
	void (*irq_print_chip)(struct irq_data___32 *, struct seq_file___9 *);
	int (*irq_request_resources)(struct irq_data___32 *);
	void (*irq_release_resources)(struct irq_data___32 *);
	void (*irq_compose_msi_msg)(struct irq_data___32 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___32 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___32 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___32 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___32 *, void *);
	void (*ipi_send_single)(struct irq_data___32 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___32 *, const struct cpumask *);
	long unsigned int flags;
};

struct irq_chip_type___20 {
	struct irq_chip___32 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___24 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___20 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___20 *);
	void (*resume)(struct irq_chip_generic___20 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___32 *domain;
	struct list_head list;
	struct irq_chip_type___20 chip_types[0];
};

struct irq_domain_chip_generic___19 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___20 *gc[0];
};

struct irq_fwspec___32 {
	struct fwnode_handle___284 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___32 {
	int (*match)(struct irq_domain___32 *, struct device_node___96 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___32 *, struct irq_fwspec___32 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___32 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___32 *, unsigned int);
	int (*xlate)(struct irq_domain___32 *, struct device_node___96 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___32 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___32 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___32 *, struct irq_data___32 *, bool);
	void (*deactivate)(struct irq_domain___32 *, struct irq_data___32 *);
	int (*translate)(struct irq_domain___32 *, struct irq_fwspec___32 *, long unsigned int *, unsigned int *);
};

struct of_endpoint {
	unsigned int port;
	unsigned int id;
	const struct device_node___96 *local_node;
};

struct of_changeset_entry {
	struct list_head node;
	long unsigned int action;
	struct device_node___95 *np;
	struct property___91 *prop;
	struct property___91 *old_prop;
};

struct of_changeset {
	struct list_head entries;
};

struct of_bus {
	void (*count_cells)(const void *, int, int *, int *);
	u64 (*map)(__be32 *, const __be32 *, int, int, int);
	int (*translate)(__be32 *, u64, int);
};

struct of_bus___2 {
	const char *name;
	const char *addresses;
	int (*match)(struct device_node___5 *);
	void (*count_cells)(struct device_node___5 *, int *, int *);
	u64 (*map)(__be32 *, const __be32 *, int, int, int);
	int (*translate)(__be32 *, u64, int);
	unsigned int (*get_flags)(const __be32 *);
};

typedef int (*of_irq_init_cb_t)(struct device_node___44 *, struct device_node___44 *);

struct of_intc_desc {
	struct list_head list;
	of_irq_init_cb_t irq_init_cb;
	struct device_node___44 *dev;
	struct device_node___44 *interrupt_parent;
};

struct nvmem_cell;

struct module___327;

struct file___397;

struct kiocb___397;

struct iov_iter___167;

struct vm_area_struct___398;

struct inode___397;

struct file_lock___397;

struct page___398;

struct pipe_inode_info___81;

struct seq_file___336;

struct file_operations___397 {
	struct module___327 *owner;
	loff_t (*llseek)(struct file___397 *, loff_t, int);
	ssize_t (*read)(struct file___397 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___397 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___397 *, struct iov_iter___167 *);
	ssize_t (*write_iter)(struct kiocb___397 *, struct iov_iter___167 *);
	int (*iopoll)(struct kiocb___397 *, bool);
	int (*iterate)(struct file___397 *, struct dir_context *);
	int (*iterate_shared)(struct file___397 *, struct dir_context *);
	__poll_t (*poll)(struct file___397 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___397 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___397 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___397 *, struct vm_area_struct___398 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___397 *, struct file___397 *);
	int (*flush)(struct file___397 *, fl_owner_t);
	int (*release)(struct inode___397 *, struct file___397 *);
	int (*fsync)(struct file___397 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___397 *, int);
	int (*lock)(struct file___397 *, int, struct file_lock___397 *);
	ssize_t (*sendpage)(struct file___397 *, struct page___398 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___397 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___397 *, int, struct file_lock___397 *);
	ssize_t (*splice_write)(struct pipe_inode_info___81 *, struct file___397 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___397 *, loff_t *, struct pipe_inode_info___81 *, size_t, unsigned int);
	int (*setlease)(struct file___397 *, long int, struct file_lock___397 **, void **);
	long int (*fallocate)(struct file___397 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___336 *, struct file___397 *);
	ssize_t (*copy_file_range)(struct file___397 *, loff_t, struct file___397 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___397 *, loff_t, struct file___397 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___397 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___398 {
	u64 seqnum;
	struct vm_area_struct___398 *vmas[4];
};

struct page_frag___398 {
	struct page___398 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___398;

struct cred___365;

struct nsproxy___292;

struct signal_struct___272;

struct css_set___246;

struct vm_struct___301;

struct task_struct___399 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___399 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___398 *mm;
	struct mm_struct___398 *active_mm;
	struct vmacache___398 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___399 *real_parent;
	struct task_struct___399 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___399 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___227 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___227 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___227 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___365 *ptracer_cred;
	const struct cred___365 *real_cred;
	const struct cred___365 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___292 *nsproxy;
	struct signal_struct___272 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___399 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___246 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___81 *splice_pipe;
	struct page_frag___398 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___399 *oom_reaper_list;
	struct vm_struct___301 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___150 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___398 *pgtable_t___398;

struct address_space___397;

struct dev_pagemap___385;

struct page___398 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___397 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___398 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___398 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___398 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___385 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___398;

struct lruvec___398 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___398 *pgdat;
};

struct zone___398 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___398 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___398 {
	struct zone___398 *zone;
	int zone_idx;
};

struct zonelist___398 {
	struct zoneref___398 _zonerefs[25];
};

struct pglist_data___398 {
	struct zone___398 node_zones[3];
	struct zonelist___398 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___399 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___399 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___398 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___399 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___399 *owner;
};

struct secondary_data___399 {
	void *stack;
	struct task_struct___399 *task;
	long int status;
};

struct blocking_notifier_head___398 {
	struct rw_semaphore___399 rwsem;
	struct notifier_block *head;
};

struct key___365;

struct ucounts___262;

struct user_namespace___262 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___262 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___9 ns;
	long unsigned int flags;
	struct key___365 *persistent_keyring_register;
	struct rw_semaphore___399 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___262 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_root___391;

struct kernfs_elem_dir___391 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___391 *root;
};

struct kernfs_node___392;

struct kernfs_syscall_ops___391;

struct kernfs_root___391 {
	struct kernfs_node___392 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___391 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___391 {
	struct kernfs_node___392 *target_kn;
};

struct kernfs_ops___391;

struct kernfs_elem_attr___391 {
	const struct kernfs_ops___391 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___392 *notify_next;
};

struct kernfs_node___392 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___392 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___391 dir;
		struct kernfs_elem_symlink___391 symlink;
		struct kernfs_elem_attr___391 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___391;

struct kernfs_ops___391 {
	int (*open)(struct kernfs_open_file___391 *);
	void (*release)(struct kernfs_open_file___391 *);
	int (*seq_show)(struct seq_file___336 *, void *);
	void * (*seq_start)(struct seq_file___336 *, loff_t *);
	void * (*seq_next)(struct seq_file___336 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___336 *, void *);
	ssize_t (*read)(struct kernfs_open_file___391 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___391 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___391 *, struct vm_area_struct___398 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___391 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___391 {
	int (*remount_fs)(struct kernfs_root___391 *, int *, char *);
	int (*show_options)(struct seq_file___336 *, struct kernfs_root___391 *);
	int (*mkdir)(struct kernfs_node___392 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___392 *);
	int (*rename)(struct kernfs_node___392 *, struct kernfs_node___392 *, const char *);
	int (*show_path)(struct seq_file___336 *, struct kernfs_node___392 *, struct kernfs_root___391 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___336;

struct seq_file___336 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___336 *op;
	int poll_event;
	const struct file___397 *file;
	void *private;
};

struct vm_operations_struct___385;

struct kernfs_open_file___391 {
	struct kernfs_node___392 *kn;
	struct file___397 *file;
	struct seq_file___336 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___385 *vm_ops;
};

struct dentry___397;

struct path___398 {
	struct vfsmount *mnt;
	struct dentry___397 *dentry;
};

struct file___397 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___398 f_path;
	struct inode___397 *f_inode;
	const struct file_operations___397 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___227 f_owner;
	const struct cred___365 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___397 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___385;

struct vm_operations_struct___385 {
	void (*open)(struct vm_area_struct___398 *);
	void (*close)(struct vm_area_struct___398 *);
	int (*split)(struct vm_area_struct___398 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___398 *);
	vm_fault_t (*fault)(struct vm_fault___385 *);
	vm_fault_t (*huge_fault)(struct vm_fault___385 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___385 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___398 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___385 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___385 *);
	int (*access)(struct vm_area_struct___398 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___398 *);
	int (*set_policy)(struct vm_area_struct___398 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___398 *, long unsigned int);
	struct page___398 * (*find_special_page)(struct vm_area_struct___398 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_area_struct___398 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___398 *vm_next;
	struct vm_area_struct___398 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___398 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___385 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___397 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___385;

struct bin_attribute___361;

struct attribute_group___362 {
	const char *name;
	umode_t (*is_visible)(struct kobject___385 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___385 *, struct bin_attribute___361 *, int);
	struct attribute **attrs;
	struct bin_attribute___361 **bin_attrs;
};

struct kset___384;

struct kobj_type___384;

struct kobject___385 {
	const char *name;
	struct list_head entry;
	struct kobject___385 *parent;
	struct kset___384 *kset;
	struct kobj_type___384 *ktype;
	struct kernfs_node___392 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___361 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___397 *, struct kobject___385 *, struct bin_attribute___361 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___397 *, struct kobject___385 *, struct bin_attribute___361 *, char *, loff_t, size_t);
	int (*mmap)(struct file___397 *, struct kobject___385 *, struct bin_attribute___361 *, struct vm_area_struct___398 *);
};

struct sysfs_ops___384 {
	ssize_t (*show)(struct kobject___385 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___385 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___384;

struct kset___384 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___385 kobj;
	const struct kset_uevent_ops___384 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___384 {
	void (*release)(struct kobject___385 *);
	const struct sysfs_ops___384 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___29 * (*child_ns_type)(struct kobject___385 *);
	const void * (*namespace)(struct kobject___385 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___384 {
	int (* const filter)(struct kset___384 *, struct kobject___385 *);
	const char * (* const name)(struct kset___384 *, struct kobject___385 *);
	int (* const uevent)(struct kset___384 *, struct kobject___385 *, struct kobj_uevent_env *);
};

struct kobj_attribute___375 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___385 *, struct kobj_attribute___375 *, char *);
	ssize_t (*store)(struct kobject___385 *, struct kobj_attribute___375 *, const char *, size_t);
};

struct device___365;

struct dev_pm_ops___365 {
	int (*prepare)(struct device___365 *);
	void (*complete)(struct device___365 *);
	int (*suspend)(struct device___365 *);
	int (*resume)(struct device___365 *);
	int (*freeze)(struct device___365 *);
	int (*thaw)(struct device___365 *);
	int (*poweroff)(struct device___365 *);
	int (*restore)(struct device___365 *);
	int (*suspend_late)(struct device___365 *);
	int (*resume_early)(struct device___365 *);
	int (*freeze_late)(struct device___365 *);
	int (*thaw_early)(struct device___365 *);
	int (*poweroff_late)(struct device___365 *);
	int (*restore_early)(struct device___365 *);
	int (*suspend_noirq)(struct device___365 *);
	int (*resume_noirq)(struct device___365 *);
	int (*freeze_noirq)(struct device___365 *);
	int (*thaw_noirq)(struct device___365 *);
	int (*poweroff_noirq)(struct device___365 *);
	int (*restore_noirq)(struct device___365 *);
	int (*runtime_suspend)(struct device___365 *);
	int (*runtime_resume)(struct device___365 *);
	int (*runtime_idle)(struct device___365 *);
};

struct dev_pm_info___365 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___365 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___365;

struct bus_type___365;

struct device_driver___365;

struct dev_pm_domain___365;

struct irq_domain___33;

struct dma_map_ops___139;

struct device_node___97;

struct fwnode_handle___285;

struct class___365;

struct device___365 {
	struct device___365 *parent;
	struct device_private *p;
	struct kobject___385 kobj;
	const char *init_name;
	const struct device_type___365 *type;
	struct mutex mutex;
	struct bus_type___365 *bus;
	struct device_driver___365 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___365 power;
	struct dev_pm_domain___365 *pm_domain;
	struct irq_domain___33 *msi_domain;
	struct dev_pin_info___4 *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___139 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___97 *of_node;
	struct fwnode_handle___285 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___365 *class;
	const struct attribute_group___362 **groups;
	void (*release)(struct device___365 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___365 {
	struct dev_pm_ops___365 ops;
	void (*detach)(struct device___365 *, bool);
	int (*activate)(struct device___365 *);
	void (*sync)(struct device___365 *);
	void (*dismiss)(struct device___365 *);
};

struct user_struct___365 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___365 *uid_keyring;
	struct key___365 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___398;

struct mm_struct___398 {
	struct {
		struct vm_area_struct___398 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___397 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___399 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___398 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___399 *owner;
		struct user_namespace___262 *user_ns;
		struct file___397 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___398 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___365 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___365 *session_keyring;
	struct key___365 *process_keyring;
	struct key___365 *thread_keyring;
	struct key___365 *request_key_auth;
	void *security;
	struct user_struct___365 *user;
	struct user_namespace___262 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___57;

struct cgroup_namespace___246;

struct nsproxy___292 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net___57 *net_ns;
	struct cgroup_namespace___246 *cgroup_ns;
};

struct signal_struct___272 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___399 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___399 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___227 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___227 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___398 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___227 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___246;

struct cgroup___246;

struct css_set___246 {
	struct cgroup_subsys_state___246 *subsys[13];
	refcount_t refcount;
	struct css_set___246 *dom_cset;
	struct cgroup___246 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___246 *mg_src_cgrp;
	struct cgroup___246 *mg_dst_cgrp;
	struct css_set___246 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___397;

struct pipe_buffer___81;

struct pipe_inode_info___81 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___398 *tmp_page;
	struct fasync_struct___397 *fasync_readers;
	struct fasync_struct___397 *fasync_writers;
	struct pipe_buffer___81 *bufs;
	struct user_struct___365 *user;
};

struct vm_struct___301 {
	struct vm_struct___301 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___398 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___284 {
	struct task_struct___399 task;
	long unsigned int stack[8192];
};

struct bus_type___365 {
	const char *name;
	const char *dev_name;
	struct device___365 *dev_root;
	const struct attribute_group___362 **bus_groups;
	const struct attribute_group___362 **dev_groups;
	const struct attribute_group___362 **drv_groups;
	int (*match)(struct device___365 *, struct device_driver___365 *);
	int (*uevent)(struct device___365 *, struct kobj_uevent_env *);
	int (*probe)(struct device___365 *);
	int (*remove)(struct device___365 *);
	void (*shutdown)(struct device___365 *);
	int (*online)(struct device___365 *);
	int (*offline)(struct device___365 *);
	int (*suspend)(struct device___365 *, pm_message_t);
	int (*resume)(struct device___365 *);
	int (*num_vf)(struct device___365 *);
	int (*dma_configure)(struct device___365 *);
	const struct dev_pm_ops___365 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___365 {
	const char *name;
	struct bus_type___365 *bus;
	struct module___327 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___365 *);
	int (*remove)(struct device___365 *);
	void (*shutdown)(struct device___365 *);
	int (*suspend)(struct device___365 *, pm_message_t);
	int (*resume)(struct device___365 *);
	const struct attribute_group___362 **groups;
	const struct dev_pm_ops___365 *pm;
	void (*coredump)(struct device___365 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___365 {
	const char *name;
	const struct attribute_group___362 **groups;
	int (*uevent)(struct device___365 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___365 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___365 *);
	const struct dev_pm_ops___365 *pm;
};

struct module_kobject___325 {
	struct kobject___385 kobj;
	struct module___327 *mod;
	struct kobject___385 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___325 {
	struct module___327 *mod;
	struct latch_tree_node node;
};

struct module_layout___325 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___325 mtn;
};

struct module_attribute___325;

struct kernel_param___325;

struct module___327 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___325 mkobj;
	struct module_attribute___325 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___385 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___325 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___325 core_layout;
	struct module_layout___325 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide38;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide39;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct class___365 {
	const char *name;
	struct module___327 *owner;
	const struct attribute_group___362 **class_groups;
	const struct attribute_group___362 **dev_groups;
	struct kobject___385 *dev_kobj;
	int (*dev_uevent)(struct device___365 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___365 *, umode_t *);
	void (*class_release)(struct class___365 *);
	void (*dev_release)(struct device___365 *);
	int (*shutdown_pre)(struct device___365 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___365 *);
	const struct dev_pm_ops___365 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct irq_domain_ops___33;

struct irq_domain_chip_generic___20;

struct irq_domain___33 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___33 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___285 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___20 *gc;
	struct irq_domain___33 *parent;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_direct_max_irq;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_tree_mutex;
	unsigned int linear_revmap[0];
};

struct dma_map_ops___139 {
	void * (*alloc)(struct device___365 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___365 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___365 *, struct vm_area_struct___398 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___365 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___365 *, struct page___398 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___365 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___365 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___365 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___365 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___365 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___365 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___365 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___365 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___365 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___365 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___365 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___365 *, u64);
	u64 (*get_required_mask)(struct device___365 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___285;

struct fwnode_handle___285 {
	struct fwnode_handle___285 *secondary;
	const struct fwnode_operations___285 *ops;
};

struct property___93;

struct device_node___97 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___285 fwnode;
	struct property___93 *properties;
	struct property___93 *deadprops;
	struct device_node___97 *parent;
	struct device_node___97 *child;
	struct device_node___97 *sibling;
	struct kobject___385 kobj;
	long unsigned int _flags;
	void *data;
};

struct address_space_operations___397;

struct address_space___397 {
	struct inode___397 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___399 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___397 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___385)(struct vm_area_struct___398 *, long unsigned int, const struct page___398 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___385)(struct page___398 *, void *);

struct dev_pagemap___385 {
	dev_page_fault_t___385 page_fault;
	dev_page_free_t___385 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___365 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___398 {
	struct task_struct___399 *task;
	struct core_thread___398 *next;
};

struct core_state___398 {
	atomic_t nr_threads;
	struct core_thread___398 dumper;
	struct completion startup;
};

struct vm_fault___385 {
	struct vm_area_struct___398 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___398 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___398 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___398 prealloc_pte;
};

struct iov_iter___167 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___3 *bvec;
		struct pipe_inode_info___81 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct kiocb___397 {
	struct file___397 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___397 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dentry_operations___397;

struct super_block___397;

struct dentry___397 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___397 *d_parent;
	struct qstr d_name;
	struct inode___397 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___397 *d_op;
	struct super_block___397 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___397;

struct block_device___397;

struct inode___397 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___397 *i_op;
	struct super_block___397 *i_sb;
	struct address_space___397 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___399 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___397 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___397 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___81 *i_pipe;
		struct block_device___397 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___397 {
	int (*d_revalidate)(struct dentry___397 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___397 *, unsigned int);
	int (*d_hash)(const struct dentry___397 *, struct qstr *);
	int (*d_compare)(const struct dentry___397 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___397 *);
	int (*d_init)(struct dentry___397 *);
	void (*d_release)(struct dentry___397 *);
	void (*d_prune)(struct dentry___397 *);
	void (*d_iput)(struct dentry___397 *, struct inode___397 *);
	char * (*d_dname)(struct dentry___397 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___398 *);
	int (*d_manage)(const struct path___398 *, bool);
	struct dentry___397 * (*d_real)(struct dentry___397 *, const struct inode___397 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___397;

struct mem_dqinfo___397 {
	struct quota_format_type___397 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___397;

struct quota_info___397 {
	unsigned int flags;
	struct rw_semaphore___399 dqio_sem;
	struct inode___397 *files[3];
	struct mem_dqinfo___397 info[3];
	const struct quota_format_ops___397 *ops[3];
};

struct rcuwait___397 {
	struct task_struct___399 *task;
};

struct percpu_rw_semaphore___397 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___399 rw_sem;
	struct rcuwait___397 writer;
	int readers_block;
};

struct sb_writers___397 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___397 rw_sem[3];
};

struct file_system_type___397;

struct super_operations___397;

struct dquot_operations___397;

struct quotactl_ops___397;

struct super_block___397 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___397 *s_type;
	const struct super_operations___397 *s_op;
	const struct dquot_operations___397 *dq_op;
	const struct quotactl_ops___397 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___397 *s_root;
	struct rw_semaphore___399 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___397 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___397 s_dquot;
	struct sb_writers___397 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___397 *s_d_op;
	int cleancache_poolid;
	struct shrinker___137 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___262 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct iattr___397 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___397 *ia_file;
};

struct dquot___397 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___397 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___397 {
	int qf_fmt_id;
	const struct quota_format_ops___397 *qf_ops;
	struct module___327 *qf_owner;
	struct quota_format_type___397 *qf_next;
};

struct quota_format_ops___397 {
	int (*check_quota_file)(struct super_block___397 *, int);
	int (*read_file_info)(struct super_block___397 *, int);
	int (*write_file_info)(struct super_block___397 *, int);
	int (*free_file_info)(struct super_block___397 *, int);
	int (*read_dqblk)(struct dquot___397 *);
	int (*commit_dqblk)(struct dquot___397 *);
	int (*release_dqblk)(struct dquot___397 *);
	int (*get_next_id)(struct super_block___397 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___397 {
	int (*write_dquot)(struct dquot___397 *);
	struct dquot___397 * (*alloc_dquot)(struct super_block___397 *, int);
	void (*destroy_dquot)(struct dquot___397 *);
	int (*acquire_dquot)(struct dquot___397 *);
	int (*release_dquot)(struct dquot___397 *);
	int (*mark_dirty)(struct dquot___397 *);
	int (*write_info)(struct super_block___397 *, int);
	qsize_t * (*get_reserved_space)(struct inode___397 *);
	int (*get_projid)(struct inode___397 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___397 *, qsize_t *);
	int (*get_next_id)(struct super_block___397 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___397 {
	int (*quota_on)(struct super_block___397 *, int, int, const struct path___398 *);
	int (*quota_off)(struct super_block___397 *, int);
	int (*quota_enable)(struct super_block___397 *, unsigned int);
	int (*quota_disable)(struct super_block___397 *, unsigned int);
	int (*quota_sync)(struct super_block___397 *, int);
	int (*set_info)(struct super_block___397 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___397 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___397 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___397 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___397 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___397 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___397 {
	int (*writepage)(struct page___398 *, struct writeback_control___3 *);
	int (*readpage)(struct file___397 *, struct page___398 *);
	int (*writepages)(struct address_space___397 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___398 *);
	int (*readpages)(struct file___397 *, struct address_space___397 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___397 *, struct address_space___397 *, loff_t, unsigned int, unsigned int, struct page___398 **, void **);
	int (*write_end)(struct file___397 *, struct address_space___397 *, loff_t, unsigned int, unsigned int, struct page___398 *, void *);
	sector_t (*bmap)(struct address_space___397 *, sector_t);
	void (*invalidatepage)(struct page___398 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___398 *, gfp_t);
	void (*freepage)(struct page___398 *);
	ssize_t (*direct_IO)(struct kiocb___397 *, struct iov_iter___167 *);
	int (*migratepage)(struct address_space___397 *, struct page___398 *, struct page___398 *, enum migrate_mode);
	bool (*isolate_page)(struct page___398 *, isolate_mode_t);
	void (*putback_page)(struct page___398 *);
	int (*launder_page)(struct page___398 *);
	int (*is_partially_uptodate)(struct page___398 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___398 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___397 *, struct page___398 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___397 *, sector_t *);
	void (*swap_deactivate)(struct file___397 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___397 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___397 *bd_inode;
	struct super_block___397 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___397 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___397 {
	struct dentry___397 * (*lookup)(struct inode___397 *, struct dentry___397 *, unsigned int);
	const char * (*get_link)(struct dentry___397 *, struct inode___397 *, struct delayed_call *);
	int (*permission)(struct inode___397 *, int);
	struct posix_acl * (*get_acl)(struct inode___397 *, int);
	int (*readlink)(struct dentry___397 *, char *, int);
	int (*create)(struct inode___397 *, struct dentry___397 *, umode_t, bool);
	int (*link)(struct dentry___397 *, struct inode___397 *, struct dentry___397 *);
	int (*unlink)(struct inode___397 *, struct dentry___397 *);
	int (*symlink)(struct inode___397 *, struct dentry___397 *, const char *);
	int (*mkdir)(struct inode___397 *, struct dentry___397 *, umode_t);
	int (*rmdir)(struct inode___397 *, struct dentry___397 *);
	int (*mknod)(struct inode___397 *, struct dentry___397 *, umode_t, dev_t);
	int (*rename)(struct inode___397 *, struct dentry___397 *, struct inode___397 *, struct dentry___397 *, unsigned int);
	int (*setattr)(struct dentry___397 *, struct iattr___397 *);
	int (*getattr)(const struct path___398 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___397 *, char *, size_t);
	int (*fiemap)(struct inode___397 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___397 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___397 *, struct dentry___397 *, struct file___397 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___397 *, struct dentry___397 *, umode_t);
	int (*set_acl)(struct inode___397 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___397 {
	void (*fl_copy_lock)(struct file_lock___397 *, struct file_lock___397 *);
	void (*fl_release_private)(struct file_lock___397 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___397;

struct file_lock___397 {
	struct file_lock___397 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___397 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___397 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___397 *fl_ops;
	const struct lock_manager_operations___397 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___397 {
	int (*lm_compare_owner)(struct file_lock___397 *, struct file_lock___397 *);
	long unsigned int (*lm_owner_key)(struct file_lock___397 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___397 *);
	int (*lm_grant)(struct file_lock___397 *, int);
	bool (*lm_break)(struct file_lock___397 *);
	int (*lm_change)(struct file_lock___397 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___397 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___397 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___397 *fa_next;
	struct file___397 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___397 {
	const char *name;
	int fs_flags;
	struct dentry___397 * (*mount)(struct file_system_type___397 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___397 *);
	struct module___327 *owner;
	struct file_system_type___397 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___397 {
	struct inode___397 * (*alloc_inode)(struct super_block___397 *);
	void (*destroy_inode)(struct inode___397 *);
	void (*dirty_inode)(struct inode___397 *, int);
	int (*write_inode)(struct inode___397 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___397 *);
	void (*evict_inode)(struct inode___397 *);
	void (*put_super)(struct super_block___397 *);
	int (*sync_fs)(struct super_block___397 *, int);
	int (*freeze_super)(struct super_block___397 *);
	int (*freeze_fs)(struct super_block___397 *);
	int (*thaw_super)(struct super_block___397 *);
	int (*unfreeze_fs)(struct super_block___397 *);
	int (*statfs)(struct dentry___397 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___397 *, int *, char *);
	void (*umount_begin)(struct super_block___397 *);
	int (*show_options)(struct seq_file___336 *, struct dentry___397 *);
	int (*show_devname)(struct seq_file___336 *, struct dentry___397 *);
	int (*show_path)(struct seq_file___336 *, struct dentry___397 *);
	int (*show_stats)(struct seq_file___336 *, struct dentry___397 *);
	ssize_t (*quota_read)(struct super_block___397 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___397 *, int, const char *, size_t, loff_t);
	struct dquot___397 ** (*get_dquots)(struct inode___397 *);
	int (*bdev_try_to_free_page)(struct super_block___397 *, struct page___398 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___397 *, struct shrink_control___137 *);
	long int (*free_cached_objects)(struct super_block___397 *, struct shrink_control___137 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct net_device___47;

struct nf_bridge_info___45;

struct sk_buff___47 {
	union {
		struct {
			struct sk_buff___47 *next;
			struct sk_buff___47 *prev;
			union {
				struct net_device___47 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___30 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___47 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___45 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___45;

struct netns_frags___45 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___45 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv4___45 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct sock *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock **tcp_sk;
	struct netns_frags___45 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct dst_ops___56 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___56 *);
	struct dst_entry___2 * (*check)(struct dst_entry___2 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___2 *);
	unsigned int (*mtu)(const struct dst_entry___2 *);
	u32 * (*cow_metrics)(struct dst_entry___2 *, long unsigned int);
	void (*destroy)(struct dst_entry___2 *);
	void (*ifdown)(struct dst_entry___2 *, struct net_device___47 *, int);
	struct dst_entry___2 * (*negative_advice)(struct dst_entry___2 *);
	void (*link_failure)(struct sk_buff___47 *);
	void (*update_pmtu)(struct dst_entry___2 *, struct sock *, struct sk_buff___47 *, u32);
	void (*redirect)(struct dst_entry___2 *, struct sock *, struct sk_buff___47 *);
	int (*local_out)(struct net___57 *, struct sock *, struct sk_buff___47 *);
	struct neighbour___2 * (*neigh_lookup)(const struct dst_entry___2 *, struct sk_buff___47 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___2 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___56 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___45 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___56 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct sock *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops *notifier_ops;
	struct fib_notifier_ops *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_nf_frag___45 {
	struct netns_frags___45 frags;
};

struct netns_xfrm___56 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___56 xfrm4_dst_ops;
	struct dst_ops___56 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct net___57 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___262 *user_ns;
	struct ucounts___262 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___9 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___47 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___45 ipv4;
	struct netns_ipv6___56 ipv6;
	struct netns_sctp___30 sctp;
	struct netns_nf nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___45 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock *nfnl;
	struct sock *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___56 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef void compound_page_dtor___385(struct page___398 *);

struct fwnode_reference_args___285;

struct fwnode_endpoint___285;

struct fwnode_operations___285 {
	struct fwnode_handle___285 * (*get)(struct fwnode_handle___285 *);
	void (*put)(struct fwnode_handle___285 *);
	bool (*device_is_available)(const struct fwnode_handle___285 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___285 *, const struct device___365 *);
	bool (*property_present)(const struct fwnode_handle___285 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___285 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___285 *, const char *, const char **, size_t);
	struct fwnode_handle___285 * (*get_parent)(const struct fwnode_handle___285 *);
	struct fwnode_handle___285 * (*get_next_child_node)(const struct fwnode_handle___285 *, struct fwnode_handle___285 *);
	struct fwnode_handle___285 * (*get_named_child_node)(const struct fwnode_handle___285 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___285 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___285 *);
	struct fwnode_handle___285 * (*graph_get_next_endpoint)(const struct fwnode_handle___285 *, struct fwnode_handle___285 *);
	struct fwnode_handle___285 * (*graph_get_remote_endpoint)(const struct fwnode_handle___285 *);
	struct fwnode_handle___285 * (*graph_get_port_parent)(struct fwnode_handle___285 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___285 *, struct fwnode_endpoint___285 *);
};

struct fwnode_endpoint___285 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___285 *local_fwnode;
};

struct fwnode_reference_args___285 {
	struct fwnode_handle___285 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___81;

struct pipe_buffer___81 {
	struct page___398 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___81 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___81 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___81 *, struct pipe_buffer___81 *);
	void (*release)(struct pipe_inode_info___81 *, struct pipe_buffer___81 *);
	int (*steal)(struct pipe_inode_info___81 *, struct pipe_buffer___81 *);
	union {
		bool (*get)(struct pipe_inode_info___81 *, struct pipe_buffer___81 *);
		struct {
			void (*get)(struct pipe_inode_info___81 *, struct pipe_buffer___81 *);
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
};

struct nf_bridge_info___45 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___45 = 0,
		BRNF_PROTO_8021Q___45 = 1,
		BRNF_PROTO_PPPOE___45 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___47 *physindev;
	struct net_device___47 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___45(struct sk_buff___47 **);

typedef struct {
	struct net___57 *net;
} possible_net_t___47;

struct net_device_ops___45;

struct ethtool_ops___45;

struct xfrmdev_ops___45;

struct tlsdev_ops___45;

struct header_ops___45;

struct netdev_rx_queue___45;

struct netdev_queue___45;

struct dcbnl_rtnl_ops___45;

struct phy_device___7;

struct net_device___47 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___45 *netdev_ops;
	const struct ethtool_ops___45 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___2 *l3mdev_ops;
	const struct ndisc_ops___2 *ndisc_ops;
	const struct xfrmdev_ops___45 *xfrmdev_ops;
	const struct tlsdev_ops___45 *tlsdev_ops;
	const struct header_ops___45 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___384 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___2 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___45 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___45 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___2 *miniq_ingress;
	struct netdev_queue___45 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___45 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___2 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___2 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___45 = 0,
		NETREG_REGISTERED___45 = 1,
		NETREG_UNREGISTERING___45 = 2,
		NETREG_UNREGISTERED___45 = 3,
		NETREG_RELEASED___45 = 4,
		NETREG_DUMMY___45 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___45 = 0,
		RTNL_LINK_INITIALIZING___45 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___47 *);
	struct netpoll_info *npinfo;
	possible_net_t___47 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___365 dev;
	const struct attribute_group___362 *sysfs_groups[4];
	const struct attribute_group___362 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___2 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___45 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device___7 *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct sk_buff_head___45 {
	struct sk_buff___47 *next;
	struct sk_buff___47 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct ethtool_ops___45 {
	int (*get_settings)(struct net_device___47 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___47 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___47 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___47 *);
	void (*get_regs)(struct net_device___47 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___47 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___47 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___47 *);
	void (*set_msglevel)(struct net_device___47 *, u32);
	int (*nway_reset)(struct net_device___47 *);
	u32 (*get_link)(struct net_device___47 *);
	int (*get_eeprom_len)(struct net_device___47 *);
	int (*get_eeprom)(struct net_device___47 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___47 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___47 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___47 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___47 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___47 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___47 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___47 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___47 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___47 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___47 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___47 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___47 *);
	void (*complete)(struct net_device___47 *);
	u32 (*get_priv_flags)(struct net_device___47 *);
	int (*set_priv_flags)(struct net_device___47 *, u32);
	int (*get_sset_count)(struct net_device___47 *, int);
	int (*get_rxnfc)(struct net_device___47 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___47 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___47 *, struct ethtool_flash *);
	int (*reset)(struct net_device___47 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___47 *);
	u32 (*get_rxfh_indir_size)(struct net_device___47 *);
	int (*get_rxfh)(struct net_device___47 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___47 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___47 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___47 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___47 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___47 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___47 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___47 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___47 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___47 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___47 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___47 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___47 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___47 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___47 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___47 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___47 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___47 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___47 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___47 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___47 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___47 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	int (*get_fecparam)(struct net_device___47 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___47 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___47 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___47 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___47 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___45;

struct inet_frags___45 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___45 *, const void *);
	void (*destructor)(struct inet_frag_queue___45 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___45 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___47 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___47 *fragments_tail;
	struct sk_buff___47 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___45 *net;
	struct callback_head rcu;
};

struct ucounts___262 {
	struct hlist_node node;
	struct user_namespace___262 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

typedef int (*key_restrict_link_func_t___366)(struct key___365 *, const struct key_type *, const union key_payload *, struct key___365 *);

struct key_restriction___365;

struct key___365 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___399 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___365 *restrict_link;
};

struct key_restriction___365 {
	key_restrict_link_func_t___366 check;
	struct key___365 *key;
	struct key_type *keytype;
};

struct seq_operations___336 {
	void * (*start)(struct seq_file___336 *, loff_t *);
	void (*stop)(struct seq_file___336 *, void *);
	void * (*next)(struct seq_file___336 *, void *, loff_t *);
	int (*show)(struct seq_file___336 *, void *);
};

struct pernet_operations___46 {
	struct list_head list;
	int (*init)(struct net___57 *);
	void (*exit)(struct net___57 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___45 {
	int (*ieee_getets)(struct net_device___47 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___47 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___47 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___47 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___47 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___47 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___47 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___47 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___47 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___47 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___47 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___47 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___47 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___47 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___47 *);
	u8 (*setstate)(struct net_device___47 *, u8);
	void (*getpermhwaddr)(struct net_device___47 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___47 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___47 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___47 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___47 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___47 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___47 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___47 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___47 *, int, u8 *);
	void (*setpfccfg)(struct net_device___47 *, int, u8);
	void (*getpfccfg)(struct net_device___47 *, int, u8 *);
	u8 (*setall)(struct net_device___47 *);
	u8 (*getcap)(struct net_device___47 *, int, u8 *);
	int (*getnumtcs)(struct net_device___47 *, int, u8 *);
	int (*setnumtcs)(struct net_device___47 *, int, u8);
	u8 (*getpfcstate)(struct net_device___47 *);
	void (*setpfcstate)(struct net_device___47 *, u8);
	void (*getbcncfg)(struct net_device___47 *, int, u32 *);
	void (*setbcncfg)(struct net_device___47 *, int, u32);
	void (*getbcnrp)(struct net_device___47 *, int, u8 *);
	void (*setbcnrp)(struct net_device___47 *, int, u8);
	int (*setapp)(struct net_device___47 *, u8, u16, u8);
	int (*getapp)(struct net_device___47 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___47 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___47 *, int, u8);
	u8 (*getdcbx)(struct net_device___47 *);
	u8 (*setdcbx)(struct net_device___47 *, u8);
	int (*peer_getappinfo)(struct net_device___47 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___47 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___47 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___47 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___47 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___47 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___246 {
	refcount_t count;
	struct ns_common___9 ns;
	struct user_namespace___262 *user_ns;
	struct ucounts___262 *ucounts;
	struct css_set___246 *root_cset;
};

struct irqaction___20 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___20 *next;
	irq_handler_t thread_fn;
	struct task_struct___399 *thread;
	struct irqaction___20 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_map___247;

struct bpf_map_ops___246 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___247 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___247 *, struct file___397 *);
	void (*map_free)(struct bpf_map___247 *);
	int (*map_get_next_key)(struct bpf_map___247 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___247 *);
	void * (*map_lookup_elem)(struct bpf_map___247 *, void *);
	int (*map_update_elem)(struct bpf_map___247 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___247 *, void *);
	int (*map_push_elem)(struct bpf_map___247 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___247 *, void *);
	int (*map_peek_elem)(struct bpf_map___247 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___247 *, struct file___397 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___247 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___247 *, void *, struct seq_file___336 *);
	int (*map_check_btf)(const struct bpf_map___247 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___247 {
	const struct bpf_map_ops___246 *ops;
	struct bpf_map___247 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___365 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___45;

struct bpf_map_dev_ops___45 {
	int (*map_get_next_key)(struct bpf_offloaded_map___45 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___45 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___45 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___45 *, void *);
};

struct bpf_offloaded_map___45 {
	struct bpf_map___247 map;
	struct net_device___47 *netdev;
	const struct bpf_map_dev_ops___45 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___247;

typedef void (*kthread_work_func_t___247)(struct kthread_work___247 *);

struct kthread_worker___247;

struct kthread_work___247 {
	struct list_head node;
	kthread_work_func_t___247 func;
	struct kthread_worker___247 *worker;
	int canceling;
};

struct kthread_worker___247 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___399 *task;
	struct kthread_work___247 *current_work;
};

struct kthread_delayed_work___246 {
	struct kthread_work___247 work;
	struct timer_list timer;
};

struct psi_group___246 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___247 *poll_kworker;
	struct kthread_delayed_work___246 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___246 {
	struct kernfs_node___392 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___246;

struct cgroup_subsys_state___246 {
	struct cgroup___246 *cgroup;
	struct cgroup_subsys___246 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___246 *parent;
};

struct cgroup_root___246;

struct cgroup_rstat_cpu___246;

struct cgroup___246 {
	struct cgroup_subsys_state___246 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___392 *kn;
	struct cgroup_file___246 procs_file;
	struct cgroup_file___246 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___246 *subsys[13];
	struct cgroup_root___246 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___246 *dom_cgrp;
	struct cgroup_rstat_cpu___246 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___39 bpf;
	atomic_t congestion_count;
	struct cgroup___246 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___246 psi;
	int ancestor_ids[0];
};

struct cftype___246;

struct cgroup_subsys___246 {
	struct cgroup_subsys_state___246 * (*css_alloc)(struct cgroup_subsys_state___246 *);
	int (*css_online)(struct cgroup_subsys_state___246 *);
	void (*css_offline)(struct cgroup_subsys_state___246 *);
	void (*css_released)(struct cgroup_subsys_state___246 *);
	void (*css_free)(struct cgroup_subsys_state___246 *);
	void (*css_reset)(struct cgroup_subsys_state___246 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___246 *, int);
	int (*css_extra_stat_show)(struct seq_file___336 *, struct cgroup_subsys_state___246 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___399 *);
	void (*cancel_fork)(struct task_struct___399 *);
	void (*fork)(struct task_struct___399 *);
	void (*exit)(struct task_struct___399 *);
	void (*free)(struct task_struct___399 *);
	void (*bind)(struct cgroup_subsys_state___246 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___246 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___246 *dfl_cftypes;
	struct cftype___246 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___246 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___246 *updated_children;
	struct cgroup___246 *updated_next;
};

struct cgroup_root___246 {
	struct kernfs_root___391 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___246 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___246 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___246 *ss;
	struct list_head node;
	struct kernfs_ops___391 *kf_ops;
	int (*open)(struct kernfs_open_file___391 *);
	void (*release)(struct kernfs_open_file___391 *);
	u64 (*read_u64)(struct cgroup_subsys_state___246 *, struct cftype___246 *);
	s64 (*read_s64)(struct cgroup_subsys_state___246 *, struct cftype___246 *);
	int (*seq_show)(struct seq_file___336 *, void *);
	void * (*seq_start)(struct seq_file___336 *, loff_t *);
	void * (*seq_next)(struct seq_file___336 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___336 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___246 *, struct cftype___246 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___246 *, struct cftype___246 *, s64);
	ssize_t (*write)(struct kernfs_open_file___391 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___391 *, struct poll_table_struct___6 *);
};

struct xdp_rxq_info___45 {
	struct net_device___47 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___45 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___47 *dev_rx;
};

struct netlink_callback___47 {
	struct sk_buff___47 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___47 *);
	int (*dump)(struct sk_buff___47 *, struct netlink_callback___47 *);
	int (*done)(struct netlink_callback___47 *);
	void *data;
	struct module___327 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___45 {
	int (*create)(struct sk_buff___47 *, struct net_device___47 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___47 *, unsigned char *);
	int (*cache)(const struct neighbour___2 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___47 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___45 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___45 *, int);
	int poll_owner;
	struct net_device___47 *dev;
	struct sk_buff___47 *gro_list;
	struct sk_buff___47 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___45 {
	struct net_device___47 *dev;
	struct Qdisc___2 *qdisc;
	struct Qdisc___2 *qdisc_sleeping;
	struct kobject___385 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___47 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct netdev_rx_queue___45 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___385 kobj;
	struct net_device___47 *dev;
	long: 64;
	struct xdp_rxq_info___45 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___45)(struct net_device___47 *, struct sk_buff___47 *, struct net_device___47 *);

struct netdev_bpf___45 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___39 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___39 *prog;
			const struct bpf_prog_offload_ops___39 *ops;
		} verifier;
		struct {
			struct bpf_prog___39 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___45 *offmap;
		};
		struct {
			struct xdp_umem *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___45 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___47 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___45 {
	int (*tls_dev_add)(struct net_device___47 *, struct sock *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___47 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___47 *, struct sock *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___45 {
	int (*ndo_init)(struct net_device___47 *);
	void (*ndo_uninit)(struct net_device___47 *);
	int (*ndo_open)(struct net_device___47 *);
	int (*ndo_stop)(struct net_device___47 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___47 *, struct net_device___47 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___47 *, struct net_device___47 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___47 *, struct sk_buff___47 *, struct net_device___47 *, select_queue_fallback_t___45);
	void (*ndo_change_rx_flags)(struct net_device___47 *, int);
	void (*ndo_set_rx_mode)(struct net_device___47 *);
	int (*ndo_set_mac_address)(struct net_device___47 *, void *);
	int (*ndo_validate_addr)(struct net_device___47 *);
	int (*ndo_do_ioctl)(struct net_device___47 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___47 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___47 *, int);
	int (*ndo_neigh_setup)(struct net_device___47 *, struct neigh_parms___3 *);
	void (*ndo_tx_timeout)(struct net_device___47 *);
	void (*ndo_get_stats64)(struct net_device___47 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___47 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___47 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___47 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___47 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___47 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___47 *);
	int (*ndo_netpoll_setup)(struct net_device___47 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___47 *);
	int (*ndo_set_vf_mac)(struct net_device___47 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___47 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___47 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___47 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___47 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___47 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___47 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___47 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___47 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___47 *, int, struct sk_buff___47 *);
	int (*ndo_set_vf_guid)(struct net_device___47 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___47 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___47 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___47 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___47 *, const struct sk_buff___47 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___47 *, struct net_device___47 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___47 *, struct net_device___47 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___47 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___47 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___47 *, struct neighbour___2 *);
	void (*ndo_neigh_destroy)(struct net_device___47 *, struct neighbour___2 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___47 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___47 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___47 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___47 *, struct netlink_callback___47 *, struct net_device___47 *, struct net_device___47 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___47 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___47 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___47 *, u32, u32, struct net_device___47 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___47 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___47 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___47 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___47 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___47 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___47 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___47 *, struct net_device___47 *);
	void (*ndo_dfwd_del_station)(struct net_device___47 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___47 *);
	int (*ndo_set_tx_maxrate)(struct net_device___47 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___47 *);
	int (*ndo_change_proto_down)(struct net_device___47 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___47 *, struct sk_buff___47 *);
	void (*ndo_set_rx_headroom)(struct net_device___47 *, int);
	int (*ndo_bpf)(struct net_device___47 *, struct netdev_bpf___45 *);
	int (*ndo_xdp_xmit)(struct net_device___47 *, int, struct xdp_frame___45 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___47 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___47 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct mii_bus___7;

struct mdio_device___7 {
	struct device___365 dev;
	struct mii_bus___7 *bus;
	char modalias[32];
	int (*bus_match)(struct device___365 *, struct device_driver___365 *);
	void (*device_free)(struct mdio_device___7 *);
	void (*device_remove)(struct mdio_device___7 *);
	int addr;
	int flags;
	struct gpio_desc *reset;
	unsigned int reset_assert_delay;
	unsigned int reset_deassert_delay;
};

struct phy_driver___7;

struct phy_device___7 {
	struct mdio_device___7 mdio;
	struct phy_driver___7 *drv;
	u32 phy_id;
	struct phy_c45_device_ids c45_ids;
	unsigned int is_c45: 1;
	unsigned int is_internal: 1;
	unsigned int is_pseudo_fixed_link: 1;
	unsigned int has_fixups: 1;
	unsigned int suspended: 1;
	unsigned int sysfs_links: 1;
	unsigned int loopback_enabled: 1;
	unsigned int autoneg: 1;
	unsigned int link: 1;
	enum phy_state state;
	u32 dev_flags;
	phy_interface_t interface;
	int speed;
	int duplex;
	int pause;
	int asym_pause;
	u32 interrupts;
	u32 rh_reserved_supported;
	u32 rh_reserved_advertising;
	u32 rh_reserved_lp_advertising;
	u32 eee_broken_modes;
	int link_timeout;
	struct phy_led_trigger *phy_led_triggers;
	unsigned int phy_num_led_triggers;
	struct phy_led_trigger *last_triggered;
	struct phy_led_trigger *led_link_trigger;
	int irq;
	void *priv;
	struct work_struct phy_queue;
	struct delayed_work state_queue;
	struct mutex lock;
	struct phylink *phylink;
	struct net_device___47 *attached_dev;
	u8 mdix;
	u8 mdix_ctrl;
	long unsigned int supported[2];
	long unsigned int advertising[2];
	long unsigned int lp_advertising[2];
	void (*phy_link_change)(struct phy_device___7 *, bool, bool);
	void (*adjust_link)(struct net_device___47 *);
};

struct softnet_data___45 {
	struct list_head poll_list;
	struct sk_buff_head___45 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___45 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___2 *output_queue;
	struct Qdisc___2 **output_queue_tailp;
	struct sk_buff___47 *completion_queue;
	struct sk_buff_head___45 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___45 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___45 input_pkt_queue;
	struct napi_struct___45 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct mii_bus___7 {
	struct module___327 *owner;
	const char *name;
	char id[61];
	void *priv;
	int (*read)(struct mii_bus___7 *, int, int);
	int (*write)(struct mii_bus___7 *, int, int, u16);
	int (*reset)(struct mii_bus___7 *);
	struct mutex mdio_lock;
	struct device___365 *parent;
	enum {
		MDIOBUS_ALLOCATED___7 = 1,
		MDIOBUS_REGISTERED___7 = 2,
		MDIOBUS_UNREGISTERED___7 = 3,
		MDIOBUS_RELEASED___7 = 4,
	} state;
	struct device___365 dev;
	struct mdio_device___7 *mdio_map[32];
	u32 phy_mask;
	u32 phy_ignore_ta_mask;
	int irq[32];
	int reset_delay_us;
	struct gpio_desc *reset_gpiod;
};

struct mdio_driver_common___7 {
	struct device_driver___365 driver;
	int flags;
};

struct kernel_param_ops___325 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___325 *);
	int (*get)(char *, const struct kernel_param___325 *);
	void (*free)(void *);
};

struct kparam_array___325;

struct kernel_param___325 {
	const char *name;
	struct module___327 *mod;
	const struct kernel_param_ops___325 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___325 *arr;
	};
};

struct kparam_array___325 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___325 *ops;
	void *elem;
};

struct module_attribute___325 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___325 *, struct module_kobject___325 *, char *);
	ssize_t (*store)(struct module_attribute___325 *, struct module_kobject___325 *, const char *, size_t);
	void (*setup)(struct module___327 *, const char *);
	int (*test)(struct module___327 *);
	void (*free)(struct module___327 *);
};

struct phy_driver___7 {
	struct mdio_driver_common___7 mdiodrv;
	u32 phy_id;
	char *name;
	u32 phy_id_mask;
	u32 rh_reserved_features;
	u32 flags;
	const void *driver_data;
	const long unsigned int * const features;
	int (*soft_reset)(struct phy_device___7 *);
	int (*config_init)(struct phy_device___7 *);
	int (*probe)(struct phy_device___7 *);
	int (*suspend)(struct phy_device___7 *);
	int (*resume)(struct phy_device___7 *);
	int (*config_aneg)(struct phy_device___7 *);
	int (*aneg_done)(struct phy_device___7 *);
	int (*read_status)(struct phy_device___7 *);
	int (*ack_interrupt)(struct phy_device___7 *);
	int (*config_intr)(struct phy_device___7 *);
	int (*did_interrupt)(struct phy_device___7 *);
	void (*remove)(struct phy_device___7 *);
	int (*match_phy_device)(struct phy_device___7 *);
	int (*ts_info)(struct phy_device___7 *, struct ethtool_ts_info *);
	int (*hwtstamp)(struct phy_device___7 *, struct ifreq *);
	bool (*rxtstamp)(struct phy_device___7 *, struct sk_buff___47 *, int);
	void (*txtstamp)(struct phy_device___7 *, struct sk_buff___47 *, int);
	int (*set_wol)(struct phy_device___7 *, struct ethtool_wolinfo *);
	void (*get_wol)(struct phy_device___7 *, struct ethtool_wolinfo *);
	void (*link_change_notify)(struct phy_device___7 *);
	int (*read_mmd)(struct phy_device___7 *, int, u16);
	int (*write_mmd)(struct phy_device___7 *, int, u16, u16);
	int (*read_page)(struct phy_device___7 *);
	int (*write_page)(struct phy_device___7 *, int);
	int (*module_info)(struct phy_device___7 *, struct ethtool_modinfo *);
	int (*module_eeprom)(struct phy_device___7 *, struct ethtool_eeprom *, u8 *);
	int (*get_sset_count)(struct phy_device___7 *);
	void (*get_strings)(struct phy_device___7 *, u8 *);
	void (*get_stats)(struct phy_device___7 *, struct ethtool_stats *, u64 *);
	int (*get_tunable)(struct phy_device___7 *, struct ethtool_tunable *, void *);
	int (*set_tunable)(struct phy_device___7 *, struct ethtool_tunable *, const void *);
	int (*set_loopback)(struct phy_device___7 *, bool);
};

struct property___93 {
	char *name;
	int length;
	void *value;
	struct property___93 *next;
	long unsigned int _flags;
	struct bin_attribute___361 attr;
};

struct irq_desc___25;

typedef void (*irq_flow_handler_t___25)(struct irq_desc___25 *);

struct irq_chip___33;

struct irq_data___33 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___11 *common;
	struct irq_chip___33 *chip;
	struct irq_domain___33 *domain;
	struct irq_data___33 *parent_data;
	void *chip_data;
};

struct irq_desc___25 {
	struct irq_common_data___11 irq_common_data;
	struct irq_data___33 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___25 handle_irq;
	struct irqaction___20 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int irq_count;
	unsigned int tot_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___385 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___327 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip___33 {
	struct device___365 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___33 *);
	void (*irq_shutdown)(struct irq_data___33 *);
	void (*irq_enable)(struct irq_data___33 *);
	void (*irq_disable)(struct irq_data___33 *);
	void (*irq_ack)(struct irq_data___33 *);
	void (*irq_mask)(struct irq_data___33 *);
	void (*irq_mask_ack)(struct irq_data___33 *);
	void (*irq_unmask)(struct irq_data___33 *);
	void (*irq_eoi)(struct irq_data___33 *);
	int (*irq_set_affinity)(struct irq_data___33 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___33 *);
	int (*irq_set_type)(struct irq_data___33 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___33 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___33 *);
	void (*irq_bus_sync_unlock)(struct irq_data___33 *);
	void (*irq_cpu_online)(struct irq_data___33 *);
	void (*irq_cpu_offline)(struct irq_data___33 *);
	void (*irq_suspend)(struct irq_data___33 *);
	void (*irq_resume)(struct irq_data___33 *);
	void (*irq_pm_shutdown)(struct irq_data___33 *);
	void (*irq_calc_mask)(struct irq_data___33 *);
	void (*irq_print_chip)(struct irq_data___33 *, struct seq_file___336 *);
	int (*irq_request_resources)(struct irq_data___33 *);
	void (*irq_release_resources)(struct irq_data___33 *);
	void (*irq_compose_msi_msg)(struct irq_data___33 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___33 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___33 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___33 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___33 *, void *);
	void (*ipi_send_single)(struct irq_data___33 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___33 *, const struct cpumask *);
	long unsigned int flags;
};

struct irq_chip_type___21 {
	struct irq_chip___33 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___25 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___21 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___21 *);
	void (*resume)(struct irq_chip_generic___21 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___33 *domain;
	struct list_head list;
	struct irq_chip_type___21 chip_types[0];
};

struct irq_domain_chip_generic___20 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___21 *gc[0];
};

struct irq_fwspec___33 {
	struct fwnode_handle___285 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___33 {
	int (*match)(struct irq_domain___33 *, struct device_node___97 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___33 *, struct irq_fwspec___33 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___33 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___33 *, unsigned int);
	int (*xlate)(struct irq_domain___33 *, struct device_node___97 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___33 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___33 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___33 *, struct irq_data___33 *, bool);
	void (*deactivate)(struct irq_domain___33 *, struct irq_data___33 *);
	int (*translate)(struct irq_domain___33 *, struct irq_fwspec___33 *, long unsigned int *, unsigned int *);
};

struct reserved_mem_ops___2;

struct reserved_mem___2 {
	const char *name;
	long unsigned int fdt_node;
	long unsigned int phandle;
	const struct reserved_mem_ops___2 *ops;
	phys_addr_t base;
	phys_addr_t size;
	void *priv;
};

struct reserved_mem_ops___2 {
	int (*device_init)(struct reserved_mem___2 *, struct device___365 *);
	void (*device_release)(struct reserved_mem___2 *, struct device___365 *);
};

typedef int (*reservedmem_of_init_fn___2)(struct reserved_mem___2 *);

struct rmem_assigned_device {
	struct device___365 *dev;
	struct reserved_mem___2 *rmem;
	struct list_head list;
};

enum of_overlay_notify_action {
	OF_OVERLAY_PRE_APPLY = 0,
	OF_OVERLAY_POST_APPLY = 1,
	OF_OVERLAY_PRE_REMOVE = 2,
	OF_OVERLAY_POST_REMOVE = 3,
};

struct of_overlay_notify_data {
	struct device_node___96 *overlay;
	struct device_node___96 *target;
};

struct fragment {
	struct device_node___96 *target;
	struct device_node___96 *overlay;
};

struct overlay_changeset {
	int id;
	struct list_head ovcs_list;
	const void *fdt;
	struct device_node___96 *overlay_tree;
	int count;
	struct fragment *fragments;
	bool symbols_fragment;
	struct of_changeset cset;
};

struct mbox_client___3 {
	struct device___364 *dev;
	bool tx_block;
	long unsigned int tx_tout;
	bool knows_txdone;
	void (*rx_callback)(struct mbox_client___3 *, void *);
	void (*tx_prepare)(struct mbox_client___3 *, void *);
	void (*tx_done)(struct mbox_client___3 *, void *, int);
};

struct mbox_chan___3;

struct mbox_chan_ops___2 {
	int (*send_data)(struct mbox_chan___3 *, void *);
	int (*startup)(struct mbox_chan___3 *);
	void (*shutdown)(struct mbox_chan___3 *);
	bool (*last_tx_done)(struct mbox_chan___3 *);
	bool (*peek_data)(struct mbox_chan___3 *);
};

struct mbox_controller___2;

struct mbox_chan___3 {
	struct mbox_controller___2 *mbox;
	unsigned int txdone_method;
	struct mbox_client___3 *cl;
	struct completion tx_complete;
	void *active_req;
	unsigned int msg_count;
	unsigned int msg_free;
	void *msg_data[20];
	spinlock_t lock;
	void *con_priv;
};

struct mbox_controller___2 {
	struct device___364 *dev;
	const struct mbox_chan_ops___2 *ops;
	struct mbox_chan___3 *chans;
	int num_chans;
	bool txdone_irq;
	bool txdone_poll;
	unsigned int txpoll_period;
	struct mbox_chan___3 * (*of_xlate)(struct mbox_controller___2 *, const struct of_phandle_args___16 *);
	struct hrtimer poll_hrt;
	struct list_head node;
};

struct acpi_table_pcct {
	struct acpi_table_header header;
	u32 flags;
	u64 reserved;
};

enum acpi_pcct_type {
	ACPI_PCCT_TYPE_GENERIC_SUBSPACE = 0,
	ACPI_PCCT_TYPE_HW_REDUCED_SUBSPACE = 1,
	ACPI_PCCT_TYPE_HW_REDUCED_SUBSPACE_TYPE2 = 2,
	ACPI_PCCT_TYPE_EXT_PCC_MASTER_SUBSPACE = 3,
	ACPI_PCCT_TYPE_EXT_PCC_SLAVE_SUBSPACE = 4,
	ACPI_PCCT_TYPE_RESERVED = 5,
};

struct acpi_pcct_subspace {
	struct acpi_subtable_header header;
	u8 reserved[6];
	u64 base_address;
	u64 length;
	struct acpi_generic_address doorbell_register;
	u64 preserve_mask;
	u64 write_mask;
	u32 latency;
	u32 max_access_rate;
	u16 min_turnaround_time;
} __attribute__((packed));

struct acpi_pcct_hw_reduced_type2 {
	struct acpi_subtable_header header;
	u32 platform_interrupt;
	u8 flags;
	u8 reserved;
	u64 base_address;
	u64 length;
	struct acpi_generic_address doorbell_register;
	u64 preserve_mask;
	u64 write_mask;
	u32 latency;
	u32 max_access_rate;
	u16 min_turnaround_time;
	struct acpi_generic_address platform_ack_register;
	u64 ack_preserve_mask;
	u64 ack_write_mask;
} __attribute__((packed));

struct mbox_chan___4;

struct mbox_chan_ops___3 {
	int (*send_data)(struct mbox_chan___4 *, void *);
	int (*startup)(struct mbox_chan___4 *);
	void (*shutdown)(struct mbox_chan___4 *);
	bool (*last_tx_done)(struct mbox_chan___4 *);
	bool (*peek_data)(struct mbox_chan___4 *);
};

struct mbox_controller___3;

struct mbox_client___4;

struct mbox_chan___4 {
	struct mbox_controller___3 *mbox;
	unsigned int txdone_method;
	struct mbox_client___4 *cl;
	struct completion tx_complete;
	void *active_req;
	unsigned int msg_count;
	unsigned int msg_free;
	void *msg_data[20];
	spinlock_t lock;
	void *con_priv;
};

struct mbox_controller___3 {
	struct device___360 *dev;
	const struct mbox_chan_ops___3 *ops;
	struct mbox_chan___4 *chans;
	int num_chans;
	bool txdone_irq;
	bool txdone_poll;
	unsigned int txpoll_period;
	struct mbox_chan___4 * (*of_xlate)(struct mbox_controller___3 *, const struct of_phandle_args___5 *);
	struct hrtimer poll_hrt;
	struct list_head node;
};

struct mbox_client___4 {
	struct device___360 *dev;
	bool tx_block;
	long unsigned int tx_tout;
	bool knows_txdone;
	void (*rx_callback)(struct mbox_client___4 *, void *);
	void (*tx_prepare)(struct mbox_client___4 *, void *);
	void (*tx_done)(struct mbox_client___4 *, void *, int);
};

struct hi3660_chan_info {
	unsigned int dst_irq;
	unsigned int ack_irq;
};

struct hi3660_mbox {
	struct device___360 *dev;
	void *base;
	struct mbox_chan___4 chan[32];
	struct hi3660_chan_info mchan[32];
	struct mbox_controller___3 controller;
};

struct mbox_chan___5;

struct mbox_chan_ops___4 {
	int (*send_data)(struct mbox_chan___5 *, void *);
	int (*startup)(struct mbox_chan___5 *);
	void (*shutdown)(struct mbox_chan___5 *);
	bool (*last_tx_done)(struct mbox_chan___5 *);
	bool (*peek_data)(struct mbox_chan___5 *);
};

struct mbox_controller___4;

struct mbox_chan___5 {
	struct mbox_controller___4 *mbox;
	unsigned int txdone_method;
	struct mbox_client___4 *cl;
	struct completion tx_complete;
	void *active_req;
	unsigned int msg_count;
	unsigned int msg_free;
	void *msg_data[20];
	spinlock_t lock;
	void *con_priv;
};

struct mbox_controller___4 {
	struct device___296 *dev;
	const struct mbox_chan_ops___4 *ops;
	struct mbox_chan___5 *chans;
	int num_chans;
	bool txdone_irq;
	bool txdone_poll;
	unsigned int txpoll_period;
	struct mbox_chan___5 * (*of_xlate)(struct mbox_controller___4 *, const struct of_phandle_args___12 *);
	struct hrtimer poll_hrt;
	struct list_head node;
};

struct platform_device___27 {
	const char *name;
	int id;
	bool id_auto;
	struct device___296 dev;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct platform_driver___20 {
	int (*probe)(struct platform_device___27 *);
	int (*remove)(struct platform_device___27 *);
	void (*shutdown)(struct platform_device___27 *);
	int (*suspend)(struct platform_device___27 *, pm_message_t);
	int (*resume)(struct platform_device___27 *);
	struct device_driver___296 driver;
	const struct platform_device_id *id_table;
	bool prevent_deferred_probe;
};

struct hi6220_mbox;

struct hi6220_mbox_chan {
	unsigned int dir;
	unsigned int dst_irq;
	unsigned int ack_irq;
	unsigned int slot;
	struct hi6220_mbox *parent;
};

struct hi6220_mbox {
	struct device___296 *dev;
	int irq;
	bool tx_irq_mode;
	void *ipc;
	void *base;
	unsigned int chan_num;
	struct hi6220_mbox_chan *mchan;
	void *irq_map_chan[32];
	struct mbox_chan___5 *chan;
	struct mbox_controller___4 controller;
};

struct hwspinlock___2;

struct hwspinlock_ops {
	int (*trylock)(struct hwspinlock___2 *);
	void (*unlock)(struct hwspinlock___2 *);
	void (*relax)(struct hwspinlock___2 *);
};

struct hwspinlock_device;

struct hwspinlock___2 {
	struct hwspinlock_device *bank;
	spinlock_t lock;
	void *priv;
};

struct hwspinlock_device {
	struct device___364 *dev;
	const struct hwspinlock_ops *ops;
	int base_id;
	int num_locks;
	struct hwspinlock___2 lock[0];
};

union extcon_property_value {
	int intval;
};

struct extcon_cable;

struct extcon_dev___2 {
	const char *name;
	const unsigned int *supported_cable;
	const u32 *mutually_exclusive;
	struct device___364 dev;
	struct raw_notifier_head nh_all;
	struct raw_notifier_head *nh;
	struct list_head entry;
	int max_supported;
	spinlock_t lock;
	u32 state;
	struct device_type___364 extcon_dev_type;
	struct extcon_cable *cables;
	struct attribute_group___361 attr_g_muex;
	struct attribute **attrs_muex;
	struct device_attribute___56 *d_attrs_muex;
};

struct extcon_cable {
	struct extcon_dev___2 *edev;
	int cable_index;
	struct attribute_group___361 attr_g;
	struct device_attribute___56 attr_name;
	struct device_attribute___56 attr_state;
	struct attribute *attrs[3];
	union extcon_property_value usb_propval[3];
	union extcon_property_value chg_propval[1];
	union extcon_property_value jack_propval[1];
	union extcon_property_value disp_propval[2];
	long unsigned int usb_bits[1];
	long unsigned int chg_bits[1];
	long unsigned int jack_bits[1];
	long unsigned int disp_bits[1];
};

struct __extcon_info {
	unsigned int type;
	unsigned int id;
	const char *name;
};

typedef void (*dr_release_t___30)(struct device___365 *, void *);

struct extcon_dev_notifier_devres {
	struct extcon_dev___2 *edev;
	unsigned int id;
	struct notifier_block *nb;
};

struct module___328;

struct file___398;

struct kiocb___398;

struct vm_area_struct___399;

struct inode___398;

struct file_lock___398;

struct page___399;

struct seq_file___337;

struct file_operations___398 {
	struct module___328 *owner;
	loff_t (*llseek)(struct file___398 *, loff_t, int);
	ssize_t (*read)(struct file___398 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___398 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___398 *, struct iov_iter___167 *);
	ssize_t (*write_iter)(struct kiocb___398 *, struct iov_iter___167 *);
	int (*iopoll)(struct kiocb___398 *, bool);
	int (*iterate)(struct file___398 *, struct dir_context *);
	int (*iterate_shared)(struct file___398 *, struct dir_context *);
	__poll_t (*poll)(struct file___398 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___398 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___398 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___398 *, struct vm_area_struct___399 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___398 *, struct file___398 *);
	int (*flush)(struct file___398 *, fl_owner_t);
	int (*release)(struct inode___398 *, struct file___398 *);
	int (*fsync)(struct file___398 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___398 *, int);
	int (*lock)(struct file___398 *, int, struct file_lock___398 *);
	ssize_t (*sendpage)(struct file___398 *, struct page___399 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___398 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___398 *, int, struct file_lock___398 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___398 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___398 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___398 *, long int, struct file_lock___398 **, void **);
	long int (*fallocate)(struct file___398 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___337 *, struct file___398 *);
	ssize_t (*copy_file_range)(struct file___398 *, loff_t, struct file___398 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___398 *, loff_t, struct file___398 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___398 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___399 {
	u64 seqnum;
	struct vm_area_struct___399 *vmas[4];
};

struct page_frag___399 {
	struct page___399 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___151;

struct debug_info___151 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___151 *hbp_break[16];
	struct perf_event___151 *hbp_watch[16];
};

struct thread_struct___151 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___151 debug;
	long: 64;
};

struct mm_struct___399;

struct pid___228;

struct cred___366;

struct nsproxy___293;

struct signal_struct___273;

struct css_set___247;

struct perf_event_context___151;

struct vm_struct___302;

struct task_struct___400 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___400 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___399 *mm;
	struct mm_struct___399 *active_mm;
	struct vmacache___399 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___400 *real_parent;
	struct task_struct___400 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___400 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___228 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___228 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___228 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___366 *ptracer_cred;
	const struct cred___366 *real_cred;
	const struct cred___366 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___293 *nsproxy;
	struct signal_struct___273 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___400 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___247 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___151 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___399 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___400 *oom_reaper_list;
	struct vm_struct___302 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___151 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___151 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___400 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___151)(struct perf_event___151 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___151;

struct fasync_struct___398;

struct pid_namespace___228;

struct perf_cgroup___151;

struct perf_event___151 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___151 *group_leader;
	struct pmu___151 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___151 hw;
	struct perf_event_context___151 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___151 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___400 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___398 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___151 *);
	struct callback_head callback_head;
	struct pid_namespace___228 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___151 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___151 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___5 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___151 *cgrp;
	struct list_head sb_list;
};

struct secondary_data___400 {
	void *stack;
	struct task_struct___400 *task;
	long int status;
};

typedef struct page___399 *pgtable_t___399;

struct address_space___398;

struct dev_pagemap___386;

struct page___399 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___398 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___399 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___399 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___399 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___386 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___399;

struct lruvec___399 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___399 *pgdat;
};

struct zone___399 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___399 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___399 {
	struct zone___399 *zone;
	int zone_idx;
};

struct zonelist___399 {
	struct zoneref___399 _zonerefs[25];
};

struct pglist_data___399 {
	struct zone___399 node_zones[3];
	struct zonelist___399 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___400 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___400 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___399 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___400 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___400 *owner;
};

struct blocking_notifier_head___399 {
	struct rw_semaphore___400 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___386;

struct vm_area_struct___399 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___399 *vm_next;
	struct vm_area_struct___399 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___399 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___386 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___398 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___399;

struct user_namespace___263;

struct mm_struct___399 {
	struct {
		struct vm_area_struct___399 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___398 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___400 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___399 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___400 *owner;
		struct user_namespace___263 *user_ns;
		struct file___398 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___399 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___398;

struct address_space___398 {
	struct inode___398 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___400 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___398 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___386)(struct vm_area_struct___399 *, long unsigned int, const struct page___399 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___386)(struct page___399 *, void *);

struct device___366;

struct dev_pagemap___386 {
	dev_page_fault_t___386 page_fault;
	dev_page_free_t___386 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___366 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct dentry___398;

struct path___399 {
	struct vfsmount *mnt;
	struct dentry___398 *dentry;
};

struct fown_struct___228 {
	rwlock_t lock;
	struct pid___228 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___398 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___399 f_path;
	struct inode___398 *f_inode;
	const struct file_operations___398 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___228 f_owner;
	const struct cred___366 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___398 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___386;

struct vm_operations_struct___386 {
	void (*open)(struct vm_area_struct___399 *);
	void (*close)(struct vm_area_struct___399 *);
	int (*split)(struct vm_area_struct___399 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___399 *);
	vm_fault_t (*fault)(struct vm_fault___386 *);
	vm_fault_t (*huge_fault)(struct vm_fault___386 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___386 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___399 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___386 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___386 *);
	int (*access)(struct vm_area_struct___399 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___399 *);
	int (*set_policy)(struct vm_area_struct___399 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___399 *, long unsigned int);
	struct page___399 * (*find_special_page)(struct vm_area_struct___399 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___399 {
	struct task_struct___400 *task;
	struct core_thread___399 *next;
};

struct core_state___399 {
	atomic_t nr_threads;
	struct core_thread___399 dumper;
	struct completion startup;
};

struct key___366;

struct ucounts___263;

struct user_namespace___263 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___263 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___9 ns;
	long unsigned int flags;
	struct key___366 *persistent_keyring_register;
	struct rw_semaphore___400 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___263 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___386 {
	struct vm_area_struct___399 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___399 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___399 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___399 prealloc_pte;
};

struct upid___228 {
	int nr;
	struct pid_namespace___228 *ns;
};

struct pid_namespace___228 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___400 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___228 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___398 *proc_self;
	struct dentry___398 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___263 *user_ns;
	struct ucounts___263 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___9 ns;
};

struct pid___228 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___228 numbers[1];
};

struct user_struct___366 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___366 *uid_keyring;
	struct key___366 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___366 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___366 *session_keyring;
	struct key___366 *process_keyring;
	struct key___366 *thread_keyring;
	struct key___366 *request_key_auth;
	void *security;
	struct user_struct___366 *user;
	struct user_namespace___263 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___247;

struct nsproxy___293 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___228 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___247 *cgroup_ns;
};

struct signal_struct___273 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___400 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___400 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___228 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___228 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___399 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___228 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___247;

struct cgroup___247;

struct css_set___247 {
	struct cgroup_subsys_state___247 *subsys[13];
	refcount_t refcount;
	struct css_set___247 *dom_cset;
	struct cgroup___247 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___247 *mg_src_cgrp;
	struct cgroup___247 *mg_dst_cgrp;
	struct css_set___247 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___151 {
	struct pmu___151 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___400 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___151 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___302 {
	struct vm_struct___302 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___399 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___285 {
	struct task_struct___400 task;
	long unsigned int stack[8192];
};

struct fwnode_operations___286;

struct fwnode_handle___286 {
	struct fwnode_handle___286 *secondary;
	const struct fwnode_operations___286 *ops;
};

struct fwnode_reference_args___286;

struct fwnode_endpoint___286;

struct fwnode_operations___286 {
	struct fwnode_handle___286 * (*get)(struct fwnode_handle___286 *);
	void (*put)(struct fwnode_handle___286 *);
	bool (*device_is_available)(const struct fwnode_handle___286 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___286 *, const struct device___366 *);
	bool (*property_present)(const struct fwnode_handle___286 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___286 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___286 *, const char *, const char **, size_t);
	struct fwnode_handle___286 * (*get_parent)(const struct fwnode_handle___286 *);
	struct fwnode_handle___286 * (*get_next_child_node)(const struct fwnode_handle___286 *, struct fwnode_handle___286 *);
	struct fwnode_handle___286 * (*get_named_child_node)(const struct fwnode_handle___286 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___286 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___286 *);
	struct fwnode_handle___286 * (*graph_get_next_endpoint)(const struct fwnode_handle___286 *, struct fwnode_handle___286 *);
	struct fwnode_handle___286 * (*graph_get_remote_endpoint)(const struct fwnode_handle___286 *);
	struct fwnode_handle___286 * (*graph_get_port_parent)(struct fwnode_handle___286 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___286 *, struct fwnode_endpoint___286 *);
};

struct fwnode_endpoint___286 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___286 *local_fwnode;
};

struct fwnode_reference_args___286 {
	struct fwnode_handle___286 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct kset___385;

struct kobj_type___385;

struct kernfs_node___393;

struct kobject___386 {
	const char *name;
	struct list_head entry;
	struct kobject___386 *parent;
	struct kset___385 *kset;
	struct kobj_type___385 *ktype;
	struct kernfs_node___393 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___366 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___366 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___366;

struct bus_type___366;

struct device_driver___366;

struct dev_pm_domain___366;

struct class___366;

struct attribute_group___363;

struct device___366 {
	struct device___366 *parent;
	struct device_private *p;
	struct kobject___386 kobj;
	const char *init_name;
	const struct device_type___366 *type;
	struct mutex mutex;
	struct bus_type___366 *bus;
	struct device_driver___366 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___366 power;
	struct dev_pm_domain___366 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___286 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___366 *class;
	const struct attribute_group___363 **groups;
	void (*release)(struct device___366 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct kernfs_root___392;

struct kernfs_elem_dir___392 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___392 *root;
};

struct kernfs_syscall_ops___392;

struct kernfs_root___392 {
	struct kernfs_node___393 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___392 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___392 {
	struct kernfs_node___393 *target_kn;
};

struct kernfs_ops___392;

struct kernfs_elem_attr___392 {
	const struct kernfs_ops___392 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___393 *notify_next;
};

struct kernfs_node___393 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___393 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___392 dir;
		struct kernfs_elem_symlink___392 symlink;
		struct kernfs_elem_attr___392 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___392;

struct kernfs_ops___392 {
	int (*open)(struct kernfs_open_file___392 *);
	void (*release)(struct kernfs_open_file___392 *);
	int (*seq_show)(struct seq_file___337 *, void *);
	void * (*seq_start)(struct seq_file___337 *, loff_t *);
	void * (*seq_next)(struct seq_file___337 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___337 *, void *);
	ssize_t (*read)(struct kernfs_open_file___392 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___392 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___392 *, struct vm_area_struct___399 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___392 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___392 {
	int (*remount_fs)(struct kernfs_root___392 *, int *, char *);
	int (*show_options)(struct seq_file___337 *, struct kernfs_root___392 *);
	int (*mkdir)(struct kernfs_node___393 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___393 *);
	int (*rename)(struct kernfs_node___393 *, struct kernfs_node___393 *, const char *);
	int (*show_path)(struct seq_file___337 *, struct kernfs_node___393 *, struct kernfs_root___392 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___337;

struct seq_file___337 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___337 *op;
	int poll_event;
	const struct file___398 *file;
	void *private;
};

struct kernfs_open_file___392 {
	struct kernfs_node___393 *kn;
	struct file___398 *file;
	struct seq_file___337 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___386 *vm_ops;
};

struct bin_attribute___362;

struct attribute_group___363 {
	const char *name;
	umode_t (*is_visible)(struct kobject___386 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___386 *, struct bin_attribute___362 *, int);
	struct attribute **attrs;
	struct bin_attribute___362 **bin_attrs;
};

struct bin_attribute___362 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___398 *, struct kobject___386 *, struct bin_attribute___362 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___398 *, struct kobject___386 *, struct bin_attribute___362 *, char *, loff_t, size_t);
	int (*mmap)(struct file___398 *, struct kobject___386 *, struct bin_attribute___362 *, struct vm_area_struct___399 *);
};

struct sysfs_ops___385 {
	ssize_t (*show)(struct kobject___386 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___386 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___385;

struct kset___385 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___386 kobj;
	const struct kset_uevent_ops___385 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___385 {
	void (*release)(struct kobject___386 *);
	const struct sysfs_ops___385 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___29 * (*child_ns_type)(struct kobject___386 *);
	const void * (*namespace)(struct kobject___386 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___385 {
	int (* const filter)(struct kset___385 *, struct kobject___386 *);
	const char * (* const name)(struct kset___385 *, struct kobject___386 *);
	int (* const uevent)(struct kset___385 *, struct kobject___386 *, struct kobj_uevent_env *);
};

struct kobj_attribute___376 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___386 *, struct kobj_attribute___376 *, char *);
	ssize_t (*store)(struct kobject___386 *, struct kobj_attribute___376 *, const char *, size_t);
};

struct kernel_param___326;

struct kernel_param_ops___326 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___326 *);
	int (*get)(char *, const struct kernel_param___326 *);
	void (*free)(void *);
};

struct kparam_array___326;

struct kernel_param___326 {
	const char *name;
	struct module___328 *mod;
	const struct kernel_param_ops___326 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___326 *arr;
	};
};

struct kparam_array___326 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___326 *ops;
	void *elem;
};

struct module_kobject___326 {
	struct kobject___386 kobj;
	struct module___328 *mod;
	struct kobject___386 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___326 {
	struct module___328 *mod;
	struct latch_tree_node node;
};

struct module_layout___326 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___326 mtn;
};

struct module_attribute___326;

struct module___328 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___326 mkobj;
	struct module_attribute___326 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___386 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___326 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___326 core_layout;
	struct module_layout___326 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___326 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___326 *, struct module_kobject___326 *, char *);
	ssize_t (*store)(struct module_attribute___326 *, struct module_kobject___326 *, const char *, size_t);
	void (*setup)(struct module___328 *, const char *);
	int (*test)(struct module___328 *);
	void (*free)(struct module___328 *);
};

struct dentry_operations___398;

struct super_block___398;

struct dentry___398 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___398 *d_parent;
	struct qstr d_name;
	struct inode___398 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___398 *d_op;
	struct super_block___398 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___398;

struct block_device___398;

struct inode___398 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___398 *i_op;
	struct super_block___398 *i_sb;
	struct address_space___398 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___400 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___398 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___398 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___398 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___398 {
	int (*d_revalidate)(struct dentry___398 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___398 *, unsigned int);
	int (*d_hash)(const struct dentry___398 *, struct qstr *);
	int (*d_compare)(const struct dentry___398 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___398 *);
	int (*d_init)(struct dentry___398 *);
	void (*d_release)(struct dentry___398 *);
	void (*d_prune)(struct dentry___398 *);
	void (*d_iput)(struct dentry___398 *, struct inode___398 *);
	char * (*d_dname)(struct dentry___398 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___399 *);
	int (*d_manage)(const struct path___399 *, bool);
	struct dentry___398 * (*d_real)(struct dentry___398 *, const struct inode___398 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___398;

struct mem_dqinfo___398 {
	struct quota_format_type___398 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___398;

struct quota_info___398 {
	unsigned int flags;
	struct rw_semaphore___400 dqio_sem;
	struct inode___398 *files[3];
	struct mem_dqinfo___398 info[3];
	const struct quota_format_ops___398 *ops[3];
};

struct rcuwait___398 {
	struct task_struct___400 *task;
};

struct percpu_rw_semaphore___398 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___400 rw_sem;
	struct rcuwait___398 writer;
	int readers_block;
};

struct sb_writers___398 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___398 rw_sem[3];
};

struct file_system_type___398;

struct super_operations___398;

struct dquot_operations___398;

struct quotactl_ops___398;

struct super_block___398 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___398 *s_type;
	const struct super_operations___398 *s_op;
	const struct dquot_operations___398 *dq_op;
	const struct quotactl_ops___398 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___398 *s_root;
	struct rw_semaphore___400 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___398 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___398 s_dquot;
	struct sb_writers___398 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___398 *s_d_op;
	int cleancache_poolid;
	struct shrinker___137 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___263 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___398 {
	struct file___398 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___398 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___398 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___398 *ia_file;
};

struct dquot___398 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___398 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___398 {
	int qf_fmt_id;
	const struct quota_format_ops___398 *qf_ops;
	struct module___328 *qf_owner;
	struct quota_format_type___398 *qf_next;
};

struct quota_format_ops___398 {
	int (*check_quota_file)(struct super_block___398 *, int);
	int (*read_file_info)(struct super_block___398 *, int);
	int (*write_file_info)(struct super_block___398 *, int);
	int (*free_file_info)(struct super_block___398 *, int);
	int (*read_dqblk)(struct dquot___398 *);
	int (*commit_dqblk)(struct dquot___398 *);
	int (*release_dqblk)(struct dquot___398 *);
	int (*get_next_id)(struct super_block___398 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___398 {
	int (*write_dquot)(struct dquot___398 *);
	struct dquot___398 * (*alloc_dquot)(struct super_block___398 *, int);
	void (*destroy_dquot)(struct dquot___398 *);
	int (*acquire_dquot)(struct dquot___398 *);
	int (*release_dquot)(struct dquot___398 *);
	int (*mark_dirty)(struct dquot___398 *);
	int (*write_info)(struct super_block___398 *, int);
	qsize_t * (*get_reserved_space)(struct inode___398 *);
	int (*get_projid)(struct inode___398 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___398 *, qsize_t *);
	int (*get_next_id)(struct super_block___398 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___398 {
	int (*quota_on)(struct super_block___398 *, int, int, const struct path___399 *);
	int (*quota_off)(struct super_block___398 *, int);
	int (*quota_enable)(struct super_block___398 *, unsigned int);
	int (*quota_disable)(struct super_block___398 *, unsigned int);
	int (*quota_sync)(struct super_block___398 *, int);
	int (*set_info)(struct super_block___398 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___398 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___398 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___398 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___398 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___398 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___398 {
	int (*writepage)(struct page___399 *, struct writeback_control___3 *);
	int (*readpage)(struct file___398 *, struct page___399 *);
	int (*writepages)(struct address_space___398 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___399 *);
	int (*readpages)(struct file___398 *, struct address_space___398 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___398 *, struct address_space___398 *, loff_t, unsigned int, unsigned int, struct page___399 **, void **);
	int (*write_end)(struct file___398 *, struct address_space___398 *, loff_t, unsigned int, unsigned int, struct page___399 *, void *);
	sector_t (*bmap)(struct address_space___398 *, sector_t);
	void (*invalidatepage)(struct page___399 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___399 *, gfp_t);
	void (*freepage)(struct page___399 *);
	ssize_t (*direct_IO)(struct kiocb___398 *, struct iov_iter___167 *);
	int (*migratepage)(struct address_space___398 *, struct page___399 *, struct page___399 *, enum migrate_mode);
	bool (*isolate_page)(struct page___399 *, isolate_mode_t);
	void (*putback_page)(struct page___399 *);
	int (*launder_page)(struct page___399 *);
	int (*is_partially_uptodate)(struct page___399 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___399 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___398 *, struct page___399 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___398 *, sector_t *);
	void (*swap_deactivate)(struct file___398 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___398 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___398 *bd_inode;
	struct super_block___398 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___398 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___398 {
	struct dentry___398 * (*lookup)(struct inode___398 *, struct dentry___398 *, unsigned int);
	const char * (*get_link)(struct dentry___398 *, struct inode___398 *, struct delayed_call *);
	int (*permission)(struct inode___398 *, int);
	struct posix_acl * (*get_acl)(struct inode___398 *, int);
	int (*readlink)(struct dentry___398 *, char *, int);
	int (*create)(struct inode___398 *, struct dentry___398 *, umode_t, bool);
	int (*link)(struct dentry___398 *, struct inode___398 *, struct dentry___398 *);
	int (*unlink)(struct inode___398 *, struct dentry___398 *);
	int (*symlink)(struct inode___398 *, struct dentry___398 *, const char *);
	int (*mkdir)(struct inode___398 *, struct dentry___398 *, umode_t);
	int (*rmdir)(struct inode___398 *, struct dentry___398 *);
	int (*mknod)(struct inode___398 *, struct dentry___398 *, umode_t, dev_t);
	int (*rename)(struct inode___398 *, struct dentry___398 *, struct inode___398 *, struct dentry___398 *, unsigned int);
	int (*setattr)(struct dentry___398 *, struct iattr___398 *);
	int (*getattr)(const struct path___399 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___398 *, char *, size_t);
	int (*fiemap)(struct inode___398 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___398 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___398 *, struct dentry___398 *, struct file___398 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___398 *, struct dentry___398 *, umode_t);
	int (*set_acl)(struct inode___398 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___398 {
	void (*fl_copy_lock)(struct file_lock___398 *, struct file_lock___398 *);
	void (*fl_release_private)(struct file_lock___398 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___398;

struct file_lock___398 {
	struct file_lock___398 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___398 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___398 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___398 *fl_ops;
	const struct lock_manager_operations___398 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___398 {
	int (*lm_compare_owner)(struct file_lock___398 *, struct file_lock___398 *);
	long unsigned int (*lm_owner_key)(struct file_lock___398 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___398 *);
	int (*lm_grant)(struct file_lock___398 *, int);
	bool (*lm_break)(struct file_lock___398 *);
	int (*lm_change)(struct file_lock___398 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___398 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___398 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___398 *fa_next;
	struct file___398 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___398 {
	const char *name;
	int fs_flags;
	struct dentry___398 * (*mount)(struct file_system_type___398 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___398 *);
	struct module___328 *owner;
	struct file_system_type___398 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___398 {
	struct inode___398 * (*alloc_inode)(struct super_block___398 *);
	void (*destroy_inode)(struct inode___398 *);
	void (*dirty_inode)(struct inode___398 *, int);
	int (*write_inode)(struct inode___398 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___398 *);
	void (*evict_inode)(struct inode___398 *);
	void (*put_super)(struct super_block___398 *);
	int (*sync_fs)(struct super_block___398 *, int);
	int (*freeze_super)(struct super_block___398 *);
	int (*freeze_fs)(struct super_block___398 *);
	int (*thaw_super)(struct super_block___398 *);
	int (*unfreeze_fs)(struct super_block___398 *);
	int (*statfs)(struct dentry___398 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___398 *, int *, char *);
	void (*umount_begin)(struct super_block___398 *);
	int (*show_options)(struct seq_file___337 *, struct dentry___398 *);
	int (*show_devname)(struct seq_file___337 *, struct dentry___398 *);
	int (*show_path)(struct seq_file___337 *, struct dentry___398 *);
	int (*show_stats)(struct seq_file___337 *, struct dentry___398 *);
	ssize_t (*quota_read)(struct super_block___398 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___398 *, int, const char *, size_t, loff_t);
	struct dquot___398 ** (*get_dquots)(struct inode___398 *);
	int (*bdev_try_to_free_page)(struct super_block___398 *, struct page___399 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___398 *, struct shrink_control___137 *);
	long int (*free_cached_objects)(struct super_block___398 *, struct shrink_control___137 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void compound_page_dtor___386(struct page___399 *);

struct cgroup_namespace___247 {
	refcount_t count;
	struct ns_common___9 ns;
	struct user_namespace___263 *user_ns;
	struct ucounts___263 *ucounts;
	struct css_set___247 *root_cset;
};

struct ucounts___263 {
	struct hlist_node node;
	struct user_namespace___263 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

typedef int (*key_restrict_link_func_t___367)(struct key___366 *, const struct key_type *, const union key_payload *, struct key___366 *);

struct key_restriction___366;

struct key___366 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___400 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___366 *restrict_link;
};

struct key_restriction___366 {
	key_restrict_link_func_t___367 check;
	struct key___366 *key;
	struct key_type *keytype;
};

struct dev_pm_ops___366 {
	int (*prepare)(struct device___366 *);
	void (*complete)(struct device___366 *);
	int (*suspend)(struct device___366 *);
	int (*resume)(struct device___366 *);
	int (*freeze)(struct device___366 *);
	int (*thaw)(struct device___366 *);
	int (*poweroff)(struct device___366 *);
	int (*restore)(struct device___366 *);
	int (*suspend_late)(struct device___366 *);
	int (*resume_early)(struct device___366 *);
	int (*freeze_late)(struct device___366 *);
	int (*thaw_early)(struct device___366 *);
	int (*poweroff_late)(struct device___366 *);
	int (*restore_early)(struct device___366 *);
	int (*suspend_noirq)(struct device___366 *);
	int (*resume_noirq)(struct device___366 *);
	int (*freeze_noirq)(struct device___366 *);
	int (*thaw_noirq)(struct device___366 *);
	int (*poweroff_noirq)(struct device___366 *);
	int (*restore_noirq)(struct device___366 *);
	int (*runtime_suspend)(struct device___366 *);
	int (*runtime_resume)(struct device___366 *);
	int (*runtime_idle)(struct device___366 *);
};

struct dev_pm_domain___366 {
	struct dev_pm_ops___366 ops;
	void (*detach)(struct device___366 *, bool);
	int (*activate)(struct device___366 *);
	void (*sync)(struct device___366 *);
	void (*dismiss)(struct device___366 *);
};

struct bus_type___366 {
	const char *name;
	const char *dev_name;
	struct device___366 *dev_root;
	const struct attribute_group___363 **bus_groups;
	const struct attribute_group___363 **dev_groups;
	const struct attribute_group___363 **drv_groups;
	int (*match)(struct device___366 *, struct device_driver___366 *);
	int (*uevent)(struct device___366 *, struct kobj_uevent_env *);
	int (*probe)(struct device___366 *);
	int (*remove)(struct device___366 *);
	void (*shutdown)(struct device___366 *);
	int (*online)(struct device___366 *);
	int (*offline)(struct device___366 *);
	int (*suspend)(struct device___366 *, pm_message_t);
	int (*resume)(struct device___366 *);
	int (*num_vf)(struct device___366 *);
	int (*dma_configure)(struct device___366 *);
	const struct dev_pm_ops___366 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___366 {
	const char *name;
	struct bus_type___366 *bus;
	struct module___328 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___366 *);
	int (*remove)(struct device___366 *);
	void (*shutdown)(struct device___366 *);
	int (*suspend)(struct device___366 *, pm_message_t);
	int (*resume)(struct device___366 *);
	const struct attribute_group___363 **groups;
	const struct dev_pm_ops___366 *pm;
	void (*coredump)(struct device___366 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___366 {
	const char *name;
	const struct attribute_group___363 **groups;
	int (*uevent)(struct device___366 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___366 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___366 *);
	const struct dev_pm_ops___366 *pm;
};

struct class___366 {
	const char *name;
	struct module___328 *owner;
	const struct attribute_group___363 **class_groups;
	const struct attribute_group___363 **dev_groups;
	struct kobject___386 *dev_kobj;
	int (*dev_uevent)(struct device___366 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___366 *, umode_t *);
	void (*class_release)(struct class___366 *);
	void (*dev_release)(struct device___366 *);
	int (*shutdown_pre)(struct device___366 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___366 *);
	const struct dev_pm_ops___366 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct device_attribute___58 {
	struct attribute attr;
	ssize_t (*show)(struct device___366 *, struct device_attribute___58 *, char *);
	ssize_t (*store)(struct device___366 *, struct device_attribute___58 *, const char *, size_t);
};

struct dev_ext_attribute___2 {
	struct device_attribute___58 attr;
	void *var;
};

struct node___219 {
	struct device___366 dev;
};

struct seq_operations___337 {
	void * (*start)(struct seq_file___337 *, loff_t *);
	void (*stop)(struct seq_file___337 *, void *);
	void * (*next)(struct seq_file___337 *, void *, loff_t *);
	int (*show)(struct seq_file___337 *, void *);
};

struct bpf_map___248;

struct bpf_map_ops___247 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___248 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___248 *, struct file___398 *);
	void (*map_free)(struct bpf_map___248 *);
	int (*map_get_next_key)(struct bpf_map___248 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___248 *);
	void * (*map_lookup_elem)(struct bpf_map___248 *, void *);
	int (*map_update_elem)(struct bpf_map___248 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___248 *, void *);
	int (*map_push_elem)(struct bpf_map___248 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___248 *, void *);
	int (*map_peek_elem)(struct bpf_map___248 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___248 *, struct file___398 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___248 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___248 *, void *, struct seq_file___337 *);
	int (*map_check_btf)(const struct bpf_map___248 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___248 {
	const struct bpf_map_ops___247 *ops;
	struct bpf_map___248 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___366 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___248;

typedef void (*kthread_work_func_t___248)(struct kthread_work___248 *);

struct kthread_worker___248;

struct kthread_work___248 {
	struct list_head node;
	kthread_work_func_t___248 func;
	struct kthread_worker___248 *worker;
	int canceling;
};

struct kthread_worker___248 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___400 *task;
	struct kthread_work___248 *current_work;
};

struct kthread_delayed_work___247 {
	struct kthread_work___248 work;
	struct timer_list timer;
};

struct psi_group___247 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___248 *poll_kworker;
	struct kthread_delayed_work___247 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___247 {
	struct kernfs_node___393 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___247;

struct cgroup_subsys_state___247 {
	struct cgroup___247 *cgroup;
	struct cgroup_subsys___247 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___247 *parent;
};

struct cgroup_root___247;

struct cgroup_rstat_cpu___247;

struct cgroup___247 {
	struct cgroup_subsys_state___247 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___393 *kn;
	struct cgroup_file___247 procs_file;
	struct cgroup_file___247 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___247 *subsys[13];
	struct cgroup_root___247 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___247 *dom_cgrp;
	struct cgroup_rstat_cpu___247 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___39 bpf;
	atomic_t congestion_count;
	struct cgroup___247 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___247 psi;
	int ancestor_ids[0];
};

struct cftype___247;

struct cgroup_subsys___247 {
	struct cgroup_subsys_state___247 * (*css_alloc)(struct cgroup_subsys_state___247 *);
	int (*css_online)(struct cgroup_subsys_state___247 *);
	void (*css_offline)(struct cgroup_subsys_state___247 *);
	void (*css_released)(struct cgroup_subsys_state___247 *);
	void (*css_free)(struct cgroup_subsys_state___247 *);
	void (*css_reset)(struct cgroup_subsys_state___247 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___247 *, int);
	int (*css_extra_stat_show)(struct seq_file___337 *, struct cgroup_subsys_state___247 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___400 *);
	void (*cancel_fork)(struct task_struct___400 *);
	void (*fork)(struct task_struct___400 *);
	void (*exit)(struct task_struct___400 *);
	void (*free)(struct task_struct___400 *);
	void (*bind)(struct cgroup_subsys_state___247 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___247 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___247 *dfl_cftypes;
	struct cftype___247 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___247 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___247 *updated_children;
	struct cgroup___247 *updated_next;
};

struct cgroup_root___247 {
	struct kernfs_root___392 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___247 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___247 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___247 *ss;
	struct list_head node;
	struct kernfs_ops___392 *kf_ops;
	int (*open)(struct kernfs_open_file___392 *);
	void (*release)(struct kernfs_open_file___392 *);
	u64 (*read_u64)(struct cgroup_subsys_state___247 *, struct cftype___247 *);
	s64 (*read_s64)(struct cgroup_subsys_state___247 *, struct cftype___247 *);
	int (*seq_show)(struct seq_file___337 *, void *);
	void * (*seq_start)(struct seq_file___337 *, loff_t *);
	void * (*seq_next)(struct seq_file___337 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___337 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___247 *, struct cftype___247 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___247 *, struct cftype___247 *, s64);
	ssize_t (*write)(struct kernfs_open_file___392 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___392 *, struct poll_table_struct___6 *);
};

struct perf_cpu_context___151;

struct pmu___151 {
	struct list_head entry;
	struct module___328 *module;
	struct device___366 *dev;
	const struct attribute_group___363 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___151 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___151 *);
	void (*pmu_disable)(struct pmu___151 *);
	int (*event_init)(struct perf_event___151 *);
	void (*event_mapped)(struct perf_event___151 *, struct mm_struct___399 *);
	void (*event_unmapped)(struct perf_event___151 *, struct mm_struct___399 *);
	int (*add)(struct perf_event___151 *, int);
	void (*del)(struct perf_event___151 *, int);
	void (*start)(struct perf_event___151 *, int);
	void (*stop)(struct perf_event___151 *, int);
	void (*read)(struct perf_event___151 *);
	void (*start_txn)(struct pmu___151 *, unsigned int);
	int (*commit_txn)(struct pmu___151 *);
	void (*cancel_txn)(struct pmu___151 *);
	int (*event_idx)(struct perf_event___151 *);
	void (*sched_task)(struct perf_event_context___151 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___151 *);
	int (*filter_match)(struct perf_event___151 *);
	int (*check_period)(struct perf_event___151 *, u64);
};

struct perf_cpu_context___151 {
	struct perf_event_context___151 ctx;
	struct perf_event_context___151 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___151 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___151 {
	struct cgroup_subsys_state___247 css;
	struct perf_cgroup_info *info;
};

struct platform_device___28 {
	const char *name;
	int id;
	bool id_auto;
	struct device___366 dev;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct platform_driver___21 {
	int (*probe)(struct platform_device___28 *);
	int (*remove)(struct platform_device___28 *);
	void (*shutdown)(struct platform_device___28 *);
	int (*suspend)(struct platform_device___28 *, pm_message_t);
	int (*resume)(struct platform_device___28 *);
	struct device_driver___366 driver;
	const struct platform_device_id *id_table;
	bool prevent_deferred_probe;
};

struct arm_ccn_component {
	void *base;
	u32 type;
	long unsigned int pmu_events_mask[1];
	union {
		struct {
			long unsigned int dt_cmp_mask[1];
		} xp;
	};
};

struct arm_ccn_dt {
	int id;
	void *base;
	spinlock_t config_lock;
	long unsigned int pmu_counters_mask[1];
	struct {
		struct arm_ccn_component *source;
		struct perf_event___151 *event;
	} pmu_counters[9];
	struct {
		u64 l;
		u64 h;
	} cmp_mask[12];
	struct hrtimer hrtimer;
	cpumask_t cpu;
	struct hlist_node node;
	struct pmu___151 pmu;
};

struct arm_ccn {
	struct device___366 *dev;
	void *base;
	unsigned int irq;
	unsigned int sbas_present: 1;
	unsigned int sbsx_present: 1;
	int num_nodes;
	struct arm_ccn_component *node;
	int num_xps;
	struct arm_ccn_component *xp;
	struct arm_ccn_dt dt;
	int mn_id;
};

struct arm_ccn_pmu_event {
	struct device_attribute___58 attr;
	u32 type;
	u32 event;
	int num_ports;
	int num_vcs;
	const char *def;
	int mask;
};

struct device_attribute___59 {
	struct attribute attr;
	ssize_t (*show)(struct device___95 *, struct device_attribute___59 *, char *);
	ssize_t (*store)(struct device___95 *, struct device_attribute___59 *, const char *, size_t);
};

struct platform_device___29 {
	const char *name;
	int id;
	bool id_auto;
	struct device___95 dev;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct arm_pmu___2;

struct pmu_hw_events___2 {
	struct perf_event___62 *events[32];
	long unsigned int used_mask[1];
	raw_spinlock_t pmu_lock;
	struct arm_pmu___2 *percpu_pmu;
	int irq;
};

struct arm_pmu___2 {
	struct pmu___62 pmu;
	cpumask_t supported_cpus;
	char *name;
	irqreturn_t (*handle_irq)(struct arm_pmu___2 *);
	void (*enable)(struct perf_event___62 *);
	void (*disable)(struct perf_event___62 *);
	int (*get_event_idx)(struct pmu_hw_events___2 *, struct perf_event___62 *);
	void (*clear_event_idx)(struct pmu_hw_events___2 *, struct perf_event___62 *);
	int (*set_event_filter)(struct hw_perf_event___62 *, struct perf_event_attr *);
	u64 (*read_counter)(struct perf_event___62 *);
	void (*write_counter)(struct perf_event___62 *, u64);
	void (*start)(struct arm_pmu___2 *);
	void (*stop)(struct arm_pmu___2 *);
	void (*reset)(void *);
	int (*map_event)(struct perf_event___62 *);
	int (*filter_match)(struct perf_event___62 *);
	int num_events;
	bool secure_access;
	long unsigned int pmceid_bitmap[1];
	long unsigned int pmceid_ext_bitmap[1];
	struct platform_device___29 *plat_device;
	struct pmu_hw_events___2 *hw_events;
	struct hlist_node node;
	struct notifier_block cpu_pm_nb;
	const struct attribute_group___94 *attr_groups[4];
	long unsigned int acpi_cpuid;
};

struct irq_desc___26;

typedef void (*irq_flow_handler_t___26)(struct irq_desc___26 *);

struct irq_desc___26 {
	struct irq_common_data___3 irq_common_data;
	struct irq_data___9 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___26 handle_irq;
	struct irqaction___5 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int irq_count;
	unsigned int tot_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___98 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___87 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_desc___27;

typedef void (*irq_flow_handler_t___27)(struct irq_desc___27 *);

struct irqaction___21;

struct irq_desc___27 {
	struct irq_common_data___3 irq_common_data;
	struct irq_data___7 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___27 handle_irq;
	struct irqaction___21 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int irq_count;
	unsigned int tot_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___18 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___18 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irqaction___21 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___21 *next;
	irq_handler_t thread_fn;
	struct task_struct___19 *thread;
	struct irqaction___21 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct platform_device___30 {
	const char *name;
	int id;
	bool id_auto;
	struct device___16 dev;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct arm_pmu___3;

struct pmu_hw_events___3 {
	struct perf_event___10 *events[32];
	long unsigned int used_mask[1];
	raw_spinlock_t pmu_lock;
	struct arm_pmu___3 *percpu_pmu;
	int irq;
};

struct arm_pmu___3 {
	struct pmu___10 pmu;
	cpumask_t supported_cpus;
	char *name;
	irqreturn_t (*handle_irq)(struct arm_pmu___3 *);
	void (*enable)(struct perf_event___10 *);
	void (*disable)(struct perf_event___10 *);
	int (*get_event_idx)(struct pmu_hw_events___3 *, struct perf_event___10 *);
	void (*clear_event_idx)(struct pmu_hw_events___3 *, struct perf_event___10 *);
	int (*set_event_filter)(struct hw_perf_event___10 *, struct perf_event_attr *);
	u64 (*read_counter)(struct perf_event___10 *);
	void (*write_counter)(struct perf_event___10 *, u64);
	void (*start)(struct arm_pmu___3 *);
	void (*stop)(struct arm_pmu___3 *);
	void (*reset)(void *);
	int (*map_event)(struct perf_event___10 *);
	int (*filter_match)(struct perf_event___10 *);
	int num_events;
	bool secure_access;
	long unsigned int pmceid_bitmap[1];
	long unsigned int pmceid_ext_bitmap[1];
	struct platform_device___30 *plat_device;
	struct pmu_hw_events___3 *hw_events;
	struct hlist_node node;
	struct notifier_block cpu_pm_nb;
	const struct attribute_group___16 *attr_groups[4];
	long unsigned int acpi_cpuid;
};

typedef int (*armpmu_init_fn)(struct arm_pmu___3 *);

struct pmu_probe_info {
	unsigned int cpuid;
	unsigned int mask;
	armpmu_init_fn init;
};

typedef int (*armpmu_init_fn___2)(struct arm_pmu *);

struct device_attribute___60 {
	struct attribute attr;
	ssize_t (*show)(struct device___16 *, struct device_attribute___60 *, char *);
	ssize_t (*store)(struct device___16 *, struct device_attribute___60 *, const char *, size_t);
};

struct dev_ext_attribute___3 {
	struct device_attribute___60 attr;
	void *var;
};

struct hisi_pmu;

struct hisi_uncore_ops {
	void (*write_evtype)(struct hisi_pmu *, int, u32);
	int (*get_event_idx)(struct perf_event___10 *);
	u64 (*read_counter)(struct hisi_pmu *, struct hw_perf_event___10 *);
	void (*write_counter)(struct hisi_pmu *, struct hw_perf_event___10 *, u64);
	void (*enable_counter)(struct hisi_pmu *, struct hw_perf_event___10 *);
	void (*disable_counter)(struct hisi_pmu *, struct hw_perf_event___10 *);
	void (*enable_counter_int)(struct hisi_pmu *, struct hw_perf_event___10 *);
	void (*disable_counter_int)(struct hisi_pmu *, struct hw_perf_event___10 *);
	void (*start_counters)(struct hisi_pmu *);
	void (*stop_counters)(struct hisi_pmu *);
};

struct hisi_pmu_hwevents {
	struct perf_event___10 *hw_events[16];
	long unsigned int used_mask[1];
};

struct hisi_pmu {
	struct pmu___10 pmu;
	const struct hisi_uncore_ops *ops;
	struct hisi_pmu_hwevents pmu_events;
	cpumask_t associated_cpus;
	int on_cpu;
	int irq;
	struct device___16 *dev;
	struct hlist_node node;
	int sccl_id;
	int ccl_id;
	void *base;
	u32 index_id;
	int num_counters;
	int counter_bits;
	int check_event;
};

struct dev_ext_attribute___4 {
	struct device_attribute___3 attr;
	void *var;
};

struct hisi_pmu___2;

struct hisi_uncore_ops___2 {
	void (*write_evtype)(struct hisi_pmu___2 *, int, u32);
	int (*get_event_idx)(struct perf_event___9 *);
	u64 (*read_counter)(struct hisi_pmu___2 *, struct hw_perf_event___9 *);
	void (*write_counter)(struct hisi_pmu___2 *, struct hw_perf_event___9 *, u64);
	void (*enable_counter)(struct hisi_pmu___2 *, struct hw_perf_event___9 *);
	void (*disable_counter)(struct hisi_pmu___2 *, struct hw_perf_event___9 *);
	void (*enable_counter_int)(struct hisi_pmu___2 *, struct hw_perf_event___9 *);
	void (*disable_counter_int)(struct hisi_pmu___2 *, struct hw_perf_event___9 *);
	void (*start_counters)(struct hisi_pmu___2 *);
	void (*stop_counters)(struct hisi_pmu___2 *);
};

struct hisi_pmu_hwevents___2 {
	struct perf_event___9 *hw_events[16];
	long unsigned int used_mask[1];
};

struct hisi_pmu___2 {
	struct pmu___9 pmu;
	const struct hisi_uncore_ops___2 *ops;
	struct hisi_pmu_hwevents___2 pmu_events;
	cpumask_t associated_cpus;
	int on_cpu;
	int irq;
	struct device___2 *dev;
	struct hlist_node node;
	int sccl_id;
	int ccl_id;
	void *base;
	u32 index_id;
	int num_counters;
	int counter_bits;
	int check_event;
};

struct cluster_pmu;

struct l2cache_pmu {
	struct hlist_node node;
	u32 num_pmus;
	struct pmu___9 pmu;
	int num_counters;
	cpumask_t cpumask;
	struct platform_device *pdev;
	struct cluster_pmu **pmu_cluster;
	struct list_head clusters;
};

struct cluster_pmu {
	struct list_head next;
	struct perf_event___9 *events[9];
	struct l2cache_pmu *l2cache_pmu;
	long unsigned int used_counters[1];
	long unsigned int used_groups[1];
	int irq;
	int cluster_id;
	int on_cpu;
	cpumask_t cluster_cpus;
	spinlock_t pmu_lock;
};

struct l3cache_pmu {
	struct pmu___9 pmu;
	struct hlist_node node;
	void *regs;
	struct perf_event___9 *events[8];
	long unsigned int used_mask[1];
	cpumask_t cpumask;
};

struct l3cache_event_ops {
	void (*start)(struct perf_event___9 *);
	void (*stop)(struct perf_event___9 *, int);
	void (*update)(struct perf_event___9 *);
};

struct module___329;

struct file___399;

struct kiocb___399;

struct poll_table_struct___242;

struct vm_area_struct___400;

struct inode___399;

struct file_lock___399;

struct page___400;

struct seq_file___338;

struct file_operations___399 {
	struct module___329 *owner;
	loff_t (*llseek)(struct file___399 *, loff_t, int);
	ssize_t (*read)(struct file___399 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___399 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___399 *, struct iov_iter___167 *);
	ssize_t (*write_iter)(struct kiocb___399 *, struct iov_iter___167 *);
	int (*iopoll)(struct kiocb___399 *, bool);
	int (*iterate)(struct file___399 *, struct dir_context *);
	int (*iterate_shared)(struct file___399 *, struct dir_context *);
	__poll_t (*poll)(struct file___399 *, struct poll_table_struct___242 *);
	long int (*unlocked_ioctl)(struct file___399 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___399 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___399 *, struct vm_area_struct___400 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___399 *, struct file___399 *);
	int (*flush)(struct file___399 *, fl_owner_t);
	int (*release)(struct inode___399 *, struct file___399 *);
	int (*fsync)(struct file___399 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___399 *, int);
	int (*lock)(struct file___399 *, int, struct file_lock___399 *);
	ssize_t (*sendpage)(struct file___399 *, struct page___400 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___399 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___399 *, int, struct file_lock___399 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___399 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___399 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___399 *, long int, struct file_lock___399 **, void **);
	long int (*fallocate)(struct file___399 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___338 *, struct file___399 *);
	ssize_t (*copy_file_range)(struct file___399 *, loff_t, struct file___399 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___399 *, loff_t, struct file___399 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___399 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___400 {
	u64 seqnum;
	struct vm_area_struct___400 *vmas[4];
};

struct page_frag___400 {
	struct page___400 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___152;

struct debug_info___152 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___152 *hbp_break[16];
	struct perf_event___152 *hbp_watch[16];
};

struct thread_struct___152 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___152 debug;
	long: 64;
};

struct mm_struct___400;

struct pid___229;

struct cred___367;

struct nsproxy___294;

struct signal_struct___274;

struct css_set___248;

struct perf_event_context___152;

struct vm_struct___303;

struct task_struct___401 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___401 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___400 *mm;
	struct mm_struct___400 *active_mm;
	struct vmacache___400 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___401 *real_parent;
	struct task_struct___401 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___401 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___229 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___229 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___229 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___367 *ptracer_cred;
	const struct cred___367 *real_cred;
	const struct cred___367 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___294 *nsproxy;
	struct signal_struct___274 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___401 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___248 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___152 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___400 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___401 *oom_reaper_list;
	struct vm_struct___303 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___152 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___152 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___401 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___152)(struct perf_event___152 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___152;

struct fasync_struct___399;

struct pid_namespace___229;

struct perf_cgroup___152;

struct perf_event___152 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___152 *group_leader;
	struct pmu___152 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___152 hw;
	struct perf_event_context___152 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___152 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___401 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___399 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___152 *);
	struct callback_head callback_head;
	struct pid_namespace___229 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___152 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___152 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___5 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___152 *cgrp;
	struct list_head sb_list;
};

typedef struct page___400 *pgtable_t___400;

struct address_space___399;

struct dev_pagemap___387;

struct page___400 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___399 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___400 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___400 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___400 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___387 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___400;

struct lruvec___400 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___400 *pgdat;
};

struct zone___400 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___400 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___400 {
	struct zone___400 *zone;
	int zone_idx;
};

struct zonelist___400 {
	struct zoneref___400 _zonerefs[25];
};

struct pglist_data___400 {
	struct zone___400 node_zones[3];
	struct zonelist___400 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___401 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___401 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___400 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___401 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___401 *owner;
};

struct secondary_data___401 {
	void *stack;
	struct task_struct___401 *task;
	long int status;
};

struct blocking_notifier_head___400 {
	struct rw_semaphore___401 rwsem;
	struct notifier_block *head;
};

struct key___367;

struct ucounts___264;

struct user_namespace___264 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___264 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___9 ns;
	long unsigned int flags;
	struct key___367 *persistent_keyring_register;
	struct rw_semaphore___401 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___264 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_root___393;

struct kernfs_elem_dir___393 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___393 *root;
};

struct kernfs_node___394;

struct kernfs_syscall_ops___393;

struct kernfs_root___393 {
	struct kernfs_node___394 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___393 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___393 {
	struct kernfs_node___394 *target_kn;
};

struct kernfs_ops___393;

struct kernfs_elem_attr___393 {
	const struct kernfs_ops___393 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___394 *notify_next;
};

struct kernfs_node___394 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___394 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___393 dir;
		struct kernfs_elem_symlink___393 symlink;
		struct kernfs_elem_attr___393 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___393;

struct kernfs_ops___393 {
	int (*open)(struct kernfs_open_file___393 *);
	void (*release)(struct kernfs_open_file___393 *);
	int (*seq_show)(struct seq_file___338 *, void *);
	void * (*seq_start)(struct seq_file___338 *, loff_t *);
	void * (*seq_next)(struct seq_file___338 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___338 *, void *);
	ssize_t (*read)(struct kernfs_open_file___393 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___393 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___393 *, struct vm_area_struct___400 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___393 *, struct poll_table_struct___242 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___393 {
	int (*remount_fs)(struct kernfs_root___393 *, int *, char *);
	int (*show_options)(struct seq_file___338 *, struct kernfs_root___393 *);
	int (*mkdir)(struct kernfs_node___394 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___394 *);
	int (*rename)(struct kernfs_node___394 *, struct kernfs_node___394 *, const char *);
	int (*show_path)(struct seq_file___338 *, struct kernfs_node___394 *, struct kernfs_root___393 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___338;

struct seq_file___338 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___338 *op;
	int poll_event;
	const struct file___399 *file;
	void *private;
};

struct vm_operations_struct___387;

struct kernfs_open_file___393 {
	struct kernfs_node___394 *kn;
	struct file___399 *file;
	struct seq_file___338 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___387 *vm_ops;
};

struct dentry___399;

struct path___400 {
	struct vfsmount *mnt;
	struct dentry___399 *dentry;
};

struct fown_struct___229 {
	rwlock_t lock;
	struct pid___229 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___399 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___400 f_path;
	struct inode___399 *f_inode;
	const struct file_operations___399 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___229 f_owner;
	const struct cred___367 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___399 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___387;

struct vm_operations_struct___387 {
	void (*open)(struct vm_area_struct___400 *);
	void (*close)(struct vm_area_struct___400 *);
	int (*split)(struct vm_area_struct___400 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___400 *);
	vm_fault_t (*fault)(struct vm_fault___387 *);
	vm_fault_t (*huge_fault)(struct vm_fault___387 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___387 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___400 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___387 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___387 *);
	int (*access)(struct vm_area_struct___400 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___400 *);
	int (*set_policy)(struct vm_area_struct___400 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___400 *, long unsigned int);
	struct page___400 * (*find_special_page)(struct vm_area_struct___400 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___252)(struct file___399 *, wait_queue_head_t *, struct poll_table_struct___242 *);

struct poll_table_struct___242 {
	poll_queue_proc___252 _qproc;
	__poll_t _key;
};

struct vm_area_struct___400 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___400 *vm_next;
	struct vm_area_struct___400 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___400 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___387 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___399 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobject___387;

struct bin_attribute___363;

struct attribute_group___364 {
	const char *name;
	umode_t (*is_visible)(struct kobject___387 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___387 *, struct bin_attribute___363 *, int);
	struct attribute **attrs;
	struct bin_attribute___363 **bin_attrs;
};

struct kset___386;

struct kobj_type___386;

struct kobject___387 {
	const char *name;
	struct list_head entry;
	struct kobject___387 *parent;
	struct kset___386 *kset;
	struct kobj_type___386 *ktype;
	struct kernfs_node___394 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___363 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___399 *, struct kobject___387 *, struct bin_attribute___363 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___399 *, struct kobject___387 *, struct bin_attribute___363 *, char *, loff_t, size_t);
	int (*mmap)(struct file___399 *, struct kobject___387 *, struct bin_attribute___363 *, struct vm_area_struct___400 *);
};

struct sysfs_ops___386 {
	ssize_t (*show)(struct kobject___387 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___387 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___386;

struct kset___386 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___387 kobj;
	const struct kset_uevent_ops___386 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___386 {
	void (*release)(struct kobject___387 *);
	const struct sysfs_ops___386 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___29 * (*child_ns_type)(struct kobject___387 *);
	const void * (*namespace)(struct kobject___387 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___386 {
	int (* const filter)(struct kset___386 *, struct kobject___387 *);
	const char * (* const name)(struct kset___386 *, struct kobject___387 *);
	int (* const uevent)(struct kset___386 *, struct kobject___387 *, struct kobj_uevent_env *);
};

struct kobj_attribute___377 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___387 *, struct kobj_attribute___377 *, char *);
	ssize_t (*store)(struct kobject___387 *, struct kobj_attribute___377 *, const char *, size_t);
};

struct device___367;

struct dev_pm_ops___367 {
	int (*prepare)(struct device___367 *);
	void (*complete)(struct device___367 *);
	int (*suspend)(struct device___367 *);
	int (*resume)(struct device___367 *);
	int (*freeze)(struct device___367 *);
	int (*thaw)(struct device___367 *);
	int (*poweroff)(struct device___367 *);
	int (*restore)(struct device___367 *);
	int (*suspend_late)(struct device___367 *);
	int (*resume_early)(struct device___367 *);
	int (*freeze_late)(struct device___367 *);
	int (*thaw_early)(struct device___367 *);
	int (*poweroff_late)(struct device___367 *);
	int (*restore_early)(struct device___367 *);
	int (*suspend_noirq)(struct device___367 *);
	int (*resume_noirq)(struct device___367 *);
	int (*freeze_noirq)(struct device___367 *);
	int (*thaw_noirq)(struct device___367 *);
	int (*poweroff_noirq)(struct device___367 *);
	int (*restore_noirq)(struct device___367 *);
	int (*runtime_suspend)(struct device___367 *);
	int (*runtime_resume)(struct device___367 *);
	int (*runtime_idle)(struct device___367 *);
};

struct dev_pm_info___367 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___367 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___367;

struct bus_type___367;

struct device_driver___367;

struct dev_pm_domain___367;

struct irq_domain___34;

struct device_node___98;

struct fwnode_handle___287;

struct class___367;

struct device___367 {
	struct device___367 *parent;
	struct device_private *p;
	struct kobject___387 kobj;
	const char *init_name;
	const struct device_type___367 *type;
	struct mutex mutex;
	struct bus_type___367 *bus;
	struct device_driver___367 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___367 power;
	struct dev_pm_domain___367 *pm_domain;
	struct irq_domain___34 *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___98 *of_node;
	struct fwnode_handle___287 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___367 *class;
	const struct attribute_group___364 **groups;
	void (*release)(struct device___367 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___367 {
	struct dev_pm_ops___367 ops;
	void (*detach)(struct device___367 *, bool);
	int (*activate)(struct device___367 *);
	void (*sync)(struct device___367 *);
	void (*dismiss)(struct device___367 *);
};

struct upid___229 {
	int nr;
	struct pid_namespace___229 *ns;
};

struct pid_namespace___229 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___401 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___229 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___399 *proc_self;
	struct dentry___399 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___264 *user_ns;
	struct ucounts___264 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___9 ns;
};

struct pid___229 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___229 numbers[1];
};

struct user_struct___367 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___367 *uid_keyring;
	struct key___367 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___400;

struct mm_struct___400 {
	struct {
		struct vm_area_struct___400 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___399 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___401 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___400 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___401 *owner;
		struct user_namespace___264 *user_ns;
		struct file___399 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___400 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___367 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___367 *session_keyring;
	struct key___367 *process_keyring;
	struct key___367 *thread_keyring;
	struct key___367 *request_key_auth;
	void *security;
	struct user_struct___367 *user;
	struct user_namespace___264 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___248;

struct nsproxy___294 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___229 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___248 *cgroup_ns;
};

struct signal_struct___274 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___401 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___401 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___229 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___229 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___400 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___229 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___248;

struct cgroup___248;

struct css_set___248 {
	struct cgroup_subsys_state___248 *subsys[13];
	refcount_t refcount;
	struct css_set___248 *dom_cset;
	struct cgroup___248 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___248 *mg_src_cgrp;
	struct cgroup___248 *mg_dst_cgrp;
	struct css_set___248 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___152 {
	struct pmu___152 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___401 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___152 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___303 {
	struct vm_struct___303 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___400 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___286 {
	struct task_struct___401 task;
	long unsigned int stack[8192];
};

struct bus_type___367 {
	const char *name;
	const char *dev_name;
	struct device___367 *dev_root;
	const struct attribute_group___364 **bus_groups;
	const struct attribute_group___364 **dev_groups;
	const struct attribute_group___364 **drv_groups;
	int (*match)(struct device___367 *, struct device_driver___367 *);
	int (*uevent)(struct device___367 *, struct kobj_uevent_env *);
	int (*probe)(struct device___367 *);
	int (*remove)(struct device___367 *);
	void (*shutdown)(struct device___367 *);
	int (*online)(struct device___367 *);
	int (*offline)(struct device___367 *);
	int (*suspend)(struct device___367 *, pm_message_t);
	int (*resume)(struct device___367 *);
	int (*num_vf)(struct device___367 *);
	int (*dma_configure)(struct device___367 *);
	const struct dev_pm_ops___367 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___367 {
	const char *name;
	struct bus_type___367 *bus;
	struct module___329 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___367 *);
	int (*remove)(struct device___367 *);
	void (*shutdown)(struct device___367 *);
	int (*suspend)(struct device___367 *, pm_message_t);
	int (*resume)(struct device___367 *);
	const struct attribute_group___364 **groups;
	const struct dev_pm_ops___367 *pm;
	void (*coredump)(struct device___367 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___367 {
	const char *name;
	const struct attribute_group___364 **groups;
	int (*uevent)(struct device___367 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___367 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___367 *);
	const struct dev_pm_ops___367 *pm;
};

struct module_kobject___327 {
	struct kobject___387 kobj;
	struct module___329 *mod;
	struct kobject___387 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___327 {
	struct module___329 *mod;
	struct latch_tree_node node;
};

struct module_layout___327 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___327 mtn;
};

struct module_attribute___327;

struct kernel_param___327;

struct module___329 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___327 mkobj;
	struct module_attribute___327 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___387 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___327 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___327 core_layout;
	struct module_layout___327 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct class___367 {
	const char *name;
	struct module___329 *owner;
	const struct attribute_group___364 **class_groups;
	const struct attribute_group___364 **dev_groups;
	struct kobject___387 *dev_kobj;
	int (*dev_uevent)(struct device___367 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___367 *, umode_t *);
	void (*class_release)(struct class___367 *);
	void (*dev_release)(struct device___367 *);
	int (*shutdown_pre)(struct device___367 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___367 *);
	const struct dev_pm_ops___367 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct device_attribute___61 {
	struct attribute attr;
	ssize_t (*show)(struct device___367 *, struct device_attribute___61 *, char *);
	ssize_t (*store)(struct device___367 *, struct device_attribute___61 *, const char *, size_t);
};

struct dev_ext_attribute___5 {
	struct device_attribute___61 attr;
	void *var;
};

struct irq_domain_ops___34;

struct irq_domain_chip_generic___21;

struct irq_domain___34 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___34 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___287 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___21 *gc;
	struct irq_domain___34 *parent;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_direct_max_irq;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_tree_mutex;
	unsigned int linear_revmap[0];
};

struct fwnode_operations___287;

struct fwnode_handle___287 {
	struct fwnode_handle___287 *secondary;
	const struct fwnode_operations___287 *ops;
};

struct property___94;

struct device_node___98 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___287 fwnode;
	struct property___94 *properties;
	struct property___94 *deadprops;
	struct device_node___98 *parent;
	struct device_node___98 *child;
	struct device_node___98 *sibling;
	struct kobject___387 kobj;
	long unsigned int _flags;
	void *data;
};

struct fwnode_reference_args___287;

struct fwnode_endpoint___287;

struct fwnode_operations___287 {
	struct fwnode_handle___287 * (*get)(struct fwnode_handle___287 *);
	void (*put)(struct fwnode_handle___287 *);
	bool (*device_is_available)(const struct fwnode_handle___287 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___287 *, const struct device___367 *);
	bool (*property_present)(const struct fwnode_handle___287 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___287 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___287 *, const char *, const char **, size_t);
	struct fwnode_handle___287 * (*get_parent)(const struct fwnode_handle___287 *);
	struct fwnode_handle___287 * (*get_next_child_node)(const struct fwnode_handle___287 *, struct fwnode_handle___287 *);
	struct fwnode_handle___287 * (*get_named_child_node)(const struct fwnode_handle___287 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___287 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___287 *);
	struct fwnode_handle___287 * (*graph_get_next_endpoint)(const struct fwnode_handle___287 *, struct fwnode_handle___287 *);
	struct fwnode_handle___287 * (*graph_get_remote_endpoint)(const struct fwnode_handle___287 *);
	struct fwnode_handle___287 * (*graph_get_port_parent)(struct fwnode_handle___287 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___287 *, struct fwnode_endpoint___287 *);
};

struct fwnode_endpoint___287 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___287 *local_fwnode;
};

struct fwnode_reference_args___287 {
	struct fwnode_handle___287 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct kernel_param_ops___327 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___327 *);
	int (*get)(char *, const struct kernel_param___327 *);
	void (*free)(void *);
};

struct kparam_array___327;

struct kernel_param___327 {
	const char *name;
	struct module___329 *mod;
	const struct kernel_param_ops___327 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___327 *arr;
	};
};

struct kparam_array___327 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___327 *ops;
	void *elem;
};

struct module_attribute___327 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___327 *, struct module_kobject___327 *, char *);
	ssize_t (*store)(struct module_attribute___327 *, struct module_kobject___327 *, const char *, size_t);
	void (*setup)(struct module___329 *, const char *);
	int (*test)(struct module___329 *);
	void (*free)(struct module___329 *);
};

struct dentry_operations___399;

struct super_block___399;

struct dentry___399 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___399 *d_parent;
	struct qstr d_name;
	struct inode___399 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___399 *d_op;
	struct super_block___399 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___399;

struct address_space___399 {
	struct inode___399 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___401 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___399 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___399;

struct block_device___399;

struct cdev___100;

struct inode___399 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___399 *i_op;
	struct super_block___399 *i_sb;
	struct address_space___399 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___401 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___399 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___399 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___399 *i_bdev;
		struct cdev___100 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___399 {
	int (*d_revalidate)(struct dentry___399 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___399 *, unsigned int);
	int (*d_hash)(const struct dentry___399 *, struct qstr *);
	int (*d_compare)(const struct dentry___399 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___399 *);
	int (*d_init)(struct dentry___399 *);
	void (*d_release)(struct dentry___399 *);
	void (*d_prune)(struct dentry___399 *);
	void (*d_iput)(struct dentry___399 *, struct inode___399 *);
	char * (*d_dname)(struct dentry___399 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___400 *);
	int (*d_manage)(const struct path___400 *, bool);
	struct dentry___399 * (*d_real)(struct dentry___399 *, const struct inode___399 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___399;

struct mem_dqinfo___399 {
	struct quota_format_type___399 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___399;

struct quota_info___399 {
	unsigned int flags;
	struct rw_semaphore___401 dqio_sem;
	struct inode___399 *files[3];
	struct mem_dqinfo___399 info[3];
	const struct quota_format_ops___399 *ops[3];
};

struct rcuwait___399 {
	struct task_struct___401 *task;
};

struct percpu_rw_semaphore___399 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___401 rw_sem;
	struct rcuwait___399 writer;
	int readers_block;
};

struct sb_writers___399 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___399 rw_sem[3];
};

struct file_system_type___399;

struct super_operations___399;

struct dquot_operations___399;

struct quotactl_ops___399;

struct super_block___399 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___399 *s_type;
	const struct super_operations___399 *s_op;
	const struct dquot_operations___399 *dq_op;
	const struct quotactl_ops___399 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___399 *s_root;
	struct rw_semaphore___401 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___399 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___399 s_dquot;
	struct sb_writers___399 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___399 *s_d_op;
	int cleancache_poolid;
	struct shrinker___137 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___264 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

typedef int (*dev_page_fault_t___387)(struct vm_area_struct___400 *, long unsigned int, const struct page___400 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___387)(struct page___400 *, void *);

struct dev_pagemap___387 {
	dev_page_fault_t___387 page_fault;
	dev_page_free_t___387 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___367 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___400 {
	struct task_struct___401 *task;
	struct core_thread___400 *next;
};

struct core_state___400 {
	atomic_t nr_threads;
	struct core_thread___400 dumper;
	struct completion startup;
};

struct vm_fault___387 {
	struct vm_area_struct___400 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___400 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___400 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___400 prealloc_pte;
};

struct kiocb___399 {
	struct file___399 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___399 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___399 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___399 *ia_file;
};

struct dquot___399 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___399 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___399 {
	int qf_fmt_id;
	const struct quota_format_ops___399 *qf_ops;
	struct module___329 *qf_owner;
	struct quota_format_type___399 *qf_next;
};

struct quota_format_ops___399 {
	int (*check_quota_file)(struct super_block___399 *, int);
	int (*read_file_info)(struct super_block___399 *, int);
	int (*write_file_info)(struct super_block___399 *, int);
	int (*free_file_info)(struct super_block___399 *, int);
	int (*read_dqblk)(struct dquot___399 *);
	int (*commit_dqblk)(struct dquot___399 *);
	int (*release_dqblk)(struct dquot___399 *);
	int (*get_next_id)(struct super_block___399 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___399 {
	int (*write_dquot)(struct dquot___399 *);
	struct dquot___399 * (*alloc_dquot)(struct super_block___399 *, int);
	void (*destroy_dquot)(struct dquot___399 *);
	int (*acquire_dquot)(struct dquot___399 *);
	int (*release_dquot)(struct dquot___399 *);
	int (*mark_dirty)(struct dquot___399 *);
	int (*write_info)(struct super_block___399 *, int);
	qsize_t * (*get_reserved_space)(struct inode___399 *);
	int (*get_projid)(struct inode___399 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___399 *, qsize_t *);
	int (*get_next_id)(struct super_block___399 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___399 {
	int (*quota_on)(struct super_block___399 *, int, int, const struct path___400 *);
	int (*quota_off)(struct super_block___399 *, int);
	int (*quota_enable)(struct super_block___399 *, unsigned int);
	int (*quota_disable)(struct super_block___399 *, unsigned int);
	int (*quota_sync)(struct super_block___399 *, int);
	int (*set_info)(struct super_block___399 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___399 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___399 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___399 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___399 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___399 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___399 {
	int (*writepage)(struct page___400 *, struct writeback_control___3 *);
	int (*readpage)(struct file___399 *, struct page___400 *);
	int (*writepages)(struct address_space___399 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___400 *);
	int (*readpages)(struct file___399 *, struct address_space___399 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___399 *, struct address_space___399 *, loff_t, unsigned int, unsigned int, struct page___400 **, void **);
	int (*write_end)(struct file___399 *, struct address_space___399 *, loff_t, unsigned int, unsigned int, struct page___400 *, void *);
	sector_t (*bmap)(struct address_space___399 *, sector_t);
	void (*invalidatepage)(struct page___400 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___400 *, gfp_t);
	void (*freepage)(struct page___400 *);
	ssize_t (*direct_IO)(struct kiocb___399 *, struct iov_iter___167 *);
	int (*migratepage)(struct address_space___399 *, struct page___400 *, struct page___400 *, enum migrate_mode);
	bool (*isolate_page)(struct page___400 *, isolate_mode_t);
	void (*putback_page)(struct page___400 *);
	int (*launder_page)(struct page___400 *);
	int (*is_partially_uptodate)(struct page___400 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___400 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___399 *, struct page___400 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___399 *, sector_t *);
	void (*swap_deactivate)(struct file___399 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___399 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___399 *bd_inode;
	struct super_block___399 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___399 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___100 {
	struct kobject___387 kobj;
	struct module___329 *owner;
	const struct file_operations___399 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___399 {
	struct dentry___399 * (*lookup)(struct inode___399 *, struct dentry___399 *, unsigned int);
	const char * (*get_link)(struct dentry___399 *, struct inode___399 *, struct delayed_call *);
	int (*permission)(struct inode___399 *, int);
	struct posix_acl * (*get_acl)(struct inode___399 *, int);
	int (*readlink)(struct dentry___399 *, char *, int);
	int (*create)(struct inode___399 *, struct dentry___399 *, umode_t, bool);
	int (*link)(struct dentry___399 *, struct inode___399 *, struct dentry___399 *);
	int (*unlink)(struct inode___399 *, struct dentry___399 *);
	int (*symlink)(struct inode___399 *, struct dentry___399 *, const char *);
	int (*mkdir)(struct inode___399 *, struct dentry___399 *, umode_t);
	int (*rmdir)(struct inode___399 *, struct dentry___399 *);
	int (*mknod)(struct inode___399 *, struct dentry___399 *, umode_t, dev_t);
	int (*rename)(struct inode___399 *, struct dentry___399 *, struct inode___399 *, struct dentry___399 *, unsigned int);
	int (*setattr)(struct dentry___399 *, struct iattr___399 *);
	int (*getattr)(const struct path___400 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___399 *, char *, size_t);
	int (*fiemap)(struct inode___399 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___399 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___399 *, struct dentry___399 *, struct file___399 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___399 *, struct dentry___399 *, umode_t);
	int (*set_acl)(struct inode___399 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___399 {
	void (*fl_copy_lock)(struct file_lock___399 *, struct file_lock___399 *);
	void (*fl_release_private)(struct file_lock___399 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___399;

struct file_lock___399 {
	struct file_lock___399 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___399 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___399 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___399 *fl_ops;
	const struct lock_manager_operations___399 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___399 {
	int (*lm_compare_owner)(struct file_lock___399 *, struct file_lock___399 *);
	long unsigned int (*lm_owner_key)(struct file_lock___399 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___399 *);
	int (*lm_grant)(struct file_lock___399 *, int);
	bool (*lm_break)(struct file_lock___399 *);
	int (*lm_change)(struct file_lock___399 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___399 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___399 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___399 *fa_next;
	struct file___399 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___399 {
	const char *name;
	int fs_flags;
	struct dentry___399 * (*mount)(struct file_system_type___399 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___399 *);
	struct module___329 *owner;
	struct file_system_type___399 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___399 {
	struct inode___399 * (*alloc_inode)(struct super_block___399 *);
	void (*destroy_inode)(struct inode___399 *);
	void (*dirty_inode)(struct inode___399 *, int);
	int (*write_inode)(struct inode___399 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___399 *);
	void (*evict_inode)(struct inode___399 *);
	void (*put_super)(struct super_block___399 *);
	int (*sync_fs)(struct super_block___399 *, int);
	int (*freeze_super)(struct super_block___399 *);
	int (*freeze_fs)(struct super_block___399 *);
	int (*thaw_super)(struct super_block___399 *);
	int (*unfreeze_fs)(struct super_block___399 *);
	int (*statfs)(struct dentry___399 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___399 *, int *, char *);
	void (*umount_begin)(struct super_block___399 *);
	int (*show_options)(struct seq_file___338 *, struct dentry___399 *);
	int (*show_devname)(struct seq_file___338 *, struct dentry___399 *);
	int (*show_path)(struct seq_file___338 *, struct dentry___399 *);
	int (*show_stats)(struct seq_file___338 *, struct dentry___399 *);
	ssize_t (*quota_read)(struct super_block___399 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___399 *, int, const char *, size_t, loff_t);
	struct dquot___399 ** (*get_dquots)(struct inode___399 *);
	int (*bdev_try_to_free_page)(struct super_block___399 *, struct page___400 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___399 *, struct shrink_control___137 *);
	long int (*free_cached_objects)(struct super_block___399 *, struct shrink_control___137 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct acpi_device___21;

struct acpi_hotplug_profile___21 {
	struct kobject___387 kobj;
	int (*scan_dependent)(struct acpi_device___21 *);
	void (*notify_online)(struct acpi_device___21 *);
	bool enabled: 1;
	bool demand_offline: 1;
};

struct acpi_device_wakeup_context___21 {
	void (*func)(struct acpi_device_wakeup_context___21 *);
	struct device___367 *dev;
};

struct acpi_device_wakeup___21 {
	acpi_handle gpe_device;
	u64 gpe_number;
	u64 sleep_state;
	struct list_head resources;
	struct acpi_device_wakeup_flags flags;
	struct acpi_device_wakeup_context___21 context;
	struct wakeup_source___8 *ws;
	int prepare_count;
	int enable_count;
};

struct acpi_scan_handler___21;

struct acpi_hotplug_context___21;

struct acpi_driver___21;

struct acpi_device___21 {
	int device_type;
	acpi_handle handle;
	struct fwnode_handle___287 fwnode;
	struct acpi_device___21 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup___21 wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_device_data data;
	struct acpi_scan_handler___21 *handler;
	struct acpi_hotplug_context___21 *hp;
	struct acpi_driver___21 *driver;
	const struct acpi_gpio_mapping *driver_gpios;
	void *driver_data;
	struct device___367 dev;
	unsigned int physical_node_count;
	unsigned int dep_unmet;
	struct list_head physical_node_list;
	struct mutex physical_node_lock;
	void (*remove)(struct acpi_device___21 *);
};

struct acpi_scan_handler___21 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	bool (*match)(const char *, const struct acpi_device_id **);
	int (*attach)(struct acpi_device___21 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___21 *);
	void (*bind)(struct device___367 *);
	void (*unbind)(struct device___367 *);
	struct acpi_hotplug_profile___21 hotplug;
};

struct acpi_hotplug_context___21 {
	struct acpi_device___21 *self;
	int (*notify)(struct acpi_device___21 *, u32);
	void (*uevent)(struct acpi_device___21 *, u32);
	void (*fixup)(struct acpi_device___21 *);
};

typedef int (*acpi_op_add___21)(struct acpi_device___21 *);

typedef int (*acpi_op_remove___21)(struct acpi_device___21 *);

typedef void (*acpi_op_notify___21)(struct acpi_device___21 *, u32);

struct acpi_device_ops___21 {
	acpi_op_add___21 add;
	acpi_op_remove___21 remove;
	acpi_op_notify___21 notify;
};

struct acpi_driver___21 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___21 ops;
	struct device_driver___367 drv;
	struct module___329 *owner;
};

struct irqaction___22 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___22 *next;
	irq_handler_t thread_fn;
	struct task_struct___401 *thread;
	struct irqaction___22 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef int (*key_restrict_link_func_t___368)(struct key___367 *, const struct key_type *, const union key_payload *, struct key___367 *);

struct key_restriction___367;

struct key___367 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___401 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___367 *restrict_link;
};

struct key_restriction___367 {
	key_restrict_link_func_t___368 check;
	struct key___367 *key;
	struct key_type *keytype;
};

struct seq_operations___338 {
	void * (*start)(struct seq_file___338 *, loff_t *);
	void (*stop)(struct seq_file___338 *, void *);
	void * (*next)(struct seq_file___338 *, void *, loff_t *);
	int (*show)(struct seq_file___338 *, void *);
};

typedef void compound_page_dtor___387(struct page___400 *);

struct property___94 {
	char *name;
	int length;
	void *value;
	struct property___94 *next;
	long unsigned int _flags;
	struct bin_attribute___363 attr;
};

struct irq_desc___28;

typedef void (*irq_flow_handler_t___28)(struct irq_desc___28 *);

struct irq_chip___34;

struct irq_data___34 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___11 *common;
	struct irq_chip___34 *chip;
	struct irq_domain___34 *domain;
	struct irq_data___34 *parent_data;
	void *chip_data;
};

struct irq_desc___28 {
	struct irq_common_data___11 irq_common_data;
	struct irq_data___34 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___28 handle_irq;
	struct irqaction___22 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int irq_count;
	unsigned int tot_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___387 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___329 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip___34 {
	struct device___367 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___34 *);
	void (*irq_shutdown)(struct irq_data___34 *);
	void (*irq_enable)(struct irq_data___34 *);
	void (*irq_disable)(struct irq_data___34 *);
	void (*irq_ack)(struct irq_data___34 *);
	void (*irq_mask)(struct irq_data___34 *);
	void (*irq_mask_ack)(struct irq_data___34 *);
	void (*irq_unmask)(struct irq_data___34 *);
	void (*irq_eoi)(struct irq_data___34 *);
	int (*irq_set_affinity)(struct irq_data___34 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___34 *);
	int (*irq_set_type)(struct irq_data___34 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___34 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___34 *);
	void (*irq_bus_sync_unlock)(struct irq_data___34 *);
	void (*irq_cpu_online)(struct irq_data___34 *);
	void (*irq_cpu_offline)(struct irq_data___34 *);
	void (*irq_suspend)(struct irq_data___34 *);
	void (*irq_resume)(struct irq_data___34 *);
	void (*irq_pm_shutdown)(struct irq_data___34 *);
	void (*irq_calc_mask)(struct irq_data___34 *);
	void (*irq_print_chip)(struct irq_data___34 *, struct seq_file___338 *);
	int (*irq_request_resources)(struct irq_data___34 *);
	void (*irq_release_resources)(struct irq_data___34 *);
	void (*irq_compose_msi_msg)(struct irq_data___34 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___34 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___34 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___34 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___34 *, void *);
	void (*ipi_send_single)(struct irq_data___34 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___34 *, const struct cpumask *);
	long unsigned int flags;
};

struct irq_chip_type___22 {
	struct irq_chip___34 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___28 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___22 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___22 *);
	void (*resume)(struct irq_chip_generic___22 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___34 *domain;
	struct list_head list;
	struct irq_chip_type___22 chip_types[0];
};

struct irq_domain_chip_generic___21 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___22 *gc[0];
};

struct irq_fwspec___34 {
	struct fwnode_handle___287 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___34 {
	int (*match)(struct irq_domain___34 *, struct device_node___98 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___34 *, struct irq_fwspec___34 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___34 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___34 *, unsigned int);
	int (*xlate)(struct irq_domain___34 *, struct device_node___98 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___34 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___34 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___34 *, struct irq_data___34 *, bool);
	void (*deactivate)(struct irq_domain___34 *, struct irq_data___34 *);
	int (*translate)(struct irq_domain___34 *, struct irq_fwspec___34 *, long unsigned int *, unsigned int *);
};

struct node___220 {
	struct device___367 dev;
};

struct platform_device___31 {
	const char *name;
	int id;
	bool id_auto;
	struct device___367 dev;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct platform_driver___22 {
	int (*probe)(struct platform_device___31 *);
	int (*remove)(struct platform_device___31 *);
	void (*shutdown)(struct platform_device___31 *);
	int (*suspend)(struct platform_device___31 *, pm_message_t);
	int (*resume)(struct platform_device___31 *);
	struct device_driver___367 driver;
	const struct platform_device_id *id_table;
	bool prevent_deferred_probe;
};

struct cgroup_namespace___248 {
	refcount_t count;
	struct ns_common___9 ns;
	struct user_namespace___264 *user_ns;
	struct ucounts___264 *ucounts;
	struct css_set___248 *root_cset;
};

struct ucounts___264 {
	struct hlist_node node;
	struct user_namespace___264 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___249;

struct bpf_map_ops___248 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___249 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___249 *, struct file___399 *);
	void (*map_free)(struct bpf_map___249 *);
	int (*map_get_next_key)(struct bpf_map___249 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___249 *);
	void * (*map_lookup_elem)(struct bpf_map___249 *, void *);
	int (*map_update_elem)(struct bpf_map___249 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___249 *, void *);
	int (*map_push_elem)(struct bpf_map___249 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___249 *, void *);
	int (*map_peek_elem)(struct bpf_map___249 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___249 *, struct file___399 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___249 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___249 *, void *, struct seq_file___338 *);
	int (*map_check_btf)(const struct bpf_map___249 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___249 {
	const struct bpf_map_ops___248 *ops;
	struct bpf_map___249 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___367 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___249;

typedef void (*kthread_work_func_t___249)(struct kthread_work___249 *);

struct kthread_worker___249;

struct kthread_work___249 {
	struct list_head node;
	kthread_work_func_t___249 func;
	struct kthread_worker___249 *worker;
	int canceling;
};

struct kthread_worker___249 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___401 *task;
	struct kthread_work___249 *current_work;
};

struct kthread_delayed_work___248 {
	struct kthread_work___249 work;
	struct timer_list timer;
};

struct psi_group___248 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___249 *poll_kworker;
	struct kthread_delayed_work___248 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___248 {
	struct kernfs_node___394 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___248;

struct cgroup_subsys_state___248 {
	struct cgroup___248 *cgroup;
	struct cgroup_subsys___248 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___248 *parent;
};

struct cgroup_root___248;

struct cgroup_rstat_cpu___248;

struct cgroup___248 {
	struct cgroup_subsys_state___248 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___394 *kn;
	struct cgroup_file___248 procs_file;
	struct cgroup_file___248 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___248 *subsys[13];
	struct cgroup_root___248 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___248 *dom_cgrp;
	struct cgroup_rstat_cpu___248 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___39 bpf;
	atomic_t congestion_count;
	struct cgroup___248 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___248 psi;
	int ancestor_ids[0];
};

struct cftype___248;

struct cgroup_subsys___248 {
	struct cgroup_subsys_state___248 * (*css_alloc)(struct cgroup_subsys_state___248 *);
	int (*css_online)(struct cgroup_subsys_state___248 *);
	void (*css_offline)(struct cgroup_subsys_state___248 *);
	void (*css_released)(struct cgroup_subsys_state___248 *);
	void (*css_free)(struct cgroup_subsys_state___248 *);
	void (*css_reset)(struct cgroup_subsys_state___248 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___248 *, int);
	int (*css_extra_stat_show)(struct seq_file___338 *, struct cgroup_subsys_state___248 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___401 *);
	void (*cancel_fork)(struct task_struct___401 *);
	void (*fork)(struct task_struct___401 *);
	void (*exit)(struct task_struct___401 *);
	void (*free)(struct task_struct___401 *);
	void (*bind)(struct cgroup_subsys_state___248 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___248 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___248 *dfl_cftypes;
	struct cftype___248 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___248 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___248 *updated_children;
	struct cgroup___248 *updated_next;
};

struct cgroup_root___248 {
	struct kernfs_root___393 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___248 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___248 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___248 *ss;
	struct list_head node;
	struct kernfs_ops___393 *kf_ops;
	int (*open)(struct kernfs_open_file___393 *);
	void (*release)(struct kernfs_open_file___393 *);
	u64 (*read_u64)(struct cgroup_subsys_state___248 *, struct cftype___248 *);
	s64 (*read_s64)(struct cgroup_subsys_state___248 *, struct cftype___248 *);
	int (*seq_show)(struct seq_file___338 *, void *);
	void * (*seq_start)(struct seq_file___338 *, loff_t *);
	void * (*seq_next)(struct seq_file___338 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___338 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___248 *, struct cftype___248 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___248 *, struct cftype___248 *, s64);
	ssize_t (*write)(struct kernfs_open_file___393 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___393 *, struct poll_table_struct___242 *);
};

struct perf_cpu_context___152;

struct pmu___152 {
	struct list_head entry;
	struct module___329 *module;
	struct device___367 *dev;
	const struct attribute_group___364 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___152 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___152 *);
	void (*pmu_disable)(struct pmu___152 *);
	int (*event_init)(struct perf_event___152 *);
	void (*event_mapped)(struct perf_event___152 *, struct mm_struct___400 *);
	void (*event_unmapped)(struct perf_event___152 *, struct mm_struct___400 *);
	int (*add)(struct perf_event___152 *, int);
	void (*del)(struct perf_event___152 *, int);
	void (*start)(struct perf_event___152 *, int);
	void (*stop)(struct perf_event___152 *, int);
	void (*read)(struct perf_event___152 *);
	void (*start_txn)(struct pmu___152 *, unsigned int);
	int (*commit_txn)(struct pmu___152 *);
	void (*cancel_txn)(struct pmu___152 *);
	int (*event_idx)(struct perf_event___152 *);
	void (*sched_task)(struct perf_event_context___152 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___152 *);
	int (*filter_match)(struct perf_event___152 *);
	int (*check_period)(struct perf_event___152 *, u64);
};

struct perf_cpu_context___152 {
	struct perf_event_context___152 ctx;
	struct perf_event_context___152 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___152 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___152 {
	struct cgroup_subsys_state___248 css;
	struct perf_cgroup_info *info;
};

struct hw_pmu_info {
	u32 type;
	u32 enable_mask;
	void *csr;
};

struct xgene_pmu;

struct xgene_pmu_dev {
	struct hw_pmu_info *inf;
	struct xgene_pmu *parent;
	struct pmu___152 pmu;
	u8 max_counters;
	long unsigned int cntr_assign_mask[1];
	u64 max_period;
	const struct attribute_group___364 **attr_groups;
	struct perf_event___152 *pmu_counter_event[4];
};

struct xgene_pmu_ops;

struct xgene_pmu {
	struct device___367 *dev;
	struct hlist_node node;
	int version;
	void *pcppmu_csr;
	u32 mcb_active_mask;
	u32 mc_active_mask;
	u32 l3c_active_mask;
	cpumask_t cpu;
	int irq;
	raw_spinlock_t lock;
	const struct xgene_pmu_ops *ops;
	struct list_head l3cpmus;
	struct list_head iobpmus;
	struct list_head mcbpmus;
	struct list_head mcpmus;
};

struct xgene_pmu_ops {
	void (*mask_int)(struct xgene_pmu *);
	void (*unmask_int)(struct xgene_pmu *);
	u64 (*read_counter)(struct xgene_pmu_dev *, int);
	void (*write_counter)(struct xgene_pmu_dev *, int, u64);
	void (*write_evttype)(struct xgene_pmu_dev *, int, u32);
	void (*write_agentmsk)(struct xgene_pmu_dev *, u32);
	void (*write_agent1msk)(struct xgene_pmu_dev *, u32);
	void (*enable_counter)(struct xgene_pmu_dev *, int);
	void (*disable_counter)(struct xgene_pmu_dev *, int);
	void (*enable_counter_int)(struct xgene_pmu_dev *, int);
	void (*disable_counter_int)(struct xgene_pmu_dev *, int);
	void (*reset_counters)(struct xgene_pmu_dev *);
	void (*start_counters)(struct xgene_pmu_dev *);
	void (*stop_counters)(struct xgene_pmu_dev *);
};

struct xgene_pmu_dev_ctx {
	char *name;
	struct list_head next;
	struct xgene_pmu_dev *pmu_dev;
	struct hw_pmu_info inf;
};

struct xgene_pmu_data {
	int id;
	u32 data;
};

enum xgene_pmu_version {
	PCP_PMU_V1 = 1,
	PCP_PMU_V2 = 2,
	PCP_PMU_V3 = 3,
};

enum xgene_pmu_dev_type {
	PMU_TYPE_L3C = 0,
	PMU_TYPE_IOB = 1,
	PMU_TYPE_IOB_SLOW = 2,
	PMU_TYPE_MCB = 3,
	PMU_TYPE_MC = 4,
};

typedef guid_t uuid_le;

struct module___330;

struct file___400;

struct kiocb___400;

struct poll_table_struct___243;

struct vm_area_struct___401;

struct inode___400;

struct file_lock___400;

struct page___401;

struct seq_file___339;

struct file_operations___400 {
	struct module___330 *owner;
	loff_t (*llseek)(struct file___400 *, loff_t, int);
	ssize_t (*read)(struct file___400 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___400 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___400 *, struct iov_iter___167 *);
	ssize_t (*write_iter)(struct kiocb___400 *, struct iov_iter___167 *);
	int (*iopoll)(struct kiocb___400 *, bool);
	int (*iterate)(struct file___400 *, struct dir_context *);
	int (*iterate_shared)(struct file___400 *, struct dir_context *);
	__poll_t (*poll)(struct file___400 *, struct poll_table_struct___243 *);
	long int (*unlocked_ioctl)(struct file___400 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___400 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___400 *, struct vm_area_struct___401 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___400 *, struct file___400 *);
	int (*flush)(struct file___400 *, fl_owner_t);
	int (*release)(struct inode___400 *, struct file___400 *);
	int (*fsync)(struct file___400 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___400 *, int);
	int (*lock)(struct file___400 *, int, struct file_lock___400 *);
	ssize_t (*sendpage)(struct file___400 *, struct page___401 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___400 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___400 *, int, struct file_lock___400 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___400 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___400 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___400 *, long int, struct file_lock___400 **, void **);
	long int (*fallocate)(struct file___400 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___339 *, struct file___400 *);
	ssize_t (*copy_file_range)(struct file___400 *, loff_t, struct file___400 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___400 *, loff_t, struct file___400 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___400 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___401 {
	u64 seqnum;
	struct vm_area_struct___401 *vmas[4];
};

struct page_frag___401 {
	struct page___401 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___153;

struct debug_info___153 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___153 *hbp_break[16];
	struct perf_event___153 *hbp_watch[16];
};

struct thread_struct___153 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___153 debug;
	long: 64;
};

struct mm_struct___401;

struct pid___230;

struct cred___368;

struct nsproxy___295;

struct signal_struct___275;

struct css_set___249;

struct perf_event_context___153;

struct vm_struct___304;

struct task_struct___402 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___402 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___401 *mm;
	struct mm_struct___401 *active_mm;
	struct vmacache___401 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___402 *real_parent;
	struct task_struct___402 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___402 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___230 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___230 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___230 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___368 *ptracer_cred;
	const struct cred___368 *real_cred;
	const struct cred___368 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___295 *nsproxy;
	struct signal_struct___275 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___402 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___249 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___153 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___401 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___402 *oom_reaper_list;
	struct vm_struct___304 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___153 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___153 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___402 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___153)(struct perf_event___153 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___153;

struct fasync_struct___400;

struct pid_namespace___230;

struct trace_event_call___144;

struct perf_cgroup___153;

struct perf_event___153 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___153 *group_leader;
	struct pmu___153 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___153 hw;
	struct perf_event_context___153 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___153 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___402 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___400 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___153 *);
	struct callback_head callback_head;
	struct pid_namespace___230 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___153 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___153 orig_overflow_handler;
	struct bpf_prog *prog;
	struct trace_event_call___144 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___153 *cgrp;
	struct list_head sb_list;
};

struct dentry_operations___400;

struct super_block___400;

struct dentry___400 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___400 *d_parent;
	struct qstr d_name;
	struct inode___400 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___400 *d_op;
	struct super_block___400 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct rw_semaphore___402 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___402 *owner;
};

struct address_space_operations___400;

struct address_space___400 {
	struct inode___400 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___402 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___400 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___400;

struct block_device___400;

struct inode___400 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___400 *i_op;
	struct super_block___400 *i_sb;
	struct address_space___400 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___402 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___400 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___400 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct block_device___400 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___401;

struct dentry_operations___400 {
	int (*d_revalidate)(struct dentry___400 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___400 *, unsigned int);
	int (*d_hash)(const struct dentry___400 *, struct qstr *);
	int (*d_compare)(const struct dentry___400 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___400 *);
	int (*d_init)(struct dentry___400 *);
	void (*d_release)(struct dentry___400 *);
	void (*d_prune)(struct dentry___400 *);
	void (*d_iput)(struct dentry___400 *, struct inode___400 *);
	char * (*d_dname)(struct dentry___400 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___401 *);
	int (*d_manage)(const struct path___401 *, bool);
	struct dentry___400 * (*d_real)(struct dentry___400 *, const struct inode___400 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___400;

struct mem_dqinfo___400 {
	struct quota_format_type___400 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___400;

struct quota_info___400 {
	unsigned int flags;
	struct rw_semaphore___402 dqio_sem;
	struct inode___400 *files[3];
	struct mem_dqinfo___400 info[3];
	const struct quota_format_ops___400 *ops[3];
};

struct rcuwait___400 {
	struct task_struct___402 *task;
};

struct percpu_rw_semaphore___400 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___402 rw_sem;
	struct rcuwait___400 writer;
	int readers_block;
};

struct sb_writers___400 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___400 rw_sem[3];
};

struct file_system_type___400;

struct super_operations___400;

struct dquot_operations___400;

struct quotactl_ops___400;

struct user_namespace___265;

struct super_block___400 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___400 *s_type;
	const struct super_operations___400 *s_op;
	const struct dquot_operations___400 *dq_op;
	const struct quotactl_ops___400 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___400 *s_root;
	struct rw_semaphore___402 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___400 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___400 s_dquot;
	struct sb_writers___400 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___400 *s_d_op;
	int cleancache_poolid;
	struct shrinker___137 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___265 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct path___401 {
	struct vfsmount *mnt;
	struct dentry___400 *dentry;
};

struct key___368;

struct ucounts___265;

struct user_namespace___265 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___265 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___9 ns;
	long unsigned int flags;
	struct key___368 *persistent_keyring_register;
	struct rw_semaphore___402 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___265 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___401 *pgtable_t___401;

struct dev_pagemap___388;

struct page___401 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___400 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___401 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___401 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___401 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___388 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___401;

struct lruvec___401 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___401 *pgdat;
};

struct zone___401 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___401 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___401 {
	struct zone___401 *zone;
	int zone_idx;
};

struct zonelist___401 {
	struct zoneref___401 _zonerefs[25];
};

struct pglist_data___401 {
	struct zone___401 node_zones[3];
	struct zonelist___401 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___402 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___402 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___401 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___402 {
	void *stack;
	struct task_struct___402 *task;
	long int status;
};

struct blocking_notifier_head___401 {
	struct rw_semaphore___402 rwsem;
	struct notifier_block *head;
};

struct upid___230 {
	int nr;
	struct pid_namespace___230 *ns;
};

struct pid_namespace___230 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___402 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___230 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___400 *proc_self;
	struct dentry___400 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___265 *user_ns;
	struct ucounts___265 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___9 ns;
};

struct pid___230 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___230 numbers[1];
};

struct vm_operations_struct___388;

struct vm_area_struct___401 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___401 *vm_next;
	struct vm_area_struct___401 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___401 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___388 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___400 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___401;

struct mm_struct___401 {
	struct {
		struct vm_area_struct___401 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___400 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___402 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___401 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___402 *owner;
		struct user_namespace___265 *user_ns;
		struct file___400 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___401 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___388)(struct vm_area_struct___401 *, long unsigned int, const struct page___401 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___388)(struct page___401 *, void *);

struct device___368;

struct dev_pagemap___388 {
	dev_page_fault_t___388 page_fault;
	dev_page_free_t___388 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___368 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct fown_struct___230 {
	rwlock_t lock;
	struct pid___230 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___400 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___401 f_path;
	struct inode___400 *f_inode;
	const struct file_operations___400 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___230 f_owner;
	const struct cred___368 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___400 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___388;

struct vm_operations_struct___388 {
	void (*open)(struct vm_area_struct___401 *);
	void (*close)(struct vm_area_struct___401 *);
	int (*split)(struct vm_area_struct___401 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___401 *);
	vm_fault_t (*fault)(struct vm_fault___388 *);
	vm_fault_t (*huge_fault)(struct vm_fault___388 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___388 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___401 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___388 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___388 *);
	int (*access)(struct vm_area_struct___401 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___401 *);
	int (*set_policy)(struct vm_area_struct___401 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___401 *, long unsigned int);
	struct page___401 * (*find_special_page)(struct vm_area_struct___401 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___401 {
	struct task_struct___402 *task;
	struct core_thread___401 *next;
};

struct core_state___401 {
	atomic_t nr_threads;
	struct core_thread___401 dumper;
	struct completion startup;
};

struct vm_fault___388 {
	struct vm_area_struct___401 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___401 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___401 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___401 prealloc_pte;
};

struct user_struct___368 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___368 *uid_keyring;
	struct key___368 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___368 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___368 *session_keyring;
	struct key___368 *process_keyring;
	struct key___368 *thread_keyring;
	struct key___368 *request_key_auth;
	void *security;
	struct user_struct___368 *user;
	struct user_namespace___265 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___249;

struct nsproxy___295 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___230 *pid_ns_for_children;
	struct net *net_ns;
	struct cgroup_namespace___249 *cgroup_ns;
};

struct signal_struct___275 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___402 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___402 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___230 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___230 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___401 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___230 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide21;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___249;

struct cgroup___249;

struct css_set___249 {
	struct cgroup_subsys_state___249 *subsys[13];
	refcount_t refcount;
	struct css_set___249 *dom_cset;
	struct cgroup___249 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___249 *mg_src_cgrp;
	struct cgroup___249 *mg_dst_cgrp;
	struct css_set___249 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___153 {
	struct pmu___153 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___402 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___153 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___304 {
	struct vm_struct___304 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___401 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___287 {
	struct task_struct___402 task;
	long unsigned int stack[8192];
};

struct kiocb___400 {
	struct file___400 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___400 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___400 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___400 *ia_file;
};

struct dquot___400 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___400 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___400 {
	int qf_fmt_id;
	const struct quota_format_ops___400 *qf_ops;
	struct module___330 *qf_owner;
	struct quota_format_type___400 *qf_next;
};

struct quota_format_ops___400 {
	int (*check_quota_file)(struct super_block___400 *, int);
	int (*read_file_info)(struct super_block___400 *, int);
	int (*write_file_info)(struct super_block___400 *, int);
	int (*free_file_info)(struct super_block___400 *, int);
	int (*read_dqblk)(struct dquot___400 *);
	int (*commit_dqblk)(struct dquot___400 *);
	int (*release_dqblk)(struct dquot___400 *);
	int (*get_next_id)(struct super_block___400 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___400 {
	int (*write_dquot)(struct dquot___400 *);
	struct dquot___400 * (*alloc_dquot)(struct super_block___400 *, int);
	void (*destroy_dquot)(struct dquot___400 *);
	int (*acquire_dquot)(struct dquot___400 *);
	int (*release_dquot)(struct dquot___400 *);
	int (*mark_dirty)(struct dquot___400 *);
	int (*write_info)(struct super_block___400 *, int);
	qsize_t * (*get_reserved_space)(struct inode___400 *);
	int (*get_projid)(struct inode___400 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___400 *, qsize_t *);
	int (*get_next_id)(struct super_block___400 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___400 {
	int (*quota_on)(struct super_block___400 *, int, int, const struct path___401 *);
	int (*quota_off)(struct super_block___400 *, int);
	int (*quota_enable)(struct super_block___400 *, unsigned int);
	int (*quota_disable)(struct super_block___400 *, unsigned int);
	int (*quota_sync)(struct super_block___400 *, int);
	int (*set_info)(struct super_block___400 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___400 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___400 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___400 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___400 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___400 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___387;

struct kobj_type___387;

struct kernfs_node___395;

struct kobject___388 {
	const char *name;
	struct list_head entry;
	struct kobject___388 *parent;
	struct kset___387 *kset;
	struct kobj_type___387 *ktype;
	struct kernfs_node___395 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___328 {
	struct kobject___388 kobj;
	struct module___330 *mod;
	struct kobject___388 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___328 {
	struct module___330 *mod;
	struct latch_tree_node node;
};

struct module_layout___328 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___328 mtn;
};

struct module_attribute___328;

struct kernel_param___328;

struct module___330 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___328 mkobj;
	struct module_attribute___328 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___388 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___328 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___328 core_layout;
	struct module_layout___328 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___144 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___400 {
	int (*writepage)(struct page___401 *, struct writeback_control___3 *);
	int (*readpage)(struct file___400 *, struct page___401 *);
	int (*writepages)(struct address_space___400 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___401 *);
	int (*readpages)(struct file___400 *, struct address_space___400 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___400 *, struct address_space___400 *, loff_t, unsigned int, unsigned int, struct page___401 **, void **);
	int (*write_end)(struct file___400 *, struct address_space___400 *, loff_t, unsigned int, unsigned int, struct page___401 *, void *);
	sector_t (*bmap)(struct address_space___400 *, sector_t);
	void (*invalidatepage)(struct page___401 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___401 *, gfp_t);
	void (*freepage)(struct page___401 *);
	ssize_t (*direct_IO)(struct kiocb___400 *, struct iov_iter___167 *);
	int (*migratepage)(struct address_space___400 *, struct page___401 *, struct page___401 *, enum migrate_mode);
	bool (*isolate_page)(struct page___401 *, isolate_mode_t);
	void (*putback_page)(struct page___401 *);
	int (*launder_page)(struct page___401 *);
	int (*is_partially_uptodate)(struct page___401 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___401 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___400 *, struct page___401 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___400 *, sector_t *);
	void (*swap_deactivate)(struct file___400 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___400 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___400 *bd_inode;
	struct super_block___400 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___400 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___400 {
	struct dentry___400 * (*lookup)(struct inode___400 *, struct dentry___400 *, unsigned int);
	const char * (*get_link)(struct dentry___400 *, struct inode___400 *, struct delayed_call *);
	int (*permission)(struct inode___400 *, int);
	struct posix_acl * (*get_acl)(struct inode___400 *, int);
	int (*readlink)(struct dentry___400 *, char *, int);
	int (*create)(struct inode___400 *, struct dentry___400 *, umode_t, bool);
	int (*link)(struct dentry___400 *, struct inode___400 *, struct dentry___400 *);
	int (*unlink)(struct inode___400 *, struct dentry___400 *);
	int (*symlink)(struct inode___400 *, struct dentry___400 *, const char *);
	int (*mkdir)(struct inode___400 *, struct dentry___400 *, umode_t);
	int (*rmdir)(struct inode___400 *, struct dentry___400 *);
	int (*mknod)(struct inode___400 *, struct dentry___400 *, umode_t, dev_t);
	int (*rename)(struct inode___400 *, struct dentry___400 *, struct inode___400 *, struct dentry___400 *, unsigned int);
	int (*setattr)(struct dentry___400 *, struct iattr___400 *);
	int (*getattr)(const struct path___401 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___400 *, char *, size_t);
	int (*fiemap)(struct inode___400 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___400 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___400 *, struct dentry___400 *, struct file___400 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___400 *, struct dentry___400 *, umode_t);
	int (*set_acl)(struct inode___400 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___400 {
	void (*fl_copy_lock)(struct file_lock___400 *, struct file_lock___400 *);
	void (*fl_release_private)(struct file_lock___400 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___400;

struct file_lock___400 {
	struct file_lock___400 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___400 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___400 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___400 *fl_ops;
	const struct lock_manager_operations___400 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___400 {
	int (*lm_compare_owner)(struct file_lock___400 *, struct file_lock___400 *);
	long unsigned int (*lm_owner_key)(struct file_lock___400 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___400 *);
	int (*lm_grant)(struct file_lock___400 *, int);
	bool (*lm_break)(struct file_lock___400 *);
	int (*lm_change)(struct file_lock___400 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___400 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___400 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___400 *fa_next;
	struct file___400 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___400 {
	const char *name;
	int fs_flags;
	struct dentry___400 * (*mount)(struct file_system_type___400 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___400 *);
	struct module___330 *owner;
	struct file_system_type___400 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___400 {
	struct inode___400 * (*alloc_inode)(struct super_block___400 *);
	void (*destroy_inode)(struct inode___400 *);
	void (*dirty_inode)(struct inode___400 *, int);
	int (*write_inode)(struct inode___400 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___400 *);
	void (*evict_inode)(struct inode___400 *);
	void (*put_super)(struct super_block___400 *);
	int (*sync_fs)(struct super_block___400 *, int);
	int (*freeze_super)(struct super_block___400 *);
	int (*freeze_fs)(struct super_block___400 *);
	int (*thaw_super)(struct super_block___400 *);
	int (*unfreeze_fs)(struct super_block___400 *);
	int (*statfs)(struct dentry___400 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___400 *, int *, char *);
	void (*umount_begin)(struct super_block___400 *);
	int (*show_options)(struct seq_file___339 *, struct dentry___400 *);
	int (*show_devname)(struct seq_file___339 *, struct dentry___400 *);
	int (*show_path)(struct seq_file___339 *, struct dentry___400 *);
	int (*show_stats)(struct seq_file___339 *, struct dentry___400 *);
	ssize_t (*quota_read)(struct super_block___400 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___400 *, int, const char *, size_t, loff_t);
	struct dquot___400 ** (*get_dquots)(struct inode___400 *);
	int (*bdev_try_to_free_page)(struct super_block___400 *, struct page___401 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___400 *, struct shrink_control___137 *);
	long int (*free_cached_objects)(struct super_block___400 *, struct shrink_control___137 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___253)(struct file___400 *, wait_queue_head_t *, struct poll_table_struct___243 *);

struct poll_table_struct___243 {
	poll_queue_proc___253 _qproc;
	__poll_t _key;
};

struct seq_operations___339;

struct seq_file___339 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___339 *op;
	int poll_event;
	const struct file___400 *file;
	void *private;
};

struct kernfs_root___394;

struct kernfs_elem_dir___394 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___394 *root;
};

struct kernfs_syscall_ops___394;

struct kernfs_root___394 {
	struct kernfs_node___395 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___394 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___394 {
	struct kernfs_node___395 *target_kn;
};

struct kernfs_ops___394;

struct kernfs_elem_attr___394 {
	const struct kernfs_ops___394 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___395 *notify_next;
};

struct kernfs_node___395 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___395 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___394 dir;
		struct kernfs_elem_symlink___394 symlink;
		struct kernfs_elem_attr___394 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___394;

struct kernfs_ops___394 {
	int (*open)(struct kernfs_open_file___394 *);
	void (*release)(struct kernfs_open_file___394 *);
	int (*seq_show)(struct seq_file___339 *, void *);
	void * (*seq_start)(struct seq_file___339 *, loff_t *);
	void * (*seq_next)(struct seq_file___339 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___339 *, void *);
	ssize_t (*read)(struct kernfs_open_file___394 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___394 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___394 *, struct vm_area_struct___401 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___394 *, struct poll_table_struct___243 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___394 {
	int (*remount_fs)(struct kernfs_root___394 *, int *, char *);
	int (*show_options)(struct seq_file___339 *, struct kernfs_root___394 *);
	int (*mkdir)(struct kernfs_node___395 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___395 *);
	int (*rename)(struct kernfs_node___395 *, struct kernfs_node___395 *, const char *);
	int (*show_path)(struct seq_file___339 *, struct kernfs_node___395 *, struct kernfs_root___394 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___394 {
	struct kernfs_node___395 *kn;
	struct file___400 *file;
	struct seq_file___339 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___388 *vm_ops;
};

struct bin_attribute___364;

struct attribute_group___365 {
	const char *name;
	umode_t (*is_visible)(struct kobject___388 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___388 *, struct bin_attribute___364 *, int);
	struct attribute **attrs;
	struct bin_attribute___364 **bin_attrs;
};

struct bin_attribute___364 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___400 *, struct kobject___388 *, struct bin_attribute___364 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___400 *, struct kobject___388 *, struct bin_attribute___364 *, char *, loff_t, size_t);
	int (*mmap)(struct file___400 *, struct kobject___388 *, struct bin_attribute___364 *, struct vm_area_struct___401 *);
};

struct sysfs_ops___387 {
	ssize_t (*show)(struct kobject___388 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___388 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___387;

struct kset___387 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___388 kobj;
	const struct kset_uevent_ops___387 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___387 {
	void (*release)(struct kobject___388 *);
	const struct sysfs_ops___387 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___29 * (*child_ns_type)(struct kobject___388 *);
	const void * (*namespace)(struct kobject___388 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___387 {
	int (* const filter)(struct kset___387 *, struct kobject___388 *);
	const char * (* const name)(struct kset___387 *, struct kobject___388 *);
	int (* const uevent)(struct kset___387 *, struct kobject___388 *, struct kobj_uevent_env *);
};

struct kobj_attribute___378 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___388 *, struct kobj_attribute___378 *, char *);
	ssize_t (*store)(struct kobject___388 *, struct kobj_attribute___378 *, const char *, size_t);
};

struct dev_pm_ops___368 {
	int (*prepare)(struct device___368 *);
	void (*complete)(struct device___368 *);
	int (*suspend)(struct device___368 *);
	int (*resume)(struct device___368 *);
	int (*freeze)(struct device___368 *);
	int (*thaw)(struct device___368 *);
	int (*poweroff)(struct device___368 *);
	int (*restore)(struct device___368 *);
	int (*suspend_late)(struct device___368 *);
	int (*resume_early)(struct device___368 *);
	int (*freeze_late)(struct device___368 *);
	int (*thaw_early)(struct device___368 *);
	int (*poweroff_late)(struct device___368 *);
	int (*restore_early)(struct device___368 *);
	int (*suspend_noirq)(struct device___368 *);
	int (*resume_noirq)(struct device___368 *);
	int (*freeze_noirq)(struct device___368 *);
	int (*thaw_noirq)(struct device___368 *);
	int (*poweroff_noirq)(struct device___368 *);
	int (*restore_noirq)(struct device___368 *);
	int (*runtime_suspend)(struct device___368 *);
	int (*runtime_resume)(struct device___368 *);
	int (*runtime_idle)(struct device___368 *);
};

struct dev_pm_info___368 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___368 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___368;

struct bus_type___368;

struct device_driver___368;

struct dev_pm_domain___368;

struct dma_map_ops___140;

struct fwnode_handle___288;

struct class___368;

struct device___368 {
	struct device___368 *parent;
	struct device_private *p;
	struct kobject___388 kobj;
	const char *init_name;
	const struct device_type___368 *type;
	struct mutex mutex;
	struct bus_type___368 *bus;
	struct device_driver___368 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___368 power;
	struct dev_pm_domain___368 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___140 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___288 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___368 *class;
	const struct attribute_group___365 **groups;
	void (*release)(struct device___368 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___368 {
	struct dev_pm_ops___368 ops;
	void (*detach)(struct device___368 *, bool);
	int (*activate)(struct device___368 *);
	void (*sync)(struct device___368 *);
	void (*dismiss)(struct device___368 *);
};

struct bus_type___368 {
	const char *name;
	const char *dev_name;
	struct device___368 *dev_root;
	const struct attribute_group___365 **bus_groups;
	const struct attribute_group___365 **dev_groups;
	const struct attribute_group___365 **drv_groups;
	int (*match)(struct device___368 *, struct device_driver___368 *);
	int (*uevent)(struct device___368 *, struct kobj_uevent_env *);
	int (*probe)(struct device___368 *);
	int (*remove)(struct device___368 *);
	void (*shutdown)(struct device___368 *);
	int (*online)(struct device___368 *);
	int (*offline)(struct device___368 *);
	int (*suspend)(struct device___368 *, pm_message_t);
	int (*resume)(struct device___368 *);
	int (*num_vf)(struct device___368 *);
	int (*dma_configure)(struct device___368 *);
	const struct dev_pm_ops___368 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___368 {
	const char *name;
	struct bus_type___368 *bus;
	struct module___330 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___368 *);
	int (*remove)(struct device___368 *);
	void (*shutdown)(struct device___368 *);
	int (*suspend)(struct device___368 *, pm_message_t);
	int (*resume)(struct device___368 *);
	const struct attribute_group___365 **groups;
	const struct dev_pm_ops___368 *pm;
	void (*coredump)(struct device___368 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___368 {
	const char *name;
	const struct attribute_group___365 **groups;
	int (*uevent)(struct device___368 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___368 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___368 *);
	const struct dev_pm_ops___368 *pm;
};

struct class___368 {
	const char *name;
	struct module___330 *owner;
	const struct attribute_group___365 **class_groups;
	const struct attribute_group___365 **dev_groups;
	struct kobject___388 *dev_kobj;
	int (*dev_uevent)(struct device___368 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___368 *, umode_t *);
	void (*class_release)(struct class___368 *);
	void (*dev_release)(struct device___368 *);
	int (*shutdown_pre)(struct device___368 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___368 *);
	const struct dev_pm_ops___368 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___140 {
	void * (*alloc)(struct device___368 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___368 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___368 *, struct vm_area_struct___401 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___368 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___368 *, struct page___401 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___368 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___368 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___368 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___368 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___368 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___368 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___368 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___368 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___368 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___368 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___368 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___368 *, u64);
	u64 (*get_required_mask)(struct device___368 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___288;

struct fwnode_handle___288 {
	struct fwnode_handle___288 *secondary;
	const struct fwnode_operations___288 *ops;
};

typedef int (*key_restrict_link_func_t___369)(struct key___368 *, const struct key_type *, const union key_payload *, struct key___368 *);

struct key_restriction___368;

struct key___368 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___402 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___368 *restrict_link;
};

struct key_restriction___368 {
	key_restrict_link_func_t___369 check;
	struct key___368 *key;
	struct key_type *keytype;
};

struct seq_operations___339 {
	void * (*start)(struct seq_file___339 *, loff_t *);
	void (*stop)(struct seq_file___339 *, void *);
	void * (*next)(struct seq_file___339 *, void *, loff_t *);
	int (*show)(struct seq_file___339 *, void *);
};

struct fwnode_reference_args___288;

struct fwnode_endpoint___288;

struct fwnode_operations___288 {
	struct fwnode_handle___288 * (*get)(struct fwnode_handle___288 *);
	void (*put)(struct fwnode_handle___288 *);
	bool (*device_is_available)(const struct fwnode_handle___288 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___288 *, const struct device___368 *);
	bool (*property_present)(const struct fwnode_handle___288 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___288 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___288 *, const char *, const char **, size_t);
	struct fwnode_handle___288 * (*get_parent)(const struct fwnode_handle___288 *);
	struct fwnode_handle___288 * (*get_next_child_node)(const struct fwnode_handle___288 *, struct fwnode_handle___288 *);
	struct fwnode_handle___288 * (*get_named_child_node)(const struct fwnode_handle___288 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___288 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___288 *);
	struct fwnode_handle___288 * (*graph_get_next_endpoint)(const struct fwnode_handle___288 *, struct fwnode_handle___288 *);
	struct fwnode_handle___288 * (*graph_get_remote_endpoint)(const struct fwnode_handle___288 *);
	struct fwnode_handle___288 * (*graph_get_port_parent)(struct fwnode_handle___288 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___288 *, struct fwnode_endpoint___288 *);
};

struct fwnode_endpoint___288 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___288 *local_fwnode;
};

struct fwnode_reference_args___288 {
	struct fwnode_handle___288 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

typedef void compound_page_dtor___388(struct page___401 *);

struct cgroup_namespace___249 {
	refcount_t count;
	struct ns_common___9 ns;
	struct user_namespace___265 *user_ns;
	struct ucounts___265 *ucounts;
	struct css_set___249 *root_cset;
};

struct ucounts___265 {
	struct hlist_node node;
	struct user_namespace___265 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct kernel_param_ops___328 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___328 *);
	int (*get)(char *, const struct kernel_param___328 *);
	void (*free)(void *);
};

struct kparam_array___328;

struct kernel_param___328 {
	const char *name;
	struct module___330 *mod;
	const struct kernel_param_ops___328 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___328 *arr;
	};
};

struct kparam_array___328 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___328 *ops;
	void *elem;
};

struct module_attribute___328 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___328 *, struct module_kobject___328 *, char *);
	ssize_t (*store)(struct module_attribute___328 *, struct module_kobject___328 *, const char *, size_t);
	void (*setup)(struct module___330 *, const char *);
	int (*test)(struct module___330 *);
	void (*free)(struct module___330 *);
};

struct trace_event_class___144;

struct trace_event_call___144 {
	struct list_head list;
	struct trace_event_class___144 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___13 event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___39 *prog_array;
	int (*perf_perm)(struct trace_event_call___144 *, struct perf_event___153 *);
};

struct node___221 {
	struct device___368 dev;
};

struct bpf_map___250;

struct bpf_map_ops___249 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___250 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___250 *, struct file___400 *);
	void (*map_free)(struct bpf_map___250 *);
	int (*map_get_next_key)(struct bpf_map___250 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___250 *);
	void * (*map_lookup_elem)(struct bpf_map___250 *, void *);
	int (*map_update_elem)(struct bpf_map___250 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___250 *, void *);
	int (*map_push_elem)(struct bpf_map___250 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___250 *, void *);
	int (*map_peek_elem)(struct bpf_map___250 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___250 *, struct file___400 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___250 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___250 *, void *, struct seq_file___339 *);
	int (*map_check_btf)(const struct bpf_map___250 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___250 {
	const struct bpf_map_ops___249 *ops;
	struct bpf_map___250 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___368 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___250;

typedef void (*kthread_work_func_t___250)(struct kthread_work___250 *);

struct kthread_worker___250;

struct kthread_work___250 {
	struct list_head node;
	kthread_work_func_t___250 func;
	struct kthread_worker___250 *worker;
	int canceling;
};

struct kthread_worker___250 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___402 *task;
	struct kthread_work___250 *current_work;
};

struct kthread_delayed_work___249 {
	struct kthread_work___250 work;
	struct timer_list timer;
};

struct psi_group___249 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___250 *poll_kworker;
	struct kthread_delayed_work___249 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___249 {
	struct kernfs_node___395 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___249;

struct cgroup_subsys_state___249 {
	struct cgroup___249 *cgroup;
	struct cgroup_subsys___249 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___249 *parent;
};

struct cgroup_root___249;

struct cgroup_rstat_cpu___249;

struct cgroup___249 {
	struct cgroup_subsys_state___249 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___395 *kn;
	struct cgroup_file___249 procs_file;
	struct cgroup_file___249 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___249 *subsys[13];
	struct cgroup_root___249 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___249 *dom_cgrp;
	struct cgroup_rstat_cpu___249 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___39 bpf;
	atomic_t congestion_count;
	struct cgroup___249 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___249 psi;
	int ancestor_ids[0];
};

struct cftype___249;

struct cgroup_subsys___249 {
	struct cgroup_subsys_state___249 * (*css_alloc)(struct cgroup_subsys_state___249 *);
	int (*css_online)(struct cgroup_subsys_state___249 *);
	void (*css_offline)(struct cgroup_subsys_state___249 *);
	void (*css_released)(struct cgroup_subsys_state___249 *);
	void (*css_free)(struct cgroup_subsys_state___249 *);
	void (*css_reset)(struct cgroup_subsys_state___249 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___249 *, int);
	int (*css_extra_stat_show)(struct seq_file___339 *, struct cgroup_subsys_state___249 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___402 *);
	void (*cancel_fork)(struct task_struct___402 *);
	void (*fork)(struct task_struct___402 *);
	void (*exit)(struct task_struct___402 *);
	void (*free)(struct task_struct___402 *);
	void (*bind)(struct cgroup_subsys_state___249 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___249 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___249 *dfl_cftypes;
	struct cftype___249 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___249 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___249 *updated_children;
	struct cgroup___249 *updated_next;
};

struct cgroup_root___249 {
	struct kernfs_root___394 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___249 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___249 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___249 *ss;
	struct list_head node;
	struct kernfs_ops___394 *kf_ops;
	int (*open)(struct kernfs_open_file___394 *);
	void (*release)(struct kernfs_open_file___394 *);
	u64 (*read_u64)(struct cgroup_subsys_state___249 *, struct cftype___249 *);
	s64 (*read_s64)(struct cgroup_subsys_state___249 *, struct cftype___249 *);
	int (*seq_show)(struct seq_file___339 *, void *);
	void * (*seq_start)(struct seq_file___339 *, loff_t *);
	void * (*seq_next)(struct seq_file___339 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___339 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___249 *, struct cftype___249 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___249 *, struct cftype___249 *, s64);
	ssize_t (*write)(struct kernfs_open_file___394 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___394 *, struct poll_table_struct___243 *);
};

struct perf_cpu_context___153;

struct pmu___153 {
	struct list_head entry;
	struct module___330 *module;
	struct device___368 *dev;
	const struct attribute_group___365 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___153 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___153 *);
	void (*pmu_disable)(struct pmu___153 *);
	int (*event_init)(struct perf_event___153 *);
	void (*event_mapped)(struct perf_event___153 *, struct mm_struct___401 *);
	void (*event_unmapped)(struct perf_event___153 *, struct mm_struct___401 *);
	int (*add)(struct perf_event___153 *, int);
	void (*del)(struct perf_event___153 *, int);
	void (*start)(struct perf_event___153 *, int);
	void (*stop)(struct perf_event___153 *, int);
	void (*read)(struct perf_event___153 *);
	void (*start_txn)(struct pmu___153 *, unsigned int);
	int (*commit_txn)(struct pmu___153 *);
	void (*cancel_txn)(struct pmu___153 *);
	int (*event_idx)(struct perf_event___153 *);
	void (*sched_task)(struct perf_event_context___153 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___153 *);
	int (*filter_match)(struct perf_event___153 *);
	int (*check_period)(struct perf_event___153 *, u64);
};

struct perf_cpu_context___153 {
	struct perf_event_context___153 ctx;
	struct perf_event_context___153 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___153 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___153 {
	struct cgroup_subsys_state___249 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___144 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___144 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___144 *);
	struct list_head * (*get_fields)(struct trace_event_call___144 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___144 *);
};

struct trace_event_file___61;

struct trace_event_buffer___53 {
	struct ring_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___61 *trace_file;
	void *entry;
	long unsigned int flags;
	int pc;
};

struct trace_event_file___61 {
	struct list_head list;
	struct trace_event_call___144 *event_call;
	struct event_filter *filter;
	struct dentry___400 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_mc_event {
	struct trace_entry ent;
	unsigned int error_type;
	u32 __data_loc_msg;
	u32 __data_loc_label;
	u16 error_count;
	u8 mc_index;
	s8 top_layer;
	s8 middle_layer;
	s8 lower_layer;
	long int address;
	u8 grain_bits;
	long int syndrome;
	u32 __data_loc_driver_detail;
	char __data[0];
};

struct trace_event_raw_arm_event {
	struct trace_entry ent;
	u64 mpidr;
	u64 midr;
	u32 running_state;
	u32 psci_state;
	u8 affinity;
	char __data[0];
};

struct trace_event_raw_non_standard_event {
	struct trace_entry ent;
	char sec_type[16];
	char fru_id[16];
	u32 __data_loc_fru_text;
	u8 sev;
	u32 len;
	u32 __data_loc_buf;
	char __data[0];
};

struct trace_event_raw_aer_event {
	struct trace_entry ent;
	u32 __data_loc_dev_name;
	u32 status;
	u8 severity;
	u8 tlp_header_valid;
	u32 tlp_header[4];
	char __data[0];
};

struct trace_event_raw_memory_failure_event {
	struct trace_entry ent;
	long unsigned int pfn;
	int type;
	int result;
	char __data[0];
};

struct trace_event_data_offsets_mc_event {
	u32 msg;
	u32 label;
	u32 driver_detail;
};

struct trace_event_data_offsets_arm_event {};

struct trace_event_data_offsets_non_standard_event {
	u32 fru_text;
	u32 buf;
};

struct trace_event_data_offsets_aer_event {
	u32 dev_name;
};

struct trace_event_data_offsets_memory_failure_event {};

typedef void (*dr_release_t___31)(struct device___367 *, void *);

struct nvmem_config___2 {
	struct device___367 *dev;
	const char *name;
	int id;
	struct module___329 *owner;
	const struct nvmem_cell_info *cells;
	int ncells;
	bool read_only;
	bool root_only;
	nvmem_reg_read_t reg_read;
	nvmem_reg_write_t reg_write;
	int size;
	int word_size;
	int stride;
	void *priv;
	bool compat;
	struct device___367 *base_dev;
};

struct nvmem_device___2 {
	const char *name;
	struct module___329 *owner;
	struct device___367 dev;
	int stride;
	int word_size;
	int ncells;
	int id;
	int users;
	size_t size;
	bool read_only;
	int flags;
	struct bin_attribute___363 eeprom;
	struct device___367 *base_dev;
	nvmem_reg_read_t reg_read;
	nvmem_reg_write_t reg_write;
	void *priv;
};

struct nvmem_cell___2 {
	const char *name;
	int offset;
	int bytes;
	int bit_offset;
	int nbits;
	struct nvmem_device___2 *nvmem;
	struct list_head node;
};

struct module___331;

struct file___401;

struct kiocb___401;

struct iov_iter___168;

struct poll_table_struct___244;

struct vm_area_struct___402;

struct inode___401;

struct file_lock___401;

struct page___402;

struct pipe_inode_info___82;

struct seq_file___340;

struct file_operations___401 {
	struct module___331 *owner;
	loff_t (*llseek)(struct file___401 *, loff_t, int);
	ssize_t (*read)(struct file___401 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___401 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___401 *, struct iov_iter___168 *);
	ssize_t (*write_iter)(struct kiocb___401 *, struct iov_iter___168 *);
	int (*iopoll)(struct kiocb___401 *, bool);
	int (*iterate)(struct file___401 *, struct dir_context *);
	int (*iterate_shared)(struct file___401 *, struct dir_context *);
	__poll_t (*poll)(struct file___401 *, struct poll_table_struct___244 *);
	long int (*unlocked_ioctl)(struct file___401 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___401 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___401 *, struct vm_area_struct___402 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___401 *, struct file___401 *);
	int (*flush)(struct file___401 *, fl_owner_t);
	int (*release)(struct inode___401 *, struct file___401 *);
	int (*fsync)(struct file___401 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___401 *, int);
	int (*lock)(struct file___401 *, int, struct file_lock___401 *);
	ssize_t (*sendpage)(struct file___401 *, struct page___402 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___401 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___401 *, int, struct file_lock___401 *);
	ssize_t (*splice_write)(struct pipe_inode_info___82 *, struct file___401 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___401 *, loff_t *, struct pipe_inode_info___82 *, size_t, unsigned int);
	int (*setlease)(struct file___401 *, long int, struct file_lock___401 **, void **);
	long int (*fallocate)(struct file___401 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___340 *, struct file___401 *);
	ssize_t (*copy_file_range)(struct file___401 *, loff_t, struct file___401 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___401 *, loff_t, struct file___401 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___401 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___402 {
	u64 seqnum;
	struct vm_area_struct___402 *vmas[4];
};

struct page_frag___402 {
	struct page___402 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___154;

struct debug_info___154 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___154 *hbp_break[16];
	struct perf_event___154 *hbp_watch[16];
};

struct thread_struct___154 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___154 debug;
	long: 64;
};

struct mm_struct___402;

struct mem_cgroup___138;

struct pid___231;

struct cred___369;

struct nsproxy___296;

struct signal_struct___276;

struct bio_list___195;

struct backing_dev_info___195;

struct css_set___250;

struct perf_event_context___154;

struct vm_struct___305;

struct task_struct___403 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___403 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___402 *mm;
	struct mm_struct___402 *active_mm;
	struct vmacache___402 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___403 *real_parent;
	struct task_struct___403 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___403 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___138 *active_memcg;
	long int rh_reserved2;
	struct pid___231 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___231 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___231 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___369 *ptracer_cred;
	const struct cred___369 *real_cred;
	const struct cred___369 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___296 *nsproxy;
	struct signal_struct___276 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___403 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___195 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___195 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___250 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___154 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___82 *splice_pipe;
	struct page_frag___402 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___138 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___403 *oom_reaper_list;
	struct vm_struct___305 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___154 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___154 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___403 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___154)(struct perf_event___154 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___154;

struct fasync_struct___401;

struct pid_namespace___231;

struct bpf_prog___40;

struct trace_event_call___145;

struct perf_cgroup___154;

struct perf_event___154 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___154 *group_leader;
	struct pmu___154 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___154 hw;
	struct perf_event_context___154 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___154 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___403 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___401 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___154 *);
	struct callback_head callback_head;
	struct pid_namespace___231 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___154 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___154 orig_overflow_handler;
	struct bpf_prog___40 *prog;
	struct trace_event_call___145 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___154 *cgrp;
	struct list_head sb_list;
};

typedef struct page___402 *pgtable_t___402;

struct address_space___401;

struct dev_pagemap___389;

struct page___402 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___401 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___402 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___402 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___402 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___389 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___138 *mem_cgroup;
};

struct pglist_data___402;

struct lruvec___402 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___402 *pgdat;
};

struct zone___402 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___402 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___402 {
	struct zone___402 *zone;
	int zone_idx;
};

struct zonelist___402 {
	struct zoneref___402 _zonerefs[25];
};

struct pglist_data___402 {
	struct zone___402 node_zones[3];
	struct zonelist___402 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___403 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___403 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___402 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___403 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___403 *owner;
};

struct secondary_data___403 {
	void *stack;
	struct task_struct___403 *task;
	long int status;
};

struct blocking_notifier_head___402 {
	struct rw_semaphore___403 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___389;

struct vm_area_struct___402 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___402 *vm_next;
	struct vm_area_struct___402 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___402 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___389 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___401 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___402;

struct user_namespace___266;

struct mm_struct___402 {
	struct {
		struct vm_area_struct___402 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___401 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___403 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___402 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___403 *owner;
		struct user_namespace___266 *user_ns;
		struct file___401 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___402 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___401;

struct address_space___401 {
	struct inode___401 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___403 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___401 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___389)(struct vm_area_struct___402 *, long unsigned int, const struct page___402 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___389)(struct page___402 *, void *);

struct device___369;

struct dev_pagemap___389 {
	dev_page_fault_t___389 page_fault;
	dev_page_free_t___389 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___369 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct cgroup___250;

struct cgroup_subsys___250;

struct cgroup_subsys_state___250 {
	struct cgroup___250 *cgroup;
	struct cgroup_subsys___250 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___250 *parent;
};

struct kernfs_node___396;

struct cgroup_file___250 {
	struct kernfs_node___396 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___138;

struct mem_cgroup___138 {
	struct cgroup_subsys_state___250 css;
	struct mem_cgroup_id___14 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___250 events_file;
	struct cgroup_file___250 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___403 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___138 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct vfsmount___72;

struct dentry___401;

struct path___402 {
	struct vfsmount___72 *mnt;
	struct dentry___401 *dentry;
};

struct fown_struct___231 {
	rwlock_t lock;
	struct pid___231 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___401 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___402 f_path;
	struct inode___401 *f_inode;
	const struct file_operations___401 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___231 f_owner;
	const struct cred___369 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___401 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___389;

struct vm_operations_struct___389 {
	void (*open)(struct vm_area_struct___402 *);
	void (*close)(struct vm_area_struct___402 *);
	int (*split)(struct vm_area_struct___402 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___402 *);
	vm_fault_t (*fault)(struct vm_fault___389 *);
	vm_fault_t (*huge_fault)(struct vm_fault___389 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___389 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___402 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___389 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___389 *);
	int (*access)(struct vm_area_struct___402 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___402 *);
	int (*set_policy)(struct vm_area_struct___402 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___402 *, long unsigned int);
	struct page___402 * (*find_special_page)(struct vm_area_struct___402 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___402 {
	struct task_struct___403 *task;
	struct core_thread___402 *next;
};

struct core_state___402 {
	atomic_t nr_threads;
	struct core_thread___402 dumper;
	struct completion startup;
};

struct key___369;

struct ucounts___266;

struct user_namespace___266 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___266 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___9 ns;
	long unsigned int flags;
	struct key___369 *persistent_keyring_register;
	struct rw_semaphore___403 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___266 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___389 {
	struct vm_area_struct___402 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___402 *cow_page;
	struct mem_cgroup___138 *memcg;
	struct page___402 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___402 prealloc_pte;
};

struct shrink_control___138 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___138 *memcg;
};

struct shrinker___138 {
	long unsigned int (*count_objects)(struct shrinker___138 *, struct shrink_control___138 *);
	long unsigned int (*scan_objects)(struct shrinker___138 *, struct shrink_control___138 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct upid___231 {
	int nr;
	struct pid_namespace___231 *ns;
};

struct pid_namespace___231 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___403 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___231 *parent;
	struct vfsmount___72 *proc_mnt;
	struct dentry___401 *proc_self;
	struct dentry___401 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___266 *user_ns;
	struct ucounts___266 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___9 ns;
};

struct pid___231 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___231 numbers[1];
};

struct user_struct___369 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___369 *uid_keyring;
	struct key___369 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___369 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___369 *session_keyring;
	struct key___369 *process_keyring;
	struct key___369 *thread_keyring;
	struct key___369 *request_key_auth;
	void *security;
	struct user_struct___369 *user;
	struct user_namespace___266 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___58;

struct cgroup_namespace___250;

struct nsproxy___296 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___231 *pid_ns_for_children;
	struct net___58 *net_ns;
	struct cgroup_namespace___250 *cgroup_ns;
};

struct signal_struct___276 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___403 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___403 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___231 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___231 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___402 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___231 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___195;

struct bio_list___195 {
	struct bio___195 *head;
	struct bio___195 *tail;
};

struct bdi_writeback_congested___195;

struct bdi_writeback___195 {
	struct backing_dev_info___195 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___195 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___250 *memcg_css;
	struct cgroup_subsys_state___250 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___195 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___195 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___369 *dev;
	struct device___369 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___401 *debug_dir;
	struct dentry___401 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___250 {
	struct cgroup_subsys_state___250 *subsys[13];
	refcount_t refcount;
	struct css_set___250 *dom_cset;
	struct cgroup___250 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___250 *mg_src_cgrp;
	struct cgroup___250 *mg_dst_cgrp;
	struct css_set___250 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___154 {
	struct pmu___154 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___403 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___154 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___82;

struct pipe_inode_info___82 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___402 *tmp_page;
	struct fasync_struct___401 *fasync_readers;
	struct fasync_struct___401 *fasync_writers;
	struct pipe_buffer___82 *bufs;
	struct user_struct___369 *user;
};

struct vm_struct___305 {
	struct vm_struct___305 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___402 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___288 {
	struct task_struct___403 task;
	long unsigned int stack[8192];
};

struct kset___388;

struct kobj_type___388;

struct kobject___389 {
	const char *name;
	struct list_head entry;
	struct kobject___389 *parent;
	struct kset___388 *kset;
	struct kobj_type___388 *ktype;
	struct kernfs_node___396 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___369 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___369 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___369;

struct bus_type___369;

struct device_driver___369;

struct dev_pm_domain___369;

struct dma_map_ops___141;

struct fwnode_handle___289;

struct class___369;

struct attribute_group___366;

struct device___369 {
	struct device___369 *parent;
	struct device_private *p;
	struct kobject___389 kobj;
	const char *init_name;
	const struct device_type___369 *type;
	struct mutex mutex;
	struct bus_type___369 *bus;
	struct device_driver___369 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___369 power;
	struct dev_pm_domain___369 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___141 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___289 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___369 *class;
	const struct attribute_group___366 **groups;
	void (*release)(struct device___369 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___401;

struct super_block___401;

struct dentry___401 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___401 *d_parent;
	struct qstr d_name;
	struct inode___401 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___401 *d_op;
	struct super_block___401 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___401;

struct block_device___401;

struct inode___401 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___401 *i_op;
	struct super_block___401 *i_sb;
	struct address_space___401 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___403 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___195 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___401 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___401 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___82 *i_pipe;
		struct block_device___401 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___401 {
	int (*d_revalidate)(struct dentry___401 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___401 *, unsigned int);
	int (*d_hash)(const struct dentry___401 *, struct qstr *);
	int (*d_compare)(const struct dentry___401 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___401 *);
	int (*d_init)(struct dentry___401 *);
	void (*d_release)(struct dentry___401 *);
	void (*d_prune)(struct dentry___401 *);
	void (*d_iput)(struct dentry___401 *, struct inode___401 *);
	char * (*d_dname)(struct dentry___401 *, char *, int);
	struct vfsmount___72 * (*d_automount)(struct path___402 *);
	int (*d_manage)(const struct path___402 *, bool);
	struct dentry___401 * (*d_real)(struct dentry___401 *, const struct inode___401 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___401;

struct mem_dqinfo___401 {
	struct quota_format_type___401 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___401;

struct quota_info___401 {
	unsigned int flags;
	struct rw_semaphore___403 dqio_sem;
	struct inode___401 *files[3];
	struct mem_dqinfo___401 info[3];
	const struct quota_format_ops___401 *ops[3];
};

struct rcuwait___401 {
	struct task_struct___403 *task;
};

struct percpu_rw_semaphore___401 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___403 rw_sem;
	struct rcuwait___401 writer;
	int readers_block;
};

struct sb_writers___401 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___401 rw_sem[3];
};

struct file_system_type___401;

struct super_operations___401;

struct dquot_operations___401;

struct quotactl_ops___401;

struct xattr_handler___27;

struct super_block___401 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___401 *s_type;
	const struct super_operations___401 *s_op;
	const struct dquot_operations___401 *dq_op;
	const struct quotactl_ops___401 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___401 *s_root;
	struct rw_semaphore___403 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___27 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___401 *s_bdev;
	struct backing_dev_info___195 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___401 s_dquot;
	struct sb_writers___401 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___401 *s_d_op;
	int cleancache_poolid;
	struct shrinker___138 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___266 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___72 {
	struct dentry___401 *mnt_root;
	struct super_block___401 *mnt_sb;
	int mnt_flags;
};

struct kiocb___401 {
	struct file___401 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___401 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___401 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___401 *ia_file;
};

struct dquot___401 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___401 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___401 {
	int qf_fmt_id;
	const struct quota_format_ops___401 *qf_ops;
	struct module___331 *qf_owner;
	struct quota_format_type___401 *qf_next;
};

struct quota_format_ops___401 {
	int (*check_quota_file)(struct super_block___401 *, int);
	int (*read_file_info)(struct super_block___401 *, int);
	int (*write_file_info)(struct super_block___401 *, int);
	int (*free_file_info)(struct super_block___401 *, int);
	int (*read_dqblk)(struct dquot___401 *);
	int (*commit_dqblk)(struct dquot___401 *);
	int (*release_dqblk)(struct dquot___401 *);
	int (*get_next_id)(struct super_block___401 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___401 {
	int (*write_dquot)(struct dquot___401 *);
	struct dquot___401 * (*alloc_dquot)(struct super_block___401 *, int);
	void (*destroy_dquot)(struct dquot___401 *);
	int (*acquire_dquot)(struct dquot___401 *);
	int (*release_dquot)(struct dquot___401 *);
	int (*mark_dirty)(struct dquot___401 *);
	int (*write_info)(struct super_block___401 *, int);
	qsize_t * (*get_reserved_space)(struct inode___401 *);
	int (*get_projid)(struct inode___401 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___401 *, qsize_t *);
	int (*get_next_id)(struct super_block___401 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___401 {
	int (*quota_on)(struct super_block___401 *, int, int, const struct path___402 *);
	int (*quota_off)(struct super_block___401 *, int);
	int (*quota_enable)(struct super_block___401 *, unsigned int);
	int (*quota_disable)(struct super_block___401 *, unsigned int);
	int (*quota_sync)(struct super_block___401 *, int);
	int (*set_info)(struct super_block___401 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___401 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___401 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___401 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___401 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___401 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___329 {
	struct kobject___389 kobj;
	struct module___331 *mod;
	struct kobject___389 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___329 {
	struct module___331 *mod;
	struct latch_tree_node node;
};

struct module_layout___329 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___329 mtn;
};

struct module_attribute___329;

struct kernel_param___329;

struct module___331 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___329 mkobj;
	struct module_attribute___329 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___389 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___329 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___329 core_layout;
	struct module_layout___329 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___145 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide38;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide39;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___158;

struct address_space_operations___401 {
	int (*writepage)(struct page___402 *, struct writeback_control___158 *);
	int (*readpage)(struct file___401 *, struct page___402 *);
	int (*writepages)(struct address_space___401 *, struct writeback_control___158 *);
	int (*set_page_dirty)(struct page___402 *);
	int (*readpages)(struct file___401 *, struct address_space___401 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___401 *, struct address_space___401 *, loff_t, unsigned int, unsigned int, struct page___402 **, void **);
	int (*write_end)(struct file___401 *, struct address_space___401 *, loff_t, unsigned int, unsigned int, struct page___402 *, void *);
	sector_t (*bmap)(struct address_space___401 *, sector_t);
	void (*invalidatepage)(struct page___402 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___402 *, gfp_t);
	void (*freepage)(struct page___402 *);
	ssize_t (*direct_IO)(struct kiocb___401 *, struct iov_iter___168 *);
	int (*migratepage)(struct address_space___401 *, struct page___402 *, struct page___402 *, enum migrate_mode);
	bool (*isolate_page)(struct page___402 *, isolate_mode_t);
	void (*putback_page)(struct page___402 *);
	int (*launder_page)(struct page___402 *);
	int (*is_partially_uptodate)(struct page___402 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___402 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___401 *, struct page___402 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___401 *, sector_t *);
	void (*swap_deactivate)(struct file___401 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___158 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___195 *wb;
	struct inode___401 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___197;

struct iov_iter___168 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___197 *bvec;
		struct pipe_inode_info___82 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___401 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___401 *bd_inode;
	struct super_block___401 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___401 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___195 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___401 {
	struct dentry___401 * (*lookup)(struct inode___401 *, struct dentry___401 *, unsigned int);
	const char * (*get_link)(struct dentry___401 *, struct inode___401 *, struct delayed_call *);
	int (*permission)(struct inode___401 *, int);
	struct posix_acl * (*get_acl)(struct inode___401 *, int);
	int (*readlink)(struct dentry___401 *, char *, int);
	int (*create)(struct inode___401 *, struct dentry___401 *, umode_t, bool);
	int (*link)(struct dentry___401 *, struct inode___401 *, struct dentry___401 *);
	int (*unlink)(struct inode___401 *, struct dentry___401 *);
	int (*symlink)(struct inode___401 *, struct dentry___401 *, const char *);
	int (*mkdir)(struct inode___401 *, struct dentry___401 *, umode_t);
	int (*rmdir)(struct inode___401 *, struct dentry___401 *);
	int (*mknod)(struct inode___401 *, struct dentry___401 *, umode_t, dev_t);
	int (*rename)(struct inode___401 *, struct dentry___401 *, struct inode___401 *, struct dentry___401 *, unsigned int);
	int (*setattr)(struct dentry___401 *, struct iattr___401 *);
	int (*getattr)(const struct path___402 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___401 *, char *, size_t);
	int (*fiemap)(struct inode___401 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___401 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___401 *, struct dentry___401 *, struct file___401 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___401 *, struct dentry___401 *, umode_t);
	int (*set_acl)(struct inode___401 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___401 {
	void (*fl_copy_lock)(struct file_lock___401 *, struct file_lock___401 *);
	void (*fl_release_private)(struct file_lock___401 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___401;

struct file_lock___401 {
	struct file_lock___401 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___401 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___401 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___401 *fl_ops;
	const struct lock_manager_operations___401 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___401 {
	int (*lm_compare_owner)(struct file_lock___401 *, struct file_lock___401 *);
	long unsigned int (*lm_owner_key)(struct file_lock___401 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___401 *);
	int (*lm_grant)(struct file_lock___401 *, int);
	bool (*lm_break)(struct file_lock___401 *);
	int (*lm_change)(struct file_lock___401 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___401 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___401 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___401 *fa_next;
	struct file___401 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___401 {
	const char *name;
	int fs_flags;
	struct dentry___401 * (*mount)(struct file_system_type___401 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___401 *);
	struct module___331 *owner;
	struct file_system_type___401 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___401 {
	struct inode___401 * (*alloc_inode)(struct super_block___401 *);
	void (*destroy_inode)(struct inode___401 *);
	void (*dirty_inode)(struct inode___401 *, int);
	int (*write_inode)(struct inode___401 *, struct writeback_control___158 *);
	int (*drop_inode)(struct inode___401 *);
	void (*evict_inode)(struct inode___401 *);
	void (*put_super)(struct super_block___401 *);
	int (*sync_fs)(struct super_block___401 *, int);
	int (*freeze_super)(struct super_block___401 *);
	int (*freeze_fs)(struct super_block___401 *);
	int (*thaw_super)(struct super_block___401 *);
	int (*unfreeze_fs)(struct super_block___401 *);
	int (*statfs)(struct dentry___401 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___401 *, int *, char *);
	void (*umount_begin)(struct super_block___401 *);
	int (*show_options)(struct seq_file___340 *, struct dentry___401 *);
	int (*show_devname)(struct seq_file___340 *, struct dentry___401 *);
	int (*show_path)(struct seq_file___340 *, struct dentry___401 *);
	int (*show_stats)(struct seq_file___340 *, struct dentry___401 *);
	ssize_t (*quota_read)(struct super_block___401 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___401 *, int, const char *, size_t, loff_t);
	struct dquot___401 ** (*get_dquots)(struct inode___401 *);
	int (*bdev_try_to_free_page)(struct super_block___401 *, struct page___402 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___401 *, struct shrink_control___138 *);
	long int (*free_cached_objects)(struct super_block___401 *, struct shrink_control___138 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct xattr_handler___27 {
	const char *name;
	const char *prefix;
	int flags;
	bool (*list)(struct dentry___401 *);
	int (*get)(const struct xattr_handler___27 *, struct dentry___401 *, struct inode___401 *, const char *, void *, size_t);
	int (*set)(const struct xattr_handler___27 *, struct dentry___401 *, struct inode___401 *, const char *, const void *, size_t, int);
};

typedef void (*poll_queue_proc___254)(struct file___401 *, wait_queue_head_t *, struct poll_table_struct___244 *);

struct poll_table_struct___244 {
	poll_queue_proc___254 _qproc;
	__poll_t _key;
};

struct seq_operations___340;

struct seq_file___340 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___340 *op;
	int poll_event;
	const struct file___401 *file;
	void *private;
};

typedef void bio_end_io_t___195(struct bio___195 *);

struct bio_vec___197 {
	struct page___402 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___195;

struct bio_set___195;

struct bio___195 {
	struct bio___195 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___195 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___195 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___197 *bi_io_vec;
	struct bio_set___195 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___197 bi_inline_vecs[0];
};

struct kobj_attribute___379 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___389 *, struct kobj_attribute___379 *, char *);
	ssize_t (*store)(struct kobject___389 *, struct kobj_attribute___379 *, const char *, size_t);
};

typedef void compound_page_dtor___389(struct page___402 *);

struct msghdr___33 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___168 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___401 *msg_iocb;
};

struct user_msghdr {
	void *msg_name;
	int msg_namelen;
	struct iovec *msg_iov;
	__kernel_size_t msg_iovlen;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
};

struct mmsghdr {
	struct user_msghdr msg_hdr;
	unsigned int msg_len;
};

struct fd___29 {
	struct file___401 *file;
	unsigned int flags;
};

enum sock_shutdown_cmd {
	SHUT_RD = 0,
	SHUT_WR = 1,
	SHUT_RDWR = 2,
};

struct socket_wq___31 {
	wait_queue_head_t wait;
	struct fasync_struct___401 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct sock___31;

struct proto_ops___31;

struct socket___32 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___31 *wq;
	struct file___401 *file;
	struct sock___31 *sk;
	const struct proto_ops___31 *ops;
};

typedef struct {
	struct net___58 *net;
} possible_net_t___48;

struct proto___30;

struct sock_common___30 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___30 *skc_prot;
	possible_net_t___48 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___31 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___48;

struct sk_buff_head___46 {
	struct sk_buff___48 *next;
	struct sk_buff___48 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___30;

struct dst_entry___30;

struct net_device___48;

struct sock___31 {
	struct sock_common___30 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___46 sk_error_queue;
	struct sk_buff_head___46 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___48 *head;
		struct sk_buff___48 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___30 *sk_filter;
	union {
		struct socket_wq___31 *sk_wq;
		struct socket_wq___31 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___30 *sk_rx_dst;
	struct dst_entry___30 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___48 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___46 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___402 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___30 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___231 *sk_peer_pid;
	const struct cred___369 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___32 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___138 *sk_memcg;
	void (*sk_state_change)(struct sock___31 *);
	void (*sk_data_ready)(struct sock___31 *);
	void (*sk_write_space)(struct sock___31 *);
	void (*sk_error_report)(struct sock___31 *);
	int (*sk_backlog_rcv)(struct sock___31 *, struct sk_buff___48 *);
	struct sk_buff___48 * (*sk_validate_xmit_skb)(struct sock___31 *, struct net_device___48 *, struct sk_buff___48 *);
	void (*sk_destruct)(struct sock___31 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

typedef int (*sk_read_actor_t___30)(read_descriptor_t *, struct sk_buff___48 *, unsigned int, size_t);

struct proto_ops___31 {
	int family;
	struct module___331 *owner;
	int (*release)(struct socket___32 *);
	int (*bind)(struct socket___32 *, struct sockaddr *, int);
	int (*connect)(struct socket___32 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___32 *, struct socket___32 *);
	int (*accept)(struct socket___32 *, struct socket___32 *, int, bool);
	int (*getname)(struct socket___32 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___401 *, struct socket___32 *, struct poll_table_struct___244 *);
	int (*ioctl)(struct socket___32 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___32 *, int);
	int (*shutdown)(struct socket___32 *, int);
	int (*setsockopt)(struct socket___32 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___32 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___32 *, struct msghdr___33 *, size_t);
	int (*recvmsg)(struct socket___32 *, struct msghdr___33 *, size_t, int);
	int (*mmap)(struct file___401 *, struct socket___32 *, struct vm_area_struct___402 *);
	ssize_t (*sendpage)(struct socket___32 *, struct page___402 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___32 *, loff_t *, struct pipe_inode_info___82 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___31 *, int);
	int (*peek_len)(struct socket___32 *);
	int (*read_sock)(struct sock___31 *, read_descriptor_t *, sk_read_actor_t___30);
	int (*sendpage_locked)(struct sock___31 *, struct page___402 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___31 *, struct msghdr___33 *, size_t);
	int (*set_rcvlowat)(struct sock___31 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct nf_bridge_info___46;

struct sk_buff___48 {
	union {
		struct {
			struct sk_buff___48 *next;
			struct sk_buff___48 *prev;
			union {
				struct net_device___48 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___31 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___48 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___46 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct net_proto_family___2 {
	int family;
	int (*create)(struct net___58 *, struct socket___32 *, int, int);
	struct module___331 *owner;
};

struct inet_frags___46;

struct netns_frags___46 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___46 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ip_ra_chain___13;

struct fib_rules_ops___30;

struct fib_notifier_ops___30;

struct netns_ipv4___46 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___13 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___30 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___31 *fibnl;
	struct sock___31 **icmp_sk;
	struct sock___31 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___31 **tcp_sk;
	struct netns_frags___46 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___30 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___30 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___30 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___30;

struct dst_ops___57 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___57 *);
	struct dst_entry___30 * (*check)(struct dst_entry___30 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___30 *);
	unsigned int (*mtu)(const struct dst_entry___30 *);
	u32 * (*cow_metrics)(struct dst_entry___30 *, long unsigned int);
	void (*destroy)(struct dst_entry___30 *);
	void (*ifdown)(struct dst_entry___30 *, struct net_device___48 *, int);
	struct dst_entry___30 * (*negative_advice)(struct dst_entry___30 *);
	void (*link_failure)(struct sk_buff___48 *);
	void (*update_pmtu)(struct dst_entry___30 *, struct sock___31 *, struct sk_buff___48 *, u32);
	void (*redirect)(struct dst_entry___30 *, struct sock___31 *, struct sk_buff___48 *);
	int (*local_out)(struct net___58 *, struct sock___31 *, struct sk_buff___48 *);
	struct neighbour___30 * (*neigh_lookup)(const struct dst_entry___30 *, struct sk_buff___48 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___30 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___57 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___46 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___57 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___30 *fib6_rules_ops;
	struct sock___31 **icmp_sk;
	struct sock___31 *ndisc_sk;
	struct sock___31 *tcp_sk;
	struct sock___31 *igmp_sk;
	struct sock___31 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___30 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___30 *notifier_ops;
	struct fib_notifier_ops___30 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___31 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___31 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct nf_hook_entries___2;

struct netns_nf___3 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_queue_handler *queue_handler;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header *nf_log_dir_header;
	struct nf_hook_entries___2 *hooks_ipv4[5];
	struct nf_hook_entries___2 *hooks_ipv6[5];
	struct nf_hook_entries___2 *hooks_arp[3];
	struct nf_hook_entries___2 *hooks_bridge[5];
	bool defrag_ipv4;
	bool defrag_ipv6;
};

struct netns_nf_frag___46 {
	struct netns_frags___46 frags;
};

struct netns_xfrm___57 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___31 *nlsk;
	struct sock___31 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___57 xfrm4_dst_ops;
	struct dst_ops___57 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct net___58 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___266 *user_ns;
	struct ucounts___266 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___9 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___31 *rtnl;
	struct sock___31 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___48 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___46 ipv4;
	struct netns_ipv6___57 ipv6;
	struct netns_sctp___31 sctp;
	struct netns_nf___3 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___46 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___31 *nfnl;
	struct sock___31 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___57 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___31 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___40 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ifconf {
	int ifc_len;
	union {
		char *ifcu_buf;
		struct ifreq *ifcu_req;
	} ifc_ifcu;
};

struct kernfs_root___395;

struct kernfs_elem_dir___395 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___395 *root;
};

struct kernfs_syscall_ops___395;

struct kernfs_root___395 {
	struct kernfs_node___396 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___395 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___395 {
	struct kernfs_node___396 *target_kn;
};

struct kernfs_ops___395;

struct kernfs_elem_attr___395 {
	const struct kernfs_ops___395 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___396 *notify_next;
};

struct kernfs_node___396 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___396 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___395 dir;
		struct kernfs_elem_symlink___395 symlink;
		struct kernfs_elem_attr___395 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___395;

struct kernfs_ops___395 {
	int (*open)(struct kernfs_open_file___395 *);
	void (*release)(struct kernfs_open_file___395 *);
	int (*seq_show)(struct seq_file___340 *, void *);
	void * (*seq_start)(struct seq_file___340 *, loff_t *);
	void * (*seq_next)(struct seq_file___340 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___340 *, void *);
	ssize_t (*read)(struct kernfs_open_file___395 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___395 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___395 *, struct vm_area_struct___402 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___395 *, struct poll_table_struct___244 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___395 {
	int (*remount_fs)(struct kernfs_root___395 *, int *, char *);
	int (*show_options)(struct seq_file___340 *, struct kernfs_root___395 *);
	int (*mkdir)(struct kernfs_node___396 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___396 *);
	int (*rename)(struct kernfs_node___396 *, struct kernfs_node___396 *, const char *);
	int (*show_path)(struct seq_file___340 *, struct kernfs_node___396 *, struct kernfs_root___395 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___395 {
	struct kernfs_node___396 *kn;
	struct file___401 *file;
	struct seq_file___340 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___389 *vm_ops;
};

struct kobj_ns_type_operations___30 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___31 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___365;

struct attribute_group___366 {
	const char *name;
	umode_t (*is_visible)(struct kobject___389 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___389 *, struct bin_attribute___365 *, int);
	struct attribute **attrs;
	struct bin_attribute___365 **bin_attrs;
};

struct bin_attribute___365 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___401 *, struct kobject___389 *, struct bin_attribute___365 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___401 *, struct kobject___389 *, struct bin_attribute___365 *, char *, loff_t, size_t);
	int (*mmap)(struct file___401 *, struct kobject___389 *, struct bin_attribute___365 *, struct vm_area_struct___402 *);
};

struct sysfs_ops___388 {
	ssize_t (*show)(struct kobject___389 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___389 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___388;

struct kset___388 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___389 kobj;
	const struct kset_uevent_ops___388 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___388 {
	void (*release)(struct kobject___389 *);
	const struct sysfs_ops___388 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___30 * (*child_ns_type)(struct kobject___389 *);
	const void * (*namespace)(struct kobject___389 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___388 {
	int (* const filter)(struct kset___388 *, struct kobject___389 *);
	const char * (* const name)(struct kset___388 *, struct kobject___389 *);
	int (* const uevent)(struct kset___388 *, struct kobject___389 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___369 {
	int (*prepare)(struct device___369 *);
	void (*complete)(struct device___369 *);
	int (*suspend)(struct device___369 *);
	int (*resume)(struct device___369 *);
	int (*freeze)(struct device___369 *);
	int (*thaw)(struct device___369 *);
	int (*poweroff)(struct device___369 *);
	int (*restore)(struct device___369 *);
	int (*suspend_late)(struct device___369 *);
	int (*resume_early)(struct device___369 *);
	int (*freeze_late)(struct device___369 *);
	int (*thaw_early)(struct device___369 *);
	int (*poweroff_late)(struct device___369 *);
	int (*restore_early)(struct device___369 *);
	int (*suspend_noirq)(struct device___369 *);
	int (*resume_noirq)(struct device___369 *);
	int (*freeze_noirq)(struct device___369 *);
	int (*thaw_noirq)(struct device___369 *);
	int (*poweroff_noirq)(struct device___369 *);
	int (*restore_noirq)(struct device___369 *);
	int (*runtime_suspend)(struct device___369 *);
	int (*runtime_resume)(struct device___369 *);
	int (*runtime_idle)(struct device___369 *);
};

struct dev_pm_domain___369 {
	struct dev_pm_ops___369 ops;
	void (*detach)(struct device___369 *, bool);
	int (*activate)(struct device___369 *);
	void (*sync)(struct device___369 *);
	void (*dismiss)(struct device___369 *);
};

struct bus_type___369 {
	const char *name;
	const char *dev_name;
	struct device___369 *dev_root;
	const struct attribute_group___366 **bus_groups;
	const struct attribute_group___366 **dev_groups;
	const struct attribute_group___366 **drv_groups;
	int (*match)(struct device___369 *, struct device_driver___369 *);
	int (*uevent)(struct device___369 *, struct kobj_uevent_env *);
	int (*probe)(struct device___369 *);
	int (*remove)(struct device___369 *);
	void (*shutdown)(struct device___369 *);
	int (*online)(struct device___369 *);
	int (*offline)(struct device___369 *);
	int (*suspend)(struct device___369 *, pm_message_t);
	int (*resume)(struct device___369 *);
	int (*num_vf)(struct device___369 *);
	int (*dma_configure)(struct device___369 *);
	const struct dev_pm_ops___369 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___369 {
	const char *name;
	struct bus_type___369 *bus;
	struct module___331 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___369 *);
	int (*remove)(struct device___369 *);
	void (*shutdown)(struct device___369 *);
	int (*suspend)(struct device___369 *, pm_message_t);
	int (*resume)(struct device___369 *);
	const struct attribute_group___366 **groups;
	const struct dev_pm_ops___369 *pm;
	void (*coredump)(struct device___369 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___369 {
	const char *name;
	const struct attribute_group___366 **groups;
	int (*uevent)(struct device___369 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___369 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___369 *);
	const struct dev_pm_ops___369 *pm;
};

struct class___369 {
	const char *name;
	struct module___331 *owner;
	const struct attribute_group___366 **class_groups;
	const struct attribute_group___366 **dev_groups;
	struct kobject___389 *dev_kobj;
	int (*dev_uevent)(struct device___369 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___369 *, umode_t *);
	void (*class_release)(struct class___369 *);
	void (*dev_release)(struct device___369 *);
	int (*shutdown_pre)(struct device___369 *);
	const struct kobj_ns_type_operations___30 *ns_type;
	const void * (*namespace)(struct device___369 *);
	const struct dev_pm_ops___369 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___141 {
	void * (*alloc)(struct device___369 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___369 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___369 *, struct vm_area_struct___402 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___369 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___369 *, struct page___402 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___369 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___369 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___369 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___369 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___369 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___369 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___369 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___369 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___369 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___369 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___369 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___369 *, u64);
	u64 (*get_required_mask)(struct device___369 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___289;

struct fwnode_handle___289 {
	struct fwnode_handle___289 *secondary;
	const struct fwnode_operations___289 *ops;
};

struct fwnode_reference_args___289;

struct fwnode_endpoint___289;

struct fwnode_operations___289 {
	struct fwnode_handle___289 * (*get)(struct fwnode_handle___289 *);
	void (*put)(struct fwnode_handle___289 *);
	bool (*device_is_available)(const struct fwnode_handle___289 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___289 *, const struct device___369 *);
	bool (*property_present)(const struct fwnode_handle___289 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___289 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___289 *, const char *, const char **, size_t);
	struct fwnode_handle___289 * (*get_parent)(const struct fwnode_handle___289 *);
	struct fwnode_handle___289 * (*get_next_child_node)(const struct fwnode_handle___289 *, struct fwnode_handle___289 *);
	struct fwnode_handle___289 * (*get_named_child_node)(const struct fwnode_handle___289 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___289 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___289 *);
	struct fwnode_handle___289 * (*graph_get_next_endpoint)(const struct fwnode_handle___289 *, struct fwnode_handle___289 *);
	struct fwnode_handle___289 * (*graph_get_remote_endpoint)(const struct fwnode_handle___289 *);
	struct fwnode_handle___289 * (*graph_get_port_parent)(struct fwnode_handle___289 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___289 *, struct fwnode_endpoint___289 *);
};

struct fwnode_endpoint___289 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___289 *local_fwnode;
};

struct fwnode_reference_args___289 {
	struct fwnode_handle___289 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___82;

struct pipe_buffer___82 {
	struct page___402 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___82 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___82 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___82 *, struct pipe_buffer___82 *);
	void (*release)(struct pipe_inode_info___82 *, struct pipe_buffer___82 *);
	int (*steal)(struct pipe_inode_info___82 *, struct pipe_buffer___82 *);
	union {
		bool (*get)(struct pipe_inode_info___82 *, struct pipe_buffer___82 *);
		struct {
			void (*get)(struct pipe_inode_info___82 *, struct pipe_buffer___82 *);
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
};

struct nf_bridge_info___46 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___46 = 0,
		BRNF_PROTO_8021Q___46 = 1,
		BRNF_PROTO_PPPOE___46 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___48 *physindev;
	struct net_device___48 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___46(struct sk_buff___48 **);

struct net_device_ops___46;

struct ethtool_ops___46;

struct l3mdev_ops___30;

struct ndisc_ops___16;

struct xfrmdev_ops___46;

struct tlsdev_ops___46;

struct header_ops___46;

struct inet6_dev___16;

struct netdev_rx_queue___46;

struct mini_Qdisc___40;

struct netdev_queue___46;

struct Qdisc___40;

struct rtnl_link_ops___40;

struct dcbnl_rtnl_ops___46;

struct net_device___48 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___46 *netdev_ops;
	const struct ethtool_ops___46 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___30 *l3mdev_ops;
	const struct ndisc_ops___16 *ndisc_ops;
	const struct xfrmdev_ops___46 *xfrmdev_ops;
	const struct tlsdev_ops___46 *tlsdev_ops;
	const struct header_ops___46 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___388 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___16 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___46 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___40 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___46 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___40 *miniq_ingress;
	struct netdev_queue___46 *ingress_queue;
	struct nf_hook_entries___2 *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___46 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___40 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___40 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___46 = 0,
		NETREG_REGISTERED___46 = 1,
		NETREG_UNREGISTERING___46 = 2,
		NETREG_UNREGISTERED___46 = 3,
		NETREG_RELEASED___46 = 4,
		NETREG_DUMMY___46 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___46 = 0,
		RTNL_LINK_INITIALIZING___46 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___48 *);
	struct netpoll_info *npinfo;
	possible_net_t___48 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___369 dev;
	const struct attribute_group___366 *sysfs_groups[4];
	const struct attribute_group___366 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___40 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___46 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct skb_frag_struct___3 {
	struct {
		struct page___402 *p;
	} page;
	__u32 page_offset;
	__u32 size;
};

typedef struct skb_frag_struct___3 skb_frag_t___3;

struct skb_shared_info___3 {
	__u8 __unused;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___48 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___3 frags[16];
};

struct ethtool_ops___46 {
	int (*get_settings)(struct net_device___48 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___48 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___48 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___48 *);
	void (*get_regs)(struct net_device___48 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___48 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___48 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___48 *);
	void (*set_msglevel)(struct net_device___48 *, u32);
	int (*nway_reset)(struct net_device___48 *);
	u32 (*get_link)(struct net_device___48 *);
	int (*get_eeprom_len)(struct net_device___48 *);
	int (*get_eeprom)(struct net_device___48 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___48 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___48 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___48 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___48 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___48 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___48 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___48 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___48 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___48 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___48 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___48 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___48 *);
	void (*complete)(struct net_device___48 *);
	u32 (*get_priv_flags)(struct net_device___48 *);
	int (*set_priv_flags)(struct net_device___48 *, u32);
	int (*get_sset_count)(struct net_device___48 *, int);
	int (*get_rxnfc)(struct net_device___48 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___48 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___48 *, struct ethtool_flash *);
	int (*reset)(struct net_device___48 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___48 *);
	u32 (*get_rxfh_indir_size)(struct net_device___48 *);
	int (*get_rxfh)(struct net_device___48 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___48 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___48 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___48 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___48 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___48 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___48 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___48 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___48 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___48 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___48 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___48 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___48 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___48 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___48 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___48 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___48 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___48 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___48 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___48 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___48 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___48 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	int (*get_fecparam)(struct net_device___48 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___48 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___48 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___48 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___48 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___46;

struct inet_frags___46 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___46 *, const void *);
	void (*destructor)(struct inet_frag_queue___46 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___46 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___48 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___48 *fragments_tail;
	struct sk_buff___48 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___46 *net;
	struct callback_head rcu;
};

struct ip_ra_chain___13 {
	struct ip_ra_chain___13 *next;
	struct sock___31 *sk;
	union {
		void (*destructor)(struct sock___31 *);
		struct sock___31 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___30;

struct fib_lookup_arg___30;

struct fib_rules_ops___30 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___30 *, struct flowi *, int, struct fib_lookup_arg___30 *);
	bool (*suppress)(struct fib_rule___30 *, struct fib_lookup_arg___30 *);
	int (*match)(struct fib_rule___30 *, struct flowi *, int);
	int (*configure)(struct fib_rule___30 *, struct sk_buff___48 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___30 *);
	int (*compare)(struct fib_rule___30 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___30 *, struct sk_buff___48 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___30 *);
	void (*flush_cache)(struct fib_rules_ops___30 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___331 *owner;
	struct net___58 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___30 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___58 *);
	int (*fib_dump)(struct net___58 *, struct notifier_block *);
	struct module___331 *owner;
	struct callback_head rcu;
};

struct dst_entry___30 {
	struct net_device___48 *dev;
	struct dst_ops___57 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___48 *);
	int (*output)(struct net___58 *, struct sock___31 *, struct sk_buff___48 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___30;

struct neigh_parms___30;

struct neigh_ops___30;

struct neighbour___30 {
	struct neighbour___30 *next;
	struct neigh_table___30 *tbl;
	struct neigh_parms___30 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___46 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___30 *, struct sk_buff___48 *);
	const struct neigh_ops___30 *ops;
	struct callback_head rcu;
	struct net_device___48 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct nf_hook_state___2;

typedef unsigned int nf_hookfn___2(void *, struct sk_buff___48 *, const struct nf_hook_state___2 *);

struct nf_hook_entry___2 {
	nf_hookfn___2 *hook;
	void *priv;
};

struct nf_hook_entries___2 {
	u16 num_hook_entries;
	struct nf_hook_entry___2 hooks[0];
};

struct ucounts___266 {
	struct hlist_node node;
	struct user_namespace___266 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_prog_aux___43;

struct bpf_prog___40 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___43 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

typedef int (*key_restrict_link_func_t___370)(struct key___369 *, const struct key_type *, const union key_payload *, struct key___369 *);

struct key_restriction___369;

struct key___369 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___403 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___369 *restrict_link;
};

struct key_restriction___369 {
	key_restrict_link_func_t___370 check;
	struct key___369 *key;
	struct key_type *keytype;
};

struct seq_operations___340 {
	void * (*start)(struct seq_file___340 *, loff_t *);
	void (*stop)(struct seq_file___340 *, void *);
	void * (*next)(struct seq_file___340 *, void *, loff_t *);
	int (*show)(struct seq_file___340 *, void *);
};

struct pernet_operations___47 {
	struct list_head list;
	int (*init)(struct net___58 *);
	void (*exit)(struct net___58 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___46 {
	int (*ieee_getets)(struct net_device___48 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___48 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___48 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___48 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___48 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___48 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___48 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___48 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___48 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___48 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___48 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___48 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___48 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___48 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___48 *);
	u8 (*setstate)(struct net_device___48 *, u8);
	void (*getpermhwaddr)(struct net_device___48 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___48 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___48 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___48 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___48 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___48 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___48 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___48 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___48 *, int, u8 *);
	void (*setpfccfg)(struct net_device___48 *, int, u8);
	void (*getpfccfg)(struct net_device___48 *, int, u8 *);
	u8 (*setall)(struct net_device___48 *);
	u8 (*getcap)(struct net_device___48 *, int, u8 *);
	int (*getnumtcs)(struct net_device___48 *, int, u8 *);
	int (*setnumtcs)(struct net_device___48 *, int, u8);
	u8 (*getpfcstate)(struct net_device___48 *);
	void (*setpfcstate)(struct net_device___48 *, u8);
	void (*getbcncfg)(struct net_device___48 *, int, u32 *);
	void (*setbcncfg)(struct net_device___48 *, int, u32);
	void (*getbcnrp)(struct net_device___48 *, int, u8 *);
	void (*setbcnrp)(struct net_device___48 *, int, u8);
	int (*setapp)(struct net_device___48 *, u8, u16, u8);
	int (*getapp)(struct net_device___48 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___48 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___48 *, int, u8);
	u8 (*getdcbx)(struct net_device___48 *);
	u8 (*setdcbx)(struct net_device___48 *, u8);
	int (*peer_getappinfo)(struct net_device___48 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___48 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___48 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___48 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___48 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___48 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___250 {
	refcount_t count;
	struct ns_common___9 ns;
	struct user_namespace___266 *user_ns;
	struct ucounts___266 *ucounts;
	struct css_set___250 *root_cset;
};

struct bpf_map___251;

struct bpf_map_ops___250 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___251 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___251 *, struct file___401 *);
	void (*map_free)(struct bpf_map___251 *);
	int (*map_get_next_key)(struct bpf_map___251 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___251 *);
	void * (*map_lookup_elem)(struct bpf_map___251 *, void *);
	int (*map_update_elem)(struct bpf_map___251 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___251 *, void *);
	int (*map_push_elem)(struct bpf_map___251 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___251 *, void *);
	int (*map_peek_elem)(struct bpf_map___251 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___251 *, struct file___401 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___251 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___251 *, void *, struct seq_file___340 *);
	int (*map_check_btf)(const struct bpf_map___251 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___251 {
	const struct bpf_map_ops___250 *ops;
	struct bpf_map___251 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___369 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___46;

struct bpf_map_dev_ops___46 {
	int (*map_get_next_key)(struct bpf_offloaded_map___46 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___46 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___46 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___46 *, void *);
};

struct bpf_offloaded_map___46 {
	struct bpf_map___251 map;
	struct net_device___48 *netdev;
	const struct bpf_map_dev_ops___46 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___40 {
	int (*test_run)(struct bpf_prog___40 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___40 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___40 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___40 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___40 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___40 *, u32 *);
};

struct bpf_prog_offload_ops___40 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___40 *);
	int (*translate)(struct bpf_prog___40 *);
	void (*destroy)(struct bpf_prog___40 *);
};

struct bpf_prog_offload___40 {
	struct bpf_prog___40 *prog;
	struct net_device___48 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___40 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___43 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___40 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___40 *ops;
	struct bpf_map___251 **used_maps;
	struct bpf_prog___40 *prog;
	struct user_struct___369 *user;
	u64 load_time;
	struct bpf_map___251 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___40 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___40 {
	struct bpf_prog___40 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___40 {
	struct callback_head rcu;
	struct bpf_prog_array_item___40 items[0];
};

struct cgroup_bpf___40 {
	struct bpf_prog_array___40 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___40 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___251;

typedef void (*kthread_work_func_t___251)(struct kthread_work___251 *);

struct kthread_worker___251;

struct kthread_work___251 {
	struct list_head node;
	kthread_work_func_t___251 func;
	struct kthread_worker___251 *worker;
	int canceling;
};

struct kthread_worker___251 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___403 *task;
	struct kthread_work___251 *current_work;
};

struct kthread_delayed_work___250 {
	struct kthread_work___251 work;
	struct timer_list timer;
};

struct psi_group___250 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___251 *poll_kworker;
	struct kthread_delayed_work___250 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___250;

struct cgroup_rstat_cpu___250;

struct cgroup___250 {
	struct cgroup_subsys_state___250 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___396 *kn;
	struct cgroup_file___250 procs_file;
	struct cgroup_file___250 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___250 *subsys[13];
	struct cgroup_root___250 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___250 *dom_cgrp;
	struct cgroup_rstat_cpu___250 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___40 bpf;
	atomic_t congestion_count;
	struct cgroup___250 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___250 psi;
	int ancestor_ids[0];
};

struct cftype___250;

struct cgroup_subsys___250 {
	struct cgroup_subsys_state___250 * (*css_alloc)(struct cgroup_subsys_state___250 *);
	int (*css_online)(struct cgroup_subsys_state___250 *);
	void (*css_offline)(struct cgroup_subsys_state___250 *);
	void (*css_released)(struct cgroup_subsys_state___250 *);
	void (*css_free)(struct cgroup_subsys_state___250 *);
	void (*css_reset)(struct cgroup_subsys_state___250 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___250 *, int);
	int (*css_extra_stat_show)(struct seq_file___340 *, struct cgroup_subsys_state___250 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___403 *);
	void (*cancel_fork)(struct task_struct___403 *);
	void (*fork)(struct task_struct___403 *);
	void (*exit)(struct task_struct___403 *);
	void (*free)(struct task_struct___403 *);
	void (*bind)(struct cgroup_subsys_state___250 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___250 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___250 *dfl_cftypes;
	struct cftype___250 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___250 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___250 *updated_children;
	struct cgroup___250 *updated_next;
};

struct cgroup_root___250 {
	struct kernfs_root___395 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___250 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___250 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___250 *ss;
	struct list_head node;
	struct kernfs_ops___395 *kf_ops;
	int (*open)(struct kernfs_open_file___395 *);
	void (*release)(struct kernfs_open_file___395 *);
	u64 (*read_u64)(struct cgroup_subsys_state___250 *, struct cftype___250 *);
	s64 (*read_s64)(struct cgroup_subsys_state___250 *, struct cftype___250 *);
	int (*seq_show)(struct seq_file___340 *, void *);
	void * (*seq_start)(struct seq_file___340 *, loff_t *);
	void * (*seq_next)(struct seq_file___340 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___340 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___250 *, struct cftype___250 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___250 *, struct cftype___250 *, s64);
	ssize_t (*write)(struct kernfs_open_file___395 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___395 *, struct poll_table_struct___244 *);
};

struct xdp_rxq_info___46 {
	struct net_device___48 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___46 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___48 *dev_rx;
};

struct netlink_callback___48 {
	struct sk_buff___48 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___48 *);
	int (*dump)(struct sk_buff___48 *, struct netlink_callback___48 *);
	int (*done)(struct netlink_callback___48 *);
	void *data;
	struct module___331 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___46 {
	int (*create)(struct sk_buff___48 *, struct net_device___48 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___48 *, unsigned char *);
	int (*cache)(const struct neighbour___30 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___48 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___46 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___46 *, int);
	int poll_owner;
	struct net_device___48 *dev;
	struct sk_buff___48 *gro_list;
	struct sk_buff___48 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___46 {
	struct net_device___48 *dev;
	struct Qdisc___40 *qdisc;
	struct Qdisc___40 *qdisc_sleeping;
	struct kobject___389 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___48 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___40 {
	struct sk_buff___48 *head;
	struct sk_buff___48 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___40;

struct Qdisc___40 {
	int (*enqueue)(struct sk_buff___48 *, struct Qdisc___40 *, struct sk_buff___48 **);
	struct sk_buff___48 * (*dequeue)(struct Qdisc___40 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___40 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___46 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___46 gso_skb;
	struct qdisc_skb_head___40 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___40 *next_sched;
	struct sk_buff_head___46 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___46 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___389 kobj;
	struct net_device___48 *dev;
	long: 64;
	struct xdp_rxq_info___46 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___46)(struct net_device___48 *, struct sk_buff___48 *, struct net_device___48 *);

struct netdev_bpf___46 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___40 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___40 *prog;
			const struct bpf_prog_offload_ops___40 *ops;
		} verifier;
		struct {
			struct bpf_prog___40 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___46 *offmap;
		};
		struct {
			struct xdp_umem *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___46 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___48 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___46 {
	int (*tls_dev_add)(struct net_device___48 *, struct sock___31 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___48 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___48 *, struct sock___31 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___46 {
	int (*ndo_init)(struct net_device___48 *);
	void (*ndo_uninit)(struct net_device___48 *);
	int (*ndo_open)(struct net_device___48 *);
	int (*ndo_stop)(struct net_device___48 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___48 *, struct net_device___48 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___48 *, struct net_device___48 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___48 *, struct sk_buff___48 *, struct net_device___48 *, select_queue_fallback_t___46);
	void (*ndo_change_rx_flags)(struct net_device___48 *, int);
	void (*ndo_set_rx_mode)(struct net_device___48 *);
	int (*ndo_set_mac_address)(struct net_device___48 *, void *);
	int (*ndo_validate_addr)(struct net_device___48 *);
	int (*ndo_do_ioctl)(struct net_device___48 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___48 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___48 *, int);
	int (*ndo_neigh_setup)(struct net_device___48 *, struct neigh_parms___30 *);
	void (*ndo_tx_timeout)(struct net_device___48 *);
	void (*ndo_get_stats64)(struct net_device___48 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___48 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___48 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___48 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___48 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___48 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___48 *);
	int (*ndo_netpoll_setup)(struct net_device___48 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___48 *);
	int (*ndo_set_vf_mac)(struct net_device___48 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___48 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___48 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___48 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___48 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___48 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___48 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___48 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___48 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___48 *, int, struct sk_buff___48 *);
	int (*ndo_set_vf_guid)(struct net_device___48 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___48 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___48 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___48 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___48 *, const struct sk_buff___48 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___48 *, struct net_device___48 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___48 *, struct net_device___48 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___48 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___48 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___48 *, struct neighbour___30 *);
	void (*ndo_neigh_destroy)(struct net_device___48 *, struct neighbour___30 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___48 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___48 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___48 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___48 *, struct netlink_callback___48 *, struct net_device___48 *, struct net_device___48 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___48 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___48 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___48 *, u32, u32, struct net_device___48 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___48 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___48 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___48 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___48 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___48 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___48 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___48 *, struct net_device___48 *);
	void (*ndo_dfwd_del_station)(struct net_device___48 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___48 *);
	int (*ndo_set_tx_maxrate)(struct net_device___48 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___48 *);
	int (*ndo_change_proto_down)(struct net_device___48 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___48 *, struct sk_buff___48 *);
	void (*ndo_set_rx_headroom)(struct net_device___48 *, int);
	int (*ndo_bpf)(struct net_device___48 *, struct netdev_bpf___46 *);
	int (*ndo_xdp_xmit)(struct net_device___48 *, int, struct xdp_frame___46 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___48 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___48 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___30 {
	possible_net_t___48 net;
	struct net_device___48 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___30 *);
	void (*neigh_cleanup)(struct neighbour___30 *);
	struct neigh_table___30 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___30 {
	u32 (*l3mdev_fib_table)(const struct net_device___48 *);
	struct sk_buff___48 * (*l3mdev_l3_rcv)(struct net_device___48 *, struct sk_buff___48 *, u16);
	struct sk_buff___48 * (*l3mdev_l3_out)(struct net_device___48 *, struct sock___31 *, struct sk_buff___48 *, u16);
	struct dst_entry___30 * (*l3mdev_link_scope_lookup)(const struct net_device___48 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct ndisc_ops___16 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___48 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___48 *, struct neighbour___30 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___48 *, u8, struct neighbour___30 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___48 *, struct sk_buff___48 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___58 *, struct net_device___48 *, const struct prefix_info *, struct inet6_dev___16 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___16;

struct inet6_dev___16 {
	struct net_device___48 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___16 *mc_list;
	struct ifmcaddr6___16 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	u8 rndid[8];
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___30 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
};

struct tcf_proto___40;

struct mini_Qdisc___40 {
	struct tcf_proto___40 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___40 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___48 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___58 *, struct net_device___48 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___48 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___48 *, struct list_head *);
	size_t (*get_size)(const struct net_device___48 *);
	int (*fill_info)(struct sk_buff___48 *, const struct net_device___48 *);
	size_t (*get_xstats_size)(const struct net_device___48 *);
	int (*fill_xstats)(struct sk_buff___48 *, const struct net_device___48 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___48 *, struct net_device___48 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___48 *, const struct net_device___48 *);
	int (*fill_slave_info)(struct sk_buff___48 *, const struct net_device___48 *, const struct net_device___48 *);
	struct net___58 * (*get_link_net)(const struct net_device___48 *);
	size_t (*get_linkxstats_size)(const struct net_device___48 *, int);
	int (*fill_linkxstats)(struct sk_buff___48 *, const struct net_device___48 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___46 {
	struct list_head poll_list;
	struct sk_buff_head___46 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___46 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___40 *output_queue;
	struct Qdisc___40 **output_queue_tailp;
	struct sk_buff___48 *completion_queue;
	struct sk_buff_head___46 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___46 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___46 input_pkt_queue;
	struct napi_struct___46 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef int br_should_route_hook_t(struct sk_buff___48 *);

typedef struct poll_table_struct___244 poll_table___41;

struct kernel_param_ops___329 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___329 *);
	int (*get)(char *, const struct kernel_param___329 *);
	void (*free)(void *);
};

struct kparam_array___329;

struct kernel_param___329 {
	const char *name;
	struct module___331 *mod;
	const struct kernel_param_ops___329 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___329 *arr;
	};
};

struct kparam_array___329 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___329 *ops;
	void *elem;
};

struct module_attribute___329 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___329 *, struct module_kobject___329 *, char *);
	ssize_t (*store)(struct module_attribute___329 *, struct module_kobject___329 *, const char *, size_t);
	void (*setup)(struct module___331 *, const char *);
	int (*test)(struct module___331 *);
	void (*free)(struct module___331 *);
};

struct trace_event_class___145;

struct trace_event_call___145 {
	struct list_head list;
	struct trace_event_class___145 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___13 event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___40 *prog_array;
	int (*perf_perm)(struct trace_event_call___145 *, struct perf_event___154 *);
};

struct node___222 {
	struct device___369 dev;
};

struct perf_cpu_context___154;

struct pmu___154 {
	struct list_head entry;
	struct module___331 *module;
	struct device___369 *dev;
	const struct attribute_group___366 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___154 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___154 *);
	void (*pmu_disable)(struct pmu___154 *);
	int (*event_init)(struct perf_event___154 *);
	void (*event_mapped)(struct perf_event___154 *, struct mm_struct___402 *);
	void (*event_unmapped)(struct perf_event___154 *, struct mm_struct___402 *);
	int (*add)(struct perf_event___154 *, int);
	void (*del)(struct perf_event___154 *, int);
	void (*start)(struct perf_event___154 *, int);
	void (*stop)(struct perf_event___154 *, int);
	void (*read)(struct perf_event___154 *);
	void (*start_txn)(struct pmu___154 *, unsigned int);
	int (*commit_txn)(struct pmu___154 *);
	void (*cancel_txn)(struct pmu___154 *);
	int (*event_idx)(struct perf_event___154 *);
	void (*sched_task)(struct perf_event_context___154 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___154 *);
	int (*filter_match)(struct perf_event___154 *);
	int (*check_period)(struct perf_event___154 *, u64);
};

struct perf_cpu_context___154 {
	struct perf_event_context___154 ctx;
	struct perf_event_context___154 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___154 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___154 {
	struct cgroup_subsys_state___250 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___145 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___145 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___145 *);
	struct list_head * (*get_fields)(struct trace_event_call___145 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___145 *);
};

struct syscall_metadata___66 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___145 *enter_event;
	struct trace_event_call___145 *exit_event;
};

struct bdi_writeback_congested___195 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___195 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___195 {
	struct bio___195 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___197 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___197 bip_inline_vecs[0];
};

struct bio_set___195 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___195 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___138 {
	struct mem_cgroup___138 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___138 {
	struct lruvec___402 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___138 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___138 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct gnet_dump___40 {
	spinlock_t *lock;
	struct sk_buff___48 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___40;

struct Qdisc_ops___40 {
	struct Qdisc_ops___40 *next;
	const struct Qdisc_class_ops___40 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___48 *, struct Qdisc___40 *, struct sk_buff___48 **);
	struct sk_buff___48 * (*dequeue)(struct Qdisc___40 *);
	struct sk_buff___48 * (*peek)(struct Qdisc___40 *);
	int (*init)(struct Qdisc___40 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___40 *);
	void (*destroy)(struct Qdisc___40 *);
	int (*change)(struct Qdisc___40 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___40 *);
	int (*change_tx_queue_len)(struct Qdisc___40 *, unsigned int);
	int (*dump)(struct Qdisc___40 *, struct sk_buff___48 *);
	int (*dump_stats)(struct Qdisc___40 *, struct gnet_dump___40 *);
	void (*ingress_block_set)(struct Qdisc___40 *, u32);
	void (*egress_block_set)(struct Qdisc___40 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___40 *);
	u32 (*egress_block_get)(struct Qdisc___40 *);
	struct module___331 *owner;
};

struct tcf_block___40;

struct Qdisc_class_ops___40 {
	unsigned int flags;
	struct netdev_queue___46 * (*select_queue)(struct Qdisc___40 *, struct tcmsg *);
	int (*graft)(struct Qdisc___40 *, long unsigned int, struct Qdisc___40 *, struct Qdisc___40 **, struct netlink_ext_ack *);
	struct Qdisc___40 * (*leaf)(struct Qdisc___40 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___40 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___40 *, u32);
	int (*change)(struct Qdisc___40 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___40 *, long unsigned int);
	void (*walk)(struct Qdisc___40 *, struct qdisc_walker *);
	struct tcf_block___40 * (*tcf_block)(struct Qdisc___40 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___40 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___40 *, long unsigned int);
	int (*dump)(struct Qdisc___40 *, long unsigned int, struct sk_buff___48 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___40 *, long unsigned int, struct gnet_dump___40 *);
};

struct tcf_chain___40;

struct tcf_block___40 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___58 *net;
	struct Qdisc___40 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___40 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___40;

struct tcf_proto_ops___40;

struct tcf_proto___40 {
	struct tcf_proto___40 *next;
	void *root;
	int (*classify)(struct sk_buff___48 *, const struct tcf_proto___40 *, struct tcf_result___40 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___40 *ops;
	struct tcf_chain___40 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___40 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___40 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___40 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___48 *, const struct tcf_proto___40 *, struct tcf_result___40 *);
	int (*init)(struct tcf_proto___40 *);
	void (*destroy)(struct tcf_proto___40 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___40 *, u32);
	void (*put)(struct tcf_proto___40 *, void *);
	int (*change)(struct net___58 *, struct sk_buff___48 *, struct tcf_proto___40 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___40 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___40 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___40 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___58 *, struct tcf_chain___40 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___58 *, struct tcf_proto___40 *, void *, struct sk_buff___48 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___48 *, struct net___58 *, void *);
	struct module___331 *owner;
	int flags;
};

struct tcf_chain___40 {
	struct mutex filter_chain_lock;
	struct tcf_proto___40 *filter_chain;
	struct list_head list;
	struct tcf_block___40 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___40 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___30 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___40 *prog;
};

struct bpf_redirect_info___40 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___251 *map;
	struct bpf_map___251 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___30;

struct neigh_hash_table___30;

struct neigh_table___30 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___48 *, __u32 *);
	bool (*key_eq)(const struct neighbour___30 *, const void *);
	int (*constructor)(struct neighbour___30 *);
	int (*pconstructor)(struct pneigh_entry___30 *);
	void (*pdestructor)(struct pneigh_entry___30 *);
	void (*proxy_redo)(struct sk_buff___48 *);
	char *id;
	struct neigh_parms___30 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___46 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___30 *nht;
	struct pneigh_entry___30 **phash_buckets;
};

struct neigh_ops___30 {
	int family;
	void (*solicit)(struct neighbour___30 *, struct sk_buff___48 *);
	void (*error_report)(struct neighbour___30 *, struct sk_buff___48 *);
	int (*output)(struct neighbour___30 *, struct sk_buff___48 *);
	int (*connected_output)(struct neighbour___30 *, struct sk_buff___48 *);
};

struct pneigh_entry___30 {
	struct pneigh_entry___30 *next;
	possible_net_t___48 net;
	struct net_device___48 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___30 {
	struct neighbour___30 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct scm_ts_pktinfo {
	__u32 if_index;
	__u32 pkt_length;
	__u32 reserved[2];
};

struct fib_rule___30 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___30 *ctarget;
	struct net___58 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___30 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___30 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___19;

struct timewait_sock_ops___17;

struct proto___30 {
	void (*close)(struct sock___31 *, long int);
	int (*pre_connect)(struct sock___31 *, struct sockaddr *, int);
	int (*connect)(struct sock___31 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___31 *, int);
	struct sock___31 * (*accept)(struct sock___31 *, int, int *, bool);
	int (*ioctl)(struct sock___31 *, int, long unsigned int);
	int (*init)(struct sock___31 *);
	void (*destroy)(struct sock___31 *);
	void (*shutdown)(struct sock___31 *, int);
	int (*setsockopt)(struct sock___31 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___31 *, int, int, char *, int *);
	void (*keepalive)(struct sock___31 *, int);
	int (*sendmsg)(struct sock___31 *, struct msghdr___33 *, size_t);
	int (*recvmsg)(struct sock___31 *, struct msghdr___33 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___31 *, struct page___402 *, int, size_t, int);
	int (*bind)(struct sock___31 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___31 *, struct sk_buff___48 *);
	void (*release_cb)(struct sock___31 *);
	int (*hash)(struct sock___31 *);
	void (*unhash)(struct sock___31 *);
	void (*rehash)(struct sock___31 *);
	int (*get_port)(struct sock___31 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___31 *);
	bool (*stream_memory_read)(const struct sock___31 *);
	void (*enter_memory_pressure)(struct sock___31 *);
	void (*leave_memory_pressure)(struct sock___31 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___19 *rsk_prot;
	struct timewait_sock_ops___17 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___331 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___31 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct request_sock___20;

struct request_sock_ops___19 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___31 *, struct request_sock___20 *);
	void (*send_ack)(const struct sock___31 *, struct sk_buff___48 *, struct request_sock___20 *);
	void (*send_reset)(const struct sock___31 *, struct sk_buff___48 *);
	void (*destructor)(struct request_sock___20 *);
	void (*syn_ack_timeout)(const struct request_sock___20 *);
};

struct timewait_sock_ops___17 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___31 *, struct sock___31 *, void *);
	void (*twsk_destructor)(struct sock___31 *);
};

struct socket_alloc___2 {
	struct socket___32 socket;
	struct inode___401 vfs_inode;
};

struct sock_skb_cb {
	u32 dropcount;
};

struct request_sock___20 {
	struct sock_common___30 __req_common;
	struct request_sock___20 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___19 *rsk_ops;
	struct sock___31 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct inet_cork___3 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___30 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
	__u16 gso_size;
	u64 transmit_time;
};

struct inet_cork_full___3 {
	struct inet_cork___3 base;
	struct flowi fl;
};

struct ipv6_pinfo___3;

struct inet_sock___3 {
	struct sock___31 sk;
	struct ipv6_pinfo___3 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	__be16 inet_sport;
	__u16 inet_id;
	struct ip_options_rcu *inet_opt;
	int rx_dst_ifindex;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 bind_address_no_port: 1;
	__u8 defer_connect: 1;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___3 cork;
};

struct ipv6_fl_socklist___3;

struct ipv6_pinfo___3 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
			__u16 recvfragsize: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 repflow: 1;
	__u16 pmtudisc: 3;
	__u16 padding: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u16 autoflowlabel: 1;
	__u16 autoflowlabel_set: 1;
	__u8 min_hopcount;
	__u8 tclass;
	__be32 rcv_flowinfo;
	__u32 dst_cookie;
	__u32 rx_dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___3 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___48 *pktoptions;
	struct sk_buff___48 *rxpmtu;
	struct inet6_cork cork;
};

struct nf_hook_state___2 {
	unsigned int hook;
	u_int8_t pf;
	struct net_device___48 *in;
	struct net_device___48 *out;
	struct sock___31 *sk;
	struct net___58 *net;
	int (*okfn)(struct net___58 *, struct sock___31 *, struct sk_buff___48 *);
};

struct nf_nat_hook___2 {
	int (*parse_nat_setup)(struct nf_conn *, enum nf_nat_manip_type, const struct nlattr *);
	void (*decode_session)(struct sk_buff___48 *, struct flowi *);
	unsigned int (*manip_pkt)(struct sk_buff___48 *, struct nf_conn *, enum nf_nat_manip_type, enum ip_conntrack_dir);
};

struct nf_ct_hook___2 {
	int (*update)(struct net___58 *, struct sk_buff___48 *);
	void (*destroy)(struct nf_conntrack *);
	bool (*get_tuple_skb)(struct nf_conntrack_tuple *, const struct sk_buff___48 *);
};

struct nfnl_ct_hook___2 {
	struct nf_conn * (*get_ct)(const struct sk_buff___48 *, enum ip_conntrack_info *);
	size_t (*build_size)(const struct nf_conn *);
	int (*build)(struct sk_buff___48 *, struct nf_conn *, enum ip_conntrack_info, u_int16_t, u_int16_t);
	int (*parse)(const struct nlattr *, struct nf_conn *);
	int (*attach_expect)(const struct nlattr *, struct nf_conn *, u32, u32);
	void (*seq_adjust)(struct sk_buff___48 *, struct nf_conn *, enum ip_conntrack_info, s32);
};

struct ip6_flowlabel___3;

struct ipv6_fl_socklist___3 {
	struct ipv6_fl_socklist___3 *next;
	struct ip6_flowlabel___3 *fl;
	struct callback_head rcu;
};

struct ifmcaddr6___16 {
	struct in6_addr mca_addr;
	struct inet6_dev___16 *idev;
	struct ifmcaddr6___16 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ip6_ra_chain___16 {
	struct ip6_ra_chain___16 *next;
	struct sock___31 *sk;
	int sel;
	void (*destructor)(struct sock___31 *);
};

struct ip6_flowlabel___3 {
	struct ip6_flowlabel___3 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___231 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___58 *fl_net;
};

struct sock_extended_err {
	__u32 ee_errno;
	__u8 ee_origin;
	__u8 ee_type;
	__u8 ee_code;
	__u8 ee_pad;
	__u32 ee_info;
	__u32 ee_data;
};

struct scm_timestamping {
	struct timespec ts[3];
};

struct sock_exterr_skb {
	union {
		struct inet_skb_parm h4;
		struct inet6_skb_parm h6;
	} header;
	struct sock_extended_err ee;
	u16 addr_offset;
	__be16 port;
	u8 opt_stats: 1;
	u8 unused: 7;
};

struct used_address {
	struct __kernel_sockaddr_storage name;
	unsigned int name_len;
	int: 32;
};

struct module___332;

struct file___402;

struct kiocb___402;

struct iov_iter___169;

struct poll_table_struct___245;

struct vm_area_struct___403;

struct inode___402;

struct file_lock___402;

struct page___403;

struct pipe_inode_info___83;

struct seq_file___341;

struct file_operations___402 {
	struct module___332 *owner;
	loff_t (*llseek)(struct file___402 *, loff_t, int);
	ssize_t (*read)(struct file___402 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___402 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___402 *, struct iov_iter___169 *);
	ssize_t (*write_iter)(struct kiocb___402 *, struct iov_iter___169 *);
	int (*iopoll)(struct kiocb___402 *, bool);
	int (*iterate)(struct file___402 *, struct dir_context *);
	int (*iterate_shared)(struct file___402 *, struct dir_context *);
	__poll_t (*poll)(struct file___402 *, struct poll_table_struct___245 *);
	long int (*unlocked_ioctl)(struct file___402 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___402 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___402 *, struct vm_area_struct___403 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___402 *, struct file___402 *);
	int (*flush)(struct file___402 *, fl_owner_t);
	int (*release)(struct inode___402 *, struct file___402 *);
	int (*fsync)(struct file___402 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___402 *, int);
	int (*lock)(struct file___402 *, int, struct file_lock___402 *);
	ssize_t (*sendpage)(struct file___402 *, struct page___403 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___402 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___402 *, int, struct file_lock___402 *);
	ssize_t (*splice_write)(struct pipe_inode_info___83 *, struct file___402 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___402 *, loff_t *, struct pipe_inode_info___83 *, size_t, unsigned int);
	int (*setlease)(struct file___402 *, long int, struct file_lock___402 **, void **);
	long int (*fallocate)(struct file___402 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___341 *, struct file___402 *);
	ssize_t (*copy_file_range)(struct file___402 *, loff_t, struct file___402 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___402 *, loff_t, struct file___402 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___402 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___403 {
	u64 seqnum;
	struct vm_area_struct___403 *vmas[4];
};

struct page_frag___403 {
	struct page___403 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___403;

struct mem_cgroup___139;

struct pid___232;

struct cred___370;

struct nsproxy___297;

struct signal_struct___277;

struct bio_list___196;

struct backing_dev_info___196;

struct css_set___251;

struct vm_struct___306;

struct task_struct___404 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___404 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___403 *mm;
	struct mm_struct___403 *active_mm;
	struct vmacache___403 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___404 *real_parent;
	struct task_struct___404 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___404 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___139 *active_memcg;
	long int rh_reserved2;
	struct pid___232 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___232 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___232 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___370 *ptracer_cred;
	const struct cred___370 *real_cred;
	const struct cred___370 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___297 *nsproxy;
	struct signal_struct___277 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___404 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___196 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___196 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___251 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___83 *splice_pipe;
	struct page_frag___403 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___139 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___404 *oom_reaper_list;
	struct vm_struct___306 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___154 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___403 *pgtable_t___403;

struct address_space___402;

struct dev_pagemap___390;

struct page___403 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___402 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___403 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___403 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___403 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___390 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___139 *mem_cgroup;
};

struct pglist_data___403;

struct lruvec___403 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___403 *pgdat;
};

struct zone___403 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___403 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___403 {
	struct zone___403 *zone;
	int zone_idx;
};

struct zonelist___403 {
	struct zoneref___403 _zonerefs[25];
};

struct pglist_data___403 {
	struct zone___403 node_zones[3];
	struct zonelist___403 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___404 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___404 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___403 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___404 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___404 *owner;
};

struct secondary_data___404 {
	void *stack;
	struct task_struct___404 *task;
	long int status;
};

struct blocking_notifier_head___403 {
	struct rw_semaphore___404 rwsem;
	struct notifier_block *head;
};

struct cgroup___251;

struct cgroup_subsys___251;

struct cgroup_subsys_state___251 {
	struct cgroup___251 *cgroup;
	struct cgroup_subsys___251 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___251 *parent;
};

struct kernfs_node___397;

struct cgroup_file___251 {
	struct kernfs_node___397 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___139;

struct mem_cgroup___139 {
	struct cgroup_subsys_state___251 css;
	struct mem_cgroup_id___16 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___251 events_file;
	struct cgroup_file___251 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___404 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___139 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___232;

struct upid___232 {
	int nr;
	struct pid_namespace___232 *ns;
};

struct dentry___402;

struct user_namespace___267;

struct ucounts___267;

struct pid_namespace___232 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___404 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___232 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___402 *proc_self;
	struct dentry___402 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___267 *user_ns;
	struct ucounts___267 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___9 ns;
};

struct pid___232 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___232 numbers[1];
};

struct key___370;

struct user_namespace___267 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___267 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___9 ns;
	long unsigned int flags;
	struct key___370 *persistent_keyring_register;
	struct rw_semaphore___404 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___267 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct user_struct___370 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___370 *uid_keyring;
	struct key___370 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___390;

struct vm_area_struct___403 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___403 *vm_next;
	struct vm_area_struct___403 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___403 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___390 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___402 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___403;

struct mm_struct___403 {
	struct {
		struct vm_area_struct___403 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___402 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___404 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___403 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___404 *owner;
		struct user_namespace___267 *user_ns;
		struct file___402 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___403 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___370 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___370 *session_keyring;
	struct key___370 *process_keyring;
	struct key___370 *thread_keyring;
	struct key___370 *request_key_auth;
	void *security;
	struct user_struct___370 *user;
	struct user_namespace___267 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___59;

struct cgroup_namespace___251;

struct nsproxy___297 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___232 *pid_ns_for_children;
	struct net___59 *net_ns;
	struct cgroup_namespace___251 *cgroup_ns;
};

struct signal_struct___277 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___404 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___404 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___232 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___232 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___403 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___232 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___196;

struct bio_list___196 {
	struct bio___196 *head;
	struct bio___196 *tail;
};

struct bdi_writeback_congested___196;

struct bdi_writeback___196 {
	struct backing_dev_info___196 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___196 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___251 *memcg_css;
	struct cgroup_subsys_state___251 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___370;

struct backing_dev_info___196 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___196 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___370 *dev;
	struct device___370 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___402 *debug_dir;
	struct dentry___402 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___251 {
	struct cgroup_subsys_state___251 *subsys[13];
	refcount_t refcount;
	struct css_set___251 *dom_cset;
	struct cgroup___251 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___251 *mg_src_cgrp;
	struct cgroup___251 *mg_dst_cgrp;
	struct css_set___251 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___402;

struct pipe_buffer___83;

struct pipe_inode_info___83 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___403 *tmp_page;
	struct fasync_struct___402 *fasync_readers;
	struct fasync_struct___402 *fasync_writers;
	struct pipe_buffer___83 *bufs;
	struct user_struct___370 *user;
};

struct vm_struct___306 {
	struct vm_struct___306 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___403 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___289 {
	struct task_struct___404 task;
	long unsigned int stack[8192];
};

struct address_space_operations___402;

struct address_space___402 {
	struct inode___402 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___404 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___402 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___390)(struct vm_area_struct___403 *, long unsigned int, const struct page___403 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___390)(struct page___403 *, void *);

struct dev_pagemap___390 {
	dev_page_fault_t___390 page_fault;
	dev_page_free_t___390 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___370 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___403 {
	struct vfsmount *mnt;
	struct dentry___402 *dentry;
};

struct fown_struct___232 {
	rwlock_t lock;
	struct pid___232 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___402 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___403 f_path;
	struct inode___402 *f_inode;
	const struct file_operations___402 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___232 f_owner;
	const struct cred___370 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___402 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___390;

struct vm_operations_struct___390 {
	void (*open)(struct vm_area_struct___403 *);
	void (*close)(struct vm_area_struct___403 *);
	int (*split)(struct vm_area_struct___403 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___403 *);
	vm_fault_t (*fault)(struct vm_fault___390 *);
	vm_fault_t (*huge_fault)(struct vm_fault___390 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___390 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___403 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___390 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___390 *);
	int (*access)(struct vm_area_struct___403 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___403 *);
	int (*set_policy)(struct vm_area_struct___403 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___403 *, long unsigned int);
	struct page___403 * (*find_special_page)(struct vm_area_struct___403 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___403 {
	struct task_struct___404 *task;
	struct core_thread___403 *next;
};

struct core_state___403 {
	atomic_t nr_threads;
	struct core_thread___403 dumper;
	struct completion startup;
};

struct vm_fault___390 {
	struct vm_area_struct___403 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___403 *cow_page;
	struct mem_cgroup___139 *memcg;
	struct page___403 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___403 prealloc_pte;
};

struct crypto_async_request___21;

typedef void (*crypto_completion_t___21)(struct crypto_async_request___21 *, int);

struct crypto_tfm___21;

struct crypto_async_request___21 {
	struct list_head list;
	crypto_completion_t___21 complete;
	void *data;
	struct crypto_tfm___21 *tfm;
	u32 flags;
};

struct crypto_ablkcipher___21;

struct ablkcipher_request___21;

struct ablkcipher_tfm___21 {
	int (*setkey)(struct crypto_ablkcipher___21 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___21 *);
	int (*decrypt)(struct ablkcipher_request___21 *);
	struct crypto_ablkcipher___21 *base;
	unsigned int ivsize;
	unsigned int reqsize;
};

struct blkcipher_desc___21;

struct blkcipher_tfm___21 {
	void *iv;
	int (*setkey)(struct crypto_tfm___21 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___21 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___21 *, struct scatterlist *, struct scatterlist *, unsigned int);
};

struct cipher_tfm___21 {
	int (*cit_setkey)(struct crypto_tfm___21 *, const u8 *, unsigned int);
	void (*cit_encrypt_one)(struct crypto_tfm___21 *, u8 *, const u8 *);
	void (*cit_decrypt_one)(struct crypto_tfm___21 *, u8 *, const u8 *);
};

struct compress_tfm___21 {
	int (*cot_compress)(struct crypto_tfm___21 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*cot_decompress)(struct crypto_tfm___21 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___21;

struct crypto_tfm___21 {
	u32 crt_flags;
	union {
		struct ablkcipher_tfm___21 ablkcipher;
		struct blkcipher_tfm___21 blkcipher;
		struct cipher_tfm___21 cipher;
		struct compress_tfm___21 compress;
	} crt_u;
	void (*exit)(struct crypto_tfm___21 *);
	struct crypto_alg___21 *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct ablkcipher_request___21 {
	struct crypto_async_request___21 base;
	unsigned int nbytes;
	void *info;
	struct scatterlist *src;
	struct scatterlist *dst;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_blkcipher___21;

struct blkcipher_desc___21 {
	struct crypto_blkcipher___21 *tfm;
	void *info;
	u32 flags;
};

struct crypto_blkcipher___21 {
	struct crypto_tfm___21 base;
};

struct ablkcipher_alg___21 {
	int (*setkey)(struct crypto_ablkcipher___21 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___21 *);
	int (*decrypt)(struct ablkcipher_request___21 *);
	int (*givencrypt)(struct skcipher_givcrypt_request *);
	int (*givdecrypt)(struct skcipher_givcrypt_request *);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct crypto_ablkcipher___21 {
	struct crypto_tfm___21 base;
};

struct blkcipher_alg___21 {
	int (*setkey)(struct crypto_tfm___21 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___21 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___21 *, struct scatterlist *, struct scatterlist *, unsigned int);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct cipher_alg___21 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___21 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___21 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___21 *, u8 *, const u8 *);
};

struct compress_alg___21 {
	int (*coa_compress)(struct crypto_tfm___21 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___21 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___21 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type *cra_type;
	union {
		struct ablkcipher_alg___21 ablkcipher;
		struct blkcipher_alg___21 blkcipher;
		struct cipher_alg___21 cipher;
		struct compress_alg___21 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___21 *);
	void (*cra_exit)(struct crypto_tfm___21 *);
	void (*cra_destroy)(struct crypto_alg___21 *);
	struct module___332 *cra_module;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___389;

struct kobj_type___389;

struct kobject___390 {
	const char *name;
	struct list_head entry;
	struct kobject___390 *parent;
	struct kset___389 *kset;
	struct kobj_type___389 *ktype;
	struct kernfs_node___397 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___330 {
	struct kobject___390 kobj;
	struct module___332 *mod;
	struct kobject___390 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___330 {
	struct module___332 *mod;
	struct latch_tree_node node;
};

struct module_layout___330 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___330 mtn;
};

struct module_attribute___330;

struct kernel_param___330;

struct module___332 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___330 mkobj;
	struct module_attribute___330 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___390 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___330 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___330 core_layout;
	struct module_layout___330 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide53;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide54;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct crypto_cipher___5 {
	struct crypto_tfm___21 base;
};

struct bio_vec___198 {
	struct page___403 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___169 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___198 *bvec;
		struct pipe_inode_info___83 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct linger {
	int l_onoff;
	int l_linger;
};

struct msghdr___34 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___169 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___402 *msg_iocb;
};

struct kiocb___402 {
	struct file___402 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___402 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct ucred {
	__u32 pid;
	__u32 uid;
	__u32 gid;
};

struct dentry_operations___402;

struct super_block___402;

struct dentry___402 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___402 *d_parent;
	struct qstr d_name;
	struct inode___402 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___402 *d_op;
	struct super_block___402 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___402;

struct block_device___402;

struct inode___402 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___402 *i_op;
	struct super_block___402 *i_sb;
	struct address_space___402 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___404 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___196 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___402 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___402 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___83 *i_pipe;
		struct block_device___402 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___402 {
	int (*d_revalidate)(struct dentry___402 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___402 *, unsigned int);
	int (*d_hash)(const struct dentry___402 *, struct qstr *);
	int (*d_compare)(const struct dentry___402 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___402 *);
	int (*d_init)(struct dentry___402 *);
	void (*d_release)(struct dentry___402 *);
	void (*d_prune)(struct dentry___402 *);
	void (*d_iput)(struct dentry___402 *, struct inode___402 *);
	char * (*d_dname)(struct dentry___402 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___403 *);
	int (*d_manage)(const struct path___403 *, bool);
	struct dentry___402 * (*d_real)(struct dentry___402 *, const struct inode___402 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___402;

struct mem_dqinfo___402 {
	struct quota_format_type___402 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___402;

struct quota_info___402 {
	unsigned int flags;
	struct rw_semaphore___404 dqio_sem;
	struct inode___402 *files[3];
	struct mem_dqinfo___402 info[3];
	const struct quota_format_ops___402 *ops[3];
};

struct rcuwait___402 {
	struct task_struct___404 *task;
};

struct percpu_rw_semaphore___402 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___404 rw_sem;
	struct rcuwait___402 writer;
	int readers_block;
};

struct sb_writers___402 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___402 rw_sem[3];
};

struct shrink_control___139;

struct shrinker___139 {
	long unsigned int (*count_objects)(struct shrinker___139 *, struct shrink_control___139 *);
	long unsigned int (*scan_objects)(struct shrinker___139 *, struct shrink_control___139 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___402;

struct super_operations___402;

struct dquot_operations___402;

struct quotactl_ops___402;

struct super_block___402 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___402 *s_type;
	const struct super_operations___402 *s_op;
	const struct dquot_operations___402 *dq_op;
	const struct quotactl_ops___402 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___402 *s_root;
	struct rw_semaphore___404 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___402 *s_bdev;
	struct backing_dev_info___196 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___402 s_dquot;
	struct sb_writers___402 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___402 *s_d_op;
	int cleancache_poolid;
	struct shrinker___139 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___267 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___139 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___139 *memcg;
};

struct iattr___402 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___402 *ia_file;
};

struct dquot___402 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___402 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___402 {
	int qf_fmt_id;
	const struct quota_format_ops___402 *qf_ops;
	struct module___332 *qf_owner;
	struct quota_format_type___402 *qf_next;
};

struct quota_format_ops___402 {
	int (*check_quota_file)(struct super_block___402 *, int);
	int (*read_file_info)(struct super_block___402 *, int);
	int (*write_file_info)(struct super_block___402 *, int);
	int (*free_file_info)(struct super_block___402 *, int);
	int (*read_dqblk)(struct dquot___402 *);
	int (*commit_dqblk)(struct dquot___402 *);
	int (*release_dqblk)(struct dquot___402 *);
	int (*get_next_id)(struct super_block___402 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___402 {
	int (*write_dquot)(struct dquot___402 *);
	struct dquot___402 * (*alloc_dquot)(struct super_block___402 *, int);
	void (*destroy_dquot)(struct dquot___402 *);
	int (*acquire_dquot)(struct dquot___402 *);
	int (*release_dquot)(struct dquot___402 *);
	int (*mark_dirty)(struct dquot___402 *);
	int (*write_info)(struct super_block___402 *, int);
	qsize_t * (*get_reserved_space)(struct inode___402 *);
	int (*get_projid)(struct inode___402 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___402 *, qsize_t *);
	int (*get_next_id)(struct super_block___402 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___402 {
	int (*quota_on)(struct super_block___402 *, int, int, const struct path___403 *);
	int (*quota_off)(struct super_block___402 *, int);
	int (*quota_enable)(struct super_block___402 *, unsigned int);
	int (*quota_disable)(struct super_block___402 *, unsigned int);
	int (*quota_sync)(struct super_block___402 *, int);
	int (*set_info)(struct super_block___402 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___402 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___402 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___402 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___402 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___402 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___159;

struct address_space_operations___402 {
	int (*writepage)(struct page___403 *, struct writeback_control___159 *);
	int (*readpage)(struct file___402 *, struct page___403 *);
	int (*writepages)(struct address_space___402 *, struct writeback_control___159 *);
	int (*set_page_dirty)(struct page___403 *);
	int (*readpages)(struct file___402 *, struct address_space___402 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___402 *, struct address_space___402 *, loff_t, unsigned int, unsigned int, struct page___403 **, void **);
	int (*write_end)(struct file___402 *, struct address_space___402 *, loff_t, unsigned int, unsigned int, struct page___403 *, void *);
	sector_t (*bmap)(struct address_space___402 *, sector_t);
	void (*invalidatepage)(struct page___403 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___403 *, gfp_t);
	void (*freepage)(struct page___403 *);
	ssize_t (*direct_IO)(struct kiocb___402 *, struct iov_iter___169 *);
	int (*migratepage)(struct address_space___402 *, struct page___403 *, struct page___403 *, enum migrate_mode);
	bool (*isolate_page)(struct page___403 *, isolate_mode_t);
	void (*putback_page)(struct page___403 *);
	int (*launder_page)(struct page___403 *);
	int (*is_partially_uptodate)(struct page___403 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___403 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___402 *, struct page___403 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___402 *, sector_t *);
	void (*swap_deactivate)(struct file___402 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___159 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___196 *wb;
	struct inode___402 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___402 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___402 *bd_inode;
	struct super_block___402 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___402 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___196 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___402 {
	struct dentry___402 * (*lookup)(struct inode___402 *, struct dentry___402 *, unsigned int);
	const char * (*get_link)(struct dentry___402 *, struct inode___402 *, struct delayed_call *);
	int (*permission)(struct inode___402 *, int);
	struct posix_acl * (*get_acl)(struct inode___402 *, int);
	int (*readlink)(struct dentry___402 *, char *, int);
	int (*create)(struct inode___402 *, struct dentry___402 *, umode_t, bool);
	int (*link)(struct dentry___402 *, struct inode___402 *, struct dentry___402 *);
	int (*unlink)(struct inode___402 *, struct dentry___402 *);
	int (*symlink)(struct inode___402 *, struct dentry___402 *, const char *);
	int (*mkdir)(struct inode___402 *, struct dentry___402 *, umode_t);
	int (*rmdir)(struct inode___402 *, struct dentry___402 *);
	int (*mknod)(struct inode___402 *, struct dentry___402 *, umode_t, dev_t);
	int (*rename)(struct inode___402 *, struct dentry___402 *, struct inode___402 *, struct dentry___402 *, unsigned int);
	int (*setattr)(struct dentry___402 *, struct iattr___402 *);
	int (*getattr)(const struct path___403 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___402 *, char *, size_t);
	int (*fiemap)(struct inode___402 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___402 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___402 *, struct dentry___402 *, struct file___402 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___402 *, struct dentry___402 *, umode_t);
	int (*set_acl)(struct inode___402 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___402 {
	void (*fl_copy_lock)(struct file_lock___402 *, struct file_lock___402 *);
	void (*fl_release_private)(struct file_lock___402 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___402;

struct file_lock___402 {
	struct file_lock___402 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___402 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___402 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___402 *fl_ops;
	const struct lock_manager_operations___402 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___402 {
	int (*lm_compare_owner)(struct file_lock___402 *, struct file_lock___402 *);
	long unsigned int (*lm_owner_key)(struct file_lock___402 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___402 *);
	int (*lm_grant)(struct file_lock___402 *, int);
	bool (*lm_break)(struct file_lock___402 *);
	int (*lm_change)(struct file_lock___402 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___402 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___402 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___402 *fa_next;
	struct file___402 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___402 {
	const char *name;
	int fs_flags;
	struct dentry___402 * (*mount)(struct file_system_type___402 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___402 *);
	struct module___332 *owner;
	struct file_system_type___402 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___402 {
	struct inode___402 * (*alloc_inode)(struct super_block___402 *);
	void (*destroy_inode)(struct inode___402 *);
	void (*dirty_inode)(struct inode___402 *, int);
	int (*write_inode)(struct inode___402 *, struct writeback_control___159 *);
	int (*drop_inode)(struct inode___402 *);
	void (*evict_inode)(struct inode___402 *);
	void (*put_super)(struct super_block___402 *);
	int (*sync_fs)(struct super_block___402 *, int);
	int (*freeze_super)(struct super_block___402 *);
	int (*freeze_fs)(struct super_block___402 *);
	int (*thaw_super)(struct super_block___402 *);
	int (*unfreeze_fs)(struct super_block___402 *);
	int (*statfs)(struct dentry___402 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___402 *, int *, char *);
	void (*umount_begin)(struct super_block___402 *);
	int (*show_options)(struct seq_file___341 *, struct dentry___402 *);
	int (*show_devname)(struct seq_file___341 *, struct dentry___402 *);
	int (*show_path)(struct seq_file___341 *, struct dentry___402 *);
	int (*show_stats)(struct seq_file___341 *, struct dentry___402 *);
	ssize_t (*quota_read)(struct super_block___402 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___402 *, int, const char *, size_t, loff_t);
	struct dquot___402 ** (*get_dquots)(struct inode___402 *);
	int (*bdev_try_to_free_page)(struct super_block___402 *, struct page___403 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___402 *, struct shrink_control___139 *);
	long int (*free_cached_objects)(struct super_block___402 *, struct shrink_control___139 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___255)(struct file___402 *, wait_queue_head_t *, struct poll_table_struct___245 *);

struct poll_table_struct___245 {
	poll_queue_proc___255 _qproc;
	__poll_t _key;
};

struct seq_operations___341;

struct seq_file___341 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___341 *op;
	int poll_event;
	const struct file___402 *file;
	void *private;
};

typedef void bio_end_io_t___196(struct bio___196 *);

struct bio_integrity_payload___196;

struct bio_set___196;

struct bio___196 {
	struct bio___196 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___196 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___196 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___198 *bi_io_vec;
	struct bio_set___196 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___198 bi_inline_vecs[0];
};

struct socket_wq___32 {
	wait_queue_head_t wait;
	struct fasync_struct___402 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct sock___32;

struct proto_ops___32;

struct socket___33 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___32 *wq;
	struct file___402 *file;
	struct sock___32 *sk;
	const struct proto_ops___32 *ops;
};

typedef struct {
	struct net___59 *net;
} possible_net_t___49;

struct proto___31;

struct sock_common___31 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___31 *skc_prot;
	possible_net_t___49 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___32 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___49;

struct sk_buff_head___47 {
	struct sk_buff___49 *next;
	struct sk_buff___49 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___31;

struct xfrm_policy___2;

struct dst_entry___31;

struct net_device___49;

struct sock___32 {
	struct sock_common___31 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___47 sk_error_queue;
	struct sk_buff_head___47 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___49 *head;
		struct sk_buff___49 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___31 *sk_filter;
	union {
		struct socket_wq___32 *sk_wq;
		struct socket_wq___32 *sk_wq_raw;
	};
	struct xfrm_policy___2 *sk_policy[2];
	struct dst_entry___31 *sk_rx_dst;
	struct dst_entry___31 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___49 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___47 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___403 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___31 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___232 *sk_peer_pid;
	const struct cred___370 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___33 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___139 *sk_memcg;
	void (*sk_state_change)(struct sock___32 *);
	void (*sk_data_ready)(struct sock___32 *);
	void (*sk_write_space)(struct sock___32 *);
	void (*sk_error_report)(struct sock___32 *);
	int (*sk_backlog_rcv)(struct sock___32 *, struct sk_buff___49 *);
	struct sk_buff___49 * (*sk_validate_xmit_skb)(struct sock___32 *, struct net_device___49 *, struct sk_buff___49 *);
	void (*sk_destruct)(struct sock___32 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

typedef int (*sk_read_actor_t___31)(read_descriptor_t *, struct sk_buff___49 *, unsigned int, size_t);

struct proto_ops___32 {
	int family;
	struct module___332 *owner;
	int (*release)(struct socket___33 *);
	int (*bind)(struct socket___33 *, struct sockaddr *, int);
	int (*connect)(struct socket___33 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___33 *, struct socket___33 *);
	int (*accept)(struct socket___33 *, struct socket___33 *, int, bool);
	int (*getname)(struct socket___33 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___402 *, struct socket___33 *, struct poll_table_struct___245 *);
	int (*ioctl)(struct socket___33 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___33 *, int);
	int (*shutdown)(struct socket___33 *, int);
	int (*setsockopt)(struct socket___33 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___33 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___33 *, struct msghdr___34 *, size_t);
	int (*recvmsg)(struct socket___33 *, struct msghdr___34 *, size_t, int);
	int (*mmap)(struct file___402 *, struct socket___33 *, struct vm_area_struct___403 *);
	ssize_t (*sendpage)(struct socket___33 *, struct page___403 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___33 *, loff_t *, struct pipe_inode_info___83 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___32 *, int);
	int (*peek_len)(struct socket___33 *);
	int (*read_sock)(struct sock___32 *, read_descriptor_t *, sk_read_actor_t___31);
	int (*sendpage_locked)(struct sock___32 *, struct page___403 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___32 *, struct msghdr___34 *, size_t);
	int (*set_rcvlowat)(struct sock___32 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct sec_path___2;

struct nf_bridge_info___47;

struct sk_buff___49 {
	union {
		struct {
			struct sk_buff___49 *next;
			struct sk_buff___49 *prev;
			union {
				struct net_device___49 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___32 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___49 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path___2 *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___47 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___47;

struct netns_frags___47 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___47 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ip_ra_chain___14;

struct fib_rules_ops___31;

struct tcp_congestion_ops___3;

struct tcp_fastopen_context___3;

struct fib_notifier_ops___31;

struct netns_ipv4___47 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___14 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___31 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___32 *fibnl;
	struct sock___32 **icmp_sk;
	struct sock___32 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___32 **tcp_sk;
	struct netns_frags___47 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops___3 *tcp_congestion_control;
	struct tcp_fastopen_context___3 *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___31 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___31 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___31 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___31;

struct dst_ops___58 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___58 *);
	struct dst_entry___31 * (*check)(struct dst_entry___31 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___31 *);
	unsigned int (*mtu)(const struct dst_entry___31 *);
	u32 * (*cow_metrics)(struct dst_entry___31 *, long unsigned int);
	void (*destroy)(struct dst_entry___31 *);
	void (*ifdown)(struct dst_entry___31 *, struct net_device___49 *, int);
	struct dst_entry___31 * (*negative_advice)(struct dst_entry___31 *);
	void (*link_failure)(struct sk_buff___49 *);
	void (*update_pmtu)(struct dst_entry___31 *, struct sock___32 *, struct sk_buff___49 *, u32);
	void (*redirect)(struct dst_entry___31 *, struct sock___32 *, struct sk_buff___49 *);
	int (*local_out)(struct net___59 *, struct sock___32 *, struct sk_buff___49 *);
	struct neighbour___31 * (*neigh_lookup)(const struct dst_entry___31 *, struct sk_buff___49 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___31 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_info___2;

struct rt6_info___2;

struct fib6_table___2;

struct netns_ipv6___58 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___47 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info___2 *fib6_null_entry;
	struct rt6_info___2 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___2 *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___58 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info___2 *ip6_prohibit_entry;
	struct rt6_info___2 *ip6_blk_hole_entry;
	struct fib6_table___2 *fib6_local_tbl;
	struct fib_rules_ops___31 *fib6_rules_ops;
	struct sock___32 **icmp_sk;
	struct sock___32 *ndisc_sk;
	struct sock___32 *tcp_sk;
	struct sock___32 *igmp_sk;
	struct sock___32 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___31 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___31 *notifier_ops;
	struct fib_notifier_ops___31 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___32 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___32 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___47 {
	struct netns_frags___47 frags;
};

struct netns_xfrm___58 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___32 *nlsk;
	struct sock___32 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___58 xfrm4_dst_ops;
	struct dst_ops___58 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___41;

struct net___59 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___267 *user_ns;
	struct ucounts___267 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___9 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___32 *rtnl;
	struct sock___32 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___49 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___47 ipv4;
	struct netns_ipv6___58 ipv6;
	struct netns_sctp___32 sctp;
	struct netns_nf___3 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___47 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___32 *nfnl;
	struct sock___32 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___58 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___32 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___41 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kernfs_root___396;

struct kernfs_elem_dir___396 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___396 *root;
};

struct kernfs_syscall_ops___396;

struct kernfs_root___396 {
	struct kernfs_node___397 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___396 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___396 {
	struct kernfs_node___397 *target_kn;
};

struct kernfs_ops___396;

struct kernfs_elem_attr___396 {
	const struct kernfs_ops___396 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___397 *notify_next;
};

struct kernfs_node___397 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___397 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___396 dir;
		struct kernfs_elem_symlink___396 symlink;
		struct kernfs_elem_attr___396 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___396;

struct kernfs_ops___396 {
	int (*open)(struct kernfs_open_file___396 *);
	void (*release)(struct kernfs_open_file___396 *);
	int (*seq_show)(struct seq_file___341 *, void *);
	void * (*seq_start)(struct seq_file___341 *, loff_t *);
	void * (*seq_next)(struct seq_file___341 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___341 *, void *);
	ssize_t (*read)(struct kernfs_open_file___396 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___396 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___396 *, struct vm_area_struct___403 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___396 *, struct poll_table_struct___245 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___396 {
	int (*remount_fs)(struct kernfs_root___396 *, int *, char *);
	int (*show_options)(struct seq_file___341 *, struct kernfs_root___396 *);
	int (*mkdir)(struct kernfs_node___397 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___397 *);
	int (*rename)(struct kernfs_node___397 *, struct kernfs_node___397 *, const char *);
	int (*show_path)(struct seq_file___341 *, struct kernfs_node___397 *, struct kernfs_root___396 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___396 {
	struct kernfs_node___397 *kn;
	struct file___402 *file;
	struct seq_file___341 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___390 *vm_ops;
};

struct kobj_ns_type_operations___31 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___32 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___366;

struct attribute_group___367 {
	const char *name;
	umode_t (*is_visible)(struct kobject___390 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___390 *, struct bin_attribute___366 *, int);
	struct attribute **attrs;
	struct bin_attribute___366 **bin_attrs;
};

struct bin_attribute___366 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___402 *, struct kobject___390 *, struct bin_attribute___366 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___402 *, struct kobject___390 *, struct bin_attribute___366 *, char *, loff_t, size_t);
	int (*mmap)(struct file___402 *, struct kobject___390 *, struct bin_attribute___366 *, struct vm_area_struct___403 *);
};

struct sysfs_ops___389 {
	ssize_t (*show)(struct kobject___390 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___390 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___389;

struct kset___389 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___390 kobj;
	const struct kset_uevent_ops___389 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___389 {
	void (*release)(struct kobject___390 *);
	const struct sysfs_ops___389 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___31 * (*child_ns_type)(struct kobject___390 *);
	const void * (*namespace)(struct kobject___390 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___389 {
	int (* const filter)(struct kset___389 *, struct kobject___390 *);
	const char * (* const name)(struct kset___389 *, struct kobject___390 *);
	int (* const uevent)(struct kset___389 *, struct kobject___390 *, struct kobj_uevent_env *);
};

struct kobj_attribute___380 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___390 *, struct kobj_attribute___380 *, char *);
	ssize_t (*store)(struct kobject___390 *, struct kobj_attribute___380 *, const char *, size_t);
};

struct dev_pm_ops___370 {
	int (*prepare)(struct device___370 *);
	void (*complete)(struct device___370 *);
	int (*suspend)(struct device___370 *);
	int (*resume)(struct device___370 *);
	int (*freeze)(struct device___370 *);
	int (*thaw)(struct device___370 *);
	int (*poweroff)(struct device___370 *);
	int (*restore)(struct device___370 *);
	int (*suspend_late)(struct device___370 *);
	int (*resume_early)(struct device___370 *);
	int (*freeze_late)(struct device___370 *);
	int (*thaw_early)(struct device___370 *);
	int (*poweroff_late)(struct device___370 *);
	int (*restore_early)(struct device___370 *);
	int (*suspend_noirq)(struct device___370 *);
	int (*resume_noirq)(struct device___370 *);
	int (*freeze_noirq)(struct device___370 *);
	int (*thaw_noirq)(struct device___370 *);
	int (*poweroff_noirq)(struct device___370 *);
	int (*restore_noirq)(struct device___370 *);
	int (*runtime_suspend)(struct device___370 *);
	int (*runtime_resume)(struct device___370 *);
	int (*runtime_idle)(struct device___370 *);
};

struct dev_pm_info___370 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___370 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___370;

struct bus_type___370;

struct device_driver___370;

struct dev_pm_domain___370;

struct dma_map_ops___142;

struct fwnode_handle___290;

struct class___370;

struct device___370 {
	struct device___370 *parent;
	struct device_private *p;
	struct kobject___390 kobj;
	const char *init_name;
	const struct device_type___370 *type;
	struct mutex mutex;
	struct bus_type___370 *bus;
	struct device_driver___370 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___370 power;
	struct dev_pm_domain___370 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___142 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___290 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___370 *class;
	const struct attribute_group___367 **groups;
	void (*release)(struct device___370 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___370 {
	struct dev_pm_ops___370 ops;
	void (*detach)(struct device___370 *, bool);
	int (*activate)(struct device___370 *);
	void (*sync)(struct device___370 *);
	void (*dismiss)(struct device___370 *);
};

struct bus_type___370 {
	const char *name;
	const char *dev_name;
	struct device___370 *dev_root;
	const struct attribute_group___367 **bus_groups;
	const struct attribute_group___367 **dev_groups;
	const struct attribute_group___367 **drv_groups;
	int (*match)(struct device___370 *, struct device_driver___370 *);
	int (*uevent)(struct device___370 *, struct kobj_uevent_env *);
	int (*probe)(struct device___370 *);
	int (*remove)(struct device___370 *);
	void (*shutdown)(struct device___370 *);
	int (*online)(struct device___370 *);
	int (*offline)(struct device___370 *);
	int (*suspend)(struct device___370 *, pm_message_t);
	int (*resume)(struct device___370 *);
	int (*num_vf)(struct device___370 *);
	int (*dma_configure)(struct device___370 *);
	const struct dev_pm_ops___370 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___370 {
	const char *name;
	struct bus_type___370 *bus;
	struct module___332 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___370 *);
	int (*remove)(struct device___370 *);
	void (*shutdown)(struct device___370 *);
	int (*suspend)(struct device___370 *, pm_message_t);
	int (*resume)(struct device___370 *);
	const struct attribute_group___367 **groups;
	const struct dev_pm_ops___370 *pm;
	void (*coredump)(struct device___370 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___370 {
	const char *name;
	const struct attribute_group___367 **groups;
	int (*uevent)(struct device___370 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___370 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___370 *);
	const struct dev_pm_ops___370 *pm;
};

struct class___370 {
	const char *name;
	struct module___332 *owner;
	const struct attribute_group___367 **class_groups;
	const struct attribute_group___367 **dev_groups;
	struct kobject___390 *dev_kobj;
	int (*dev_uevent)(struct device___370 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___370 *, umode_t *);
	void (*class_release)(struct class___370 *);
	void (*dev_release)(struct device___370 *);
	int (*shutdown_pre)(struct device___370 *);
	const struct kobj_ns_type_operations___31 *ns_type;
	const void * (*namespace)(struct device___370 *);
	const struct dev_pm_ops___370 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___142 {
	void * (*alloc)(struct device___370 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___370 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___370 *, struct vm_area_struct___403 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___370 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___370 *, struct page___403 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___370 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___370 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___370 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___370 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___370 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___370 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___370 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___370 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___370 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___370 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___370 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___370 *, u64);
	u64 (*get_required_mask)(struct device___370 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___290;

struct fwnode_handle___290 {
	struct fwnode_handle___290 *secondary;
	const struct fwnode_operations___290 *ops;
};

typedef void compound_page_dtor___390(struct page___403 *);

struct fwnode_reference_args___290;

struct fwnode_endpoint___290;

struct fwnode_operations___290 {
	struct fwnode_handle___290 * (*get)(struct fwnode_handle___290 *);
	void (*put)(struct fwnode_handle___290 *);
	bool (*device_is_available)(const struct fwnode_handle___290 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___290 *, const struct device___370 *);
	bool (*property_present)(const struct fwnode_handle___290 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___290 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___290 *, const char *, const char **, size_t);
	struct fwnode_handle___290 * (*get_parent)(const struct fwnode_handle___290 *);
	struct fwnode_handle___290 * (*get_next_child_node)(const struct fwnode_handle___290 *, struct fwnode_handle___290 *);
	struct fwnode_handle___290 * (*get_named_child_node)(const struct fwnode_handle___290 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___290 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___290 *);
	struct fwnode_handle___290 * (*graph_get_next_endpoint)(const struct fwnode_handle___290 *, struct fwnode_handle___290 *);
	struct fwnode_handle___290 * (*graph_get_remote_endpoint)(const struct fwnode_handle___290 *);
	struct fwnode_handle___290 * (*graph_get_port_parent)(struct fwnode_handle___290 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___290 *, struct fwnode_endpoint___290 *);
};

struct fwnode_endpoint___290 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___290 *local_fwnode;
};

struct fwnode_reference_args___290 {
	struct fwnode_handle___290 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___83;

struct pipe_buffer___83 {
	struct page___403 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___83 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___83 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___83 *, struct pipe_buffer___83 *);
	void (*release)(struct pipe_inode_info___83 *, struct pipe_buffer___83 *);
	int (*steal)(struct pipe_inode_info___83 *, struct pipe_buffer___83 *);
	union {
		bool (*get)(struct pipe_inode_info___83 *, struct pipe_buffer___83 *);
		struct {
			void (*get)(struct pipe_inode_info___83 *, struct pipe_buffer___83 *);
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
};

struct nf_bridge_info___47 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___47 = 0,
		BRNF_PROTO_8021Q___47 = 1,
		BRNF_PROTO_PPPOE___47 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___49 *physindev;
	struct net_device___49 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___47(struct sk_buff___49 **);

struct net_device_ops___47;

struct ethtool_ops___47;

struct l3mdev_ops___31;

struct ndisc_ops___17;

struct xfrmdev_ops___47;

struct tlsdev_ops___47;

struct header_ops___47;

struct inet6_dev___17;

struct netdev_rx_queue___47;

struct mini_Qdisc___41;

struct netdev_queue___47;

struct Qdisc___41;

struct rtnl_link_ops___41;

struct dcbnl_rtnl_ops___47;

struct net_device___49 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___47 *netdev_ops;
	const struct ethtool_ops___47 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___31 *l3mdev_ops;
	const struct ndisc_ops___17 *ndisc_ops;
	const struct xfrmdev_ops___47 *xfrmdev_ops;
	const struct tlsdev_ops___47 *tlsdev_ops;
	const struct header_ops___47 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___389 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___17 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___47 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___41 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___47 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___41 *miniq_ingress;
	struct netdev_queue___47 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___47 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___41 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___41 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___47 = 0,
		NETREG_REGISTERED___47 = 1,
		NETREG_UNREGISTERING___47 = 2,
		NETREG_UNREGISTERED___47 = 3,
		NETREG_RELEASED___47 = 4,
		NETREG_DUMMY___47 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___47 = 0,
		RTNL_LINK_INITIALIZING___47 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___49 *);
	struct netpoll_info *npinfo;
	possible_net_t___49 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___370 dev;
	const struct attribute_group___367 *sysfs_groups[4];
	const struct attribute_group___367 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___41 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___47 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct skb_frag_struct___4 {
	struct {
		struct page___403 *p;
	} page;
	__u32 page_offset;
	__u32 size;
};

typedef struct skb_frag_struct___4 skb_frag_t___4;

struct skb_shared_info___4 {
	__u8 __unused;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___49 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___4 frags[16];
};

enum {
	SKB_GSO_TCPV4 = 1,
	SKB_GSO_DODGY = 2,
	SKB_GSO_TCP_ECN = 4,
	SKB_GSO_TCP_FIXEDID = 8,
	SKB_GSO_TCPV6 = 16,
	SKB_GSO_FCOE = 32,
	SKB_GSO_GRE = 64,
	SKB_GSO_GRE_CSUM = 128,
	SKB_GSO_IPXIP4 = 256,
	SKB_GSO_IPXIP6 = 512,
	SKB_GSO_UDP_TUNNEL = 1024,
	SKB_GSO_UDP_TUNNEL_CSUM = 2048,
	SKB_GSO_PARTIAL = 4096,
	SKB_GSO_TUNNEL_REMCSUM = 8192,
	SKB_GSO_SCTP = 16384,
	SKB_GSO_ESP = 32768,
	SKB_GSO_UDP = 65536,
	SKB_GSO_UDP_L4 = 131072,
};

struct xfrm_state___2;

struct sec_path___2 {
	refcount_t refcnt;
	int len;
	int olen;
	struct xfrm_state___2 *xvec[6];
	struct xfrm_offload ovec[1];
};

struct ethtool_ops___47 {
	int (*get_settings)(struct net_device___49 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___49 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___49 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___49 *);
	void (*get_regs)(struct net_device___49 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___49 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___49 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___49 *);
	void (*set_msglevel)(struct net_device___49 *, u32);
	int (*nway_reset)(struct net_device___49 *);
	u32 (*get_link)(struct net_device___49 *);
	int (*get_eeprom_len)(struct net_device___49 *);
	int (*get_eeprom)(struct net_device___49 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___49 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___49 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___49 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___49 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___49 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___49 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___49 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___49 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___49 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___49 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___49 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___49 *);
	void (*complete)(struct net_device___49 *);
	u32 (*get_priv_flags)(struct net_device___49 *);
	int (*set_priv_flags)(struct net_device___49 *, u32);
	int (*get_sset_count)(struct net_device___49 *, int);
	int (*get_rxnfc)(struct net_device___49 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___49 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___49 *, struct ethtool_flash *);
	int (*reset)(struct net_device___49 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___49 *);
	u32 (*get_rxfh_indir_size)(struct net_device___49 *);
	int (*get_rxfh)(struct net_device___49 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___49 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___49 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___49 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___49 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___49 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___49 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___49 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___49 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___49 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___49 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___49 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___49 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___49 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___49 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___49 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___49 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___49 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___49 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___49 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___49 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___49 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	int (*get_fecparam)(struct net_device___49 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___49 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___49 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___49 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___49 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct prot_inuse {
	int val[64];
};

struct inet_frag_queue___47;

struct inet_frags___47 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___47 *, const void *);
	void (*destructor)(struct inet_frag_queue___47 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___47 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___49 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___49 *fragments_tail;
	struct sk_buff___49 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___47 *net;
	struct callback_head rcu;
};

struct ip_ra_chain___14 {
	struct ip_ra_chain___14 *next;
	struct sock___32 *sk;
	union {
		void (*destructor)(struct sock___32 *);
		struct sock___32 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___31;

struct fib_lookup_arg___31;

struct fib_rules_ops___31 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___31 *, struct flowi *, int, struct fib_lookup_arg___31 *);
	bool (*suppress)(struct fib_rule___31 *, struct fib_lookup_arg___31 *);
	int (*match)(struct fib_rule___31 *, struct flowi *, int);
	int (*configure)(struct fib_rule___31 *, struct sk_buff___49 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___31 *);
	int (*compare)(struct fib_rule___31 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___31 *, struct sk_buff___49 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___31 *);
	void (*flush_cache)(struct fib_rules_ops___31 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___332 *owner;
	struct net___59 *fro_net;
	struct callback_head rcu;
};

struct tcp_congestion_ops___3 {
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___32 *);
	void (*release)(struct sock___32 *);
	u32 (*ssthresh)(struct sock___32 *);
	void (*cong_avoid)(struct sock___32 *, u32, u32);
	void (*set_state)(struct sock___32 *, u8);
	void (*cwnd_event)(struct sock___32 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___32 *, u32);
	u32 (*undo_cwnd)(struct sock___32 *);
	void (*pkts_acked)(struct sock___32 *, const struct ack_sample *);
	u32 (*min_tso_segs)(struct sock___32 *);
	u32 (*sndbuf_expand)(struct sock___32 *);
	void (*cong_control)(struct sock___32 *, const struct rate_sample *);
	size_t (*get_info)(struct sock___32 *, u32, int *, union tcp_cc_info *);
	char name[16];
	struct module___332 *owner;
};

struct tcp_fastopen_context___3 {
	struct crypto_cipher___5 *tfm;
	__u8 key[16];
	struct callback_head rcu;
};

struct fib_notifier_ops___31 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___59 *);
	int (*fib_dump)(struct net___59 *, struct notifier_block *);
	struct module___332 *owner;
	struct callback_head rcu;
};

struct dst_entry___31 {
	struct net_device___49 *dev;
	struct dst_ops___58 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state___2 *xfrm;
	int (*input)(struct sk_buff___49 *);
	int (*output)(struct net___59 *, struct sock___32 *, struct sk_buff___49 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___31;

struct neigh_parms___31;

struct neigh_ops___31;

struct neighbour___31 {
	struct neighbour___31 *next;
	struct neigh_table___31 *tbl;
	struct neigh_parms___31 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___47 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___31 *, struct sk_buff___49 *);
	const struct neigh_ops___31 *ops;
	struct callback_head rcu;
	struct net_device___49 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct fib6_nh___2 {
	struct in6_addr nh_gw;
	struct net_device___49 *nh_dev;
	struct lwtunnel_state *nh_lwtstate;
	unsigned int nh_flags;
	atomic_t nh_upper_bound;
	int nh_weight;
};

struct fib6_node___2;

struct fib6_info___2 {
	struct fib6_table___2 *fib6_table;
	struct fib6_info___2 *fib6_next;
	struct fib6_node___2 *fib6_node;
	struct list_head fib6_siblings;
	unsigned int fib6_nsiblings;
	atomic_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	struct rt6_info___2 **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
	long unsigned int last_probe;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 exception_bucket_flushed: 1;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 dst_host: 1;
	u8 fib6_destroying: 1;
	u8 unused: 2;
	struct fib6_nh___2 fib6_nh;
	struct callback_head rcu;
};

struct rt6_info___2 {
	struct dst_entry___31 dst;
	struct fib6_info___2 *from;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___17 *rt6i_idev;
	u32 rt6i_flags;
	struct rt6key rt6i_prefsrc;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct fib6_node___2 {
	struct fib6_node___2 *parent;
	struct fib6_node___2 *left;
	struct fib6_node___2 *right;
	struct fib6_info___2 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info___2 *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table___2 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node___2 tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

struct ucounts___267 {
	struct hlist_node node;
	struct user_namespace___267 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_prog_aux___44;

struct bpf_prog___41 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___44 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

typedef int (*key_restrict_link_func_t___371)(struct key___370 *, const struct key_type *, const union key_payload *, struct key___370 *);

struct key_restriction___370;

struct key___370 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___404 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___370 *restrict_link;
};

struct key_restriction___370 {
	key_restrict_link_func_t___371 check;
	struct key___370 *key;
	struct key_type *keytype;
};

struct seq_operations___341 {
	void * (*start)(struct seq_file___341 *, loff_t *);
	void (*stop)(struct seq_file___341 *, void *);
	void * (*next)(struct seq_file___341 *, void *, loff_t *);
	int (*show)(struct seq_file___341 *, void *);
};

struct seq_net_private___2 {
	struct net___59 *net;
};

struct pernet_operations___48 {
	struct list_head list;
	int (*init)(struct net___59 *);
	void (*exit)(struct net___59 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___47 {
	int (*ieee_getets)(struct net_device___49 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___49 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___49 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___49 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___49 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___49 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___49 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___49 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___49 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___49 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___49 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___49 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___49 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___49 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___49 *);
	u8 (*setstate)(struct net_device___49 *, u8);
	void (*getpermhwaddr)(struct net_device___49 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___49 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___49 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___49 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___49 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___49 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___49 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___49 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___49 *, int, u8 *);
	void (*setpfccfg)(struct net_device___49 *, int, u8);
	void (*getpfccfg)(struct net_device___49 *, int, u8 *);
	u8 (*setall)(struct net_device___49 *);
	u8 (*getcap)(struct net_device___49 *, int, u8 *);
	int (*getnumtcs)(struct net_device___49 *, int, u8 *);
	int (*setnumtcs)(struct net_device___49 *, int, u8);
	u8 (*getpfcstate)(struct net_device___49 *);
	void (*setpfcstate)(struct net_device___49 *, u8);
	void (*getbcncfg)(struct net_device___49 *, int, u32 *);
	void (*setbcncfg)(struct net_device___49 *, int, u32);
	void (*getbcnrp)(struct net_device___49 *, int, u8 *);
	void (*setbcnrp)(struct net_device___49 *, int, u8);
	int (*setapp)(struct net_device___49 *, u8, u16, u8);
	int (*getapp)(struct net_device___49 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___49 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___49 *, int, u8);
	u8 (*getdcbx)(struct net_device___49 *);
	u8 (*setdcbx)(struct net_device___49 *, u8);
	int (*peer_getappinfo)(struct net_device___49 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___49 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___49 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___49 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___49 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___49 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___251 {
	refcount_t count;
	struct ns_common___9 ns;
	struct user_namespace___267 *user_ns;
	struct ucounts___267 *ucounts;
	struct css_set___251 *root_cset;
};

struct bpf_map___252;

struct bpf_map_ops___251 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___252 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___252 *, struct file___402 *);
	void (*map_free)(struct bpf_map___252 *);
	int (*map_get_next_key)(struct bpf_map___252 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___252 *);
	void * (*map_lookup_elem)(struct bpf_map___252 *, void *);
	int (*map_update_elem)(struct bpf_map___252 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___252 *, void *);
	int (*map_push_elem)(struct bpf_map___252 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___252 *, void *);
	int (*map_peek_elem)(struct bpf_map___252 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___252 *, struct file___402 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___252 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___252 *, void *, struct seq_file___341 *);
	int (*map_check_btf)(const struct bpf_map___252 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___252 {
	const struct bpf_map_ops___251 *ops;
	struct bpf_map___252 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___370 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___47;

struct bpf_map_dev_ops___47 {
	int (*map_get_next_key)(struct bpf_offloaded_map___47 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___47 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___47 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___47 *, void *);
};

struct bpf_offloaded_map___47 {
	struct bpf_map___252 map;
	struct net_device___49 *netdev;
	const struct bpf_map_dev_ops___47 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___41 {
	int (*test_run)(struct bpf_prog___41 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___41 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___41 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___41 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___41 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___41 *, u32 *);
};

struct bpf_prog_offload_ops___41 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___41 *);
	int (*translate)(struct bpf_prog___41 *);
	void (*destroy)(struct bpf_prog___41 *);
};

struct bpf_prog_offload___41 {
	struct bpf_prog___41 *prog;
	struct net_device___49 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___41 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___44 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___41 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___41 *ops;
	struct bpf_map___252 **used_maps;
	struct bpf_prog___41 *prog;
	struct user_struct___370 *user;
	u64 load_time;
	struct bpf_map___252 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___41 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___41 {
	struct bpf_prog___41 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___41 {
	struct callback_head rcu;
	struct bpf_prog_array_item___41 items[0];
};

struct cgroup_bpf___41 {
	struct bpf_prog_array___41 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___41 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___252;

typedef void (*kthread_work_func_t___252)(struct kthread_work___252 *);

struct kthread_worker___252;

struct kthread_work___252 {
	struct list_head node;
	kthread_work_func_t___252 func;
	struct kthread_worker___252 *worker;
	int canceling;
};

struct kthread_worker___252 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___404 *task;
	struct kthread_work___252 *current_work;
};

struct kthread_delayed_work___251 {
	struct kthread_work___252 work;
	struct timer_list timer;
};

struct psi_group___251 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___252 *poll_kworker;
	struct kthread_delayed_work___251 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___251;

struct cgroup_rstat_cpu___251;

struct cgroup___251 {
	struct cgroup_subsys_state___251 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___397 *kn;
	struct cgroup_file___251 procs_file;
	struct cgroup_file___251 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___251 *subsys[13];
	struct cgroup_root___251 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___251 *dom_cgrp;
	struct cgroup_rstat_cpu___251 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___41 bpf;
	atomic_t congestion_count;
	struct cgroup___251 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___251 psi;
	int ancestor_ids[0];
};

struct cftype___251;

struct cgroup_subsys___251 {
	struct cgroup_subsys_state___251 * (*css_alloc)(struct cgroup_subsys_state___251 *);
	int (*css_online)(struct cgroup_subsys_state___251 *);
	void (*css_offline)(struct cgroup_subsys_state___251 *);
	void (*css_released)(struct cgroup_subsys_state___251 *);
	void (*css_free)(struct cgroup_subsys_state___251 *);
	void (*css_reset)(struct cgroup_subsys_state___251 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___251 *, int);
	int (*css_extra_stat_show)(struct seq_file___341 *, struct cgroup_subsys_state___251 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___404 *);
	void (*cancel_fork)(struct task_struct___404 *);
	void (*fork)(struct task_struct___404 *);
	void (*exit)(struct task_struct___404 *);
	void (*free)(struct task_struct___404 *);
	void (*bind)(struct cgroup_subsys_state___251 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___251 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___251 *dfl_cftypes;
	struct cftype___251 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___251 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___251 *updated_children;
	struct cgroup___251 *updated_next;
};

struct cgroup_root___251 {
	struct kernfs_root___396 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___251 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___251 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___251 *ss;
	struct list_head node;
	struct kernfs_ops___396 *kf_ops;
	int (*open)(struct kernfs_open_file___396 *);
	void (*release)(struct kernfs_open_file___396 *);
	u64 (*read_u64)(struct cgroup_subsys_state___251 *, struct cftype___251 *);
	s64 (*read_s64)(struct cgroup_subsys_state___251 *, struct cftype___251 *);
	int (*seq_show)(struct seq_file___341 *, void *);
	void * (*seq_start)(struct seq_file___341 *, loff_t *);
	void * (*seq_next)(struct seq_file___341 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___341 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___251 *, struct cftype___251 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___251 *, struct cftype___251 *, s64);
	ssize_t (*write)(struct kernfs_open_file___396 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___396 *, struct poll_table_struct___245 *);
};

struct xdp_rxq_info___47 {
	struct net_device___49 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___47 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___49 *dev_rx;
};

struct netlink_callback___49 {
	struct sk_buff___49 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___49 *);
	int (*dump)(struct sk_buff___49 *, struct netlink_callback___49 *);
	int (*done)(struct netlink_callback___49 *);
	void *data;
	struct module___332 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___47 {
	int (*create)(struct sk_buff___49 *, struct net_device___49 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___49 *, unsigned char *);
	int (*cache)(const struct neighbour___31 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___49 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___47 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___47 *, int);
	int poll_owner;
	struct net_device___49 *dev;
	struct sk_buff___49 *gro_list;
	struct sk_buff___49 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___47 {
	struct net_device___49 *dev;
	struct Qdisc___41 *qdisc;
	struct Qdisc___41 *qdisc_sleeping;
	struct kobject___390 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___49 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___41 {
	struct sk_buff___49 *head;
	struct sk_buff___49 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___41;

struct Qdisc___41 {
	int (*enqueue)(struct sk_buff___49 *, struct Qdisc___41 *, struct sk_buff___49 **);
	struct sk_buff___49 * (*dequeue)(struct Qdisc___41 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___41 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___47 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___47 gso_skb;
	struct qdisc_skb_head___41 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___41 *next_sched;
	struct sk_buff_head___47 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___47 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___390 kobj;
	struct net_device___49 *dev;
	long: 64;
	struct xdp_rxq_info___47 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___47)(struct net_device___49 *, struct sk_buff___49 *, struct net_device___49 *);

struct netdev_bpf___47 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___41 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___41 *prog;
			const struct bpf_prog_offload_ops___41 *ops;
		} verifier;
		struct {
			struct bpf_prog___41 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___47 *offmap;
		};
		struct {
			struct xdp_umem *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___47 {
	int (*xdo_dev_state_add)(struct xfrm_state___2 *);
	void (*xdo_dev_state_delete)(struct xfrm_state___2 *);
	void (*xdo_dev_state_free)(struct xfrm_state___2 *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___49 *, struct xfrm_state___2 *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state___2 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct xfrm_state_offload___2 {
	struct net_device___49 *dev;
	long unsigned int offload_handle;
	unsigned int num_exthdrs;
	u8 flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct xfrm_replay___2;

struct xfrm_type___2;

struct xfrm_mode___2;

struct xfrm_type_offload___2;

struct xfrm_state___2 {
	possible_net_t___49 xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	refcount_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
		u32 output_mark;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	const char *geniv;
	struct xfrm_encap_tmpl *encap;
	xfrm_address_t *coaddr;
	struct xfrm_state___2 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	const struct xfrm_replay___2 *repl;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct tasklet_hrtimer mtimer;
	struct xfrm_state_offload___2 xso;
	long int saved_tmo;
	long unsigned int lastused;
	struct page_frag___403 xfrag;
	const struct xfrm_type___2 *type;
	struct xfrm_mode___2 *inner_mode;
	struct xfrm_mode___2 *inner_mode_iaf;
	struct xfrm_mode___2 *outer_mode;
	const struct xfrm_type_offload___2 *type_offload;
	struct xfrm_sec_ctx___2 *security;
	void *data;
	u32 output_mark_mask;
	u32 if_id;
};

struct tlsdev_ops___47 {
	int (*tls_dev_add)(struct net_device___49 *, struct sock___32 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___49 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___49 *, struct sock___32 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___47 {
	int (*ndo_init)(struct net_device___49 *);
	void (*ndo_uninit)(struct net_device___49 *);
	int (*ndo_open)(struct net_device___49 *);
	int (*ndo_stop)(struct net_device___49 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___49 *, struct net_device___49 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___49 *, struct net_device___49 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___49 *, struct sk_buff___49 *, struct net_device___49 *, select_queue_fallback_t___47);
	void (*ndo_change_rx_flags)(struct net_device___49 *, int);
	void (*ndo_set_rx_mode)(struct net_device___49 *);
	int (*ndo_set_mac_address)(struct net_device___49 *, void *);
	int (*ndo_validate_addr)(struct net_device___49 *);
	int (*ndo_do_ioctl)(struct net_device___49 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___49 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___49 *, int);
	int (*ndo_neigh_setup)(struct net_device___49 *, struct neigh_parms___31 *);
	void (*ndo_tx_timeout)(struct net_device___49 *);
	void (*ndo_get_stats64)(struct net_device___49 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___49 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___49 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___49 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___49 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___49 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___49 *);
	int (*ndo_netpoll_setup)(struct net_device___49 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___49 *);
	int (*ndo_set_vf_mac)(struct net_device___49 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___49 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___49 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___49 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___49 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___49 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___49 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___49 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___49 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___49 *, int, struct sk_buff___49 *);
	int (*ndo_set_vf_guid)(struct net_device___49 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___49 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___49 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___49 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___49 *, const struct sk_buff___49 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___49 *, struct net_device___49 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___49 *, struct net_device___49 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___49 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___49 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___49 *, struct neighbour___31 *);
	void (*ndo_neigh_destroy)(struct net_device___49 *, struct neighbour___31 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___49 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___49 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___49 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___49 *, struct netlink_callback___49 *, struct net_device___49 *, struct net_device___49 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___49 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___49 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___49 *, u32, u32, struct net_device___49 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___49 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___49 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___49 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___49 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___49 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___49 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___49 *, struct net_device___49 *);
	void (*ndo_dfwd_del_station)(struct net_device___49 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___49 *);
	int (*ndo_set_tx_maxrate)(struct net_device___49 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___49 *);
	int (*ndo_change_proto_down)(struct net_device___49 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___49 *, struct sk_buff___49 *);
	void (*ndo_set_rx_headroom)(struct net_device___49 *, int);
	int (*ndo_bpf)(struct net_device___49 *, struct netdev_bpf___47 *);
	int (*ndo_xdp_xmit)(struct net_device___49 *, int, struct xdp_frame___47 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___49 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___49 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___31 {
	possible_net_t___49 net;
	struct net_device___49 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___31 *);
	void (*neigh_cleanup)(struct neighbour___31 *);
	struct neigh_table___31 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___31 {
	u32 (*l3mdev_fib_table)(const struct net_device___49 *);
	struct sk_buff___49 * (*l3mdev_l3_rcv)(struct net_device___49 *, struct sk_buff___49 *, u16);
	struct sk_buff___49 * (*l3mdev_l3_out)(struct net_device___49 *, struct sock___32 *, struct sk_buff___49 *, u16);
	struct dst_entry___31 * (*l3mdev_link_scope_lookup)(const struct net_device___49 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct ndisc_ops___17 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___49 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___49 *, struct neighbour___31 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___49 *, u8, struct neighbour___31 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___49 *, struct sk_buff___49 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___59 *, struct net_device___49 *, const struct prefix_info *, struct inet6_dev___17 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___17;

struct ifacaddr6___2;

struct inet6_dev___17 {
	struct net_device___49 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___17 *mc_list;
	struct ifmcaddr6___17 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___2 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	u8 rndid[8];
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___31 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
};

struct tcf_proto___41;

struct mini_Qdisc___41 {
	struct tcf_proto___41 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___41 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___49 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___59 *, struct net_device___49 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___49 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___49 *, struct list_head *);
	size_t (*get_size)(const struct net_device___49 *);
	int (*fill_info)(struct sk_buff___49 *, const struct net_device___49 *);
	size_t (*get_xstats_size)(const struct net_device___49 *);
	int (*fill_xstats)(struct sk_buff___49 *, const struct net_device___49 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___49 *, struct net_device___49 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___49 *, const struct net_device___49 *);
	int (*fill_slave_info)(struct sk_buff___49 *, const struct net_device___49 *, const struct net_device___49 *);
	struct net___59 * (*get_link_net)(const struct net_device___49 *);
	size_t (*get_linkxstats_size)(const struct net_device___49 *, int);
	int (*fill_linkxstats)(struct sk_buff___49 *, const struct net_device___49 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct offload_callbacks {
	struct sk_buff___49 * (*gso_segment)(struct sk_buff___49 *, netdev_features_t);
	struct sk_buff___49 ** (*gro_receive)(struct sk_buff___49 **, struct sk_buff___49 *);
	int (*gro_complete)(struct sk_buff___49 *, int);
};

struct softnet_data___47 {
	struct list_head poll_list;
	struct sk_buff_head___47 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___47 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___41 *output_queue;
	struct Qdisc___41 **output_queue_tailp;
	struct sk_buff___49 *completion_queue;
	struct sk_buff_head___47 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___47 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___47 input_pkt_queue;
	struct napi_struct___47 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bdi_writeback_congested___196 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___196 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___196 {
	struct bio___196 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___198 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___198 bip_inline_vecs[0];
};

struct bio_set___196 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___196 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___139 {
	struct mem_cgroup___139 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___139 {
	struct lruvec___403 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___139 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___139 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct kernel_param_ops___330 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___330 *);
	int (*get)(char *, const struct kernel_param___330 *);
	void (*free)(void *);
};

struct kparam_array___330;

struct kernel_param___330 {
	const char *name;
	struct module___332 *mod;
	const struct kernel_param_ops___330 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___330 *arr;
	};
};

struct kparam_array___330 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___330 *ops;
	void *elem;
};

struct module_attribute___330 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___330 *, struct module_kobject___330 *, char *);
	ssize_t (*store)(struct module_attribute___330 *, struct module_kobject___330 *, const char *, size_t);
	void (*setup)(struct module___332 *, const char *);
	int (*test)(struct module___332 *);
	void (*free)(struct module___332 *);
};

struct gnet_dump___41 {
	spinlock_t *lock;
	struct sk_buff___49 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___41;

struct Qdisc_ops___41 {
	struct Qdisc_ops___41 *next;
	const struct Qdisc_class_ops___41 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___49 *, struct Qdisc___41 *, struct sk_buff___49 **);
	struct sk_buff___49 * (*dequeue)(struct Qdisc___41 *);
	struct sk_buff___49 * (*peek)(struct Qdisc___41 *);
	int (*init)(struct Qdisc___41 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___41 *);
	void (*destroy)(struct Qdisc___41 *);
	int (*change)(struct Qdisc___41 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___41 *);
	int (*change_tx_queue_len)(struct Qdisc___41 *, unsigned int);
	int (*dump)(struct Qdisc___41 *, struct sk_buff___49 *);
	int (*dump_stats)(struct Qdisc___41 *, struct gnet_dump___41 *);
	void (*ingress_block_set)(struct Qdisc___41 *, u32);
	void (*egress_block_set)(struct Qdisc___41 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___41 *);
	u32 (*egress_block_get)(struct Qdisc___41 *);
	struct module___332 *owner;
};

struct tcf_block___41;

struct Qdisc_class_ops___41 {
	unsigned int flags;
	struct netdev_queue___47 * (*select_queue)(struct Qdisc___41 *, struct tcmsg *);
	int (*graft)(struct Qdisc___41 *, long unsigned int, struct Qdisc___41 *, struct Qdisc___41 **, struct netlink_ext_ack *);
	struct Qdisc___41 * (*leaf)(struct Qdisc___41 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___41 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___41 *, u32);
	int (*change)(struct Qdisc___41 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___41 *, long unsigned int);
	void (*walk)(struct Qdisc___41 *, struct qdisc_walker *);
	struct tcf_block___41 * (*tcf_block)(struct Qdisc___41 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___41 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___41 *, long unsigned int);
	int (*dump)(struct Qdisc___41 *, long unsigned int, struct sk_buff___49 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___41 *, long unsigned int, struct gnet_dump___41 *);
};

struct tcf_chain___41;

struct tcf_block___41 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___59 *net;
	struct Qdisc___41 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___41 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___41;

struct tcf_proto_ops___41;

struct tcf_proto___41 {
	struct tcf_proto___41 *next;
	void *root;
	int (*classify)(struct sk_buff___49 *, const struct tcf_proto___41 *, struct tcf_result___41 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___41 *ops;
	struct tcf_chain___41 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___41 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___41 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___41 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___49 *, const struct tcf_proto___41 *, struct tcf_result___41 *);
	int (*init)(struct tcf_proto___41 *);
	void (*destroy)(struct tcf_proto___41 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___41 *, u32);
	void (*put)(struct tcf_proto___41 *, void *);
	int (*change)(struct net___59 *, struct sk_buff___49 *, struct tcf_proto___41 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___41 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___41 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___41 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___59 *, struct tcf_chain___41 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___59 *, struct tcf_proto___41 *, void *, struct sk_buff___49 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___49 *, struct net___59 *, void *);
	struct module___332 *owner;
	int flags;
};

struct tcf_chain___41 {
	struct mutex filter_chain_lock;
	struct tcf_proto___41 *filter_chain;
	struct list_head list;
	struct tcf_block___41 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___41 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___31 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___41 *prog;
};

struct bpf_redirect_info___41 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___252 *map;
	struct bpf_map___252 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___31;

struct neigh_hash_table___31;

struct neigh_table___31 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___49 *, __u32 *);
	bool (*key_eq)(const struct neighbour___31 *, const void *);
	int (*constructor)(struct neighbour___31 *);
	int (*pconstructor)(struct pneigh_entry___31 *);
	void (*pdestructor)(struct pneigh_entry___31 *);
	void (*proxy_redo)(struct sk_buff___49 *);
	char *id;
	struct neigh_parms___31 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___47 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___31 *nht;
	struct pneigh_entry___31 **phash_buckets;
};

struct neigh_ops___31 {
	int family;
	void (*solicit)(struct neighbour___31 *, struct sk_buff___49 *);
	void (*error_report)(struct neighbour___31 *, struct sk_buff___49 *);
	int (*output)(struct neighbour___31 *, struct sk_buff___49 *);
	int (*connected_output)(struct neighbour___31 *, struct sk_buff___49 *);
};

struct pneigh_entry___31 {
	struct pneigh_entry___31 *next;
	possible_net_t___49 net;
	struct net_device___49 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___31 {
	struct neighbour___31 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

enum txtime_flags {
	SOF_TXTIME_DEADLINE_MODE = 1,
	SOF_TXTIME_REPORT_ERRORS = 2,
	SOF_TXTIME_FLAGS_LAST = 2,
	SOF_TXTIME_FLAGS_MASK = 3,
};

struct sock_txtime {
	__kernel_clockid_t clockid;
	__u32 flags;
};

struct fib_rule___31 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___31 *ctarget;
	struct net___59 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___31 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___31 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___20;

struct timewait_sock_ops___18;

struct proto___31 {
	void (*close)(struct sock___32 *, long int);
	int (*pre_connect)(struct sock___32 *, struct sockaddr *, int);
	int (*connect)(struct sock___32 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___32 *, int);
	struct sock___32 * (*accept)(struct sock___32 *, int, int *, bool);
	int (*ioctl)(struct sock___32 *, int, long unsigned int);
	int (*init)(struct sock___32 *);
	void (*destroy)(struct sock___32 *);
	void (*shutdown)(struct sock___32 *, int);
	int (*setsockopt)(struct sock___32 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___32 *, int, int, char *, int *);
	void (*keepalive)(struct sock___32 *, int);
	int (*sendmsg)(struct sock___32 *, struct msghdr___34 *, size_t);
	int (*recvmsg)(struct sock___32 *, struct msghdr___34 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___32 *, struct page___403 *, int, size_t, int);
	int (*bind)(struct sock___32 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___32 *, struct sk_buff___49 *);
	void (*release_cb)(struct sock___32 *);
	int (*hash)(struct sock___32 *);
	void (*unhash)(struct sock___32 *);
	void (*rehash)(struct sock___32 *);
	int (*get_port)(struct sock___32 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___32 *);
	bool (*stream_memory_read)(const struct sock___32 *);
	void (*enter_memory_pressure)(struct sock___32 *);
	void (*leave_memory_pressure)(struct sock___32 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___20 *rsk_prot;
	struct timewait_sock_ops___18 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___332 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___32 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct xfrm_policy_queue___2 {
	struct sk_buff_head___47 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___2 {
	possible_net_t___49 xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	refcount_t refcnt;
	struct timer_list timer;
	atomic_t genid;
	u32 priority;
	u32 index;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___2 polq;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx___2 *security;
	struct xfrm_tmpl xfrm_vec[6];
	struct callback_head rcu;
	u32 if_id;
};

struct sock_reuseport {
	struct callback_head rcu;
	u16 max_socks;
	u16 num_socks;
	unsigned int reuseport_id;
	bool bind_inany;
	struct bpf_prog___41 *prog;
	struct sock___32 *socks[0];
};

enum sk_pacing {
	SK_PACING_NONE = 0,
	SK_PACING_NEEDED = 1,
	SK_PACING_FQ = 2,
};

struct request_sock___21;

struct request_sock_ops___20 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___32 *, struct request_sock___21 *);
	void (*send_ack)(const struct sock___32 *, struct sk_buff___49 *, struct request_sock___21 *);
	void (*send_reset)(const struct sock___32 *, struct sk_buff___49 *);
	void (*destructor)(struct request_sock___21 *);
	void (*syn_ack_timeout)(const struct request_sock___21 *);
};

struct timewait_sock_ops___18 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___32 *, struct sock___32 *, void *);
	void (*twsk_destructor)(struct sock___32 *);
};

struct socket_alloc___3 {
	struct socket___33 socket;
	struct inode___402 vfs_inode;
};

struct sockcm_cookie {
	u64 transmit_time;
	u32 mark;
	u16 tsflags;
};

struct request_sock___21 {
	struct sock_common___31 __req_common;
	struct request_sock___21 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___20 *rsk_ops;
	struct sock___32 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct fastopen_queue {
	struct request_sock___21 *rskq_rst_head;
	struct request_sock___21 *rskq_rst_tail;
	spinlock_t lock;
	int qlen;
	int max_qlen;
	struct tcp_fastopen_context___3 *ctx;
};

struct request_sock_queue {
	spinlock_t rskq_lock;
	u8 rskq_defer_accept;
	u32 synflood_warned;
	atomic_t qlen;
	atomic_t young;
	struct request_sock___21 *rskq_accept_head;
	struct request_sock___21 *rskq_accept_tail;
	struct fastopen_queue fastopenq;
};

struct inet_cork___4 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___31 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
	__u16 gso_size;
	u64 transmit_time;
};

struct inet_cork_full___4 {
	struct inet_cork___4 base;
	struct flowi fl;
};

struct ipv6_pinfo___4;

struct inet_sock___4 {
	struct sock___32 sk;
	struct ipv6_pinfo___4 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	__be16 inet_sport;
	__u16 inet_id;
	struct ip_options_rcu *inet_opt;
	int rx_dst_ifindex;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 bind_address_no_port: 1;
	__u8 defer_connect: 1;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___4 cork;
};

struct ipv6_fl_socklist___4;

struct ipv6_pinfo___4 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
			__u16 recvfragsize: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 repflow: 1;
	__u16 pmtudisc: 3;
	__u16 padding: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u16 autoflowlabel: 1;
	__u16 autoflowlabel_set: 1;
	__u8 min_hopcount;
	__u8 tclass;
	__be32 rcv_flowinfo;
	__u32 dst_cookie;
	__u32 rx_dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___4 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___49 *pktoptions;
	struct sk_buff___49 *rxpmtu;
	struct inet6_cork cork;
};

struct minmax_sample {
	u32 t;
	u32 v;
};

struct minmax {
	struct minmax_sample s[3];
};

struct inet_connection_sock_af_ops {
	int (*queue_xmit)(struct sock___32 *, struct sk_buff___49 *, struct flowi *);
	void (*send_check)(struct sock___32 *, struct sk_buff___49 *);
	int (*rebuild_header)(struct sock___32 *);
	void (*sk_rx_dst_set)(struct sock___32 *, const struct sk_buff___49 *);
	int (*conn_request)(struct sock___32 *, struct sk_buff___49 *);
	struct sock___32 * (*syn_recv_sock)(const struct sock___32 *, struct sk_buff___49 *, struct request_sock___21 *, struct dst_entry___31 *, struct request_sock___21 *, bool *);
	u16 net_header_len;
	u16 net_frag_header_len;
	u16 sockaddr_len;
	int (*setsockopt)(struct sock___32 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___32 *, int, int, char *, int *);
	void (*addr2sockaddr)(struct sock___32 *, struct sockaddr *);
	void (*mtu_reduced)(struct sock___32 *);
};

struct inet_bind_bucket;

struct tcp_ulp_ops;

struct inet_connection_sock {
	struct inet_sock___4 icsk_inet;
	struct request_sock_queue icsk_accept_queue;
	struct inet_bind_bucket *icsk_bind_hash;
	long unsigned int icsk_timeout;
	struct timer_list icsk_retransmit_timer;
	struct timer_list icsk_delack_timer;
	__u32 icsk_rto;
	__u32 icsk_pmtu_cookie;
	const struct tcp_congestion_ops___3 *icsk_ca_ops;
	const struct inet_connection_sock_af_ops *icsk_af_ops;
	const struct tcp_ulp_ops *icsk_ulp_ops;
	void *icsk_ulp_data;
	void (*icsk_clean_acked)(struct sock___32 *, u32);
	struct hlist_node icsk_listen_portaddr_node;
	unsigned int (*icsk_sync_mss)(struct sock___32 *, u32);
	__u8 icsk_ca_state: 6;
	__u8 icsk_ca_setsockopt: 1;
	__u8 icsk_ca_dst_locked: 1;
	__u8 icsk_retransmits;
	__u8 icsk_pending;
	__u8 icsk_backoff;
	__u8 icsk_syn_retries;
	__u8 icsk_probes_out;
	__u16 icsk_ext_hdr_len;
	struct {
		__u8 pending;
		__u8 quick;
		__u8 pingpong;
		__u8 blocked;
		__u32 ato;
		long unsigned int timeout;
		__u32 lrcvtime;
		__u16 last_seg_size;
		__u16 rcv_mss;
	} icsk_ack;
	struct {
		int enabled;
		int search_high;
		int search_low;
		int probe_size;
		u32 probe_timestamp;
	} icsk_mtup;
	u32 icsk_user_timeout;
	u64 icsk_ca_priv[11];
};

struct inet_bind_bucket {
	possible_net_t___49 ib_net;
	short unsigned int port;
	signed char fastreuse;
	signed char fastreuseport;
	kuid_t fastuid;
	struct in6_addr fast_v6_rcv_saddr;
	__be32 fast_rcv_saddr;
	short unsigned int fast_sk_family;
	bool fast_ipv6_only;
	struct hlist_node node;
	struct hlist_head owners;
};

struct tcp_ulp_ops {
	struct list_head list;
	int (*init)(struct sock___32 *);
	void (*release)(struct sock___32 *);
	char name[16];
	struct module___332 *owner;
};

struct tcp_fastopen_cookie {
	union {
		u8 val[16];
		struct in6_addr addr;
	};
	s8 len;
	bool exp;
};

struct tcp_sack_block {
	u32 start_seq;
	u32 end_seq;
};

struct tcp_options_received {
	long int ts_recent_stamp;
	u32 ts_recent;
	u32 rcv_tsval;
	u32 rcv_tsecr;
	u16 saw_tstamp: 1;
	u16 tstamp_ok: 1;
	u16 dsack: 1;
	u16 wscale_ok: 1;
	u16 sack_ok: 3;
	u16 smc_ok: 1;
	u16 snd_wscale: 4;
	u16 rcv_wscale: 4;
	u8 num_sacks;
	u16 user_mss;
	u16 mss_clamp;
};

struct tcp_rack {
	u64 mstamp;
	u32 rtt_us;
	u32 end_seq;
	u32 last_delivered;
	u8 reo_wnd_steps;
	u8 reo_wnd_persist: 5;
	u8 dsack_seen: 1;
	u8 advanced: 1;
	u8 reord: 1;
};

struct tcp_sock_af_ops;

struct tcp_md5sig_info;

struct tcp_fastopen_request;

struct tcp_sock {
	struct inet_connection_sock inet_conn;
	u16 tcp_header_len;
	u16 gso_segs;
	__be32 pred_flags;
	u64 bytes_received;
	u32 segs_in;
	u32 data_segs_in;
	u32 rcv_nxt;
	u32 copied_seq;
	u32 rcv_wup;
	u32 snd_nxt;
	u32 segs_out;
	u32 data_segs_out;
	u64 bytes_acked;
	u32 snd_una;
	u32 snd_sml;
	u32 rcv_tstamp;
	u32 lsndtime;
	u32 last_oow_ack_time;
	u32 compressed_ack_rcv_nxt;
	u32 tsoffset;
	struct list_head tsq_node;
	struct list_head tsorted_sent_queue;
	u32 snd_wl1;
	u32 snd_wnd;
	u32 max_window;
	u32 mss_cache;
	u32 window_clamp;
	u32 rcv_ssthresh;
	struct tcp_rack rack;
	u16 advmss;
	u8 compressed_ack;
	u32 chrono_start;
	u32 chrono_stat[3];
	u8 chrono_type: 2;
	u8 rate_app_limited: 1;
	u8 fastopen_connect: 1;
	u8 fastopen_no_cookie: 1;
	u8 is_sack_reneg: 1;
	u8 unused: 2;
	u8 nonagle: 4;
	u8 thin_lto: 1;
	u8 recvmsg_inq: 1;
	u8 repair: 1;
	u8 frto: 1;
	u8 repair_queue;
	u8 syn_data: 1;
	u8 syn_fastopen: 1;
	u8 syn_fastopen_exp: 1;
	u8 syn_fastopen_ch: 1;
	u8 syn_data_acked: 1;
	u8 save_syn: 1;
	u8 is_cwnd_limited: 1;
	u8 syn_smc: 1;
	u32 tlp_high_seq;
	u64 tcp_mstamp;
	u32 srtt_us;
	u32 mdev_us;
	u32 mdev_max_us;
	u32 rttvar_us;
	u32 rtt_seq;
	struct minmax rtt_min;
	u32 packets_out;
	u32 retrans_out;
	u32 max_packets_out;
	u32 max_packets_seq;
	u16 urg_data;
	u8 ecn_flags;
	u8 keepalive_probes;
	u32 reordering;
	u32 snd_up;
	struct tcp_options_received rx_opt;
	u32 snd_ssthresh;
	u32 snd_cwnd;
	u32 snd_cwnd_cnt;
	u32 snd_cwnd_clamp;
	u32 snd_cwnd_used;
	u32 snd_cwnd_stamp;
	u32 prior_cwnd;
	u32 prr_delivered;
	u32 prr_out;
	u32 delivered;
	u32 delivered_ce;
	u32 lost;
	u32 app_limited;
	u64 first_tx_mstamp;
	u64 delivered_mstamp;
	u32 rate_delivered;
	u32 rate_interval_us;
	u32 rcv_wnd;
	u32 write_seq;
	u32 notsent_lowat;
	u32 pushed_seq;
	u32 lost_out;
	u32 sacked_out;
	struct hrtimer pacing_timer;
	struct hrtimer compressed_ack_timer;
	struct sk_buff___49 *lost_skb_hint;
	struct sk_buff___49 *retransmit_skb_hint;
	struct rb_root out_of_order_queue;
	struct sk_buff___49 *ooo_last_skb;
	struct tcp_sack_block duplicate_sack[1];
	struct tcp_sack_block selective_acks[4];
	struct tcp_sack_block recv_sack_cache[4];
	struct sk_buff___49 *highest_sack;
	int lost_cnt_hint;
	u32 prior_ssthresh;
	u32 high_seq;
	u32 retrans_stamp;
	u32 undo_marker;
	int undo_retrans;
	u32 total_retrans;
	u32 urg_seq;
	unsigned int keepalive_time;
	unsigned int keepalive_intvl;
	int linger2;
	u8 bpf_sock_ops_cb_flags;
	struct {
		u32 rtt_us;
		u32 seq;
		u64 time;
	} rcv_rtt_est;
	struct {
		u32 space;
		u32 seq;
		u64 time;
	} rcvq_space;
	struct {
		u32 probe_seq_start;
		u32 probe_seq_end;
	} mtu_probe;
	u32 mtu_info;
	const struct tcp_sock_af_ops *af_specific;
	struct tcp_md5sig_info *md5sig_info;
	struct tcp_fastopen_request *fastopen_req;
	struct request_sock___21 *fastopen_rsk;
	u32 *saved_syn;
};

struct tcp_md5sig_key;

struct tcp_sock_af_ops {
	struct tcp_md5sig_key * (*md5_lookup)(const struct sock___32 *, const struct sock___32 *);
	int (*calc_md5_hash)(char *, const struct tcp_md5sig_key *, const struct sock___32 *, const struct sk_buff___49 *);
	int (*md5_parse)(struct sock___32 *, int, char *, int);
};

struct tcp_md5sig_info {
	struct hlist_head head;
	struct callback_head rcu;
};

struct tcp_fastopen_request {
	struct tcp_fastopen_cookie cookie;
	struct msghdr___34 *data;
	size_t size;
	int copied;
};

union tcp_md5_addr {
	struct in_addr a4;
	struct in6_addr a6;
};

struct tcp_md5sig_key {
	struct hlist_node node;
	u8 keylen;
	u8 family;
	union tcp_md5_addr addr;
	u8 prefixlen;
	u8 key[80];
	struct callback_head rcu;
};

struct ip6_flowlabel___4;

struct ipv6_fl_socklist___4 {
	struct ipv6_fl_socklist___4 *next;
	struct ip6_flowlabel___4 *fl;
	struct callback_head rcu;
};

struct ifmcaddr6___17 {
	struct in6_addr mca_addr;
	struct inet6_dev___17 *idev;
	struct ifmcaddr6___17 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___2 {
	struct in6_addr aca_addr;
	struct fib6_info___2 *aca_rt;
	struct ifacaddr6___2 *aca_next;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct ip6_ra_chain___17 {
	struct ip6_ra_chain___17 *next;
	struct sock___32 *sk;
	int sel;
	void (*destructor)(struct sock___32 *);
};

struct ip6_flowlabel___4 {
	struct ip6_flowlabel___4 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___232 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___59 *fl_net;
};

struct rtable___2 {
	struct dst_entry___31 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	__be32 rt_gateway;
	u32 rt_mtu_locked: 1;
	u32 rt_pmtu: 31;
	struct list_head rt_uncached;
	struct uncached_list *rt_uncached_list;
};

struct net_protocol {
	int (*early_demux)(struct sk_buff___49 *);
	int (*early_demux_handler)(struct sk_buff___49 *);
	int (*handler)(struct sk_buff___49 *);
	void (*err_handler)(struct sk_buff___49 *, u32);
	unsigned int no_policy: 1;
	unsigned int netns_ok: 1;
	unsigned int icmp_strict_tag_validation: 1;
};

struct inet6_protocol {
	void (*early_demux)(struct sk_buff___49 *);
	void (*early_demux_handler)(struct sk_buff___49 *);
	int (*handler)(struct sk_buff___49 *);
	void (*err_handler)(struct sk_buff___49 *, struct inet6_skb_parm *, u8, u8, int, __be32);
	unsigned int flags;
};

struct net_offload {
	struct offload_callbacks callbacks;
	unsigned int flags;
};

struct xfrm_replay___2 {
	void (*advance)(struct xfrm_state___2 *, __be32);
	int (*check)(struct xfrm_state___2 *, struct sk_buff___49 *, __be32);
	int (*recheck)(struct xfrm_state___2 *, struct sk_buff___49 *, __be32);
	void (*notify)(struct xfrm_state___2 *, int);
	int (*overflow)(struct xfrm_state___2 *, struct sk_buff___49 *);
};

struct xfrm_type___2 {
	char *description;
	struct module___332 *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___2 *);
	void (*destructor)(struct xfrm_state___2 *);
	int (*input)(struct xfrm_state___2 *, struct sk_buff___49 *);
	int (*output)(struct xfrm_state___2 *, struct sk_buff___49 *);
	int (*reject)(struct xfrm_state___2 *, struct sk_buff___49 *, const struct flowi *);
	int (*hdr_offset)(struct xfrm_state___2 *, struct sk_buff___49 *, u8 **);
	u32 (*get_mtu)(struct xfrm_state___2 *, int);
};

struct xfrm_state_afinfo___2;

struct xfrm_mode___2 {
	int (*input2)(struct xfrm_state___2 *, struct sk_buff___49 *);
	int (*input)(struct xfrm_state___2 *, struct sk_buff___49 *);
	int (*output2)(struct xfrm_state___2 *, struct sk_buff___49 *);
	int (*output)(struct xfrm_state___2 *, struct sk_buff___49 *);
	struct sk_buff___49 * (*gso_segment)(struct xfrm_state___2 *, struct sk_buff___49 *, netdev_features_t);
	void (*xmit)(struct xfrm_state___2 *, struct sk_buff___49 *);
	struct xfrm_state_afinfo___2 *afinfo;
	struct module___332 *owner;
	unsigned int encap;
	int flags;
};

struct xfrm_type_offload___2 {
	char *description;
	struct module___332 *owner;
	u8 proto;
	void (*encap)(struct xfrm_state___2 *, struct sk_buff___49 *);
	int (*input_tail)(struct xfrm_state___2 *, struct sk_buff___49 *);
	int (*xmit)(struct xfrm_state___2 *, struct sk_buff___49 *, netdev_features_t);
};

struct xfrm_dst___2 {
	union {
		struct dst_entry___31 dst;
		struct rtable___2 rt;
		struct rt6_info___2 rt6;
	} u;
	struct dst_entry___31 *route;
	struct dst_entry___31 *child;
	struct dst_entry___31 *path;
	struct xfrm_policy___2 *pols[2];
	int num_pols;
	int num_xfrms;
	u32 xfrm_genid;
	u32 policy_genid;
	u32 route_mtu_cached;
	u32 child_mtu_cached;
	u32 route_cookie;
	u32 path_cookie;
};

struct xfrm_state_afinfo___2 {
	unsigned int family;
	unsigned int proto;
	__be16 eth_proto;
	struct module___332 *owner;
	const struct xfrm_type___2 *type_map[256];
	const struct xfrm_type_offload___2 *type_offload_map[256];
	struct xfrm_mode___2 *mode_map[5];
	int (*init_flags)(struct xfrm_state___2 *);
	void (*init_tempsel)(struct xfrm_selector *, const struct flowi *);
	void (*init_temprop)(struct xfrm_state___2 *, const struct xfrm_tmpl *, const xfrm_address_t *, const xfrm_address_t *);
	int (*tmpl_sort)(struct xfrm_tmpl **, struct xfrm_tmpl **, int);
	int (*state_sort)(struct xfrm_state___2 **, struct xfrm_state___2 **, int);
	int (*output)(struct net___59 *, struct sock___32 *, struct sk_buff___49 *);
	int (*output_finish)(struct sock___32 *, struct sk_buff___49 *);
	int (*extract_input)(struct xfrm_state___2 *, struct sk_buff___49 *);
	int (*extract_output)(struct xfrm_state___2 *, struct sk_buff___49 *);
	int (*transport_finish)(struct sk_buff___49 *, int);
	void (*local_error)(struct sk_buff___49 *, u32);
};

struct cgroup_cls_state {
	struct cgroup_subsys_state___251 css;
	u32 classid;
};

enum {
	SK_MEMINFO_RMEM_ALLOC = 0,
	SK_MEMINFO_RCVBUF = 1,
	SK_MEMINFO_WMEM_ALLOC = 2,
	SK_MEMINFO_SNDBUF = 3,
	SK_MEMINFO_FWD_ALLOC = 4,
	SK_MEMINFO_WMEM_QUEUED = 5,
	SK_MEMINFO_OPTMEM = 6,
	SK_MEMINFO_BACKLOG = 7,
	SK_MEMINFO_DROPS = 8,
	SK_MEMINFO_VARS = 9,
};

enum sknetlink_groups {
	SKNLGRP_NONE = 0,
	SKNLGRP_INET_TCP_DESTROY = 1,
	SKNLGRP_INET_UDP_DESTROY = 2,
	SKNLGRP_INET6_TCP_DESTROY = 3,
	SKNLGRP_INET6_UDP_DESTROY = 4,
	__SKNLGRP_MAX = 5,
};

struct fastopen_queue___2 {
	struct request_sock___19 *rskq_rst_head;
	struct request_sock___19 *rskq_rst_tail;
	spinlock_t lock;
	int qlen;
	int max_qlen;
	struct tcp_fastopen_context *ctx;
};

struct request_sock_queue___2 {
	spinlock_t rskq_lock;
	u8 rskq_defer_accept;
	u32 synflood_warned;
	atomic_t qlen;
	atomic_t young;
	struct request_sock___19 *rskq_accept_head;
	struct request_sock___19 *rskq_accept_tail;
	struct fastopen_queue___2 fastopenq;
};

struct ipv6_txoptions___2;

struct inet_request_sock {
	struct request_sock___19 req;
	u16 snd_wscale: 4;
	u16 rcv_wscale: 4;
	u16 tstamp_ok: 1;
	u16 sack_ok: 1;
	u16 wscale_ok: 1;
	u16 ecn_ok: 1;
	u16 acked: 1;
	u16 no_srccheck: 1;
	u16 smc_ok: 1;
	u32 ir_mark;
	union {
		struct ip_options_rcu *ireq_opt;
		struct {
			struct ipv6_txoptions___2 *ipv6_opt;
			struct sk_buff___44 *pktopts;
		};
	};
};

struct inet_cork___5 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___29 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
	__u16 gso_size;
	u64 transmit_time;
};

struct inet_cork_full___5 {
	struct inet_cork___5 base;
	struct flowi fl;
};

struct ipv6_pinfo___5;

struct inet_sock___5 {
	struct sock___30 sk;
	struct ipv6_pinfo___5 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	__be16 inet_sport;
	__u16 inet_id;
	struct ip_options_rcu *inet_opt;
	int rx_dst_ifindex;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 bind_address_no_port: 1;
	__u8 defer_connect: 1;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___5 cork;
};

struct inet_connection_sock_af_ops___2 {
	int (*queue_xmit)(struct sock___30 *, struct sk_buff___44 *, struct flowi *);
	void (*send_check)(struct sock___30 *, struct sk_buff___44 *);
	int (*rebuild_header)(struct sock___30 *);
	void (*sk_rx_dst_set)(struct sock___30 *, const struct sk_buff___44 *);
	int (*conn_request)(struct sock___30 *, struct sk_buff___44 *);
	struct sock___30 * (*syn_recv_sock)(const struct sock___30 *, struct sk_buff___44 *, struct request_sock___19 *, struct dst_entry___29 *, struct request_sock___19 *, bool *);
	u16 net_header_len;
	u16 net_frag_header_len;
	u16 sockaddr_len;
	int (*setsockopt)(struct sock___30 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___30 *, int, int, char *, int *);
	void (*addr2sockaddr)(struct sock___30 *, struct sockaddr *);
	void (*mtu_reduced)(struct sock___30 *);
};

struct inet_bind_bucket___2;

struct tcp_ulp_ops___2;

struct inet_connection_sock___2 {
	struct inet_sock___5 icsk_inet;
	struct request_sock_queue___2 icsk_accept_queue;
	struct inet_bind_bucket___2 *icsk_bind_hash;
	long unsigned int icsk_timeout;
	struct timer_list icsk_retransmit_timer;
	struct timer_list icsk_delack_timer;
	__u32 icsk_rto;
	__u32 icsk_pmtu_cookie;
	const struct tcp_congestion_ops *icsk_ca_ops;
	const struct inet_connection_sock_af_ops___2 *icsk_af_ops;
	const struct tcp_ulp_ops___2 *icsk_ulp_ops;
	void *icsk_ulp_data;
	void (*icsk_clean_acked)(struct sock___30 *, u32);
	struct hlist_node icsk_listen_portaddr_node;
	unsigned int (*icsk_sync_mss)(struct sock___30 *, u32);
	__u8 icsk_ca_state: 6;
	__u8 icsk_ca_setsockopt: 1;
	__u8 icsk_ca_dst_locked: 1;
	__u8 icsk_retransmits;
	__u8 icsk_pending;
	__u8 icsk_backoff;
	__u8 icsk_syn_retries;
	__u8 icsk_probes_out;
	__u16 icsk_ext_hdr_len;
	struct {
		__u8 pending;
		__u8 quick;
		__u8 pingpong;
		__u8 blocked;
		__u32 ato;
		long unsigned int timeout;
		__u32 lrcvtime;
		__u16 last_seg_size;
		__u16 rcv_mss;
	} icsk_ack;
	struct {
		int enabled;
		int search_high;
		int search_low;
		int probe_size;
		u32 probe_timestamp;
	} icsk_mtup;
	u32 icsk_user_timeout;
	u64 icsk_ca_priv[11];
};

struct sock___33;

struct module___333;

struct tcp_ulp_ops___2 {
	struct list_head list;
	int (*init)(struct sock___33 *);
	void (*release)(struct sock___33 *);
	char name[16];
	struct module___333 *owner;
};

struct tcp_request_sock_ops;

struct tcp_request_sock {
	struct inet_request_sock req;
	const struct tcp_request_sock_ops *af_specific;
	u64 snt_synack;
	bool tfo_listener;
	u32 txhash;
	u32 rcv_isn;
	u32 snt_isn;
	u32 ts_off;
	u32 last_oow_ack_time;
	u32 rcv_nxt;
};

struct tcp_sock_af_ops___2;

struct tcp_md5sig_info___2;

struct tcp_fastopen_request___2;

struct tcp_sock___2 {
	struct inet_connection_sock___2 inet_conn;
	u16 tcp_header_len;
	u16 gso_segs;
	__be32 pred_flags;
	u64 bytes_received;
	u32 segs_in;
	u32 data_segs_in;
	u32 rcv_nxt;
	u32 copied_seq;
	u32 rcv_wup;
	u32 snd_nxt;
	u32 segs_out;
	u32 data_segs_out;
	u64 bytes_acked;
	u32 snd_una;
	u32 snd_sml;
	u32 rcv_tstamp;
	u32 lsndtime;
	u32 last_oow_ack_time;
	u32 compressed_ack_rcv_nxt;
	u32 tsoffset;
	struct list_head tsq_node;
	struct list_head tsorted_sent_queue;
	u32 snd_wl1;
	u32 snd_wnd;
	u32 max_window;
	u32 mss_cache;
	u32 window_clamp;
	u32 rcv_ssthresh;
	struct tcp_rack rack;
	u16 advmss;
	u8 compressed_ack;
	u32 chrono_start;
	u32 chrono_stat[3];
	u8 chrono_type: 2;
	u8 rate_app_limited: 1;
	u8 fastopen_connect: 1;
	u8 fastopen_no_cookie: 1;
	u8 is_sack_reneg: 1;
	u8 unused: 2;
	u8 nonagle: 4;
	u8 thin_lto: 1;
	u8 recvmsg_inq: 1;
	u8 repair: 1;
	u8 frto: 1;
	u8 repair_queue;
	u8 syn_data: 1;
	u8 syn_fastopen: 1;
	u8 syn_fastopen_exp: 1;
	u8 syn_fastopen_ch: 1;
	u8 syn_data_acked: 1;
	u8 save_syn: 1;
	u8 is_cwnd_limited: 1;
	u8 syn_smc: 1;
	u32 tlp_high_seq;
	u64 tcp_mstamp;
	u32 srtt_us;
	u32 mdev_us;
	u32 mdev_max_us;
	u32 rttvar_us;
	u32 rtt_seq;
	struct minmax rtt_min;
	u32 packets_out;
	u32 retrans_out;
	u32 max_packets_out;
	u32 max_packets_seq;
	u16 urg_data;
	u8 ecn_flags;
	u8 keepalive_probes;
	u32 reordering;
	u32 snd_up;
	struct tcp_options_received rx_opt;
	u32 snd_ssthresh;
	u32 snd_cwnd;
	u32 snd_cwnd_cnt;
	u32 snd_cwnd_clamp;
	u32 snd_cwnd_used;
	u32 snd_cwnd_stamp;
	u32 prior_cwnd;
	u32 prr_delivered;
	u32 prr_out;
	u32 delivered;
	u32 delivered_ce;
	u32 lost;
	u32 app_limited;
	u64 first_tx_mstamp;
	u64 delivered_mstamp;
	u32 rate_delivered;
	u32 rate_interval_us;
	u32 rcv_wnd;
	u32 write_seq;
	u32 notsent_lowat;
	u32 pushed_seq;
	u32 lost_out;
	u32 sacked_out;
	struct hrtimer pacing_timer;
	struct hrtimer compressed_ack_timer;
	struct sk_buff___44 *lost_skb_hint;
	struct sk_buff___44 *retransmit_skb_hint;
	struct rb_root out_of_order_queue;
	struct sk_buff___44 *ooo_last_skb;
	struct tcp_sack_block duplicate_sack[1];
	struct tcp_sack_block selective_acks[4];
	struct tcp_sack_block recv_sack_cache[4];
	struct sk_buff___44 *highest_sack;
	int lost_cnt_hint;
	u32 prior_ssthresh;
	u32 high_seq;
	u32 retrans_stamp;
	u32 undo_marker;
	int undo_retrans;
	u32 total_retrans;
	u32 urg_seq;
	unsigned int keepalive_time;
	unsigned int keepalive_intvl;
	int linger2;
	u8 bpf_sock_ops_cb_flags;
	struct {
		u32 rtt_us;
		u32 seq;
		u64 time;
	} rcv_rtt_est;
	struct {
		u32 space;
		u32 seq;
		u64 time;
	} rcvq_space;
	struct {
		u32 probe_seq_start;
		u32 probe_seq_end;
	} mtu_probe;
	u32 mtu_info;
	const struct tcp_sock_af_ops___2 *af_specific;
	struct tcp_md5sig_info___2 *md5sig_info;
	struct tcp_fastopen_request___2 *fastopen_req;
	struct request_sock___19 *fastopen_rsk;
	u32 *saved_syn;
};

struct file___403;

struct kiocb___403;

struct iov_iter___170;

struct poll_table_struct___246;

struct vm_area_struct___404;

struct inode___403;

struct file_lock___403;

struct page___404;

struct pipe_inode_info___84;

struct seq_file___342;

struct file_operations___403 {
	struct module___4 *owner;
	loff_t (*llseek)(struct file___403 *, loff_t, int);
	ssize_t (*read)(struct file___403 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___403 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___403 *, struct iov_iter___170 *);
	ssize_t (*write_iter)(struct kiocb___403 *, struct iov_iter___170 *);
	int (*iopoll)(struct kiocb___403 *, bool);
	int (*iterate)(struct file___403 *, struct dir_context *);
	int (*iterate_shared)(struct file___403 *, struct dir_context *);
	__poll_t (*poll)(struct file___403 *, struct poll_table_struct___246 *);
	long int (*unlocked_ioctl)(struct file___403 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___403 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___403 *, struct vm_area_struct___404 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___403 *, struct file___403 *);
	int (*flush)(struct file___403 *, fl_owner_t);
	int (*release)(struct inode___403 *, struct file___403 *);
	int (*fsync)(struct file___403 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___403 *, int);
	int (*lock)(struct file___403 *, int, struct file_lock___403 *);
	ssize_t (*sendpage)(struct file___403 *, struct page___404 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___403 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___403 *, int, struct file_lock___403 *);
	ssize_t (*splice_write)(struct pipe_inode_info___84 *, struct file___403 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___403 *, loff_t *, struct pipe_inode_info___84 *, size_t, unsigned int);
	int (*setlease)(struct file___403 *, long int, struct file_lock___403 **, void **);
	long int (*fallocate)(struct file___403 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___342 *, struct file___403 *);
	ssize_t (*copy_file_range)(struct file___403 *, loff_t, struct file___403 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___403 *, loff_t, struct file___403 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___403 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___404 {
	u64 seqnum;
	struct vm_area_struct___404 *vmas[4];
};

struct page_frag___404 {
	struct page___404 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___404;

struct mem_cgroup___140;

struct pid___233;

struct cred___371;

struct nsproxy___298;

struct signal_struct___278;

struct bio_list___197;

struct backing_dev_info___197;

struct css_set___252;

struct vm_struct___307;

struct task_struct___405 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___405 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___404 *mm;
	struct mm_struct___404 *active_mm;
	struct vmacache___404 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___405 *real_parent;
	struct task_struct___405 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___405 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___140 *active_memcg;
	long int rh_reserved2;
	struct pid___233 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___233 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___233 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___371 *ptracer_cred;
	const struct cred___371 *real_cred;
	const struct cred___371 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___298 *nsproxy;
	struct signal_struct___278 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___405 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___197 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___197 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___252 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___84 *splice_pipe;
	struct page_frag___404 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___140 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___405 *oom_reaper_list;
	struct vm_struct___307 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___154 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rw_semaphore___405 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___405 *owner;
};

struct key___371;

struct ucounts___268;

struct user_namespace___268 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___268 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___9 ns;
	long unsigned int flags;
	struct key___371 *persistent_keyring_register;
	struct rw_semaphore___405 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___268 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___404 *pgtable_t___404;

struct address_space___403;

struct dev_pagemap___391;

struct page___404 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___403 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___404 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___404 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___404 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___391 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___140 *mem_cgroup;
};

struct pglist_data___404;

struct lruvec___404 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___404 *pgdat;
};

struct zone___404 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___404 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___404 {
	struct zone___404 *zone;
	int zone_idx;
};

struct zonelist___404 {
	struct zoneref___404 _zonerefs[25];
};

struct pglist_data___404 {
	struct zone___404 node_zones[3];
	struct zonelist___404 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___405 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___405 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___404 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___405 {
	void *stack;
	struct task_struct___405 *task;
	long int status;
};

struct blocking_notifier_head___404 {
	struct rw_semaphore___405 rwsem;
	struct notifier_block *head;
};

struct dentry___403;

struct path___404 {
	struct vfsmount *mnt;
	struct dentry___403 *dentry;
};

struct fown_struct___233 {
	rwlock_t lock;
	struct pid___233 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___403 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___404 f_path;
	struct inode___403 *f_inode;
	const struct file_operations___403 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___233 f_owner;
	const struct cred___371 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___403 *f_mapping;
	errseq_t f_wb_err;
};

struct user_struct___371;

struct cred___371 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___371 *session_keyring;
	struct key___371 *process_keyring;
	struct key___371 *thread_keyring;
	struct key___371 *request_key_auth;
	void *security;
	struct user_struct___371 *user;
	struct user_namespace___268 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___397;

struct kernfs_elem_dir___397 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___397 *root;
};

struct kernfs_node___398;

struct kernfs_syscall_ops___397;

struct kernfs_root___397 {
	struct kernfs_node___398 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___397 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___397 {
	struct kernfs_node___398 *target_kn;
};

struct kernfs_ops___397;

struct kernfs_elem_attr___397 {
	const struct kernfs_ops___397 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___398 *notify_next;
};

struct kernfs_node___398 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___398 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___397 dir;
		struct kernfs_elem_symlink___397 symlink;
		struct kernfs_elem_attr___397 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___397;

struct kernfs_ops___397 {
	int (*open)(struct kernfs_open_file___397 *);
	void (*release)(struct kernfs_open_file___397 *);
	int (*seq_show)(struct seq_file___342 *, void *);
	void * (*seq_start)(struct seq_file___342 *, loff_t *);
	void * (*seq_next)(struct seq_file___342 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___342 *, void *);
	ssize_t (*read)(struct kernfs_open_file___397 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___397 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___397 *, struct vm_area_struct___404 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___397 *, struct poll_table_struct___246 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___397 {
	int (*remount_fs)(struct kernfs_root___397 *, int *, char *);
	int (*show_options)(struct seq_file___342 *, struct kernfs_root___397 *);
	int (*mkdir)(struct kernfs_node___398 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___398 *);
	int (*rename)(struct kernfs_node___398 *, struct kernfs_node___398 *, const char *);
	int (*show_path)(struct seq_file___342 *, struct kernfs_node___398 *, struct kernfs_root___397 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___342;

struct seq_file___342 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___342 *op;
	int poll_event;
	const struct file___403 *file;
	void *private;
};

struct vm_operations_struct___391;

struct kernfs_open_file___397 {
	struct kernfs_node___398 *kn;
	struct file___403 *file;
	struct seq_file___342 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___391 *vm_ops;
};

struct vm_fault___391;

struct vm_operations_struct___391 {
	void (*open)(struct vm_area_struct___404 *);
	void (*close)(struct vm_area_struct___404 *);
	int (*split)(struct vm_area_struct___404 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___404 *);
	vm_fault_t (*fault)(struct vm_fault___391 *);
	vm_fault_t (*huge_fault)(struct vm_fault___391 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___391 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___404 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___391 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___391 *);
	int (*access)(struct vm_area_struct___404 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___404 *);
	int (*set_policy)(struct vm_area_struct___404 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___404 *, long unsigned int);
	struct page___404 * (*find_special_page)(struct vm_area_struct___404 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___256)(struct file___403 *, wait_queue_head_t *, struct poll_table_struct___246 *);

struct poll_table_struct___246 {
	poll_queue_proc___256 _qproc;
	__poll_t _key;
};

struct vm_area_struct___404 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___404 *vm_next;
	struct vm_area_struct___404 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___404 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___391 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___403 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_ns_type_operations___32 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___2 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct net___60;

typedef struct {
	struct net___60 *net;
} possible_net_t___50;

struct proto___32;

struct sock_common___32 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___32 *skc_prot;
	possible_net_t___50 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___2 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___50;

struct sk_buff_head___48 {
	struct sk_buff___50 *next;
	struct sk_buff___50 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___32;

struct socket_wq___33;

struct xfrm_policy___3;

struct dst_entry___32;

struct socket___34;

struct net_device___50;

struct sock___2 {
	struct sock_common___32 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___48 sk_error_queue;
	struct sk_buff_head___48 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___50 *head;
		struct sk_buff___50 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___32 *sk_filter;
	union {
		struct socket_wq___33 *sk_wq;
		struct socket_wq___33 *sk_wq_raw;
	};
	struct xfrm_policy___3 *sk_policy[2];
	struct dst_entry___32 *sk_rx_dst;
	struct dst_entry___32 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___50 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___48 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___404 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___32 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___233 *sk_peer_pid;
	const struct cred___371 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___34 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___140 *sk_memcg;
	void (*sk_state_change)(struct sock___2 *);
	void (*sk_data_ready)(struct sock___2 *);
	void (*sk_write_space)(struct sock___2 *);
	void (*sk_error_report)(struct sock___2 *);
	int (*sk_backlog_rcv)(struct sock___2 *, struct sk_buff___50 *);
	struct sk_buff___50 * (*sk_validate_xmit_skb)(struct sock___2 *, struct net_device___50 *, struct sk_buff___50 *);
	void (*sk_destruct)(struct sock___2 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kobject___391;

struct bin_attribute___367;

struct attribute_group___368 {
	const char *name;
	umode_t (*is_visible)(struct kobject___391 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___391 *, struct bin_attribute___367 *, int);
	struct attribute **attrs;
	struct bin_attribute___367 **bin_attrs;
};

struct kset___390;

struct kobj_type___390;

struct kobject___391 {
	const char *name;
	struct list_head entry;
	struct kobject___391 *parent;
	struct kset___390 *kset;
	struct kobj_type___390 *ktype;
	struct kernfs_node___398 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___367 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___403 *, struct kobject___391 *, struct bin_attribute___367 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___403 *, struct kobject___391 *, struct bin_attribute___367 *, char *, loff_t, size_t);
	int (*mmap)(struct file___403 *, struct kobject___391 *, struct bin_attribute___367 *, struct vm_area_struct___404 *);
};

struct sysfs_ops___390 {
	ssize_t (*show)(struct kobject___391 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___391 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___390;

struct kset___390 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___391 kobj;
	const struct kset_uevent_ops___390 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___390 {
	void (*release)(struct kobject___391 *);
	const struct sysfs_ops___390 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___32 * (*child_ns_type)(struct kobject___391 *);
	const void * (*namespace)(struct kobject___391 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___390 {
	int (* const filter)(struct kset___390 *, struct kobject___391 *);
	const char * (* const name)(struct kset___390 *, struct kobject___391 *);
	int (* const uevent)(struct kset___390 *, struct kobject___391 *, struct kobj_uevent_env *);
};

struct kobj_attribute___381 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___391 *, struct kobj_attribute___381 *, char *);
	ssize_t (*store)(struct kobject___391 *, struct kobj_attribute___381 *, const char *, size_t);
};

struct kernel_param___331;

struct kernel_param_ops___331 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___331 *);
	int (*get)(char *, const struct kernel_param___331 *);
	void (*free)(void *);
};

struct kparam_array___331;

struct kernel_param___331 {
	const char *name;
	struct module___4 *mod;
	const struct kernel_param_ops___331 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___331 *arr;
	};
};

struct kparam_array___331 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___331 *ops;
	void *elem;
};

struct module_kobject___331 {
	struct kobject___391 kobj;
	struct module___4 *mod;
	struct kobject___391 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___331 {
	struct module___4 *mod;
	struct latch_tree_node node;
};

struct module_layout___331 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___331 mtn;
};

struct module_attribute___331;

struct module___4 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___331 mkobj;
	struct module_attribute___331 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___391 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___331 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___331 core_layout;
	struct module_layout___331 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___331 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___331 *, struct module_kobject___331 *, char *);
	ssize_t (*store)(struct module_attribute___331 *, struct module_kobject___331 *, const char *, size_t);
	void (*setup)(struct module___4 *, const char *);
	int (*test)(struct module___4 *);
	void (*free)(struct module___4 *);
};

struct core_state___404;

struct mm_struct___404 {
	struct {
		struct vm_area_struct___404 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___403 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___405 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___404 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___405 *owner;
		struct user_namespace___268 *user_ns;
		struct file___403 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___404 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___403;

struct address_space___403 {
	struct inode___403 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___405 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___403 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___391)(struct vm_area_struct___404 *, long unsigned int, const struct page___404 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___391)(struct page___404 *, void *);

struct device___371;

struct dev_pagemap___391 {
	dev_page_fault_t___391 page_fault;
	dev_page_free_t___391 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___371 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct cgroup___252;

struct cgroup_subsys___252;

struct cgroup_subsys_state___252 {
	struct cgroup___252 *cgroup;
	struct cgroup_subsys___252 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___252 *parent;
};

struct cgroup_file___252 {
	struct kernfs_node___398 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___140;

struct mem_cgroup___140 {
	struct cgroup_subsys_state___252 css;
	struct mem_cgroup_id___13 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___252 events_file;
	struct cgroup_file___252 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___405 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___140 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct core_thread___404 {
	struct task_struct___405 *task;
	struct core_thread___404 *next;
};

struct core_state___404 {
	atomic_t nr_threads;
	struct core_thread___404 dumper;
	struct completion startup;
};

struct vm_fault___391 {
	struct vm_area_struct___404 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___404 *cow_page;
	struct mem_cgroup___140 *memcg;
	struct page___404 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___404 prealloc_pte;
};

struct shrink_control___140 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___140 *memcg;
};

struct shrinker___140 {
	long unsigned int (*count_objects)(struct shrinker___140 *, struct shrink_control___140 *);
	long unsigned int (*scan_objects)(struct shrinker___140 *, struct shrink_control___140 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct pid_namespace___233;

struct upid___233 {
	int nr;
	struct pid_namespace___233 *ns;
};

struct pid_namespace___233 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___405 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___233 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___403 *proc_self;
	struct dentry___403 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___268 *user_ns;
	struct ucounts___268 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___9 ns;
};

struct pid___233 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___233 numbers[1];
};

struct user_struct___371 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___371 *uid_keyring;
	struct key___371 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cgroup_namespace___252;

struct nsproxy___298 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___233 *pid_ns_for_children;
	struct net___60 *net_ns;
	struct cgroup_namespace___252 *cgroup_ns;
};

struct signal_struct___278 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___405 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___405 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___233 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___233 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___404 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___233 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___197;

struct bio_list___197 {
	struct bio___197 *head;
	struct bio___197 *tail;
};

struct bdi_writeback_congested___197;

struct bdi_writeback___197 {
	struct backing_dev_info___197 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___197 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___252 *memcg_css;
	struct cgroup_subsys_state___252 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___197 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___197 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___371 *dev;
	struct device___371 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___403 *debug_dir;
	struct dentry___403 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___252 {
	struct cgroup_subsys_state___252 *subsys[13];
	refcount_t refcount;
	struct css_set___252 *dom_cset;
	struct cgroup___252 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___252 *mg_src_cgrp;
	struct cgroup___252 *mg_dst_cgrp;
	struct css_set___252 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___403;

struct pipe_buffer___84;

struct pipe_inode_info___84 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___404 *tmp_page;
	struct fasync_struct___403 *fasync_readers;
	struct fasync_struct___403 *fasync_writers;
	struct pipe_buffer___84 *bufs;
	struct user_struct___371 *user;
};

struct vm_struct___307 {
	struct vm_struct___307 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___404 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___290 {
	struct task_struct___405 task;
	long unsigned int stack[8192];
};

struct dev_pm_info___371 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___371 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___371;

struct bus_type___371;

struct device_driver___371;

struct dev_pm_domain___371;

struct dma_map_ops___143;

struct fwnode_handle___291;

struct class___371;

struct device___371 {
	struct device___371 *parent;
	struct device_private *p;
	struct kobject___391 kobj;
	const char *init_name;
	const struct device_type___371 *type;
	struct mutex mutex;
	struct bus_type___371 *bus;
	struct device_driver___371 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___371 power;
	struct dev_pm_domain___371 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___143 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___291 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___371 *class;
	const struct attribute_group___368 **groups;
	void (*release)(struct device___371 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___403;

struct super_block___403;

struct dentry___403 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___403 *d_parent;
	struct qstr d_name;
	struct inode___403 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___403 *d_op;
	struct super_block___403 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___403;

struct block_device___403;

struct inode___403 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___403 *i_op;
	struct super_block___403 *i_sb;
	struct address_space___403 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___405 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___197 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___403 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___403 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___84 *i_pipe;
		struct block_device___403 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___403 {
	int (*d_revalidate)(struct dentry___403 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___403 *, unsigned int);
	int (*d_hash)(const struct dentry___403 *, struct qstr *);
	int (*d_compare)(const struct dentry___403 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___403 *);
	int (*d_init)(struct dentry___403 *);
	void (*d_release)(struct dentry___403 *);
	void (*d_prune)(struct dentry___403 *);
	void (*d_iput)(struct dentry___403 *, struct inode___403 *);
	char * (*d_dname)(struct dentry___403 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___404 *);
	int (*d_manage)(const struct path___404 *, bool);
	struct dentry___403 * (*d_real)(struct dentry___403 *, const struct inode___403 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___403;

struct mem_dqinfo___403 {
	struct quota_format_type___403 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___403;

struct quota_info___403 {
	unsigned int flags;
	struct rw_semaphore___405 dqio_sem;
	struct inode___403 *files[3];
	struct mem_dqinfo___403 info[3];
	const struct quota_format_ops___403 *ops[3];
};

struct rcuwait___403 {
	struct task_struct___405 *task;
};

struct percpu_rw_semaphore___403 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___405 rw_sem;
	struct rcuwait___403 writer;
	int readers_block;
};

struct sb_writers___403 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___403 rw_sem[3];
};

struct file_system_type___403;

struct super_operations___403;

struct dquot_operations___403;

struct quotactl_ops___403;

struct super_block___403 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___403 *s_type;
	const struct super_operations___403 *s_op;
	const struct dquot_operations___403 *dq_op;
	const struct quotactl_ops___403 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___403 *s_root;
	struct rw_semaphore___405 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___403 *s_bdev;
	struct backing_dev_info___197 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___403 s_dquot;
	struct sb_writers___403 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___403 *s_d_op;
	int cleancache_poolid;
	struct shrinker___140 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___268 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___403 {
	struct file___403 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___403 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___403 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___403 *ia_file;
};

struct dquot___403 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___403 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___403 {
	int qf_fmt_id;
	const struct quota_format_ops___403 *qf_ops;
	struct module___4 *qf_owner;
	struct quota_format_type___403 *qf_next;
};

struct quota_format_ops___403 {
	int (*check_quota_file)(struct super_block___403 *, int);
	int (*read_file_info)(struct super_block___403 *, int);
	int (*write_file_info)(struct super_block___403 *, int);
	int (*free_file_info)(struct super_block___403 *, int);
	int (*read_dqblk)(struct dquot___403 *);
	int (*commit_dqblk)(struct dquot___403 *);
	int (*release_dqblk)(struct dquot___403 *);
	int (*get_next_id)(struct super_block___403 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___403 {
	int (*write_dquot)(struct dquot___403 *);
	struct dquot___403 * (*alloc_dquot)(struct super_block___403 *, int);
	void (*destroy_dquot)(struct dquot___403 *);
	int (*acquire_dquot)(struct dquot___403 *);
	int (*release_dquot)(struct dquot___403 *);
	int (*mark_dirty)(struct dquot___403 *);
	int (*write_info)(struct super_block___403 *, int);
	qsize_t * (*get_reserved_space)(struct inode___403 *);
	int (*get_projid)(struct inode___403 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___403 *, qsize_t *);
	int (*get_next_id)(struct super_block___403 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___403 {
	int (*quota_on)(struct super_block___403 *, int, int, const struct path___404 *);
	int (*quota_off)(struct super_block___403 *, int);
	int (*quota_enable)(struct super_block___403 *, unsigned int);
	int (*quota_disable)(struct super_block___403 *, unsigned int);
	int (*quota_sync)(struct super_block___403 *, int);
	int (*set_info)(struct super_block___403 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___403 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___403 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___403 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___403 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___403 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___160;

struct address_space_operations___403 {
	int (*writepage)(struct page___404 *, struct writeback_control___160 *);
	int (*readpage)(struct file___403 *, struct page___404 *);
	int (*writepages)(struct address_space___403 *, struct writeback_control___160 *);
	int (*set_page_dirty)(struct page___404 *);
	int (*readpages)(struct file___403 *, struct address_space___403 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___403 *, struct address_space___403 *, loff_t, unsigned int, unsigned int, struct page___404 **, void **);
	int (*write_end)(struct file___403 *, struct address_space___403 *, loff_t, unsigned int, unsigned int, struct page___404 *, void *);
	sector_t (*bmap)(struct address_space___403 *, sector_t);
	void (*invalidatepage)(struct page___404 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___404 *, gfp_t);
	void (*freepage)(struct page___404 *);
	ssize_t (*direct_IO)(struct kiocb___403 *, struct iov_iter___170 *);
	int (*migratepage)(struct address_space___403 *, struct page___404 *, struct page___404 *, enum migrate_mode);
	bool (*isolate_page)(struct page___404 *, isolate_mode_t);
	void (*putback_page)(struct page___404 *);
	int (*launder_page)(struct page___404 *);
	int (*is_partially_uptodate)(struct page___404 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___404 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___403 *, struct page___404 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___403 *, sector_t *);
	void (*swap_deactivate)(struct file___403 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___160 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___197 *wb;
	struct inode___403 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___199;

struct iov_iter___170 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___199 *bvec;
		struct pipe_inode_info___84 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___403 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___403 *bd_inode;
	struct super_block___403 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___403 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___197 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___403 {
	struct dentry___403 * (*lookup)(struct inode___403 *, struct dentry___403 *, unsigned int);
	const char * (*get_link)(struct dentry___403 *, struct inode___403 *, struct delayed_call *);
	int (*permission)(struct inode___403 *, int);
	struct posix_acl * (*get_acl)(struct inode___403 *, int);
	int (*readlink)(struct dentry___403 *, char *, int);
	int (*create)(struct inode___403 *, struct dentry___403 *, umode_t, bool);
	int (*link)(struct dentry___403 *, struct inode___403 *, struct dentry___403 *);
	int (*unlink)(struct inode___403 *, struct dentry___403 *);
	int (*symlink)(struct inode___403 *, struct dentry___403 *, const char *);
	int (*mkdir)(struct inode___403 *, struct dentry___403 *, umode_t);
	int (*rmdir)(struct inode___403 *, struct dentry___403 *);
	int (*mknod)(struct inode___403 *, struct dentry___403 *, umode_t, dev_t);
	int (*rename)(struct inode___403 *, struct dentry___403 *, struct inode___403 *, struct dentry___403 *, unsigned int);
	int (*setattr)(struct dentry___403 *, struct iattr___403 *);
	int (*getattr)(const struct path___404 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___403 *, char *, size_t);
	int (*fiemap)(struct inode___403 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___403 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___403 *, struct dentry___403 *, struct file___403 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___403 *, struct dentry___403 *, umode_t);
	int (*set_acl)(struct inode___403 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___403 {
	void (*fl_copy_lock)(struct file_lock___403 *, struct file_lock___403 *);
	void (*fl_release_private)(struct file_lock___403 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___403;

struct file_lock___403 {
	struct file_lock___403 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___403 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___403 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___403 *fl_ops;
	const struct lock_manager_operations___403 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___403 {
	int (*lm_compare_owner)(struct file_lock___403 *, struct file_lock___403 *);
	long unsigned int (*lm_owner_key)(struct file_lock___403 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___403 *);
	int (*lm_grant)(struct file_lock___403 *, int);
	bool (*lm_break)(struct file_lock___403 *);
	int (*lm_change)(struct file_lock___403 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___403 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___403 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___403 *fa_next;
	struct file___403 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___403 {
	const char *name;
	int fs_flags;
	struct dentry___403 * (*mount)(struct file_system_type___403 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___403 *);
	struct module___4 *owner;
	struct file_system_type___403 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___403 {
	struct inode___403 * (*alloc_inode)(struct super_block___403 *);
	void (*destroy_inode)(struct inode___403 *);
	void (*dirty_inode)(struct inode___403 *, int);
	int (*write_inode)(struct inode___403 *, struct writeback_control___160 *);
	int (*drop_inode)(struct inode___403 *);
	void (*evict_inode)(struct inode___403 *);
	void (*put_super)(struct super_block___403 *);
	int (*sync_fs)(struct super_block___403 *, int);
	int (*freeze_super)(struct super_block___403 *);
	int (*freeze_fs)(struct super_block___403 *);
	int (*thaw_super)(struct super_block___403 *);
	int (*unfreeze_fs)(struct super_block___403 *);
	int (*statfs)(struct dentry___403 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___403 *, int *, char *);
	void (*umount_begin)(struct super_block___403 *);
	int (*show_options)(struct seq_file___342 *, struct dentry___403 *);
	int (*show_devname)(struct seq_file___342 *, struct dentry___403 *);
	int (*show_path)(struct seq_file___342 *, struct dentry___403 *);
	int (*show_stats)(struct seq_file___342 *, struct dentry___403 *);
	ssize_t (*quota_read)(struct super_block___403 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___403 *, int, const char *, size_t, loff_t);
	struct dquot___403 ** (*get_dquots)(struct inode___403 *);
	int (*bdev_try_to_free_page)(struct super_block___403 *, struct page___404 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___403 *, struct shrink_control___140 *);
	long int (*free_cached_objects)(struct super_block___403 *, struct shrink_control___140 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___197(struct bio___197 *);

struct bio_vec___199 {
	struct page___404 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___197;

struct bio_set___197;

struct bio___197 {
	struct bio___197 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___197 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___197 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___199 *bi_io_vec;
	struct bio_set___197 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___199 bi_inline_vecs[0];
};

typedef void compound_page_dtor___391(struct page___404 *);

struct msghdr___35 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___170 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___403 *msg_iocb;
};

struct inet_frags___48;

struct netns_frags___48 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___48 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct inet_frag_queue___48;

struct inet_frags___48 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___48 *, const void *);
	void (*destructor)(struct inet_frag_queue___48 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___48 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___50 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___50 *fragments_tail;
	struct sk_buff___50 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___48 *net;
	struct callback_head rcu;
};

struct sec_path___3;

struct nf_bridge_info___48;

struct sk_buff___50 {
	union {
		struct {
			struct sk_buff___50 *next;
			struct sk_buff___50 *prev;
			union {
				struct net_device___50 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___2 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___50 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path___3 *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___48 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct ip_ra_chain___15;

struct fib_rules_ops___32;

struct fib_notifier_ops___32;

struct netns_ipv4___48 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___15 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___32 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___2 *fibnl;
	struct sock___2 **icmp_sk;
	struct sock___2 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___2 **tcp_sk;
	struct netns_frags___48 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___32 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___32 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___32 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct ip_ra_chain___15 {
	struct ip_ra_chain___15 *next;
	struct sock___2 *sk;
	union {
		void (*destructor)(struct sock___2 *);
		struct sock___2 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___32;

struct fib_lookup_arg___32;

struct fib_rules_ops___32 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___32 *, struct flowi *, int, struct fib_lookup_arg___32 *);
	bool (*suppress)(struct fib_rule___32 *, struct fib_lookup_arg___32 *);
	int (*match)(struct fib_rule___32 *, struct flowi *, int);
	int (*configure)(struct fib_rule___32 *, struct sk_buff___50 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___32 *);
	int (*compare)(struct fib_rule___32 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___32 *, struct sk_buff___50 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___32 *);
	void (*flush_cache)(struct fib_rules_ops___32 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___4 *owner;
	struct net___60 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___32 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___60 *);
	int (*fib_dump)(struct net___60 *, struct notifier_block *);
	struct module___4 *owner;
	struct callback_head rcu;
};

struct neighbour___32;

struct dst_ops___59 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___59 *);
	struct dst_entry___32 * (*check)(struct dst_entry___32 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___32 *);
	unsigned int (*mtu)(const struct dst_entry___32 *);
	u32 * (*cow_metrics)(struct dst_entry___32 *, long unsigned int);
	void (*destroy)(struct dst_entry___32 *);
	void (*ifdown)(struct dst_entry___32 *, struct net_device___50 *, int);
	struct dst_entry___32 * (*negative_advice)(struct dst_entry___32 *);
	void (*link_failure)(struct sk_buff___50 *);
	void (*update_pmtu)(struct dst_entry___32 *, struct sock___2 *, struct sk_buff___50 *, u32);
	void (*redirect)(struct dst_entry___32 *, struct sock___2 *, struct sk_buff___50 *);
	int (*local_out)(struct net___60 *, struct sock___2 *, struct sk_buff___50 *);
	struct neighbour___32 * (*neigh_lookup)(const struct dst_entry___32 *, struct sk_buff___50 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___32 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct xfrm_state___3;

struct dst_entry___32 {
	struct net_device___50 *dev;
	struct dst_ops___59 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state___3 *xfrm;
	int (*input)(struct sk_buff___50 *);
	int (*output)(struct net___60 *, struct sock___2 *, struct sk_buff___50 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

typedef rx_handler_result_t rx_handler_func_t___48(struct sk_buff___50 **);

struct net_device_ops___48;

struct ethtool_ops___48;

struct l3mdev_ops___32;

struct ndisc_ops___18;

struct xfrmdev_ops___48;

struct tlsdev_ops___48;

struct header_ops___48;

struct inet6_dev___18;

struct netdev_rx_queue___48;

struct bpf_prog___42;

struct mini_Qdisc___42;

struct netdev_queue___48;

struct Qdisc___42;

struct rtnl_link_ops___42;

struct dcbnl_rtnl_ops___48;

struct net_device___50 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___48 *netdev_ops;
	const struct ethtool_ops___48 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___32 *l3mdev_ops;
	const struct ndisc_ops___18 *ndisc_ops;
	const struct xfrmdev_ops___48 *xfrmdev_ops;
	const struct tlsdev_ops___48 *tlsdev_ops;
	const struct header_ops___48 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___390 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___18 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___48 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___42 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___48 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___42 *miniq_ingress;
	struct netdev_queue___48 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___48 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___42 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___42 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___48 = 0,
		NETREG_REGISTERED___48 = 1,
		NETREG_UNREGISTERING___48 = 2,
		NETREG_UNREGISTERED___48 = 3,
		NETREG_RELEASED___48 = 4,
		NETREG_DUMMY___48 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___48 = 0,
		RTNL_LINK_INITIALIZING___48 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___50 *);
	struct netpoll_info *npinfo;
	possible_net_t___50 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___371 dev;
	const struct attribute_group___368 *sysfs_groups[4];
	const struct attribute_group___368 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___42 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___48 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide35;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct fib6_info___3;

struct rt6_info___3;

struct fib6_table___3;

struct netns_ipv6___59 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___48 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info___3 *fib6_null_entry;
	struct rt6_info___3 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___3 *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___59 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info___3 *ip6_prohibit_entry;
	struct rt6_info___3 *ip6_blk_hole_entry;
	struct fib6_table___3 *fib6_local_tbl;
	struct fib_rules_ops___32 *fib6_rules_ops;
	struct sock___2 **icmp_sk;
	struct sock___2 *ndisc_sk;
	struct sock___2 *tcp_sk;
	struct sock___2 *igmp_sk;
	struct sock___2 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___32 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___32 *notifier_ops;
	struct fib_notifier_ops___32 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___33 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___2 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___48 {
	struct netns_frags___48 frags;
};

struct netns_xfrm___59 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___2 *nlsk;
	struct sock___2 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___59 xfrm4_dst_ops;
	struct dst_ops___59 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct net___60 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___268 *user_ns;
	struct ucounts___268 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___9 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___2 *rtnl;
	struct sock___2 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___50 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___48 ipv4;
	struct netns_ipv6___59 ipv6;
	struct netns_sctp___33 sctp;
	struct netns_nf___3 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___48 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___2 *nfnl;
	struct sock___2 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___59 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___2 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___42 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neigh_table___32;

struct neigh_parms___32;

struct neigh_ops___32;

struct neighbour___32 {
	struct neighbour___32 *next;
	struct neigh_table___32 *tbl;
	struct neigh_parms___32 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___48 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___32 *, struct sk_buff___50 *);
	const struct neigh_ops___32 *ops;
	struct callback_head rcu;
	struct net_device___50 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct fib6_nh___3 {
	struct in6_addr nh_gw;
	struct net_device___50 *nh_dev;
	struct lwtunnel_state *nh_lwtstate;
	unsigned int nh_flags;
	atomic_t nh_upper_bound;
	int nh_weight;
};

struct fib6_node___3;

struct fib6_info___3 {
	struct fib6_table___3 *fib6_table;
	struct fib6_info___3 *fib6_next;
	struct fib6_node___3 *fib6_node;
	struct list_head fib6_siblings;
	unsigned int fib6_nsiblings;
	atomic_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	struct rt6_info___3 **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
	long unsigned int last_probe;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 exception_bucket_flushed: 1;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 dst_host: 1;
	u8 fib6_destroying: 1;
	u8 unused: 2;
	struct fib6_nh___3 fib6_nh;
	struct callback_head rcu;
};

struct rt6_info___3 {
	struct dst_entry___32 dst;
	struct fib6_info___3 *from;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___18 *rt6i_idev;
	u32 rt6i_flags;
	struct rt6key rt6i_prefsrc;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct fib6_node___3 {
	struct fib6_node___3 *parent;
	struct fib6_node___3 *left;
	struct fib6_node___3 *right;
	struct fib6_info___3 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info___3 *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table___3 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node___3 tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

struct socket_wq___33 {
	wait_queue_head_t wait;
	struct fasync_struct___403 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___33;

struct socket___34 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___33 *wq;
	struct file___403 *file;
	struct sock___2 *sk;
	const struct proto_ops___33 *ops;
};

typedef int (*sk_read_actor_t___32)(read_descriptor_t *, struct sk_buff___50 *, unsigned int, size_t);

struct proto_ops___33 {
	int family;
	struct module___4 *owner;
	int (*release)(struct socket___34 *);
	int (*bind)(struct socket___34 *, struct sockaddr *, int);
	int (*connect)(struct socket___34 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___34 *, struct socket___34 *);
	int (*accept)(struct socket___34 *, struct socket___34 *, int, bool);
	int (*getname)(struct socket___34 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___403 *, struct socket___34 *, struct poll_table_struct___246 *);
	int (*ioctl)(struct socket___34 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___34 *, int);
	int (*shutdown)(struct socket___34 *, int);
	int (*setsockopt)(struct socket___34 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___34 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___34 *, struct msghdr___35 *, size_t);
	int (*recvmsg)(struct socket___34 *, struct msghdr___35 *, size_t, int);
	int (*mmap)(struct file___403 *, struct socket___34 *, struct vm_area_struct___404 *);
	ssize_t (*sendpage)(struct socket___34 *, struct page___404 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___34 *, loff_t *, struct pipe_inode_info___84 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___2 *, int);
	int (*peek_len)(struct socket___34 *);
	int (*read_sock)(struct sock___2 *, read_descriptor_t *, sk_read_actor_t___32);
	int (*sendpage_locked)(struct sock___2 *, struct page___404 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___2 *, struct msghdr___35 *, size_t);
	int (*set_rcvlowat)(struct sock___2 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct ts_config___2;

struct ts_ops___2 {
	const char *name;
	struct ts_config___2 * (*init)(const void *, unsigned int, gfp_t, int);
	unsigned int (*find)(struct ts_config___2 *, struct ts_state *);
	void (*destroy)(struct ts_config___2 *);
	void * (*get_pattern)(struct ts_config___2 *);
	unsigned int (*get_pattern_len)(struct ts_config___2 *);
	struct module___4 *owner;
	struct list_head list;
};

struct ts_config___2 {
	struct ts_ops___2 *ops;
	int flags;
	unsigned int (*get_next_block)(unsigned int, const u8 **, struct ts_config___2 *, struct ts_state *);
	void (*finish)(struct ts_config___2 *, struct ts_state *);
};

struct dev_pm_ops___371 {
	int (*prepare)(struct device___371 *);
	void (*complete)(struct device___371 *);
	int (*suspend)(struct device___371 *);
	int (*resume)(struct device___371 *);
	int (*freeze)(struct device___371 *);
	int (*thaw)(struct device___371 *);
	int (*poweroff)(struct device___371 *);
	int (*restore)(struct device___371 *);
	int (*suspend_late)(struct device___371 *);
	int (*resume_early)(struct device___371 *);
	int (*freeze_late)(struct device___371 *);
	int (*thaw_early)(struct device___371 *);
	int (*poweroff_late)(struct device___371 *);
	int (*restore_early)(struct device___371 *);
	int (*suspend_noirq)(struct device___371 *);
	int (*resume_noirq)(struct device___371 *);
	int (*freeze_noirq)(struct device___371 *);
	int (*thaw_noirq)(struct device___371 *);
	int (*poweroff_noirq)(struct device___371 *);
	int (*restore_noirq)(struct device___371 *);
	int (*runtime_suspend)(struct device___371 *);
	int (*runtime_resume)(struct device___371 *);
	int (*runtime_idle)(struct device___371 *);
};

struct dev_pm_domain___371 {
	struct dev_pm_ops___371 ops;
	void (*detach)(struct device___371 *, bool);
	int (*activate)(struct device___371 *);
	void (*sync)(struct device___371 *);
	void (*dismiss)(struct device___371 *);
};

struct bus_type___371 {
	const char *name;
	const char *dev_name;
	struct device___371 *dev_root;
	const struct attribute_group___368 **bus_groups;
	const struct attribute_group___368 **dev_groups;
	const struct attribute_group___368 **drv_groups;
	int (*match)(struct device___371 *, struct device_driver___371 *);
	int (*uevent)(struct device___371 *, struct kobj_uevent_env *);
	int (*probe)(struct device___371 *);
	int (*remove)(struct device___371 *);
	void (*shutdown)(struct device___371 *);
	int (*online)(struct device___371 *);
	int (*offline)(struct device___371 *);
	int (*suspend)(struct device___371 *, pm_message_t);
	int (*resume)(struct device___371 *);
	int (*num_vf)(struct device___371 *);
	int (*dma_configure)(struct device___371 *);
	const struct dev_pm_ops___371 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___371 {
	const char *name;
	struct bus_type___371 *bus;
	struct module___4 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___371 *);
	int (*remove)(struct device___371 *);
	void (*shutdown)(struct device___371 *);
	int (*suspend)(struct device___371 *, pm_message_t);
	int (*resume)(struct device___371 *);
	const struct attribute_group___368 **groups;
	const struct dev_pm_ops___371 *pm;
	void (*coredump)(struct device___371 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___371 {
	const char *name;
	const struct attribute_group___368 **groups;
	int (*uevent)(struct device___371 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___371 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___371 *);
	const struct dev_pm_ops___371 *pm;
};

struct class___371 {
	const char *name;
	struct module___4 *owner;
	const struct attribute_group___368 **class_groups;
	const struct attribute_group___368 **dev_groups;
	struct kobject___391 *dev_kobj;
	int (*dev_uevent)(struct device___371 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___371 *, umode_t *);
	void (*class_release)(struct class___371 *);
	void (*dev_release)(struct device___371 *);
	int (*shutdown_pre)(struct device___371 *);
	const struct kobj_ns_type_operations___32 *ns_type;
	const void * (*namespace)(struct device___371 *);
	const struct dev_pm_ops___371 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___143 {
	void * (*alloc)(struct device___371 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___371 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___371 *, struct vm_area_struct___404 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___371 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___371 *, struct page___404 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___371 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___371 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___371 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___371 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___371 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___371 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___371 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___371 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___371 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___371 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___371 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___371 *, u64);
	u64 (*get_required_mask)(struct device___371 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___291;

struct fwnode_handle___291 {
	struct fwnode_handle___291 *secondary;
	const struct fwnode_operations___291 *ops;
};

struct fwnode_reference_args___291;

struct fwnode_endpoint___291;

struct fwnode_operations___291 {
	struct fwnode_handle___291 * (*get)(struct fwnode_handle___291 *);
	void (*put)(struct fwnode_handle___291 *);
	bool (*device_is_available)(const struct fwnode_handle___291 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___291 *, const struct device___371 *);
	bool (*property_present)(const struct fwnode_handle___291 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___291 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___291 *, const char *, const char **, size_t);
	struct fwnode_handle___291 * (*get_parent)(const struct fwnode_handle___291 *);
	struct fwnode_handle___291 * (*get_next_child_node)(const struct fwnode_handle___291 *, struct fwnode_handle___291 *);
	struct fwnode_handle___291 * (*get_named_child_node)(const struct fwnode_handle___291 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___291 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___291 *);
	struct fwnode_handle___291 * (*graph_get_next_endpoint)(const struct fwnode_handle___291 *, struct fwnode_handle___291 *);
	struct fwnode_handle___291 * (*graph_get_remote_endpoint)(const struct fwnode_handle___291 *);
	struct fwnode_handle___291 * (*graph_get_port_parent)(struct fwnode_handle___291 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___291 *, struct fwnode_endpoint___291 *);
};

struct fwnode_endpoint___291 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___291 *local_fwnode;
};

struct fwnode_reference_args___291 {
	struct fwnode_handle___291 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___84;

struct pipe_buffer___84 {
	struct page___404 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___84 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___84 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___84 *, struct pipe_buffer___84 *);
	void (*release)(struct pipe_inode_info___84 *, struct pipe_buffer___84 *);
	int (*steal)(struct pipe_inode_info___84 *, struct pipe_buffer___84 *);
	union {
		bool (*get)(struct pipe_inode_info___84 *, struct pipe_buffer___84 *);
		struct {
			void (*get)(struct pipe_inode_info___84 *, struct pipe_buffer___84 *);
		} __UNIQUE_ID_rh_kabi_hide21;
		union {		};
	};
};

struct splice_pipe_desc___4 {
	struct page___404 **pages;
	struct partial_page *partial;
	int nr_pages;
	unsigned int nr_pages_max;
	const struct pipe_buf_operations___84 *ops;
	void (*spd_release)(struct splice_pipe_desc___4 *, unsigned int);
};

struct nf_bridge_info___48 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___48 = 0,
		BRNF_PROTO_8021Q___48 = 1,
		BRNF_PROTO_PPPOE___48 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___50 *physindev;
	struct net_device___50 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

struct skb_frag_struct___5 {
	struct {
		struct page___404 *p;
	} page;
	__u32 page_offset;
	__u32 size;
};

typedef struct skb_frag_struct___5 skb_frag_t___5;

struct mmpin {
	struct user_struct___371 *user;
	unsigned int num_pg;
};

struct ubuf_info {
	void (*callback)(struct ubuf_info *, bool);
	union {
		struct {
			long unsigned int desc;
			void *ctx;
		};
		struct {
			u32 id;
			u16 len;
			u16 zerocopy: 1;
			u32 bytelen;
		};
	};
	refcount_t refcnt;
	struct mmpin mmp;
};

struct skb_shared_info___5 {
	__u8 __unused;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___50 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___5 frags[16];
};

enum {
	SKB_FCLONE_UNAVAILABLE = 0,
	SKB_FCLONE_ORIG = 1,
	SKB_FCLONE_CLONE = 2,
};

struct sec_path___3 {
	refcount_t refcnt;
	int len;
	int olen;
	struct xfrm_state___3 *xvec[6];
	struct xfrm_offload ovec[1];
};

struct sk_buff_fclones {
	struct sk_buff___50 skb1;
	struct sk_buff___50 skb2;
	refcount_t fclone_ref;
};

struct skb_seq_state {
	__u32 lower_offset;
	__u32 upper_offset;
	__u32 frag_idx;
	__u32 stepped_offset;
	struct sk_buff___50 *root_skb;
	struct sk_buff___50 *cur_skb;
	__u8 *frag_data;
};

struct skb_gso_cb {
	union {
		int mac_offset;
		int data_offset;
	};
	int encap_level;
	__wsum csum;
	__u16 csum_start;
};

struct ucounts___268 {
	struct hlist_node node;
	struct user_namespace___268 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_prog_aux___45;

struct bpf_prog___42 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___45 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

typedef int (*key_restrict_link_func_t___372)(struct key___371 *, const struct key_type *, const union key_payload *, struct key___371 *);

struct key_restriction___371;

struct key___371 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___405 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___371 *restrict_link;
};

struct key_restriction___371 {
	key_restrict_link_func_t___372 check;
	struct key___371 *key;
	struct key_type *keytype;
};

struct seq_operations___342 {
	void * (*start)(struct seq_file___342 *, loff_t *);
	void (*stop)(struct seq_file___342 *, void *);
	void * (*next)(struct seq_file___342 *, void *, loff_t *);
	int (*show)(struct seq_file___342 *, void *);
};

struct pernet_operations___49 {
	struct list_head list;
	int (*init)(struct net___60 *);
	void (*exit)(struct net___60 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct ethtool_ops___48 {
	int (*get_settings)(struct net_device___50 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___50 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___50 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___50 *);
	void (*get_regs)(struct net_device___50 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___50 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___50 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___50 *);
	void (*set_msglevel)(struct net_device___50 *, u32);
	int (*nway_reset)(struct net_device___50 *);
	u32 (*get_link)(struct net_device___50 *);
	int (*get_eeprom_len)(struct net_device___50 *);
	int (*get_eeprom)(struct net_device___50 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___50 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___50 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___50 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___50 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___50 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___50 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___50 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___50 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___50 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___50 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___50 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___50 *);
	void (*complete)(struct net_device___50 *);
	u32 (*get_priv_flags)(struct net_device___50 *);
	int (*set_priv_flags)(struct net_device___50 *, u32);
	int (*get_sset_count)(struct net_device___50 *, int);
	int (*get_rxnfc)(struct net_device___50 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___50 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___50 *, struct ethtool_flash *);
	int (*reset)(struct net_device___50 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___50 *);
	u32 (*get_rxfh_indir_size)(struct net_device___50 *);
	int (*get_rxfh)(struct net_device___50 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___50 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___50 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___50 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___50 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___50 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___50 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___50 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___50 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___50 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___50 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___50 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___50 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___50 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___50 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___50 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___50 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___50 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___50 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___50 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___50 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___50 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	int (*get_fecparam)(struct net_device___50 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___50 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___50 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___50 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___50 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct dcbnl_rtnl_ops___48 {
	int (*ieee_getets)(struct net_device___50 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___50 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___50 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___50 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___50 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___50 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___50 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___50 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___50 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___50 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___50 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___50 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___50 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___50 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___50 *);
	u8 (*setstate)(struct net_device___50 *, u8);
	void (*getpermhwaddr)(struct net_device___50 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___50 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___50 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___50 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___50 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___50 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___50 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___50 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___50 *, int, u8 *);
	void (*setpfccfg)(struct net_device___50 *, int, u8);
	void (*getpfccfg)(struct net_device___50 *, int, u8 *);
	u8 (*setall)(struct net_device___50 *);
	u8 (*getcap)(struct net_device___50 *, int, u8 *);
	int (*getnumtcs)(struct net_device___50 *, int, u8 *);
	int (*setnumtcs)(struct net_device___50 *, int, u8);
	u8 (*getpfcstate)(struct net_device___50 *);
	void (*setpfcstate)(struct net_device___50 *, u8);
	void (*getbcncfg)(struct net_device___50 *, int, u32 *);
	void (*setbcncfg)(struct net_device___50 *, int, u32);
	void (*getbcnrp)(struct net_device___50 *, int, u8 *);
	void (*setbcnrp)(struct net_device___50 *, int, u8);
	int (*setapp)(struct net_device___50 *, u8, u16, u8);
	int (*getapp)(struct net_device___50 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___50 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___50 *, int, u8);
	u8 (*getdcbx)(struct net_device___50 *);
	u8 (*setdcbx)(struct net_device___50 *, u8);
	int (*peer_getappinfo)(struct net_device___50 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___50 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___50 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___50 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___50 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___50 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___252 {
	refcount_t count;
	struct ns_common___9 ns;
	struct user_namespace___268 *user_ns;
	struct ucounts___268 *ucounts;
	struct css_set___252 *root_cset;
};

struct bpf_map___253;

struct bpf_map_ops___252 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___253 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___253 *, struct file___403 *);
	void (*map_free)(struct bpf_map___253 *);
	int (*map_get_next_key)(struct bpf_map___253 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___253 *);
	void * (*map_lookup_elem)(struct bpf_map___253 *, void *);
	int (*map_update_elem)(struct bpf_map___253 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___253 *, void *);
	int (*map_push_elem)(struct bpf_map___253 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___253 *, void *);
	int (*map_peek_elem)(struct bpf_map___253 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___253 *, struct file___403 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___253 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___253 *, void *, struct seq_file___342 *);
	int (*map_check_btf)(const struct bpf_map___253 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___253 {
	const struct bpf_map_ops___252 *ops;
	struct bpf_map___253 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___371 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___48;

struct bpf_map_dev_ops___48 {
	int (*map_get_next_key)(struct bpf_offloaded_map___48 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___48 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___48 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___48 *, void *);
};

struct bpf_offloaded_map___48 {
	struct bpf_map___253 map;
	struct net_device___50 *netdev;
	const struct bpf_map_dev_ops___48 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___42 {
	int (*test_run)(struct bpf_prog___42 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___42 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___42 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___42 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___42 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___42 *, u32 *);
};

struct bpf_prog_offload_ops___42 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___42 *);
	int (*translate)(struct bpf_prog___42 *);
	void (*destroy)(struct bpf_prog___42 *);
};

struct bpf_prog_offload___42 {
	struct bpf_prog___42 *prog;
	struct net_device___50 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___42 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___45 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___42 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___42 *ops;
	struct bpf_map___253 **used_maps;
	struct bpf_prog___42 *prog;
	struct user_struct___371 *user;
	u64 load_time;
	struct bpf_map___253 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___42 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___42 {
	struct bpf_prog___42 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___42 {
	struct callback_head rcu;
	struct bpf_prog_array_item___42 items[0];
};

struct cgroup_bpf___42 {
	struct bpf_prog_array___42 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___42 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___253;

typedef void (*kthread_work_func_t___253)(struct kthread_work___253 *);

struct kthread_worker___253;

struct kthread_work___253 {
	struct list_head node;
	kthread_work_func_t___253 func;
	struct kthread_worker___253 *worker;
	int canceling;
};

struct kthread_worker___253 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___405 *task;
	struct kthread_work___253 *current_work;
};

struct kthread_delayed_work___252 {
	struct kthread_work___253 work;
	struct timer_list timer;
};

struct psi_group___252 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___253 *poll_kworker;
	struct kthread_delayed_work___252 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___252;

struct cgroup_rstat_cpu___252;

struct cgroup___252 {
	struct cgroup_subsys_state___252 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___398 *kn;
	struct cgroup_file___252 procs_file;
	struct cgroup_file___252 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___252 *subsys[13];
	struct cgroup_root___252 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___252 *dom_cgrp;
	struct cgroup_rstat_cpu___252 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___42 bpf;
	atomic_t congestion_count;
	struct cgroup___252 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___252 psi;
	int ancestor_ids[0];
};

struct cftype___252;

struct cgroup_subsys___252 {
	struct cgroup_subsys_state___252 * (*css_alloc)(struct cgroup_subsys_state___252 *);
	int (*css_online)(struct cgroup_subsys_state___252 *);
	void (*css_offline)(struct cgroup_subsys_state___252 *);
	void (*css_released)(struct cgroup_subsys_state___252 *);
	void (*css_free)(struct cgroup_subsys_state___252 *);
	void (*css_reset)(struct cgroup_subsys_state___252 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___252 *, int);
	int (*css_extra_stat_show)(struct seq_file___342 *, struct cgroup_subsys_state___252 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___405 *);
	void (*cancel_fork)(struct task_struct___405 *);
	void (*fork)(struct task_struct___405 *);
	void (*exit)(struct task_struct___405 *);
	void (*free)(struct task_struct___405 *);
	void (*bind)(struct cgroup_subsys_state___252 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___252 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___252 *dfl_cftypes;
	struct cftype___252 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___252 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___252 *updated_children;
	struct cgroup___252 *updated_next;
};

struct cgroup_root___252 {
	struct kernfs_root___397 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___252 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___252 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___252 *ss;
	struct list_head node;
	struct kernfs_ops___397 *kf_ops;
	int (*open)(struct kernfs_open_file___397 *);
	void (*release)(struct kernfs_open_file___397 *);
	u64 (*read_u64)(struct cgroup_subsys_state___252 *, struct cftype___252 *);
	s64 (*read_s64)(struct cgroup_subsys_state___252 *, struct cftype___252 *);
	int (*seq_show)(struct seq_file___342 *, void *);
	void * (*seq_start)(struct seq_file___342 *, loff_t *);
	void * (*seq_next)(struct seq_file___342 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___342 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___252 *, struct cftype___252 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___252 *, struct cftype___252 *, s64);
	ssize_t (*write)(struct kernfs_open_file___397 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___397 *, struct poll_table_struct___246 *);
};

struct xdp_rxq_info___48 {
	struct net_device___50 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___48 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___50 *dev_rx;
};

struct netlink_callback___50 {
	struct sk_buff___50 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___50 *);
	int (*dump)(struct sk_buff___50 *, struct netlink_callback___50 *);
	int (*done)(struct netlink_callback___50 *);
	void *data;
	struct module___4 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___48 {
	int (*create)(struct sk_buff___50 *, struct net_device___50 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___50 *, unsigned char *);
	int (*cache)(const struct neighbour___32 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___50 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___48 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___48 *, int);
	int poll_owner;
	struct net_device___50 *dev;
	struct sk_buff___50 *gro_list;
	struct sk_buff___50 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___48 {
	struct net_device___50 *dev;
	struct Qdisc___42 *qdisc;
	struct Qdisc___42 *qdisc_sleeping;
	struct kobject___391 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___50 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___42 {
	struct sk_buff___50 *head;
	struct sk_buff___50 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___42;

struct Qdisc___42 {
	int (*enqueue)(struct sk_buff___50 *, struct Qdisc___42 *, struct sk_buff___50 **);
	struct sk_buff___50 * (*dequeue)(struct Qdisc___42 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___42 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___48 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___48 gso_skb;
	struct qdisc_skb_head___42 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___42 *next_sched;
	struct sk_buff_head___48 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___48 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___391 kobj;
	struct net_device___50 *dev;
	long: 64;
	struct xdp_rxq_info___48 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___48)(struct net_device___50 *, struct sk_buff___50 *, struct net_device___50 *);

struct netdev_bpf___48 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___42 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___42 *prog;
			const struct bpf_prog_offload_ops___42 *ops;
		} verifier;
		struct {
			struct bpf_prog___42 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___48 *offmap;
		};
		struct {
			struct xdp_umem *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___48 {
	int (*xdo_dev_state_add)(struct xfrm_state___3 *);
	void (*xdo_dev_state_delete)(struct xfrm_state___3 *);
	void (*xdo_dev_state_free)(struct xfrm_state___3 *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___50 *, struct xfrm_state___3 *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state___3 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct xfrm_state_offload___3 {
	struct net_device___50 *dev;
	long unsigned int offload_handle;
	unsigned int num_exthdrs;
	u8 flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct xfrm_replay___3;

struct xfrm_type___3;

struct xfrm_mode___3;

struct xfrm_type_offload___3;

struct xfrm_state___3 {
	possible_net_t___50 xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	refcount_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
		u32 output_mark;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	const char *geniv;
	struct xfrm_encap_tmpl *encap;
	xfrm_address_t *coaddr;
	struct xfrm_state___3 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	const struct xfrm_replay___3 *repl;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct tasklet_hrtimer mtimer;
	struct xfrm_state_offload___3 xso;
	long int saved_tmo;
	long unsigned int lastused;
	struct page_frag___404 xfrag;
	const struct xfrm_type___3 *type;
	struct xfrm_mode___3 *inner_mode;
	struct xfrm_mode___3 *inner_mode_iaf;
	struct xfrm_mode___3 *outer_mode;
	const struct xfrm_type_offload___3 *type_offload;
	struct xfrm_sec_ctx___2 *security;
	void *data;
	u32 output_mark_mask;
	u32 if_id;
};

struct tlsdev_ops___48 {
	int (*tls_dev_add)(struct net_device___50 *, struct sock___2 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___50 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___50 *, struct sock___2 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___48 {
	int (*ndo_init)(struct net_device___50 *);
	void (*ndo_uninit)(struct net_device___50 *);
	int (*ndo_open)(struct net_device___50 *);
	int (*ndo_stop)(struct net_device___50 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___50 *, struct net_device___50 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___50 *, struct net_device___50 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___50 *, struct sk_buff___50 *, struct net_device___50 *, select_queue_fallback_t___48);
	void (*ndo_change_rx_flags)(struct net_device___50 *, int);
	void (*ndo_set_rx_mode)(struct net_device___50 *);
	int (*ndo_set_mac_address)(struct net_device___50 *, void *);
	int (*ndo_validate_addr)(struct net_device___50 *);
	int (*ndo_do_ioctl)(struct net_device___50 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___50 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___50 *, int);
	int (*ndo_neigh_setup)(struct net_device___50 *, struct neigh_parms___32 *);
	void (*ndo_tx_timeout)(struct net_device___50 *);
	void (*ndo_get_stats64)(struct net_device___50 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___50 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___50 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___50 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___50 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___50 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___50 *);
	int (*ndo_netpoll_setup)(struct net_device___50 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___50 *);
	int (*ndo_set_vf_mac)(struct net_device___50 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___50 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___50 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___50 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___50 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___50 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___50 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___50 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___50 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___50 *, int, struct sk_buff___50 *);
	int (*ndo_set_vf_guid)(struct net_device___50 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___50 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___50 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___50 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___50 *, const struct sk_buff___50 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___50 *, struct net_device___50 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___50 *, struct net_device___50 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___50 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___50 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___50 *, struct neighbour___32 *);
	void (*ndo_neigh_destroy)(struct net_device___50 *, struct neighbour___32 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___50 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___50 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___50 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___50 *, struct netlink_callback___50 *, struct net_device___50 *, struct net_device___50 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___50 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___50 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___50 *, u32, u32, struct net_device___50 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___50 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___50 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___50 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___50 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___50 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___50 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___50 *, struct net_device___50 *);
	void (*ndo_dfwd_del_station)(struct net_device___50 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___50 *);
	int (*ndo_set_tx_maxrate)(struct net_device___50 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___50 *);
	int (*ndo_change_proto_down)(struct net_device___50 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___50 *, struct sk_buff___50 *);
	void (*ndo_set_rx_headroom)(struct net_device___50 *, int);
	int (*ndo_bpf)(struct net_device___50 *, struct netdev_bpf___48 *);
	int (*ndo_xdp_xmit)(struct net_device___50 *, int, struct xdp_frame___48 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___50 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___50 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___32 {
	possible_net_t___50 net;
	struct net_device___50 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___32 *);
	void (*neigh_cleanup)(struct neighbour___32 *);
	struct neigh_table___32 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___32 {
	u32 (*l3mdev_fib_table)(const struct net_device___50 *);
	struct sk_buff___50 * (*l3mdev_l3_rcv)(struct net_device___50 *, struct sk_buff___50 *, u16);
	struct sk_buff___50 * (*l3mdev_l3_out)(struct net_device___50 *, struct sock___2 *, struct sk_buff___50 *, u16);
	struct dst_entry___32 * (*l3mdev_link_scope_lookup)(const struct net_device___50 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct ndisc_ops___18 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___50 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___50 *, struct neighbour___32 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___50 *, u8, struct neighbour___32 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___50 *, struct sk_buff___50 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___60 *, struct net_device___50 *, const struct prefix_info *, struct inet6_dev___18 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___18;

struct ifacaddr6___3;

struct inet6_dev___18 {
	struct net_device___50 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___18 *mc_list;
	struct ifmcaddr6___18 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___3 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	u8 rndid[8];
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___32 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
};

struct tcf_proto___42;

struct mini_Qdisc___42 {
	struct tcf_proto___42 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___42 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___50 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___60 *, struct net_device___50 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___50 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___50 *, struct list_head *);
	size_t (*get_size)(const struct net_device___50 *);
	int (*fill_info)(struct sk_buff___50 *, const struct net_device___50 *);
	size_t (*get_xstats_size)(const struct net_device___50 *);
	int (*fill_xstats)(struct sk_buff___50 *, const struct net_device___50 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___50 *, struct net_device___50 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___50 *, const struct net_device___50 *);
	int (*fill_slave_info)(struct sk_buff___50 *, const struct net_device___50 *, const struct net_device___50 *);
	struct net___60 * (*get_link_net)(const struct net_device___50 *);
	size_t (*get_linkxstats_size)(const struct net_device___50 *, int);
	int (*fill_linkxstats)(struct sk_buff___50 *, const struct net_device___50 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct napi_gro_cb {
	void *frag0;
	unsigned int frag0_len;
	int data_offset;
	u16 flush;
	u16 flush_id;
	u16 count;
	u16 gro_remcsum_start;
	long unsigned int age;
	u16 proto;
	u8 same_flow: 1;
	u8 encap_mark: 1;
	u8 csum_valid: 1;
	u8 csum_cnt: 3;
	u8 free: 2;
	u8 is_ipv6: 1;
	u8 is_fou: 1;
	u8 is_atomic: 1;
	u8 recursion_counter: 4;
	__wsum csum;
	struct sk_buff___50 *last;
};

struct offload_callbacks___2 {
	struct sk_buff___50 * (*gso_segment)(struct sk_buff___50 *, netdev_features_t);
	struct sk_buff___50 ** (*gro_receive)(struct sk_buff___50 **, struct sk_buff___50 *);
	int (*gro_complete)(struct sk_buff___50 *, int);
};

struct softnet_data___48 {
	struct list_head poll_list;
	struct sk_buff_head___48 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___48 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___42 *output_queue;
	struct Qdisc___42 **output_queue_tailp;
	struct sk_buff___50 *completion_queue;
	struct sk_buff_head___48 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___48 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___48 input_pkt_queue;
	struct napi_struct___48 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

enum skb_free_reason {
	SKB_REASON_CONSUMED = 0,
	SKB_REASON_DROPPED = 1,
};

struct bdi_writeback_congested___197 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___197 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___197 {
	struct bio___197 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___199 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___199 bip_inline_vecs[0];
};

struct bio_set___197 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___197 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___140 {
	struct mem_cgroup___140 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___140 {
	struct lruvec___404 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___140 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___140 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct vlan_hdr {
	__be16 h_vlan_TCI;
	__be16 h_vlan_encapsulated_proto;
};

struct vlan_ethhdr {
	unsigned char h_dest[6];
	unsigned char h_source[6];
	__be16 h_vlan_proto;
	__be16 h_vlan_TCI;
	__be16 h_vlan_encapsulated_proto;
};

struct gnet_dump___42 {
	spinlock_t *lock;
	struct sk_buff___50 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___42;

struct Qdisc_ops___42 {
	struct Qdisc_ops___42 *next;
	const struct Qdisc_class_ops___42 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___50 *, struct Qdisc___42 *, struct sk_buff___50 **);
	struct sk_buff___50 * (*dequeue)(struct Qdisc___42 *);
	struct sk_buff___50 * (*peek)(struct Qdisc___42 *);
	int (*init)(struct Qdisc___42 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___42 *);
	void (*destroy)(struct Qdisc___42 *);
	int (*change)(struct Qdisc___42 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___42 *);
	int (*change_tx_queue_len)(struct Qdisc___42 *, unsigned int);
	int (*dump)(struct Qdisc___42 *, struct sk_buff___50 *);
	int (*dump_stats)(struct Qdisc___42 *, struct gnet_dump___42 *);
	void (*ingress_block_set)(struct Qdisc___42 *, u32);
	void (*egress_block_set)(struct Qdisc___42 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___42 *);
	u32 (*egress_block_get)(struct Qdisc___42 *);
	struct module___4 *owner;
};

struct tcf_block___42;

struct Qdisc_class_ops___42 {
	unsigned int flags;
	struct netdev_queue___48 * (*select_queue)(struct Qdisc___42 *, struct tcmsg *);
	int (*graft)(struct Qdisc___42 *, long unsigned int, struct Qdisc___42 *, struct Qdisc___42 **, struct netlink_ext_ack *);
	struct Qdisc___42 * (*leaf)(struct Qdisc___42 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___42 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___42 *, u32);
	int (*change)(struct Qdisc___42 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___42 *, long unsigned int);
	void (*walk)(struct Qdisc___42 *, struct qdisc_walker *);
	struct tcf_block___42 * (*tcf_block)(struct Qdisc___42 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___42 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___42 *, long unsigned int);
	int (*dump)(struct Qdisc___42 *, long unsigned int, struct sk_buff___50 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___42 *, long unsigned int, struct gnet_dump___42 *);
};

struct qdisc_walker {
	int stop;
	int skip;
	int count;
	int (*fn)(struct Qdisc___42 *, long unsigned int, struct qdisc_walker *);
};

struct tcf_chain___42;

struct tcf_block___42 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___60 *net;
	struct Qdisc___42 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___42 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___42;

struct tcf_proto_ops___42;

struct tcf_proto___42 {
	struct tcf_proto___42 *next;
	void *root;
	int (*classify)(struct sk_buff___50 *, const struct tcf_proto___42 *, struct tcf_result___42 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___42 *ops;
	struct tcf_chain___42 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___42 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___42 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___42 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___50 *, const struct tcf_proto___42 *, struct tcf_result___42 *);
	int (*init)(struct tcf_proto___42 *);
	void (*destroy)(struct tcf_proto___42 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___42 *, u32);
	void (*put)(struct tcf_proto___42 *, void *);
	int (*change)(struct net___60 *, struct sk_buff___50 *, struct tcf_proto___42 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___42 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___42 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___42 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___60 *, struct tcf_chain___42 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___60 *, struct tcf_proto___42 *, void *, struct sk_buff___50 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___50 *, struct net___60 *, void *);
	struct module___4 *owner;
	int flags;
};

struct tcf_chain___42 {
	struct mutex filter_chain_lock;
	struct tcf_proto___42 *filter_chain;
	struct list_head list;
	struct tcf_block___42 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___42 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___32 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___42 *prog;
};

struct bpf_redirect_info___42 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___253 *map;
	struct bpf_map___253 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___32;

struct neigh_hash_table___32;

struct neigh_table___32 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___50 *, __u32 *);
	bool (*key_eq)(const struct neighbour___32 *, const void *);
	int (*constructor)(struct neighbour___32 *);
	int (*pconstructor)(struct pneigh_entry___32 *);
	void (*pdestructor)(struct pneigh_entry___32 *);
	void (*proxy_redo)(struct sk_buff___50 *);
	char *id;
	struct neigh_parms___32 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___48 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___32 *nht;
	struct pneigh_entry___32 **phash_buckets;
};

struct neigh_ops___32 {
	int family;
	void (*solicit)(struct neighbour___32 *, struct sk_buff___50 *);
	void (*error_report)(struct neighbour___32 *, struct sk_buff___50 *);
	int (*output)(struct neighbour___32 *, struct sk_buff___50 *);
	int (*connected_output)(struct neighbour___32 *, struct sk_buff___50 *);
};

struct pneigh_entry___32 {
	struct pneigh_entry___32 *next;
	possible_net_t___50 net;
	struct net_device___50 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___32 {
	struct neighbour___32 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___32 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___32 *ctarget;
	struct net___60 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___32 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___32 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___21;

struct timewait_sock_ops___19;

struct proto___32 {
	void (*close)(struct sock___2 *, long int);
	int (*pre_connect)(struct sock___2 *, struct sockaddr *, int);
	int (*connect)(struct sock___2 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___2 *, int);
	struct sock___2 * (*accept)(struct sock___2 *, int, int *, bool);
	int (*ioctl)(struct sock___2 *, int, long unsigned int);
	int (*init)(struct sock___2 *);
	void (*destroy)(struct sock___2 *);
	void (*shutdown)(struct sock___2 *, int);
	int (*setsockopt)(struct sock___2 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___2 *, int, int, char *, int *);
	void (*keepalive)(struct sock___2 *, int);
	int (*sendmsg)(struct sock___2 *, struct msghdr___35 *, size_t);
	int (*recvmsg)(struct sock___2 *, struct msghdr___35 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___2 *, struct page___404 *, int, size_t, int);
	int (*bind)(struct sock___2 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___2 *, struct sk_buff___50 *);
	void (*release_cb)(struct sock___2 *);
	int (*hash)(struct sock___2 *);
	void (*unhash)(struct sock___2 *);
	void (*rehash)(struct sock___2 *);
	int (*get_port)(struct sock___2 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___2 *);
	bool (*stream_memory_read)(const struct sock___2 *);
	void (*enter_memory_pressure)(struct sock___2 *);
	void (*leave_memory_pressure)(struct sock___2 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___21 *rsk_prot;
	struct timewait_sock_ops___19 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___4 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___2 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct xfrm_policy_queue___3 {
	struct sk_buff_head___48 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___3 {
	possible_net_t___50 xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	refcount_t refcnt;
	struct timer_list timer;
	atomic_t genid;
	u32 priority;
	u32 index;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___3 polq;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx___2 *security;
	struct xfrm_tmpl xfrm_vec[6];
	struct callback_head rcu;
	u32 if_id;
};

struct request_sock___22;

struct request_sock_ops___21 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___2 *, struct request_sock___22 *);
	void (*send_ack)(const struct sock___2 *, struct sk_buff___50 *, struct request_sock___22 *);
	void (*send_reset)(const struct sock___2 *, struct sk_buff___50 *);
	void (*destructor)(struct request_sock___22 *);
	void (*syn_ack_timeout)(const struct request_sock___22 *);
};

struct timewait_sock_ops___19 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___2 *, struct sock___2 *, void *);
	void (*twsk_destructor)(struct sock___2 *);
};

struct request_sock___22 {
	struct sock_common___32 __req_common;
	struct request_sock___22 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___21 *rsk_ops;
	struct sock___2 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ip_auth_hdr {
	__u8 nexthdr;
	__u8 hdrlen;
	__be16 reserved;
	__be32 spi;
	__be32 seq_no;
	__u8 auth_data[0];
};

struct ifmcaddr6___18 {
	struct in6_addr mca_addr;
	struct inet6_dev___18 *idev;
	struct ifmcaddr6___18 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___3 {
	struct in6_addr aca_addr;
	struct fib6_info___3 *aca_rt;
	struct ifacaddr6___3 *aca_next;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct frag_hdr {
	__u8 nexthdr;
	__u8 reserved;
	__be16 frag_off;
	__be32 identification;
};

struct ip6_ra_chain___18 {
	struct ip6_ra_chain___18 *next;
	struct sock___2 *sk;
	int sel;
	void (*destructor)(struct sock___2 *);
};

enum {
	SCM_TSTAMP_SND = 0,
	SCM_TSTAMP_SCHED = 1,
	SCM_TSTAMP_ACK = 2,
};

struct net_protocol___2 {
	int (*early_demux)(struct sk_buff___50 *);
	int (*early_demux_handler)(struct sk_buff___50 *);
	int (*handler)(struct sk_buff___50 *);
	void (*err_handler)(struct sk_buff___50 *, u32);
	unsigned int no_policy: 1;
	unsigned int netns_ok: 1;
	unsigned int icmp_strict_tag_validation: 1;
};

struct inet6_protocol___2 {
	void (*early_demux)(struct sk_buff___50 *);
	void (*early_demux_handler)(struct sk_buff___50 *);
	int (*handler)(struct sk_buff___50 *);
	void (*err_handler)(struct sk_buff___50 *, struct inet6_skb_parm *, u8, u8, int, __be32);
	unsigned int flags;
};

struct net_offload___2 {
	struct offload_callbacks___2 callbacks;
	unsigned int flags;
};

struct xfrm_replay___3 {
	void (*advance)(struct xfrm_state___3 *, __be32);
	int (*check)(struct xfrm_state___3 *, struct sk_buff___50 *, __be32);
	int (*recheck)(struct xfrm_state___3 *, struct sk_buff___50 *, __be32);
	void (*notify)(struct xfrm_state___3 *, int);
	int (*overflow)(struct xfrm_state___3 *, struct sk_buff___50 *);
};

struct xfrm_type___3 {
	char *description;
	struct module___4 *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___3 *);
	void (*destructor)(struct xfrm_state___3 *);
	int (*input)(struct xfrm_state___3 *, struct sk_buff___50 *);
	int (*output)(struct xfrm_state___3 *, struct sk_buff___50 *);
	int (*reject)(struct xfrm_state___3 *, struct sk_buff___50 *, const struct flowi *);
	int (*hdr_offset)(struct xfrm_state___3 *, struct sk_buff___50 *, u8 **);
	u32 (*get_mtu)(struct xfrm_state___3 *, int);
};

struct xfrm_state_afinfo___3;

struct xfrm_mode___3 {
	int (*input2)(struct xfrm_state___3 *, struct sk_buff___50 *);
	int (*input)(struct xfrm_state___3 *, struct sk_buff___50 *);
	int (*output2)(struct xfrm_state___3 *, struct sk_buff___50 *);
	int (*output)(struct xfrm_state___3 *, struct sk_buff___50 *);
	struct sk_buff___50 * (*gso_segment)(struct xfrm_state___3 *, struct sk_buff___50 *, netdev_features_t);
	void (*xmit)(struct xfrm_state___3 *, struct sk_buff___50 *);
	struct xfrm_state_afinfo___3 *afinfo;
	struct module___4 *owner;
	unsigned int encap;
	int flags;
};

struct xfrm_type_offload___3 {
	char *description;
	struct module___4 *owner;
	u8 proto;
	void (*encap)(struct xfrm_state___3 *, struct sk_buff___50 *);
	int (*input_tail)(struct xfrm_state___3 *, struct sk_buff___50 *);
	int (*xmit)(struct xfrm_state___3 *, struct sk_buff___50 *, netdev_features_t);
};

struct xfrm_state_afinfo___3 {
	unsigned int family;
	unsigned int proto;
	__be16 eth_proto;
	struct module___4 *owner;
	const struct xfrm_type___3 *type_map[256];
	const struct xfrm_type_offload___3 *type_offload_map[256];
	struct xfrm_mode___3 *mode_map[5];
	int (*init_flags)(struct xfrm_state___3 *);
	void (*init_tempsel)(struct xfrm_selector *, const struct flowi *);
	void (*init_temprop)(struct xfrm_state___3 *, const struct xfrm_tmpl *, const xfrm_address_t *, const xfrm_address_t *);
	int (*tmpl_sort)(struct xfrm_tmpl **, struct xfrm_tmpl **, int);
	int (*state_sort)(struct xfrm_state___3 **, struct xfrm_state___3 **, int);
	int (*output)(struct net___60 *, struct sock___2 *, struct sk_buff___50 *);
	int (*output_finish)(struct sock___2 *, struct sk_buff___50 *);
	int (*extract_input)(struct xfrm_state___3 *, struct sk_buff___50 *);
	int (*extract_output)(struct xfrm_state___3 *, struct sk_buff___50 *);
	int (*transport_finish)(struct sk_buff___50 *, int);
	void (*local_error)(struct sk_buff___50 *, u32);
};

struct napi_alloc_cache {
	struct page_frag_cache page;
	unsigned int skb_count;
	void *skb_cache[64];
};

struct crypto_async_request___22;

typedef void (*crypto_completion_t___22)(struct crypto_async_request___22 *, int);

struct crypto_tfm___22;

struct crypto_async_request___22 {
	struct list_head list;
	crypto_completion_t___22 complete;
	void *data;
	struct crypto_tfm___22 *tfm;
	u32 flags;
};

struct crypto_ablkcipher___22;

struct ablkcipher_request___22;

struct ablkcipher_tfm___22 {
	int (*setkey)(struct crypto_ablkcipher___22 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___22 *);
	int (*decrypt)(struct ablkcipher_request___22 *);
	struct crypto_ablkcipher___22 *base;
	unsigned int ivsize;
	unsigned int reqsize;
};

struct blkcipher_desc___22;

struct blkcipher_tfm___22 {
	void *iv;
	int (*setkey)(struct crypto_tfm___22 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___22 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___22 *, struct scatterlist *, struct scatterlist *, unsigned int);
};

struct cipher_tfm___22 {
	int (*cit_setkey)(struct crypto_tfm___22 *, const u8 *, unsigned int);
	void (*cit_encrypt_one)(struct crypto_tfm___22 *, u8 *, const u8 *);
	void (*cit_decrypt_one)(struct crypto_tfm___22 *, u8 *, const u8 *);
};

struct compress_tfm___22 {
	int (*cot_compress)(struct crypto_tfm___22 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*cot_decompress)(struct crypto_tfm___22 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___22;

struct crypto_tfm___22 {
	u32 crt_flags;
	union {
		struct ablkcipher_tfm___22 ablkcipher;
		struct blkcipher_tfm___22 blkcipher;
		struct cipher_tfm___22 cipher;
		struct compress_tfm___22 compress;
	} crt_u;
	void (*exit)(struct crypto_tfm___22 *);
	struct crypto_alg___22 *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct ablkcipher_request___22 {
	struct crypto_async_request___22 base;
	unsigned int nbytes;
	void *info;
	struct scatterlist *src;
	struct scatterlist *dst;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_blkcipher___22;

struct blkcipher_desc___22 {
	struct crypto_blkcipher___22 *tfm;
	void *info;
	u32 flags;
};

struct crypto_blkcipher___22 {
	struct crypto_tfm___22 base;
};

struct ablkcipher_alg___22 {
	int (*setkey)(struct crypto_ablkcipher___22 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___22 *);
	int (*decrypt)(struct ablkcipher_request___22 *);
	int (*givencrypt)(struct skcipher_givcrypt_request *);
	int (*givdecrypt)(struct skcipher_givcrypt_request *);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct crypto_ablkcipher___22 {
	struct crypto_tfm___22 base;
};

struct blkcipher_alg___22 {
	int (*setkey)(struct crypto_tfm___22 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___22 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___22 *, struct scatterlist *, struct scatterlist *, unsigned int);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct cipher_alg___22 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___22 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___22 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___22 *, u8 *, const u8 *);
};

struct compress_alg___22 {
	int (*coa_compress)(struct crypto_tfm___22 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___22 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___22 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type *cra_type;
	union {
		struct ablkcipher_alg___22 ablkcipher;
		struct blkcipher_alg___22 blkcipher;
		struct cipher_alg___22 cipher;
		struct compress_alg___22 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___22 *);
	void (*cra_exit)(struct crypto_tfm___22 *);
	void (*cra_destroy)(struct crypto_alg___22 *);
	struct module___4 *cra_module;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ahash_request___4 {
	struct crypto_async_request___22 base;
	unsigned int nbytes;
	struct scatterlist *src;
	u8 *result;
	void *priv;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

typedef struct poll_table_struct___246 poll_table___42;

struct module___334;

struct file___404;

struct kiocb___404;

struct iov_iter___171;

struct poll_table_struct___247;

struct vm_area_struct___405;

struct inode___404;

struct file_lock___404;

struct page___405;

struct pipe_inode_info___85;

struct seq_file___343;

struct file_operations___404 {
	struct module___334 *owner;
	loff_t (*llseek)(struct file___404 *, loff_t, int);
	ssize_t (*read)(struct file___404 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___404 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___404 *, struct iov_iter___171 *);
	ssize_t (*write_iter)(struct kiocb___404 *, struct iov_iter___171 *);
	int (*iopoll)(struct kiocb___404 *, bool);
	int (*iterate)(struct file___404 *, struct dir_context *);
	int (*iterate_shared)(struct file___404 *, struct dir_context *);
	__poll_t (*poll)(struct file___404 *, struct poll_table_struct___247 *);
	long int (*unlocked_ioctl)(struct file___404 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___404 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___404 *, struct vm_area_struct___405 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___404 *, struct file___404 *);
	int (*flush)(struct file___404 *, fl_owner_t);
	int (*release)(struct inode___404 *, struct file___404 *);
	int (*fsync)(struct file___404 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___404 *, int);
	int (*lock)(struct file___404 *, int, struct file_lock___404 *);
	ssize_t (*sendpage)(struct file___404 *, struct page___405 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___404 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___404 *, int, struct file_lock___404 *);
	ssize_t (*splice_write)(struct pipe_inode_info___85 *, struct file___404 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___404 *, loff_t *, struct pipe_inode_info___85 *, size_t, unsigned int);
	int (*setlease)(struct file___404 *, long int, struct file_lock___404 **, void **);
	long int (*fallocate)(struct file___404 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___343 *, struct file___404 *);
	ssize_t (*copy_file_range)(struct file___404 *, loff_t, struct file___404 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___404 *, loff_t, struct file___404 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___404 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___405 {
	u64 seqnum;
	struct vm_area_struct___405 *vmas[4];
};

struct page_frag___405 {
	struct page___405 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___405;

struct mem_cgroup___141;

struct cred___372;

struct nsproxy___299;

struct signal_struct___279;

struct bio_list___198;

struct backing_dev_info___198;

struct css_set___253;

struct vm_struct___308;

struct task_struct___406 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___406 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___405 *mm;
	struct mm_struct___405 *active_mm;
	struct vmacache___405 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___406 *real_parent;
	struct task_struct___406 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___406 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___141 *active_memcg;
	long int rh_reserved2;
	struct pid___233 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___233 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___233 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___372 *ptracer_cred;
	const struct cred___372 *real_cred;
	const struct cred___372 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___299 *nsproxy;
	struct signal_struct___279 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___406 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___198 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___198 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___253 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___85 *splice_pipe;
	struct page_frag___405 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___141 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___406 *oom_reaper_list;
	struct vm_struct___308 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___154 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rw_semaphore___406 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___406 *owner;
};

struct key___372;

struct ucounts___269;

struct user_namespace___269 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___269 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___9 ns;
	long unsigned int flags;
	struct key___372 *persistent_keyring_register;
	struct rw_semaphore___406 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___269 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___405 *pgtable_t___405;

struct address_space___404;

struct dev_pagemap___392;

struct page___405 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___404 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___405 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___405 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___405 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___392 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___141 *mem_cgroup;
};

struct pglist_data___405;

struct lruvec___405 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___405 *pgdat;
};

struct zone___405 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___405 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___405 {
	struct zone___405 *zone;
	int zone_idx;
};

struct zonelist___405 {
	struct zoneref___405 _zonerefs[25];
};

struct pglist_data___405 {
	struct zone___405 node_zones[3];
	struct zonelist___405 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___406 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___406 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___405 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___406 {
	void *stack;
	struct task_struct___406 *task;
	long int status;
};

struct blocking_notifier_head___405 {
	struct rw_semaphore___406 rwsem;
	struct notifier_block *head;
};

struct dentry___404;

struct path___405 {
	struct vfsmount *mnt;
	struct dentry___404 *dentry;
};

struct file___404 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___405 f_path;
	struct inode___404 *f_inode;
	const struct file_operations___404 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___233 f_owner;
	const struct cred___372 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___404 *f_mapping;
	errseq_t f_wb_err;
};

struct user_struct___372;

struct cred___372 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___372 *session_keyring;
	struct key___372 *process_keyring;
	struct key___372 *thread_keyring;
	struct key___372 *request_key_auth;
	void *security;
	struct user_struct___372 *user;
	struct user_namespace___269 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___398;

struct kernfs_elem_dir___398 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___398 *root;
};

struct kernfs_node___399;

struct kernfs_syscall_ops___398;

struct kernfs_root___398 {
	struct kernfs_node___399 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___398 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___398 {
	struct kernfs_node___399 *target_kn;
};

struct kernfs_ops___398;

struct kernfs_elem_attr___398 {
	const struct kernfs_ops___398 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___399 *notify_next;
};

struct kernfs_node___399 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___399 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___398 dir;
		struct kernfs_elem_symlink___398 symlink;
		struct kernfs_elem_attr___398 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___398;

struct kernfs_ops___398 {
	int (*open)(struct kernfs_open_file___398 *);
	void (*release)(struct kernfs_open_file___398 *);
	int (*seq_show)(struct seq_file___343 *, void *);
	void * (*seq_start)(struct seq_file___343 *, loff_t *);
	void * (*seq_next)(struct seq_file___343 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___343 *, void *);
	ssize_t (*read)(struct kernfs_open_file___398 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___398 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___398 *, struct vm_area_struct___405 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___398 *, struct poll_table_struct___247 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___398 {
	int (*remount_fs)(struct kernfs_root___398 *, int *, char *);
	int (*show_options)(struct seq_file___343 *, struct kernfs_root___398 *);
	int (*mkdir)(struct kernfs_node___399 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___399 *);
	int (*rename)(struct kernfs_node___399 *, struct kernfs_node___399 *, const char *);
	int (*show_path)(struct seq_file___343 *, struct kernfs_node___399 *, struct kernfs_root___398 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___343;

struct seq_file___343 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___343 *op;
	int poll_event;
	const struct file___404 *file;
	void *private;
};

struct vm_operations_struct___392;

struct kernfs_open_file___398 {
	struct kernfs_node___399 *kn;
	struct file___404 *file;
	struct seq_file___343 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___392 *vm_ops;
};

struct vm_fault___392;

struct vm_operations_struct___392 {
	void (*open)(struct vm_area_struct___405 *);
	void (*close)(struct vm_area_struct___405 *);
	int (*split)(struct vm_area_struct___405 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___405 *);
	vm_fault_t (*fault)(struct vm_fault___392 *);
	vm_fault_t (*huge_fault)(struct vm_fault___392 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___392 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___405 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___392 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___392 *);
	int (*access)(struct vm_area_struct___405 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___405 *);
	int (*set_policy)(struct vm_area_struct___405 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___405 *, long unsigned int);
	struct page___405 * (*find_special_page)(struct vm_area_struct___405 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___257)(struct file___404 *, wait_queue_head_t *, struct poll_table_struct___247 *);

struct poll_table_struct___247 {
	poll_queue_proc___257 _qproc;
	__poll_t _key;
};

struct vm_area_struct___405 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___405 *vm_next;
	struct vm_area_struct___405 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___405 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___392 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___404 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sock___34;

struct kobj_ns_type_operations___33 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___34 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct net___61;

typedef struct {
	struct net___61 *net;
} possible_net_t___51;

struct proto___33;

struct sock_common___33 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___33 *skc_prot;
	possible_net_t___51 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___34 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___51;

struct sk_buff_head___49 {
	struct sk_buff___51 *next;
	struct sk_buff___51 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___33;

struct socket_wq___34;

struct dst_entry___33;

struct socket___35;

struct net_device___51;

struct sock___34 {
	struct sock_common___33 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___49 sk_error_queue;
	struct sk_buff_head___49 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___51 *head;
		struct sk_buff___51 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___33 *sk_filter;
	union {
		struct socket_wq___34 *sk_wq;
		struct socket_wq___34 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___33 *sk_rx_dst;
	struct dst_entry___33 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___51 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___49 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___405 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___33 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___233 *sk_peer_pid;
	const struct cred___372 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___35 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___141 *sk_memcg;
	void (*sk_state_change)(struct sock___34 *);
	void (*sk_data_ready)(struct sock___34 *);
	void (*sk_write_space)(struct sock___34 *);
	void (*sk_error_report)(struct sock___34 *);
	int (*sk_backlog_rcv)(struct sock___34 *, struct sk_buff___51 *);
	struct sk_buff___51 * (*sk_validate_xmit_skb)(struct sock___34 *, struct net_device___51 *, struct sk_buff___51 *);
	void (*sk_destruct)(struct sock___34 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kobject___392;

struct bin_attribute___368;

struct attribute_group___369 {
	const char *name;
	umode_t (*is_visible)(struct kobject___392 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___392 *, struct bin_attribute___368 *, int);
	struct attribute **attrs;
	struct bin_attribute___368 **bin_attrs;
};

struct kset___391;

struct kobj_type___391;

struct kobject___392 {
	const char *name;
	struct list_head entry;
	struct kobject___392 *parent;
	struct kset___391 *kset;
	struct kobj_type___391 *ktype;
	struct kernfs_node___399 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___368 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___404 *, struct kobject___392 *, struct bin_attribute___368 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___404 *, struct kobject___392 *, struct bin_attribute___368 *, char *, loff_t, size_t);
	int (*mmap)(struct file___404 *, struct kobject___392 *, struct bin_attribute___368 *, struct vm_area_struct___405 *);
};

struct sysfs_ops___391 {
	ssize_t (*show)(struct kobject___392 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___392 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___391;

struct kset___391 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___392 kobj;
	const struct kset_uevent_ops___391 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___391 {
	void (*release)(struct kobject___392 *);
	const struct sysfs_ops___391 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___33 * (*child_ns_type)(struct kobject___392 *);
	const void * (*namespace)(struct kobject___392 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___391 {
	int (* const filter)(struct kset___391 *, struct kobject___392 *);
	const char * (* const name)(struct kset___391 *, struct kobject___392 *);
	int (* const uevent)(struct kset___391 *, struct kobject___392 *, struct kobj_uevent_env *);
};

struct kobj_attribute___382 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___392 *, struct kobj_attribute___382 *, char *);
	ssize_t (*store)(struct kobject___392 *, struct kobj_attribute___382 *, const char *, size_t);
};

struct kernel_param___332;

struct kernel_param_ops___332 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___332 *);
	int (*get)(char *, const struct kernel_param___332 *);
	void (*free)(void *);
};

struct kparam_array___332;

struct kernel_param___332 {
	const char *name;
	struct module___334 *mod;
	const struct kernel_param_ops___332 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___332 *arr;
	};
};

struct kparam_array___332 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___332 *ops;
	void *elem;
};

struct module_kobject___332 {
	struct kobject___392 kobj;
	struct module___334 *mod;
	struct kobject___392 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___332 {
	struct module___334 *mod;
	struct latch_tree_node node;
};

struct module_layout___332 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___332 mtn;
};

struct module_attribute___332;

struct module___334 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___332 mkobj;
	struct module_attribute___332 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___392 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___332 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___332 core_layout;
	struct module_layout___332 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___332 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___332 *, struct module_kobject___332 *, char *);
	ssize_t (*store)(struct module_attribute___332 *, struct module_kobject___332 *, const char *, size_t);
	void (*setup)(struct module___334 *, const char *);
	int (*test)(struct module___334 *);
	void (*free)(struct module___334 *);
};

struct user_struct___372 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___372 *uid_keyring;
	struct key___372 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___405;

struct mm_struct___405 {
	struct {
		struct vm_area_struct___405 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___404 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___406 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___405 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___406 *owner;
		struct user_namespace___269 *user_ns;
		struct file___404 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___405 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup___253;

struct cgroup_subsys___253;

struct cgroup_subsys_state___253 {
	struct cgroup___253 *cgroup;
	struct cgroup_subsys___253 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___253 *parent;
};

struct cgroup_file___253 {
	struct kernfs_node___399 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___141;

struct mem_cgroup___141 {
	struct cgroup_subsys_state___253 css;
	struct mem_cgroup_id___13 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___253 events_file;
	struct cgroup_file___253 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___406 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___141 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cgroup_namespace___253;

struct nsproxy___299 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net___61 *net_ns;
	struct cgroup_namespace___253 *cgroup_ns;
};

struct signal_struct___279 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___406 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___406 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___233 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___233 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___405 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___233 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___198;

struct bio_list___198 {
	struct bio___198 *head;
	struct bio___198 *tail;
};

struct bdi_writeback_congested___198;

struct bdi_writeback___198 {
	struct backing_dev_info___198 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___198 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___253 *memcg_css;
	struct cgroup_subsys_state___253 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___372;

struct backing_dev_info___198 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___198 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___372 *dev;
	struct device___372 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___404 *debug_dir;
	struct dentry___404 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___253 {
	struct cgroup_subsys_state___253 *subsys[13];
	refcount_t refcount;
	struct css_set___253 *dom_cset;
	struct cgroup___253 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___253 *mg_src_cgrp;
	struct cgroup___253 *mg_dst_cgrp;
	struct css_set___253 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___404;

struct pipe_buffer___85;

struct pipe_inode_info___85 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___405 *tmp_page;
	struct fasync_struct___404 *fasync_readers;
	struct fasync_struct___404 *fasync_writers;
	struct pipe_buffer___85 *bufs;
	struct user_struct___372 *user;
};

struct vm_struct___308 {
	struct vm_struct___308 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___405 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___291 {
	struct task_struct___406 task;
	long unsigned int stack[8192];
};

typedef int (*key_restrict_link_func_t___373)(struct key___372 *, const struct key_type *, const union key_payload *, struct key___372 *);

struct key_restriction___372;

struct key___372 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___406 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___372 *restrict_link;
};

struct key_restriction___372 {
	key_restrict_link_func_t___373 check;
	struct key___372 *key;
	struct key_type *keytype;
};

struct dentry_operations___404;

struct super_block___404;

struct dentry___404 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___404 *d_parent;
	struct qstr d_name;
	struct inode___404 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___404 *d_op;
	struct super_block___404 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___404;

struct address_space___404 {
	struct inode___404 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___406 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___404 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___404;

struct block_device___404;

struct inode___404 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___404 *i_op;
	struct super_block___404 *i_sb;
	struct address_space___404 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___406 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___198 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___404 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___404 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___85 *i_pipe;
		struct block_device___404 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___404 {
	int (*d_revalidate)(struct dentry___404 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___404 *, unsigned int);
	int (*d_hash)(const struct dentry___404 *, struct qstr *);
	int (*d_compare)(const struct dentry___404 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___404 *);
	int (*d_init)(struct dentry___404 *);
	void (*d_release)(struct dentry___404 *);
	void (*d_prune)(struct dentry___404 *);
	void (*d_iput)(struct dentry___404 *, struct inode___404 *);
	char * (*d_dname)(struct dentry___404 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___405 *);
	int (*d_manage)(const struct path___405 *, bool);
	struct dentry___404 * (*d_real)(struct dentry___404 *, const struct inode___404 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___404;

struct mem_dqinfo___404 {
	struct quota_format_type___404 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___404;

struct quota_info___404 {
	unsigned int flags;
	struct rw_semaphore___406 dqio_sem;
	struct inode___404 *files[3];
	struct mem_dqinfo___404 info[3];
	const struct quota_format_ops___404 *ops[3];
};

struct rcuwait___404 {
	struct task_struct___406 *task;
};

struct percpu_rw_semaphore___404 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___406 rw_sem;
	struct rcuwait___404 writer;
	int readers_block;
};

struct sb_writers___404 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___404 rw_sem[3];
};

struct shrink_control___141;

struct shrinker___141 {
	long unsigned int (*count_objects)(struct shrinker___141 *, struct shrink_control___141 *);
	long unsigned int (*scan_objects)(struct shrinker___141 *, struct shrink_control___141 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___404;

struct super_operations___404;

struct dquot_operations___404;

struct quotactl_ops___404;

struct super_block___404 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___404 *s_type;
	const struct super_operations___404 *s_op;
	const struct dquot_operations___404 *dq_op;
	const struct quotactl_ops___404 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___404 *s_root;
	struct rw_semaphore___406 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___404 *s_bdev;
	struct backing_dev_info___198 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___404 s_dquot;
	struct sb_writers___404 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___404 *s_d_op;
	int cleancache_poolid;
	struct shrinker___141 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___269 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___141 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___141 *memcg;
};

typedef int (*dev_page_fault_t___392)(struct vm_area_struct___405 *, long unsigned int, const struct page___405 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___392)(struct page___405 *, void *);

struct dev_pagemap___392 {
	dev_page_fault_t___392 page_fault;
	dev_page_free_t___392 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___372 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___405 {
	struct task_struct___406 *task;
	struct core_thread___405 *next;
};

struct core_state___405 {
	atomic_t nr_threads;
	struct core_thread___405 dumper;
	struct completion startup;
};

struct vm_fault___392 {
	struct vm_area_struct___405 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___405 *cow_page;
	struct mem_cgroup___141 *memcg;
	struct page___405 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___405 prealloc_pte;
};

struct kiocb___404 {
	struct file___404 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___404 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___404 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___404 *ia_file;
};

struct dquot___404 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___404 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___404 {
	int qf_fmt_id;
	const struct quota_format_ops___404 *qf_ops;
	struct module___334 *qf_owner;
	struct quota_format_type___404 *qf_next;
};

struct quota_format_ops___404 {
	int (*check_quota_file)(struct super_block___404 *, int);
	int (*read_file_info)(struct super_block___404 *, int);
	int (*write_file_info)(struct super_block___404 *, int);
	int (*free_file_info)(struct super_block___404 *, int);
	int (*read_dqblk)(struct dquot___404 *);
	int (*commit_dqblk)(struct dquot___404 *);
	int (*release_dqblk)(struct dquot___404 *);
	int (*get_next_id)(struct super_block___404 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___404 {
	int (*write_dquot)(struct dquot___404 *);
	struct dquot___404 * (*alloc_dquot)(struct super_block___404 *, int);
	void (*destroy_dquot)(struct dquot___404 *);
	int (*acquire_dquot)(struct dquot___404 *);
	int (*release_dquot)(struct dquot___404 *);
	int (*mark_dirty)(struct dquot___404 *);
	int (*write_info)(struct super_block___404 *, int);
	qsize_t * (*get_reserved_space)(struct inode___404 *);
	int (*get_projid)(struct inode___404 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___404 *, qsize_t *);
	int (*get_next_id)(struct super_block___404 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___404 {
	int (*quota_on)(struct super_block___404 *, int, int, const struct path___405 *);
	int (*quota_off)(struct super_block___404 *, int);
	int (*quota_enable)(struct super_block___404 *, unsigned int);
	int (*quota_disable)(struct super_block___404 *, unsigned int);
	int (*quota_sync)(struct super_block___404 *, int);
	int (*set_info)(struct super_block___404 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___404 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___404 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___404 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___404 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___404 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___161;

struct address_space_operations___404 {
	int (*writepage)(struct page___405 *, struct writeback_control___161 *);
	int (*readpage)(struct file___404 *, struct page___405 *);
	int (*writepages)(struct address_space___404 *, struct writeback_control___161 *);
	int (*set_page_dirty)(struct page___405 *);
	int (*readpages)(struct file___404 *, struct address_space___404 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___404 *, struct address_space___404 *, loff_t, unsigned int, unsigned int, struct page___405 **, void **);
	int (*write_end)(struct file___404 *, struct address_space___404 *, loff_t, unsigned int, unsigned int, struct page___405 *, void *);
	sector_t (*bmap)(struct address_space___404 *, sector_t);
	void (*invalidatepage)(struct page___405 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___405 *, gfp_t);
	void (*freepage)(struct page___405 *);
	ssize_t (*direct_IO)(struct kiocb___404 *, struct iov_iter___171 *);
	int (*migratepage)(struct address_space___404 *, struct page___405 *, struct page___405 *, enum migrate_mode);
	bool (*isolate_page)(struct page___405 *, isolate_mode_t);
	void (*putback_page)(struct page___405 *);
	int (*launder_page)(struct page___405 *);
	int (*is_partially_uptodate)(struct page___405 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___405 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___404 *, struct page___405 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___404 *, sector_t *);
	void (*swap_deactivate)(struct file___404 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___161 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___198 *wb;
	struct inode___404 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___200;

struct iov_iter___171 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___200 *bvec;
		struct pipe_inode_info___85 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___404 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___404 *bd_inode;
	struct super_block___404 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___404 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___198 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___404 {
	struct dentry___404 * (*lookup)(struct inode___404 *, struct dentry___404 *, unsigned int);
	const char * (*get_link)(struct dentry___404 *, struct inode___404 *, struct delayed_call *);
	int (*permission)(struct inode___404 *, int);
	struct posix_acl * (*get_acl)(struct inode___404 *, int);
	int (*readlink)(struct dentry___404 *, char *, int);
	int (*create)(struct inode___404 *, struct dentry___404 *, umode_t, bool);
	int (*link)(struct dentry___404 *, struct inode___404 *, struct dentry___404 *);
	int (*unlink)(struct inode___404 *, struct dentry___404 *);
	int (*symlink)(struct inode___404 *, struct dentry___404 *, const char *);
	int (*mkdir)(struct inode___404 *, struct dentry___404 *, umode_t);
	int (*rmdir)(struct inode___404 *, struct dentry___404 *);
	int (*mknod)(struct inode___404 *, struct dentry___404 *, umode_t, dev_t);
	int (*rename)(struct inode___404 *, struct dentry___404 *, struct inode___404 *, struct dentry___404 *, unsigned int);
	int (*setattr)(struct dentry___404 *, struct iattr___404 *);
	int (*getattr)(const struct path___405 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___404 *, char *, size_t);
	int (*fiemap)(struct inode___404 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___404 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___404 *, struct dentry___404 *, struct file___404 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___404 *, struct dentry___404 *, umode_t);
	int (*set_acl)(struct inode___404 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___404 {
	void (*fl_copy_lock)(struct file_lock___404 *, struct file_lock___404 *);
	void (*fl_release_private)(struct file_lock___404 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___404;

struct file_lock___404 {
	struct file_lock___404 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___404 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___404 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___404 *fl_ops;
	const struct lock_manager_operations___404 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___404 {
	int (*lm_compare_owner)(struct file_lock___404 *, struct file_lock___404 *);
	long unsigned int (*lm_owner_key)(struct file_lock___404 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___404 *);
	int (*lm_grant)(struct file_lock___404 *, int);
	bool (*lm_break)(struct file_lock___404 *);
	int (*lm_change)(struct file_lock___404 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___404 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___404 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___404 *fa_next;
	struct file___404 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___404 {
	const char *name;
	int fs_flags;
	struct dentry___404 * (*mount)(struct file_system_type___404 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___404 *);
	struct module___334 *owner;
	struct file_system_type___404 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___404 {
	struct inode___404 * (*alloc_inode)(struct super_block___404 *);
	void (*destroy_inode)(struct inode___404 *);
	void (*dirty_inode)(struct inode___404 *, int);
	int (*write_inode)(struct inode___404 *, struct writeback_control___161 *);
	int (*drop_inode)(struct inode___404 *);
	void (*evict_inode)(struct inode___404 *);
	void (*put_super)(struct super_block___404 *);
	int (*sync_fs)(struct super_block___404 *, int);
	int (*freeze_super)(struct super_block___404 *);
	int (*freeze_fs)(struct super_block___404 *);
	int (*thaw_super)(struct super_block___404 *);
	int (*unfreeze_fs)(struct super_block___404 *);
	int (*statfs)(struct dentry___404 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___404 *, int *, char *);
	void (*umount_begin)(struct super_block___404 *);
	int (*show_options)(struct seq_file___343 *, struct dentry___404 *);
	int (*show_devname)(struct seq_file___343 *, struct dentry___404 *);
	int (*show_path)(struct seq_file___343 *, struct dentry___404 *);
	int (*show_stats)(struct seq_file___343 *, struct dentry___404 *);
	ssize_t (*quota_read)(struct super_block___404 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___404 *, int, const char *, size_t, loff_t);
	struct dquot___404 ** (*get_dquots)(struct inode___404 *);
	int (*bdev_try_to_free_page)(struct super_block___404 *, struct page___405 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___404 *, struct shrink_control___141 *);
	long int (*free_cached_objects)(struct super_block___404 *, struct shrink_control___141 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___198(struct bio___198 *);

struct bio_vec___200 {
	struct page___405 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___198;

struct bio_set___198;

struct bio___198 {
	struct bio___198 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___198 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___198 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___200 *bi_io_vec;
	struct bio_set___198 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___200 bi_inline_vecs[0];
};

struct msghdr___36 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___171 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___404 *msg_iocb;
};

struct socket_wq___34 {
	wait_queue_head_t wait;
	struct fasync_struct___404 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___34;

struct socket___35 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___34 *wq;
	struct file___404 *file;
	struct sock___34 *sk;
	const struct proto_ops___34 *ops;
};

typedef int (*sk_read_actor_t___33)(read_descriptor_t *, struct sk_buff___51 *, unsigned int, size_t);

struct proto_ops___34 {
	int family;
	struct module___334 *owner;
	int (*release)(struct socket___35 *);
	int (*bind)(struct socket___35 *, struct sockaddr *, int);
	int (*connect)(struct socket___35 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___35 *, struct socket___35 *);
	int (*accept)(struct socket___35 *, struct socket___35 *, int, bool);
	int (*getname)(struct socket___35 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___404 *, struct socket___35 *, struct poll_table_struct___247 *);
	int (*ioctl)(struct socket___35 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___35 *, int);
	int (*shutdown)(struct socket___35 *, int);
	int (*setsockopt)(struct socket___35 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___35 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___35 *, struct msghdr___36 *, size_t);
	int (*recvmsg)(struct socket___35 *, struct msghdr___36 *, size_t, int);
	int (*mmap)(struct file___404 *, struct socket___35 *, struct vm_area_struct___405 *);
	ssize_t (*sendpage)(struct socket___35 *, struct page___405 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___35 *, loff_t *, struct pipe_inode_info___85 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___34 *, int);
	int (*peek_len)(struct socket___35 *);
	int (*read_sock)(struct sock___34 *, read_descriptor_t *, sk_read_actor_t___33);
	int (*sendpage_locked)(struct sock___34 *, struct page___405 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___34 *, struct msghdr___36 *, size_t);
	int (*set_rcvlowat)(struct sock___34 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct nf_bridge_info___49;

struct sk_buff___51 {
	union {
		struct {
			struct sk_buff___51 *next;
			struct sk_buff___51 *prev;
			union {
				struct net_device___51 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___34 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___51 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___49 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___49;

struct netns_frags___49 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___49 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_rules_ops___33;

struct fib_notifier_ops___33;

struct netns_ipv4___49 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___33 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___34 *fibnl;
	struct sock___34 **icmp_sk;
	struct sock___34 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___34 **tcp_sk;
	struct netns_frags___49 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___33 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___33 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___33 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___33;

struct dst_ops___60 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___60 *);
	struct dst_entry___33 * (*check)(struct dst_entry___33 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___33 *);
	unsigned int (*mtu)(const struct dst_entry___33 *);
	u32 * (*cow_metrics)(struct dst_entry___33 *, long unsigned int);
	void (*destroy)(struct dst_entry___33 *);
	void (*ifdown)(struct dst_entry___33 *, struct net_device___51 *, int);
	struct dst_entry___33 * (*negative_advice)(struct dst_entry___33 *);
	void (*link_failure)(struct sk_buff___51 *);
	void (*update_pmtu)(struct dst_entry___33 *, struct sock___34 *, struct sk_buff___51 *, u32);
	void (*redirect)(struct dst_entry___33 *, struct sock___34 *, struct sk_buff___51 *);
	int (*local_out)(struct net___61 *, struct sock___34 *, struct sk_buff___51 *);
	struct neighbour___33 * (*neigh_lookup)(const struct dst_entry___33 *, struct sk_buff___51 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___33 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___60 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___49 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___60 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___33 *fib6_rules_ops;
	struct sock___34 **icmp_sk;
	struct sock___34 *ndisc_sk;
	struct sock___34 *tcp_sk;
	struct sock___34 *igmp_sk;
	struct sock___34 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___33 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___33 *notifier_ops;
	struct fib_notifier_ops___33 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___34 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___34 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___49 {
	struct netns_frags___49 frags;
};

struct netns_xfrm___60 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___34 *nlsk;
	struct sock___34 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___60 xfrm4_dst_ops;
	struct dst_ops___60 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___43;

struct net___61 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___269 *user_ns;
	struct ucounts___269 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___9 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___34 *rtnl;
	struct sock___34 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___51 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___49 ipv4;
	struct netns_ipv6___60 ipv6;
	struct netns_sctp___34 sctp;
	struct netns_nf___3 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___49 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___34 *nfnl;
	struct sock___34 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___60 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___34 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___43 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___372 {
	int (*prepare)(struct device___372 *);
	void (*complete)(struct device___372 *);
	int (*suspend)(struct device___372 *);
	int (*resume)(struct device___372 *);
	int (*freeze)(struct device___372 *);
	int (*thaw)(struct device___372 *);
	int (*poweroff)(struct device___372 *);
	int (*restore)(struct device___372 *);
	int (*suspend_late)(struct device___372 *);
	int (*resume_early)(struct device___372 *);
	int (*freeze_late)(struct device___372 *);
	int (*thaw_early)(struct device___372 *);
	int (*poweroff_late)(struct device___372 *);
	int (*restore_early)(struct device___372 *);
	int (*suspend_noirq)(struct device___372 *);
	int (*resume_noirq)(struct device___372 *);
	int (*freeze_noirq)(struct device___372 *);
	int (*thaw_noirq)(struct device___372 *);
	int (*poweroff_noirq)(struct device___372 *);
	int (*restore_noirq)(struct device___372 *);
	int (*runtime_suspend)(struct device___372 *);
	int (*runtime_resume)(struct device___372 *);
	int (*runtime_idle)(struct device___372 *);
};

struct dev_pm_info___372 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___372 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___372;

struct bus_type___372;

struct device_driver___372;

struct dev_pm_domain___372;

struct dma_map_ops___144;

struct fwnode_handle___292;

struct class___372;

struct device___372 {
	struct device___372 *parent;
	struct device_private *p;
	struct kobject___392 kobj;
	const char *init_name;
	const struct device_type___372 *type;
	struct mutex mutex;
	struct bus_type___372 *bus;
	struct device_driver___372 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___372 power;
	struct dev_pm_domain___372 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___144 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___292 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___372 *class;
	const struct attribute_group___369 **groups;
	void (*release)(struct device___372 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___372 {
	struct dev_pm_ops___372 ops;
	void (*detach)(struct device___372 *, bool);
	int (*activate)(struct device___372 *);
	void (*sync)(struct device___372 *);
	void (*dismiss)(struct device___372 *);
};

struct bus_type___372 {
	const char *name;
	const char *dev_name;
	struct device___372 *dev_root;
	const struct attribute_group___369 **bus_groups;
	const struct attribute_group___369 **dev_groups;
	const struct attribute_group___369 **drv_groups;
	int (*match)(struct device___372 *, struct device_driver___372 *);
	int (*uevent)(struct device___372 *, struct kobj_uevent_env *);
	int (*probe)(struct device___372 *);
	int (*remove)(struct device___372 *);
	void (*shutdown)(struct device___372 *);
	int (*online)(struct device___372 *);
	int (*offline)(struct device___372 *);
	int (*suspend)(struct device___372 *, pm_message_t);
	int (*resume)(struct device___372 *);
	int (*num_vf)(struct device___372 *);
	int (*dma_configure)(struct device___372 *);
	const struct dev_pm_ops___372 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___372 {
	const char *name;
	struct bus_type___372 *bus;
	struct module___334 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___372 *);
	int (*remove)(struct device___372 *);
	void (*shutdown)(struct device___372 *);
	int (*suspend)(struct device___372 *, pm_message_t);
	int (*resume)(struct device___372 *);
	const struct attribute_group___369 **groups;
	const struct dev_pm_ops___372 *pm;
	void (*coredump)(struct device___372 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___372 {
	const char *name;
	const struct attribute_group___369 **groups;
	int (*uevent)(struct device___372 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___372 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___372 *);
	const struct dev_pm_ops___372 *pm;
};

struct class___372 {
	const char *name;
	struct module___334 *owner;
	const struct attribute_group___369 **class_groups;
	const struct attribute_group___369 **dev_groups;
	struct kobject___392 *dev_kobj;
	int (*dev_uevent)(struct device___372 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___372 *, umode_t *);
	void (*class_release)(struct class___372 *);
	void (*dev_release)(struct device___372 *);
	int (*shutdown_pre)(struct device___372 *);
	const struct kobj_ns_type_operations___33 *ns_type;
	const void * (*namespace)(struct device___372 *);
	const struct dev_pm_ops___372 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___144 {
	void * (*alloc)(struct device___372 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___372 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___372 *, struct vm_area_struct___405 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___372 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___372 *, struct page___405 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___372 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___372 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___372 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___372 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___372 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___372 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___372 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___372 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___372 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___372 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___372 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___372 *, u64);
	u64 (*get_required_mask)(struct device___372 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___292;

struct fwnode_handle___292 {
	struct fwnode_handle___292 *secondary;
	const struct fwnode_operations___292 *ops;
};

typedef void compound_page_dtor___392(struct page___405 *);

struct fwnode_reference_args___292;

struct fwnode_endpoint___292;

struct fwnode_operations___292 {
	struct fwnode_handle___292 * (*get)(struct fwnode_handle___292 *);
	void (*put)(struct fwnode_handle___292 *);
	bool (*device_is_available)(const struct fwnode_handle___292 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___292 *, const struct device___372 *);
	bool (*property_present)(const struct fwnode_handle___292 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___292 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___292 *, const char *, const char **, size_t);
	struct fwnode_handle___292 * (*get_parent)(const struct fwnode_handle___292 *);
	struct fwnode_handle___292 * (*get_next_child_node)(const struct fwnode_handle___292 *, struct fwnode_handle___292 *);
	struct fwnode_handle___292 * (*get_named_child_node)(const struct fwnode_handle___292 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___292 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___292 *);
	struct fwnode_handle___292 * (*graph_get_next_endpoint)(const struct fwnode_handle___292 *, struct fwnode_handle___292 *);
	struct fwnode_handle___292 * (*graph_get_remote_endpoint)(const struct fwnode_handle___292 *);
	struct fwnode_handle___292 * (*graph_get_port_parent)(struct fwnode_handle___292 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___292 *, struct fwnode_endpoint___292 *);
};

struct fwnode_endpoint___292 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___292 *local_fwnode;
};

struct fwnode_reference_args___292 {
	struct fwnode_handle___292 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___85;

struct pipe_buffer___85 {
	struct page___405 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___85 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___85 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___85 *, struct pipe_buffer___85 *);
	void (*release)(struct pipe_inode_info___85 *, struct pipe_buffer___85 *);
	int (*steal)(struct pipe_inode_info___85 *, struct pipe_buffer___85 *);
	union {
		bool (*get)(struct pipe_inode_info___85 *, struct pipe_buffer___85 *);
		struct {
			void (*get)(struct pipe_inode_info___85 *, struct pipe_buffer___85 *);
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
};

struct nf_bridge_info___49 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___49 = 0,
		BRNF_PROTO_8021Q___49 = 1,
		BRNF_PROTO_PPPOE___49 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___51 *physindev;
	struct net_device___51 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___49(struct sk_buff___51 **);

struct net_device_ops___49;

struct ethtool_ops___49;

struct l3mdev_ops___33;

struct xfrmdev_ops___49;

struct tlsdev_ops___49;

struct header_ops___49;

struct netdev_rx_queue___49;

struct mini_Qdisc___43;

struct netdev_queue___49;

struct Qdisc___43;

struct rtnl_link_ops___43;

struct dcbnl_rtnl_ops___49;

struct net_device___51 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___49 *netdev_ops;
	const struct ethtool_ops___49 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___33 *l3mdev_ops;
	const struct ndisc_ops___2 *ndisc_ops;
	const struct xfrmdev_ops___49 *xfrmdev_ops;
	const struct tlsdev_ops___49 *tlsdev_ops;
	const struct header_ops___49 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___391 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___2 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___49 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___43 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___49 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___43 *miniq_ingress;
	struct netdev_queue___49 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___49 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___43 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___43 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___49 = 0,
		NETREG_REGISTERED___49 = 1,
		NETREG_UNREGISTERING___49 = 2,
		NETREG_UNREGISTERED___49 = 3,
		NETREG_RELEASED___49 = 4,
		NETREG_DUMMY___49 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___49 = 0,
		RTNL_LINK_INITIALIZING___49 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___51 *);
	struct netpoll_info *npinfo;
	possible_net_t___51 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___372 dev;
	const struct attribute_group___369 *sysfs_groups[4];
	const struct attribute_group___369 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___43 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___49 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide35;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct ethtool_ops___49 {
	int (*get_settings)(struct net_device___51 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___51 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___51 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___51 *);
	void (*get_regs)(struct net_device___51 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___51 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___51 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___51 *);
	void (*set_msglevel)(struct net_device___51 *, u32);
	int (*nway_reset)(struct net_device___51 *);
	u32 (*get_link)(struct net_device___51 *);
	int (*get_eeprom_len)(struct net_device___51 *);
	int (*get_eeprom)(struct net_device___51 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___51 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___51 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___51 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___51 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___51 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___51 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___51 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___51 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___51 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___51 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___51 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___51 *);
	void (*complete)(struct net_device___51 *);
	u32 (*get_priv_flags)(struct net_device___51 *);
	int (*set_priv_flags)(struct net_device___51 *, u32);
	int (*get_sset_count)(struct net_device___51 *, int);
	int (*get_rxnfc)(struct net_device___51 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___51 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___51 *, struct ethtool_flash *);
	int (*reset)(struct net_device___51 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___51 *);
	u32 (*get_rxfh_indir_size)(struct net_device___51 *);
	int (*get_rxfh)(struct net_device___51 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___51 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___51 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___51 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___51 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___51 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___51 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___51 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___51 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___51 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___51 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___51 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___51 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___51 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___51 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___51 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___51 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___51 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___51 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___51 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___51 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___51 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	int (*get_fecparam)(struct net_device___51 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___51 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___51 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___51 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___51 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___49;

struct inet_frags___49 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___49 *, const void *);
	void (*destructor)(struct inet_frag_queue___49 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___49 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___51 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___51 *fragments_tail;
	struct sk_buff___51 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___49 *net;
	struct callback_head rcu;
};

struct fib_rule___33;

struct fib_lookup_arg___33;

struct fib_rules_ops___33 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___33 *, struct flowi *, int, struct fib_lookup_arg___33 *);
	bool (*suppress)(struct fib_rule___33 *, struct fib_lookup_arg___33 *);
	int (*match)(struct fib_rule___33 *, struct flowi *, int);
	int (*configure)(struct fib_rule___33 *, struct sk_buff___51 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___33 *);
	int (*compare)(struct fib_rule___33 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___33 *, struct sk_buff___51 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___33 *);
	void (*flush_cache)(struct fib_rules_ops___33 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___334 *owner;
	struct net___61 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___33 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___61 *);
	int (*fib_dump)(struct net___61 *, struct notifier_block *);
	struct module___334 *owner;
	struct callback_head rcu;
};

struct dst_entry___33 {
	struct net_device___51 *dev;
	struct dst_ops___60 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___51 *);
	int (*output)(struct net___61 *, struct sock___34 *, struct sk_buff___51 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___33;

struct neigh_parms___33;

struct neigh_ops___33;

struct neighbour___33 {
	struct neighbour___33 *next;
	struct neigh_table___33 *tbl;
	struct neigh_parms___33 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___49 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___33 *, struct sk_buff___51 *);
	const struct neigh_ops___33 *ops;
	struct callback_head rcu;
	struct net_device___51 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct ucounts___269 {
	struct hlist_node node;
	struct user_namespace___269 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_prog_aux___46;

struct bpf_prog___43 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___46 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

struct seq_operations___343 {
	void * (*start)(struct seq_file___343 *, loff_t *);
	void (*stop)(struct seq_file___343 *, void *);
	void * (*next)(struct seq_file___343 *, void *, loff_t *);
	int (*show)(struct seq_file___343 *, void *);
};

struct pernet_operations___50 {
	struct list_head list;
	int (*init)(struct net___61 *);
	void (*exit)(struct net___61 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___49 {
	int (*ieee_getets)(struct net_device___51 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___51 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___51 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___51 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___51 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___51 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___51 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___51 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___51 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___51 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___51 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___51 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___51 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___51 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___51 *);
	u8 (*setstate)(struct net_device___51 *, u8);
	void (*getpermhwaddr)(struct net_device___51 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___51 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___51 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___51 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___51 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___51 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___51 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___51 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___51 *, int, u8 *);
	void (*setpfccfg)(struct net_device___51 *, int, u8);
	void (*getpfccfg)(struct net_device___51 *, int, u8 *);
	u8 (*setall)(struct net_device___51 *);
	u8 (*getcap)(struct net_device___51 *, int, u8 *);
	int (*getnumtcs)(struct net_device___51 *, int, u8 *);
	int (*setnumtcs)(struct net_device___51 *, int, u8);
	u8 (*getpfcstate)(struct net_device___51 *);
	void (*setpfcstate)(struct net_device___51 *, u8);
	void (*getbcncfg)(struct net_device___51 *, int, u32 *);
	void (*setbcncfg)(struct net_device___51 *, int, u32);
	void (*getbcnrp)(struct net_device___51 *, int, u8 *);
	void (*setbcnrp)(struct net_device___51 *, int, u8);
	int (*setapp)(struct net_device___51 *, u8, u16, u8);
	int (*getapp)(struct net_device___51 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___51 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___51 *, int, u8);
	u8 (*getdcbx)(struct net_device___51 *);
	u8 (*setdcbx)(struct net_device___51 *, u8);
	int (*peer_getappinfo)(struct net_device___51 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___51 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___51 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___51 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___51 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___51 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___253 {
	refcount_t count;
	struct ns_common___9 ns;
	struct user_namespace___269 *user_ns;
	struct ucounts___269 *ucounts;
	struct css_set___253 *root_cset;
};

struct bpf_map___254;

struct bpf_map_ops___253 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___254 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___254 *, struct file___404 *);
	void (*map_free)(struct bpf_map___254 *);
	int (*map_get_next_key)(struct bpf_map___254 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___254 *);
	void * (*map_lookup_elem)(struct bpf_map___254 *, void *);
	int (*map_update_elem)(struct bpf_map___254 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___254 *, void *);
	int (*map_push_elem)(struct bpf_map___254 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___254 *, void *);
	int (*map_peek_elem)(struct bpf_map___254 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___254 *, struct file___404 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___254 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___254 *, void *, struct seq_file___343 *);
	int (*map_check_btf)(const struct bpf_map___254 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___254 {
	const struct bpf_map_ops___253 *ops;
	struct bpf_map___254 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___372 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___49;

struct bpf_map_dev_ops___49 {
	int (*map_get_next_key)(struct bpf_offloaded_map___49 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___49 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___49 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___49 *, void *);
};

struct bpf_offloaded_map___49 {
	struct bpf_map___254 map;
	struct net_device___51 *netdev;
	const struct bpf_map_dev_ops___49 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___43 {
	int (*test_run)(struct bpf_prog___43 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___43 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___43 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___43 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___43 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___43 *, u32 *);
};

struct bpf_prog_offload_ops___43 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___43 *);
	int (*translate)(struct bpf_prog___43 *);
	void (*destroy)(struct bpf_prog___43 *);
};

struct bpf_prog_offload___43 {
	struct bpf_prog___43 *prog;
	struct net_device___51 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___43 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___46 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___43 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___43 *ops;
	struct bpf_map___254 **used_maps;
	struct bpf_prog___43 *prog;
	struct user_struct___372 *user;
	u64 load_time;
	struct bpf_map___254 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___43 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___43 {
	struct bpf_prog___43 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___43 {
	struct callback_head rcu;
	struct bpf_prog_array_item___43 items[0];
};

struct cgroup_bpf___43 {
	struct bpf_prog_array___43 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___43 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___254;

typedef void (*kthread_work_func_t___254)(struct kthread_work___254 *);

struct kthread_worker___254;

struct kthread_work___254 {
	struct list_head node;
	kthread_work_func_t___254 func;
	struct kthread_worker___254 *worker;
	int canceling;
};

struct kthread_worker___254 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___406 *task;
	struct kthread_work___254 *current_work;
};

struct kthread_delayed_work___253 {
	struct kthread_work___254 work;
	struct timer_list timer;
};

struct psi_group___253 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___254 *poll_kworker;
	struct kthread_delayed_work___253 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___253;

struct cgroup_rstat_cpu___253;

struct cgroup___253 {
	struct cgroup_subsys_state___253 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___399 *kn;
	struct cgroup_file___253 procs_file;
	struct cgroup_file___253 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___253 *subsys[13];
	struct cgroup_root___253 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___253 *dom_cgrp;
	struct cgroup_rstat_cpu___253 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___43 bpf;
	atomic_t congestion_count;
	struct cgroup___253 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___253 psi;
	int ancestor_ids[0];
};

struct cftype___253;

struct cgroup_subsys___253 {
	struct cgroup_subsys_state___253 * (*css_alloc)(struct cgroup_subsys_state___253 *);
	int (*css_online)(struct cgroup_subsys_state___253 *);
	void (*css_offline)(struct cgroup_subsys_state___253 *);
	void (*css_released)(struct cgroup_subsys_state___253 *);
	void (*css_free)(struct cgroup_subsys_state___253 *);
	void (*css_reset)(struct cgroup_subsys_state___253 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___253 *, int);
	int (*css_extra_stat_show)(struct seq_file___343 *, struct cgroup_subsys_state___253 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___406 *);
	void (*cancel_fork)(struct task_struct___406 *);
	void (*fork)(struct task_struct___406 *);
	void (*exit)(struct task_struct___406 *);
	void (*free)(struct task_struct___406 *);
	void (*bind)(struct cgroup_subsys_state___253 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___253 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___253 *dfl_cftypes;
	struct cftype___253 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___253 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___253 *updated_children;
	struct cgroup___253 *updated_next;
};

struct cgroup_root___253 {
	struct kernfs_root___398 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___253 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___253 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___253 *ss;
	struct list_head node;
	struct kernfs_ops___398 *kf_ops;
	int (*open)(struct kernfs_open_file___398 *);
	void (*release)(struct kernfs_open_file___398 *);
	u64 (*read_u64)(struct cgroup_subsys_state___253 *, struct cftype___253 *);
	s64 (*read_s64)(struct cgroup_subsys_state___253 *, struct cftype___253 *);
	int (*seq_show)(struct seq_file___343 *, void *);
	void * (*seq_start)(struct seq_file___343 *, loff_t *);
	void * (*seq_next)(struct seq_file___343 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___343 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___253 *, struct cftype___253 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___253 *, struct cftype___253 *, s64);
	ssize_t (*write)(struct kernfs_open_file___398 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___398 *, struct poll_table_struct___247 *);
};

struct xdp_rxq_info___49 {
	struct net_device___51 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___49 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___51 *dev_rx;
};

struct netlink_callback___51 {
	struct sk_buff___51 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___51 *);
	int (*dump)(struct sk_buff___51 *, struct netlink_callback___51 *);
	int (*done)(struct netlink_callback___51 *);
	void *data;
	struct module___334 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___49 {
	int (*create)(struct sk_buff___51 *, struct net_device___51 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___51 *, unsigned char *);
	int (*cache)(const struct neighbour___33 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___51 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___49 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___49 *, int);
	int poll_owner;
	struct net_device___51 *dev;
	struct sk_buff___51 *gro_list;
	struct sk_buff___51 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___49 {
	struct net_device___51 *dev;
	struct Qdisc___43 *qdisc;
	struct Qdisc___43 *qdisc_sleeping;
	struct kobject___392 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___51 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___43 {
	struct sk_buff___51 *head;
	struct sk_buff___51 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___43;

struct Qdisc___43 {
	int (*enqueue)(struct sk_buff___51 *, struct Qdisc___43 *, struct sk_buff___51 **);
	struct sk_buff___51 * (*dequeue)(struct Qdisc___43 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___43 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___49 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___49 gso_skb;
	struct qdisc_skb_head___43 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___43 *next_sched;
	struct sk_buff_head___49 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___49 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___392 kobj;
	struct net_device___51 *dev;
	long: 64;
	struct xdp_rxq_info___49 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___49)(struct net_device___51 *, struct sk_buff___51 *, struct net_device___51 *);

struct netdev_bpf___49 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___43 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___43 *prog;
			const struct bpf_prog_offload_ops___43 *ops;
		} verifier;
		struct {
			struct bpf_prog___43 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___49 *offmap;
		};
		struct {
			struct xdp_umem *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___49 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___51 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___49 {
	int (*tls_dev_add)(struct net_device___51 *, struct sock___34 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___51 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___51 *, struct sock___34 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___49 {
	int (*ndo_init)(struct net_device___51 *);
	void (*ndo_uninit)(struct net_device___51 *);
	int (*ndo_open)(struct net_device___51 *);
	int (*ndo_stop)(struct net_device___51 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___51 *, struct net_device___51 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___51 *, struct net_device___51 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___51 *, struct sk_buff___51 *, struct net_device___51 *, select_queue_fallback_t___49);
	void (*ndo_change_rx_flags)(struct net_device___51 *, int);
	void (*ndo_set_rx_mode)(struct net_device___51 *);
	int (*ndo_set_mac_address)(struct net_device___51 *, void *);
	int (*ndo_validate_addr)(struct net_device___51 *);
	int (*ndo_do_ioctl)(struct net_device___51 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___51 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___51 *, int);
	int (*ndo_neigh_setup)(struct net_device___51 *, struct neigh_parms___33 *);
	void (*ndo_tx_timeout)(struct net_device___51 *);
	void (*ndo_get_stats64)(struct net_device___51 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___51 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___51 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___51 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___51 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___51 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___51 *);
	int (*ndo_netpoll_setup)(struct net_device___51 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___51 *);
	int (*ndo_set_vf_mac)(struct net_device___51 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___51 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___51 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___51 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___51 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___51 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___51 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___51 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___51 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___51 *, int, struct sk_buff___51 *);
	int (*ndo_set_vf_guid)(struct net_device___51 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___51 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___51 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___51 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___51 *, const struct sk_buff___51 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___51 *, struct net_device___51 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___51 *, struct net_device___51 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___51 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___51 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___51 *, struct neighbour___33 *);
	void (*ndo_neigh_destroy)(struct net_device___51 *, struct neighbour___33 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___51 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___51 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___51 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___51 *, struct netlink_callback___51 *, struct net_device___51 *, struct net_device___51 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___51 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___51 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___51 *, u32, u32, struct net_device___51 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___51 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___51 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___51 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___51 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___51 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___51 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___51 *, struct net_device___51 *);
	void (*ndo_dfwd_del_station)(struct net_device___51 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___51 *);
	int (*ndo_set_tx_maxrate)(struct net_device___51 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___51 *);
	int (*ndo_change_proto_down)(struct net_device___51 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___51 *, struct sk_buff___51 *);
	void (*ndo_set_rx_headroom)(struct net_device___51 *, int);
	int (*ndo_bpf)(struct net_device___51 *, struct netdev_bpf___49 *);
	int (*ndo_xdp_xmit)(struct net_device___51 *, int, struct xdp_frame___49 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___51 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___51 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___33 {
	possible_net_t___51 net;
	struct net_device___51 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___33 *);
	void (*neigh_cleanup)(struct neighbour___33 *);
	struct neigh_table___33 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___33 {
	u32 (*l3mdev_fib_table)(const struct net_device___51 *);
	struct sk_buff___51 * (*l3mdev_l3_rcv)(struct net_device___51 *, struct sk_buff___51 *, u16);
	struct sk_buff___51 * (*l3mdev_l3_out)(struct net_device___51 *, struct sock___34 *, struct sk_buff___51 *, u16);
	struct dst_entry___33 * (*l3mdev_link_scope_lookup)(const struct net_device___51 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct tcf_proto___43;

struct mini_Qdisc___43 {
	struct tcf_proto___43 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___43 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___51 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___61 *, struct net_device___51 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___51 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___51 *, struct list_head *);
	size_t (*get_size)(const struct net_device___51 *);
	int (*fill_info)(struct sk_buff___51 *, const struct net_device___51 *);
	size_t (*get_xstats_size)(const struct net_device___51 *);
	int (*fill_xstats)(struct sk_buff___51 *, const struct net_device___51 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___51 *, struct net_device___51 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___51 *, const struct net_device___51 *);
	int (*fill_slave_info)(struct sk_buff___51 *, const struct net_device___51 *, const struct net_device___51 *);
	struct net___61 * (*get_link_net)(const struct net_device___51 *);
	size_t (*get_linkxstats_size)(const struct net_device___51 *, int);
	int (*fill_linkxstats)(struct sk_buff___51 *, const struct net_device___51 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___49 {
	struct list_head poll_list;
	struct sk_buff_head___49 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___49 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___43 *output_queue;
	struct Qdisc___43 **output_queue_tailp;
	struct sk_buff___51 *completion_queue;
	struct sk_buff_head___49 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___49 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___49 input_pkt_queue;
	struct napi_struct___49 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bdi_writeback_congested___198 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___198 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___198 {
	struct bio___198 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___200 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___200 bip_inline_vecs[0];
};

struct bio_set___198 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___198 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___141 {
	struct mem_cgroup___141 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___141 {
	struct lruvec___405 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___141 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___141 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct gnet_dump___43 {
	spinlock_t *lock;
	struct sk_buff___51 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___43;

struct Qdisc_ops___43 {
	struct Qdisc_ops___43 *next;
	const struct Qdisc_class_ops___43 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___51 *, struct Qdisc___43 *, struct sk_buff___51 **);
	struct sk_buff___51 * (*dequeue)(struct Qdisc___43 *);
	struct sk_buff___51 * (*peek)(struct Qdisc___43 *);
	int (*init)(struct Qdisc___43 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___43 *);
	void (*destroy)(struct Qdisc___43 *);
	int (*change)(struct Qdisc___43 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___43 *);
	int (*change_tx_queue_len)(struct Qdisc___43 *, unsigned int);
	int (*dump)(struct Qdisc___43 *, struct sk_buff___51 *);
	int (*dump_stats)(struct Qdisc___43 *, struct gnet_dump___43 *);
	void (*ingress_block_set)(struct Qdisc___43 *, u32);
	void (*egress_block_set)(struct Qdisc___43 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___43 *);
	u32 (*egress_block_get)(struct Qdisc___43 *);
	struct module___334 *owner;
};

struct tcf_block___43;

struct Qdisc_class_ops___43 {
	unsigned int flags;
	struct netdev_queue___49 * (*select_queue)(struct Qdisc___43 *, struct tcmsg *);
	int (*graft)(struct Qdisc___43 *, long unsigned int, struct Qdisc___43 *, struct Qdisc___43 **, struct netlink_ext_ack *);
	struct Qdisc___43 * (*leaf)(struct Qdisc___43 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___43 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___43 *, u32);
	int (*change)(struct Qdisc___43 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___43 *, long unsigned int);
	void (*walk)(struct Qdisc___43 *, struct qdisc_walker *);
	struct tcf_block___43 * (*tcf_block)(struct Qdisc___43 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___43 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___43 *, long unsigned int);
	int (*dump)(struct Qdisc___43 *, long unsigned int, struct sk_buff___51 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___43 *, long unsigned int, struct gnet_dump___43 *);
};

struct tcf_chain___43;

struct tcf_block___43 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___61 *net;
	struct Qdisc___43 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___43 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___43;

struct tcf_proto_ops___43;

struct tcf_proto___43 {
	struct tcf_proto___43 *next;
	void *root;
	int (*classify)(struct sk_buff___51 *, const struct tcf_proto___43 *, struct tcf_result___43 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___43 *ops;
	struct tcf_chain___43 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___43 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___43 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___43 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___51 *, const struct tcf_proto___43 *, struct tcf_result___43 *);
	int (*init)(struct tcf_proto___43 *);
	void (*destroy)(struct tcf_proto___43 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___43 *, u32);
	void (*put)(struct tcf_proto___43 *, void *);
	int (*change)(struct net___61 *, struct sk_buff___51 *, struct tcf_proto___43 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___43 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___43 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___43 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___61 *, struct tcf_chain___43 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___61 *, struct tcf_proto___43 *, void *, struct sk_buff___51 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___51 *, struct net___61 *, void *);
	struct module___334 *owner;
	int flags;
};

struct tcf_chain___43 {
	struct mutex filter_chain_lock;
	struct tcf_proto___43 *filter_chain;
	struct list_head list;
	struct tcf_block___43 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___43 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___33 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___43 *prog;
};

struct bpf_redirect_info___43 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___254 *map;
	struct bpf_map___254 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___33;

struct neigh_hash_table___33;

struct neigh_table___33 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___51 *, __u32 *);
	bool (*key_eq)(const struct neighbour___33 *, const void *);
	int (*constructor)(struct neighbour___33 *);
	int (*pconstructor)(struct pneigh_entry___33 *);
	void (*pdestructor)(struct pneigh_entry___33 *);
	void (*proxy_redo)(struct sk_buff___51 *);
	char *id;
	struct neigh_parms___33 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___49 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___33 *nht;
	struct pneigh_entry___33 **phash_buckets;
};

struct neigh_ops___33 {
	int family;
	void (*solicit)(struct neighbour___33 *, struct sk_buff___51 *);
	void (*error_report)(struct neighbour___33 *, struct sk_buff___51 *);
	int (*output)(struct neighbour___33 *, struct sk_buff___51 *);
	int (*connected_output)(struct neighbour___33 *, struct sk_buff___51 *);
};

struct pneigh_entry___33 {
	struct pneigh_entry___33 *next;
	possible_net_t___51 net;
	struct net_device___51 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___33 {
	struct neighbour___33 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___33 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___33 *ctarget;
	struct net___61 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___33 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___33 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___22;

struct timewait_sock_ops___20;

struct proto___33 {
	void (*close)(struct sock___34 *, long int);
	int (*pre_connect)(struct sock___34 *, struct sockaddr *, int);
	int (*connect)(struct sock___34 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___34 *, int);
	struct sock___34 * (*accept)(struct sock___34 *, int, int *, bool);
	int (*ioctl)(struct sock___34 *, int, long unsigned int);
	int (*init)(struct sock___34 *);
	void (*destroy)(struct sock___34 *);
	void (*shutdown)(struct sock___34 *, int);
	int (*setsockopt)(struct sock___34 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___34 *, int, int, char *, int *);
	void (*keepalive)(struct sock___34 *, int);
	int (*sendmsg)(struct sock___34 *, struct msghdr___36 *, size_t);
	int (*recvmsg)(struct sock___34 *, struct msghdr___36 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___34 *, struct page___405 *, int, size_t, int);
	int (*bind)(struct sock___34 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___34 *, struct sk_buff___51 *);
	void (*release_cb)(struct sock___34 *);
	int (*hash)(struct sock___34 *);
	void (*unhash)(struct sock___34 *);
	void (*rehash)(struct sock___34 *);
	int (*get_port)(struct sock___34 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___34 *);
	bool (*stream_memory_read)(const struct sock___34 *);
	void (*enter_memory_pressure)(struct sock___34 *);
	void (*leave_memory_pressure)(struct sock___34 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___22 *rsk_prot;
	struct timewait_sock_ops___20 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___334 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___34 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct request_sock___23;

struct request_sock_ops___22 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___34 *, struct request_sock___23 *);
	void (*send_ack)(const struct sock___34 *, struct sk_buff___51 *, struct request_sock___23 *);
	void (*send_reset)(const struct sock___34 *, struct sk_buff___51 *);
	void (*destructor)(struct request_sock___23 *);
	void (*syn_ack_timeout)(const struct request_sock___23 *);
};

struct timewait_sock_ops___20 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___34 *, struct sock___34 *, void *);
	void (*twsk_destructor)(struct sock___34 *);
};

struct request_sock___23 {
	struct sock_common___33 __req_common;
	struct request_sock___23 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___22 *rsk_ops;
	struct sock___34 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct scm_fp_list {
	short int count;
	short int max;
	struct user_struct___371 *user;
	struct file___403 *fp[253];
};

struct scm_cookie {
	struct pid___233 *pid;
	struct scm_fp_list *fp;
	struct scm_creds creds;
	u32 secid;
};

struct cgroup_cls_state___2 {
	struct cgroup_subsys_state___252 css;
	u32 classid;
};

enum {
	TCA_STATS_UNSPEC = 0,
	TCA_STATS_BASIC = 1,
	TCA_STATS_RATE_EST = 2,
	TCA_STATS_QUEUE = 3,
	TCA_STATS_APP = 4,
	TCA_STATS_RATE_EST64 = 5,
	TCA_STATS_PAD = 6,
	TCA_STATS_BASIC_HW = 7,
	__TCA_STATS_MAX = 8,
};

struct gnet_stats_basic {
	__u64 bytes;
	__u32 packets;
};

struct gnet_stats_rate_est {
	__u32 bps;
	__u32 pps;
};

struct gnet_stats_rate_est64 {
	__u64 bps;
	__u64 pps;
};

struct module___335;

struct file___405;

struct kiocb___405;

struct iov_iter___172;

struct poll_table_struct___248;

struct vm_area_struct___406;

struct inode___405;

struct file_lock___405;

struct page___406;

struct pipe_inode_info___86;

struct seq_file___344;

struct file_operations___405 {
	struct module___335 *owner;
	loff_t (*llseek)(struct file___405 *, loff_t, int);
	ssize_t (*read)(struct file___405 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___405 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___405 *, struct iov_iter___172 *);
	ssize_t (*write_iter)(struct kiocb___405 *, struct iov_iter___172 *);
	int (*iopoll)(struct kiocb___405 *, bool);
	int (*iterate)(struct file___405 *, struct dir_context *);
	int (*iterate_shared)(struct file___405 *, struct dir_context *);
	__poll_t (*poll)(struct file___405 *, struct poll_table_struct___248 *);
	long int (*unlocked_ioctl)(struct file___405 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___405 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___405 *, struct vm_area_struct___406 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___405 *, struct file___405 *);
	int (*flush)(struct file___405 *, fl_owner_t);
	int (*release)(struct inode___405 *, struct file___405 *);
	int (*fsync)(struct file___405 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___405 *, int);
	int (*lock)(struct file___405 *, int, struct file_lock___405 *);
	ssize_t (*sendpage)(struct file___405 *, struct page___406 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___405 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___405 *, int, struct file_lock___405 *);
	ssize_t (*splice_write)(struct pipe_inode_info___86 *, struct file___405 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___405 *, loff_t *, struct pipe_inode_info___86 *, size_t, unsigned int);
	int (*setlease)(struct file___405 *, long int, struct file_lock___405 **, void **);
	long int (*fallocate)(struct file___405 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___344 *, struct file___405 *);
	ssize_t (*copy_file_range)(struct file___405 *, loff_t, struct file___405 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___405 *, loff_t, struct file___405 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___405 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___406 {
	u64 seqnum;
	struct vm_area_struct___406 *vmas[4];
};

struct page_frag___406 {
	struct page___406 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___406;

struct mem_cgroup___142;

struct cred___373;

struct nsproxy___300;

struct signal_struct___280;

struct bio_list___199;

struct backing_dev_info___199;

struct css_set___254;

struct vm_struct___309;

struct task_struct___407 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___407 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___406 *mm;
	struct mm_struct___406 *active_mm;
	struct vmacache___406 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___407 *real_parent;
	struct task_struct___407 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___407 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___142 *active_memcg;
	long int rh_reserved2;
	struct pid___233 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___233 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___233 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___373 *ptracer_cred;
	const struct cred___373 *real_cred;
	const struct cred___373 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___300 *nsproxy;
	struct signal_struct___280 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___407 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___199 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___199 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___254 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___86 *splice_pipe;
	struct page_frag___406 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___142 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___407 *oom_reaper_list;
	struct vm_struct___309 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___154 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rw_semaphore___407 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___407 *owner;
};

struct key___373;

struct ucounts___270;

struct user_namespace___270 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___270 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___9 ns;
	long unsigned int flags;
	struct key___373 *persistent_keyring_register;
	struct rw_semaphore___407 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___270 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct secondary_data___407 {
	void *stack;
	struct task_struct___407 *task;
	long int status;
};

typedef struct page___406 *pgtable_t___406;

struct address_space___405;

struct dev_pagemap___393;

struct page___406 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___405 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___406 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___406 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___406 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___393 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___142 *mem_cgroup;
};

struct user_struct___373 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___373 *uid_keyring;
	struct key___373 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___393;

struct vm_area_struct___406 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___406 *vm_next;
	struct vm_area_struct___406 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___406 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___393 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___405 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___406;

struct mm_struct___406 {
	struct {
		struct vm_area_struct___406 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___405 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___407 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___406 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___407 *owner;
		struct user_namespace___270 *user_ns;
		struct file___405 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___406 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup___254;

struct cgroup_subsys___254;

struct cgroup_subsys_state___254 {
	struct cgroup___254 *cgroup;
	struct cgroup_subsys___254 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___254 *parent;
};

struct kernfs_node___400;

struct cgroup_file___254 {
	struct kernfs_node___400 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___142;

struct mem_cgroup___142 {
	struct cgroup_subsys_state___254 css;
	struct mem_cgroup_id___13 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___254 events_file;
	struct cgroup_file___254 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___407 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___142 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cred___373 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___373 *session_keyring;
	struct key___373 *process_keyring;
	struct key___373 *thread_keyring;
	struct key___373 *request_key_auth;
	void *security;
	struct user_struct___373 *user;
	struct user_namespace___270 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___62;

struct cgroup_namespace___254;

struct nsproxy___300 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net___62 *net_ns;
	struct cgroup_namespace___254 *cgroup_ns;
};

struct signal_struct___280 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___407 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___407 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___233 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___233 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___406 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___233 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___199;

struct bio_list___199 {
	struct bio___199 *head;
	struct bio___199 *tail;
};

struct bdi_writeback_congested___199;

struct bdi_writeback___199 {
	struct backing_dev_info___199 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___199 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___254 *memcg_css;
	struct cgroup_subsys_state___254 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___373;

struct dentry___405;

struct backing_dev_info___199 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___199 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___373 *dev;
	struct device___373 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___405 *debug_dir;
	struct dentry___405 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___254 {
	struct cgroup_subsys_state___254 *subsys[13];
	refcount_t refcount;
	struct css_set___254 *dom_cset;
	struct cgroup___254 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___254 *mg_src_cgrp;
	struct cgroup___254 *mg_dst_cgrp;
	struct css_set___254 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___405;

struct pipe_buffer___86;

struct pipe_inode_info___86 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___406 *tmp_page;
	struct fasync_struct___405 *fasync_readers;
	struct fasync_struct___405 *fasync_writers;
	struct pipe_buffer___86 *bufs;
	struct user_struct___373 *user;
};

struct vm_struct___309 {
	struct vm_struct___309 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___406 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___292 {
	struct task_struct___407 task;
	long unsigned int stack[8192];
};

struct address_space_operations___405;

struct address_space___405 {
	struct inode___405 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___407 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___405 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___393)(struct vm_area_struct___406 *, long unsigned int, const struct page___406 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___393)(struct page___406 *, void *);

struct dev_pagemap___393 {
	dev_page_fault_t___393 page_fault;
	dev_page_free_t___393 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___373 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___406 {
	struct vfsmount *mnt;
	struct dentry___405 *dentry;
};

struct file___405 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___406 f_path;
	struct inode___405 *f_inode;
	const struct file_operations___405 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___233 f_owner;
	const struct cred___373 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___405 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___393;

struct vm_operations_struct___393 {
	void (*open)(struct vm_area_struct___406 *);
	void (*close)(struct vm_area_struct___406 *);
	int (*split)(struct vm_area_struct___406 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___406 *);
	vm_fault_t (*fault)(struct vm_fault___393 *);
	vm_fault_t (*huge_fault)(struct vm_fault___393 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___393 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___406 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___393 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___393 *);
	int (*access)(struct vm_area_struct___406 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___406 *);
	int (*set_policy)(struct vm_area_struct___406 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___406 *, long unsigned int);
	struct page___406 * (*find_special_page)(struct vm_area_struct___406 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___406 {
	struct task_struct___407 *task;
	struct core_thread___406 *next;
};

struct core_state___406 {
	atomic_t nr_threads;
	struct core_thread___406 dumper;
	struct completion startup;
};

struct vm_fault___393 {
	struct vm_area_struct___406 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___406 *cow_page;
	struct mem_cgroup___142 *memcg;
	struct page___406 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___406 prealloc_pte;
};

struct pglist_data___406;

struct lruvec___406 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___406 *pgdat;
};

struct zone___406 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___406 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___406 {
	struct zone___406 *zone;
	int zone_idx;
};

struct zonelist___406 {
	struct zoneref___406 _zonerefs[25];
};

struct pglist_data___406 {
	struct zone___406 node_zones[3];
	struct zonelist___406 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___407 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___407 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___406 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___406 {
	struct rw_semaphore___407 rwsem;
	struct notifier_block *head;
};

struct kernfs_root___399;

struct kernfs_elem_dir___399 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___399 *root;
};

struct kernfs_syscall_ops___399;

struct kernfs_root___399 {
	struct kernfs_node___400 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___399 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___399 {
	struct kernfs_node___400 *target_kn;
};

struct kernfs_ops___399;

struct kernfs_elem_attr___399 {
	const struct kernfs_ops___399 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___400 *notify_next;
};

struct kernfs_node___400 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___400 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___399 dir;
		struct kernfs_elem_symlink___399 symlink;
		struct kernfs_elem_attr___399 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___399;

struct kernfs_ops___399 {
	int (*open)(struct kernfs_open_file___399 *);
	void (*release)(struct kernfs_open_file___399 *);
	int (*seq_show)(struct seq_file___344 *, void *);
	void * (*seq_start)(struct seq_file___344 *, loff_t *);
	void * (*seq_next)(struct seq_file___344 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___344 *, void *);
	ssize_t (*read)(struct kernfs_open_file___399 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___399 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___399 *, struct vm_area_struct___406 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___399 *, struct poll_table_struct___248 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___399 {
	int (*remount_fs)(struct kernfs_root___399 *, int *, char *);
	int (*show_options)(struct seq_file___344 *, struct kernfs_root___399 *);
	int (*mkdir)(struct kernfs_node___400 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___400 *);
	int (*rename)(struct kernfs_node___400 *, struct kernfs_node___400 *, const char *);
	int (*show_path)(struct seq_file___344 *, struct kernfs_node___400 *, struct kernfs_root___399 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___344;

struct seq_file___344 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___344 *op;
	int poll_event;
	const struct file___405 *file;
	void *private;
};

struct kernfs_open_file___399 {
	struct kernfs_node___400 *kn;
	struct file___405 *file;
	struct seq_file___344 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___393 *vm_ops;
};

typedef void (*poll_queue_proc___258)(struct file___405 *, wait_queue_head_t *, struct poll_table_struct___248 *);

struct poll_table_struct___248 {
	poll_queue_proc___258 _qproc;
	__poll_t _key;
};

struct sock___35;

struct kobj_ns_type_operations___34 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___35 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___62 *net;
} possible_net_t___52;

struct proto___34;

struct sock_common___34 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___34 *skc_prot;
	possible_net_t___52 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___35 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___52;

struct sk_buff_head___50 {
	struct sk_buff___52 *next;
	struct sk_buff___52 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___34;

struct socket_wq___35;

struct dst_entry___34;

struct socket___36;

struct net_device___52;

struct sock___35 {
	struct sock_common___34 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___50 sk_error_queue;
	struct sk_buff_head___50 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___52 *head;
		struct sk_buff___52 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___34 *sk_filter;
	union {
		struct socket_wq___35 *sk_wq;
		struct socket_wq___35 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___34 *sk_rx_dst;
	struct dst_entry___34 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___52 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___50 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___406 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___34 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___233 *sk_peer_pid;
	const struct cred___373 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___36 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___142 *sk_memcg;
	void (*sk_state_change)(struct sock___35 *);
	void (*sk_data_ready)(struct sock___35 *);
	void (*sk_write_space)(struct sock___35 *);
	void (*sk_error_report)(struct sock___35 *);
	int (*sk_backlog_rcv)(struct sock___35 *, struct sk_buff___52 *);
	struct sk_buff___52 * (*sk_validate_xmit_skb)(struct sock___35 *, struct net_device___52 *, struct sk_buff___52 *);
	void (*sk_destruct)(struct sock___35 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kobject___393;

struct bin_attribute___369;

struct attribute_group___370 {
	const char *name;
	umode_t (*is_visible)(struct kobject___393 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___393 *, struct bin_attribute___369 *, int);
	struct attribute **attrs;
	struct bin_attribute___369 **bin_attrs;
};

struct kset___392;

struct kobj_type___392;

struct kobject___393 {
	const char *name;
	struct list_head entry;
	struct kobject___393 *parent;
	struct kset___392 *kset;
	struct kobj_type___392 *ktype;
	struct kernfs_node___400 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___369 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___405 *, struct kobject___393 *, struct bin_attribute___369 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___405 *, struct kobject___393 *, struct bin_attribute___369 *, char *, loff_t, size_t);
	int (*mmap)(struct file___405 *, struct kobject___393 *, struct bin_attribute___369 *, struct vm_area_struct___406 *);
};

struct sysfs_ops___392 {
	ssize_t (*show)(struct kobject___393 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___393 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___392;

struct kset___392 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___393 kobj;
	const struct kset_uevent_ops___392 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___392 {
	void (*release)(struct kobject___393 *);
	const struct sysfs_ops___392 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___34 * (*child_ns_type)(struct kobject___393 *);
	const void * (*namespace)(struct kobject___393 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___392 {
	int (* const filter)(struct kset___392 *, struct kobject___393 *);
	const char * (* const name)(struct kset___392 *, struct kobject___393 *);
	int (* const uevent)(struct kset___392 *, struct kobject___393 *, struct kobj_uevent_env *);
};

struct kobj_attribute___383 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___393 *, struct kobj_attribute___383 *, char *);
	ssize_t (*store)(struct kobject___393 *, struct kobj_attribute___383 *, const char *, size_t);
};

struct kernel_param___333;

struct kernel_param_ops___333 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___333 *);
	int (*get)(char *, const struct kernel_param___333 *);
	void (*free)(void *);
};

struct kparam_array___333;

struct kernel_param___333 {
	const char *name;
	struct module___335 *mod;
	const struct kernel_param_ops___333 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___333 *arr;
	};
};

struct kparam_array___333 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___333 *ops;
	void *elem;
};

struct module_kobject___333 {
	struct kobject___393 kobj;
	struct module___335 *mod;
	struct kobject___393 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___333 {
	struct module___335 *mod;
	struct latch_tree_node node;
};

struct module_layout___333 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___333 mtn;
};

struct module_attribute___333;

struct module___335 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___333 mkobj;
	struct module_attribute___333 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___393 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___333 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___333 core_layout;
	struct module_layout___333 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___333 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___333 *, struct module_kobject___333 *, char *);
	ssize_t (*store)(struct module_attribute___333 *, struct module_kobject___333 *, const char *, size_t);
	void (*setup)(struct module___335 *, const char *);
	int (*test)(struct module___335 *);
	void (*free)(struct module___335 *);
};

struct shrink_control___142 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___142 *memcg;
};

struct shrinker___142 {
	long unsigned int (*count_objects)(struct shrinker___142 *, struct shrink_control___142 *);
	long unsigned int (*scan_objects)(struct shrinker___142 *, struct shrink_control___142 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct dev_pm_info___373 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___373 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___373;

struct bus_type___373;

struct device_driver___373;

struct dev_pm_domain___373;

struct dma_map_ops___145;

struct fwnode_handle___293;

struct class___373;

struct device___373 {
	struct device___373 *parent;
	struct device_private *p;
	struct kobject___393 kobj;
	const char *init_name;
	const struct device_type___373 *type;
	struct mutex mutex;
	struct bus_type___373 *bus;
	struct device_driver___373 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___373 power;
	struct dev_pm_domain___373 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___145 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___293 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___373 *class;
	const struct attribute_group___370 **groups;
	void (*release)(struct device___373 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___405;

struct super_block___405;

struct dentry___405 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___405 *d_parent;
	struct qstr d_name;
	struct inode___405 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___405 *d_op;
	struct super_block___405 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___405;

struct block_device___405;

struct inode___405 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___405 *i_op;
	struct super_block___405 *i_sb;
	struct address_space___405 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___407 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___199 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___405 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___405 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___86 *i_pipe;
		struct block_device___405 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___405 {
	int (*d_revalidate)(struct dentry___405 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___405 *, unsigned int);
	int (*d_hash)(const struct dentry___405 *, struct qstr *);
	int (*d_compare)(const struct dentry___405 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___405 *);
	int (*d_init)(struct dentry___405 *);
	void (*d_release)(struct dentry___405 *);
	void (*d_prune)(struct dentry___405 *);
	void (*d_iput)(struct dentry___405 *, struct inode___405 *);
	char * (*d_dname)(struct dentry___405 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___406 *);
	int (*d_manage)(const struct path___406 *, bool);
	struct dentry___405 * (*d_real)(struct dentry___405 *, const struct inode___405 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___405;

struct mem_dqinfo___405 {
	struct quota_format_type___405 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___405;

struct quota_info___405 {
	unsigned int flags;
	struct rw_semaphore___407 dqio_sem;
	struct inode___405 *files[3];
	struct mem_dqinfo___405 info[3];
	const struct quota_format_ops___405 *ops[3];
};

struct rcuwait___405 {
	struct task_struct___407 *task;
};

struct percpu_rw_semaphore___405 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___407 rw_sem;
	struct rcuwait___405 writer;
	int readers_block;
};

struct sb_writers___405 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___405 rw_sem[3];
};

struct file_system_type___405;

struct super_operations___405;

struct dquot_operations___405;

struct quotactl_ops___405;

struct super_block___405 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___405 *s_type;
	const struct super_operations___405 *s_op;
	const struct dquot_operations___405 *dq_op;
	const struct quotactl_ops___405 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___405 *s_root;
	struct rw_semaphore___407 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___405 *s_bdev;
	struct backing_dev_info___199 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___405 s_dquot;
	struct sb_writers___405 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___405 *s_d_op;
	int cleancache_poolid;
	struct shrinker___142 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___270 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___405 {
	struct file___405 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___405 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___405 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___405 *ia_file;
};

struct dquot___405 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___405 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___405 {
	int qf_fmt_id;
	const struct quota_format_ops___405 *qf_ops;
	struct module___335 *qf_owner;
	struct quota_format_type___405 *qf_next;
};

struct quota_format_ops___405 {
	int (*check_quota_file)(struct super_block___405 *, int);
	int (*read_file_info)(struct super_block___405 *, int);
	int (*write_file_info)(struct super_block___405 *, int);
	int (*free_file_info)(struct super_block___405 *, int);
	int (*read_dqblk)(struct dquot___405 *);
	int (*commit_dqblk)(struct dquot___405 *);
	int (*release_dqblk)(struct dquot___405 *);
	int (*get_next_id)(struct super_block___405 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___405 {
	int (*write_dquot)(struct dquot___405 *);
	struct dquot___405 * (*alloc_dquot)(struct super_block___405 *, int);
	void (*destroy_dquot)(struct dquot___405 *);
	int (*acquire_dquot)(struct dquot___405 *);
	int (*release_dquot)(struct dquot___405 *);
	int (*mark_dirty)(struct dquot___405 *);
	int (*write_info)(struct super_block___405 *, int);
	qsize_t * (*get_reserved_space)(struct inode___405 *);
	int (*get_projid)(struct inode___405 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___405 *, qsize_t *);
	int (*get_next_id)(struct super_block___405 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___405 {
	int (*quota_on)(struct super_block___405 *, int, int, const struct path___406 *);
	int (*quota_off)(struct super_block___405 *, int);
	int (*quota_enable)(struct super_block___405 *, unsigned int);
	int (*quota_disable)(struct super_block___405 *, unsigned int);
	int (*quota_sync)(struct super_block___405 *, int);
	int (*set_info)(struct super_block___405 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___405 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___405 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___405 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___405 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___405 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___162;

struct address_space_operations___405 {
	int (*writepage)(struct page___406 *, struct writeback_control___162 *);
	int (*readpage)(struct file___405 *, struct page___406 *);
	int (*writepages)(struct address_space___405 *, struct writeback_control___162 *);
	int (*set_page_dirty)(struct page___406 *);
	int (*readpages)(struct file___405 *, struct address_space___405 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___405 *, struct address_space___405 *, loff_t, unsigned int, unsigned int, struct page___406 **, void **);
	int (*write_end)(struct file___405 *, struct address_space___405 *, loff_t, unsigned int, unsigned int, struct page___406 *, void *);
	sector_t (*bmap)(struct address_space___405 *, sector_t);
	void (*invalidatepage)(struct page___406 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___406 *, gfp_t);
	void (*freepage)(struct page___406 *);
	ssize_t (*direct_IO)(struct kiocb___405 *, struct iov_iter___172 *);
	int (*migratepage)(struct address_space___405 *, struct page___406 *, struct page___406 *, enum migrate_mode);
	bool (*isolate_page)(struct page___406 *, isolate_mode_t);
	void (*putback_page)(struct page___406 *);
	int (*launder_page)(struct page___406 *);
	int (*is_partially_uptodate)(struct page___406 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___406 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___405 *, struct page___406 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___405 *, sector_t *);
	void (*swap_deactivate)(struct file___405 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___162 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___199 *wb;
	struct inode___405 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___201;

struct iov_iter___172 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___201 *bvec;
		struct pipe_inode_info___86 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___405 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___405 *bd_inode;
	struct super_block___405 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___405 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___199 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___405 {
	struct dentry___405 * (*lookup)(struct inode___405 *, struct dentry___405 *, unsigned int);
	const char * (*get_link)(struct dentry___405 *, struct inode___405 *, struct delayed_call *);
	int (*permission)(struct inode___405 *, int);
	struct posix_acl * (*get_acl)(struct inode___405 *, int);
	int (*readlink)(struct dentry___405 *, char *, int);
	int (*create)(struct inode___405 *, struct dentry___405 *, umode_t, bool);
	int (*link)(struct dentry___405 *, struct inode___405 *, struct dentry___405 *);
	int (*unlink)(struct inode___405 *, struct dentry___405 *);
	int (*symlink)(struct inode___405 *, struct dentry___405 *, const char *);
	int (*mkdir)(struct inode___405 *, struct dentry___405 *, umode_t);
	int (*rmdir)(struct inode___405 *, struct dentry___405 *);
	int (*mknod)(struct inode___405 *, struct dentry___405 *, umode_t, dev_t);
	int (*rename)(struct inode___405 *, struct dentry___405 *, struct inode___405 *, struct dentry___405 *, unsigned int);
	int (*setattr)(struct dentry___405 *, struct iattr___405 *);
	int (*getattr)(const struct path___406 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___405 *, char *, size_t);
	int (*fiemap)(struct inode___405 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___405 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___405 *, struct dentry___405 *, struct file___405 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___405 *, struct dentry___405 *, umode_t);
	int (*set_acl)(struct inode___405 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___405 {
	void (*fl_copy_lock)(struct file_lock___405 *, struct file_lock___405 *);
	void (*fl_release_private)(struct file_lock___405 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___405;

struct file_lock___405 {
	struct file_lock___405 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___405 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___405 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___405 *fl_ops;
	const struct lock_manager_operations___405 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___405 {
	int (*lm_compare_owner)(struct file_lock___405 *, struct file_lock___405 *);
	long unsigned int (*lm_owner_key)(struct file_lock___405 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___405 *);
	int (*lm_grant)(struct file_lock___405 *, int);
	bool (*lm_break)(struct file_lock___405 *);
	int (*lm_change)(struct file_lock___405 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___405 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___405 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___405 *fa_next;
	struct file___405 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___405 {
	const char *name;
	int fs_flags;
	struct dentry___405 * (*mount)(struct file_system_type___405 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___405 *);
	struct module___335 *owner;
	struct file_system_type___405 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___405 {
	struct inode___405 * (*alloc_inode)(struct super_block___405 *);
	void (*destroy_inode)(struct inode___405 *);
	void (*dirty_inode)(struct inode___405 *, int);
	int (*write_inode)(struct inode___405 *, struct writeback_control___162 *);
	int (*drop_inode)(struct inode___405 *);
	void (*evict_inode)(struct inode___405 *);
	void (*put_super)(struct super_block___405 *);
	int (*sync_fs)(struct super_block___405 *, int);
	int (*freeze_super)(struct super_block___405 *);
	int (*freeze_fs)(struct super_block___405 *);
	int (*thaw_super)(struct super_block___405 *);
	int (*unfreeze_fs)(struct super_block___405 *);
	int (*statfs)(struct dentry___405 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___405 *, int *, char *);
	void (*umount_begin)(struct super_block___405 *);
	int (*show_options)(struct seq_file___344 *, struct dentry___405 *);
	int (*show_devname)(struct seq_file___344 *, struct dentry___405 *);
	int (*show_path)(struct seq_file___344 *, struct dentry___405 *);
	int (*show_stats)(struct seq_file___344 *, struct dentry___405 *);
	ssize_t (*quota_read)(struct super_block___405 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___405 *, int, const char *, size_t, loff_t);
	struct dquot___405 ** (*get_dquots)(struct inode___405 *);
	int (*bdev_try_to_free_page)(struct super_block___405 *, struct page___406 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___405 *, struct shrink_control___142 *);
	long int (*free_cached_objects)(struct super_block___405 *, struct shrink_control___142 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___199(struct bio___199 *);

struct bio_vec___201 {
	struct page___406 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___199;

struct bio_set___199;

struct bio___199 {
	struct bio___199 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___199 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___199 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___201 *bi_io_vec;
	struct bio_set___199 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___201 bi_inline_vecs[0];
};

typedef void compound_page_dtor___393(struct page___406 *);

struct msghdr___37 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___172 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___405 *msg_iocb;
};

struct socket_wq___35 {
	wait_queue_head_t wait;
	struct fasync_struct___405 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___35;

struct socket___36 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___35 *wq;
	struct file___405 *file;
	struct sock___35 *sk;
	const struct proto_ops___35 *ops;
};

typedef int (*sk_read_actor_t___34)(read_descriptor_t *, struct sk_buff___52 *, unsigned int, size_t);

struct proto_ops___35 {
	int family;
	struct module___335 *owner;
	int (*release)(struct socket___36 *);
	int (*bind)(struct socket___36 *, struct sockaddr *, int);
	int (*connect)(struct socket___36 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___36 *, struct socket___36 *);
	int (*accept)(struct socket___36 *, struct socket___36 *, int, bool);
	int (*getname)(struct socket___36 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___405 *, struct socket___36 *, struct poll_table_struct___248 *);
	int (*ioctl)(struct socket___36 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___36 *, int);
	int (*shutdown)(struct socket___36 *, int);
	int (*setsockopt)(struct socket___36 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___36 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___36 *, struct msghdr___37 *, size_t);
	int (*recvmsg)(struct socket___36 *, struct msghdr___37 *, size_t, int);
	int (*mmap)(struct file___405 *, struct socket___36 *, struct vm_area_struct___406 *);
	ssize_t (*sendpage)(struct socket___36 *, struct page___406 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___36 *, loff_t *, struct pipe_inode_info___86 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___35 *, int);
	int (*peek_len)(struct socket___36 *);
	int (*read_sock)(struct sock___35 *, read_descriptor_t *, sk_read_actor_t___34);
	int (*sendpage_locked)(struct sock___35 *, struct page___406 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___35 *, struct msghdr___37 *, size_t);
	int (*set_rcvlowat)(struct sock___35 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct nf_bridge_info___50;

struct sk_buff___52 {
	union {
		struct {
			struct sk_buff___52 *next;
			struct sk_buff___52 *prev;
			union {
				struct net_device___52 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___35 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___52 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___50 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___50;

struct netns_frags___50 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___50 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_rules_ops___34;

struct fib_notifier_ops___34;

struct netns_ipv4___50 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___34 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___35 *fibnl;
	struct sock___35 **icmp_sk;
	struct sock___35 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___35 **tcp_sk;
	struct netns_frags___50 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___34 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___34 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___34 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___34;

struct dst_ops___61 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___61 *);
	struct dst_entry___34 * (*check)(struct dst_entry___34 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___34 *);
	unsigned int (*mtu)(const struct dst_entry___34 *);
	u32 * (*cow_metrics)(struct dst_entry___34 *, long unsigned int);
	void (*destroy)(struct dst_entry___34 *);
	void (*ifdown)(struct dst_entry___34 *, struct net_device___52 *, int);
	struct dst_entry___34 * (*negative_advice)(struct dst_entry___34 *);
	void (*link_failure)(struct sk_buff___52 *);
	void (*update_pmtu)(struct dst_entry___34 *, struct sock___35 *, struct sk_buff___52 *, u32);
	void (*redirect)(struct dst_entry___34 *, struct sock___35 *, struct sk_buff___52 *);
	int (*local_out)(struct net___62 *, struct sock___35 *, struct sk_buff___52 *);
	struct neighbour___34 * (*neigh_lookup)(const struct dst_entry___34 *, struct sk_buff___52 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___34 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___61 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___50 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___61 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___34 *fib6_rules_ops;
	struct sock___35 **icmp_sk;
	struct sock___35 *ndisc_sk;
	struct sock___35 *tcp_sk;
	struct sock___35 *igmp_sk;
	struct sock___35 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___34 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___34 *notifier_ops;
	struct fib_notifier_ops___34 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___35 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___35 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___50 {
	struct netns_frags___50 frags;
};

struct netns_xfrm___61 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___35 *nlsk;
	struct sock___35 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___61 xfrm4_dst_ops;
	struct dst_ops___61 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___44;

struct net___62 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___270 *user_ns;
	struct ucounts___270 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___9 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___35 *rtnl;
	struct sock___35 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___52 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___50 ipv4;
	struct netns_ipv6___61 ipv6;
	struct netns_sctp___35 sctp;
	struct netns_nf___3 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___50 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___35 *nfnl;
	struct sock___35 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___61 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___35 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___44 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___373 {
	int (*prepare)(struct device___373 *);
	void (*complete)(struct device___373 *);
	int (*suspend)(struct device___373 *);
	int (*resume)(struct device___373 *);
	int (*freeze)(struct device___373 *);
	int (*thaw)(struct device___373 *);
	int (*poweroff)(struct device___373 *);
	int (*restore)(struct device___373 *);
	int (*suspend_late)(struct device___373 *);
	int (*resume_early)(struct device___373 *);
	int (*freeze_late)(struct device___373 *);
	int (*thaw_early)(struct device___373 *);
	int (*poweroff_late)(struct device___373 *);
	int (*restore_early)(struct device___373 *);
	int (*suspend_noirq)(struct device___373 *);
	int (*resume_noirq)(struct device___373 *);
	int (*freeze_noirq)(struct device___373 *);
	int (*thaw_noirq)(struct device___373 *);
	int (*poweroff_noirq)(struct device___373 *);
	int (*restore_noirq)(struct device___373 *);
	int (*runtime_suspend)(struct device___373 *);
	int (*runtime_resume)(struct device___373 *);
	int (*runtime_idle)(struct device___373 *);
};

struct dev_pm_domain___373 {
	struct dev_pm_ops___373 ops;
	void (*detach)(struct device___373 *, bool);
	int (*activate)(struct device___373 *);
	void (*sync)(struct device___373 *);
	void (*dismiss)(struct device___373 *);
};

struct bus_type___373 {
	const char *name;
	const char *dev_name;
	struct device___373 *dev_root;
	const struct attribute_group___370 **bus_groups;
	const struct attribute_group___370 **dev_groups;
	const struct attribute_group___370 **drv_groups;
	int (*match)(struct device___373 *, struct device_driver___373 *);
	int (*uevent)(struct device___373 *, struct kobj_uevent_env *);
	int (*probe)(struct device___373 *);
	int (*remove)(struct device___373 *);
	void (*shutdown)(struct device___373 *);
	int (*online)(struct device___373 *);
	int (*offline)(struct device___373 *);
	int (*suspend)(struct device___373 *, pm_message_t);
	int (*resume)(struct device___373 *);
	int (*num_vf)(struct device___373 *);
	int (*dma_configure)(struct device___373 *);
	const struct dev_pm_ops___373 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___373 {
	const char *name;
	struct bus_type___373 *bus;
	struct module___335 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___373 *);
	int (*remove)(struct device___373 *);
	void (*shutdown)(struct device___373 *);
	int (*suspend)(struct device___373 *, pm_message_t);
	int (*resume)(struct device___373 *);
	const struct attribute_group___370 **groups;
	const struct dev_pm_ops___373 *pm;
	void (*coredump)(struct device___373 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___373 {
	const char *name;
	const struct attribute_group___370 **groups;
	int (*uevent)(struct device___373 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___373 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___373 *);
	const struct dev_pm_ops___373 *pm;
};

struct class___373 {
	const char *name;
	struct module___335 *owner;
	const struct attribute_group___370 **class_groups;
	const struct attribute_group___370 **dev_groups;
	struct kobject___393 *dev_kobj;
	int (*dev_uevent)(struct device___373 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___373 *, umode_t *);
	void (*class_release)(struct class___373 *);
	void (*dev_release)(struct device___373 *);
	int (*shutdown_pre)(struct device___373 *);
	const struct kobj_ns_type_operations___34 *ns_type;
	const void * (*namespace)(struct device___373 *);
	const struct dev_pm_ops___373 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___145 {
	void * (*alloc)(struct device___373 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___373 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___373 *, struct vm_area_struct___406 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___373 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___373 *, struct page___406 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___373 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___373 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___373 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___373 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___373 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___373 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___373 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___373 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___373 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___373 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___373 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___373 *, u64);
	u64 (*get_required_mask)(struct device___373 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___293;

struct fwnode_handle___293 {
	struct fwnode_handle___293 *secondary;
	const struct fwnode_operations___293 *ops;
};

struct fwnode_reference_args___293;

struct fwnode_endpoint___293;

struct fwnode_operations___293 {
	struct fwnode_handle___293 * (*get)(struct fwnode_handle___293 *);
	void (*put)(struct fwnode_handle___293 *);
	bool (*device_is_available)(const struct fwnode_handle___293 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___293 *, const struct device___373 *);
	bool (*property_present)(const struct fwnode_handle___293 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___293 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___293 *, const char *, const char **, size_t);
	struct fwnode_handle___293 * (*get_parent)(const struct fwnode_handle___293 *);
	struct fwnode_handle___293 * (*get_next_child_node)(const struct fwnode_handle___293 *, struct fwnode_handle___293 *);
	struct fwnode_handle___293 * (*get_named_child_node)(const struct fwnode_handle___293 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___293 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___293 *);
	struct fwnode_handle___293 * (*graph_get_next_endpoint)(const struct fwnode_handle___293 *, struct fwnode_handle___293 *);
	struct fwnode_handle___293 * (*graph_get_remote_endpoint)(const struct fwnode_handle___293 *);
	struct fwnode_handle___293 * (*graph_get_port_parent)(struct fwnode_handle___293 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___293 *, struct fwnode_endpoint___293 *);
};

struct fwnode_endpoint___293 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___293 *local_fwnode;
};

struct fwnode_reference_args___293 {
	struct fwnode_handle___293 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___86;

struct pipe_buffer___86 {
	struct page___406 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___86 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___86 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___86 *, struct pipe_buffer___86 *);
	void (*release)(struct pipe_inode_info___86 *, struct pipe_buffer___86 *);
	int (*steal)(struct pipe_inode_info___86 *, struct pipe_buffer___86 *);
	union {
		bool (*get)(struct pipe_inode_info___86 *, struct pipe_buffer___86 *);
		struct {
			void (*get)(struct pipe_inode_info___86 *, struct pipe_buffer___86 *);
		} __UNIQUE_ID_rh_kabi_hide21;
		union {		};
	};
};

struct nf_bridge_info___50 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___50 = 0,
		BRNF_PROTO_8021Q___50 = 1,
		BRNF_PROTO_PPPOE___50 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___52 *physindev;
	struct net_device___52 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___50(struct sk_buff___52 **);

struct net_device_ops___50;

struct ethtool_ops___50;

struct l3mdev_ops___34;

struct xfrmdev_ops___50;

struct tlsdev_ops___50;

struct header_ops___50;

struct netdev_rx_queue___50;

struct mini_Qdisc___44;

struct netdev_queue___50;

struct Qdisc___44;

struct rtnl_link_ops___44;

struct dcbnl_rtnl_ops___50;

struct net_device___52 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___50 *netdev_ops;
	const struct ethtool_ops___50 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___34 *l3mdev_ops;
	const struct ndisc_ops___2 *ndisc_ops;
	const struct xfrmdev_ops___50 *xfrmdev_ops;
	const struct tlsdev_ops___50 *tlsdev_ops;
	const struct header_ops___50 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___392 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___2 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___50 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___44 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___50 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___44 *miniq_ingress;
	struct netdev_queue___50 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___50 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___44 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___44 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___50 = 0,
		NETREG_REGISTERED___50 = 1,
		NETREG_UNREGISTERING___50 = 2,
		NETREG_UNREGISTERED___50 = 3,
		NETREG_RELEASED___50 = 4,
		NETREG_DUMMY___50 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___50 = 0,
		RTNL_LINK_INITIALIZING___50 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___52 *);
	struct netpoll_info *npinfo;
	possible_net_t___52 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___373 dev;
	const struct attribute_group___370 *sysfs_groups[4];
	const struct attribute_group___370 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___44 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___50 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide35;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct ethtool_ops___50 {
	int (*get_settings)(struct net_device___52 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___52 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___52 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___52 *);
	void (*get_regs)(struct net_device___52 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___52 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___52 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___52 *);
	void (*set_msglevel)(struct net_device___52 *, u32);
	int (*nway_reset)(struct net_device___52 *);
	u32 (*get_link)(struct net_device___52 *);
	int (*get_eeprom_len)(struct net_device___52 *);
	int (*get_eeprom)(struct net_device___52 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___52 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___52 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___52 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___52 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___52 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___52 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___52 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___52 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___52 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___52 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___52 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___52 *);
	void (*complete)(struct net_device___52 *);
	u32 (*get_priv_flags)(struct net_device___52 *);
	int (*set_priv_flags)(struct net_device___52 *, u32);
	int (*get_sset_count)(struct net_device___52 *, int);
	int (*get_rxnfc)(struct net_device___52 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___52 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___52 *, struct ethtool_flash *);
	int (*reset)(struct net_device___52 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___52 *);
	u32 (*get_rxfh_indir_size)(struct net_device___52 *);
	int (*get_rxfh)(struct net_device___52 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___52 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___52 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___52 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___52 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___52 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___52 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___52 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___52 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___52 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___52 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___52 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___52 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___52 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___52 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___52 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___52 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___52 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___52 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___52 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___52 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___52 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	int (*get_fecparam)(struct net_device___52 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___52 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___52 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___52 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___52 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___50;

struct inet_frags___50 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___50 *, const void *);
	void (*destructor)(struct inet_frag_queue___50 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___50 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___52 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___52 *fragments_tail;
	struct sk_buff___52 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___50 *net;
	struct callback_head rcu;
};

struct fib_rule___34;

struct fib_lookup_arg___34;

struct fib_rules_ops___34 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___34 *, struct flowi *, int, struct fib_lookup_arg___34 *);
	bool (*suppress)(struct fib_rule___34 *, struct fib_lookup_arg___34 *);
	int (*match)(struct fib_rule___34 *, struct flowi *, int);
	int (*configure)(struct fib_rule___34 *, struct sk_buff___52 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___34 *);
	int (*compare)(struct fib_rule___34 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___34 *, struct sk_buff___52 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___34 *);
	void (*flush_cache)(struct fib_rules_ops___34 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___335 *owner;
	struct net___62 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___34 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___62 *);
	int (*fib_dump)(struct net___62 *, struct notifier_block *);
	struct module___335 *owner;
	struct callback_head rcu;
};

struct dst_entry___34 {
	struct net_device___52 *dev;
	struct dst_ops___61 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___52 *);
	int (*output)(struct net___62 *, struct sock___35 *, struct sk_buff___52 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___34;

struct neigh_parms___34;

struct neigh_ops___34;

struct neighbour___34 {
	struct neighbour___34 *next;
	struct neigh_table___34 *tbl;
	struct neigh_parms___34 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___50 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___34 *, struct sk_buff___52 *);
	const struct neigh_ops___34 *ops;
	struct callback_head rcu;
	struct net_device___52 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct ucounts___270 {
	struct hlist_node node;
	struct user_namespace___270 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_prog_aux___47;

struct bpf_prog___44 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___47 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

typedef int (*key_restrict_link_func_t___374)(struct key___373 *, const struct key_type *, const union key_payload *, struct key___373 *);

struct key_restriction___373;

struct key___373 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___407 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___373 *restrict_link;
};

struct key_restriction___373 {
	key_restrict_link_func_t___374 check;
	struct key___373 *key;
	struct key_type *keytype;
};

struct seq_operations___344 {
	void * (*start)(struct seq_file___344 *, loff_t *);
	void (*stop)(struct seq_file___344 *, void *);
	void * (*next)(struct seq_file___344 *, void *, loff_t *);
	int (*show)(struct seq_file___344 *, void *);
};

struct pernet_operations___51 {
	struct list_head list;
	int (*init)(struct net___62 *);
	void (*exit)(struct net___62 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___50 {
	int (*ieee_getets)(struct net_device___52 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___52 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___52 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___52 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___52 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___52 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___52 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___52 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___52 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___52 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___52 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___52 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___52 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___52 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___52 *);
	u8 (*setstate)(struct net_device___52 *, u8);
	void (*getpermhwaddr)(struct net_device___52 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___52 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___52 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___52 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___52 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___52 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___52 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___52 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___52 *, int, u8 *);
	void (*setpfccfg)(struct net_device___52 *, int, u8);
	void (*getpfccfg)(struct net_device___52 *, int, u8 *);
	u8 (*setall)(struct net_device___52 *);
	u8 (*getcap)(struct net_device___52 *, int, u8 *);
	int (*getnumtcs)(struct net_device___52 *, int, u8 *);
	int (*setnumtcs)(struct net_device___52 *, int, u8);
	u8 (*getpfcstate)(struct net_device___52 *);
	void (*setpfcstate)(struct net_device___52 *, u8);
	void (*getbcncfg)(struct net_device___52 *, int, u32 *);
	void (*setbcncfg)(struct net_device___52 *, int, u32);
	void (*getbcnrp)(struct net_device___52 *, int, u8 *);
	void (*setbcnrp)(struct net_device___52 *, int, u8);
	int (*setapp)(struct net_device___52 *, u8, u16, u8);
	int (*getapp)(struct net_device___52 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___52 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___52 *, int, u8);
	u8 (*getdcbx)(struct net_device___52 *);
	u8 (*setdcbx)(struct net_device___52 *, u8);
	int (*peer_getappinfo)(struct net_device___52 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___52 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___52 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___52 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___52 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___52 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___254 {
	refcount_t count;
	struct ns_common___9 ns;
	struct user_namespace___270 *user_ns;
	struct ucounts___270 *ucounts;
	struct css_set___254 *root_cset;
};

struct bpf_map___255;

struct bpf_map_ops___254 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___255 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___255 *, struct file___405 *);
	void (*map_free)(struct bpf_map___255 *);
	int (*map_get_next_key)(struct bpf_map___255 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___255 *);
	void * (*map_lookup_elem)(struct bpf_map___255 *, void *);
	int (*map_update_elem)(struct bpf_map___255 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___255 *, void *);
	int (*map_push_elem)(struct bpf_map___255 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___255 *, void *);
	int (*map_peek_elem)(struct bpf_map___255 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___255 *, struct file___405 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___255 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___255 *, void *, struct seq_file___344 *);
	int (*map_check_btf)(const struct bpf_map___255 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___255 {
	const struct bpf_map_ops___254 *ops;
	struct bpf_map___255 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___373 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___50;

struct bpf_map_dev_ops___50 {
	int (*map_get_next_key)(struct bpf_offloaded_map___50 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___50 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___50 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___50 *, void *);
};

struct bpf_offloaded_map___50 {
	struct bpf_map___255 map;
	struct net_device___52 *netdev;
	const struct bpf_map_dev_ops___50 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___44 {
	int (*test_run)(struct bpf_prog___44 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___44 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___44 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___44 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___44 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___44 *, u32 *);
};

struct bpf_prog_offload_ops___44 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___44 *);
	int (*translate)(struct bpf_prog___44 *);
	void (*destroy)(struct bpf_prog___44 *);
};

struct bpf_prog_offload___44 {
	struct bpf_prog___44 *prog;
	struct net_device___52 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___44 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___47 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___44 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___44 *ops;
	struct bpf_map___255 **used_maps;
	struct bpf_prog___44 *prog;
	struct user_struct___373 *user;
	u64 load_time;
	struct bpf_map___255 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___44 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___44 {
	struct bpf_prog___44 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___44 {
	struct callback_head rcu;
	struct bpf_prog_array_item___44 items[0];
};

struct cgroup_bpf___44 {
	struct bpf_prog_array___44 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___44 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___255;

typedef void (*kthread_work_func_t___255)(struct kthread_work___255 *);

struct kthread_worker___255;

struct kthread_work___255 {
	struct list_head node;
	kthread_work_func_t___255 func;
	struct kthread_worker___255 *worker;
	int canceling;
};

struct kthread_worker___255 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___407 *task;
	struct kthread_work___255 *current_work;
};

struct kthread_delayed_work___254 {
	struct kthread_work___255 work;
	struct timer_list timer;
};

struct psi_group___254 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___255 *poll_kworker;
	struct kthread_delayed_work___254 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___254;

struct cgroup_rstat_cpu___254;

struct cgroup___254 {
	struct cgroup_subsys_state___254 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___400 *kn;
	struct cgroup_file___254 procs_file;
	struct cgroup_file___254 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___254 *subsys[13];
	struct cgroup_root___254 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___254 *dom_cgrp;
	struct cgroup_rstat_cpu___254 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___44 bpf;
	atomic_t congestion_count;
	struct cgroup___254 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___254 psi;
	int ancestor_ids[0];
};

struct cftype___254;

struct cgroup_subsys___254 {
	struct cgroup_subsys_state___254 * (*css_alloc)(struct cgroup_subsys_state___254 *);
	int (*css_online)(struct cgroup_subsys_state___254 *);
	void (*css_offline)(struct cgroup_subsys_state___254 *);
	void (*css_released)(struct cgroup_subsys_state___254 *);
	void (*css_free)(struct cgroup_subsys_state___254 *);
	void (*css_reset)(struct cgroup_subsys_state___254 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___254 *, int);
	int (*css_extra_stat_show)(struct seq_file___344 *, struct cgroup_subsys_state___254 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___407 *);
	void (*cancel_fork)(struct task_struct___407 *);
	void (*fork)(struct task_struct___407 *);
	void (*exit)(struct task_struct___407 *);
	void (*free)(struct task_struct___407 *);
	void (*bind)(struct cgroup_subsys_state___254 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___254 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___254 *dfl_cftypes;
	struct cftype___254 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___254 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___254 *updated_children;
	struct cgroup___254 *updated_next;
};

struct cgroup_root___254 {
	struct kernfs_root___399 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___254 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___254 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___254 *ss;
	struct list_head node;
	struct kernfs_ops___399 *kf_ops;
	int (*open)(struct kernfs_open_file___399 *);
	void (*release)(struct kernfs_open_file___399 *);
	u64 (*read_u64)(struct cgroup_subsys_state___254 *, struct cftype___254 *);
	s64 (*read_s64)(struct cgroup_subsys_state___254 *, struct cftype___254 *);
	int (*seq_show)(struct seq_file___344 *, void *);
	void * (*seq_start)(struct seq_file___344 *, loff_t *);
	void * (*seq_next)(struct seq_file___344 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___344 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___254 *, struct cftype___254 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___254 *, struct cftype___254 *, s64);
	ssize_t (*write)(struct kernfs_open_file___399 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___399 *, struct poll_table_struct___248 *);
};

struct xdp_rxq_info___50 {
	struct net_device___52 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___50 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___52 *dev_rx;
};

struct netlink_callback___52 {
	struct sk_buff___52 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___52 *);
	int (*dump)(struct sk_buff___52 *, struct netlink_callback___52 *);
	int (*done)(struct netlink_callback___52 *);
	void *data;
	struct module___335 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___50 {
	int (*create)(struct sk_buff___52 *, struct net_device___52 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___52 *, unsigned char *);
	int (*cache)(const struct neighbour___34 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___52 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___50 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___50 *, int);
	int poll_owner;
	struct net_device___52 *dev;
	struct sk_buff___52 *gro_list;
	struct sk_buff___52 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___50 {
	struct net_device___52 *dev;
	struct Qdisc___44 *qdisc;
	struct Qdisc___44 *qdisc_sleeping;
	struct kobject___393 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___52 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___44 {
	struct sk_buff___52 *head;
	struct sk_buff___52 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___44;

struct net_rate_estimator___2;

struct Qdisc___44 {
	int (*enqueue)(struct sk_buff___52 *, struct Qdisc___44 *, struct sk_buff___52 **);
	struct sk_buff___52 * (*dequeue)(struct Qdisc___44 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___44 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___50 *dev_queue;
	struct net_rate_estimator___2 *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___50 gso_skb;
	struct qdisc_skb_head___44 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___44 *next_sched;
	struct sk_buff_head___50 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___50 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___393 kobj;
	struct net_device___52 *dev;
	long: 64;
	struct xdp_rxq_info___50 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___50)(struct net_device___52 *, struct sk_buff___52 *, struct net_device___52 *);

struct netdev_bpf___50 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___44 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___44 *prog;
			const struct bpf_prog_offload_ops___44 *ops;
		} verifier;
		struct {
			struct bpf_prog___44 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___50 *offmap;
		};
		struct {
			struct xdp_umem *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___50 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___52 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___50 {
	int (*tls_dev_add)(struct net_device___52 *, struct sock___35 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___52 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___52 *, struct sock___35 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___50 {
	int (*ndo_init)(struct net_device___52 *);
	void (*ndo_uninit)(struct net_device___52 *);
	int (*ndo_open)(struct net_device___52 *);
	int (*ndo_stop)(struct net_device___52 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___52 *, struct net_device___52 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___52 *, struct net_device___52 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___52 *, struct sk_buff___52 *, struct net_device___52 *, select_queue_fallback_t___50);
	void (*ndo_change_rx_flags)(struct net_device___52 *, int);
	void (*ndo_set_rx_mode)(struct net_device___52 *);
	int (*ndo_set_mac_address)(struct net_device___52 *, void *);
	int (*ndo_validate_addr)(struct net_device___52 *);
	int (*ndo_do_ioctl)(struct net_device___52 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___52 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___52 *, int);
	int (*ndo_neigh_setup)(struct net_device___52 *, struct neigh_parms___34 *);
	void (*ndo_tx_timeout)(struct net_device___52 *);
	void (*ndo_get_stats64)(struct net_device___52 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___52 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___52 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___52 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___52 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___52 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___52 *);
	int (*ndo_netpoll_setup)(struct net_device___52 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___52 *);
	int (*ndo_set_vf_mac)(struct net_device___52 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___52 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___52 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___52 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___52 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___52 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___52 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___52 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___52 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___52 *, int, struct sk_buff___52 *);
	int (*ndo_set_vf_guid)(struct net_device___52 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___52 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___52 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___52 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___52 *, const struct sk_buff___52 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___52 *, struct net_device___52 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___52 *, struct net_device___52 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___52 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___52 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___52 *, struct neighbour___34 *);
	void (*ndo_neigh_destroy)(struct net_device___52 *, struct neighbour___34 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___52 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___52 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___52 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___52 *, struct netlink_callback___52 *, struct net_device___52 *, struct net_device___52 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___52 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___52 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___52 *, u32, u32, struct net_device___52 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___52 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___52 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___52 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___52 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___52 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___52 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___52 *, struct net_device___52 *);
	void (*ndo_dfwd_del_station)(struct net_device___52 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___52 *);
	int (*ndo_set_tx_maxrate)(struct net_device___52 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___52 *);
	int (*ndo_change_proto_down)(struct net_device___52 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___52 *, struct sk_buff___52 *);
	void (*ndo_set_rx_headroom)(struct net_device___52 *, int);
	int (*ndo_bpf)(struct net_device___52 *, struct netdev_bpf___50 *);
	int (*ndo_xdp_xmit)(struct net_device___52 *, int, struct xdp_frame___50 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___52 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___52 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___34 {
	possible_net_t___52 net;
	struct net_device___52 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___34 *);
	void (*neigh_cleanup)(struct neighbour___34 *);
	struct neigh_table___34 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___34 {
	u32 (*l3mdev_fib_table)(const struct net_device___52 *);
	struct sk_buff___52 * (*l3mdev_l3_rcv)(struct net_device___52 *, struct sk_buff___52 *, u16);
	struct sk_buff___52 * (*l3mdev_l3_out)(struct net_device___52 *, struct sock___35 *, struct sk_buff___52 *, u16);
	struct dst_entry___34 * (*l3mdev_link_scope_lookup)(const struct net_device___52 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct tcf_proto___44;

struct mini_Qdisc___44 {
	struct tcf_proto___44 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___44 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___52 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___62 *, struct net_device___52 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___52 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___52 *, struct list_head *);
	size_t (*get_size)(const struct net_device___52 *);
	int (*fill_info)(struct sk_buff___52 *, const struct net_device___52 *);
	size_t (*get_xstats_size)(const struct net_device___52 *);
	int (*fill_xstats)(struct sk_buff___52 *, const struct net_device___52 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___52 *, struct net_device___52 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___52 *, const struct net_device___52 *);
	int (*fill_slave_info)(struct sk_buff___52 *, const struct net_device___52 *, const struct net_device___52 *);
	struct net___62 * (*get_link_net)(const struct net_device___52 *);
	size_t (*get_linkxstats_size)(const struct net_device___52 *, int);
	int (*fill_linkxstats)(struct sk_buff___52 *, const struct net_device___52 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___50 {
	struct list_head poll_list;
	struct sk_buff_head___50 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___50 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___44 *output_queue;
	struct Qdisc___44 **output_queue_tailp;
	struct sk_buff___52 *completion_queue;
	struct sk_buff_head___50 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___50 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___50 input_pkt_queue;
	struct napi_struct___50 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bdi_writeback_congested___199 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___199 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___199 {
	struct bio___199 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___201 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___201 bip_inline_vecs[0];
};

struct bio_set___199 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___199 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___142 {
	struct mem_cgroup___142 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___142 {
	struct lruvec___406 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___142 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___142 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct gnet_estimator {
	signed char interval;
	unsigned char ewma_log;
};

struct gnet_dump___44 {
	spinlock_t *lock;
	struct sk_buff___52 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___44;

struct Qdisc_ops___44 {
	struct Qdisc_ops___44 *next;
	const struct Qdisc_class_ops___44 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___52 *, struct Qdisc___44 *, struct sk_buff___52 **);
	struct sk_buff___52 * (*dequeue)(struct Qdisc___44 *);
	struct sk_buff___52 * (*peek)(struct Qdisc___44 *);
	int (*init)(struct Qdisc___44 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___44 *);
	void (*destroy)(struct Qdisc___44 *);
	int (*change)(struct Qdisc___44 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___44 *);
	int (*change_tx_queue_len)(struct Qdisc___44 *, unsigned int);
	int (*dump)(struct Qdisc___44 *, struct sk_buff___52 *);
	int (*dump_stats)(struct Qdisc___44 *, struct gnet_dump___44 *);
	void (*ingress_block_set)(struct Qdisc___44 *, u32);
	void (*egress_block_set)(struct Qdisc___44 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___44 *);
	u32 (*egress_block_get)(struct Qdisc___44 *);
	struct module___335 *owner;
};

struct net_rate_estimator___2 {
	struct gnet_stats_basic_packed *bstats;
	spinlock_t *stats_lock;
	seqcount_t *running;
	struct gnet_stats_basic_cpu *cpu_bstats;
	u8 ewma_log;
	u8 intvl_log;
	seqcount_t seq;
	u32 last_packets;
	u64 last_bytes;
	u64 avpps;
	u64 avbps;
	long unsigned int next_jiffies;
	struct timer_list timer;
	struct callback_head rcu;
};

struct tcf_block___44;

struct Qdisc_class_ops___44 {
	unsigned int flags;
	struct netdev_queue___50 * (*select_queue)(struct Qdisc___44 *, struct tcmsg *);
	int (*graft)(struct Qdisc___44 *, long unsigned int, struct Qdisc___44 *, struct Qdisc___44 **, struct netlink_ext_ack *);
	struct Qdisc___44 * (*leaf)(struct Qdisc___44 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___44 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___44 *, u32);
	int (*change)(struct Qdisc___44 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___44 *, long unsigned int);
	void (*walk)(struct Qdisc___44 *, struct qdisc_walker *);
	struct tcf_block___44 * (*tcf_block)(struct Qdisc___44 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___44 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___44 *, long unsigned int);
	int (*dump)(struct Qdisc___44 *, long unsigned int, struct sk_buff___52 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___44 *, long unsigned int, struct gnet_dump___44 *);
};

struct tcf_chain___44;

struct tcf_block___44 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___62 *net;
	struct Qdisc___44 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___44 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___44;

struct tcf_proto_ops___44;

struct tcf_proto___44 {
	struct tcf_proto___44 *next;
	void *root;
	int (*classify)(struct sk_buff___52 *, const struct tcf_proto___44 *, struct tcf_result___44 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___44 *ops;
	struct tcf_chain___44 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___44 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___44 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___44 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___52 *, const struct tcf_proto___44 *, struct tcf_result___44 *);
	int (*init)(struct tcf_proto___44 *);
	void (*destroy)(struct tcf_proto___44 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___44 *, u32);
	void (*put)(struct tcf_proto___44 *, void *);
	int (*change)(struct net___62 *, struct sk_buff___52 *, struct tcf_proto___44 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___44 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___44 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___44 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___62 *, struct tcf_chain___44 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___62 *, struct tcf_proto___44 *, void *, struct sk_buff___52 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___52 *, struct net___62 *, void *);
	struct module___335 *owner;
	int flags;
};

struct tcf_chain___44 {
	struct mutex filter_chain_lock;
	struct tcf_proto___44 *filter_chain;
	struct list_head list;
	struct tcf_block___44 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___44 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___34 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___44 *prog;
};

struct bpf_redirect_info___44 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___255 *map;
	struct bpf_map___255 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___34;

struct neigh_hash_table___34;

struct neigh_table___34 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___52 *, __u32 *);
	bool (*key_eq)(const struct neighbour___34 *, const void *);
	int (*constructor)(struct neighbour___34 *);
	int (*pconstructor)(struct pneigh_entry___34 *);
	void (*pdestructor)(struct pneigh_entry___34 *);
	void (*proxy_redo)(struct sk_buff___52 *);
	char *id;
	struct neigh_parms___34 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___50 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___34 *nht;
	struct pneigh_entry___34 **phash_buckets;
};

struct neigh_ops___34 {
	int family;
	void (*solicit)(struct neighbour___34 *, struct sk_buff___52 *);
	void (*error_report)(struct neighbour___34 *, struct sk_buff___52 *);
	int (*output)(struct neighbour___34 *, struct sk_buff___52 *);
	int (*connected_output)(struct neighbour___34 *, struct sk_buff___52 *);
};

struct pneigh_entry___34 {
	struct pneigh_entry___34 *next;
	possible_net_t___52 net;
	struct net_device___52 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___34 {
	struct neighbour___34 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___34 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___34 *ctarget;
	struct net___62 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___34 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___34 *rule;
	u32 table;
	int flags;
};

struct proto___34 {
	void (*close)(struct sock___35 *, long int);
	int (*pre_connect)(struct sock___35 *, struct sockaddr *, int);
	int (*connect)(struct sock___35 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___35 *, int);
	struct sock___35 * (*accept)(struct sock___35 *, int, int *, bool);
	int (*ioctl)(struct sock___35 *, int, long unsigned int);
	int (*init)(struct sock___35 *);
	void (*destroy)(struct sock___35 *);
	void (*shutdown)(struct sock___35 *, int);
	int (*setsockopt)(struct sock___35 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___35 *, int, int, char *, int *);
	void (*keepalive)(struct sock___35 *, int);
	int (*sendmsg)(struct sock___35 *, struct msghdr___37 *, size_t);
	int (*recvmsg)(struct sock___35 *, struct msghdr___37 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___35 *, struct page___406 *, int, size_t, int);
	int (*bind)(struct sock___35 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___35 *, struct sk_buff___52 *);
	void (*release_cb)(struct sock___35 *);
	int (*hash)(struct sock___35 *);
	void (*unhash)(struct sock___35 *);
	void (*rehash)(struct sock___35 *);
	int (*get_port)(struct sock___35 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___35 *);
	bool (*stream_memory_read)(const struct sock___35 *);
	void (*enter_memory_pressure)(struct sock___35 *);
	void (*leave_memory_pressure)(struct sock___35 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___3 *rsk_prot;
	struct timewait_sock_ops___3 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___335 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___35 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct module___336;

struct file___406;

struct kiocb___406;

struct iov_iter___173;

struct poll_table_struct___249;

struct vm_area_struct___407;

struct inode___406;

struct file_lock___406;

struct page___407;

struct pipe_inode_info___87;

struct seq_file___345;

struct file_operations___406 {
	struct module___336 *owner;
	loff_t (*llseek)(struct file___406 *, loff_t, int);
	ssize_t (*read)(struct file___406 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___406 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___406 *, struct iov_iter___173 *);
	ssize_t (*write_iter)(struct kiocb___406 *, struct iov_iter___173 *);
	int (*iopoll)(struct kiocb___406 *, bool);
	int (*iterate)(struct file___406 *, struct dir_context *);
	int (*iterate_shared)(struct file___406 *, struct dir_context *);
	__poll_t (*poll)(struct file___406 *, struct poll_table_struct___249 *);
	long int (*unlocked_ioctl)(struct file___406 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___406 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___406 *, struct vm_area_struct___407 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___406 *, struct file___406 *);
	int (*flush)(struct file___406 *, fl_owner_t);
	int (*release)(struct inode___406 *, struct file___406 *);
	int (*fsync)(struct file___406 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___406 *, int);
	int (*lock)(struct file___406 *, int, struct file_lock___406 *);
	ssize_t (*sendpage)(struct file___406 *, struct page___407 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___406 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___406 *, int, struct file_lock___406 *);
	ssize_t (*splice_write)(struct pipe_inode_info___87 *, struct file___406 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___406 *, loff_t *, struct pipe_inode_info___87 *, size_t, unsigned int);
	int (*setlease)(struct file___406 *, long int, struct file_lock___406 **, void **);
	long int (*fallocate)(struct file___406 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___345 *, struct file___406 *);
	ssize_t (*copy_file_range)(struct file___406 *, loff_t, struct file___406 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___406 *, loff_t, struct file___406 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___406 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___407 {
	u64 seqnum;
	struct vm_area_struct___407 *vmas[4];
};

struct page_frag___407 {
	struct page___407 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___407;

struct mem_cgroup___143;

struct cred___374;

struct nsproxy___301;

struct signal_struct___281;

struct bio_list___200;

struct backing_dev_info___200;

struct css_set___255;

struct vm_struct___310;

struct task_struct___408 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___408 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___407 *mm;
	struct mm_struct___407 *active_mm;
	struct vmacache___407 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___408 *real_parent;
	struct task_struct___408 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___408 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___143 *active_memcg;
	long int rh_reserved2;
	struct pid___233 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___233 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___233 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___374 *ptracer_cred;
	const struct cred___374 *real_cred;
	const struct cred___374 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___301 *nsproxy;
	struct signal_struct___281 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___408 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___200 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___200 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___255 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___87 *splice_pipe;
	struct page_frag___407 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___143 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___408 *oom_reaper_list;
	struct vm_struct___310 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___154 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct secondary_data___408 {
	void *stack;
	struct task_struct___408 *task;
	long int status;
};

struct proc_ns_operations___29;

struct ns_common___29 {
	atomic_long_t stashed;
	const struct proc_ns_operations___29 *ops;
	unsigned int inum;
};

struct rw_semaphore___408 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___408 *owner;
};

struct key___374;

struct ucounts___271;

struct user_namespace___271 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___271 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___29 ns;
	long unsigned int flags;
	struct key___374 *persistent_keyring_register;
	struct rw_semaphore___408 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___271 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___407 *pgtable_t___407;

struct address_space___406;

struct dev_pagemap___394;

struct page___407 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___406 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___407 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___407 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___407 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___394 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___143 *mem_cgroup;
};

struct pglist_data___407;

struct lruvec___407 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___407 *pgdat;
};

struct zone___407 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___407 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___407 {
	struct zone___407 *zone;
	int zone_idx;
};

struct zonelist___407 {
	struct zoneref___407 _zonerefs[25];
};

struct pglist_data___407 {
	struct zone___407 node_zones[3];
	struct zonelist___407 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___408 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___408 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___407 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___407 {
	struct rw_semaphore___408 rwsem;
	struct notifier_block *head;
};

struct cgroup___255;

struct cgroup_subsys___255;

struct cgroup_subsys_state___255 {
	struct cgroup___255 *cgroup;
	struct cgroup_subsys___255 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___255 *parent;
};

struct kernfs_node___401;

struct cgroup_file___255 {
	struct kernfs_node___401 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___143;

struct mem_cgroup___143 {
	struct cgroup_subsys_state___255 css;
	struct mem_cgroup_id___16 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___255 events_file;
	struct cgroup_file___255 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___408 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___143 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct user_struct___374 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___374 *uid_keyring;
	struct key___374 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___394;

struct vm_area_struct___407 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___407 *vm_next;
	struct vm_area_struct___407 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___407 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___394 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___406 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___407;

struct mm_struct___407 {
	struct {
		struct vm_area_struct___407 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___406 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___408 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___407 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___408 *owner;
		struct user_namespace___271 *user_ns;
		struct file___406 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___407 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___374 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___374 *session_keyring;
	struct key___374 *process_keyring;
	struct key___374 *thread_keyring;
	struct key___374 *request_key_auth;
	void *security;
	struct user_struct___374 *user;
	struct user_namespace___271 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___63;

struct cgroup_namespace___255;

struct nsproxy___301 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net___63 *net_ns;
	struct cgroup_namespace___255 *cgroup_ns;
};

struct signal_struct___281 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___408 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___408 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___233 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___233 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___407 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___233 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___200;

struct bio_list___200 {
	struct bio___200 *head;
	struct bio___200 *tail;
};

struct bdi_writeback_congested___200;

struct bdi_writeback___200 {
	struct backing_dev_info___200 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___200 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___255 *memcg_css;
	struct cgroup_subsys_state___255 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___374;

struct dentry___406;

struct backing_dev_info___200 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___200 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___374 *dev;
	struct device___374 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___406 *debug_dir;
	struct dentry___406 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___255 {
	struct cgroup_subsys_state___255 *subsys[13];
	refcount_t refcount;
	struct css_set___255 *dom_cset;
	struct cgroup___255 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___255 *mg_src_cgrp;
	struct cgroup___255 *mg_dst_cgrp;
	struct css_set___255 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___406;

struct pipe_buffer___87;

struct pipe_inode_info___87 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___407 *tmp_page;
	struct fasync_struct___406 *fasync_readers;
	struct fasync_struct___406 *fasync_writers;
	struct pipe_buffer___87 *bufs;
	struct user_struct___374 *user;
};

struct vm_struct___310 {
	struct vm_struct___310 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___407 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___293 {
	struct task_struct___408 task;
	long unsigned int stack[8192];
};

struct address_space_operations___406;

struct address_space___406 {
	struct inode___406 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___408 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___406 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___394)(struct vm_area_struct___407 *, long unsigned int, const struct page___407 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___394)(struct page___407 *, void *);

struct dev_pagemap___394 {
	dev_page_fault_t___394 page_fault;
	dev_page_free_t___394 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___374 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___407 {
	struct vfsmount *mnt;
	struct dentry___406 *dentry;
};

struct file___406 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___407 f_path;
	struct inode___406 *f_inode;
	const struct file_operations___406 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___233 f_owner;
	const struct cred___374 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___406 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___394;

struct vm_operations_struct___394 {
	void (*open)(struct vm_area_struct___407 *);
	void (*close)(struct vm_area_struct___407 *);
	int (*split)(struct vm_area_struct___407 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___407 *);
	vm_fault_t (*fault)(struct vm_fault___394 *);
	vm_fault_t (*huge_fault)(struct vm_fault___394 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___394 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___407 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___394 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___394 *);
	int (*access)(struct vm_area_struct___407 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___407 *);
	int (*set_policy)(struct vm_area_struct___407 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___407 *, long unsigned int);
	struct page___407 * (*find_special_page)(struct vm_area_struct___407 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___407 {
	struct task_struct___408 *task;
	struct core_thread___407 *next;
};

struct core_state___407 {
	atomic_t nr_threads;
	struct core_thread___407 dumper;
	struct completion startup;
};

struct vm_fault___394 {
	struct vm_area_struct___407 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___407 *cow_page;
	struct mem_cgroup___143 *memcg;
	struct page___407 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___407 prealloc_pte;
};

struct kset___393;

struct kobj_type___393;

struct kobject___394 {
	const char *name;
	struct list_head entry;
	struct kobject___394 *parent;
	struct kset___393 *kset;
	struct kobj_type___393 *ktype;
	struct kernfs_node___401 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___334 {
	struct kobject___394 kobj;
	struct module___336 *mod;
	struct kobject___394 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___334 {
	struct module___336 *mod;
	struct latch_tree_node node;
};

struct module_layout___334 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___334 mtn;
};

struct module_attribute___334;

struct kernel_param___334;

struct module___336 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___334 mkobj;
	struct module_attribute___334 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___394 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___334 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___334 core_layout;
	struct module_layout___334 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide53;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide54;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bio_vec___202 {
	struct page___407 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___173 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___202 *bvec;
		struct pipe_inode_info___87 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct msghdr___38 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___173 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___406 *msg_iocb;
};

struct kiocb___406 {
	struct file___406 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___406 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dentry_operations___406;

struct super_block___406;

struct dentry___406 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___406 *d_parent;
	struct qstr d_name;
	struct inode___406 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___406 *d_op;
	struct super_block___406 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___406;

struct block_device___406;

struct inode___406 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___406 *i_op;
	struct super_block___406 *i_sb;
	struct address_space___406 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___408 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___200 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___406 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___406 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___87 *i_pipe;
		struct block_device___406 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___406 {
	int (*d_revalidate)(struct dentry___406 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___406 *, unsigned int);
	int (*d_hash)(const struct dentry___406 *, struct qstr *);
	int (*d_compare)(const struct dentry___406 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___406 *);
	int (*d_init)(struct dentry___406 *);
	void (*d_release)(struct dentry___406 *);
	void (*d_prune)(struct dentry___406 *);
	void (*d_iput)(struct dentry___406 *, struct inode___406 *);
	char * (*d_dname)(struct dentry___406 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___407 *);
	int (*d_manage)(const struct path___407 *, bool);
	struct dentry___406 * (*d_real)(struct dentry___406 *, const struct inode___406 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___406;

struct mem_dqinfo___406 {
	struct quota_format_type___406 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___406;

struct quota_info___406 {
	unsigned int flags;
	struct rw_semaphore___408 dqio_sem;
	struct inode___406 *files[3];
	struct mem_dqinfo___406 info[3];
	const struct quota_format_ops___406 *ops[3];
};

struct rcuwait___406 {
	struct task_struct___408 *task;
};

struct percpu_rw_semaphore___406 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___408 rw_sem;
	struct rcuwait___406 writer;
	int readers_block;
};

struct sb_writers___406 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___406 rw_sem[3];
};

struct shrink_control___143;

struct shrinker___143 {
	long unsigned int (*count_objects)(struct shrinker___143 *, struct shrink_control___143 *);
	long unsigned int (*scan_objects)(struct shrinker___143 *, struct shrink_control___143 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___406;

struct super_operations___406;

struct dquot_operations___406;

struct quotactl_ops___406;

struct super_block___406 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___406 *s_type;
	const struct super_operations___406 *s_op;
	const struct dquot_operations___406 *dq_op;
	const struct quotactl_ops___406 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___406 *s_root;
	struct rw_semaphore___408 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___406 *s_bdev;
	struct backing_dev_info___200 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___406 s_dquot;
	struct sb_writers___406 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___406 *s_d_op;
	int cleancache_poolid;
	struct shrinker___143 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___271 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___143 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___143 *memcg;
};

struct iattr___406 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___406 *ia_file;
};

struct dquot___406 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___406 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___406 {
	int qf_fmt_id;
	const struct quota_format_ops___406 *qf_ops;
	struct module___336 *qf_owner;
	struct quota_format_type___406 *qf_next;
};

struct quota_format_ops___406 {
	int (*check_quota_file)(struct super_block___406 *, int);
	int (*read_file_info)(struct super_block___406 *, int);
	int (*write_file_info)(struct super_block___406 *, int);
	int (*free_file_info)(struct super_block___406 *, int);
	int (*read_dqblk)(struct dquot___406 *);
	int (*commit_dqblk)(struct dquot___406 *);
	int (*release_dqblk)(struct dquot___406 *);
	int (*get_next_id)(struct super_block___406 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___406 {
	int (*write_dquot)(struct dquot___406 *);
	struct dquot___406 * (*alloc_dquot)(struct super_block___406 *, int);
	void (*destroy_dquot)(struct dquot___406 *);
	int (*acquire_dquot)(struct dquot___406 *);
	int (*release_dquot)(struct dquot___406 *);
	int (*mark_dirty)(struct dquot___406 *);
	int (*write_info)(struct super_block___406 *, int);
	qsize_t * (*get_reserved_space)(struct inode___406 *);
	int (*get_projid)(struct inode___406 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___406 *, qsize_t *);
	int (*get_next_id)(struct super_block___406 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___406 {
	int (*quota_on)(struct super_block___406 *, int, int, const struct path___407 *);
	int (*quota_off)(struct super_block___406 *, int);
	int (*quota_enable)(struct super_block___406 *, unsigned int);
	int (*quota_disable)(struct super_block___406 *, unsigned int);
	int (*quota_sync)(struct super_block___406 *, int);
	int (*set_info)(struct super_block___406 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___406 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___406 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___406 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___406 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___406 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___163;

struct address_space_operations___406 {
	int (*writepage)(struct page___407 *, struct writeback_control___163 *);
	int (*readpage)(struct file___406 *, struct page___407 *);
	int (*writepages)(struct address_space___406 *, struct writeback_control___163 *);
	int (*set_page_dirty)(struct page___407 *);
	int (*readpages)(struct file___406 *, struct address_space___406 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___406 *, struct address_space___406 *, loff_t, unsigned int, unsigned int, struct page___407 **, void **);
	int (*write_end)(struct file___406 *, struct address_space___406 *, loff_t, unsigned int, unsigned int, struct page___407 *, void *);
	sector_t (*bmap)(struct address_space___406 *, sector_t);
	void (*invalidatepage)(struct page___407 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___407 *, gfp_t);
	void (*freepage)(struct page___407 *);
	ssize_t (*direct_IO)(struct kiocb___406 *, struct iov_iter___173 *);
	int (*migratepage)(struct address_space___406 *, struct page___407 *, struct page___407 *, enum migrate_mode);
	bool (*isolate_page)(struct page___407 *, isolate_mode_t);
	void (*putback_page)(struct page___407 *);
	int (*launder_page)(struct page___407 *);
	int (*is_partially_uptodate)(struct page___407 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___407 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___406 *, struct page___407 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___406 *, sector_t *);
	void (*swap_deactivate)(struct file___406 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___163 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___200 *wb;
	struct inode___406 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___406 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___406 *bd_inode;
	struct super_block___406 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___406 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___200 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___406 {
	struct dentry___406 * (*lookup)(struct inode___406 *, struct dentry___406 *, unsigned int);
	const char * (*get_link)(struct dentry___406 *, struct inode___406 *, struct delayed_call *);
	int (*permission)(struct inode___406 *, int);
	struct posix_acl * (*get_acl)(struct inode___406 *, int);
	int (*readlink)(struct dentry___406 *, char *, int);
	int (*create)(struct inode___406 *, struct dentry___406 *, umode_t, bool);
	int (*link)(struct dentry___406 *, struct inode___406 *, struct dentry___406 *);
	int (*unlink)(struct inode___406 *, struct dentry___406 *);
	int (*symlink)(struct inode___406 *, struct dentry___406 *, const char *);
	int (*mkdir)(struct inode___406 *, struct dentry___406 *, umode_t);
	int (*rmdir)(struct inode___406 *, struct dentry___406 *);
	int (*mknod)(struct inode___406 *, struct dentry___406 *, umode_t, dev_t);
	int (*rename)(struct inode___406 *, struct dentry___406 *, struct inode___406 *, struct dentry___406 *, unsigned int);
	int (*setattr)(struct dentry___406 *, struct iattr___406 *);
	int (*getattr)(const struct path___407 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___406 *, char *, size_t);
	int (*fiemap)(struct inode___406 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___406 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___406 *, struct dentry___406 *, struct file___406 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___406 *, struct dentry___406 *, umode_t);
	int (*set_acl)(struct inode___406 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___406 {
	void (*fl_copy_lock)(struct file_lock___406 *, struct file_lock___406 *);
	void (*fl_release_private)(struct file_lock___406 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___406;

struct file_lock___406 {
	struct file_lock___406 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___406 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___406 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___406 *fl_ops;
	const struct lock_manager_operations___406 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___406 {
	int (*lm_compare_owner)(struct file_lock___406 *, struct file_lock___406 *);
	long unsigned int (*lm_owner_key)(struct file_lock___406 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___406 *);
	int (*lm_grant)(struct file_lock___406 *, int);
	bool (*lm_break)(struct file_lock___406 *);
	int (*lm_change)(struct file_lock___406 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___406 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___406 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___406 *fa_next;
	struct file___406 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___406 {
	const char *name;
	int fs_flags;
	struct dentry___406 * (*mount)(struct file_system_type___406 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___406 *);
	struct module___336 *owner;
	struct file_system_type___406 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___406 {
	struct inode___406 * (*alloc_inode)(struct super_block___406 *);
	void (*destroy_inode)(struct inode___406 *);
	void (*dirty_inode)(struct inode___406 *, int);
	int (*write_inode)(struct inode___406 *, struct writeback_control___163 *);
	int (*drop_inode)(struct inode___406 *);
	void (*evict_inode)(struct inode___406 *);
	void (*put_super)(struct super_block___406 *);
	int (*sync_fs)(struct super_block___406 *, int);
	int (*freeze_super)(struct super_block___406 *);
	int (*freeze_fs)(struct super_block___406 *);
	int (*thaw_super)(struct super_block___406 *);
	int (*unfreeze_fs)(struct super_block___406 *);
	int (*statfs)(struct dentry___406 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___406 *, int *, char *);
	void (*umount_begin)(struct super_block___406 *);
	int (*show_options)(struct seq_file___345 *, struct dentry___406 *);
	int (*show_devname)(struct seq_file___345 *, struct dentry___406 *);
	int (*show_path)(struct seq_file___345 *, struct dentry___406 *);
	int (*show_stats)(struct seq_file___345 *, struct dentry___406 *);
	ssize_t (*quota_read)(struct super_block___406 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___406 *, int, const char *, size_t, loff_t);
	struct dquot___406 ** (*get_dquots)(struct inode___406 *);
	int (*bdev_try_to_free_page)(struct super_block___406 *, struct page___407 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___406 *, struct shrink_control___143 *);
	long int (*free_cached_objects)(struct super_block___406 *, struct shrink_control___143 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___259)(struct file___406 *, wait_queue_head_t *, struct poll_table_struct___249 *);

struct poll_table_struct___249 {
	poll_queue_proc___259 _qproc;
	__poll_t _key;
};

struct seq_operations___345;

struct seq_file___345 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___345 *op;
	int poll_event;
	const struct file___406 *file;
	void *private;
};

typedef void bio_end_io_t___200(struct bio___200 *);

struct bio_integrity_payload___200;

struct bio_set___200;

struct bio___200 {
	struct bio___200 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___200 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___200 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___202 *bi_io_vec;
	struct bio_set___200 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___202 bi_inline_vecs[0];
};

struct socket_wq___36 {
	wait_queue_head_t wait;
	struct fasync_struct___406 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct sock___36;

struct proto_ops___36;

struct socket___37 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___36 *wq;
	struct file___406 *file;
	struct sock___36 *sk;
	const struct proto_ops___36 *ops;
};

typedef struct {
	struct net___63 *net;
} possible_net_t___53;

struct proto___35;

struct sock_common___35 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___35 *skc_prot;
	possible_net_t___53 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___36 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___53;

struct sk_buff_head___51 {
	struct sk_buff___53 *next;
	struct sk_buff___53 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___35;

struct dst_entry___35;

struct net_device___53;

struct sock___36 {
	struct sock_common___35 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___51 sk_error_queue;
	struct sk_buff_head___51 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___53 *head;
		struct sk_buff___53 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___35 *sk_filter;
	union {
		struct socket_wq___36 *sk_wq;
		struct socket_wq___36 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___35 *sk_rx_dst;
	struct dst_entry___35 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___53 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___51 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___407 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___35 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___233 *sk_peer_pid;
	const struct cred___374 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___37 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___143 *sk_memcg;
	void (*sk_state_change)(struct sock___36 *);
	void (*sk_data_ready)(struct sock___36 *);
	void (*sk_write_space)(struct sock___36 *);
	void (*sk_error_report)(struct sock___36 *);
	int (*sk_backlog_rcv)(struct sock___36 *, struct sk_buff___53 *);
	struct sk_buff___53 * (*sk_validate_xmit_skb)(struct sock___36 *, struct net_device___53 *, struct sk_buff___53 *);
	void (*sk_destruct)(struct sock___36 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

typedef int (*sk_read_actor_t___35)(read_descriptor_t *, struct sk_buff___53 *, unsigned int, size_t);

struct proto_ops___36 {
	int family;
	struct module___336 *owner;
	int (*release)(struct socket___37 *);
	int (*bind)(struct socket___37 *, struct sockaddr *, int);
	int (*connect)(struct socket___37 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___37 *, struct socket___37 *);
	int (*accept)(struct socket___37 *, struct socket___37 *, int, bool);
	int (*getname)(struct socket___37 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___406 *, struct socket___37 *, struct poll_table_struct___249 *);
	int (*ioctl)(struct socket___37 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___37 *, int);
	int (*shutdown)(struct socket___37 *, int);
	int (*setsockopt)(struct socket___37 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___37 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___37 *, struct msghdr___38 *, size_t);
	int (*recvmsg)(struct socket___37 *, struct msghdr___38 *, size_t, int);
	int (*mmap)(struct file___406 *, struct socket___37 *, struct vm_area_struct___407 *);
	ssize_t (*sendpage)(struct socket___37 *, struct page___407 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___37 *, loff_t *, struct pipe_inode_info___87 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___36 *, int);
	int (*peek_len)(struct socket___37 *);
	int (*read_sock)(struct sock___36 *, read_descriptor_t *, sk_read_actor_t___35);
	int (*sendpage_locked)(struct sock___36 *, struct page___407 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___36 *, struct msghdr___38 *, size_t);
	int (*set_rcvlowat)(struct sock___36 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct nf_bridge_info___51;

struct sk_buff___53 {
	union {
		struct {
			struct sk_buff___53 *next;
			struct sk_buff___53 *prev;
			union {
				struct net_device___53 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___36 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___53 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___51 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___51;

struct netns_frags___51 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___51 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_rules_ops___35;

struct fib_notifier_ops___35;

struct netns_ipv4___51 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___35 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___36 *fibnl;
	struct sock___36 **icmp_sk;
	struct sock___36 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___36 **tcp_sk;
	struct netns_frags___51 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___35 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___35 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___35 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___35;

struct dst_ops___62 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___62 *);
	struct dst_entry___35 * (*check)(struct dst_entry___35 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___35 *);
	unsigned int (*mtu)(const struct dst_entry___35 *);
	u32 * (*cow_metrics)(struct dst_entry___35 *, long unsigned int);
	void (*destroy)(struct dst_entry___35 *);
	void (*ifdown)(struct dst_entry___35 *, struct net_device___53 *, int);
	struct dst_entry___35 * (*negative_advice)(struct dst_entry___35 *);
	void (*link_failure)(struct sk_buff___53 *);
	void (*update_pmtu)(struct dst_entry___35 *, struct sock___36 *, struct sk_buff___53 *, u32);
	void (*redirect)(struct dst_entry___35 *, struct sock___36 *, struct sk_buff___53 *);
	int (*local_out)(struct net___63 *, struct sock___36 *, struct sk_buff___53 *);
	struct neighbour___35 * (*neigh_lookup)(const struct dst_entry___35 *, struct sk_buff___53 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___35 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___62 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___51 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___62 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___35 *fib6_rules_ops;
	struct sock___36 **icmp_sk;
	struct sock___36 *ndisc_sk;
	struct sock___36 *tcp_sk;
	struct sock___36 *igmp_sk;
	struct sock___36 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___35 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___35 *notifier_ops;
	struct fib_notifier_ops___35 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___36 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___36 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___51 {
	struct netns_frags___51 frags;
};

struct netns_xfrm___62 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___36 *nlsk;
	struct sock___36 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___62 xfrm4_dst_ops;
	struct dst_ops___62 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___45;

struct net___63 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___271 *user_ns;
	struct ucounts___271 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___29 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___36 *rtnl;
	struct sock___36 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___53 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___51 ipv4;
	struct netns_ipv6___62 ipv6;
	struct netns_sctp___36 sctp;
	struct netns_nf___3 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___51 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___36 *nfnl;
	struct sock___36 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___62 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___36 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___45 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kernfs_root___400;

struct kernfs_elem_dir___400 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___400 *root;
};

struct kernfs_syscall_ops___400;

struct kernfs_root___400 {
	struct kernfs_node___401 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___400 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___400 {
	struct kernfs_node___401 *target_kn;
};

struct kernfs_ops___400;

struct kernfs_elem_attr___400 {
	const struct kernfs_ops___400 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___401 *notify_next;
};

struct kernfs_node___401 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___401 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___400 dir;
		struct kernfs_elem_symlink___400 symlink;
		struct kernfs_elem_attr___400 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___400;

struct kernfs_ops___400 {
	int (*open)(struct kernfs_open_file___400 *);
	void (*release)(struct kernfs_open_file___400 *);
	int (*seq_show)(struct seq_file___345 *, void *);
	void * (*seq_start)(struct seq_file___345 *, loff_t *);
	void * (*seq_next)(struct seq_file___345 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___345 *, void *);
	ssize_t (*read)(struct kernfs_open_file___400 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___400 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___400 *, struct vm_area_struct___407 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___400 *, struct poll_table_struct___249 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___400 {
	int (*remount_fs)(struct kernfs_root___400 *, int *, char *);
	int (*show_options)(struct seq_file___345 *, struct kernfs_root___400 *);
	int (*mkdir)(struct kernfs_node___401 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___401 *);
	int (*rename)(struct kernfs_node___401 *, struct kernfs_node___401 *, const char *);
	int (*show_path)(struct seq_file___345 *, struct kernfs_node___401 *, struct kernfs_root___400 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___400 {
	struct kernfs_node___401 *kn;
	struct file___406 *file;
	struct seq_file___345 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___394 *vm_ops;
};

struct kobj_ns_type_operations___35 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___36 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___370;

struct attribute_group___371 {
	const char *name;
	umode_t (*is_visible)(struct kobject___394 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___394 *, struct bin_attribute___370 *, int);
	struct attribute **attrs;
	struct bin_attribute___370 **bin_attrs;
};

struct bin_attribute___370 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___406 *, struct kobject___394 *, struct bin_attribute___370 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___406 *, struct kobject___394 *, struct bin_attribute___370 *, char *, loff_t, size_t);
	int (*mmap)(struct file___406 *, struct kobject___394 *, struct bin_attribute___370 *, struct vm_area_struct___407 *);
};

struct sysfs_ops___393 {
	ssize_t (*show)(struct kobject___394 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___394 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___393;

struct kset___393 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___394 kobj;
	const struct kset_uevent_ops___393 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___393 {
	void (*release)(struct kobject___394 *);
	const struct sysfs_ops___393 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___35 * (*child_ns_type)(struct kobject___394 *);
	const void * (*namespace)(struct kobject___394 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___393 {
	int (* const filter)(struct kset___393 *, struct kobject___394 *);
	const char * (* const name)(struct kset___393 *, struct kobject___394 *);
	int (* const uevent)(struct kset___393 *, struct kobject___394 *, struct kobj_uevent_env *);
};

struct kobj_attribute___384 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___394 *, struct kobj_attribute___384 *, char *);
	ssize_t (*store)(struct kobject___394 *, struct kobj_attribute___384 *, const char *, size_t);
};

struct dev_pm_ops___374 {
	int (*prepare)(struct device___374 *);
	void (*complete)(struct device___374 *);
	int (*suspend)(struct device___374 *);
	int (*resume)(struct device___374 *);
	int (*freeze)(struct device___374 *);
	int (*thaw)(struct device___374 *);
	int (*poweroff)(struct device___374 *);
	int (*restore)(struct device___374 *);
	int (*suspend_late)(struct device___374 *);
	int (*resume_early)(struct device___374 *);
	int (*freeze_late)(struct device___374 *);
	int (*thaw_early)(struct device___374 *);
	int (*poweroff_late)(struct device___374 *);
	int (*restore_early)(struct device___374 *);
	int (*suspend_noirq)(struct device___374 *);
	int (*resume_noirq)(struct device___374 *);
	int (*freeze_noirq)(struct device___374 *);
	int (*thaw_noirq)(struct device___374 *);
	int (*poweroff_noirq)(struct device___374 *);
	int (*restore_noirq)(struct device___374 *);
	int (*runtime_suspend)(struct device___374 *);
	int (*runtime_resume)(struct device___374 *);
	int (*runtime_idle)(struct device___374 *);
};

struct dev_pm_info___374 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___374 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___374;

struct bus_type___374;

struct device_driver___374;

struct dev_pm_domain___374;

struct dma_map_ops___146;

struct fwnode_handle___294;

struct class___374;

struct device___374 {
	struct device___374 *parent;
	struct device_private *p;
	struct kobject___394 kobj;
	const char *init_name;
	const struct device_type___374 *type;
	struct mutex mutex;
	struct bus_type___374 *bus;
	struct device_driver___374 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___374 power;
	struct dev_pm_domain___374 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___146 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___294 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___374 *class;
	const struct attribute_group___371 **groups;
	void (*release)(struct device___374 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___374 {
	struct dev_pm_ops___374 ops;
	void (*detach)(struct device___374 *, bool);
	int (*activate)(struct device___374 *);
	void (*sync)(struct device___374 *);
	void (*dismiss)(struct device___374 *);
};

struct bus_type___374 {
	const char *name;
	const char *dev_name;
	struct device___374 *dev_root;
	const struct attribute_group___371 **bus_groups;
	const struct attribute_group___371 **dev_groups;
	const struct attribute_group___371 **drv_groups;
	int (*match)(struct device___374 *, struct device_driver___374 *);
	int (*uevent)(struct device___374 *, struct kobj_uevent_env *);
	int (*probe)(struct device___374 *);
	int (*remove)(struct device___374 *);
	void (*shutdown)(struct device___374 *);
	int (*online)(struct device___374 *);
	int (*offline)(struct device___374 *);
	int (*suspend)(struct device___374 *, pm_message_t);
	int (*resume)(struct device___374 *);
	int (*num_vf)(struct device___374 *);
	int (*dma_configure)(struct device___374 *);
	const struct dev_pm_ops___374 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___374 {
	const char *name;
	struct bus_type___374 *bus;
	struct module___336 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___374 *);
	int (*remove)(struct device___374 *);
	void (*shutdown)(struct device___374 *);
	int (*suspend)(struct device___374 *, pm_message_t);
	int (*resume)(struct device___374 *);
	const struct attribute_group___371 **groups;
	const struct dev_pm_ops___374 *pm;
	void (*coredump)(struct device___374 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___374 {
	const char *name;
	const struct attribute_group___371 **groups;
	int (*uevent)(struct device___374 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___374 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___374 *);
	const struct dev_pm_ops___374 *pm;
};

struct class___374 {
	const char *name;
	struct module___336 *owner;
	const struct attribute_group___371 **class_groups;
	const struct attribute_group___371 **dev_groups;
	struct kobject___394 *dev_kobj;
	int (*dev_uevent)(struct device___374 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___374 *, umode_t *);
	void (*class_release)(struct class___374 *);
	void (*dev_release)(struct device___374 *);
	int (*shutdown_pre)(struct device___374 *);
	const struct kobj_ns_type_operations___35 *ns_type;
	const void * (*namespace)(struct device___374 *);
	const struct dev_pm_ops___374 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___146 {
	void * (*alloc)(struct device___374 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___374 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___374 *, struct vm_area_struct___407 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___374 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___374 *, struct page___407 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___374 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___374 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___374 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___374 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___374 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___374 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___374 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___374 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___374 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___374 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___374 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___374 *, u64);
	u64 (*get_required_mask)(struct device___374 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___294;

struct fwnode_handle___294 {
	struct fwnode_handle___294 *secondary;
	const struct fwnode_operations___294 *ops;
};

typedef void compound_page_dtor___394(struct page___407 *);

struct fwnode_reference_args___294;

struct fwnode_endpoint___294;

struct fwnode_operations___294 {
	struct fwnode_handle___294 * (*get)(struct fwnode_handle___294 *);
	void (*put)(struct fwnode_handle___294 *);
	bool (*device_is_available)(const struct fwnode_handle___294 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___294 *, const struct device___374 *);
	bool (*property_present)(const struct fwnode_handle___294 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___294 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___294 *, const char *, const char **, size_t);
	struct fwnode_handle___294 * (*get_parent)(const struct fwnode_handle___294 *);
	struct fwnode_handle___294 * (*get_next_child_node)(const struct fwnode_handle___294 *, struct fwnode_handle___294 *);
	struct fwnode_handle___294 * (*get_named_child_node)(const struct fwnode_handle___294 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___294 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___294 *);
	struct fwnode_handle___294 * (*graph_get_next_endpoint)(const struct fwnode_handle___294 *, struct fwnode_handle___294 *);
	struct fwnode_handle___294 * (*graph_get_remote_endpoint)(const struct fwnode_handle___294 *);
	struct fwnode_handle___294 * (*graph_get_port_parent)(struct fwnode_handle___294 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___294 *, struct fwnode_endpoint___294 *);
};

struct fwnode_endpoint___294 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___294 *local_fwnode;
};

struct fwnode_reference_args___294 {
	struct fwnode_handle___294 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___87;

struct pipe_buffer___87 {
	struct page___407 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___87 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___87 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___87 *, struct pipe_buffer___87 *);
	void (*release)(struct pipe_inode_info___87 *, struct pipe_buffer___87 *);
	int (*steal)(struct pipe_inode_info___87 *, struct pipe_buffer___87 *);
	union {
		bool (*get)(struct pipe_inode_info___87 *, struct pipe_buffer___87 *);
		struct {
			void (*get)(struct pipe_inode_info___87 *, struct pipe_buffer___87 *);
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
};

struct nf_bridge_info___51 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___51 = 0,
		BRNF_PROTO_8021Q___51 = 1,
		BRNF_PROTO_PPPOE___51 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___53 *physindev;
	struct net_device___53 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___51(struct sk_buff___53 **);

struct net_device_ops___51;

struct ethtool_ops___51;

struct l3mdev_ops___35;

struct xfrmdev_ops___51;

struct tlsdev_ops___51;

struct header_ops___51;

struct netdev_rx_queue___51;

struct mini_Qdisc___45;

struct netdev_queue___51;

struct Qdisc___45;

struct rtnl_link_ops___45;

struct dcbnl_rtnl_ops___51;

struct net_device___53 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___51 *netdev_ops;
	const struct ethtool_ops___51 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___35 *l3mdev_ops;
	const struct ndisc_ops___2 *ndisc_ops;
	const struct xfrmdev_ops___51 *xfrmdev_ops;
	const struct tlsdev_ops___51 *tlsdev_ops;
	const struct header_ops___51 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___393 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___2 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___51 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___45 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___51 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___45 *miniq_ingress;
	struct netdev_queue___51 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___51 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___45 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___45 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___51 = 0,
		NETREG_REGISTERED___51 = 1,
		NETREG_UNREGISTERING___51 = 2,
		NETREG_UNREGISTERED___51 = 3,
		NETREG_RELEASED___51 = 4,
		NETREG_DUMMY___51 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___51 = 0,
		RTNL_LINK_INITIALIZING___51 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___53 *);
	struct netpoll_info *npinfo;
	possible_net_t___53 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___374 dev;
	const struct attribute_group___371 *sysfs_groups[4];
	const struct attribute_group___371 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___45 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___51 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct ethtool_ops___51 {
	int (*get_settings)(struct net_device___53 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___53 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___53 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___53 *);
	void (*get_regs)(struct net_device___53 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___53 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___53 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___53 *);
	void (*set_msglevel)(struct net_device___53 *, u32);
	int (*nway_reset)(struct net_device___53 *);
	u32 (*get_link)(struct net_device___53 *);
	int (*get_eeprom_len)(struct net_device___53 *);
	int (*get_eeprom)(struct net_device___53 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___53 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___53 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___53 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___53 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___53 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___53 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___53 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___53 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___53 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___53 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___53 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___53 *);
	void (*complete)(struct net_device___53 *);
	u32 (*get_priv_flags)(struct net_device___53 *);
	int (*set_priv_flags)(struct net_device___53 *, u32);
	int (*get_sset_count)(struct net_device___53 *, int);
	int (*get_rxnfc)(struct net_device___53 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___53 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___53 *, struct ethtool_flash *);
	int (*reset)(struct net_device___53 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___53 *);
	u32 (*get_rxfh_indir_size)(struct net_device___53 *);
	int (*get_rxfh)(struct net_device___53 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___53 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___53 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___53 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___53 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___53 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___53 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___53 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___53 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___53 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___53 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___53 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___53 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___53 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___53 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___53 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___53 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___53 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___53 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___53 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___53 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___53 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	int (*get_fecparam)(struct net_device___53 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___53 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___53 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___53 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___53 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___51;

struct inet_frags___51 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___51 *, const void *);
	void (*destructor)(struct inet_frag_queue___51 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___51 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___53 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___53 *fragments_tail;
	struct sk_buff___53 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___51 *net;
	struct callback_head rcu;
};

struct fib_rule___35;

struct fib_lookup_arg___35;

struct fib_rules_ops___35 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___35 *, struct flowi *, int, struct fib_lookup_arg___35 *);
	bool (*suppress)(struct fib_rule___35 *, struct fib_lookup_arg___35 *);
	int (*match)(struct fib_rule___35 *, struct flowi *, int);
	int (*configure)(struct fib_rule___35 *, struct sk_buff___53 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___35 *);
	int (*compare)(struct fib_rule___35 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___35 *, struct sk_buff___53 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___35 *);
	void (*flush_cache)(struct fib_rules_ops___35 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___336 *owner;
	struct net___63 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___35 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___63 *);
	int (*fib_dump)(struct net___63 *, struct notifier_block *);
	struct module___336 *owner;
	struct callback_head rcu;
};

struct dst_entry___35 {
	struct net_device___53 *dev;
	struct dst_ops___62 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___53 *);
	int (*output)(struct net___63 *, struct sock___36 *, struct sk_buff___53 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___35;

struct neigh_parms___35;

struct neigh_ops___35;

struct neighbour___35 {
	struct neighbour___35 *next;
	struct neigh_table___35 *tbl;
	struct neigh_parms___35 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___51 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___35 *, struct sk_buff___53 *);
	const struct neigh_ops___35 *ops;
	struct callback_head rcu;
	struct net_device___53 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct proc_ns_operations___29 {
	const char *name;
	const char *real_ns_name;
	int type;
	struct ns_common___29 * (*get)(struct task_struct___408 *);
	void (*put)(struct ns_common___29 *);
	int (*install)(struct nsproxy___301 *, struct ns_common___29 *);
	struct user_namespace___271 * (*owner)(struct ns_common___29 *);
	struct ns_common___29 * (*get_parent)(struct ns_common___29 *);
};

struct ucounts___271 {
	struct hlist_node node;
	struct user_namespace___271 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_prog_aux___48;

struct bpf_prog___45 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___48 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

typedef int (*key_restrict_link_func_t___375)(struct key___374 *, const struct key_type *, const union key_payload *, struct key___374 *);

struct key_restriction___374;

struct key___374 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___408 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___374 *restrict_link;
};

struct key_restriction___374 {
	key_restrict_link_func_t___375 check;
	struct key___374 *key;
	struct key_type *keytype;
};

struct seq_operations___345 {
	void * (*start)(struct seq_file___345 *, loff_t *);
	void (*stop)(struct seq_file___345 *, void *);
	void * (*next)(struct seq_file___345 *, void *, loff_t *);
	int (*show)(struct seq_file___345 *, void *);
};

struct pernet_operations___52 {
	struct list_head list;
	int (*init)(struct net___63 *);
	void (*exit)(struct net___63 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___51 {
	int (*ieee_getets)(struct net_device___53 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___53 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___53 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___53 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___53 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___53 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___53 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___53 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___53 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___53 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___53 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___53 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___53 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___53 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___53 *);
	u8 (*setstate)(struct net_device___53 *, u8);
	void (*getpermhwaddr)(struct net_device___53 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___53 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___53 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___53 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___53 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___53 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___53 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___53 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___53 *, int, u8 *);
	void (*setpfccfg)(struct net_device___53 *, int, u8);
	void (*getpfccfg)(struct net_device___53 *, int, u8 *);
	u8 (*setall)(struct net_device___53 *);
	u8 (*getcap)(struct net_device___53 *, int, u8 *);
	int (*getnumtcs)(struct net_device___53 *, int, u8 *);
	int (*setnumtcs)(struct net_device___53 *, int, u8);
	u8 (*getpfcstate)(struct net_device___53 *);
	void (*setpfcstate)(struct net_device___53 *, u8);
	void (*getbcncfg)(struct net_device___53 *, int, u32 *);
	void (*setbcncfg)(struct net_device___53 *, int, u32);
	void (*getbcnrp)(struct net_device___53 *, int, u8 *);
	void (*setbcnrp)(struct net_device___53 *, int, u8);
	int (*setapp)(struct net_device___53 *, u8, u16, u8);
	int (*getapp)(struct net_device___53 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___53 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___53 *, int, u8);
	u8 (*getdcbx)(struct net_device___53 *);
	u8 (*setdcbx)(struct net_device___53 *, u8);
	int (*peer_getappinfo)(struct net_device___53 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___53 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___53 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___53 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___53 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___53 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___255 {
	refcount_t count;
	struct ns_common___29 ns;
	struct user_namespace___271 *user_ns;
	struct ucounts___271 *ucounts;
	struct css_set___255 *root_cset;
};

struct bpf_map___256;

struct bpf_map_ops___255 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___256 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___256 *, struct file___406 *);
	void (*map_free)(struct bpf_map___256 *);
	int (*map_get_next_key)(struct bpf_map___256 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___256 *);
	void * (*map_lookup_elem)(struct bpf_map___256 *, void *);
	int (*map_update_elem)(struct bpf_map___256 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___256 *, void *);
	int (*map_push_elem)(struct bpf_map___256 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___256 *, void *);
	int (*map_peek_elem)(struct bpf_map___256 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___256 *, struct file___406 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___256 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___256 *, void *, struct seq_file___345 *);
	int (*map_check_btf)(const struct bpf_map___256 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___256 {
	const struct bpf_map_ops___255 *ops;
	struct bpf_map___256 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___374 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___51;

struct bpf_map_dev_ops___51 {
	int (*map_get_next_key)(struct bpf_offloaded_map___51 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___51 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___51 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___51 *, void *);
};

struct bpf_offloaded_map___51 {
	struct bpf_map___256 map;
	struct net_device___53 *netdev;
	const struct bpf_map_dev_ops___51 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___45 {
	int (*test_run)(struct bpf_prog___45 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___45 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___45 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___45 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___45 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___45 *, u32 *);
};

struct bpf_prog_offload_ops___45 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___45 *);
	int (*translate)(struct bpf_prog___45 *);
	void (*destroy)(struct bpf_prog___45 *);
};

struct bpf_prog_offload___45 {
	struct bpf_prog___45 *prog;
	struct net_device___53 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___45 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___48 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___45 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___45 *ops;
	struct bpf_map___256 **used_maps;
	struct bpf_prog___45 *prog;
	struct user_struct___374 *user;
	u64 load_time;
	struct bpf_map___256 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___45 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___45 {
	struct bpf_prog___45 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___45 {
	struct callback_head rcu;
	struct bpf_prog_array_item___45 items[0];
};

struct cgroup_bpf___45 {
	struct bpf_prog_array___45 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___45 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___256;

typedef void (*kthread_work_func_t___256)(struct kthread_work___256 *);

struct kthread_worker___256;

struct kthread_work___256 {
	struct list_head node;
	kthread_work_func_t___256 func;
	struct kthread_worker___256 *worker;
	int canceling;
};

struct kthread_worker___256 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___408 *task;
	struct kthread_work___256 *current_work;
};

struct kthread_delayed_work___255 {
	struct kthread_work___256 work;
	struct timer_list timer;
};

struct psi_group___255 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___256 *poll_kworker;
	struct kthread_delayed_work___255 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___255;

struct cgroup_rstat_cpu___255;

struct cgroup___255 {
	struct cgroup_subsys_state___255 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___401 *kn;
	struct cgroup_file___255 procs_file;
	struct cgroup_file___255 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___255 *subsys[13];
	struct cgroup_root___255 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___255 *dom_cgrp;
	struct cgroup_rstat_cpu___255 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___45 bpf;
	atomic_t congestion_count;
	struct cgroup___255 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___255 psi;
	int ancestor_ids[0];
};

struct cftype___255;

struct cgroup_subsys___255 {
	struct cgroup_subsys_state___255 * (*css_alloc)(struct cgroup_subsys_state___255 *);
	int (*css_online)(struct cgroup_subsys_state___255 *);
	void (*css_offline)(struct cgroup_subsys_state___255 *);
	void (*css_released)(struct cgroup_subsys_state___255 *);
	void (*css_free)(struct cgroup_subsys_state___255 *);
	void (*css_reset)(struct cgroup_subsys_state___255 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___255 *, int);
	int (*css_extra_stat_show)(struct seq_file___345 *, struct cgroup_subsys_state___255 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___408 *);
	void (*cancel_fork)(struct task_struct___408 *);
	void (*fork)(struct task_struct___408 *);
	void (*exit)(struct task_struct___408 *);
	void (*free)(struct task_struct___408 *);
	void (*bind)(struct cgroup_subsys_state___255 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___255 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___255 *dfl_cftypes;
	struct cftype___255 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___255 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___255 *updated_children;
	struct cgroup___255 *updated_next;
};

struct cgroup_root___255 {
	struct kernfs_root___400 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___255 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___255 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___255 *ss;
	struct list_head node;
	struct kernfs_ops___400 *kf_ops;
	int (*open)(struct kernfs_open_file___400 *);
	void (*release)(struct kernfs_open_file___400 *);
	u64 (*read_u64)(struct cgroup_subsys_state___255 *, struct cftype___255 *);
	s64 (*read_s64)(struct cgroup_subsys_state___255 *, struct cftype___255 *);
	int (*seq_show)(struct seq_file___345 *, void *);
	void * (*seq_start)(struct seq_file___345 *, loff_t *);
	void * (*seq_next)(struct seq_file___345 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___345 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___255 *, struct cftype___255 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___255 *, struct cftype___255 *, s64);
	ssize_t (*write)(struct kernfs_open_file___400 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___400 *, struct poll_table_struct___249 *);
};

struct xdp_rxq_info___51 {
	struct net_device___53 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___51 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___53 *dev_rx;
};

struct netlink_skb_parms___6 {
	struct scm_creds creds;
	__u32 portid;
	__u32 dst_group;
	__u32 flags;
	struct sock___36 *sk;
	bool nsid_is_set;
	int nsid;
};

struct netlink_callback___53 {
	struct sk_buff___53 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___53 *);
	int (*dump)(struct sk_buff___53 *, struct netlink_callback___53 *);
	int (*done)(struct netlink_callback___53 *);
	void *data;
	struct module___336 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___51 {
	int (*create)(struct sk_buff___53 *, struct net_device___53 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___53 *, unsigned char *);
	int (*cache)(const struct neighbour___35 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___53 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___51 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___51 *, int);
	int poll_owner;
	struct net_device___53 *dev;
	struct sk_buff___53 *gro_list;
	struct sk_buff___53 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___51 {
	struct net_device___53 *dev;
	struct Qdisc___45 *qdisc;
	struct Qdisc___45 *qdisc_sleeping;
	struct kobject___394 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___53 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___45 {
	struct sk_buff___53 *head;
	struct sk_buff___53 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___45;

struct Qdisc___45 {
	int (*enqueue)(struct sk_buff___53 *, struct Qdisc___45 *, struct sk_buff___53 **);
	struct sk_buff___53 * (*dequeue)(struct Qdisc___45 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___45 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___51 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___51 gso_skb;
	struct qdisc_skb_head___45 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___45 *next_sched;
	struct sk_buff_head___51 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___51 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___394 kobj;
	struct net_device___53 *dev;
	long: 64;
	struct xdp_rxq_info___51 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___51)(struct net_device___53 *, struct sk_buff___53 *, struct net_device___53 *);

struct netdev_bpf___51 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___45 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___45 *prog;
			const struct bpf_prog_offload_ops___45 *ops;
		} verifier;
		struct {
			struct bpf_prog___45 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___51 *offmap;
		};
		struct {
			struct xdp_umem *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___51 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___53 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___51 {
	int (*tls_dev_add)(struct net_device___53 *, struct sock___36 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___53 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___53 *, struct sock___36 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___51 {
	int (*ndo_init)(struct net_device___53 *);
	void (*ndo_uninit)(struct net_device___53 *);
	int (*ndo_open)(struct net_device___53 *);
	int (*ndo_stop)(struct net_device___53 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___53 *, struct net_device___53 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___53 *, struct net_device___53 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___53 *, struct sk_buff___53 *, struct net_device___53 *, select_queue_fallback_t___51);
	void (*ndo_change_rx_flags)(struct net_device___53 *, int);
	void (*ndo_set_rx_mode)(struct net_device___53 *);
	int (*ndo_set_mac_address)(struct net_device___53 *, void *);
	int (*ndo_validate_addr)(struct net_device___53 *);
	int (*ndo_do_ioctl)(struct net_device___53 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___53 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___53 *, int);
	int (*ndo_neigh_setup)(struct net_device___53 *, struct neigh_parms___35 *);
	void (*ndo_tx_timeout)(struct net_device___53 *);
	void (*ndo_get_stats64)(struct net_device___53 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___53 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___53 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___53 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___53 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___53 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___53 *);
	int (*ndo_netpoll_setup)(struct net_device___53 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___53 *);
	int (*ndo_set_vf_mac)(struct net_device___53 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___53 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___53 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___53 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___53 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___53 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___53 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___53 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___53 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___53 *, int, struct sk_buff___53 *);
	int (*ndo_set_vf_guid)(struct net_device___53 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___53 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___53 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___53 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___53 *, const struct sk_buff___53 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___53 *, struct net_device___53 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___53 *, struct net_device___53 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___53 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___53 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___53 *, struct neighbour___35 *);
	void (*ndo_neigh_destroy)(struct net_device___53 *, struct neighbour___35 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___53 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___53 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___53 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___53 *, struct netlink_callback___53 *, struct net_device___53 *, struct net_device___53 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___53 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___53 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___53 *, u32, u32, struct net_device___53 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___53 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___53 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___53 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___53 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___53 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___53 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___53 *, struct net_device___53 *);
	void (*ndo_dfwd_del_station)(struct net_device___53 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___53 *);
	int (*ndo_set_tx_maxrate)(struct net_device___53 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___53 *);
	int (*ndo_change_proto_down)(struct net_device___53 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___53 *, struct sk_buff___53 *);
	void (*ndo_set_rx_headroom)(struct net_device___53 *, int);
	int (*ndo_bpf)(struct net_device___53 *, struct netdev_bpf___51 *);
	int (*ndo_xdp_xmit)(struct net_device___53 *, int, struct xdp_frame___51 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___53 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___53 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___35 {
	possible_net_t___53 net;
	struct net_device___53 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___35 *);
	void (*neigh_cleanup)(struct neighbour___35 *);
	struct neigh_table___35 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___35 {
	u32 (*l3mdev_fib_table)(const struct net_device___53 *);
	struct sk_buff___53 * (*l3mdev_l3_rcv)(struct net_device___53 *, struct sk_buff___53 *, u16);
	struct sk_buff___53 * (*l3mdev_l3_out)(struct net_device___53 *, struct sock___36 *, struct sk_buff___53 *, u16);
	struct dst_entry___35 * (*l3mdev_link_scope_lookup)(const struct net_device___53 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct tcf_proto___45;

struct mini_Qdisc___45 {
	struct tcf_proto___45 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___45 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___53 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___63 *, struct net_device___53 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___53 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___53 *, struct list_head *);
	size_t (*get_size)(const struct net_device___53 *);
	int (*fill_info)(struct sk_buff___53 *, const struct net_device___53 *);
	size_t (*get_xstats_size)(const struct net_device___53 *);
	int (*fill_xstats)(struct sk_buff___53 *, const struct net_device___53 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___53 *, struct net_device___53 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___53 *, const struct net_device___53 *);
	int (*fill_slave_info)(struct sk_buff___53 *, const struct net_device___53 *, const struct net_device___53 *);
	struct net___63 * (*get_link_net)(const struct net_device___53 *);
	size_t (*get_linkxstats_size)(const struct net_device___53 *, int);
	int (*fill_linkxstats)(struct sk_buff___53 *, const struct net_device___53 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___51 {
	struct list_head poll_list;
	struct sk_buff_head___51 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___51 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___45 *output_queue;
	struct Qdisc___45 **output_queue_tailp;
	struct sk_buff___53 *completion_queue;
	struct sk_buff_head___51 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___51 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___51 input_pkt_queue;
	struct napi_struct___51 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rtgenmsg {
	unsigned char rtgen_family;
};

enum rtnetlink_groups {
	RTNLGRP_NONE = 0,
	RTNLGRP_LINK = 1,
	RTNLGRP_NOTIFY = 2,
	RTNLGRP_NEIGH = 3,
	RTNLGRP_TC = 4,
	RTNLGRP_IPV4_IFADDR = 5,
	RTNLGRP_IPV4_MROUTE = 6,
	RTNLGRP_IPV4_ROUTE = 7,
	RTNLGRP_IPV4_RULE = 8,
	RTNLGRP_IPV6_IFADDR = 9,
	RTNLGRP_IPV6_MROUTE = 10,
	RTNLGRP_IPV6_ROUTE = 11,
	RTNLGRP_IPV6_IFINFO = 12,
	RTNLGRP_DECnet_IFADDR = 13,
	RTNLGRP_NOP2 = 14,
	RTNLGRP_DECnet_ROUTE = 15,
	RTNLGRP_DECnet_RULE = 16,
	RTNLGRP_NOP4 = 17,
	RTNLGRP_IPV6_PREFIX = 18,
	RTNLGRP_IPV6_RULE = 19,
	RTNLGRP_ND_USEROPT = 20,
	RTNLGRP_PHONET_IFADDR = 21,
	RTNLGRP_PHONET_ROUTE = 22,
	RTNLGRP_DCB = 23,
	RTNLGRP_IPV4_NETCONF = 24,
	RTNLGRP_IPV6_NETCONF = 25,
	RTNLGRP_MDB = 26,
	RTNLGRP_MPLS_ROUTE = 27,
	RTNLGRP_NSID = 28,
	RTNLGRP_MPLS_NETCONF = 29,
	RTNLGRP_IPV4_MROUTE_R = 30,
	RTNLGRP_IPV6_MROUTE_R = 31,
	__RTNLGRP_MAX = 32,
};

enum {
	NETNSA_NONE = 0,
	NETNSA_NSID = 1,
	NETNSA_PID = 2,
	NETNSA_FD = 3,
	__NETNSA_MAX = 4,
};

struct bdi_writeback_congested___200 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___200 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___200 {
	struct bio___200 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___202 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___202 bip_inline_vecs[0];
};

struct bio_set___200 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___200 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___143 {
	struct mem_cgroup___143 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___143 {
	struct lruvec___407 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___143 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___143 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct kernel_param_ops___334 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___334 *);
	int (*get)(char *, const struct kernel_param___334 *);
	void (*free)(void *);
};

struct kparam_array___334;

struct kernel_param___334 {
	const char *name;
	struct module___336 *mod;
	const struct kernel_param_ops___334 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___334 *arr;
	};
};

struct kparam_array___334 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___334 *ops;
	void *elem;
};

struct module_attribute___334 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___334 *, struct module_kobject___334 *, char *);
	ssize_t (*store)(struct module_attribute___334 *, struct module_kobject___334 *, const char *, size_t);
	void (*setup)(struct module___336 *, const char *);
	int (*test)(struct module___336 *);
	void (*free)(struct module___336 *);
};

struct gnet_dump___45 {
	spinlock_t *lock;
	struct sk_buff___53 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

enum rtnl_link_flags {
	RTNL_FLAG_DOIT_UNLOCKED = 1,
};

struct Qdisc_class_ops___45;

struct Qdisc_ops___45 {
	struct Qdisc_ops___45 *next;
	const struct Qdisc_class_ops___45 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___53 *, struct Qdisc___45 *, struct sk_buff___53 **);
	struct sk_buff___53 * (*dequeue)(struct Qdisc___45 *);
	struct sk_buff___53 * (*peek)(struct Qdisc___45 *);
	int (*init)(struct Qdisc___45 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___45 *);
	void (*destroy)(struct Qdisc___45 *);
	int (*change)(struct Qdisc___45 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___45 *);
	int (*change_tx_queue_len)(struct Qdisc___45 *, unsigned int);
	int (*dump)(struct Qdisc___45 *, struct sk_buff___53 *);
	int (*dump_stats)(struct Qdisc___45 *, struct gnet_dump___45 *);
	void (*ingress_block_set)(struct Qdisc___45 *, u32);
	void (*egress_block_set)(struct Qdisc___45 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___45 *);
	u32 (*egress_block_get)(struct Qdisc___45 *);
	struct module___336 *owner;
};

struct tcf_block___45;

struct Qdisc_class_ops___45 {
	unsigned int flags;
	struct netdev_queue___51 * (*select_queue)(struct Qdisc___45 *, struct tcmsg *);
	int (*graft)(struct Qdisc___45 *, long unsigned int, struct Qdisc___45 *, struct Qdisc___45 **, struct netlink_ext_ack *);
	struct Qdisc___45 * (*leaf)(struct Qdisc___45 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___45 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___45 *, u32);
	int (*change)(struct Qdisc___45 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___45 *, long unsigned int);
	void (*walk)(struct Qdisc___45 *, struct qdisc_walker *);
	struct tcf_block___45 * (*tcf_block)(struct Qdisc___45 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___45 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___45 *, long unsigned int);
	int (*dump)(struct Qdisc___45 *, long unsigned int, struct sk_buff___53 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___45 *, long unsigned int, struct gnet_dump___45 *);
};

struct tcf_chain___45;

struct tcf_block___45 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___63 *net;
	struct Qdisc___45 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___45 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___45;

struct tcf_proto_ops___45;

struct tcf_proto___45 {
	struct tcf_proto___45 *next;
	void *root;
	int (*classify)(struct sk_buff___53 *, const struct tcf_proto___45 *, struct tcf_result___45 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___45 *ops;
	struct tcf_chain___45 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___45 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___45 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___45 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___53 *, const struct tcf_proto___45 *, struct tcf_result___45 *);
	int (*init)(struct tcf_proto___45 *);
	void (*destroy)(struct tcf_proto___45 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___45 *, u32);
	void (*put)(struct tcf_proto___45 *, void *);
	int (*change)(struct net___63 *, struct sk_buff___53 *, struct tcf_proto___45 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___45 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___45 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___45 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___63 *, struct tcf_chain___45 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___63 *, struct tcf_proto___45 *, void *, struct sk_buff___53 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___53 *, struct net___63 *, void *);
	struct module___336 *owner;
	int flags;
};

struct tcf_chain___45 {
	struct mutex filter_chain_lock;
	struct tcf_proto___45 *filter_chain;
	struct list_head list;
	struct tcf_block___45 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___45 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___35 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___45 *prog;
};

struct bpf_redirect_info___45 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___256 *map;
	struct bpf_map___256 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___35;

struct neigh_hash_table___35;

struct neigh_table___35 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___53 *, __u32 *);
	bool (*key_eq)(const struct neighbour___35 *, const void *);
	int (*constructor)(struct neighbour___35 *);
	int (*pconstructor)(struct pneigh_entry___35 *);
	void (*pdestructor)(struct pneigh_entry___35 *);
	void (*proxy_redo)(struct sk_buff___53 *);
	char *id;
	struct neigh_parms___35 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___51 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___35 *nht;
	struct pneigh_entry___35 **phash_buckets;
};

struct neigh_ops___35 {
	int family;
	void (*solicit)(struct neighbour___35 *, struct sk_buff___53 *);
	void (*error_report)(struct neighbour___35 *, struct sk_buff___53 *);
	int (*output)(struct neighbour___35 *, struct sk_buff___53 *);
	int (*connected_output)(struct neighbour___35 *, struct sk_buff___53 *);
};

struct pneigh_entry___35 {
	struct pneigh_entry___35 *next;
	possible_net_t___53 net;
	struct net_device___53 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___35 {
	struct neighbour___35 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___35 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___35 *ctarget;
	struct net___63 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___35 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___35 *rule;
	u32 table;
	int flags;
};

struct proto___35 {
	void (*close)(struct sock___36 *, long int);
	int (*pre_connect)(struct sock___36 *, struct sockaddr *, int);
	int (*connect)(struct sock___36 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___36 *, int);
	struct sock___36 * (*accept)(struct sock___36 *, int, int *, bool);
	int (*ioctl)(struct sock___36 *, int, long unsigned int);
	int (*init)(struct sock___36 *);
	void (*destroy)(struct sock___36 *);
	void (*shutdown)(struct sock___36 *, int);
	int (*setsockopt)(struct sock___36 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___36 *, int, int, char *, int *);
	void (*keepalive)(struct sock___36 *, int);
	int (*sendmsg)(struct sock___36 *, struct msghdr___38 *, size_t);
	int (*recvmsg)(struct sock___36 *, struct msghdr___38 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___36 *, struct page___407 *, int, size_t, int);
	int (*bind)(struct sock___36 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___36 *, struct sk_buff___53 *);
	void (*release_cb)(struct sock___36 *);
	int (*hash)(struct sock___36 *);
	void (*unhash)(struct sock___36 *);
	void (*rehash)(struct sock___36 *);
	int (*get_port)(struct sock___36 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___36 *);
	bool (*stream_memory_read)(const struct sock___36 *);
	void (*enter_memory_pressure)(struct sock___36 *);
	void (*leave_memory_pressure)(struct sock___36 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___3 *rsk_prot;
	struct timewait_sock_ops___3 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___336 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___36 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct rtnl_net_dump_cb {
	struct net___63 *net;
	struct sk_buff___53 *skb;
	struct netlink_callback___53 *cb;
	int idx;
	int s_idx;
};

struct crypto_cipher___6 {
	struct crypto_tfm___22 base;
};

struct tcp_fastopen_context {
	struct crypto_cipher___6 *tfm;
	__u8 key[16];
	struct callback_head rcu;
};

struct module___337;

struct file___407;

struct kiocb___407;

struct iov_iter___174;

struct poll_table_struct___250;

struct vm_area_struct___408;

struct inode___407;

struct file_lock___407;

struct page___408;

struct pipe_inode_info___88;

struct seq_file___346;

struct file_operations___407 {
	struct module___337 *owner;
	loff_t (*llseek)(struct file___407 *, loff_t, int);
	ssize_t (*read)(struct file___407 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___407 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___407 *, struct iov_iter___174 *);
	ssize_t (*write_iter)(struct kiocb___407 *, struct iov_iter___174 *);
	int (*iopoll)(struct kiocb___407 *, bool);
	int (*iterate)(struct file___407 *, struct dir_context *);
	int (*iterate_shared)(struct file___407 *, struct dir_context *);
	__poll_t (*poll)(struct file___407 *, struct poll_table_struct___250 *);
	long int (*unlocked_ioctl)(struct file___407 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___407 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___407 *, struct vm_area_struct___408 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___407 *, struct file___407 *);
	int (*flush)(struct file___407 *, fl_owner_t);
	int (*release)(struct inode___407 *, struct file___407 *);
	int (*fsync)(struct file___407 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___407 *, int);
	int (*lock)(struct file___407 *, int, struct file_lock___407 *);
	ssize_t (*sendpage)(struct file___407 *, struct page___408 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___407 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___407 *, int, struct file_lock___407 *);
	ssize_t (*splice_write)(struct pipe_inode_info___88 *, struct file___407 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___407 *, loff_t *, struct pipe_inode_info___88 *, size_t, unsigned int);
	int (*setlease)(struct file___407 *, long int, struct file_lock___407 **, void **);
	long int (*fallocate)(struct file___407 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___346 *, struct file___407 *);
	ssize_t (*copy_file_range)(struct file___407 *, loff_t, struct file___407 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___407 *, loff_t, struct file___407 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___407 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___408 {
	u64 seqnum;
	struct vm_area_struct___408 *vmas[4];
};

struct page_frag___408 {
	struct page___408 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___408;

struct mem_cgroup___144;

struct cred___375;

struct nsproxy___302;

struct signal_struct___282;

struct bio_list___201;

struct backing_dev_info___201;

struct css_set___256;

struct vm_struct___311;

struct task_struct___409 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___409 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___408 *mm;
	struct mm_struct___408 *active_mm;
	struct vmacache___408 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___409 *real_parent;
	struct task_struct___409 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___409 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___144 *active_memcg;
	long int rh_reserved2;
	struct pid___233 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___233 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___233 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___375 *ptracer_cred;
	const struct cred___375 *real_cred;
	const struct cred___375 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___302 *nsproxy;
	struct signal_struct___282 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___409 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___201 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___201 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___256 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___88 *splice_pipe;
	struct page_frag___408 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___144 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___409 *oom_reaper_list;
	struct vm_struct___311 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___154 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___408 *pgtable_t___408;

struct address_space___407;

struct dev_pagemap___395;

struct page___408 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___407 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___408 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___408 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___408 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___395 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___144 *mem_cgroup;
};

struct pglist_data___408;

struct lruvec___408 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___408 *pgdat;
};

struct zone___408 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___408 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___408 {
	struct zone___408 *zone;
	int zone_idx;
};

struct zonelist___408 {
	struct zoneref___408 _zonerefs[25];
};

struct pglist_data___408 {
	struct zone___408 node_zones[3];
	struct zonelist___408 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___409 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___409 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___408 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___409 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___409 *owner;
};

struct secondary_data___409 {
	void *stack;
	struct task_struct___409 *task;
	long int status;
};

struct blocking_notifier_head___408 {
	struct rw_semaphore___409 rwsem;
	struct notifier_block *head;
};

struct cgroup___256;

struct cgroup_subsys___256;

struct cgroup_subsys_state___256 {
	struct cgroup___256 *cgroup;
	struct cgroup_subsys___256 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___256 *parent;
};

struct kernfs_node___402;

struct cgroup_file___256 {
	struct kernfs_node___402 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___144;

struct mem_cgroup___144 {
	struct cgroup_subsys_state___256 css;
	struct mem_cgroup_id___16 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___256 events_file;
	struct cgroup_file___256 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___409 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___144 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct key___375;

struct ucounts___272;

struct user_namespace___272 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___272 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___29 ns;
	long unsigned int flags;
	struct key___375 *persistent_keyring_register;
	struct rw_semaphore___409 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___272 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct user_struct___375 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___375 *uid_keyring;
	struct key___375 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___395;

struct vm_area_struct___408 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___408 *vm_next;
	struct vm_area_struct___408 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___408 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___395 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___407 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___408;

struct mm_struct___408 {
	struct {
		struct vm_area_struct___408 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___407 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___409 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___408 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___409 *owner;
		struct user_namespace___272 *user_ns;
		struct file___407 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___408 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___375 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___375 *session_keyring;
	struct key___375 *process_keyring;
	struct key___375 *thread_keyring;
	struct key___375 *request_key_auth;
	void *security;
	struct user_struct___375 *user;
	struct user_namespace___272 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___64;

struct cgroup_namespace___256;

struct nsproxy___302 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net___64 *net_ns;
	struct cgroup_namespace___256 *cgroup_ns;
};

struct signal_struct___282 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___409 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___409 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___233 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___233 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___408 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___233 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___201;

struct bio_list___201 {
	struct bio___201 *head;
	struct bio___201 *tail;
};

struct bdi_writeback_congested___201;

struct bdi_writeback___201 {
	struct backing_dev_info___201 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___201 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___256 *memcg_css;
	struct cgroup_subsys_state___256 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___375;

struct dentry___407;

struct backing_dev_info___201 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___201 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___375 *dev;
	struct device___375 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___407 *debug_dir;
	struct dentry___407 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___256 {
	struct cgroup_subsys_state___256 *subsys[13];
	refcount_t refcount;
	struct css_set___256 *dom_cset;
	struct cgroup___256 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___256 *mg_src_cgrp;
	struct cgroup___256 *mg_dst_cgrp;
	struct css_set___256 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___407;

struct pipe_buffer___88;

struct pipe_inode_info___88 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___408 *tmp_page;
	struct fasync_struct___407 *fasync_readers;
	struct fasync_struct___407 *fasync_writers;
	struct pipe_buffer___88 *bufs;
	struct user_struct___375 *user;
};

struct vm_struct___311 {
	struct vm_struct___311 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___408 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___294 {
	struct task_struct___409 task;
	long unsigned int stack[8192];
};

struct address_space_operations___407;

struct address_space___407 {
	struct inode___407 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___409 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___407 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___395)(struct vm_area_struct___408 *, long unsigned int, const struct page___408 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___395)(struct page___408 *, void *);

struct dev_pagemap___395 {
	dev_page_fault_t___395 page_fault;
	dev_page_free_t___395 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___375 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___408 {
	struct vfsmount *mnt;
	struct dentry___407 *dentry;
};

struct file___407 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___408 f_path;
	struct inode___407 *f_inode;
	const struct file_operations___407 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___233 f_owner;
	const struct cred___375 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___407 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___395;

struct vm_operations_struct___395 {
	void (*open)(struct vm_area_struct___408 *);
	void (*close)(struct vm_area_struct___408 *);
	int (*split)(struct vm_area_struct___408 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___408 *);
	vm_fault_t (*fault)(struct vm_fault___395 *);
	vm_fault_t (*huge_fault)(struct vm_fault___395 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___395 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___408 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___395 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___395 *);
	int (*access)(struct vm_area_struct___408 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___408 *);
	int (*set_policy)(struct vm_area_struct___408 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___408 *, long unsigned int);
	struct page___408 * (*find_special_page)(struct vm_area_struct___408 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___408 {
	struct task_struct___409 *task;
	struct core_thread___408 *next;
};

struct core_state___408 {
	atomic_t nr_threads;
	struct core_thread___408 dumper;
	struct completion startup;
};

struct vm_fault___395 {
	struct vm_area_struct___408 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___408 *cow_page;
	struct mem_cgroup___144 *memcg;
	struct page___408 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___408 prealloc_pte;
};

struct kset___394;

struct kobj_type___394;

struct kobject___395 {
	const char *name;
	struct list_head entry;
	struct kobject___395 *parent;
	struct kset___394 *kset;
	struct kobj_type___394 *ktype;
	struct kernfs_node___402 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___335 {
	struct kobject___395 kobj;
	struct module___337 *mod;
	struct kobject___395 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___335 {
	struct module___337 *mod;
	struct latch_tree_node node;
};

struct module_layout___335 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___335 mtn;
};

struct module_attribute___335;

struct kernel_param___335;

struct module___337 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___335 mkobj;
	struct module_attribute___335 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___395 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___335 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___335 core_layout;
	struct module_layout___335 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide53;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide54;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bio_vec___203 {
	struct page___408 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___174 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___203 *bvec;
		struct pipe_inode_info___88 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct msghdr___39 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___174 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___407 *msg_iocb;
};

struct kiocb___407 {
	struct file___407 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___407 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dentry_operations___407;

struct super_block___407;

struct dentry___407 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___407 *d_parent;
	struct qstr d_name;
	struct inode___407 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___407 *d_op;
	struct super_block___407 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___407;

struct block_device___407;

struct inode___407 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___407 *i_op;
	struct super_block___407 *i_sb;
	struct address_space___407 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___409 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___201 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___407 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___407 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___88 *i_pipe;
		struct block_device___407 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___407 {
	int (*d_revalidate)(struct dentry___407 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___407 *, unsigned int);
	int (*d_hash)(const struct dentry___407 *, struct qstr *);
	int (*d_compare)(const struct dentry___407 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___407 *);
	int (*d_init)(struct dentry___407 *);
	void (*d_release)(struct dentry___407 *);
	void (*d_prune)(struct dentry___407 *);
	void (*d_iput)(struct dentry___407 *, struct inode___407 *);
	char * (*d_dname)(struct dentry___407 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___408 *);
	int (*d_manage)(const struct path___408 *, bool);
	struct dentry___407 * (*d_real)(struct dentry___407 *, const struct inode___407 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___407;

struct mem_dqinfo___407 {
	struct quota_format_type___407 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___407;

struct quota_info___407 {
	unsigned int flags;
	struct rw_semaphore___409 dqio_sem;
	struct inode___407 *files[3];
	struct mem_dqinfo___407 info[3];
	const struct quota_format_ops___407 *ops[3];
};

struct rcuwait___407 {
	struct task_struct___409 *task;
};

struct percpu_rw_semaphore___407 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___409 rw_sem;
	struct rcuwait___407 writer;
	int readers_block;
};

struct sb_writers___407 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___407 rw_sem[3];
};

struct shrink_control___144;

struct shrinker___144 {
	long unsigned int (*count_objects)(struct shrinker___144 *, struct shrink_control___144 *);
	long unsigned int (*scan_objects)(struct shrinker___144 *, struct shrink_control___144 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___407;

struct super_operations___407;

struct dquot_operations___407;

struct quotactl_ops___407;

struct super_block___407 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___407 *s_type;
	const struct super_operations___407 *s_op;
	const struct dquot_operations___407 *dq_op;
	const struct quotactl_ops___407 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___407 *s_root;
	struct rw_semaphore___409 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___407 *s_bdev;
	struct backing_dev_info___201 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___407 s_dquot;
	struct sb_writers___407 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___407 *s_d_op;
	int cleancache_poolid;
	struct shrinker___144 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___272 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___144 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___144 *memcg;
};

struct iattr___407 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___407 *ia_file;
};

struct dquot___407 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___407 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___407 {
	int qf_fmt_id;
	const struct quota_format_ops___407 *qf_ops;
	struct module___337 *qf_owner;
	struct quota_format_type___407 *qf_next;
};

struct quota_format_ops___407 {
	int (*check_quota_file)(struct super_block___407 *, int);
	int (*read_file_info)(struct super_block___407 *, int);
	int (*write_file_info)(struct super_block___407 *, int);
	int (*free_file_info)(struct super_block___407 *, int);
	int (*read_dqblk)(struct dquot___407 *);
	int (*commit_dqblk)(struct dquot___407 *);
	int (*release_dqblk)(struct dquot___407 *);
	int (*get_next_id)(struct super_block___407 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___407 {
	int (*write_dquot)(struct dquot___407 *);
	struct dquot___407 * (*alloc_dquot)(struct super_block___407 *, int);
	void (*destroy_dquot)(struct dquot___407 *);
	int (*acquire_dquot)(struct dquot___407 *);
	int (*release_dquot)(struct dquot___407 *);
	int (*mark_dirty)(struct dquot___407 *);
	int (*write_info)(struct super_block___407 *, int);
	qsize_t * (*get_reserved_space)(struct inode___407 *);
	int (*get_projid)(struct inode___407 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___407 *, qsize_t *);
	int (*get_next_id)(struct super_block___407 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___407 {
	int (*quota_on)(struct super_block___407 *, int, int, const struct path___408 *);
	int (*quota_off)(struct super_block___407 *, int);
	int (*quota_enable)(struct super_block___407 *, unsigned int);
	int (*quota_disable)(struct super_block___407 *, unsigned int);
	int (*quota_sync)(struct super_block___407 *, int);
	int (*set_info)(struct super_block___407 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___407 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___407 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___407 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___407 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___407 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___164;

struct address_space_operations___407 {
	int (*writepage)(struct page___408 *, struct writeback_control___164 *);
	int (*readpage)(struct file___407 *, struct page___408 *);
	int (*writepages)(struct address_space___407 *, struct writeback_control___164 *);
	int (*set_page_dirty)(struct page___408 *);
	int (*readpages)(struct file___407 *, struct address_space___407 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___407 *, struct address_space___407 *, loff_t, unsigned int, unsigned int, struct page___408 **, void **);
	int (*write_end)(struct file___407 *, struct address_space___407 *, loff_t, unsigned int, unsigned int, struct page___408 *, void *);
	sector_t (*bmap)(struct address_space___407 *, sector_t);
	void (*invalidatepage)(struct page___408 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___408 *, gfp_t);
	void (*freepage)(struct page___408 *);
	ssize_t (*direct_IO)(struct kiocb___407 *, struct iov_iter___174 *);
	int (*migratepage)(struct address_space___407 *, struct page___408 *, struct page___408 *, enum migrate_mode);
	bool (*isolate_page)(struct page___408 *, isolate_mode_t);
	void (*putback_page)(struct page___408 *);
	int (*launder_page)(struct page___408 *);
	int (*is_partially_uptodate)(struct page___408 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___408 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___407 *, struct page___408 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___407 *, sector_t *);
	void (*swap_deactivate)(struct file___407 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___164 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___201 *wb;
	struct inode___407 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___407 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___407 *bd_inode;
	struct super_block___407 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___407 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___201 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___407 {
	struct dentry___407 * (*lookup)(struct inode___407 *, struct dentry___407 *, unsigned int);
	const char * (*get_link)(struct dentry___407 *, struct inode___407 *, struct delayed_call *);
	int (*permission)(struct inode___407 *, int);
	struct posix_acl * (*get_acl)(struct inode___407 *, int);
	int (*readlink)(struct dentry___407 *, char *, int);
	int (*create)(struct inode___407 *, struct dentry___407 *, umode_t, bool);
	int (*link)(struct dentry___407 *, struct inode___407 *, struct dentry___407 *);
	int (*unlink)(struct inode___407 *, struct dentry___407 *);
	int (*symlink)(struct inode___407 *, struct dentry___407 *, const char *);
	int (*mkdir)(struct inode___407 *, struct dentry___407 *, umode_t);
	int (*rmdir)(struct inode___407 *, struct dentry___407 *);
	int (*mknod)(struct inode___407 *, struct dentry___407 *, umode_t, dev_t);
	int (*rename)(struct inode___407 *, struct dentry___407 *, struct inode___407 *, struct dentry___407 *, unsigned int);
	int (*setattr)(struct dentry___407 *, struct iattr___407 *);
	int (*getattr)(const struct path___408 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___407 *, char *, size_t);
	int (*fiemap)(struct inode___407 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___407 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___407 *, struct dentry___407 *, struct file___407 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___407 *, struct dentry___407 *, umode_t);
	int (*set_acl)(struct inode___407 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___407 {
	void (*fl_copy_lock)(struct file_lock___407 *, struct file_lock___407 *);
	void (*fl_release_private)(struct file_lock___407 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___407;

struct file_lock___407 {
	struct file_lock___407 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___407 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___407 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___407 *fl_ops;
	const struct lock_manager_operations___407 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___407 {
	int (*lm_compare_owner)(struct file_lock___407 *, struct file_lock___407 *);
	long unsigned int (*lm_owner_key)(struct file_lock___407 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___407 *);
	int (*lm_grant)(struct file_lock___407 *, int);
	bool (*lm_break)(struct file_lock___407 *);
	int (*lm_change)(struct file_lock___407 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___407 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___407 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___407 *fa_next;
	struct file___407 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___407 {
	const char *name;
	int fs_flags;
	struct dentry___407 * (*mount)(struct file_system_type___407 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___407 *);
	struct module___337 *owner;
	struct file_system_type___407 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___407 {
	struct inode___407 * (*alloc_inode)(struct super_block___407 *);
	void (*destroy_inode)(struct inode___407 *);
	void (*dirty_inode)(struct inode___407 *, int);
	int (*write_inode)(struct inode___407 *, struct writeback_control___164 *);
	int (*drop_inode)(struct inode___407 *);
	void (*evict_inode)(struct inode___407 *);
	void (*put_super)(struct super_block___407 *);
	int (*sync_fs)(struct super_block___407 *, int);
	int (*freeze_super)(struct super_block___407 *);
	int (*freeze_fs)(struct super_block___407 *);
	int (*thaw_super)(struct super_block___407 *);
	int (*unfreeze_fs)(struct super_block___407 *);
	int (*statfs)(struct dentry___407 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___407 *, int *, char *);
	void (*umount_begin)(struct super_block___407 *);
	int (*show_options)(struct seq_file___346 *, struct dentry___407 *);
	int (*show_devname)(struct seq_file___346 *, struct dentry___407 *);
	int (*show_path)(struct seq_file___346 *, struct dentry___407 *);
	int (*show_stats)(struct seq_file___346 *, struct dentry___407 *);
	ssize_t (*quota_read)(struct super_block___407 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___407 *, int, const char *, size_t, loff_t);
	struct dquot___407 ** (*get_dquots)(struct inode___407 *);
	int (*bdev_try_to_free_page)(struct super_block___407 *, struct page___408 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___407 *, struct shrink_control___144 *);
	long int (*free_cached_objects)(struct super_block___407 *, struct shrink_control___144 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___260)(struct file___407 *, wait_queue_head_t *, struct poll_table_struct___250 *);

struct poll_table_struct___250 {
	poll_queue_proc___260 _qproc;
	__poll_t _key;
};

struct seq_operations___346;

struct seq_file___346 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___346 *op;
	int poll_event;
	const struct file___407 *file;
	void *private;
};

typedef void bio_end_io_t___201(struct bio___201 *);

struct bio_integrity_payload___201;

struct bio_set___201;

struct bio___201 {
	struct bio___201 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___201 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___201 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___203 *bi_io_vec;
	struct bio_set___201 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___203 bi_inline_vecs[0];
};

struct socket_wq___37 {
	wait_queue_head_t wait;
	struct fasync_struct___407 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct sock___37;

struct proto_ops___37;

struct socket___38 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___37 *wq;
	struct file___407 *file;
	struct sock___37 *sk;
	const struct proto_ops___37 *ops;
};

typedef struct {
	struct net___64 *net;
} possible_net_t___54;

struct proto___36;

struct sock_common___36 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___36 *skc_prot;
	possible_net_t___54 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___37 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___54;

struct sk_buff_head___52 {
	struct sk_buff___54 *next;
	struct sk_buff___54 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___36;

struct dst_entry___36;

struct sock___37 {
	struct sock_common___36 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___52 sk_error_queue;
	struct sk_buff_head___52 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___54 *head;
		struct sk_buff___54 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___36 *sk_filter;
	union {
		struct socket_wq___37 *sk_wq;
		struct socket_wq___37 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___36 *sk_rx_dst;
	struct dst_entry___36 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___54 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___52 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___408 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___36 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___233 *sk_peer_pid;
	const struct cred___375 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___38 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___144 *sk_memcg;
	void (*sk_state_change)(struct sock___37 *);
	void (*sk_data_ready)(struct sock___37 *);
	void (*sk_write_space)(struct sock___37 *);
	void (*sk_error_report)(struct sock___37 *);
	int (*sk_backlog_rcv)(struct sock___37 *, struct sk_buff___54 *);
	struct sk_buff___54 * (*sk_validate_xmit_skb)(struct sock___37 *, struct net_device___3 *, struct sk_buff___54 *);
	void (*sk_destruct)(struct sock___37 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

typedef int (*sk_read_actor_t___36)(read_descriptor_t *, struct sk_buff___54 *, unsigned int, size_t);

struct proto_ops___37 {
	int family;
	struct module___337 *owner;
	int (*release)(struct socket___38 *);
	int (*bind)(struct socket___38 *, struct sockaddr *, int);
	int (*connect)(struct socket___38 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___38 *, struct socket___38 *);
	int (*accept)(struct socket___38 *, struct socket___38 *, int, bool);
	int (*getname)(struct socket___38 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___407 *, struct socket___38 *, struct poll_table_struct___250 *);
	int (*ioctl)(struct socket___38 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___38 *, int);
	int (*shutdown)(struct socket___38 *, int);
	int (*setsockopt)(struct socket___38 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___38 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___38 *, struct msghdr___39 *, size_t);
	int (*recvmsg)(struct socket___38 *, struct msghdr___39 *, size_t, int);
	int (*mmap)(struct file___407 *, struct socket___38 *, struct vm_area_struct___408 *);
	ssize_t (*sendpage)(struct socket___38 *, struct page___408 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___38 *, loff_t *, struct pipe_inode_info___88 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___37 *, int);
	int (*peek_len)(struct socket___38 *);
	int (*read_sock)(struct sock___37 *, read_descriptor_t *, sk_read_actor_t___36);
	int (*sendpage_locked)(struct sock___37 *, struct page___408 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___37 *, struct msghdr___39 *, size_t);
	int (*set_rcvlowat)(struct sock___37 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct nf_bridge_info___52;

struct sk_buff___54 {
	union {
		struct {
			struct sk_buff___54 *next;
			struct sk_buff___54 *prev;
			union {
				struct net_device___3 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___37 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___54 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___52 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___52;

struct netns_frags___52 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___52 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ip_ra_chain___16;

struct fib_rules_ops___36;

struct fib_notifier_ops___36;

struct netns_ipv4___52 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___16 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___36 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___37 *fibnl;
	struct sock___37 **icmp_sk;
	struct sock___37 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___37 **tcp_sk;
	struct netns_frags___52 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___36 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___36 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___36 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___36;

struct dst_ops___63 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___63 *);
	struct dst_entry___36 * (*check)(struct dst_entry___36 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___36 *);
	unsigned int (*mtu)(const struct dst_entry___36 *);
	u32 * (*cow_metrics)(struct dst_entry___36 *, long unsigned int);
	void (*destroy)(struct dst_entry___36 *);
	void (*ifdown)(struct dst_entry___36 *, struct net_device___3 *, int);
	struct dst_entry___36 * (*negative_advice)(struct dst_entry___36 *);
	void (*link_failure)(struct sk_buff___54 *);
	void (*update_pmtu)(struct dst_entry___36 *, struct sock___37 *, struct sk_buff___54 *, u32);
	void (*redirect)(struct dst_entry___36 *, struct sock___37 *, struct sk_buff___54 *);
	int (*local_out)(struct net___64 *, struct sock___37 *, struct sk_buff___54 *);
	struct neighbour___36 * (*neigh_lookup)(const struct dst_entry___36 *, struct sk_buff___54 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___36 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_info___4;

struct rt6_info___4;

struct fib6_table___4;

struct netns_ipv6___63 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___52 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info___4 *fib6_null_entry;
	struct rt6_info___4 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___4 *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___63 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info___4 *ip6_prohibit_entry;
	struct rt6_info___4 *ip6_blk_hole_entry;
	struct fib6_table___4 *fib6_local_tbl;
	struct fib_rules_ops___36 *fib6_rules_ops;
	struct sock___37 **icmp_sk;
	struct sock___37 *ndisc_sk;
	struct sock___37 *tcp_sk;
	struct sock___37 *igmp_sk;
	struct sock___37 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___36 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___36 *notifier_ops;
	struct fib_notifier_ops___36 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___37 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___37 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___52 {
	struct netns_frags___52 frags;
};

struct netns_xfrm___63 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___37 *nlsk;
	struct sock___37 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___63 xfrm4_dst_ops;
	struct dst_ops___63 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___46;

struct net___64 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___272 *user_ns;
	struct ucounts___272 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___29 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___37 *rtnl;
	struct sock___37 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___3 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___52 ipv4;
	struct netns_ipv6___63 ipv6;
	struct netns_sctp___37 sctp;
	struct netns_nf___3 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___52 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___37 *nfnl;
	struct sock___37 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___63 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___37 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___46 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kernfs_root___401;

struct kernfs_elem_dir___401 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___401 *root;
};

struct kernfs_syscall_ops___401;

struct kernfs_root___401 {
	struct kernfs_node___402 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___401 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___401 {
	struct kernfs_node___402 *target_kn;
};

struct kernfs_ops___401;

struct kernfs_elem_attr___401 {
	const struct kernfs_ops___401 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___402 *notify_next;
};

struct kernfs_node___402 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___402 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___401 dir;
		struct kernfs_elem_symlink___401 symlink;
		struct kernfs_elem_attr___401 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___401;

struct kernfs_ops___401 {
	int (*open)(struct kernfs_open_file___401 *);
	void (*release)(struct kernfs_open_file___401 *);
	int (*seq_show)(struct seq_file___346 *, void *);
	void * (*seq_start)(struct seq_file___346 *, loff_t *);
	void * (*seq_next)(struct seq_file___346 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___346 *, void *);
	ssize_t (*read)(struct kernfs_open_file___401 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___401 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___401 *, struct vm_area_struct___408 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___401 *, struct poll_table_struct___250 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___401 {
	int (*remount_fs)(struct kernfs_root___401 *, int *, char *);
	int (*show_options)(struct seq_file___346 *, struct kernfs_root___401 *);
	int (*mkdir)(struct kernfs_node___402 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___402 *);
	int (*rename)(struct kernfs_node___402 *, struct kernfs_node___402 *, const char *);
	int (*show_path)(struct seq_file___346 *, struct kernfs_node___402 *, struct kernfs_root___401 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___401 {
	struct kernfs_node___402 *kn;
	struct file___407 *file;
	struct seq_file___346 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___395 *vm_ops;
};

struct kobj_ns_type_operations___36 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___37 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___371;

struct attribute_group___372 {
	const char *name;
	umode_t (*is_visible)(struct kobject___395 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___395 *, struct bin_attribute___371 *, int);
	struct attribute **attrs;
	struct bin_attribute___371 **bin_attrs;
};

struct bin_attribute___371 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___407 *, struct kobject___395 *, struct bin_attribute___371 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___407 *, struct kobject___395 *, struct bin_attribute___371 *, char *, loff_t, size_t);
	int (*mmap)(struct file___407 *, struct kobject___395 *, struct bin_attribute___371 *, struct vm_area_struct___408 *);
};

struct sysfs_ops___394 {
	ssize_t (*show)(struct kobject___395 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___395 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___394;

struct kset___394 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___395 kobj;
	const struct kset_uevent_ops___394 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___394 {
	void (*release)(struct kobject___395 *);
	const struct sysfs_ops___394 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___36 * (*child_ns_type)(struct kobject___395 *);
	const void * (*namespace)(struct kobject___395 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___394 {
	int (* const filter)(struct kset___394 *, struct kobject___395 *);
	const char * (* const name)(struct kset___394 *, struct kobject___395 *);
	int (* const uevent)(struct kset___394 *, struct kobject___395 *, struct kobj_uevent_env *);
};

struct kobj_attribute___385 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___395 *, struct kobj_attribute___385 *, char *);
	ssize_t (*store)(struct kobject___395 *, struct kobj_attribute___385 *, const char *, size_t);
};

struct dev_pm_ops___375 {
	int (*prepare)(struct device___375 *);
	void (*complete)(struct device___375 *);
	int (*suspend)(struct device___375 *);
	int (*resume)(struct device___375 *);
	int (*freeze)(struct device___375 *);
	int (*thaw)(struct device___375 *);
	int (*poweroff)(struct device___375 *);
	int (*restore)(struct device___375 *);
	int (*suspend_late)(struct device___375 *);
	int (*resume_early)(struct device___375 *);
	int (*freeze_late)(struct device___375 *);
	int (*thaw_early)(struct device___375 *);
	int (*poweroff_late)(struct device___375 *);
	int (*restore_early)(struct device___375 *);
	int (*suspend_noirq)(struct device___375 *);
	int (*resume_noirq)(struct device___375 *);
	int (*freeze_noirq)(struct device___375 *);
	int (*thaw_noirq)(struct device___375 *);
	int (*poweroff_noirq)(struct device___375 *);
	int (*restore_noirq)(struct device___375 *);
	int (*runtime_suspend)(struct device___375 *);
	int (*runtime_resume)(struct device___375 *);
	int (*runtime_idle)(struct device___375 *);
};

struct dev_pm_info___375 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___375 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___375;

struct bus_type___375;

struct device_driver___375;

struct dev_pm_domain___375;

struct dma_map_ops___147;

struct device_node___99;

struct fwnode_handle___295;

struct class___375;

struct device___375 {
	struct device___375 *parent;
	struct device_private *p;
	struct kobject___395 kobj;
	const char *init_name;
	const struct device_type___375 *type;
	struct mutex mutex;
	struct bus_type___375 *bus;
	struct device_driver___375 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___375 power;
	struct dev_pm_domain___375 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___147 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___99 *of_node;
	struct fwnode_handle___295 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___375 *class;
	const struct attribute_group___372 **groups;
	void (*release)(struct device___375 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___375 {
	struct dev_pm_ops___375 ops;
	void (*detach)(struct device___375 *, bool);
	int (*activate)(struct device___375 *);
	void (*sync)(struct device___375 *);
	void (*dismiss)(struct device___375 *);
};

struct bus_type___375 {
	const char *name;
	const char *dev_name;
	struct device___375 *dev_root;
	const struct attribute_group___372 **bus_groups;
	const struct attribute_group___372 **dev_groups;
	const struct attribute_group___372 **drv_groups;
	int (*match)(struct device___375 *, struct device_driver___375 *);
	int (*uevent)(struct device___375 *, struct kobj_uevent_env *);
	int (*probe)(struct device___375 *);
	int (*remove)(struct device___375 *);
	void (*shutdown)(struct device___375 *);
	int (*online)(struct device___375 *);
	int (*offline)(struct device___375 *);
	int (*suspend)(struct device___375 *, pm_message_t);
	int (*resume)(struct device___375 *);
	int (*num_vf)(struct device___375 *);
	int (*dma_configure)(struct device___375 *);
	const struct dev_pm_ops___375 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___375 {
	const char *name;
	struct bus_type___375 *bus;
	struct module___337 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___375 *);
	int (*remove)(struct device___375 *);
	void (*shutdown)(struct device___375 *);
	int (*suspend)(struct device___375 *, pm_message_t);
	int (*resume)(struct device___375 *);
	const struct attribute_group___372 **groups;
	const struct dev_pm_ops___375 *pm;
	void (*coredump)(struct device___375 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___375 {
	const char *name;
	const struct attribute_group___372 **groups;
	int (*uevent)(struct device___375 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___375 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___375 *);
	const struct dev_pm_ops___375 *pm;
};

struct class___375 {
	const char *name;
	struct module___337 *owner;
	const struct attribute_group___372 **class_groups;
	const struct attribute_group___372 **dev_groups;
	struct kobject___395 *dev_kobj;
	int (*dev_uevent)(struct device___375 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___375 *, umode_t *);
	void (*class_release)(struct class___375 *);
	void (*dev_release)(struct device___375 *);
	int (*shutdown_pre)(struct device___375 *);
	const struct kobj_ns_type_operations___36 *ns_type;
	const void * (*namespace)(struct device___375 *);
	const struct dev_pm_ops___375 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___147 {
	void * (*alloc)(struct device___375 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___375 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___375 *, struct vm_area_struct___408 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___375 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___375 *, struct page___408 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___375 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___375 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___375 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___375 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___375 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___375 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___375 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___375 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___375 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___375 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___375 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___375 *, u64);
	u64 (*get_required_mask)(struct device___375 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___295;

struct fwnode_handle___295 {
	struct fwnode_handle___295 *secondary;
	const struct fwnode_operations___295 *ops;
};

struct property___95;

struct device_node___99 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___295 fwnode;
	struct property___95 *properties;
	struct property___95 *deadprops;
	struct device_node___99 *parent;
	struct device_node___99 *child;
	struct device_node___99 *sibling;
	struct kobject___395 kobj;
	long unsigned int _flags;
	void *data;
};

typedef void compound_page_dtor___395(struct page___408 *);

struct fwnode_reference_args___295;

struct fwnode_endpoint___295;

struct fwnode_operations___295 {
	struct fwnode_handle___295 * (*get)(struct fwnode_handle___295 *);
	void (*put)(struct fwnode_handle___295 *);
	bool (*device_is_available)(const struct fwnode_handle___295 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___295 *, const struct device___375 *);
	bool (*property_present)(const struct fwnode_handle___295 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___295 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___295 *, const char *, const char **, size_t);
	struct fwnode_handle___295 * (*get_parent)(const struct fwnode_handle___295 *);
	struct fwnode_handle___295 * (*get_next_child_node)(const struct fwnode_handle___295 *, struct fwnode_handle___295 *);
	struct fwnode_handle___295 * (*get_named_child_node)(const struct fwnode_handle___295 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___295 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___295 *);
	struct fwnode_handle___295 * (*graph_get_next_endpoint)(const struct fwnode_handle___295 *, struct fwnode_handle___295 *);
	struct fwnode_handle___295 * (*graph_get_remote_endpoint)(const struct fwnode_handle___295 *);
	struct fwnode_handle___295 * (*graph_get_port_parent)(struct fwnode_handle___295 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___295 *, struct fwnode_endpoint___295 *);
};

struct fwnode_endpoint___295 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___295 *local_fwnode;
};

struct fwnode_reference_args___295 {
	struct fwnode_handle___295 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct flow_dissector_key_control {
	u16 thoff;
	u16 addr_type;
	u32 flags;
};

enum flow_dissect_ret {
	FLOW_DISSECT_RET_OUT_GOOD = 0,
	FLOW_DISSECT_RET_OUT_BAD = 1,
	FLOW_DISSECT_RET_PROTO_AGAIN = 2,
	FLOW_DISSECT_RET_IPPROTO_AGAIN = 3,
	FLOW_DISSECT_RET_CONTINUE = 4,
};

struct flow_dissector_key_basic {
	__be16 n_proto;
	u8 ip_proto;
	u8 padding;
};

struct flow_dissector_key_tags {
	u32 flow_label;
};

struct flow_dissector_key_vlan {
	u16 vlan_id: 12;
	u16 vlan_priority: 3;
	__be16 vlan_tpid;
};

struct flow_dissector_key_mpls {
	u32 mpls_ttl: 8;
	u32 mpls_bos: 1;
	u32 mpls_tc: 3;
	u32 mpls_label: 20;
};

struct flow_dissector_key_enc_opts {
	u8 data[255];
	u8 len;
	__be16 dst_opt_type;
};

struct flow_dissector_key_keyid {
	__be32 keyid;
};

struct flow_dissector_key_ipv4_addrs {
	__be32 src;
	__be32 dst;
};

struct flow_dissector_key_ipv6_addrs {
	struct in6_addr src;
	struct in6_addr dst;
};

struct flow_dissector_key_tipc {
	__be32 key;
};

struct flow_dissector_key_addrs {
	union {
		struct flow_dissector_key_ipv4_addrs v4addrs;
		struct flow_dissector_key_ipv6_addrs v6addrs;
		struct flow_dissector_key_tipc tipckey;
	};
};

struct flow_dissector_key_arp {
	__u32 sip;
	__u32 tip;
	__u8 op;
	unsigned char sha[6];
	unsigned char tha[6];
};

struct flow_dissector_key_ports {
	union {
		__be32 ports;
		struct {
			__be16 src;
			__be16 dst;
		};
	};
};

struct flow_dissector_key_icmp {
	union {
		__be16 icmp;
		struct {
			u8 type;
			u8 code;
		};
	};
};

struct flow_dissector_key_eth_addrs {
	unsigned char dst[6];
	unsigned char src[6];
};

struct flow_dissector_key_tcp {
	__be16 flags;
};

struct flow_dissector_key_ip {
	__u8 tos;
	__u8 ttl;
};

struct flow_dissector_key {
	enum flow_dissector_key_id key_id;
	size_t offset;
};

struct flow_keys_basic {
	struct flow_dissector_key_control control;
	struct flow_dissector_key_basic basic;
};

struct flow_keys {
	struct flow_dissector_key_control control;
	struct flow_dissector_key_basic basic;
	struct flow_dissector_key_tags tags;
	struct flow_dissector_key_vlan vlan;
	struct flow_dissector_key_vlan cvlan;
	struct flow_dissector_key_keyid keyid;
	struct flow_dissector_key_ports ports;
	struct flow_dissector_key_addrs addrs;
};

struct flow_keys_digest {
	u8 data[16];
};

struct pipe_buf_operations___88;

struct pipe_buffer___88 {
	struct page___408 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___88 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___88 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___88 *, struct pipe_buffer___88 *);
	void (*release)(struct pipe_inode_info___88 *, struct pipe_buffer___88 *);
	int (*steal)(struct pipe_inode_info___88 *, struct pipe_buffer___88 *);
	union {
		bool (*get)(struct pipe_inode_info___88 *, struct pipe_buffer___88 *);
		struct {
			void (*get)(struct pipe_inode_info___88 *, struct pipe_buffer___88 *);
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
};

struct nf_bridge_info___52 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___52 = 0,
		BRNF_PROTO_8021Q___52 = 1,
		BRNF_PROTO_PPPOE___52 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___3 *physindev;
	struct net_device___3 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___52(struct sk_buff___54 **);

struct net_device_ops___52;

struct ethtool_ops___52;

struct l3mdev_ops___36;

struct ndisc_ops___19;

struct xfrmdev_ops___52;

struct tlsdev_ops___52;

struct header_ops___52;

struct inet6_dev___19;

struct netdev_rx_queue___52;

struct mini_Qdisc___46;

struct netdev_queue___52;

struct Qdisc___46;

struct rtnl_link_ops___46;

struct dcbnl_rtnl_ops___52;

struct phy_device___8;

struct net_device___3 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___52 *netdev_ops;
	const struct ethtool_ops___52 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___36 *l3mdev_ops;
	const struct ndisc_ops___19 *ndisc_ops;
	const struct xfrmdev_ops___52 *xfrmdev_ops;
	const struct tlsdev_ops___52 *tlsdev_ops;
	const struct header_ops___52 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___394 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___19 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___52 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___46 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___52 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___46 *miniq_ingress;
	struct netdev_queue___52 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___52 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___46 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___46 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___52 = 0,
		NETREG_REGISTERED___52 = 1,
		NETREG_UNREGISTERING___52 = 2,
		NETREG_UNREGISTERED___52 = 3,
		NETREG_RELEASED___52 = 4,
		NETREG_DUMMY___52 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___52 = 0,
		RTNL_LINK_INITIALIZING___52 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___3 *);
	struct netpoll_info *npinfo;
	possible_net_t___54 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___375 dev;
	const struct attribute_group___372 *sysfs_groups[4];
	const struct attribute_group___372 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___46 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___52 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device___8 *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct skb_frag_struct___6 {
	struct {
		struct page___408 *p;
	} page;
	__u32 page_offset;
	__u32 size;
};

typedef struct skb_frag_struct___6 skb_frag_t___6;

struct skb_shared_info___6 {
	__u8 __unused;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___54 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___6 frags[16];
};

struct ethtool_ops___52 {
	int (*get_settings)(struct net_device___3 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___3 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___3 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___3 *);
	void (*get_regs)(struct net_device___3 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___3 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___3 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___3 *);
	void (*set_msglevel)(struct net_device___3 *, u32);
	int (*nway_reset)(struct net_device___3 *);
	u32 (*get_link)(struct net_device___3 *);
	int (*get_eeprom_len)(struct net_device___3 *);
	int (*get_eeprom)(struct net_device___3 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___3 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___3 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___3 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___3 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___3 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___3 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___3 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___3 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___3 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___3 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___3 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___3 *);
	void (*complete)(struct net_device___3 *);
	u32 (*get_priv_flags)(struct net_device___3 *);
	int (*set_priv_flags)(struct net_device___3 *, u32);
	int (*get_sset_count)(struct net_device___3 *, int);
	int (*get_rxnfc)(struct net_device___3 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___3 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___3 *, struct ethtool_flash *);
	int (*reset)(struct net_device___3 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___3 *);
	u32 (*get_rxfh_indir_size)(struct net_device___3 *);
	int (*get_rxfh)(struct net_device___3 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___3 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___3 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___3 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___3 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___3 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___3 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___3 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___3 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___3 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___3 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___3 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___3 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___3 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___3 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___3 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___3 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___3 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___3 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___3 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___3 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___3 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	int (*get_fecparam)(struct net_device___3 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___3 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___3 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___3 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___3 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___52;

struct inet_frags___52 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___52 *, const void *);
	void (*destructor)(struct inet_frag_queue___52 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___52 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___54 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___54 *fragments_tail;
	struct sk_buff___54 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___52 *net;
	struct callback_head rcu;
};

struct ip_ra_chain___16 {
	struct ip_ra_chain___16 *next;
	struct sock___37 *sk;
	union {
		void (*destructor)(struct sock___37 *);
		struct sock___37 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___36;

struct fib_lookup_arg___36;

struct fib_rules_ops___36 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___36 *, struct flowi *, int, struct fib_lookup_arg___36 *);
	bool (*suppress)(struct fib_rule___36 *, struct fib_lookup_arg___36 *);
	int (*match)(struct fib_rule___36 *, struct flowi *, int);
	int (*configure)(struct fib_rule___36 *, struct sk_buff___54 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___36 *);
	int (*compare)(struct fib_rule___36 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___36 *, struct sk_buff___54 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___36 *);
	void (*flush_cache)(struct fib_rules_ops___36 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___337 *owner;
	struct net___64 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___36 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___64 *);
	int (*fib_dump)(struct net___64 *, struct notifier_block *);
	struct module___337 *owner;
	struct callback_head rcu;
};

struct dst_entry___36 {
	struct net_device___3 *dev;
	struct dst_ops___63 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___54 *);
	int (*output)(struct net___64 *, struct sock___37 *, struct sk_buff___54 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___36;

struct neigh_parms___36;

struct neigh_ops___36;

struct neighbour___36 {
	struct neighbour___36 *next;
	struct neigh_table___36 *tbl;
	struct neigh_parms___36 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___52 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___36 *, struct sk_buff___54 *);
	const struct neigh_ops___36 *ops;
	struct callback_head rcu;
	struct net_device___3 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct fib6_nh___4 {
	struct in6_addr nh_gw;
	struct net_device___3 *nh_dev;
	struct lwtunnel_state *nh_lwtstate;
	unsigned int nh_flags;
	atomic_t nh_upper_bound;
	int nh_weight;
};

struct fib6_node___4;

struct fib6_info___4 {
	struct fib6_table___4 *fib6_table;
	struct fib6_info___4 *fib6_next;
	struct fib6_node___4 *fib6_node;
	struct list_head fib6_siblings;
	unsigned int fib6_nsiblings;
	atomic_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	struct rt6_info___4 **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
	long unsigned int last_probe;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 exception_bucket_flushed: 1;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 dst_host: 1;
	u8 fib6_destroying: 1;
	u8 unused: 2;
	struct fib6_nh___4 fib6_nh;
	struct callback_head rcu;
};

struct rt6_info___4 {
	struct dst_entry___36 dst;
	struct fib6_info___4 *from;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___19 *rt6i_idev;
	u32 rt6i_flags;
	struct rt6key rt6i_prefsrc;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct fib6_node___4 {
	struct fib6_node___4 *parent;
	struct fib6_node___4 *left;
	struct fib6_node___4 *right;
	struct fib6_info___4 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info___4 *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table___4 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node___4 tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

struct ucounts___272 {
	struct hlist_node node;
	struct user_namespace___272 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_prog_aux___49;

struct bpf_prog___46 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___49 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

typedef int (*key_restrict_link_func_t___376)(struct key___375 *, const struct key_type *, const union key_payload *, struct key___375 *);

struct key_restriction___375;

struct key___375 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___409 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___375 *restrict_link;
};

struct key_restriction___375 {
	key_restrict_link_func_t___376 check;
	struct key___375 *key;
	struct key_type *keytype;
};

struct seq_operations___346 {
	void * (*start)(struct seq_file___346 *, loff_t *);
	void (*stop)(struct seq_file___346 *, void *);
	void * (*next)(struct seq_file___346 *, void *, loff_t *);
	int (*show)(struct seq_file___346 *, void *);
};

struct pernet_operations___53 {
	struct list_head list;
	int (*init)(struct net___64 *);
	void (*exit)(struct net___64 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___52 {
	int (*ieee_getets)(struct net_device___3 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___3 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___3 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___3 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___3 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___3 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___3 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___3 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___3 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___3 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___3 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___3 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___3 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___3 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___3 *);
	u8 (*setstate)(struct net_device___3 *, u8);
	void (*getpermhwaddr)(struct net_device___3 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___3 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___3 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___3 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___3 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___3 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___3 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___3 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___3 *, int, u8 *);
	void (*setpfccfg)(struct net_device___3 *, int, u8);
	void (*getpfccfg)(struct net_device___3 *, int, u8 *);
	u8 (*setall)(struct net_device___3 *);
	u8 (*getcap)(struct net_device___3 *, int, u8 *);
	int (*getnumtcs)(struct net_device___3 *, int, u8 *);
	int (*setnumtcs)(struct net_device___3 *, int, u8);
	u8 (*getpfcstate)(struct net_device___3 *);
	void (*setpfcstate)(struct net_device___3 *, u8);
	void (*getbcncfg)(struct net_device___3 *, int, u32 *);
	void (*setbcncfg)(struct net_device___3 *, int, u32);
	void (*getbcnrp)(struct net_device___3 *, int, u8 *);
	void (*setbcnrp)(struct net_device___3 *, int, u8);
	int (*setapp)(struct net_device___3 *, u8, u16, u8);
	int (*getapp)(struct net_device___3 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___3 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___3 *, int, u8);
	u8 (*getdcbx)(struct net_device___3 *);
	u8 (*setdcbx)(struct net_device___3 *, u8);
	int (*peer_getappinfo)(struct net_device___3 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___3 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___3 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___3 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___3 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___3 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___256 {
	refcount_t count;
	struct ns_common___29 ns;
	struct user_namespace___272 *user_ns;
	struct ucounts___272 *ucounts;
	struct css_set___256 *root_cset;
};

enum bpf_ret_code {
	BPF_OK = 0,
	BPF_DROP = 2,
	BPF_REDIRECT = 7,
};

struct bpf_map___257;

struct bpf_map_ops___256 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___257 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___257 *, struct file___407 *);
	void (*map_free)(struct bpf_map___257 *);
	int (*map_get_next_key)(struct bpf_map___257 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___257 *);
	void * (*map_lookup_elem)(struct bpf_map___257 *, void *);
	int (*map_update_elem)(struct bpf_map___257 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___257 *, void *);
	int (*map_push_elem)(struct bpf_map___257 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___257 *, void *);
	int (*map_peek_elem)(struct bpf_map___257 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___257 *, struct file___407 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___257 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___257 *, void *, struct seq_file___346 *);
	int (*map_check_btf)(const struct bpf_map___257 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___257 {
	const struct bpf_map_ops___256 *ops;
	struct bpf_map___257 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___375 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___52;

struct bpf_map_dev_ops___52 {
	int (*map_get_next_key)(struct bpf_offloaded_map___52 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___52 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___52 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___52 *, void *);
};

struct bpf_offloaded_map___52 {
	struct bpf_map___257 map;
	struct net_device___3 *netdev;
	const struct bpf_map_dev_ops___52 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___46 {
	int (*test_run)(struct bpf_prog___46 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___46 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___46 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___46 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___46 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___46 *, u32 *);
};

struct bpf_prog_offload_ops___46 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___46 *);
	int (*translate)(struct bpf_prog___46 *);
	void (*destroy)(struct bpf_prog___46 *);
};

struct bpf_prog_offload___46 {
	struct bpf_prog___46 *prog;
	struct net_device___3 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___46 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___49 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___46 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___46 *ops;
	struct bpf_map___257 **used_maps;
	struct bpf_prog___46 *prog;
	struct user_struct___375 *user;
	u64 load_time;
	struct bpf_map___257 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___46 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___46 {
	struct bpf_prog___46 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___46 {
	struct callback_head rcu;
	struct bpf_prog_array_item___46 items[0];
};

struct cgroup_bpf___46 {
	struct bpf_prog_array___46 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___46 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___257;

typedef void (*kthread_work_func_t___257)(struct kthread_work___257 *);

struct kthread_worker___257;

struct kthread_work___257 {
	struct list_head node;
	kthread_work_func_t___257 func;
	struct kthread_worker___257 *worker;
	int canceling;
};

struct kthread_worker___257 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___409 *task;
	struct kthread_work___257 *current_work;
};

struct kthread_delayed_work___256 {
	struct kthread_work___257 work;
	struct timer_list timer;
};

struct psi_group___256 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___257 *poll_kworker;
	struct kthread_delayed_work___256 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___256;

struct cgroup_rstat_cpu___256;

struct cgroup___256 {
	struct cgroup_subsys_state___256 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___402 *kn;
	struct cgroup_file___256 procs_file;
	struct cgroup_file___256 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___256 *subsys[13];
	struct cgroup_root___256 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___256 *dom_cgrp;
	struct cgroup_rstat_cpu___256 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___46 bpf;
	atomic_t congestion_count;
	struct cgroup___256 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___256 psi;
	int ancestor_ids[0];
};

struct cftype___256;

struct cgroup_subsys___256 {
	struct cgroup_subsys_state___256 * (*css_alloc)(struct cgroup_subsys_state___256 *);
	int (*css_online)(struct cgroup_subsys_state___256 *);
	void (*css_offline)(struct cgroup_subsys_state___256 *);
	void (*css_released)(struct cgroup_subsys_state___256 *);
	void (*css_free)(struct cgroup_subsys_state___256 *);
	void (*css_reset)(struct cgroup_subsys_state___256 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___256 *, int);
	int (*css_extra_stat_show)(struct seq_file___346 *, struct cgroup_subsys_state___256 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___409 *);
	void (*cancel_fork)(struct task_struct___409 *);
	void (*fork)(struct task_struct___409 *);
	void (*exit)(struct task_struct___409 *);
	void (*free)(struct task_struct___409 *);
	void (*bind)(struct cgroup_subsys_state___256 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___256 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___256 *dfl_cftypes;
	struct cftype___256 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___256 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___256 *updated_children;
	struct cgroup___256 *updated_next;
};

struct cgroup_root___256 {
	struct kernfs_root___401 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___256 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___256 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___256 *ss;
	struct list_head node;
	struct kernfs_ops___401 *kf_ops;
	int (*open)(struct kernfs_open_file___401 *);
	void (*release)(struct kernfs_open_file___401 *);
	u64 (*read_u64)(struct cgroup_subsys_state___256 *, struct cftype___256 *);
	s64 (*read_s64)(struct cgroup_subsys_state___256 *, struct cftype___256 *);
	int (*seq_show)(struct seq_file___346 *, void *);
	void * (*seq_start)(struct seq_file___346 *, loff_t *);
	void * (*seq_next)(struct seq_file___346 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___346 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___256 *, struct cftype___256 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___256 *, struct cftype___256 *, s64);
	ssize_t (*write)(struct kernfs_open_file___401 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___401 *, struct poll_table_struct___250 *);
};

struct xdp_rxq_info___52 {
	struct net_device___3 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___52 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___3 *dev_rx;
};

struct netlink_callback___54 {
	struct sk_buff___54 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___54 *);
	int (*dump)(struct sk_buff___54 *, struct netlink_callback___54 *);
	int (*done)(struct netlink_callback___54 *);
	void *data;
	struct module___337 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___52 {
	int (*create)(struct sk_buff___54 *, struct net_device___3 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___54 *, unsigned char *);
	int (*cache)(const struct neighbour___36 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___3 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___52 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___52 *, int);
	int poll_owner;
	struct net_device___3 *dev;
	struct sk_buff___54 *gro_list;
	struct sk_buff___54 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___52 {
	struct net_device___3 *dev;
	struct Qdisc___46 *qdisc;
	struct Qdisc___46 *qdisc_sleeping;
	struct kobject___395 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___3 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___46 {
	struct sk_buff___54 *head;
	struct sk_buff___54 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___46;

struct Qdisc___46 {
	int (*enqueue)(struct sk_buff___54 *, struct Qdisc___46 *, struct sk_buff___54 **);
	struct sk_buff___54 * (*dequeue)(struct Qdisc___46 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___46 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___52 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___52 gso_skb;
	struct qdisc_skb_head___46 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___46 *next_sched;
	struct sk_buff_head___52 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___52 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___395 kobj;
	struct net_device___3 *dev;
	long: 64;
	struct xdp_rxq_info___52 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___52)(struct net_device___3 *, struct sk_buff___54 *, struct net_device___3 *);

struct netdev_bpf___52 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___46 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___46 *prog;
			const struct bpf_prog_offload_ops___46 *ops;
		} verifier;
		struct {
			struct bpf_prog___46 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___52 *offmap;
		};
		struct {
			struct xdp_umem *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___52 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___54 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___52 {
	int (*tls_dev_add)(struct net_device___3 *, struct sock___37 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___3 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___3 *, struct sock___37 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___52 {
	int (*ndo_init)(struct net_device___3 *);
	void (*ndo_uninit)(struct net_device___3 *);
	int (*ndo_open)(struct net_device___3 *);
	int (*ndo_stop)(struct net_device___3 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___54 *, struct net_device___3 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___54 *, struct net_device___3 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___3 *, struct sk_buff___54 *, struct net_device___3 *, select_queue_fallback_t___52);
	void (*ndo_change_rx_flags)(struct net_device___3 *, int);
	void (*ndo_set_rx_mode)(struct net_device___3 *);
	int (*ndo_set_mac_address)(struct net_device___3 *, void *);
	int (*ndo_validate_addr)(struct net_device___3 *);
	int (*ndo_do_ioctl)(struct net_device___3 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___3 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___3 *, int);
	int (*ndo_neigh_setup)(struct net_device___3 *, struct neigh_parms___36 *);
	void (*ndo_tx_timeout)(struct net_device___3 *);
	void (*ndo_get_stats64)(struct net_device___3 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___3 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___3 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___3 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___3 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___3 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___3 *);
	int (*ndo_netpoll_setup)(struct net_device___3 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___3 *);
	int (*ndo_set_vf_mac)(struct net_device___3 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___3 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___3 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___3 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___3 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___3 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___3 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___3 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___3 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___3 *, int, struct sk_buff___54 *);
	int (*ndo_set_vf_guid)(struct net_device___3 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___3 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___3 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___3 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___3 *, const struct sk_buff___54 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___3 *, struct net_device___3 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___3 *, struct net_device___3 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___3 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___3 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___3 *, struct neighbour___36 *);
	void (*ndo_neigh_destroy)(struct net_device___3 *, struct neighbour___36 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___3 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___3 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___3 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___54 *, struct netlink_callback___54 *, struct net_device___3 *, struct net_device___3 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___3 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___3 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___54 *, u32, u32, struct net_device___3 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___3 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___3 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___3 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___3 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___3 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___3 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___3 *, struct net_device___3 *);
	void (*ndo_dfwd_del_station)(struct net_device___3 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___3 *);
	int (*ndo_set_tx_maxrate)(struct net_device___3 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___3 *);
	int (*ndo_change_proto_down)(struct net_device___3 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___3 *, struct sk_buff___54 *);
	void (*ndo_set_rx_headroom)(struct net_device___3 *, int);
	int (*ndo_bpf)(struct net_device___3 *, struct netdev_bpf___52 *);
	int (*ndo_xdp_xmit)(struct net_device___3 *, int, struct xdp_frame___52 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___3 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___3 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___36 {
	possible_net_t___54 net;
	struct net_device___3 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___36 *);
	void (*neigh_cleanup)(struct neighbour___36 *);
	struct neigh_table___36 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___36 {
	u32 (*l3mdev_fib_table)(const struct net_device___3 *);
	struct sk_buff___54 * (*l3mdev_l3_rcv)(struct net_device___3 *, struct sk_buff___54 *, u16);
	struct sk_buff___54 * (*l3mdev_l3_out)(struct net_device___3 *, struct sock___37 *, struct sk_buff___54 *, u16);
	struct dst_entry___36 * (*l3mdev_link_scope_lookup)(const struct net_device___3 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct ndisc_ops___19 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___3 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___3 *, struct neighbour___36 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___3 *, u8, struct neighbour___36 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___3 *, struct sk_buff___54 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___64 *, struct net_device___3 *, const struct prefix_info *, struct inet6_dev___19 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___19;

struct ifacaddr6___4;

struct inet6_dev___19 {
	struct net_device___3 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___19 *mc_list;
	struct ifmcaddr6___19 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___4 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	u8 rndid[8];
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___36 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
};

struct tcf_proto___46;

struct mini_Qdisc___46 {
	struct tcf_proto___46 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___46 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___3 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___64 *, struct net_device___3 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___3 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___3 *, struct list_head *);
	size_t (*get_size)(const struct net_device___3 *);
	int (*fill_info)(struct sk_buff___54 *, const struct net_device___3 *);
	size_t (*get_xstats_size)(const struct net_device___3 *);
	int (*fill_xstats)(struct sk_buff___54 *, const struct net_device___3 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___3 *, struct net_device___3 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___3 *, const struct net_device___3 *);
	int (*fill_slave_info)(struct sk_buff___54 *, const struct net_device___3 *, const struct net_device___3 *);
	struct net___64 * (*get_link_net)(const struct net_device___3 *);
	size_t (*get_linkxstats_size)(const struct net_device___3 *, int);
	int (*fill_linkxstats)(struct sk_buff___54 *, const struct net_device___3 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct mii_bus___8;

struct mdio_device___8 {
	struct device___375 dev;
	struct mii_bus___8 *bus;
	char modalias[32];
	int (*bus_match)(struct device___375 *, struct device_driver___375 *);
	void (*device_free)(struct mdio_device___8 *);
	void (*device_remove)(struct mdio_device___8 *);
	int addr;
	int flags;
	struct gpio_desc *reset;
	unsigned int reset_assert_delay;
	unsigned int reset_deassert_delay;
};

struct phy_driver___8;

struct phy_device___8 {
	struct mdio_device___8 mdio;
	struct phy_driver___8 *drv;
	u32 phy_id;
	struct phy_c45_device_ids c45_ids;
	unsigned int is_c45: 1;
	unsigned int is_internal: 1;
	unsigned int is_pseudo_fixed_link: 1;
	unsigned int has_fixups: 1;
	unsigned int suspended: 1;
	unsigned int sysfs_links: 1;
	unsigned int loopback_enabled: 1;
	unsigned int autoneg: 1;
	unsigned int link: 1;
	enum phy_state state;
	u32 dev_flags;
	phy_interface_t interface;
	int speed;
	int duplex;
	int pause;
	int asym_pause;
	u32 interrupts;
	u32 rh_reserved_supported;
	u32 rh_reserved_advertising;
	u32 rh_reserved_lp_advertising;
	u32 eee_broken_modes;
	int link_timeout;
	struct phy_led_trigger *phy_led_triggers;
	unsigned int phy_num_led_triggers;
	struct phy_led_trigger *last_triggered;
	struct phy_led_trigger *led_link_trigger;
	int irq;
	void *priv;
	struct work_struct phy_queue;
	struct delayed_work state_queue;
	struct mutex lock;
	struct phylink *phylink;
	struct net_device___3 *attached_dev;
	u8 mdix;
	u8 mdix_ctrl;
	long unsigned int supported[2];
	long unsigned int advertising[2];
	long unsigned int lp_advertising[2];
	void (*phy_link_change)(struct phy_device___8 *, bool, bool);
	void (*adjust_link)(struct net_device___3 *);
};

struct softnet_data___52 {
	struct list_head poll_list;
	struct sk_buff_head___52 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___52 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___46 *output_queue;
	struct Qdisc___46 **output_queue_tailp;
	struct sk_buff___54 *completion_queue;
	struct sk_buff_head___52 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___52 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___52 input_pkt_queue;
	struct napi_struct___52 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bdi_writeback_congested___201 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___201 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___201 {
	struct bio___201 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___203 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___203 bip_inline_vecs[0];
};

struct bio_set___201 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___201 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___144 {
	struct mem_cgroup___144 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___144 {
	struct lruvec___408 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___144 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___144 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct kernel_param_ops___335 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___335 *);
	int (*get)(char *, const struct kernel_param___335 *);
	void (*free)(void *);
};

struct kparam_array___335;

struct kernel_param___335 {
	const char *name;
	struct module___337 *mod;
	const struct kernel_param_ops___335 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___335 *arr;
	};
};

struct kparam_array___335 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___335 *ops;
	void *elem;
};

struct module_attribute___335 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___335 *, struct module_kobject___335 *, char *);
	ssize_t (*store)(struct module_attribute___335 *, struct module_kobject___335 *, const char *, size_t);
	void (*setup)(struct module___337 *, const char *);
	int (*test)(struct module___337 *);
	void (*free)(struct module___337 *);
};

struct gnet_dump___46 {
	spinlock_t *lock;
	struct sk_buff___54 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___46;

struct Qdisc_ops___46 {
	struct Qdisc_ops___46 *next;
	const struct Qdisc_class_ops___46 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___54 *, struct Qdisc___46 *, struct sk_buff___54 **);
	struct sk_buff___54 * (*dequeue)(struct Qdisc___46 *);
	struct sk_buff___54 * (*peek)(struct Qdisc___46 *);
	int (*init)(struct Qdisc___46 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___46 *);
	void (*destroy)(struct Qdisc___46 *);
	int (*change)(struct Qdisc___46 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___46 *);
	int (*change_tx_queue_len)(struct Qdisc___46 *, unsigned int);
	int (*dump)(struct Qdisc___46 *, struct sk_buff___54 *);
	int (*dump_stats)(struct Qdisc___46 *, struct gnet_dump___46 *);
	void (*ingress_block_set)(struct Qdisc___46 *, u32);
	void (*egress_block_set)(struct Qdisc___46 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___46 *);
	u32 (*egress_block_get)(struct Qdisc___46 *);
	struct module___337 *owner;
};

struct tcf_block___46;

struct Qdisc_class_ops___46 {
	unsigned int flags;
	struct netdev_queue___52 * (*select_queue)(struct Qdisc___46 *, struct tcmsg *);
	int (*graft)(struct Qdisc___46 *, long unsigned int, struct Qdisc___46 *, struct Qdisc___46 **, struct netlink_ext_ack *);
	struct Qdisc___46 * (*leaf)(struct Qdisc___46 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___46 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___46 *, u32);
	int (*change)(struct Qdisc___46 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___46 *, long unsigned int);
	void (*walk)(struct Qdisc___46 *, struct qdisc_walker *);
	struct tcf_block___46 * (*tcf_block)(struct Qdisc___46 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___46 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___46 *, long unsigned int);
	int (*dump)(struct Qdisc___46 *, long unsigned int, struct sk_buff___54 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___46 *, long unsigned int, struct gnet_dump___46 *);
};

struct tcf_chain___46;

struct tcf_block___46 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___64 *net;
	struct Qdisc___46 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___46 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___46;

struct tcf_proto_ops___46;

struct tcf_proto___46 {
	struct tcf_proto___46 *next;
	void *root;
	int (*classify)(struct sk_buff___54 *, const struct tcf_proto___46 *, struct tcf_result___46 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___46 *ops;
	struct tcf_chain___46 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___46 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___46 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___46 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___54 *, const struct tcf_proto___46 *, struct tcf_result___46 *);
	int (*init)(struct tcf_proto___46 *);
	void (*destroy)(struct tcf_proto___46 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___46 *, u32);
	void (*put)(struct tcf_proto___46 *, void *);
	int (*change)(struct net___64 *, struct sk_buff___54 *, struct tcf_proto___46 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___46 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___46 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___46 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___64 *, struct tcf_chain___46 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___64 *, struct tcf_proto___46 *, void *, struct sk_buff___54 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___54 *, struct net___64 *, void *);
	struct module___337 *owner;
	int flags;
};

struct tcf_chain___46 {
	struct mutex filter_chain_lock;
	struct tcf_proto___46 *filter_chain;
	struct list_head list;
	struct tcf_block___46 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___46 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___36 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___46 *prog;
};

struct bpf_redirect_info___46 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___257 *map;
	struct bpf_map___257 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___36;

struct neigh_hash_table___36;

struct neigh_table___36 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___3 *, __u32 *);
	bool (*key_eq)(const struct neighbour___36 *, const void *);
	int (*constructor)(struct neighbour___36 *);
	int (*pconstructor)(struct pneigh_entry___36 *);
	void (*pdestructor)(struct pneigh_entry___36 *);
	void (*proxy_redo)(struct sk_buff___54 *);
	char *id;
	struct neigh_parms___36 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___52 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___36 *nht;
	struct pneigh_entry___36 **phash_buckets;
};

struct neigh_ops___36 {
	int family;
	void (*solicit)(struct neighbour___36 *, struct sk_buff___54 *);
	void (*error_report)(struct neighbour___36 *, struct sk_buff___54 *);
	int (*output)(struct neighbour___36 *, struct sk_buff___54 *);
	int (*connected_output)(struct neighbour___36 *, struct sk_buff___54 *);
};

struct pneigh_entry___36 {
	struct pneigh_entry___36 *next;
	possible_net_t___54 net;
	struct net_device___3 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___36 {
	struct neighbour___36 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___64 *, struct sock___37 *, struct sk_buff___54 *);
	int (*orig_input)(struct sk_buff___54 *);
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	__u8 data[0];
};

struct fib_rule___36 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___36 *ctarget;
	struct net___64 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___36 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___36 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___23;

struct timewait_sock_ops___21;

struct proto___36 {
	void (*close)(struct sock___37 *, long int);
	int (*pre_connect)(struct sock___37 *, struct sockaddr *, int);
	int (*connect)(struct sock___37 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___37 *, int);
	struct sock___37 * (*accept)(struct sock___37 *, int, int *, bool);
	int (*ioctl)(struct sock___37 *, int, long unsigned int);
	int (*init)(struct sock___37 *);
	void (*destroy)(struct sock___37 *);
	void (*shutdown)(struct sock___37 *, int);
	int (*setsockopt)(struct sock___37 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___37 *, int, int, char *, int *);
	void (*keepalive)(struct sock___37 *, int);
	int (*sendmsg)(struct sock___37 *, struct msghdr___39 *, size_t);
	int (*recvmsg)(struct sock___37 *, struct msghdr___39 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___37 *, struct page___408 *, int, size_t, int);
	int (*bind)(struct sock___37 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___37 *, struct sk_buff___54 *);
	void (*release_cb)(struct sock___37 *);
	int (*hash)(struct sock___37 *);
	void (*unhash)(struct sock___37 *);
	void (*rehash)(struct sock___37 *);
	int (*get_port)(struct sock___37 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___37 *);
	bool (*stream_memory_read)(const struct sock___37 *);
	void (*enter_memory_pressure)(struct sock___37 *);
	void (*leave_memory_pressure)(struct sock___37 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___23 *rsk_prot;
	struct timewait_sock_ops___21 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___337 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___37 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct request_sock___24;

struct request_sock_ops___23 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___37 *, struct request_sock___24 *);
	void (*send_ack)(const struct sock___37 *, struct sk_buff___54 *, struct request_sock___24 *);
	void (*send_reset)(const struct sock___37 *, struct sk_buff___54 *);
	void (*destructor)(struct request_sock___24 *);
	void (*syn_ack_timeout)(const struct request_sock___24 *);
};

struct timewait_sock_ops___21 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___37 *, struct sock___37 *, void *);
	void (*twsk_destructor)(struct sock___37 *);
};

struct request_sock___24 {
	struct sock_common___36 __req_common;
	struct request_sock___24 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___23 *rsk_ops;
	struct sock___37 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

union tcp_word_hdr {
	struct tcphdr hdr;
	__be32 words[5];
};

struct property___95 {
	char *name;
	int length;
	void *value;
	struct property___95 *next;
	long unsigned int _flags;
	struct bin_attribute___371 attr;
};

struct mii_bus___8 {
	struct module___337 *owner;
	const char *name;
	char id[61];
	void *priv;
	int (*read)(struct mii_bus___8 *, int, int);
	int (*write)(struct mii_bus___8 *, int, int, u16);
	int (*reset)(struct mii_bus___8 *);
	struct mutex mdio_lock;
	struct device___375 *parent;
	enum {
		MDIOBUS_ALLOCATED___8 = 1,
		MDIOBUS_REGISTERED___8 = 2,
		MDIOBUS_UNREGISTERED___8 = 3,
		MDIOBUS_RELEASED___8 = 4,
	} state;
	struct device___375 dev;
	struct mdio_device___8 *mdio_map[32];
	u32 phy_mask;
	u32 phy_ignore_ta_mask;
	int irq[32];
	int reset_delay_us;
	struct gpio_desc *reset_gpiod;
};

struct mdio_driver_common___8 {
	struct device_driver___375 driver;
	int flags;
};

struct phy_driver___8 {
	struct mdio_driver_common___8 mdiodrv;
	u32 phy_id;
	char *name;
	u32 phy_id_mask;
	u32 rh_reserved_features;
	u32 flags;
	const void *driver_data;
	const long unsigned int * const features;
	int (*soft_reset)(struct phy_device___8 *);
	int (*config_init)(struct phy_device___8 *);
	int (*probe)(struct phy_device___8 *);
	int (*suspend)(struct phy_device___8 *);
	int (*resume)(struct phy_device___8 *);
	int (*config_aneg)(struct phy_device___8 *);
	int (*aneg_done)(struct phy_device___8 *);
	int (*read_status)(struct phy_device___8 *);
	int (*ack_interrupt)(struct phy_device___8 *);
	int (*config_intr)(struct phy_device___8 *);
	int (*did_interrupt)(struct phy_device___8 *);
	void (*remove)(struct phy_device___8 *);
	int (*match_phy_device)(struct phy_device___8 *);
	int (*ts_info)(struct phy_device___8 *, struct ethtool_ts_info *);
	int (*hwtstamp)(struct phy_device___8 *, struct ifreq *);
	bool (*rxtstamp)(struct phy_device___8 *, struct sk_buff___54 *, int);
	void (*txtstamp)(struct phy_device___8 *, struct sk_buff___54 *, int);
	int (*set_wol)(struct phy_device___8 *, struct ethtool_wolinfo *);
	void (*get_wol)(struct phy_device___8 *, struct ethtool_wolinfo *);
	void (*link_change_notify)(struct phy_device___8 *);
	int (*read_mmd)(struct phy_device___8 *, int, u16);
	int (*write_mmd)(struct phy_device___8 *, int, u16, u16);
	int (*read_page)(struct phy_device___8 *);
	int (*write_page)(struct phy_device___8 *, int);
	int (*module_info)(struct phy_device___8 *, struct ethtool_modinfo *);
	int (*module_eeprom)(struct phy_device___8 *, struct ethtool_eeprom *, u8 *);
	int (*get_sset_count)(struct phy_device___8 *);
	void (*get_strings)(struct phy_device___8 *, u8 *);
	void (*get_stats)(struct phy_device___8 *, struct ethtool_stats *, u64 *);
	int (*get_tunable)(struct phy_device___8 *, struct ethtool_tunable *, void *);
	int (*set_tunable)(struct phy_device___8 *, struct ethtool_tunable *, const void *);
	int (*set_loopback)(struct phy_device___8 *, bool);
};

enum devlink_dpipe_field_mapping_type {
	DEVLINK_DPIPE_FIELD_MAPPING_TYPE_NONE = 0,
	DEVLINK_DPIPE_FIELD_MAPPING_TYPE_IFINDEX = 1,
};

struct devlink_dpipe_field {
	const char *name;
	unsigned int id;
	unsigned int bitwidth;
	enum devlink_dpipe_field_mapping_type mapping_type;
};

struct devlink_dpipe_header {
	const char *name;
	unsigned int id;
	struct devlink_dpipe_field *fields;
	unsigned int fields_count;
	bool global;
};

struct ifmcaddr6___19 {
	struct in6_addr mca_addr;
	struct inet6_dev___19 *idev;
	struct ifmcaddr6___19 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___4 {
	struct in6_addr aca_addr;
	struct fib6_info___4 *aca_rt;
	struct ifacaddr6___4 *aca_next;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct arphdr {
	__be16 ar_hrd;
	__be16 ar_pro;
	unsigned char ar_hln;
	unsigned char ar_pln;
	__be16 ar_op;
};

struct ip6_ra_chain___19 {
	struct ip6_ra_chain___19 *next;
	struct sock___37 *sk;
	int sel;
	void (*destructor)(struct sock___37 *);
};

struct switchdev_trans {
	struct list_head item_list;
	bool ph_prepare;
};

enum switchdev_attr_id {
	SWITCHDEV_ATTR_ID_UNDEFINED = 0,
	SWITCHDEV_ATTR_ID_PORT_PARENT_ID = 1,
	SWITCHDEV_ATTR_ID_PORT_STP_STATE = 2,
	SWITCHDEV_ATTR_ID_PORT_BRIDGE_FLAGS = 3,
	SWITCHDEV_ATTR_ID_PORT_BRIDGE_FLAGS_SUPPORT = 4,
	SWITCHDEV_ATTR_ID_PORT_MROUTER = 5,
	SWITCHDEV_ATTR_ID_BRIDGE_AGEING_TIME = 6,
	SWITCHDEV_ATTR_ID_BRIDGE_VLAN_FILTERING = 7,
	SWITCHDEV_ATTR_ID_BRIDGE_MC_DISABLED = 8,
	SWITCHDEV_ATTR_ID_BRIDGE_MROUTER = 9,
	SWITCHDEV_ATTR_ID_PORT_PRE_BRIDGE_FLAGS = 10,
};

struct switchdev_attr {
	struct net_device___3 *orig_dev;
	enum switchdev_attr_id id;
	u32 flags;
	void *complete_priv;
	void (*complete)(struct net_device___3 *, int, void *);
	union {
		struct netdev_phys_item_id ppid;
		u8 stp_state;
		long unsigned int brport_flags;
		long unsigned int brport_flags_support;
		bool mrouter;
		clock_t ageing_time;
		bool vlan_filtering;
		bool mc_disabled;
	} u;
};

enum switchdev_obj_id {
	SWITCHDEV_OBJ_ID_UNDEFINED = 0,
	SWITCHDEV_OBJ_ID_PORT_VLAN = 1,
	SWITCHDEV_OBJ_ID_PORT_MDB = 2,
	SWITCHDEV_OBJ_ID_HOST_MDB = 3,
};

struct switchdev_obj {
	struct net_device___3 *orig_dev;
	enum switchdev_obj_id id;
	u32 flags;
	void *complete_priv;
	void (*complete)(struct net_device___3 *, int, void *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dst_cache_pcpu;

struct dst_cache {
	struct dst_cache_pcpu *cache;
	long unsigned int reset_ts;
};

struct ipv6_stub {
	int (*ipv6_sock_mc_join)(struct sock___37 *, int, const struct in6_addr *);
	int (*ipv6_sock_mc_drop)(struct sock___37 *, int, const struct in6_addr *);
	int (*ipv6_dst_lookup)(struct net___64 *, struct sock___37 *, struct dst_entry___36 **, struct flowi6 *);
	struct fib6_table___4 * (*fib6_get_table)(struct net___64 *, u32);
	struct fib6_info___4 * (*fib6_lookup)(struct net___64 *, int, struct flowi6 *, int);
	struct fib6_info___4 * (*fib6_table_lookup)(struct net___64 *, struct fib6_table___4 *, int, struct flowi6 *, int);
	struct fib6_info___4 * (*fib6_multipath_select)(const struct net___64 *, struct fib6_info___4 *, struct flowi6 *, int, const struct sk_buff___54 *, int);
	u32 (*ip6_mtu_from_fib6)(struct fib6_info___4 *, struct in6_addr *, struct in6_addr *);
	void (*udpv6_encap_enable)();
	void (*ndisc_send_na)(struct net_device___3 *, const struct in6_addr *, const struct in6_addr *, bool, bool, bool, bool);
	struct neigh_table___36 *nd_tbl;
};

struct ipv6_bpf_stub {
	int (*inet6_bind)(struct sock___37 *, struct sockaddr *, int, bool, bool);
	struct sock___37 * (*udp6_lib_lookup)(struct net___64 *, const struct in6_addr *, __be16, const struct in6_addr *, __be16, int, int, struct udp_table *, struct sk_buff___54 *);
};

struct ip_tunnel_key {
	__be64 tun_id;
	union {
		struct {
			__be32 src;
			__be32 dst;
		} ipv4;
		struct {
			struct in6_addr src;
			struct in6_addr dst;
		} ipv6;
	} u;
	__be16 tun_flags;
	u8 tos;
	u8 ttl;
	__be32 label;
	__be16 tp_src;
	__be16 tp_dst;
};

struct ip_tunnel_info {
	struct ip_tunnel_key key;
	struct dst_cache dst_cache;
	u8 options_len;
	u8 mode;
};

struct ip_tunnel_encap {
	u16 type;
	u16 flags;
	__be16 sport;
	__be16 dport;
};

struct ip_tunnel_encap_ops {
	size_t (*encap_hlen)(struct ip_tunnel_encap *);
	int (*build_header)(struct sk_buff___54 *, struct ip_tunnel_encap *, u8 *, struct flowi4 *);
};

enum metadata_type {
	METADATA_IP_TUNNEL = 0,
	METADATA_HW_PORT_MUX = 1,
};

struct hw_port_info {
	struct net_device___3 *lower_dev;
	u32 port_id;
};

struct metadata_dst {
	struct dst_entry___36 dst;
	enum metadata_type type;
	union {
		struct ip_tunnel_info tun_info;
		struct hw_port_info port_info;
	} u;
};

struct gre_base_hdr {
	__be16 flags;
	__be16 protocol;
};

struct gre_full_hdr {
	struct gre_base_hdr fixed_header;
	__be16 csum;
	__be16 reserved1;
	__be32 key;
	__be32 seq;
};

struct pptp_gre_header {
	struct gre_base_hdr gre_hd;
	__be16 payload_len;
	__be16 call_id;
	__be32 seq;
	__be32 ack;
};

struct tipc_basic_hdr {
	__be32 w[4];
};

enum l2tp_debug_flags {
	L2TP_MSG_DEBUG = 1,
	L2TP_MSG_CONTROL = 2,
	L2TP_MSG_SEQ = 4,
	L2TP_MSG_DATA = 8,
};

struct pppoe_tag {
	__be16 tag_type;
	__be16 tag_len;
	char tag_data[0];
};

struct pppoe_hdr {
	__u8 type: 4;
	__u8 ver: 4;
	__u8 code;
	__be16 sid;
	__be16 length;
	struct pppoe_tag tag[0];
};

struct mpls_label {
	__be32 entry;
};

enum batadv_packettype {
	BATADV_IV_OGM = 0,
	BATADV_BCAST = 1,
	BATADV_CODED = 2,
	BATADV_ELP = 3,
	BATADV_OGM2 = 4,
	BATADV_UNICAST = 64,
	BATADV_UNICAST_FRAG = 65,
	BATADV_UNICAST_4ADDR = 66,
	BATADV_ICMP = 67,
	BATADV_UNICAST_TVLV = 68,
};

struct batadv_unicast_packet {
	__u8 packet_type;
	__u8 version;
	__u8 ttl;
	__u8 ttvn;
	__u8 dest[6];
};

struct _flow_keys_digest_data {
	__be16 n_proto;
	u8 ip_proto;
	u8 padding;
	__be32 ports;
	__be32 src;
	__be32 dst;
};

struct module___338;

struct file___408;

struct kiocb___408;

struct iov_iter___175;

struct poll_table_struct___251;

struct vm_area_struct___409;

struct inode___408;

struct file_lock___408;

struct page___409;

struct pipe_inode_info___89;

struct seq_file___347;

struct file_operations___408 {
	struct module___338 *owner;
	loff_t (*llseek)(struct file___408 *, loff_t, int);
	ssize_t (*read)(struct file___408 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___408 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___408 *, struct iov_iter___175 *);
	ssize_t (*write_iter)(struct kiocb___408 *, struct iov_iter___175 *);
	int (*iopoll)(struct kiocb___408 *, bool);
	int (*iterate)(struct file___408 *, struct dir_context *);
	int (*iterate_shared)(struct file___408 *, struct dir_context *);
	__poll_t (*poll)(struct file___408 *, struct poll_table_struct___251 *);
	long int (*unlocked_ioctl)(struct file___408 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___408 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___408 *, struct vm_area_struct___409 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___408 *, struct file___408 *);
	int (*flush)(struct file___408 *, fl_owner_t);
	int (*release)(struct inode___408 *, struct file___408 *);
	int (*fsync)(struct file___408 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___408 *, int);
	int (*lock)(struct file___408 *, int, struct file_lock___408 *);
	ssize_t (*sendpage)(struct file___408 *, struct page___409 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___408 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___408 *, int, struct file_lock___408 *);
	ssize_t (*splice_write)(struct pipe_inode_info___89 *, struct file___408 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___408 *, loff_t *, struct pipe_inode_info___89 *, size_t, unsigned int);
	int (*setlease)(struct file___408 *, long int, struct file_lock___408 **, void **);
	long int (*fallocate)(struct file___408 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___347 *, struct file___408 *);
	ssize_t (*copy_file_range)(struct file___408 *, loff_t, struct file___408 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___408 *, loff_t, struct file___408 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___408 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___409 {
	u64 seqnum;
	struct vm_area_struct___409 *vmas[4];
};

struct page_frag___409 {
	struct page___409 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___409;

struct mem_cgroup___145;

struct cred___376;

struct nsproxy___303;

struct signal_struct___283;

struct bio_list___202;

struct backing_dev_info___202;

struct css_set___257;

struct vm_struct___312;

struct task_struct___410 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___410 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___409 *mm;
	struct mm_struct___409 *active_mm;
	struct vmacache___409 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___410 *real_parent;
	struct task_struct___410 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___410 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___145 *active_memcg;
	long int rh_reserved2;
	struct pid___233 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___233 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___233 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___376 *ptracer_cred;
	const struct cred___376 *real_cred;
	const struct cred___376 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___303 *nsproxy;
	struct signal_struct___283 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___410 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___202 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___202 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___257 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___89 *splice_pipe;
	struct page_frag___409 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___145 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___410 *oom_reaper_list;
	struct vm_struct___312 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___154 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___409 *pgtable_t___409;

struct address_space___408;

struct dev_pagemap___396;

struct page___409 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___408 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___409 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___409 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___409 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___396 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___145 *mem_cgroup;
};

struct pglist_data___409;

struct lruvec___409 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___409 *pgdat;
};

struct zone___409 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___409 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___409 {
	struct zone___409 *zone;
	int zone_idx;
};

struct zonelist___409 {
	struct zoneref___409 _zonerefs[25];
};

struct pglist_data___409 {
	struct zone___409 node_zones[3];
	struct zonelist___409 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___410 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___410 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___409 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___410 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___410 *owner;
};

struct secondary_data___410 {
	void *stack;
	struct task_struct___410 *task;
	long int status;
};

struct blocking_notifier_head___409 {
	struct rw_semaphore___410 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___396;

struct vm_area_struct___409 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___409 *vm_next;
	struct vm_area_struct___409 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___409 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___396 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___408 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___409;

struct user_namespace___273;

struct mm_struct___409 {
	struct {
		struct vm_area_struct___409 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___408 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___410 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___409 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___410 *owner;
		struct user_namespace___273 *user_ns;
		struct file___408 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___409 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___408;

struct address_space___408 {
	struct inode___408 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___410 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___408 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___396)(struct vm_area_struct___409 *, long unsigned int, const struct page___409 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___396)(struct page___409 *, void *);

struct device___376;

struct dev_pagemap___396 {
	dev_page_fault_t___396 page_fault;
	dev_page_free_t___396 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___376 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct cgroup___257;

struct cgroup_subsys___257;

struct cgroup_subsys_state___257 {
	struct cgroup___257 *cgroup;
	struct cgroup_subsys___257 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___257 *parent;
};

struct kernfs_node___403;

struct cgroup_file___257 {
	struct kernfs_node___403 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___145;

struct mem_cgroup___145 {
	struct cgroup_subsys_state___257 css;
	struct mem_cgroup_id___13 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___257 events_file;
	struct cgroup_file___257 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___410 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___145 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry___408;

struct path___409 {
	struct vfsmount *mnt;
	struct dentry___408 *dentry;
};

struct file___408 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___409 f_path;
	struct inode___408 *f_inode;
	const struct file_operations___408 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___233 f_owner;
	const struct cred___376 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___408 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___396;

struct vm_operations_struct___396 {
	void (*open)(struct vm_area_struct___409 *);
	void (*close)(struct vm_area_struct___409 *);
	int (*split)(struct vm_area_struct___409 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___409 *);
	vm_fault_t (*fault)(struct vm_fault___396 *);
	vm_fault_t (*huge_fault)(struct vm_fault___396 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___396 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___409 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___396 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___396 *);
	int (*access)(struct vm_area_struct___409 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___409 *);
	int (*set_policy)(struct vm_area_struct___409 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___409 *, long unsigned int);
	struct page___409 * (*find_special_page)(struct vm_area_struct___409 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___409 {
	struct task_struct___410 *task;
	struct core_thread___409 *next;
};

struct core_state___409 {
	atomic_t nr_threads;
	struct core_thread___409 dumper;
	struct completion startup;
};

struct key___376;

struct ucounts___273;

struct user_namespace___273 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___273 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___29 ns;
	long unsigned int flags;
	struct key___376 *persistent_keyring_register;
	struct rw_semaphore___410 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___273 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___396 {
	struct vm_area_struct___409 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___409 *cow_page;
	struct mem_cgroup___145 *memcg;
	struct page___409 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___409 prealloc_pte;
};

struct shrink_control___145 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___145 *memcg;
};

struct shrinker___145 {
	long unsigned int (*count_objects)(struct shrinker___145 *, struct shrink_control___145 *);
	long unsigned int (*scan_objects)(struct shrinker___145 *, struct shrink_control___145 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct user_struct___376 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___376 *uid_keyring;
	struct key___376 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___376 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___376 *session_keyring;
	struct key___376 *process_keyring;
	struct key___376 *thread_keyring;
	struct key___376 *request_key_auth;
	void *security;
	struct user_struct___376 *user;
	struct user_namespace___273 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___65;

struct cgroup_namespace___257;

struct nsproxy___303 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net___65 *net_ns;
	struct cgroup_namespace___257 *cgroup_ns;
};

struct signal_struct___283 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___410 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___410 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___233 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___233 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___409 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___233 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___202;

struct bio_list___202 {
	struct bio___202 *head;
	struct bio___202 *tail;
};

struct bdi_writeback_congested___202;

struct bdi_writeback___202 {
	struct backing_dev_info___202 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___202 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___257 *memcg_css;
	struct cgroup_subsys_state___257 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___202 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___202 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___376 *dev;
	struct device___376 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___408 *debug_dir;
	struct dentry___408 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___257 {
	struct cgroup_subsys_state___257 *subsys[13];
	refcount_t refcount;
	struct css_set___257 *dom_cset;
	struct cgroup___257 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___257 *mg_src_cgrp;
	struct cgroup___257 *mg_dst_cgrp;
	struct css_set___257 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___408;

struct pipe_buffer___89;

struct pipe_inode_info___89 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___409 *tmp_page;
	struct fasync_struct___408 *fasync_readers;
	struct fasync_struct___408 *fasync_writers;
	struct pipe_buffer___89 *bufs;
	struct user_struct___376 *user;
};

struct vm_struct___312 {
	struct vm_struct___312 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___409 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___295 {
	struct task_struct___410 task;
	long unsigned int stack[8192];
};

struct kset___395;

struct kobj_type___395;

struct kobject___396 {
	const char *name;
	struct list_head entry;
	struct kobject___396 *parent;
	struct kset___395 *kset;
	struct kobj_type___395 *ktype;
	struct kernfs_node___403 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___376 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___376 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___376;

struct bus_type___376;

struct device_driver___376;

struct dev_pm_domain___376;

struct dma_map_ops___148;

struct fwnode_handle___296;

struct class___376;

struct attribute_group___373;

struct device___376 {
	struct device___376 *parent;
	struct device_private *p;
	struct kobject___396 kobj;
	const char *init_name;
	const struct device_type___376 *type;
	struct mutex mutex;
	struct bus_type___376 *bus;
	struct device_driver___376 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___376 power;
	struct dev_pm_domain___376 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___148 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___296 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___376 *class;
	const struct attribute_group___373 **groups;
	void (*release)(struct device___376 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___408;

struct super_block___408;

struct dentry___408 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___408 *d_parent;
	struct qstr d_name;
	struct inode___408 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___408 *d_op;
	struct super_block___408 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___408;

struct block_device___408;

struct inode___408 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___408 *i_op;
	struct super_block___408 *i_sb;
	struct address_space___408 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___410 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___202 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___408 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___408 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___89 *i_pipe;
		struct block_device___408 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___408 {
	int (*d_revalidate)(struct dentry___408 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___408 *, unsigned int);
	int (*d_hash)(const struct dentry___408 *, struct qstr *);
	int (*d_compare)(const struct dentry___408 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___408 *);
	int (*d_init)(struct dentry___408 *);
	void (*d_release)(struct dentry___408 *);
	void (*d_prune)(struct dentry___408 *);
	void (*d_iput)(struct dentry___408 *, struct inode___408 *);
	char * (*d_dname)(struct dentry___408 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___409 *);
	int (*d_manage)(const struct path___409 *, bool);
	struct dentry___408 * (*d_real)(struct dentry___408 *, const struct inode___408 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___408;

struct mem_dqinfo___408 {
	struct quota_format_type___408 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___408;

struct quota_info___408 {
	unsigned int flags;
	struct rw_semaphore___410 dqio_sem;
	struct inode___408 *files[3];
	struct mem_dqinfo___408 info[3];
	const struct quota_format_ops___408 *ops[3];
};

struct rcuwait___408 {
	struct task_struct___410 *task;
};

struct percpu_rw_semaphore___408 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___410 rw_sem;
	struct rcuwait___408 writer;
	int readers_block;
};

struct sb_writers___408 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___408 rw_sem[3];
};

struct file_system_type___408;

struct super_operations___408;

struct dquot_operations___408;

struct quotactl_ops___408;

struct super_block___408 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___408 *s_type;
	const struct super_operations___408 *s_op;
	const struct dquot_operations___408 *dq_op;
	const struct quotactl_ops___408 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___408 *s_root;
	struct rw_semaphore___410 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___408 *s_bdev;
	struct backing_dev_info___202 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___408 s_dquot;
	struct sb_writers___408 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___408 *s_d_op;
	int cleancache_poolid;
	struct shrinker___145 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___273 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___408 {
	struct file___408 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___408 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___408 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___408 *ia_file;
};

struct dquot___408 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___408 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___408 {
	int qf_fmt_id;
	const struct quota_format_ops___408 *qf_ops;
	struct module___338 *qf_owner;
	struct quota_format_type___408 *qf_next;
};

struct quota_format_ops___408 {
	int (*check_quota_file)(struct super_block___408 *, int);
	int (*read_file_info)(struct super_block___408 *, int);
	int (*write_file_info)(struct super_block___408 *, int);
	int (*free_file_info)(struct super_block___408 *, int);
	int (*read_dqblk)(struct dquot___408 *);
	int (*commit_dqblk)(struct dquot___408 *);
	int (*release_dqblk)(struct dquot___408 *);
	int (*get_next_id)(struct super_block___408 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___408 {
	int (*write_dquot)(struct dquot___408 *);
	struct dquot___408 * (*alloc_dquot)(struct super_block___408 *, int);
	void (*destroy_dquot)(struct dquot___408 *);
	int (*acquire_dquot)(struct dquot___408 *);
	int (*release_dquot)(struct dquot___408 *);
	int (*mark_dirty)(struct dquot___408 *);
	int (*write_info)(struct super_block___408 *, int);
	qsize_t * (*get_reserved_space)(struct inode___408 *);
	int (*get_projid)(struct inode___408 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___408 *, qsize_t *);
	int (*get_next_id)(struct super_block___408 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___408 {
	int (*quota_on)(struct super_block___408 *, int, int, const struct path___409 *);
	int (*quota_off)(struct super_block___408 *, int);
	int (*quota_enable)(struct super_block___408 *, unsigned int);
	int (*quota_disable)(struct super_block___408 *, unsigned int);
	int (*quota_sync)(struct super_block___408 *, int);
	int (*set_info)(struct super_block___408 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___408 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___408 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___408 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___408 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___408 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___336 {
	struct kobject___396 kobj;
	struct module___338 *mod;
	struct kobject___396 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___336 {
	struct module___338 *mod;
	struct latch_tree_node node;
};

struct module_layout___336 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___336 mtn;
};

struct module_attribute___336;

struct kernel_param___336;

struct module___338 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___336 mkobj;
	struct module_attribute___336 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___396 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___336 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___336 core_layout;
	struct module_layout___336 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___165;

struct address_space_operations___408 {
	int (*writepage)(struct page___409 *, struct writeback_control___165 *);
	int (*readpage)(struct file___408 *, struct page___409 *);
	int (*writepages)(struct address_space___408 *, struct writeback_control___165 *);
	int (*set_page_dirty)(struct page___409 *);
	int (*readpages)(struct file___408 *, struct address_space___408 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___408 *, struct address_space___408 *, loff_t, unsigned int, unsigned int, struct page___409 **, void **);
	int (*write_end)(struct file___408 *, struct address_space___408 *, loff_t, unsigned int, unsigned int, struct page___409 *, void *);
	sector_t (*bmap)(struct address_space___408 *, sector_t);
	void (*invalidatepage)(struct page___409 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___409 *, gfp_t);
	void (*freepage)(struct page___409 *);
	ssize_t (*direct_IO)(struct kiocb___408 *, struct iov_iter___175 *);
	int (*migratepage)(struct address_space___408 *, struct page___409 *, struct page___409 *, enum migrate_mode);
	bool (*isolate_page)(struct page___409 *, isolate_mode_t);
	void (*putback_page)(struct page___409 *);
	int (*launder_page)(struct page___409 *);
	int (*is_partially_uptodate)(struct page___409 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___409 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___408 *, struct page___409 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___408 *, sector_t *);
	void (*swap_deactivate)(struct file___408 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___165 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___202 *wb;
	struct inode___408 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___204;

struct iov_iter___175 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___204 *bvec;
		struct pipe_inode_info___89 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___408 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___408 *bd_inode;
	struct super_block___408 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___408 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___202 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___408 {
	struct dentry___408 * (*lookup)(struct inode___408 *, struct dentry___408 *, unsigned int);
	const char * (*get_link)(struct dentry___408 *, struct inode___408 *, struct delayed_call *);
	int (*permission)(struct inode___408 *, int);
	struct posix_acl * (*get_acl)(struct inode___408 *, int);
	int (*readlink)(struct dentry___408 *, char *, int);
	int (*create)(struct inode___408 *, struct dentry___408 *, umode_t, bool);
	int (*link)(struct dentry___408 *, struct inode___408 *, struct dentry___408 *);
	int (*unlink)(struct inode___408 *, struct dentry___408 *);
	int (*symlink)(struct inode___408 *, struct dentry___408 *, const char *);
	int (*mkdir)(struct inode___408 *, struct dentry___408 *, umode_t);
	int (*rmdir)(struct inode___408 *, struct dentry___408 *);
	int (*mknod)(struct inode___408 *, struct dentry___408 *, umode_t, dev_t);
	int (*rename)(struct inode___408 *, struct dentry___408 *, struct inode___408 *, struct dentry___408 *, unsigned int);
	int (*setattr)(struct dentry___408 *, struct iattr___408 *);
	int (*getattr)(const struct path___409 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___408 *, char *, size_t);
	int (*fiemap)(struct inode___408 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___408 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___408 *, struct dentry___408 *, struct file___408 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___408 *, struct dentry___408 *, umode_t);
	int (*set_acl)(struct inode___408 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___408 {
	void (*fl_copy_lock)(struct file_lock___408 *, struct file_lock___408 *);
	void (*fl_release_private)(struct file_lock___408 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___408;

struct file_lock___408 {
	struct file_lock___408 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___408 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___408 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___408 *fl_ops;
	const struct lock_manager_operations___408 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___408 {
	int (*lm_compare_owner)(struct file_lock___408 *, struct file_lock___408 *);
	long unsigned int (*lm_owner_key)(struct file_lock___408 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___408 *);
	int (*lm_grant)(struct file_lock___408 *, int);
	bool (*lm_break)(struct file_lock___408 *);
	int (*lm_change)(struct file_lock___408 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___408 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___408 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___408 *fa_next;
	struct file___408 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___408 {
	const char *name;
	int fs_flags;
	struct dentry___408 * (*mount)(struct file_system_type___408 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___408 *);
	struct module___338 *owner;
	struct file_system_type___408 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___408 {
	struct inode___408 * (*alloc_inode)(struct super_block___408 *);
	void (*destroy_inode)(struct inode___408 *);
	void (*dirty_inode)(struct inode___408 *, int);
	int (*write_inode)(struct inode___408 *, struct writeback_control___165 *);
	int (*drop_inode)(struct inode___408 *);
	void (*evict_inode)(struct inode___408 *);
	void (*put_super)(struct super_block___408 *);
	int (*sync_fs)(struct super_block___408 *, int);
	int (*freeze_super)(struct super_block___408 *);
	int (*freeze_fs)(struct super_block___408 *);
	int (*thaw_super)(struct super_block___408 *);
	int (*unfreeze_fs)(struct super_block___408 *);
	int (*statfs)(struct dentry___408 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___408 *, int *, char *);
	void (*umount_begin)(struct super_block___408 *);
	int (*show_options)(struct seq_file___347 *, struct dentry___408 *);
	int (*show_devname)(struct seq_file___347 *, struct dentry___408 *);
	int (*show_path)(struct seq_file___347 *, struct dentry___408 *);
	int (*show_stats)(struct seq_file___347 *, struct dentry___408 *);
	ssize_t (*quota_read)(struct super_block___408 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___408 *, int, const char *, size_t, loff_t);
	struct dquot___408 ** (*get_dquots)(struct inode___408 *);
	int (*bdev_try_to_free_page)(struct super_block___408 *, struct page___409 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___408 *, struct shrink_control___145 *);
	long int (*free_cached_objects)(struct super_block___408 *, struct shrink_control___145 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___261)(struct file___408 *, wait_queue_head_t *, struct poll_table_struct___251 *);

struct poll_table_struct___251 {
	poll_queue_proc___261 _qproc;
	__poll_t _key;
};

struct seq_operations___347;

struct seq_file___347 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___347 *op;
	int poll_event;
	const struct file___408 *file;
	void *private;
};

typedef void bio_end_io_t___202(struct bio___202 *);

struct bio_vec___204 {
	struct page___409 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___202;

struct bio_set___202;

struct bio___202 {
	struct bio___202 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___202 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___202 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___204 *bi_io_vec;
	struct bio_set___202 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___204 bi_inline_vecs[0];
};

struct kobj_attribute___386 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___396 *, struct kobj_attribute___386 *, char *);
	ssize_t (*store)(struct kobject___396 *, struct kobj_attribute___386 *, const char *, size_t);
};

typedef void compound_page_dtor___396(struct page___409 *);

struct kernfs_root___402;

struct kernfs_elem_dir___402 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___402 *root;
};

struct kernfs_syscall_ops___402;

struct kernfs_root___402 {
	struct kernfs_node___403 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___402 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___402 {
	struct kernfs_node___403 *target_kn;
};

struct kernfs_ops___402;

struct kernfs_elem_attr___402 {
	const struct kernfs_ops___402 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___403 *notify_next;
};

struct kernfs_node___403 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___403 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___402 dir;
		struct kernfs_elem_symlink___402 symlink;
		struct kernfs_elem_attr___402 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___402;

struct kernfs_ops___402 {
	int (*open)(struct kernfs_open_file___402 *);
	void (*release)(struct kernfs_open_file___402 *);
	int (*seq_show)(struct seq_file___347 *, void *);
	void * (*seq_start)(struct seq_file___347 *, loff_t *);
	void * (*seq_next)(struct seq_file___347 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___347 *, void *);
	ssize_t (*read)(struct kernfs_open_file___402 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___402 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___402 *, struct vm_area_struct___409 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___402 *, struct poll_table_struct___251 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___402 {
	int (*remount_fs)(struct kernfs_root___402 *, int *, char *);
	int (*show_options)(struct seq_file___347 *, struct kernfs_root___402 *);
	int (*mkdir)(struct kernfs_node___403 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___403 *);
	int (*rename)(struct kernfs_node___403 *, struct kernfs_node___403 *, const char *);
	int (*show_path)(struct seq_file___347 *, struct kernfs_node___403 *, struct kernfs_root___402 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___402 {
	struct kernfs_node___403 *kn;
	struct file___408 *file;
	struct seq_file___347 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___396 *vm_ops;
};

struct sock___38;

struct kobj_ns_type_operations___37 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___38 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___65 *net;
} possible_net_t___55;

struct proto___37;

struct sock_common___37 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___37 *skc_prot;
	possible_net_t___55 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___38 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___55;

struct sk_buff_head___53 {
	struct sk_buff___55 *next;
	struct sk_buff___55 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___37;

struct socket_wq___38;

struct dst_entry___37;

struct socket___39;

struct net_device___54;

struct sock___38 {
	struct sock_common___37 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___53 sk_error_queue;
	struct sk_buff_head___53 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___55 *head;
		struct sk_buff___55 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___37 *sk_filter;
	union {
		struct socket_wq___38 *sk_wq;
		struct socket_wq___38 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___37 *sk_rx_dst;
	struct dst_entry___37 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___55 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___53 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___409 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___37 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___233 *sk_peer_pid;
	const struct cred___376 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___39 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___145 *sk_memcg;
	void (*sk_state_change)(struct sock___38 *);
	void (*sk_data_ready)(struct sock___38 *);
	void (*sk_write_space)(struct sock___38 *);
	void (*sk_error_report)(struct sock___38 *);
	int (*sk_backlog_rcv)(struct sock___38 *, struct sk_buff___55 *);
	struct sk_buff___55 * (*sk_validate_xmit_skb)(struct sock___38 *, struct net_device___54 *, struct sk_buff___55 *);
	void (*sk_destruct)(struct sock___38 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct bin_attribute___372;

struct attribute_group___373 {
	const char *name;
	umode_t (*is_visible)(struct kobject___396 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___396 *, struct bin_attribute___372 *, int);
	struct attribute **attrs;
	struct bin_attribute___372 **bin_attrs;
};

struct bin_attribute___372 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___408 *, struct kobject___396 *, struct bin_attribute___372 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___408 *, struct kobject___396 *, struct bin_attribute___372 *, char *, loff_t, size_t);
	int (*mmap)(struct file___408 *, struct kobject___396 *, struct bin_attribute___372 *, struct vm_area_struct___409 *);
};

struct sysfs_ops___395 {
	ssize_t (*show)(struct kobject___396 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___396 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___395;

struct kset___395 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___396 kobj;
	const struct kset_uevent_ops___395 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___395 {
	void (*release)(struct kobject___396 *);
	const struct sysfs_ops___395 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___37 * (*child_ns_type)(struct kobject___396 *);
	const void * (*namespace)(struct kobject___396 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___395 {
	int (* const filter)(struct kset___395 *, struct kobject___396 *);
	const char * (* const name)(struct kset___395 *, struct kobject___396 *);
	int (* const uevent)(struct kset___395 *, struct kobject___396 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___336 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___336 *);
	int (*get)(char *, const struct kernel_param___336 *);
	void (*free)(void *);
};

struct kparam_array___336;

struct kernel_param___336 {
	const char *name;
	struct module___338 *mod;
	const struct kernel_param_ops___336 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___336 *arr;
	};
};

struct kparam_array___336 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___336 *ops;
	void *elem;
};

struct module_attribute___336 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___336 *, struct module_kobject___336 *, char *);
	ssize_t (*store)(struct module_attribute___336 *, struct module_kobject___336 *, const char *, size_t);
	void (*setup)(struct module___338 *, const char *);
	int (*test)(struct module___338 *);
	void (*free)(struct module___338 *);
};

struct msghdr___40 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___175 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___408 *msg_iocb;
};

struct socket_wq___38 {
	wait_queue_head_t wait;
	struct fasync_struct___408 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___38;

struct socket___39 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___38 *wq;
	struct file___408 *file;
	struct sock___38 *sk;
	const struct proto_ops___38 *ops;
};

typedef int (*sk_read_actor_t___37)(read_descriptor_t *, struct sk_buff___55 *, unsigned int, size_t);

struct proto_ops___38 {
	int family;
	struct module___338 *owner;
	int (*release)(struct socket___39 *);
	int (*bind)(struct socket___39 *, struct sockaddr *, int);
	int (*connect)(struct socket___39 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___39 *, struct socket___39 *);
	int (*accept)(struct socket___39 *, struct socket___39 *, int, bool);
	int (*getname)(struct socket___39 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___408 *, struct socket___39 *, struct poll_table_struct___251 *);
	int (*ioctl)(struct socket___39 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___39 *, int);
	int (*shutdown)(struct socket___39 *, int);
	int (*setsockopt)(struct socket___39 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___39 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___39 *, struct msghdr___40 *, size_t);
	int (*recvmsg)(struct socket___39 *, struct msghdr___40 *, size_t, int);
	int (*mmap)(struct file___408 *, struct socket___39 *, struct vm_area_struct___409 *);
	ssize_t (*sendpage)(struct socket___39 *, struct page___409 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___39 *, loff_t *, struct pipe_inode_info___89 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___38 *, int);
	int (*peek_len)(struct socket___39 *);
	int (*read_sock)(struct sock___38 *, read_descriptor_t *, sk_read_actor_t___37);
	int (*sendpage_locked)(struct sock___38 *, struct page___409 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___38 *, struct msghdr___40 *, size_t);
	int (*set_rcvlowat)(struct sock___38 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct nf_bridge_info___53;

struct sk_buff___55 {
	union {
		struct {
			struct sk_buff___55 *next;
			struct sk_buff___55 *prev;
			union {
				struct net_device___54 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___38 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___55 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___53 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___53;

struct netns_frags___53 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___53 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ip_ra_chain___17;

struct fib_rules_ops___37;

struct fib_notifier_ops___37;

struct netns_ipv4___53 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___17 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___37 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___38 *fibnl;
	struct sock___38 **icmp_sk;
	struct sock___38 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___38 **tcp_sk;
	struct netns_frags___53 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___37 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___37 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___37 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___37;

struct dst_ops___64 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___64 *);
	struct dst_entry___37 * (*check)(struct dst_entry___37 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___37 *);
	unsigned int (*mtu)(const struct dst_entry___37 *);
	u32 * (*cow_metrics)(struct dst_entry___37 *, long unsigned int);
	void (*destroy)(struct dst_entry___37 *);
	void (*ifdown)(struct dst_entry___37 *, struct net_device___54 *, int);
	struct dst_entry___37 * (*negative_advice)(struct dst_entry___37 *);
	void (*link_failure)(struct sk_buff___55 *);
	void (*update_pmtu)(struct dst_entry___37 *, struct sock___38 *, struct sk_buff___55 *, u32);
	void (*redirect)(struct dst_entry___37 *, struct sock___38 *, struct sk_buff___55 *);
	int (*local_out)(struct net___65 *, struct sock___38 *, struct sk_buff___55 *);
	struct neighbour___37 * (*neigh_lookup)(const struct dst_entry___37 *, struct sk_buff___55 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___37 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___64 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___53 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___64 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___37 *fib6_rules_ops;
	struct sock___38 **icmp_sk;
	struct sock___38 *ndisc_sk;
	struct sock___38 *tcp_sk;
	struct sock___38 *igmp_sk;
	struct sock___38 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___37 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___37 *notifier_ops;
	struct fib_notifier_ops___37 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___38 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___38 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___53 {
	struct netns_frags___53 frags;
};

struct netns_xfrm___64 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___38 *nlsk;
	struct sock___38 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___64 xfrm4_dst_ops;
	struct dst_ops___64 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___47;

struct net___65 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___273 *user_ns;
	struct ucounts___273 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___29 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___38 *rtnl;
	struct sock___38 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___54 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___53 ipv4;
	struct netns_ipv6___64 ipv6;
	struct netns_sctp___38 sctp;
	struct netns_nf___3 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___53 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___38 *nfnl;
	struct sock___38 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___64 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___38 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___47 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___376 {
	int (*prepare)(struct device___376 *);
	void (*complete)(struct device___376 *);
	int (*suspend)(struct device___376 *);
	int (*resume)(struct device___376 *);
	int (*freeze)(struct device___376 *);
	int (*thaw)(struct device___376 *);
	int (*poweroff)(struct device___376 *);
	int (*restore)(struct device___376 *);
	int (*suspend_late)(struct device___376 *);
	int (*resume_early)(struct device___376 *);
	int (*freeze_late)(struct device___376 *);
	int (*thaw_early)(struct device___376 *);
	int (*poweroff_late)(struct device___376 *);
	int (*restore_early)(struct device___376 *);
	int (*suspend_noirq)(struct device___376 *);
	int (*resume_noirq)(struct device___376 *);
	int (*freeze_noirq)(struct device___376 *);
	int (*thaw_noirq)(struct device___376 *);
	int (*poweroff_noirq)(struct device___376 *);
	int (*restore_noirq)(struct device___376 *);
	int (*runtime_suspend)(struct device___376 *);
	int (*runtime_resume)(struct device___376 *);
	int (*runtime_idle)(struct device___376 *);
};

struct dev_pm_domain___376 {
	struct dev_pm_ops___376 ops;
	void (*detach)(struct device___376 *, bool);
	int (*activate)(struct device___376 *);
	void (*sync)(struct device___376 *);
	void (*dismiss)(struct device___376 *);
};

struct bus_type___376 {
	const char *name;
	const char *dev_name;
	struct device___376 *dev_root;
	const struct attribute_group___373 **bus_groups;
	const struct attribute_group___373 **dev_groups;
	const struct attribute_group___373 **drv_groups;
	int (*match)(struct device___376 *, struct device_driver___376 *);
	int (*uevent)(struct device___376 *, struct kobj_uevent_env *);
	int (*probe)(struct device___376 *);
	int (*remove)(struct device___376 *);
	void (*shutdown)(struct device___376 *);
	int (*online)(struct device___376 *);
	int (*offline)(struct device___376 *);
	int (*suspend)(struct device___376 *, pm_message_t);
	int (*resume)(struct device___376 *);
	int (*num_vf)(struct device___376 *);
	int (*dma_configure)(struct device___376 *);
	const struct dev_pm_ops___376 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___376 {
	const char *name;
	struct bus_type___376 *bus;
	struct module___338 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___376 *);
	int (*remove)(struct device___376 *);
	void (*shutdown)(struct device___376 *);
	int (*suspend)(struct device___376 *, pm_message_t);
	int (*resume)(struct device___376 *);
	const struct attribute_group___373 **groups;
	const struct dev_pm_ops___376 *pm;
	void (*coredump)(struct device___376 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___376 {
	const char *name;
	const struct attribute_group___373 **groups;
	int (*uevent)(struct device___376 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___376 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___376 *);
	const struct dev_pm_ops___376 *pm;
};

struct class___376 {
	const char *name;
	struct module___338 *owner;
	const struct attribute_group___373 **class_groups;
	const struct attribute_group___373 **dev_groups;
	struct kobject___396 *dev_kobj;
	int (*dev_uevent)(struct device___376 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___376 *, umode_t *);
	void (*class_release)(struct class___376 *);
	void (*dev_release)(struct device___376 *);
	int (*shutdown_pre)(struct device___376 *);
	const struct kobj_ns_type_operations___37 *ns_type;
	const void * (*namespace)(struct device___376 *);
	const struct dev_pm_ops___376 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___148 {
	void * (*alloc)(struct device___376 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___376 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___376 *, struct vm_area_struct___409 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___376 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___376 *, struct page___409 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___376 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___376 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___376 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___376 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___376 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___376 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___376 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___376 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___376 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___376 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___376 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___376 *, u64);
	u64 (*get_required_mask)(struct device___376 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___296;

struct fwnode_handle___296 {
	struct fwnode_handle___296 *secondary;
	const struct fwnode_operations___296 *ops;
};

struct fwnode_reference_args___296;

struct fwnode_endpoint___296;

struct fwnode_operations___296 {
	struct fwnode_handle___296 * (*get)(struct fwnode_handle___296 *);
	void (*put)(struct fwnode_handle___296 *);
	bool (*device_is_available)(const struct fwnode_handle___296 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___296 *, const struct device___376 *);
	bool (*property_present)(const struct fwnode_handle___296 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___296 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___296 *, const char *, const char **, size_t);
	struct fwnode_handle___296 * (*get_parent)(const struct fwnode_handle___296 *);
	struct fwnode_handle___296 * (*get_next_child_node)(const struct fwnode_handle___296 *, struct fwnode_handle___296 *);
	struct fwnode_handle___296 * (*get_named_child_node)(const struct fwnode_handle___296 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___296 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___296 *);
	struct fwnode_handle___296 * (*graph_get_next_endpoint)(const struct fwnode_handle___296 *, struct fwnode_handle___296 *);
	struct fwnode_handle___296 * (*graph_get_remote_endpoint)(const struct fwnode_handle___296 *);
	struct fwnode_handle___296 * (*graph_get_port_parent)(struct fwnode_handle___296 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___296 *, struct fwnode_endpoint___296 *);
};

struct fwnode_endpoint___296 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___296 *local_fwnode;
};

struct fwnode_reference_args___296 {
	struct fwnode_handle___296 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___89;

struct pipe_buffer___89 {
	struct page___409 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___89 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___89 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___89 *, struct pipe_buffer___89 *);
	void (*release)(struct pipe_inode_info___89 *, struct pipe_buffer___89 *);
	int (*steal)(struct pipe_inode_info___89 *, struct pipe_buffer___89 *);
	union {
		bool (*get)(struct pipe_inode_info___89 *, struct pipe_buffer___89 *);
		struct {
			void (*get)(struct pipe_inode_info___89 *, struct pipe_buffer___89 *);
		} __UNIQUE_ID_rh_kabi_hide21;
		union {		};
	};
};

struct nf_bridge_info___53 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___53 = 0,
		BRNF_PROTO_8021Q___53 = 1,
		BRNF_PROTO_PPPOE___53 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___54 *physindev;
	struct net_device___54 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___53(struct sk_buff___55 **);

struct net_device_ops___53;

struct ethtool_ops___53;

struct l3mdev_ops___37;

struct ndisc_ops___20;

struct xfrmdev_ops___53;

struct tlsdev_ops___53;

struct header_ops___53;

struct inet6_dev___20;

struct netdev_rx_queue___53;

struct mini_Qdisc___47;

struct netdev_queue___53;

struct Qdisc___47;

struct rtnl_link_ops___47;

struct dcbnl_rtnl_ops___53;

struct net_device___54 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___53 *netdev_ops;
	const struct ethtool_ops___53 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___37 *l3mdev_ops;
	const struct ndisc_ops___20 *ndisc_ops;
	const struct xfrmdev_ops___53 *xfrmdev_ops;
	const struct tlsdev_ops___53 *tlsdev_ops;
	const struct header_ops___53 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___395 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___20 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___53 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___47 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___53 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___47 *miniq_ingress;
	struct netdev_queue___53 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___53 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___47 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___47 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___53 = 0,
		NETREG_REGISTERED___53 = 1,
		NETREG_UNREGISTERING___53 = 2,
		NETREG_UNREGISTERED___53 = 3,
		NETREG_RELEASED___53 = 4,
		NETREG_DUMMY___53 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___53 = 0,
		RTNL_LINK_INITIALIZING___53 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___54 *);
	struct netpoll_info *npinfo;
	possible_net_t___55 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___376 dev;
	const struct attribute_group___373 *sysfs_groups[4];
	const struct attribute_group___373 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___47 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___53 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide35;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct ethtool_ops___53 {
	int (*get_settings)(struct net_device___54 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___54 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___54 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___54 *);
	void (*get_regs)(struct net_device___54 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___54 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___54 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___54 *);
	void (*set_msglevel)(struct net_device___54 *, u32);
	int (*nway_reset)(struct net_device___54 *);
	u32 (*get_link)(struct net_device___54 *);
	int (*get_eeprom_len)(struct net_device___54 *);
	int (*get_eeprom)(struct net_device___54 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___54 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___54 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___54 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___54 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___54 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___54 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___54 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___54 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___54 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___54 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___54 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___54 *);
	void (*complete)(struct net_device___54 *);
	u32 (*get_priv_flags)(struct net_device___54 *);
	int (*set_priv_flags)(struct net_device___54 *, u32);
	int (*get_sset_count)(struct net_device___54 *, int);
	int (*get_rxnfc)(struct net_device___54 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___54 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___54 *, struct ethtool_flash *);
	int (*reset)(struct net_device___54 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___54 *);
	u32 (*get_rxfh_indir_size)(struct net_device___54 *);
	int (*get_rxfh)(struct net_device___54 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___54 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___54 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___54 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___54 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___54 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___54 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___54 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___54 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___54 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___54 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___54 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___54 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___54 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___54 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___54 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___54 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___54 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___54 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___54 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___54 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___54 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	int (*get_fecparam)(struct net_device___54 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___54 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___54 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___54 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___54 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___53;

struct inet_frags___53 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___53 *, const void *);
	void (*destructor)(struct inet_frag_queue___53 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___53 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___55 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___55 *fragments_tail;
	struct sk_buff___55 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___53 *net;
	struct callback_head rcu;
};

struct ip_ra_chain___17 {
	struct ip_ra_chain___17 *next;
	struct sock___38 *sk;
	union {
		void (*destructor)(struct sock___38 *);
		struct sock___38 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___37;

struct fib_lookup_arg___37;

struct fib_rules_ops___37 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___37 *, struct flowi *, int, struct fib_lookup_arg___37 *);
	bool (*suppress)(struct fib_rule___37 *, struct fib_lookup_arg___37 *);
	int (*match)(struct fib_rule___37 *, struct flowi *, int);
	int (*configure)(struct fib_rule___37 *, struct sk_buff___55 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___37 *);
	int (*compare)(struct fib_rule___37 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___37 *, struct sk_buff___55 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___37 *);
	void (*flush_cache)(struct fib_rules_ops___37 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___338 *owner;
	struct net___65 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___37 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___65 *);
	int (*fib_dump)(struct net___65 *, struct notifier_block *);
	struct module___338 *owner;
	struct callback_head rcu;
};

struct dst_entry___37 {
	struct net_device___54 *dev;
	struct dst_ops___64 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___55 *);
	int (*output)(struct net___65 *, struct sock___38 *, struct sk_buff___55 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___37;

struct neigh_parms___37;

struct neigh_ops___37;

struct neighbour___37 {
	struct neighbour___37 *next;
	struct neigh_table___37 *tbl;
	struct neigh_parms___37 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___53 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___37 *, struct sk_buff___55 *);
	const struct neigh_ops___37 *ops;
	struct callback_head rcu;
	struct net_device___54 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct ucounts___273 {
	struct hlist_node node;
	struct user_namespace___273 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_prog_aux___50;

struct bpf_prog___47 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___50 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

typedef int (*key_restrict_link_func_t___377)(struct key___376 *, const struct key_type *, const union key_payload *, struct key___376 *);

struct key_restriction___376;

struct key___376 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___410 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___376 *restrict_link;
};

struct key_restriction___376 {
	key_restrict_link_func_t___377 check;
	struct key___376 *key;
	struct key_type *keytype;
};

struct seq_operations___347 {
	void * (*start)(struct seq_file___347 *, loff_t *);
	void (*stop)(struct seq_file___347 *, void *);
	void * (*next)(struct seq_file___347 *, void *, loff_t *);
	int (*show)(struct seq_file___347 *, void *);
};

struct pernet_operations___54 {
	struct list_head list;
	int (*init)(struct net___65 *);
	void (*exit)(struct net___65 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___53 {
	int (*ieee_getets)(struct net_device___54 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___54 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___54 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___54 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___54 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___54 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___54 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___54 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___54 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___54 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___54 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___54 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___54 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___54 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___54 *);
	u8 (*setstate)(struct net_device___54 *, u8);
	void (*getpermhwaddr)(struct net_device___54 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___54 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___54 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___54 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___54 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___54 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___54 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___54 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___54 *, int, u8 *);
	void (*setpfccfg)(struct net_device___54 *, int, u8);
	void (*getpfccfg)(struct net_device___54 *, int, u8 *);
	u8 (*setall)(struct net_device___54 *);
	u8 (*getcap)(struct net_device___54 *, int, u8 *);
	int (*getnumtcs)(struct net_device___54 *, int, u8 *);
	int (*setnumtcs)(struct net_device___54 *, int, u8);
	u8 (*getpfcstate)(struct net_device___54 *);
	void (*setpfcstate)(struct net_device___54 *, u8);
	void (*getbcncfg)(struct net_device___54 *, int, u32 *);
	void (*setbcncfg)(struct net_device___54 *, int, u32);
	void (*getbcnrp)(struct net_device___54 *, int, u8 *);
	void (*setbcnrp)(struct net_device___54 *, int, u8);
	int (*setapp)(struct net_device___54 *, u8, u16, u8);
	int (*getapp)(struct net_device___54 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___54 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___54 *, int, u8);
	u8 (*getdcbx)(struct net_device___54 *);
	u8 (*setdcbx)(struct net_device___54 *, u8);
	int (*peer_getappinfo)(struct net_device___54 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___54 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___54 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___54 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___54 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___54 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___257 {
	refcount_t count;
	struct ns_common___29 ns;
	struct user_namespace___273 *user_ns;
	struct ucounts___273 *ucounts;
	struct css_set___257 *root_cset;
};

struct bpf_map___258;

struct bpf_map_ops___257 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___258 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___258 *, struct file___408 *);
	void (*map_free)(struct bpf_map___258 *);
	int (*map_get_next_key)(struct bpf_map___258 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___258 *);
	void * (*map_lookup_elem)(struct bpf_map___258 *, void *);
	int (*map_update_elem)(struct bpf_map___258 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___258 *, void *);
	int (*map_push_elem)(struct bpf_map___258 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___258 *, void *);
	int (*map_peek_elem)(struct bpf_map___258 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___258 *, struct file___408 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___258 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___258 *, void *, struct seq_file___347 *);
	int (*map_check_btf)(const struct bpf_map___258 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___258 {
	const struct bpf_map_ops___257 *ops;
	struct bpf_map___258 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___376 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___53;

struct bpf_map_dev_ops___53 {
	int (*map_get_next_key)(struct bpf_offloaded_map___53 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___53 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___53 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___53 *, void *);
};

struct bpf_offloaded_map___53 {
	struct bpf_map___258 map;
	struct net_device___54 *netdev;
	const struct bpf_map_dev_ops___53 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___47 {
	int (*test_run)(struct bpf_prog___47 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___47 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___47 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___47 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___47 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___47 *, u32 *);
};

struct bpf_prog_offload_ops___47 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___47 *);
	int (*translate)(struct bpf_prog___47 *);
	void (*destroy)(struct bpf_prog___47 *);
};

struct bpf_prog_offload___47 {
	struct bpf_prog___47 *prog;
	struct net_device___54 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___47 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___50 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___47 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___47 *ops;
	struct bpf_map___258 **used_maps;
	struct bpf_prog___47 *prog;
	struct user_struct___376 *user;
	u64 load_time;
	struct bpf_map___258 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___47 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___47 {
	struct bpf_prog___47 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___47 {
	struct callback_head rcu;
	struct bpf_prog_array_item___47 items[0];
};

struct cgroup_bpf___47 {
	struct bpf_prog_array___47 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___47 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___258;

typedef void (*kthread_work_func_t___258)(struct kthread_work___258 *);

struct kthread_worker___258;

struct kthread_work___258 {
	struct list_head node;
	kthread_work_func_t___258 func;
	struct kthread_worker___258 *worker;
	int canceling;
};

struct kthread_worker___258 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___410 *task;
	struct kthread_work___258 *current_work;
};

struct kthread_delayed_work___257 {
	struct kthread_work___258 work;
	struct timer_list timer;
};

struct psi_group___257 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___258 *poll_kworker;
	struct kthread_delayed_work___257 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___257;

struct cgroup_rstat_cpu___257;

struct cgroup___257 {
	struct cgroup_subsys_state___257 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___403 *kn;
	struct cgroup_file___257 procs_file;
	struct cgroup_file___257 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___257 *subsys[13];
	struct cgroup_root___257 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___257 *dom_cgrp;
	struct cgroup_rstat_cpu___257 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___47 bpf;
	atomic_t congestion_count;
	struct cgroup___257 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___257 psi;
	int ancestor_ids[0];
};

struct cftype___257;

struct cgroup_subsys___257 {
	struct cgroup_subsys_state___257 * (*css_alloc)(struct cgroup_subsys_state___257 *);
	int (*css_online)(struct cgroup_subsys_state___257 *);
	void (*css_offline)(struct cgroup_subsys_state___257 *);
	void (*css_released)(struct cgroup_subsys_state___257 *);
	void (*css_free)(struct cgroup_subsys_state___257 *);
	void (*css_reset)(struct cgroup_subsys_state___257 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___257 *, int);
	int (*css_extra_stat_show)(struct seq_file___347 *, struct cgroup_subsys_state___257 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___410 *);
	void (*cancel_fork)(struct task_struct___410 *);
	void (*fork)(struct task_struct___410 *);
	void (*exit)(struct task_struct___410 *);
	void (*free)(struct task_struct___410 *);
	void (*bind)(struct cgroup_subsys_state___257 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___257 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___257 *dfl_cftypes;
	struct cftype___257 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___257 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___257 *updated_children;
	struct cgroup___257 *updated_next;
};

struct cgroup_root___257 {
	struct kernfs_root___402 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___257 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___257 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___257 *ss;
	struct list_head node;
	struct kernfs_ops___402 *kf_ops;
	int (*open)(struct kernfs_open_file___402 *);
	void (*release)(struct kernfs_open_file___402 *);
	u64 (*read_u64)(struct cgroup_subsys_state___257 *, struct cftype___257 *);
	s64 (*read_s64)(struct cgroup_subsys_state___257 *, struct cftype___257 *);
	int (*seq_show)(struct seq_file___347 *, void *);
	void * (*seq_start)(struct seq_file___347 *, loff_t *);
	void * (*seq_next)(struct seq_file___347 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___347 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___257 *, struct cftype___257 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___257 *, struct cftype___257 *, s64);
	ssize_t (*write)(struct kernfs_open_file___402 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___402 *, struct poll_table_struct___251 *);
};

struct xdp_rxq_info___53 {
	struct net_device___54 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___53 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___54 *dev_rx;
};

struct netlink_callback___55 {
	struct sk_buff___55 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___55 *);
	int (*dump)(struct sk_buff___55 *, struct netlink_callback___55 *);
	int (*done)(struct netlink_callback___55 *);
	void *data;
	struct module___338 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___53 {
	int (*create)(struct sk_buff___55 *, struct net_device___54 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___55 *, unsigned char *);
	int (*cache)(const struct neighbour___37 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___54 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___53 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___53 *, int);
	int poll_owner;
	struct net_device___54 *dev;
	struct sk_buff___55 *gro_list;
	struct sk_buff___55 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___53 {
	struct net_device___54 *dev;
	struct Qdisc___47 *qdisc;
	struct Qdisc___47 *qdisc_sleeping;
	struct kobject___396 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___54 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___47 {
	struct sk_buff___55 *head;
	struct sk_buff___55 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___47;

struct Qdisc___47 {
	int (*enqueue)(struct sk_buff___55 *, struct Qdisc___47 *, struct sk_buff___55 **);
	struct sk_buff___55 * (*dequeue)(struct Qdisc___47 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___47 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___53 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___53 gso_skb;
	struct qdisc_skb_head___47 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___47 *next_sched;
	struct sk_buff_head___53 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___53 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___396 kobj;
	struct net_device___54 *dev;
	long: 64;
	struct xdp_rxq_info___53 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___53)(struct net_device___54 *, struct sk_buff___55 *, struct net_device___54 *);

struct netdev_bpf___53 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___47 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___47 *prog;
			const struct bpf_prog_offload_ops___47 *ops;
		} verifier;
		struct {
			struct bpf_prog___47 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___53 *offmap;
		};
		struct {
			struct xdp_umem *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___53 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___55 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___53 {
	int (*tls_dev_add)(struct net_device___54 *, struct sock___38 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___54 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___54 *, struct sock___38 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___53 {
	int (*ndo_init)(struct net_device___54 *);
	void (*ndo_uninit)(struct net_device___54 *);
	int (*ndo_open)(struct net_device___54 *);
	int (*ndo_stop)(struct net_device___54 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___55 *, struct net_device___54 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___55 *, struct net_device___54 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___54 *, struct sk_buff___55 *, struct net_device___54 *, select_queue_fallback_t___53);
	void (*ndo_change_rx_flags)(struct net_device___54 *, int);
	void (*ndo_set_rx_mode)(struct net_device___54 *);
	int (*ndo_set_mac_address)(struct net_device___54 *, void *);
	int (*ndo_validate_addr)(struct net_device___54 *);
	int (*ndo_do_ioctl)(struct net_device___54 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___54 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___54 *, int);
	int (*ndo_neigh_setup)(struct net_device___54 *, struct neigh_parms___37 *);
	void (*ndo_tx_timeout)(struct net_device___54 *);
	void (*ndo_get_stats64)(struct net_device___54 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___54 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___54 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___54 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___54 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___54 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___54 *);
	int (*ndo_netpoll_setup)(struct net_device___54 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___54 *);
	int (*ndo_set_vf_mac)(struct net_device___54 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___54 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___54 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___54 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___54 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___54 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___54 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___54 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___54 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___54 *, int, struct sk_buff___55 *);
	int (*ndo_set_vf_guid)(struct net_device___54 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___54 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___54 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___54 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___54 *, const struct sk_buff___55 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___54 *, struct net_device___54 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___54 *, struct net_device___54 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___54 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___54 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___54 *, struct neighbour___37 *);
	void (*ndo_neigh_destroy)(struct net_device___54 *, struct neighbour___37 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___54 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___54 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___54 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___55 *, struct netlink_callback___55 *, struct net_device___54 *, struct net_device___54 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___54 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___54 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___55 *, u32, u32, struct net_device___54 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___54 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___54 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___54 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___54 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___54 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___54 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___54 *, struct net_device___54 *);
	void (*ndo_dfwd_del_station)(struct net_device___54 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___54 *);
	int (*ndo_set_tx_maxrate)(struct net_device___54 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___54 *);
	int (*ndo_change_proto_down)(struct net_device___54 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___54 *, struct sk_buff___55 *);
	void (*ndo_set_rx_headroom)(struct net_device___54 *, int);
	int (*ndo_bpf)(struct net_device___54 *, struct netdev_bpf___53 *);
	int (*ndo_xdp_xmit)(struct net_device___54 *, int, struct xdp_frame___53 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___54 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___54 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___37 {
	possible_net_t___55 net;
	struct net_device___54 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___37 *);
	void (*neigh_cleanup)(struct neighbour___37 *);
	struct neigh_table___37 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___37 {
	u32 (*l3mdev_fib_table)(const struct net_device___54 *);
	struct sk_buff___55 * (*l3mdev_l3_rcv)(struct net_device___54 *, struct sk_buff___55 *, u16);
	struct sk_buff___55 * (*l3mdev_l3_out)(struct net_device___54 *, struct sock___38 *, struct sk_buff___55 *, u16);
	struct dst_entry___37 * (*l3mdev_link_scope_lookup)(const struct net_device___54 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct ndisc_ops___20 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___54 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___54 *, struct neighbour___37 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___54 *, u8, struct neighbour___37 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___54 *, struct sk_buff___55 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___65 *, struct net_device___54 *, const struct prefix_info *, struct inet6_dev___20 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___20;

struct inet6_dev___20 {
	struct net_device___54 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___20 *mc_list;
	struct ifmcaddr6___20 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___4 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	u8 rndid[8];
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___37 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
};

struct tcf_proto___47;

struct mini_Qdisc___47 {
	struct tcf_proto___47 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___47 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___54 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___65 *, struct net_device___54 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___54 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___54 *, struct list_head *);
	size_t (*get_size)(const struct net_device___54 *);
	int (*fill_info)(struct sk_buff___55 *, const struct net_device___54 *);
	size_t (*get_xstats_size)(const struct net_device___54 *);
	int (*fill_xstats)(struct sk_buff___55 *, const struct net_device___54 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___54 *, struct net_device___54 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___54 *, const struct net_device___54 *);
	int (*fill_slave_info)(struct sk_buff___55 *, const struct net_device___54 *, const struct net_device___54 *);
	struct net___65 * (*get_link_net)(const struct net_device___54 *);
	size_t (*get_linkxstats_size)(const struct net_device___54 *, int);
	int (*fill_linkxstats)(struct sk_buff___55 *, const struct net_device___54 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___53 {
	struct list_head poll_list;
	struct sk_buff_head___53 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___53 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___47 *output_queue;
	struct Qdisc___47 **output_queue_tailp;
	struct sk_buff___55 *completion_queue;
	struct sk_buff_head___53 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___53 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___53 input_pkt_queue;
	struct napi_struct___53 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bdi_writeback_congested___202 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___202 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___202 {
	struct bio___202 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___204 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___204 bip_inline_vecs[0];
};

struct bio_set___202 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___202 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___145 {
	struct mem_cgroup___145 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___145 {
	struct lruvec___409 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___145 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___145 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct gnet_dump___47 {
	spinlock_t *lock;
	struct sk_buff___55 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___47;

struct Qdisc_ops___47 {
	struct Qdisc_ops___47 *next;
	const struct Qdisc_class_ops___47 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___55 *, struct Qdisc___47 *, struct sk_buff___55 **);
	struct sk_buff___55 * (*dequeue)(struct Qdisc___47 *);
	struct sk_buff___55 * (*peek)(struct Qdisc___47 *);
	int (*init)(struct Qdisc___47 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___47 *);
	void (*destroy)(struct Qdisc___47 *);
	int (*change)(struct Qdisc___47 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___47 *);
	int (*change_tx_queue_len)(struct Qdisc___47 *, unsigned int);
	int (*dump)(struct Qdisc___47 *, struct sk_buff___55 *);
	int (*dump_stats)(struct Qdisc___47 *, struct gnet_dump___47 *);
	void (*ingress_block_set)(struct Qdisc___47 *, u32);
	void (*egress_block_set)(struct Qdisc___47 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___47 *);
	u32 (*egress_block_get)(struct Qdisc___47 *);
	struct module___338 *owner;
};

struct qdisc_walker___2;

struct tcf_block___47;

struct Qdisc_class_ops___47 {
	unsigned int flags;
	struct netdev_queue___53 * (*select_queue)(struct Qdisc___47 *, struct tcmsg *);
	int (*graft)(struct Qdisc___47 *, long unsigned int, struct Qdisc___47 *, struct Qdisc___47 **, struct netlink_ext_ack *);
	struct Qdisc___47 * (*leaf)(struct Qdisc___47 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___47 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___47 *, u32);
	int (*change)(struct Qdisc___47 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___47 *, long unsigned int);
	void (*walk)(struct Qdisc___47 *, struct qdisc_walker___2 *);
	struct tcf_block___47 * (*tcf_block)(struct Qdisc___47 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___47 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___47 *, long unsigned int);
	int (*dump)(struct Qdisc___47 *, long unsigned int, struct sk_buff___55 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___47 *, long unsigned int, struct gnet_dump___47 *);
};

struct qdisc_walker___2 {
	int stop;
	int skip;
	int count;
	int (*fn)(struct Qdisc___47 *, long unsigned int, struct qdisc_walker___2 *);
};

struct tcf_chain___47;

struct tcf_block___47 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___65 *net;
	struct Qdisc___47 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___47 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___47;

struct tcf_proto_ops___47;

struct tcf_proto___47 {
	struct tcf_proto___47 *next;
	void *root;
	int (*classify)(struct sk_buff___55 *, const struct tcf_proto___47 *, struct tcf_result___47 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___47 *ops;
	struct tcf_chain___47 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___47 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___47 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___47 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___55 *, const struct tcf_proto___47 *, struct tcf_result___47 *);
	int (*init)(struct tcf_proto___47 *);
	void (*destroy)(struct tcf_proto___47 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___47 *, u32);
	void (*put)(struct tcf_proto___47 *, void *);
	int (*change)(struct net___65 *, struct sk_buff___55 *, struct tcf_proto___47 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___47 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___47 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___47 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___65 *, struct tcf_chain___47 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___65 *, struct tcf_proto___47 *, void *, struct sk_buff___55 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___55 *, struct net___65 *, void *);
	struct module___338 *owner;
	int flags;
};

struct tcf_chain___47 {
	struct mutex filter_chain_lock;
	struct tcf_proto___47 *filter_chain;
	struct list_head list;
	struct tcf_block___47 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___47 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___37 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___47 *prog;
};

struct bpf_redirect_info___47 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___258 *map;
	struct bpf_map___258 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___37;

struct neigh_hash_table___37;

struct neigh_table___37 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___54 *, __u32 *);
	bool (*key_eq)(const struct neighbour___37 *, const void *);
	int (*constructor)(struct neighbour___37 *);
	int (*pconstructor)(struct pneigh_entry___37 *);
	void (*pdestructor)(struct pneigh_entry___37 *);
	void (*proxy_redo)(struct sk_buff___55 *);
	char *id;
	struct neigh_parms___37 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___53 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___37 *nht;
	struct pneigh_entry___37 **phash_buckets;
};

struct neigh_ops___37 {
	int family;
	void (*solicit)(struct neighbour___37 *, struct sk_buff___55 *);
	void (*error_report)(struct neighbour___37 *, struct sk_buff___55 *);
	int (*output)(struct neighbour___37 *, struct sk_buff___55 *);
	int (*connected_output)(struct neighbour___37 *, struct sk_buff___55 *);
};

struct pneigh_entry___37 {
	struct pneigh_entry___37 *next;
	possible_net_t___55 net;
	struct net_device___54 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___37 {
	struct neighbour___37 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___37 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___37 *ctarget;
	struct net___65 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___37 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___37 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___24;

struct timewait_sock_ops___22;

struct proto___37 {
	void (*close)(struct sock___38 *, long int);
	int (*pre_connect)(struct sock___38 *, struct sockaddr *, int);
	int (*connect)(struct sock___38 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___38 *, int);
	struct sock___38 * (*accept)(struct sock___38 *, int, int *, bool);
	int (*ioctl)(struct sock___38 *, int, long unsigned int);
	int (*init)(struct sock___38 *);
	void (*destroy)(struct sock___38 *);
	void (*shutdown)(struct sock___38 *, int);
	int (*setsockopt)(struct sock___38 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___38 *, int, int, char *, int *);
	void (*keepalive)(struct sock___38 *, int);
	int (*sendmsg)(struct sock___38 *, struct msghdr___40 *, size_t);
	int (*recvmsg)(struct sock___38 *, struct msghdr___40 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___38 *, struct page___409 *, int, size_t, int);
	int (*bind)(struct sock___38 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___38 *, struct sk_buff___55 *);
	void (*release_cb)(struct sock___38 *);
	int (*hash)(struct sock___38 *);
	void (*unhash)(struct sock___38 *);
	void (*rehash)(struct sock___38 *);
	int (*get_port)(struct sock___38 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___38 *);
	bool (*stream_memory_read)(const struct sock___38 *);
	void (*enter_memory_pressure)(struct sock___38 *);
	void (*leave_memory_pressure)(struct sock___38 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___24 *rsk_prot;
	struct timewait_sock_ops___22 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___338 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___38 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct request_sock___25;

struct request_sock_ops___24 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___38 *, struct request_sock___25 *);
	void (*send_ack)(const struct sock___38 *, struct sk_buff___55 *, struct request_sock___25 *);
	void (*send_reset)(const struct sock___38 *, struct sk_buff___55 *);
	void (*destructor)(struct request_sock___25 *);
	void (*syn_ack_timeout)(const struct request_sock___25 *);
};

struct timewait_sock_ops___22 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___38 *, struct sock___38 *, void *);
	void (*twsk_destructor)(struct sock___38 *);
};

struct request_sock___25 {
	struct sock_common___37 __req_common;
	struct request_sock___25 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___24 *rsk_ops;
	struct sock___38 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___20 {
	struct in6_addr mca_addr;
	struct inet6_dev___20 *idev;
	struct ifmcaddr6___20 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ip6_ra_chain___20 {
	struct ip6_ra_chain___20 *next;
	struct sock___38 *sk;
	int sel;
	void (*destructor)(struct sock___38 *);
};

struct module___339;

struct file___409;

struct kiocb___409;

struct iov_iter___176;

struct poll_table_struct___252;

struct vm_area_struct___410;

struct inode___409;

struct file_lock___409;

struct page___410;

struct pipe_inode_info___90;

struct seq_file___348;

struct file_operations___409 {
	struct module___339 *owner;
	loff_t (*llseek)(struct file___409 *, loff_t, int);
	ssize_t (*read)(struct file___409 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___409 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___409 *, struct iov_iter___176 *);
	ssize_t (*write_iter)(struct kiocb___409 *, struct iov_iter___176 *);
	int (*iopoll)(struct kiocb___409 *, bool);
	int (*iterate)(struct file___409 *, struct dir_context *);
	int (*iterate_shared)(struct file___409 *, struct dir_context *);
	__poll_t (*poll)(struct file___409 *, struct poll_table_struct___252 *);
	long int (*unlocked_ioctl)(struct file___409 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___409 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___409 *, struct vm_area_struct___410 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___409 *, struct file___409 *);
	int (*flush)(struct file___409 *, fl_owner_t);
	int (*release)(struct inode___409 *, struct file___409 *);
	int (*fsync)(struct file___409 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___409 *, int);
	int (*lock)(struct file___409 *, int, struct file_lock___409 *);
	ssize_t (*sendpage)(struct file___409 *, struct page___410 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___409 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___409 *, int, struct file_lock___409 *);
	ssize_t (*splice_write)(struct pipe_inode_info___90 *, struct file___409 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___409 *, loff_t *, struct pipe_inode_info___90 *, size_t, unsigned int);
	int (*setlease)(struct file___409 *, long int, struct file_lock___409 **, void **);
	long int (*fallocate)(struct file___409 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___348 *, struct file___409 *);
	ssize_t (*copy_file_range)(struct file___409 *, loff_t, struct file___409 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___409 *, loff_t, struct file___409 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___409 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___410 {
	u64 seqnum;
	struct vm_area_struct___410 *vmas[4];
};

struct page_frag___410 {
	struct page___410 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___410;

struct mem_cgroup___146;

struct pid___234;

struct cred___377;

struct nsproxy___304;

struct signal_struct___284;

struct bio_list___203;

struct backing_dev_info___203;

struct css_set___258;

struct vm_struct___313;

struct task_struct___411 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___411 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___410 *mm;
	struct mm_struct___410 *active_mm;
	struct vmacache___410 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___411 *real_parent;
	struct task_struct___411 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___411 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___146 *active_memcg;
	long int rh_reserved2;
	struct pid___234 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___234 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___234 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___377 *ptracer_cred;
	const struct cred___377 *real_cred;
	const struct cred___377 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___304 *nsproxy;
	struct signal_struct___284 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___411 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___203 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___203 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___258 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___90 *splice_pipe;
	struct page_frag___410 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___146 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___411 *oom_reaper_list;
	struct vm_struct___313 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___154 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___234;

struct upid___234 {
	int nr;
	struct pid_namespace___234 *ns;
};

struct dentry___409;

struct user_namespace___274;

struct ucounts___274;

struct pid_namespace___234 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___411 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___234 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___409 *proc_self;
	struct dentry___409 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___274 *user_ns;
	struct ucounts___274 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___29 ns;
};

struct pid___234 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___234 numbers[1];
};

struct rw_semaphore___411 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___411 *owner;
};

struct key___377;

struct user_namespace___274 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___274 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___29 ns;
	long unsigned int flags;
	struct key___377 *persistent_keyring_register;
	struct rw_semaphore___411 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___274 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct secondary_data___411 {
	void *stack;
	struct task_struct___411 *task;
	long int status;
};

typedef struct page___410 *pgtable_t___410;

struct address_space___409;

struct dev_pagemap___397;

struct page___410 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___409 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___410 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___410 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___410 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___397 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___146 *mem_cgroup;
};

struct user_struct___377 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___377 *uid_keyring;
	struct key___377 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___397;

struct vm_area_struct___410 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___410 *vm_next;
	struct vm_area_struct___410 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___410 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___397 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___409 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___410;

struct mm_struct___410 {
	struct {
		struct vm_area_struct___410 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___409 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___411 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___410 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___411 *owner;
		struct user_namespace___274 *user_ns;
		struct file___409 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___410 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup___258;

struct cgroup_subsys___258;

struct cgroup_subsys_state___258 {
	struct cgroup___258 *cgroup;
	struct cgroup_subsys___258 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___258 *parent;
};

struct kernfs_node___404;

struct cgroup_file___258 {
	struct kernfs_node___404 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___146;

struct mem_cgroup___146 {
	struct cgroup_subsys_state___258 css;
	struct mem_cgroup_id___21 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___258 events_file;
	struct cgroup_file___258 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___411 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___146 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cred___377 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___377 *session_keyring;
	struct key___377 *process_keyring;
	struct key___377 *thread_keyring;
	struct key___377 *request_key_auth;
	void *security;
	struct user_struct___377 *user;
	struct user_namespace___274 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___66;

struct cgroup_namespace___258;

struct nsproxy___304 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___234 *pid_ns_for_children;
	struct net___66 *net_ns;
	struct cgroup_namespace___258 *cgroup_ns;
};

struct signal_struct___284 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___411 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___411 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___234 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___234 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___410 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___234 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___203;

struct bio_list___203 {
	struct bio___203 *head;
	struct bio___203 *tail;
};

struct bdi_writeback_congested___203;

struct bdi_writeback___203 {
	struct backing_dev_info___203 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___203 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___258 *memcg_css;
	struct cgroup_subsys_state___258 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___377;

struct backing_dev_info___203 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___203 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___377 *dev;
	struct device___377 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___409 *debug_dir;
	struct dentry___409 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___258 {
	struct cgroup_subsys_state___258 *subsys[13];
	refcount_t refcount;
	struct css_set___258 *dom_cset;
	struct cgroup___258 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___258 *mg_src_cgrp;
	struct cgroup___258 *mg_dst_cgrp;
	struct css_set___258 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___409;

struct pipe_buffer___90;

struct pipe_inode_info___90 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___410 *tmp_page;
	struct fasync_struct___409 *fasync_readers;
	struct fasync_struct___409 *fasync_writers;
	struct pipe_buffer___90 *bufs;
	struct user_struct___377 *user;
};

struct vm_struct___313 {
	struct vm_struct___313 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___410 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___296 {
	struct task_struct___411 task;
	long unsigned int stack[8192];
};

struct address_space_operations___409;

struct address_space___409 {
	struct inode___409 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___411 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___409 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___397)(struct vm_area_struct___410 *, long unsigned int, const struct page___410 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___397)(struct page___410 *, void *);

struct dev_pagemap___397 {
	dev_page_fault_t___397 page_fault;
	dev_page_free_t___397 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___377 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___410 {
	struct vfsmount *mnt;
	struct dentry___409 *dentry;
};

struct fown_struct___234 {
	rwlock_t lock;
	struct pid___234 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___409 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___410 f_path;
	struct inode___409 *f_inode;
	const struct file_operations___409 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___234 f_owner;
	const struct cred___377 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___409 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___397;

struct vm_operations_struct___397 {
	void (*open)(struct vm_area_struct___410 *);
	void (*close)(struct vm_area_struct___410 *);
	int (*split)(struct vm_area_struct___410 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___410 *);
	vm_fault_t (*fault)(struct vm_fault___397 *);
	vm_fault_t (*huge_fault)(struct vm_fault___397 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___397 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___410 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___397 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___397 *);
	int (*access)(struct vm_area_struct___410 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___410 *);
	int (*set_policy)(struct vm_area_struct___410 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___410 *, long unsigned int);
	struct page___410 * (*find_special_page)(struct vm_area_struct___410 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___410 {
	struct task_struct___411 *task;
	struct core_thread___410 *next;
};

struct core_state___410 {
	atomic_t nr_threads;
	struct core_thread___410 dumper;
	struct completion startup;
};

struct vm_fault___397 {
	struct vm_area_struct___410 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___410 *cow_page;
	struct mem_cgroup___146 *memcg;
	struct page___410 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___410 prealloc_pte;
};

struct pglist_data___410;

struct lruvec___410 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___410 *pgdat;
};

struct zone___410 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___410 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___410 {
	struct zone___410 *zone;
	int zone_idx;
};

struct zonelist___410 {
	struct zoneref___410 _zonerefs[25];
};

struct pglist_data___410 {
	struct zone___410 node_zones[3];
	struct zonelist___410 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___411 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___411 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___410 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___410 {
	struct rw_semaphore___411 rwsem;
	struct notifier_block *head;
};

struct kernfs_root___403;

struct kernfs_elem_dir___403 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___403 *root;
};

struct kernfs_syscall_ops___403;

struct kernfs_root___403 {
	struct kernfs_node___404 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___403 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___403 {
	struct kernfs_node___404 *target_kn;
};

struct kernfs_ops___403;

struct kernfs_elem_attr___403 {
	const struct kernfs_ops___403 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___404 *notify_next;
};

struct kernfs_node___404 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___404 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___403 dir;
		struct kernfs_elem_symlink___403 symlink;
		struct kernfs_elem_attr___403 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___403;

struct kernfs_ops___403 {
	int (*open)(struct kernfs_open_file___403 *);
	void (*release)(struct kernfs_open_file___403 *);
	int (*seq_show)(struct seq_file___348 *, void *);
	void * (*seq_start)(struct seq_file___348 *, loff_t *);
	void * (*seq_next)(struct seq_file___348 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___348 *, void *);
	ssize_t (*read)(struct kernfs_open_file___403 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___403 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___403 *, struct vm_area_struct___410 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___403 *, struct poll_table_struct___252 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___403 {
	int (*remount_fs)(struct kernfs_root___403 *, int *, char *);
	int (*show_options)(struct seq_file___348 *, struct kernfs_root___403 *);
	int (*mkdir)(struct kernfs_node___404 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___404 *);
	int (*rename)(struct kernfs_node___404 *, struct kernfs_node___404 *, const char *);
	int (*show_path)(struct seq_file___348 *, struct kernfs_node___404 *, struct kernfs_root___403 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___348;

struct seq_file___348 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___348 *op;
	int poll_event;
	const struct file___409 *file;
	void *private;
};

struct kernfs_open_file___403 {
	struct kernfs_node___404 *kn;
	struct file___409 *file;
	struct seq_file___348 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___397 *vm_ops;
};

typedef void (*poll_queue_proc___262)(struct file___409 *, wait_queue_head_t *, struct poll_table_struct___252 *);

struct poll_table_struct___252 {
	poll_queue_proc___262 _qproc;
	__poll_t _key;
};

struct sock___39;

struct kobj_ns_type_operations___38 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___39 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___66 *net;
} possible_net_t___56;

struct proto___38;

struct sock_common___38 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___38 *skc_prot;
	possible_net_t___56 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___39 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___56;

struct sk_buff_head___54 {
	struct sk_buff___56 *next;
	struct sk_buff___56 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___38;

struct socket_wq___39;

struct xfrm_policy___4;

struct dst_entry___38;

struct socket___40;

struct net_device___55;

struct sock___39 {
	struct sock_common___38 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___54 sk_error_queue;
	struct sk_buff_head___54 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___56 *head;
		struct sk_buff___56 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___38 *sk_filter;
	union {
		struct socket_wq___39 *sk_wq;
		struct socket_wq___39 *sk_wq_raw;
	};
	struct xfrm_policy___4 *sk_policy[2];
	struct dst_entry___38 *sk_rx_dst;
	struct dst_entry___38 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___56 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___54 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___410 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___38 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___234 *sk_peer_pid;
	const struct cred___377 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___40 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___146 *sk_memcg;
	void (*sk_state_change)(struct sock___39 *);
	void (*sk_data_ready)(struct sock___39 *);
	void (*sk_write_space)(struct sock___39 *);
	void (*sk_error_report)(struct sock___39 *);
	int (*sk_backlog_rcv)(struct sock___39 *, struct sk_buff___56 *);
	struct sk_buff___56 * (*sk_validate_xmit_skb)(struct sock___39 *, struct net_device___55 *, struct sk_buff___56 *);
	void (*sk_destruct)(struct sock___39 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kobject___397;

struct bin_attribute___373;

struct attribute_group___374 {
	const char *name;
	umode_t (*is_visible)(struct kobject___397 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___397 *, struct bin_attribute___373 *, int);
	struct attribute **attrs;
	struct bin_attribute___373 **bin_attrs;
};

struct kset___396;

struct kobj_type___396;

struct kobject___397 {
	const char *name;
	struct list_head entry;
	struct kobject___397 *parent;
	struct kset___396 *kset;
	struct kobj_type___396 *ktype;
	struct kernfs_node___404 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___373 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___409 *, struct kobject___397 *, struct bin_attribute___373 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___409 *, struct kobject___397 *, struct bin_attribute___373 *, char *, loff_t, size_t);
	int (*mmap)(struct file___409 *, struct kobject___397 *, struct bin_attribute___373 *, struct vm_area_struct___410 *);
};

struct sysfs_ops___396 {
	ssize_t (*show)(struct kobject___397 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___397 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___396;

struct kset___396 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___397 kobj;
	const struct kset_uevent_ops___396 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___396 {
	void (*release)(struct kobject___397 *);
	const struct sysfs_ops___396 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___38 * (*child_ns_type)(struct kobject___397 *);
	const void * (*namespace)(struct kobject___397 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___396 {
	int (* const filter)(struct kset___396 *, struct kobject___397 *);
	const char * (* const name)(struct kset___396 *, struct kobject___397 *);
	int (* const uevent)(struct kset___396 *, struct kobject___397 *, struct kobj_uevent_env *);
};

struct kobj_attribute___387 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___397 *, struct kobj_attribute___387 *, char *);
	ssize_t (*store)(struct kobject___397 *, struct kobj_attribute___387 *, const char *, size_t);
};

struct dev_pm_ops___377 {
	int (*prepare)(struct device___377 *);
	void (*complete)(struct device___377 *);
	int (*suspend)(struct device___377 *);
	int (*resume)(struct device___377 *);
	int (*freeze)(struct device___377 *);
	int (*thaw)(struct device___377 *);
	int (*poweroff)(struct device___377 *);
	int (*restore)(struct device___377 *);
	int (*suspend_late)(struct device___377 *);
	int (*resume_early)(struct device___377 *);
	int (*freeze_late)(struct device___377 *);
	int (*thaw_early)(struct device___377 *);
	int (*poweroff_late)(struct device___377 *);
	int (*restore_early)(struct device___377 *);
	int (*suspend_noirq)(struct device___377 *);
	int (*resume_noirq)(struct device___377 *);
	int (*freeze_noirq)(struct device___377 *);
	int (*thaw_noirq)(struct device___377 *);
	int (*poweroff_noirq)(struct device___377 *);
	int (*restore_noirq)(struct device___377 *);
	int (*runtime_suspend)(struct device___377 *);
	int (*runtime_resume)(struct device___377 *);
	int (*runtime_idle)(struct device___377 *);
};

struct dev_pm_info___377 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___377 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___377;

struct bus_type___377;

struct device_driver___377;

struct dev_pm_domain___377;

struct dma_map_ops___149;

struct fwnode_handle___297;

struct class___377;

struct device___377 {
	struct device___377 *parent;
	struct device_private *p;
	struct kobject___397 kobj;
	const char *init_name;
	const struct device_type___377 *type;
	struct mutex mutex;
	struct bus_type___377 *bus;
	struct device_driver___377 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___377 power;
	struct dev_pm_domain___377 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___149 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___297 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___377 *class;
	const struct attribute_group___374 **groups;
	void (*release)(struct device___377 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___377 {
	struct dev_pm_ops___377 ops;
	void (*detach)(struct device___377 *, bool);
	int (*activate)(struct device___377 *);
	void (*sync)(struct device___377 *);
	void (*dismiss)(struct device___377 *);
};

struct bus_type___377 {
	const char *name;
	const char *dev_name;
	struct device___377 *dev_root;
	const struct attribute_group___374 **bus_groups;
	const struct attribute_group___374 **dev_groups;
	const struct attribute_group___374 **drv_groups;
	int (*match)(struct device___377 *, struct device_driver___377 *);
	int (*uevent)(struct device___377 *, struct kobj_uevent_env *);
	int (*probe)(struct device___377 *);
	int (*remove)(struct device___377 *);
	void (*shutdown)(struct device___377 *);
	int (*online)(struct device___377 *);
	int (*offline)(struct device___377 *);
	int (*suspend)(struct device___377 *, pm_message_t);
	int (*resume)(struct device___377 *);
	int (*num_vf)(struct device___377 *);
	int (*dma_configure)(struct device___377 *);
	const struct dev_pm_ops___377 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___377 {
	const char *name;
	struct bus_type___377 *bus;
	struct module___339 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___377 *);
	int (*remove)(struct device___377 *);
	void (*shutdown)(struct device___377 *);
	int (*suspend)(struct device___377 *, pm_message_t);
	int (*resume)(struct device___377 *);
	const struct attribute_group___374 **groups;
	const struct dev_pm_ops___377 *pm;
	void (*coredump)(struct device___377 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___377 {
	const char *name;
	const struct attribute_group___374 **groups;
	int (*uevent)(struct device___377 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___377 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___377 *);
	const struct dev_pm_ops___377 *pm;
};

struct module_kobject___337 {
	struct kobject___397 kobj;
	struct module___339 *mod;
	struct kobject___397 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___337 {
	struct module___339 *mod;
	struct latch_tree_node node;
};

struct module_layout___337 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___337 mtn;
};

struct module_attribute___337;

struct kernel_param___337;

struct module___339 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___337 mkobj;
	struct module_attribute___337 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___397 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___337 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___337 core_layout;
	struct module_layout___337 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide38;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide39;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct class___377 {
	const char *name;
	struct module___339 *owner;
	const struct attribute_group___374 **class_groups;
	const struct attribute_group___374 **dev_groups;
	struct kobject___397 *dev_kobj;
	int (*dev_uevent)(struct device___377 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___377 *, umode_t *);
	void (*class_release)(struct class___377 *);
	void (*dev_release)(struct device___377 *);
	int (*shutdown_pre)(struct device___377 *);
	const struct kobj_ns_type_operations___38 *ns_type;
	const void * (*namespace)(struct device___377 *);
	const struct dev_pm_ops___377 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___149 {
	void * (*alloc)(struct device___377 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___377 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___377 *, struct vm_area_struct___410 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___377 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___377 *, struct page___410 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___377 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___377 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___377 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___377 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___377 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___377 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___377 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___377 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___377 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___377 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___377 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___377 *, u64);
	u64 (*get_required_mask)(struct device___377 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___297;

struct fwnode_handle___297 {
	struct fwnode_handle___297 *secondary;
	const struct fwnode_operations___297 *ops;
};

struct node___223 {
	struct device___377 dev;
};

struct shrink_control___146 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___146 *memcg;
};

struct shrinker___146 {
	long unsigned int (*count_objects)(struct shrinker___146 *, struct shrink_control___146 *);
	long unsigned int (*scan_objects)(struct shrinker___146 *, struct shrink_control___146 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct dentry_operations___409;

struct super_block___409;

struct dentry___409 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___409 *d_parent;
	struct qstr d_name;
	struct inode___409 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___409 *d_op;
	struct super_block___409 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___409;

struct block_device___409;

struct inode___409 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___409 *i_op;
	struct super_block___409 *i_sb;
	struct address_space___409 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___411 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___203 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___409 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___409 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___90 *i_pipe;
		struct block_device___409 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___409 {
	int (*d_revalidate)(struct dentry___409 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___409 *, unsigned int);
	int (*d_hash)(const struct dentry___409 *, struct qstr *);
	int (*d_compare)(const struct dentry___409 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___409 *);
	int (*d_init)(struct dentry___409 *);
	void (*d_release)(struct dentry___409 *);
	void (*d_prune)(struct dentry___409 *);
	void (*d_iput)(struct dentry___409 *, struct inode___409 *);
	char * (*d_dname)(struct dentry___409 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___410 *);
	int (*d_manage)(const struct path___410 *, bool);
	struct dentry___409 * (*d_real)(struct dentry___409 *, const struct inode___409 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___409;

struct mem_dqinfo___409 {
	struct quota_format_type___409 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___409;

struct quota_info___409 {
	unsigned int flags;
	struct rw_semaphore___411 dqio_sem;
	struct inode___409 *files[3];
	struct mem_dqinfo___409 info[3];
	const struct quota_format_ops___409 *ops[3];
};

struct rcuwait___409 {
	struct task_struct___411 *task;
};

struct percpu_rw_semaphore___409 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___411 rw_sem;
	struct rcuwait___409 writer;
	int readers_block;
};

struct sb_writers___409 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___409 rw_sem[3];
};

struct file_system_type___409;

struct super_operations___409;

struct dquot_operations___409;

struct quotactl_ops___409;

struct super_block___409 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___409 *s_type;
	const struct super_operations___409 *s_op;
	const struct dquot_operations___409 *dq_op;
	const struct quotactl_ops___409 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___409 *s_root;
	struct rw_semaphore___411 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___409 *s_bdev;
	struct backing_dev_info___203 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___409 s_dquot;
	struct sb_writers___409 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___409 *s_d_op;
	int cleancache_poolid;
	struct shrinker___146 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___274 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___409 {
	struct file___409 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___409 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___409 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___409 *ia_file;
};

struct dquot___409 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___409 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___409 {
	int qf_fmt_id;
	const struct quota_format_ops___409 *qf_ops;
	struct module___339 *qf_owner;
	struct quota_format_type___409 *qf_next;
};

struct quota_format_ops___409 {
	int (*check_quota_file)(struct super_block___409 *, int);
	int (*read_file_info)(struct super_block___409 *, int);
	int (*write_file_info)(struct super_block___409 *, int);
	int (*free_file_info)(struct super_block___409 *, int);
	int (*read_dqblk)(struct dquot___409 *);
	int (*commit_dqblk)(struct dquot___409 *);
	int (*release_dqblk)(struct dquot___409 *);
	int (*get_next_id)(struct super_block___409 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___409 {
	int (*write_dquot)(struct dquot___409 *);
	struct dquot___409 * (*alloc_dquot)(struct super_block___409 *, int);
	void (*destroy_dquot)(struct dquot___409 *);
	int (*acquire_dquot)(struct dquot___409 *);
	int (*release_dquot)(struct dquot___409 *);
	int (*mark_dirty)(struct dquot___409 *);
	int (*write_info)(struct super_block___409 *, int);
	qsize_t * (*get_reserved_space)(struct inode___409 *);
	int (*get_projid)(struct inode___409 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___409 *, qsize_t *);
	int (*get_next_id)(struct super_block___409 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___409 {
	int (*quota_on)(struct super_block___409 *, int, int, const struct path___410 *);
	int (*quota_off)(struct super_block___409 *, int);
	int (*quota_enable)(struct super_block___409 *, unsigned int);
	int (*quota_disable)(struct super_block___409 *, unsigned int);
	int (*quota_sync)(struct super_block___409 *, int);
	int (*set_info)(struct super_block___409 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___409 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___409 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___409 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___409 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___409 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___166;

struct address_space_operations___409 {
	int (*writepage)(struct page___410 *, struct writeback_control___166 *);
	int (*readpage)(struct file___409 *, struct page___410 *);
	int (*writepages)(struct address_space___409 *, struct writeback_control___166 *);
	int (*set_page_dirty)(struct page___410 *);
	int (*readpages)(struct file___409 *, struct address_space___409 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___409 *, struct address_space___409 *, loff_t, unsigned int, unsigned int, struct page___410 **, void **);
	int (*write_end)(struct file___409 *, struct address_space___409 *, loff_t, unsigned int, unsigned int, struct page___410 *, void *);
	sector_t (*bmap)(struct address_space___409 *, sector_t);
	void (*invalidatepage)(struct page___410 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___410 *, gfp_t);
	void (*freepage)(struct page___410 *);
	ssize_t (*direct_IO)(struct kiocb___409 *, struct iov_iter___176 *);
	int (*migratepage)(struct address_space___409 *, struct page___410 *, struct page___410 *, enum migrate_mode);
	bool (*isolate_page)(struct page___410 *, isolate_mode_t);
	void (*putback_page)(struct page___410 *);
	int (*launder_page)(struct page___410 *);
	int (*is_partially_uptodate)(struct page___410 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___410 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___409 *, struct page___410 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___409 *, sector_t *);
	void (*swap_deactivate)(struct file___409 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___166 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___203 *wb;
	struct inode___409 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___205;

struct iov_iter___176 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___205 *bvec;
		struct pipe_inode_info___90 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___409 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___409 *bd_inode;
	struct super_block___409 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___409 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___203 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___409 {
	struct dentry___409 * (*lookup)(struct inode___409 *, struct dentry___409 *, unsigned int);
	const char * (*get_link)(struct dentry___409 *, struct inode___409 *, struct delayed_call *);
	int (*permission)(struct inode___409 *, int);
	struct posix_acl * (*get_acl)(struct inode___409 *, int);
	int (*readlink)(struct dentry___409 *, char *, int);
	int (*create)(struct inode___409 *, struct dentry___409 *, umode_t, bool);
	int (*link)(struct dentry___409 *, struct inode___409 *, struct dentry___409 *);
	int (*unlink)(struct inode___409 *, struct dentry___409 *);
	int (*symlink)(struct inode___409 *, struct dentry___409 *, const char *);
	int (*mkdir)(struct inode___409 *, struct dentry___409 *, umode_t);
	int (*rmdir)(struct inode___409 *, struct dentry___409 *);
	int (*mknod)(struct inode___409 *, struct dentry___409 *, umode_t, dev_t);
	int (*rename)(struct inode___409 *, struct dentry___409 *, struct inode___409 *, struct dentry___409 *, unsigned int);
	int (*setattr)(struct dentry___409 *, struct iattr___409 *);
	int (*getattr)(const struct path___410 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___409 *, char *, size_t);
	int (*fiemap)(struct inode___409 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___409 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___409 *, struct dentry___409 *, struct file___409 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___409 *, struct dentry___409 *, umode_t);
	int (*set_acl)(struct inode___409 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___409 {
	void (*fl_copy_lock)(struct file_lock___409 *, struct file_lock___409 *);
	void (*fl_release_private)(struct file_lock___409 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___409;

struct file_lock___409 {
	struct file_lock___409 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___409 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___409 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___409 *fl_ops;
	const struct lock_manager_operations___409 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___409 {
	int (*lm_compare_owner)(struct file_lock___409 *, struct file_lock___409 *);
	long unsigned int (*lm_owner_key)(struct file_lock___409 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___409 *);
	int (*lm_grant)(struct file_lock___409 *, int);
	bool (*lm_break)(struct file_lock___409 *);
	int (*lm_change)(struct file_lock___409 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___409 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___409 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___409 *fa_next;
	struct file___409 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___409 {
	const char *name;
	int fs_flags;
	struct dentry___409 * (*mount)(struct file_system_type___409 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___409 *);
	struct module___339 *owner;
	struct file_system_type___409 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___409 {
	struct inode___409 * (*alloc_inode)(struct super_block___409 *);
	void (*destroy_inode)(struct inode___409 *);
	void (*dirty_inode)(struct inode___409 *, int);
	int (*write_inode)(struct inode___409 *, struct writeback_control___166 *);
	int (*drop_inode)(struct inode___409 *);
	void (*evict_inode)(struct inode___409 *);
	void (*put_super)(struct super_block___409 *);
	int (*sync_fs)(struct super_block___409 *, int);
	int (*freeze_super)(struct super_block___409 *);
	int (*freeze_fs)(struct super_block___409 *);
	int (*thaw_super)(struct super_block___409 *);
	int (*unfreeze_fs)(struct super_block___409 *);
	int (*statfs)(struct dentry___409 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___409 *, int *, char *);
	void (*umount_begin)(struct super_block___409 *);
	int (*show_options)(struct seq_file___348 *, struct dentry___409 *);
	int (*show_devname)(struct seq_file___348 *, struct dentry___409 *);
	int (*show_path)(struct seq_file___348 *, struct dentry___409 *);
	int (*show_stats)(struct seq_file___348 *, struct dentry___409 *);
	ssize_t (*quota_read)(struct super_block___409 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___409 *, int, const char *, size_t, loff_t);
	struct dquot___409 ** (*get_dquots)(struct inode___409 *);
	int (*bdev_try_to_free_page)(struct super_block___409 *, struct page___410 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___409 *, struct shrink_control___146 *);
	long int (*free_cached_objects)(struct super_block___409 *, struct shrink_control___146 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___203(struct bio___203 *);

struct bio_vec___205 {
	struct page___410 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___203;

struct bio_set___203;

struct bio___203 {
	struct bio___203 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___203 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___203 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___205 *bi_io_vec;
	struct bio_set___203 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___205 bi_inline_vecs[0];
};

typedef void compound_page_dtor___397(struct page___410 *);

struct msghdr___41 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___176 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___409 *msg_iocb;
};

struct socket_wq___39 {
	wait_queue_head_t wait;
	struct fasync_struct___409 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___39;

struct socket___40 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___39 *wq;
	struct file___409 *file;
	struct sock___39 *sk;
	const struct proto_ops___39 *ops;
};

typedef int (*sk_read_actor_t___38)(read_descriptor_t *, struct sk_buff___56 *, unsigned int, size_t);

struct proto_ops___39 {
	int family;
	struct module___339 *owner;
	int (*release)(struct socket___40 *);
	int (*bind)(struct socket___40 *, struct sockaddr *, int);
	int (*connect)(struct socket___40 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___40 *, struct socket___40 *);
	int (*accept)(struct socket___40 *, struct socket___40 *, int, bool);
	int (*getname)(struct socket___40 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___409 *, struct socket___40 *, struct poll_table_struct___252 *);
	int (*ioctl)(struct socket___40 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___40 *, int);
	int (*shutdown)(struct socket___40 *, int);
	int (*setsockopt)(struct socket___40 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___40 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___40 *, struct msghdr___41 *, size_t);
	int (*recvmsg)(struct socket___40 *, struct msghdr___41 *, size_t, int);
	int (*mmap)(struct file___409 *, struct socket___40 *, struct vm_area_struct___410 *);
	ssize_t (*sendpage)(struct socket___40 *, struct page___410 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___40 *, loff_t *, struct pipe_inode_info___90 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___39 *, int);
	int (*peek_len)(struct socket___40 *);
	int (*read_sock)(struct sock___39 *, read_descriptor_t *, sk_read_actor_t___38);
	int (*sendpage_locked)(struct sock___39 *, struct page___410 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___39 *, struct msghdr___41 *, size_t);
	int (*set_rcvlowat)(struct sock___39 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct sec_path___4;

struct nf_bridge_info___54;

struct sk_buff___56 {
	union {
		struct {
			struct sk_buff___56 *next;
			struct sk_buff___56 *prev;
			union {
				struct net_device___55 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___39 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___56 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path___4 *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___54 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___54;

struct netns_frags___54 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___54 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ip_ra_chain___18;

struct fib_rules_ops___38;

struct fib_notifier_ops___38;

struct netns_ipv4___54 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___18 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___38 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___39 *fibnl;
	struct sock___39 **icmp_sk;
	struct sock___39 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___39 **tcp_sk;
	struct netns_frags___54 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___38 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___38 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___38 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___38;

struct dst_ops___65 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___65 *);
	struct dst_entry___38 * (*check)(struct dst_entry___38 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___38 *);
	unsigned int (*mtu)(const struct dst_entry___38 *);
	u32 * (*cow_metrics)(struct dst_entry___38 *, long unsigned int);
	void (*destroy)(struct dst_entry___38 *);
	void (*ifdown)(struct dst_entry___38 *, struct net_device___55 *, int);
	struct dst_entry___38 * (*negative_advice)(struct dst_entry___38 *);
	void (*link_failure)(struct sk_buff___56 *);
	void (*update_pmtu)(struct dst_entry___38 *, struct sock___39 *, struct sk_buff___56 *, u32);
	void (*redirect)(struct dst_entry___38 *, struct sock___39 *, struct sk_buff___56 *);
	int (*local_out)(struct net___66 *, struct sock___39 *, struct sk_buff___56 *);
	struct neighbour___38 * (*neigh_lookup)(const struct dst_entry___38 *, struct sk_buff___56 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___38 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_info___5;

struct rt6_info___5;

struct fib6_table___5;

struct netns_ipv6___65 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___54 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info___5 *fib6_null_entry;
	struct rt6_info___5 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___5 *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___65 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info___5 *ip6_prohibit_entry;
	struct rt6_info___5 *ip6_blk_hole_entry;
	struct fib6_table___5 *fib6_local_tbl;
	struct fib_rules_ops___38 *fib6_rules_ops;
	struct sock___39 **icmp_sk;
	struct sock___39 *ndisc_sk;
	struct sock___39 *tcp_sk;
	struct sock___39 *igmp_sk;
	struct sock___39 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___38 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___38 *notifier_ops;
	struct fib_notifier_ops___38 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___39 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___39 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct nf_hook_entries___3;

struct netns_nf___4 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_queue_handler *queue_handler;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header *nf_log_dir_header;
	struct nf_hook_entries___3 *hooks_ipv4[5];
	struct nf_hook_entries___3 *hooks_ipv6[5];
	struct nf_hook_entries___3 *hooks_arp[3];
	struct nf_hook_entries___3 *hooks_bridge[5];
	bool defrag_ipv4;
	bool defrag_ipv6;
};

struct netns_nf_frag___54 {
	struct netns_frags___54 frags;
};

struct netns_xfrm___65 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___39 *nlsk;
	struct sock___39 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___65 xfrm4_dst_ops;
	struct dst_ops___65 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___48;

struct net___66 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___274 *user_ns;
	struct ucounts___274 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___29 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___39 *rtnl;
	struct sock___39 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___55 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___54 ipv4;
	struct netns_ipv6___65 ipv6;
	struct netns_sctp___39 sctp;
	struct netns_nf___4 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___54 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___39 *nfnl;
	struct sock___39 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___65 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___39 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___48 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_reference_args___297;

struct fwnode_endpoint___297;

struct fwnode_operations___297 {
	struct fwnode_handle___297 * (*get)(struct fwnode_handle___297 *);
	void (*put)(struct fwnode_handle___297 *);
	bool (*device_is_available)(const struct fwnode_handle___297 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___297 *, const struct device___377 *);
	bool (*property_present)(const struct fwnode_handle___297 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___297 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___297 *, const char *, const char **, size_t);
	struct fwnode_handle___297 * (*get_parent)(const struct fwnode_handle___297 *);
	struct fwnode_handle___297 * (*get_next_child_node)(const struct fwnode_handle___297 *, struct fwnode_handle___297 *);
	struct fwnode_handle___297 * (*get_named_child_node)(const struct fwnode_handle___297 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___297 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___297 *);
	struct fwnode_handle___297 * (*graph_get_next_endpoint)(const struct fwnode_handle___297 *, struct fwnode_handle___297 *);
	struct fwnode_handle___297 * (*graph_get_remote_endpoint)(const struct fwnode_handle___297 *);
	struct fwnode_handle___297 * (*graph_get_port_parent)(struct fwnode_handle___297 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___297 *, struct fwnode_endpoint___297 *);
};

struct fwnode_endpoint___297 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___297 *local_fwnode;
};

struct fwnode_reference_args___297 {
	struct fwnode_handle___297 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___90;

struct pipe_buffer___90 {
	struct page___410 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___90 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___90 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___90 *, struct pipe_buffer___90 *);
	void (*release)(struct pipe_inode_info___90 *, struct pipe_buffer___90 *);
	int (*steal)(struct pipe_inode_info___90 *, struct pipe_buffer___90 *);
	union {
		bool (*get)(struct pipe_inode_info___90 *, struct pipe_buffer___90 *);
		struct {
			void (*get)(struct pipe_inode_info___90 *, struct pipe_buffer___90 *);
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
};

struct nf_bridge_info___54 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___54 = 0,
		BRNF_PROTO_8021Q___54 = 1,
		BRNF_PROTO_PPPOE___54 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___55 *physindev;
	struct net_device___55 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___54(struct sk_buff___56 **);

struct net_device_ops___54;

struct ethtool_ops___54;

struct l3mdev_ops___38;

struct ndisc_ops___21;

struct xfrmdev_ops___54;

struct tlsdev_ops___54;

struct header_ops___54;

struct in_device___2;

struct inet6_dev___21;

struct netdev_rx_queue___54;

struct mini_Qdisc___48;

struct netdev_queue___54;

struct Qdisc___48;

struct netpoll_info___2;

struct rtnl_link_ops___48;

struct dcbnl_rtnl_ops___54;

struct net_device___55 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___54 *netdev_ops;
	const struct ethtool_ops___54 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___38 *l3mdev_ops;
	const struct ndisc_ops___21 *ndisc_ops;
	const struct xfrmdev_ops___54 *xfrmdev_ops;
	const struct tlsdev_ops___54 *tlsdev_ops;
	const struct header_ops___54 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___396 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device___2 *ip_ptr;
	struct inet6_dev___21 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___54 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___48 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___54 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___48 *miniq_ingress;
	struct netdev_queue___54 *ingress_queue;
	struct nf_hook_entries___3 *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap___2 *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___54 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___48 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___48 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___54 = 0,
		NETREG_REGISTERED___54 = 1,
		NETREG_UNREGISTERING___54 = 2,
		NETREG_UNREGISTERED___54 = 3,
		NETREG_RELEASED___54 = 4,
		NETREG_DUMMY___54 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___54 = 0,
		RTNL_LINK_INITIALIZING___54 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___55 *);
	struct netpoll_info___2 *npinfo;
	possible_net_t___56 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___377 dev;
	const struct attribute_group___374 *sysfs_groups[4];
	const struct attribute_group___374 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___48 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___54 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct skb_frag_struct___7 {
	struct {
		struct page___410 *p;
	} page;
	__u32 page_offset;
	__u32 size;
};

typedef struct skb_frag_struct___7 skb_frag_t___7;

struct mmpin___2 {
	struct user_struct___377 *user;
	unsigned int num_pg;
};

struct ubuf_info___2 {
	void (*callback)(struct ubuf_info___2 *, bool);
	union {
		struct {
			long unsigned int desc;
			void *ctx;
		};
		struct {
			u32 id;
			u16 len;
			u16 zerocopy: 1;
			u32 bytelen;
		};
	};
	refcount_t refcnt;
	struct mmpin___2 mmp;
};

struct skb_shared_info___7 {
	__u8 __unused;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___56 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___7 frags[16];
};

struct xfrm_state___4;

struct sec_path___4 {
	refcount_t refcnt;
	int len;
	int olen;
	struct xfrm_state___4 *xvec[6];
	struct xfrm_offload ovec[1];
};

enum {
	IF_OPER_UNKNOWN = 0,
	IF_OPER_NOTPRESENT = 1,
	IF_OPER_DOWN = 2,
	IF_OPER_LOWERLAYERDOWN = 3,
	IF_OPER_TESTING = 4,
	IF_OPER_DORMANT = 5,
	IF_OPER_UP = 6,
};

struct ethtool_ops___54 {
	int (*get_settings)(struct net_device___55 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___55 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___55 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___55 *);
	void (*get_regs)(struct net_device___55 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___55 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___55 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___55 *);
	void (*set_msglevel)(struct net_device___55 *, u32);
	int (*nway_reset)(struct net_device___55 *);
	u32 (*get_link)(struct net_device___55 *);
	int (*get_eeprom_len)(struct net_device___55 *);
	int (*get_eeprom)(struct net_device___55 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___55 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___55 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___55 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___55 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___55 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___55 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___55 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___55 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___55 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___55 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___55 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___55 *);
	void (*complete)(struct net_device___55 *);
	u32 (*get_priv_flags)(struct net_device___55 *);
	int (*set_priv_flags)(struct net_device___55 *, u32);
	int (*get_sset_count)(struct net_device___55 *, int);
	int (*get_rxnfc)(struct net_device___55 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___55 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___55 *, struct ethtool_flash *);
	int (*reset)(struct net_device___55 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___55 *);
	u32 (*get_rxfh_indir_size)(struct net_device___55 *);
	int (*get_rxfh)(struct net_device___55 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___55 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___55 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___55 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___55 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___55 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___55 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___55 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___55 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___55 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___55 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___55 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___55 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___55 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___55 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___55 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___55 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___55 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___55 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___55 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___55 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___55 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	int (*get_fecparam)(struct net_device___55 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___55 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___55 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___55 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___55 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___54;

struct inet_frags___54 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___54 *, const void *);
	void (*destructor)(struct inet_frag_queue___54 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___54 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___56 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___56 *fragments_tail;
	struct sk_buff___56 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___54 *net;
	struct callback_head rcu;
};

struct ipv4_devconf {
	void *sysctl;
	int data[47];
	long unsigned int state[1];
};

struct ip_ra_chain___18 {
	struct ip_ra_chain___18 *next;
	struct sock___39 *sk;
	union {
		void (*destructor)(struct sock___39 *);
		struct sock___39 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___38;

struct fib_lookup_arg___38;

struct fib_rules_ops___38 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___38 *, struct flowi *, int, struct fib_lookup_arg___38 *);
	bool (*suppress)(struct fib_rule___38 *, struct fib_lookup_arg___38 *);
	int (*match)(struct fib_rule___38 *, struct flowi *, int);
	int (*configure)(struct fib_rule___38 *, struct sk_buff___56 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___38 *);
	int (*compare)(struct fib_rule___38 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___38 *, struct sk_buff___56 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___38 *);
	void (*flush_cache)(struct fib_rules_ops___38 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___339 *owner;
	struct net___66 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___38 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___66 *);
	int (*fib_dump)(struct net___66 *, struct notifier_block *);
	struct module___339 *owner;
	struct callback_head rcu;
};

struct lwtunnel_state___2;

struct dst_entry___38 {
	struct net_device___55 *dev;
	struct dst_ops___65 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state___4 *xfrm;
	int (*input)(struct sk_buff___56 *);
	int (*output)(struct net___66 *, struct sock___39 *, struct sk_buff___56 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___2 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___38;

struct neigh_parms___38;

struct neigh_ops___38;

struct neighbour___38 {
	struct neighbour___38 *next;
	struct neigh_table___38 *tbl;
	struct neigh_parms___38 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___54 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___38 *, struct sk_buff___56 *);
	const struct neigh_ops___38 *ops;
	struct callback_head rcu;
	struct net_device___55 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct fib6_nh___5 {
	struct in6_addr nh_gw;
	struct net_device___55 *nh_dev;
	struct lwtunnel_state___2 *nh_lwtstate;
	unsigned int nh_flags;
	atomic_t nh_upper_bound;
	int nh_weight;
};

struct fib6_node___5;

struct fib6_info___5 {
	struct fib6_table___5 *fib6_table;
	struct fib6_info___5 *fib6_next;
	struct fib6_node___5 *fib6_node;
	struct list_head fib6_siblings;
	unsigned int fib6_nsiblings;
	atomic_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	struct rt6_info___5 **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
	long unsigned int last_probe;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 exception_bucket_flushed: 1;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 dst_host: 1;
	u8 fib6_destroying: 1;
	u8 unused: 2;
	struct fib6_nh___5 fib6_nh;
	struct callback_head rcu;
};

struct rt6_info___5 {
	struct dst_entry___38 dst;
	struct fib6_info___5 *from;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___21 *rt6i_idev;
	u32 rt6i_flags;
	struct rt6key rt6i_prefsrc;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct fib6_node___5 {
	struct fib6_node___5 *parent;
	struct fib6_node___5 *left;
	struct fib6_node___5 *right;
	struct fib6_info___5 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info___5 *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table___5 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node___5 tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

enum nf_dev_hooks {
	NF_NETDEV_INGRESS = 0,
	NF_NETDEV_NUMHOOKS = 1,
};

struct nf_hook_state___3;

typedef unsigned int nf_hookfn___3(void *, struct sk_buff___56 *, const struct nf_hook_state___3 *);

struct nf_hook_entry___3 {
	nf_hookfn___3 *hook;
	void *priv;
};

struct nf_hook_entries___3 {
	u16 num_hook_entries;
	struct nf_hook_entry___3 hooks[0];
};

struct ucounts___274 {
	struct hlist_node node;
	struct user_namespace___274 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_prog_aux___51;

struct bpf_prog___48 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___51 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

typedef int (*key_restrict_link_func_t___378)(struct key___377 *, const struct key_type *, const union key_payload *, struct key___377 *);

struct key_restriction___377;

struct key___377 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___411 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___377 *restrict_link;
};

struct key_restriction___377 {
	key_restrict_link_func_t___378 check;
	struct key___377 *key;
	struct key_type *keytype;
};

struct seq_operations___348 {
	void * (*start)(struct seq_file___348 *, loff_t *);
	void (*stop)(struct seq_file___348 *, void *);
	void * (*next)(struct seq_file___348 *, void *, loff_t *);
	int (*show)(struct seq_file___348 *, void *);
};

struct pernet_operations___55 {
	struct list_head list;
	int (*init)(struct net___66 *);
	void (*exit)(struct net___66 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___54 {
	int (*ieee_getets)(struct net_device___55 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___55 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___55 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___55 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___55 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___55 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___55 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___55 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___55 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___55 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___55 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___55 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___55 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___55 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___55 *);
	u8 (*setstate)(struct net_device___55 *, u8);
	void (*getpermhwaddr)(struct net_device___55 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___55 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___55 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___55 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___55 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___55 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___55 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___55 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___55 *, int, u8 *);
	void (*setpfccfg)(struct net_device___55 *, int, u8);
	void (*getpfccfg)(struct net_device___55 *, int, u8 *);
	u8 (*setall)(struct net_device___55 *);
	u8 (*getcap)(struct net_device___55 *, int, u8 *);
	int (*getnumtcs)(struct net_device___55 *, int, u8 *);
	int (*setnumtcs)(struct net_device___55 *, int, u8);
	u8 (*getpfcstate)(struct net_device___55 *);
	void (*setpfcstate)(struct net_device___55 *, u8);
	void (*getbcncfg)(struct net_device___55 *, int, u32 *);
	void (*setbcncfg)(struct net_device___55 *, int, u32);
	void (*getbcnrp)(struct net_device___55 *, int, u8 *);
	void (*setbcnrp)(struct net_device___55 *, int, u8);
	int (*setapp)(struct net_device___55 *, u8, u16, u8);
	int (*getapp)(struct net_device___55 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___55 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___55 *, int, u8);
	u8 (*getdcbx)(struct net_device___55 *);
	u8 (*setdcbx)(struct net_device___55 *, u8);
	int (*peer_getappinfo)(struct net_device___55 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___55 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___55 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___55 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___55 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___55 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___258 {
	refcount_t count;
	struct ns_common___29 ns;
	struct user_namespace___274 *user_ns;
	struct ucounts___274 *ucounts;
	struct css_set___258 *root_cset;
};

struct bpf_map___259;

struct bpf_map_ops___258 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___259 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___259 *, struct file___409 *);
	void (*map_free)(struct bpf_map___259 *);
	int (*map_get_next_key)(struct bpf_map___259 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___259 *);
	void * (*map_lookup_elem)(struct bpf_map___259 *, void *);
	int (*map_update_elem)(struct bpf_map___259 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___259 *, void *);
	int (*map_push_elem)(struct bpf_map___259 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___259 *, void *);
	int (*map_peek_elem)(struct bpf_map___259 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___259 *, struct file___409 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___259 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___259 *, void *, struct seq_file___348 *);
	int (*map_check_btf)(const struct bpf_map___259 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___259 {
	const struct bpf_map_ops___258 *ops;
	struct bpf_map___259 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___377 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___54;

struct bpf_map_dev_ops___54 {
	int (*map_get_next_key)(struct bpf_offloaded_map___54 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___54 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___54 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___54 *, void *);
};

struct bpf_offloaded_map___54 {
	struct bpf_map___259 map;
	struct net_device___55 *netdev;
	const struct bpf_map_dev_ops___54 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___48 {
	int (*test_run)(struct bpf_prog___48 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___48 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___48 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___48 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___48 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___48 *, u32 *);
};

struct bpf_prog_offload_ops___48 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___48 *);
	int (*translate)(struct bpf_prog___48 *);
	void (*destroy)(struct bpf_prog___48 *);
};

struct bpf_prog_offload___48 {
	struct bpf_prog___48 *prog;
	struct net_device___55 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___48 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___51 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___48 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___48 *ops;
	struct bpf_map___259 **used_maps;
	struct bpf_prog___48 *prog;
	struct user_struct___377 *user;
	u64 load_time;
	struct bpf_map___259 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___48 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___48 {
	struct bpf_prog___48 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___48 {
	struct callback_head rcu;
	struct bpf_prog_array_item___48 items[0];
};

struct cgroup_bpf___48 {
	struct bpf_prog_array___48 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___48 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___259;

typedef void (*kthread_work_func_t___259)(struct kthread_work___259 *);

struct kthread_worker___259;

struct kthread_work___259 {
	struct list_head node;
	kthread_work_func_t___259 func;
	struct kthread_worker___259 *worker;
	int canceling;
};

struct kthread_worker___259 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___411 *task;
	struct kthread_work___259 *current_work;
};

struct kthread_delayed_work___258 {
	struct kthread_work___259 work;
	struct timer_list timer;
};

struct psi_group___258 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___259 *poll_kworker;
	struct kthread_delayed_work___258 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___258;

struct cgroup_rstat_cpu___258;

struct cgroup___258 {
	struct cgroup_subsys_state___258 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___404 *kn;
	struct cgroup_file___258 procs_file;
	struct cgroup_file___258 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___258 *subsys[13];
	struct cgroup_root___258 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___258 *dom_cgrp;
	struct cgroup_rstat_cpu___258 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___48 bpf;
	atomic_t congestion_count;
	struct cgroup___258 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___258 psi;
	int ancestor_ids[0];
};

struct cftype___258;

struct cgroup_subsys___258 {
	struct cgroup_subsys_state___258 * (*css_alloc)(struct cgroup_subsys_state___258 *);
	int (*css_online)(struct cgroup_subsys_state___258 *);
	void (*css_offline)(struct cgroup_subsys_state___258 *);
	void (*css_released)(struct cgroup_subsys_state___258 *);
	void (*css_free)(struct cgroup_subsys_state___258 *);
	void (*css_reset)(struct cgroup_subsys_state___258 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___258 *, int);
	int (*css_extra_stat_show)(struct seq_file___348 *, struct cgroup_subsys_state___258 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___411 *);
	void (*cancel_fork)(struct task_struct___411 *);
	void (*fork)(struct task_struct___411 *);
	void (*exit)(struct task_struct___411 *);
	void (*free)(struct task_struct___411 *);
	void (*bind)(struct cgroup_subsys_state___258 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___258 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___258 *dfl_cftypes;
	struct cftype___258 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___258 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___258 *updated_children;
	struct cgroup___258 *updated_next;
};

struct cgroup_root___258 {
	struct kernfs_root___403 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___258 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___258 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___258 *ss;
	struct list_head node;
	struct kernfs_ops___403 *kf_ops;
	int (*open)(struct kernfs_open_file___403 *);
	void (*release)(struct kernfs_open_file___403 *);
	u64 (*read_u64)(struct cgroup_subsys_state___258 *, struct cftype___258 *);
	s64 (*read_s64)(struct cgroup_subsys_state___258 *, struct cftype___258 *);
	int (*seq_show)(struct seq_file___348 *, void *);
	void * (*seq_start)(struct seq_file___348 *, loff_t *);
	void * (*seq_next)(struct seq_file___348 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___348 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___258 *, struct cftype___258 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___258 *, struct cftype___258 *, s64);
	ssize_t (*write)(struct kernfs_open_file___403 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___403 *, struct poll_table_struct___252 *);
};

struct xdp_rxq_info___54 {
	struct net_device___55 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_buff___3 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	long unsigned int handle;
	struct xdp_rxq_info___54 *rxq;
};

struct xdp_frame___54 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___55 *dev_rx;
};

struct netlink_callback___56 {
	struct sk_buff___56 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___56 *);
	int (*dump)(struct sk_buff___56 *, struct netlink_callback___56 *);
	int (*done)(struct netlink_callback___56 *);
	void *data;
	struct module___339 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct ifbond {
	__s32 bond_mode;
	__s32 num_slaves;
	__s32 miimon;
};

typedef struct ifbond ifbond;

struct ifslave {
	__s32 slave_id;
	char slave_name[16];
	__s8 link;
	__s8 state;
	__u32 link_failure_count;
};

typedef struct ifslave ifslave;

struct header_ops___54 {
	int (*create)(struct sk_buff___56 *, struct net_device___55 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___56 *, unsigned char *);
	int (*cache)(const struct neighbour___38 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___55 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

enum netdev_state_t {
	__LINK_STATE_START = 0,
	__LINK_STATE_PRESENT = 1,
	__LINK_STATE_NOCARRIER = 2,
	__LINK_STATE_LINKWATCH_PENDING = 3,
	__LINK_STATE_DORMANT = 4,
};

struct netdev_boot_setup {
	char name[16];
	struct ifmap map;
};

struct napi_struct___54 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___54 *, int);
	int poll_owner;
	struct net_device___55 *dev;
	struct sk_buff___56 *gro_list;
	struct sk_buff___56 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

enum {
	NAPIF_STATE_SCHED = 1,
	NAPIF_STATE_MISSED = 2,
	NAPIF_STATE_DISABLE = 4,
	NAPIF_STATE_NPSVC = 8,
	NAPIF_STATE_HASHED = 16,
	NAPIF_STATE_NO_BUSY_POLL = 32,
	NAPIF_STATE_IN_BUSY_POLL = 64,
};

enum gro_result {
	GRO_MERGED = 0,
	GRO_MERGED_FREE = 1,
	GRO_HELD = 2,
	GRO_NORMAL = 3,
	GRO_DROP = 4,
	GRO_CONSUMED = 5,
};

typedef enum gro_result gro_result_t;

enum netdev_queue_state_t {
	__QUEUE_STATE_DRV_XOFF = 0,
	__QUEUE_STATE_STACK_XOFF = 1,
	__QUEUE_STATE_FROZEN = 2,
};

struct netdev_queue___54 {
	struct net_device___55 *dev;
	struct Qdisc___48 *qdisc;
	struct Qdisc___48 *qdisc_sleeping;
	struct kobject___397 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___55 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___48 {
	struct sk_buff___56 *head;
	struct sk_buff___56 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___48;

struct Qdisc___48 {
	int (*enqueue)(struct sk_buff___56 *, struct Qdisc___48 *, struct sk_buff___56 **);
	struct sk_buff___56 * (*dequeue)(struct Qdisc___48 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___48 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___54 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___54 gso_skb;
	struct qdisc_skb_head___48 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___48 *next_sched;
	struct sk_buff_head___54 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___54 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___397 kobj;
	struct net_device___55 *dev;
	long: 64;
	struct xdp_rxq_info___54 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___54)(struct net_device___55 *, struct sk_buff___56 *, struct net_device___55 *);

struct netdev_bpf___54 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___48 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___48 *prog;
			const struct bpf_prog_offload_ops___48 *ops;
		} verifier;
		struct {
			struct bpf_prog___48 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___54 *offmap;
		};
		struct {
			struct xdp_umem *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___54 {
	int (*xdo_dev_state_add)(struct xfrm_state___4 *);
	void (*xdo_dev_state_delete)(struct xfrm_state___4 *);
	void (*xdo_dev_state_free)(struct xfrm_state___4 *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___56 *, struct xfrm_state___4 *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state___4 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct xfrm_state_offload___4 {
	struct net_device___55 *dev;
	long unsigned int offload_handle;
	unsigned int num_exthdrs;
	u8 flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct xfrm_replay___4;

struct xfrm_type___4;

struct xfrm_mode___4;

struct xfrm_type_offload___4;

struct xfrm_state___4 {
	possible_net_t___56 xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	refcount_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
		u32 output_mark;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	const char *geniv;
	struct xfrm_encap_tmpl *encap;
	xfrm_address_t *coaddr;
	struct xfrm_state___4 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	const struct xfrm_replay___4 *repl;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct tasklet_hrtimer mtimer;
	struct xfrm_state_offload___4 xso;
	long int saved_tmo;
	long unsigned int lastused;
	struct page_frag___410 xfrag;
	const struct xfrm_type___4 *type;
	struct xfrm_mode___4 *inner_mode;
	struct xfrm_mode___4 *inner_mode_iaf;
	struct xfrm_mode___4 *outer_mode;
	const struct xfrm_type_offload___4 *type_offload;
	struct xfrm_sec_ctx___2 *security;
	void *data;
	u32 output_mark_mask;
	u32 if_id;
};

struct tlsdev_ops___54 {
	int (*tls_dev_add)(struct net_device___55 *, struct sock___39 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___55 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___55 *, struct sock___39 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct udp_tunnel_info___2;

struct net_device_ops___54 {
	int (*ndo_init)(struct net_device___55 *);
	void (*ndo_uninit)(struct net_device___55 *);
	int (*ndo_open)(struct net_device___55 *);
	int (*ndo_stop)(struct net_device___55 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___56 *, struct net_device___55 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___56 *, struct net_device___55 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___55 *, struct sk_buff___56 *, struct net_device___55 *, select_queue_fallback_t___54);
	void (*ndo_change_rx_flags)(struct net_device___55 *, int);
	void (*ndo_set_rx_mode)(struct net_device___55 *);
	int (*ndo_set_mac_address)(struct net_device___55 *, void *);
	int (*ndo_validate_addr)(struct net_device___55 *);
	int (*ndo_do_ioctl)(struct net_device___55 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___55 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___55 *, int);
	int (*ndo_neigh_setup)(struct net_device___55 *, struct neigh_parms___38 *);
	void (*ndo_tx_timeout)(struct net_device___55 *);
	void (*ndo_get_stats64)(struct net_device___55 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___55 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___55 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___55 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___55 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___55 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___55 *);
	int (*ndo_netpoll_setup)(struct net_device___55 *, struct netpoll_info___2 *);
	void (*ndo_netpoll_cleanup)(struct net_device___55 *);
	int (*ndo_set_vf_mac)(struct net_device___55 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___55 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___55 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___55 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___55 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___55 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___55 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___55 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___55 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___55 *, int, struct sk_buff___56 *);
	int (*ndo_set_vf_guid)(struct net_device___55 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___55 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___55 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___55 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___55 *, const struct sk_buff___56 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___55 *, struct net_device___55 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___55 *, struct net_device___55 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___55 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___55 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___55 *, struct neighbour___38 *);
	void (*ndo_neigh_destroy)(struct net_device___55 *, struct neighbour___38 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___55 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___55 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___55 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___56 *, struct netlink_callback___56 *, struct net_device___55 *, struct net_device___55 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___55 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___55 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___56 *, u32, u32, struct net_device___55 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___55 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___55 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___55 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___55 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___55 *, struct udp_tunnel_info___2 *);
	void (*ndo_udp_tunnel_del)(struct net_device___55 *, struct udp_tunnel_info___2 *);
	void * (*ndo_dfwd_add_station)(struct net_device___55 *, struct net_device___55 *);
	void (*ndo_dfwd_del_station)(struct net_device___55 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___55 *);
	int (*ndo_set_tx_maxrate)(struct net_device___55 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___55 *);
	int (*ndo_change_proto_down)(struct net_device___55 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___55 *, struct sk_buff___56 *);
	void (*ndo_set_rx_headroom)(struct net_device___55 *, int);
	int (*ndo_bpf)(struct net_device___55 *, struct netdev_bpf___54 *);
	int (*ndo_xdp_xmit)(struct net_device___55 *, int, struct xdp_frame___54 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___55 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___55 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___38 {
	possible_net_t___56 net;
	struct net_device___55 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___38 *);
	void (*neigh_cleanup)(struct neighbour___38 *);
	struct neigh_table___38 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct netpoll;

struct netpoll_info___2 {
	refcount_t refcnt;
	struct semaphore dev_lock;
	struct sk_buff_head___54 txq;
	struct delayed_work tx_work;
	struct netpoll *netpoll;
	struct callback_head rcu;
};

struct udp_tunnel_info___2 {
	short unsigned int type;
	sa_family_t sa_family;
	__be16 port;
};

struct l3mdev_ops___38 {
	u32 (*l3mdev_fib_table)(const struct net_device___55 *);
	struct sk_buff___56 * (*l3mdev_l3_rcv)(struct net_device___55 *, struct sk_buff___56 *, u16);
	struct sk_buff___56 * (*l3mdev_l3_out)(struct net_device___55 *, struct sock___39 *, struct sk_buff___56 *, u16);
	struct dst_entry___38 * (*l3mdev_link_scope_lookup)(const struct net_device___55 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct ndisc_ops___21 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___55 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___55 *, struct neighbour___38 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___55 *, u8, struct neighbour___38 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___55 *, struct sk_buff___56 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___66 *, struct net_device___55 *, const struct prefix_info *, struct inet6_dev___21 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct in_ifaddr;

struct ip_mc_list;

struct in_device___2 {
	struct net_device___55 *dev;
	refcount_t refcnt;
	int dead;
	struct in_ifaddr *ifa_list;
	struct ip_mc_list *mc_list;
	struct ip_mc_list **mc_hash;
	int mc_count;
	spinlock_t mc_tomb_lock;
	struct ip_mc_list *mc_tomb;
	long unsigned int mr_v1_seen;
	long unsigned int mr_v2_seen;
	long unsigned int mr_maxdelay;
	long unsigned int mr_qi;
	long unsigned int mr_qri;
	unsigned char mr_qrv;
	unsigned char mr_gq_running;
	unsigned char mr_ifc_count;
	struct timer_list mr_gq_timer;
	struct timer_list mr_ifc_timer;
	struct neigh_parms___38 *arp_parms;
	struct ipv4_devconf cnf;
	struct callback_head callback_head;
};

struct ifmcaddr6___21;

struct ifacaddr6___5;

struct inet6_dev___21 {
	struct net_device___55 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___21 *mc_list;
	struct ifmcaddr6___21 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___5 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	u8 rndid[8];
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___38 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
};

struct tcf_proto___48;

struct mini_Qdisc___48 {
	struct tcf_proto___48 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___48 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___55 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___66 *, struct net_device___55 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___55 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___55 *, struct list_head *);
	size_t (*get_size)(const struct net_device___55 *);
	int (*fill_info)(struct sk_buff___56 *, const struct net_device___55 *);
	size_t (*get_xstats_size)(const struct net_device___55 *);
	int (*fill_xstats)(struct sk_buff___56 *, const struct net_device___55 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___55 *, struct net_device___55 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___55 *, const struct net_device___55 *);
	int (*fill_slave_info)(struct sk_buff___56 *, const struct net_device___55 *, const struct net_device___55 *);
	struct net___66 * (*get_link_net)(const struct net_device___55 *);
	size_t (*get_linkxstats_size)(const struct net_device___55 *, int);
	int (*fill_linkxstats)(struct sk_buff___56 *, const struct net_device___55 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct napi_gro_cb___2 {
	void *frag0;
	unsigned int frag0_len;
	int data_offset;
	u16 flush;
	u16 flush_id;
	u16 count;
	u16 gro_remcsum_start;
	long unsigned int age;
	u16 proto;
	u8 same_flow: 1;
	u8 encap_mark: 1;
	u8 csum_valid: 1;
	u8 csum_cnt: 3;
	u8 free: 2;
	u8 is_ipv6: 1;
	u8 is_fou: 1;
	u8 is_atomic: 1;
	u8 recursion_counter: 4;
	__wsum csum;
	struct sk_buff___56 *last;
};

struct packet_type {
	__be16 type;
	struct net_device___55 *dev;
	int (*func)(struct sk_buff___56 *, struct net_device___55 *, struct packet_type *, struct net_device___55 *);
	bool (*id_match)(struct packet_type *, struct sock___39 *);
	void *af_packet_priv;
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct offload_callbacks___3 {
	struct sk_buff___56 * (*gso_segment)(struct sk_buff___56 *, netdev_features_t);
	struct sk_buff___56 ** (*gro_receive)(struct sk_buff___56 **, struct sk_buff___56 *);
	int (*gro_complete)(struct sk_buff___56 *, int);
};

struct packet_offload {
	__be16 type;
	u16 priority;
	struct offload_callbacks___3 callbacks;
	struct list_head list;
};

struct netdev_notifier_info___3 {
	struct net_device___55 *dev;
	struct netlink_ext_ack *extack;
};

struct netdev_notifier_info_ext {
	struct netdev_notifier_info___3 info;
	union {
		u32 mtu;
	} ext;
};

struct netdev_notifier_change_info {
	struct netdev_notifier_info___3 info;
	unsigned int flags_changed;
};

struct netdev_notifier_changeupper_info {
	struct netdev_notifier_info___3 info;
	struct net_device___55 *upper_dev;
	bool master;
	bool linking;
	void *upper_info;
};

struct netdev_notifier_changelowerstate_info {
	struct netdev_notifier_info___3 info;
	void *lower_state_info;
};

struct netdev_notifier_pre_changeaddr_info {
	struct netdev_notifier_info___3 info;
	const unsigned char *dev_addr;
};

struct softnet_data___54 {
	struct list_head poll_list;
	struct sk_buff_head___54 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___54 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___48 *output_queue;
	struct Qdisc___48 **output_queue_tailp;
	struct sk_buff___56 *completion_queue;
	struct sk_buff_head___54 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___54 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___54 input_pkt_queue;
	struct napi_struct___54 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef int (*bpf_op_t)(struct net_device___55 *, struct netdev_bpf___54 *);

struct netdev_bonding_info {
	ifslave slave;
	ifbond master;
};

struct netdev_notifier_bonding_info {
	struct netdev_notifier_info___3 info;
	struct netdev_bonding_info bonding_info;
};

struct kernel_param_ops___337 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___337 *);
	int (*get)(char *, const struct kernel_param___337 *);
	void (*free)(void *);
};

struct kparam_array___337;

struct kernel_param___337 {
	const char *name;
	struct module___339 *mod;
	const struct kernel_param_ops___337 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___337 *arr;
	};
};

struct kparam_array___337 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___337 *ops;
	void *elem;
};

struct module_attribute___337 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___337 *, struct module_kobject___337 *, char *);
	ssize_t (*store)(struct module_attribute___337 *, struct module_kobject___337 *, const char *, size_t);
	void (*setup)(struct module___339 *, const char *);
	int (*test)(struct module___339 *);
	void (*free)(struct module___339 *);
};

union inet_addr {
	__u32 all[4];
	__be32 ip;
	__be32 ip6[4];
	struct in_addr in;
	struct in6_addr in6;
};

struct netpoll {
	struct net_device___55 *dev;
	char dev_name[16];
	const char *name;
	union inet_addr local_ip;
	union inet_addr remote_ip;
	bool ipv6;
	u16 local_port;
	u16 remote_port;
	u8 remote_mac[6];
	struct work_struct cleanup_work;
};

struct gnet_dump___48 {
	spinlock_t *lock;
	struct sk_buff___56 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

enum qdisc_state_t {
	__QDISC_STATE_SCHED = 0,
	__QDISC_STATE_DEACTIVATED = 1,
};

struct Qdisc_class_ops___48;

struct Qdisc_ops___48 {
	struct Qdisc_ops___48 *next;
	const struct Qdisc_class_ops___48 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___56 *, struct Qdisc___48 *, struct sk_buff___56 **);
	struct sk_buff___56 * (*dequeue)(struct Qdisc___48 *);
	struct sk_buff___56 * (*peek)(struct Qdisc___48 *);
	int (*init)(struct Qdisc___48 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___48 *);
	void (*destroy)(struct Qdisc___48 *);
	int (*change)(struct Qdisc___48 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___48 *);
	int (*change_tx_queue_len)(struct Qdisc___48 *, unsigned int);
	int (*dump)(struct Qdisc___48 *, struct sk_buff___56 *);
	int (*dump_stats)(struct Qdisc___48 *, struct gnet_dump___48 *);
	void (*ingress_block_set)(struct Qdisc___48 *, u32);
	void (*egress_block_set)(struct Qdisc___48 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___48 *);
	u32 (*egress_block_get)(struct Qdisc___48 *);
	struct module___339 *owner;
};

struct qdisc_walker___3;

struct tcf_block___48;

struct Qdisc_class_ops___48 {
	unsigned int flags;
	struct netdev_queue___54 * (*select_queue)(struct Qdisc___48 *, struct tcmsg *);
	int (*graft)(struct Qdisc___48 *, long unsigned int, struct Qdisc___48 *, struct Qdisc___48 **, struct netlink_ext_ack *);
	struct Qdisc___48 * (*leaf)(struct Qdisc___48 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___48 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___48 *, u32);
	int (*change)(struct Qdisc___48 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___48 *, long unsigned int);
	void (*walk)(struct Qdisc___48 *, struct qdisc_walker___3 *);
	struct tcf_block___48 * (*tcf_block)(struct Qdisc___48 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___48 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___48 *, long unsigned int);
	int (*dump)(struct Qdisc___48 *, long unsigned int, struct sk_buff___56 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___48 *, long unsigned int, struct gnet_dump___48 *);
};

struct qdisc_walker___3 {
	int stop;
	int skip;
	int count;
	int (*fn)(struct Qdisc___48 *, long unsigned int, struct qdisc_walker___3 *);
};

struct tcf_chain___48;

struct tcf_block___48 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___66 *net;
	struct Qdisc___48 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___48 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___48;

struct tcf_proto_ops___48;

struct tcf_proto___48 {
	struct tcf_proto___48 *next;
	void *root;
	int (*classify)(struct sk_buff___56 *, const struct tcf_proto___48 *, struct tcf_result___48 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___48 *ops;
	struct tcf_chain___48 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___48 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___48 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_walker___2;

struct tcf_proto_ops___48 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___56 *, const struct tcf_proto___48 *, struct tcf_result___48 *);
	int (*init)(struct tcf_proto___48 *);
	void (*destroy)(struct tcf_proto___48 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___48 *, u32);
	void (*put)(struct tcf_proto___48 *, void *);
	int (*change)(struct net___66 *, struct sk_buff___56 *, struct tcf_proto___48 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___48 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___48 *, struct tcf_walker___2 *, bool);
	int (*reoffload)(struct tcf_proto___48 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___66 *, struct tcf_chain___48 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___66 *, struct tcf_proto___48 *, void *, struct sk_buff___56 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___56 *, struct net___66 *, void *);
	struct module___339 *owner;
	int flags;
};

struct tcf_walker___2 {
	int stop;
	int skip;
	int count;
	bool nonempty;
	long unsigned int cookie;
	int (*fn)(struct tcf_proto___48 *, void *, struct tcf_walker___2 *);
};

struct tcf_chain___48 {
	struct mutex filter_chain_lock;
	struct tcf_proto___48 *filter_chain;
	struct list_head list;
	struct tcf_block___48 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___48 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___38 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___48 *prog;
};

struct bpf_redirect_info___48 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___259 *map;
	struct bpf_map___259 *map_to_flush;
	u32 kern_flags;
};

struct bdi_writeback_congested___203 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___203 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___203 {
	struct bio___203 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___205 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___205 bip_inline_vecs[0];
};

struct bio_set___203 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___203 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___146 {
	struct mem_cgroup___146 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___146 {
	struct lruvec___410 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___146 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___146 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct pneigh_entry___38;

struct neigh_hash_table___38;

struct neigh_table___38 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___55 *, __u32 *);
	bool (*key_eq)(const struct neighbour___38 *, const void *);
	int (*constructor)(struct neighbour___38 *);
	int (*pconstructor)(struct pneigh_entry___38 *);
	void (*pdestructor)(struct pneigh_entry___38 *);
	void (*proxy_redo)(struct sk_buff___56 *);
	char *id;
	struct neigh_parms___38 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___54 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___38 *nht;
	struct pneigh_entry___38 **phash_buckets;
};

struct neigh_ops___38 {
	int family;
	void (*solicit)(struct neighbour___38 *, struct sk_buff___56 *);
	void (*error_report)(struct neighbour___38 *, struct sk_buff___56 *);
	int (*output)(struct neighbour___38 *, struct sk_buff___56 *);
	int (*connected_output)(struct neighbour___38 *, struct sk_buff___56 *);
};

struct pneigh_entry___38 {
	struct pneigh_entry___38 *next;
	possible_net_t___56 net;
	struct net_device___55 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___38 {
	struct neighbour___38 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___2 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___66 *, struct sock___39 *, struct sk_buff___56 *);
	int (*orig_input)(struct sk_buff___56 *);
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	__u8 data[0];
};

struct fib_rule___38 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___38 *ctarget;
	struct net___66 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___38 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___38 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___25;

struct timewait_sock_ops___23;

struct proto___38 {
	void (*close)(struct sock___39 *, long int);
	int (*pre_connect)(struct sock___39 *, struct sockaddr *, int);
	int (*connect)(struct sock___39 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___39 *, int);
	struct sock___39 * (*accept)(struct sock___39 *, int, int *, bool);
	int (*ioctl)(struct sock___39 *, int, long unsigned int);
	int (*init)(struct sock___39 *);
	void (*destroy)(struct sock___39 *);
	void (*shutdown)(struct sock___39 *, int);
	int (*setsockopt)(struct sock___39 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___39 *, int, int, char *, int *);
	void (*keepalive)(struct sock___39 *, int);
	int (*sendmsg)(struct sock___39 *, struct msghdr___41 *, size_t);
	int (*recvmsg)(struct sock___39 *, struct msghdr___41 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___39 *, struct page___410 *, int, size_t, int);
	int (*bind)(struct sock___39 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___39 *, struct sk_buff___56 *);
	void (*release_cb)(struct sock___39 *);
	int (*hash)(struct sock___39 *);
	void (*unhash)(struct sock___39 *);
	void (*rehash)(struct sock___39 *);
	int (*get_port)(struct sock___39 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___39 *);
	bool (*stream_memory_read)(const struct sock___39 *);
	void (*enter_memory_pressure)(struct sock___39 *);
	void (*leave_memory_pressure)(struct sock___39 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___25 *rsk_prot;
	struct timewait_sock_ops___23 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___339 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___39 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct xfrm_policy_queue___4 {
	struct sk_buff_head___54 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___4 {
	possible_net_t___56 xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	refcount_t refcnt;
	struct timer_list timer;
	atomic_t genid;
	u32 priority;
	u32 index;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___4 polq;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx___2 *security;
	struct xfrm_tmpl xfrm_vec[6];
	struct callback_head rcu;
	u32 if_id;
};

struct request_sock___26;

struct request_sock_ops___25 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___39 *, struct request_sock___26 *);
	void (*send_ack)(const struct sock___39 *, struct sk_buff___56 *, struct request_sock___26 *);
	void (*send_reset)(const struct sock___39 *, struct sk_buff___56 *);
	void (*destructor)(struct request_sock___26 *);
	void (*syn_ack_timeout)(const struct request_sock___26 *);
};

struct timewait_sock_ops___23 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___39 *, struct sock___39 *, void *);
	void (*twsk_destructor)(struct sock___39 *);
};

enum {
	IPV4_DEVCONF_FORWARDING = 1,
	IPV4_DEVCONF_MC_FORWARDING = 2,
	IPV4_DEVCONF_PROXY_ARP = 3,
	IPV4_DEVCONF_ACCEPT_REDIRECTS = 4,
	IPV4_DEVCONF_SECURE_REDIRECTS = 5,
	IPV4_DEVCONF_SEND_REDIRECTS = 6,
	IPV4_DEVCONF_SHARED_MEDIA = 7,
	IPV4_DEVCONF_RP_FILTER = 8,
	IPV4_DEVCONF_ACCEPT_SOURCE_ROUTE = 9,
	IPV4_DEVCONF_BOOTP_RELAY = 10,
	IPV4_DEVCONF_LOG_MARTIANS = 11,
	IPV4_DEVCONF_TAG = 12,
	IPV4_DEVCONF_ARPFILTER = 13,
	IPV4_DEVCONF_MEDIUM_ID = 14,
	IPV4_DEVCONF_NOXFRM = 15,
	IPV4_DEVCONF_NOPOLICY = 16,
	IPV4_DEVCONF_FORCE_IGMP_VERSION = 17,
	IPV4_DEVCONF_ARP_ANNOUNCE = 18,
	IPV4_DEVCONF_ARP_IGNORE = 19,
	IPV4_DEVCONF_PROMOTE_SECONDARIES = 20,
	IPV4_DEVCONF_ARP_ACCEPT = 21,
	IPV4_DEVCONF_ARP_NOTIFY = 22,
	IPV4_DEVCONF_ACCEPT_LOCAL = 23,
	IPV4_DEVCONF_SRC_VMARK = 24,
	IPV4_DEVCONF_PROXY_ARP_PVLAN = 25,
	IPV4_DEVCONF_ROUTE_LOCALNET = 26,
	IPV4_DEVCONF_IGMPV2_UNSOLICITED_REPORT_INTERVAL = 27,
	IPV4_DEVCONF_IGMPV3_UNSOLICITED_REPORT_INTERVAL = 28,
	IPV4_DEVCONF_IGNORE_ROUTES_WITH_LINKDOWN = 29,
	IPV4_DEVCONF_DROP_UNICAST_IN_L2_MULTICAST = 30,
	IPV4_DEVCONF_DROP_GRATUITOUS_ARP = 31,
	RH_IPV4_DEVCONF_BASE = 31,
	IPV4_DEVCONF_BC_FORWARDING = 32,
	__IPV4_DEVCONF_MAX = 33,
};

struct request_sock___26 {
	struct sock_common___38 __req_common;
	struct request_sock___26 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___25 *rsk_ops;
	struct sock___39 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___21 {
	struct in6_addr mca_addr;
	struct inet6_dev___21 *idev;
	struct ifmcaddr6___21 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___5 {
	struct in6_addr aca_addr;
	struct fib6_info___5 *aca_rt;
	struct ifacaddr6___5 *aca_next;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct ip6_ra_chain___21 {
	struct ip6_ra_chain___21 *next;
	struct sock___39 *sk;
	int sel;
	void (*destructor)(struct sock___39 *);
};

struct ipv6_stub___2 {
	int (*ipv6_sock_mc_join)(struct sock___39 *, int, const struct in6_addr *);
	int (*ipv6_sock_mc_drop)(struct sock___39 *, int, const struct in6_addr *);
	int (*ipv6_dst_lookup)(struct net___66 *, struct sock___39 *, struct dst_entry___38 **, struct flowi6 *);
	struct fib6_table___5 * (*fib6_get_table)(struct net___66 *, u32);
	struct fib6_info___5 * (*fib6_lookup)(struct net___66 *, int, struct flowi6 *, int);
	struct fib6_info___5 * (*fib6_table_lookup)(struct net___66 *, struct fib6_table___5 *, int, struct flowi6 *, int);
	struct fib6_info___5 * (*fib6_multipath_select)(const struct net___66 *, struct fib6_info___5 *, struct flowi6 *, int, const struct sk_buff___56 *, int);
	u32 (*ip6_mtu_from_fib6)(struct fib6_info___5 *, struct in6_addr *, struct in6_addr *);
	void (*udpv6_encap_enable)();
	void (*ndisc_send_na)(struct net_device___55 *, const struct in6_addr *, const struct in6_addr *, bool, bool, bool, bool);
	struct neigh_table___38 *nd_tbl;
};

struct ipv6_bpf_stub___2 {
	int (*inet6_bind)(struct sock___39 *, struct sockaddr *, int, bool, bool);
	struct sock___39 * (*udp6_lib_lookup)(struct net___66 *, const struct in6_addr *, __be16, const struct in6_addr *, __be16, int, int, struct udp_table *, struct sk_buff___56 *);
};

struct ip_tunnel_encap_ops___2 {
	size_t (*encap_hlen)(struct ip_tunnel_encap *);
	int (*build_header)(struct sk_buff___56 *, struct ip_tunnel_encap *, u8 *, struct flowi4 *);
};

struct hw_port_info___2 {
	struct net_device___55 *lower_dev;
	u32 port_id;
};

struct metadata_dst___2 {
	struct dst_entry___38 dst;
	enum metadata_type type;
	union {
		struct ip_tunnel_info tun_info;
		struct hw_port_info___2 port_info;
	} u;
};

struct xfrm_replay___4 {
	void (*advance)(struct xfrm_state___4 *, __be32);
	int (*check)(struct xfrm_state___4 *, struct sk_buff___56 *, __be32);
	int (*recheck)(struct xfrm_state___4 *, struct sk_buff___56 *, __be32);
	void (*notify)(struct xfrm_state___4 *, int);
	int (*overflow)(struct xfrm_state___4 *, struct sk_buff___56 *);
};

struct xfrm_type___4 {
	char *description;
	struct module___339 *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___4 *);
	void (*destructor)(struct xfrm_state___4 *);
	int (*input)(struct xfrm_state___4 *, struct sk_buff___56 *);
	int (*output)(struct xfrm_state___4 *, struct sk_buff___56 *);
	int (*reject)(struct xfrm_state___4 *, struct sk_buff___56 *, const struct flowi *);
	int (*hdr_offset)(struct xfrm_state___4 *, struct sk_buff___56 *, u8 **);
	u32 (*get_mtu)(struct xfrm_state___4 *, int);
};

struct xfrm_state_afinfo___4;

struct xfrm_mode___4 {
	int (*input2)(struct xfrm_state___4 *, struct sk_buff___56 *);
	int (*input)(struct xfrm_state___4 *, struct sk_buff___56 *);
	int (*output2)(struct xfrm_state___4 *, struct sk_buff___56 *);
	int (*output)(struct xfrm_state___4 *, struct sk_buff___56 *);
	struct sk_buff___56 * (*gso_segment)(struct xfrm_state___4 *, struct sk_buff___56 *, netdev_features_t);
	void (*xmit)(struct xfrm_state___4 *, struct sk_buff___56 *);
	struct xfrm_state_afinfo___4 *afinfo;
	struct module___339 *owner;
	unsigned int encap;
	int flags;
};

struct xfrm_type_offload___4 {
	char *description;
	struct module___339 *owner;
	u8 proto;
	void (*encap)(struct xfrm_state___4 *, struct sk_buff___56 *);
	int (*input_tail)(struct xfrm_state___4 *, struct sk_buff___56 *);
	int (*xmit)(struct xfrm_state___4 *, struct sk_buff___56 *, netdev_features_t);
};

struct xfrm_state_afinfo___4 {
	unsigned int family;
	unsigned int proto;
	__be16 eth_proto;
	struct module___339 *owner;
	const struct xfrm_type___4 *type_map[256];
	const struct xfrm_type_offload___4 *type_offload_map[256];
	struct xfrm_mode___4 *mode_map[5];
	int (*init_flags)(struct xfrm_state___4 *);
	void (*init_tempsel)(struct xfrm_selector *, const struct flowi *);
	void (*init_temprop)(struct xfrm_state___4 *, const struct xfrm_tmpl *, const xfrm_address_t *, const xfrm_address_t *);
	int (*tmpl_sort)(struct xfrm_tmpl **, struct xfrm_tmpl **, int);
	int (*state_sort)(struct xfrm_state___4 **, struct xfrm_state___4 **, int);
	int (*output)(struct net___66 *, struct sock___39 *, struct sk_buff___56 *);
	int (*output_finish)(struct sock___39 *, struct sk_buff___56 *);
	int (*extract_input)(struct xfrm_state___4 *, struct sk_buff___56 *);
	int (*extract_output)(struct xfrm_state___4 *, struct sk_buff___56 *);
	int (*transport_finish)(struct sk_buff___56 *, int);
	void (*local_error)(struct sk_buff___56 *, u32);
};

struct in_ifaddr {
	struct hlist_node hash;
	struct in_ifaddr *ifa_next;
	struct in_device___2 *ifa_dev;
	struct callback_head callback_head;
	__be32 ifa_local;
	__be32 ifa_address;
	__be32 ifa_mask;
	__u32 ifa_rt_priority;
	__be32 ifa_broadcast;
	unsigned char ifa_scope;
	unsigned char ifa_prefixlen;
	__u32 ifa_flags;
	char ifa_label[16];
	__u32 ifa_valid_lft;
	__u32 ifa_preferred_lft;
	long unsigned int ifa_cstamp;
	long unsigned int ifa_tstamp;
};

struct nf_hook_state___3 {
	unsigned int hook;
	u_int8_t pf;
	struct net_device___55 *in;
	struct net_device___55 *out;
	struct sock___39 *sk;
	struct net___66 *net;
	int (*okfn)(struct net___66 *, struct sock___39 *, struct sk_buff___56 *);
};

struct nf_nat_hook___3 {
	int (*parse_nat_setup)(struct nf_conn *, enum nf_nat_manip_type, const struct nlattr *);
	void (*decode_session)(struct sk_buff___56 *, struct flowi *);
	unsigned int (*manip_pkt)(struct sk_buff___56 *, struct nf_conn *, enum nf_nat_manip_type, enum ip_conntrack_dir);
};

struct nf_ct_hook___3 {
	int (*update)(struct net___66 *, struct sk_buff___56 *);
	void (*destroy)(struct nf_conntrack *);
	bool (*get_tuple_skb)(struct nf_conntrack_tuple *, const struct sk_buff___56 *);
};

struct nfnl_ct_hook___3 {
	struct nf_conn * (*get_ct)(const struct sk_buff___56 *, enum ip_conntrack_info *);
	size_t (*build_size)(const struct nf_conn *);
	int (*build)(struct sk_buff___56 *, struct nf_conn *, enum ip_conntrack_info, u_int16_t, u_int16_t);
	int (*parse)(const struct nlattr *, struct nf_conn *);
	int (*attach_expect)(const struct nlattr *, struct nf_conn *, u32, u32);
	void (*seq_adjust)(struct sk_buff___56 *, struct nf_conn *, enum ip_conntrack_info, s32);
};

struct kimage___24;

typedef void *kexec_load_t___24(struct kimage___24 *, char *, long unsigned int, char *, long unsigned int, char *, long unsigned int);

struct kexec_file_ops___25 {
	kexec_probe_t *probe;
	kexec_load_t___24 *load;
	kexec_cleanup_t *cleanup;
};

struct kimage___24 {
	kimage_entry_t head;
	kimage_entry_t *entry;
	kimage_entry_t *last_entry;
	long unsigned int start;
	struct page___410 *control_code_page;
	struct page___410 *swap_page;
	void *vmcoreinfo_data_copy;
	long unsigned int nr_segments;
	struct kexec_segment segment[16];
	struct list_head control_pages;
	struct list_head dest_pages;
	struct list_head unusable_pages;
	long unsigned int control_page;
	unsigned int type: 1;
	unsigned int preserve_context: 1;
	unsigned int file_mode: 1;
	struct kimage_arch arch;
	void *kernel_buf;
	long unsigned int kernel_buf_len;
	void *initrd_buf;
	long unsigned int initrd_buf_len;
	char *cmdline_buf;
	long unsigned int cmdline_buf_len;
	const struct kexec_file_ops___25 *fops;
	void *image_loader_data;
	struct purgatory_info purgatory_info;
};

struct dev_kfree_skb_cb {
	enum skb_free_reason reason;
};

struct netdev_adjacent {
	struct net_device___55 *dev;
	bool master;
	u16 ref_nr;
	void *private;
	struct list_head list;
	struct callback_head rcu;
};

struct module___340;

struct file___410;

struct kiocb___410;

struct iov_iter___177;

struct poll_table_struct___253;

struct vm_area_struct___411;

struct inode___410;

struct file_lock___410;

struct page___411;

struct pipe_inode_info___91;

struct seq_file___349;

struct file_operations___410 {
	struct module___340 *owner;
	loff_t (*llseek)(struct file___410 *, loff_t, int);
	ssize_t (*read)(struct file___410 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___410 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___410 *, struct iov_iter___177 *);
	ssize_t (*write_iter)(struct kiocb___410 *, struct iov_iter___177 *);
	int (*iopoll)(struct kiocb___410 *, bool);
	int (*iterate)(struct file___410 *, struct dir_context *);
	int (*iterate_shared)(struct file___410 *, struct dir_context *);
	__poll_t (*poll)(struct file___410 *, struct poll_table_struct___253 *);
	long int (*unlocked_ioctl)(struct file___410 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___410 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___410 *, struct vm_area_struct___411 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___410 *, struct file___410 *);
	int (*flush)(struct file___410 *, fl_owner_t);
	int (*release)(struct inode___410 *, struct file___410 *);
	int (*fsync)(struct file___410 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___410 *, int);
	int (*lock)(struct file___410 *, int, struct file_lock___410 *);
	ssize_t (*sendpage)(struct file___410 *, struct page___411 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___410 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___410 *, int, struct file_lock___410 *);
	ssize_t (*splice_write)(struct pipe_inode_info___91 *, struct file___410 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___410 *, loff_t *, struct pipe_inode_info___91 *, size_t, unsigned int);
	int (*setlease)(struct file___410 *, long int, struct file_lock___410 **, void **);
	long int (*fallocate)(struct file___410 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___349 *, struct file___410 *);
	ssize_t (*copy_file_range)(struct file___410 *, loff_t, struct file___410 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___410 *, loff_t, struct file___410 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___410 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___411 {
	u64 seqnum;
	struct vm_area_struct___411 *vmas[4];
};

struct page_frag___411 {
	struct page___411 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___411;

struct mem_cgroup___147;

struct cred___378;

struct nsproxy___305;

struct signal_struct___285;

struct bio_list___204;

struct backing_dev_info___204;

struct css_set___259;

struct vm_struct___314;

struct task_struct___412 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___412 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___411 *mm;
	struct mm_struct___411 *active_mm;
	struct vmacache___411 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___412 *real_parent;
	struct task_struct___412 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___412 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___147 *active_memcg;
	long int rh_reserved2;
	struct pid___234 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___234 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___234 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___378 *ptracer_cred;
	const struct cred___378 *real_cred;
	const struct cred___378 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___305 *nsproxy;
	struct signal_struct___285 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___412 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___204 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___204 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___259 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___91 *splice_pipe;
	struct page_frag___411 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___147 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___412 *oom_reaper_list;
	struct vm_struct___314 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___154 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rw_semaphore___412 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___412 *owner;
};

struct key___378;

struct ucounts___275;

struct user_namespace___275 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___275 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___29 ns;
	long unsigned int flags;
	struct key___378 *persistent_keyring_register;
	struct rw_semaphore___412 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___275 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___411 *pgtable_t___411;

struct address_space___410;

struct dev_pagemap___398;

struct page___411 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___410 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___411 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___411 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___411 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___398 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___147 *mem_cgroup;
};

struct pglist_data___411;

struct lruvec___411 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___411 *pgdat;
};

struct zone___411 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___411 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___411 {
	struct zone___411 *zone;
	int zone_idx;
};

struct zonelist___411 {
	struct zoneref___411 _zonerefs[25];
};

struct pglist_data___411 {
	struct zone___411 node_zones[3];
	struct zonelist___411 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___412 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___412 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___411 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___412 {
	void *stack;
	struct task_struct___412 *task;
	long int status;
};

struct blocking_notifier_head___411 {
	struct rw_semaphore___412 rwsem;
	struct notifier_block *head;
};

struct dentry___410;

struct path___411 {
	struct vfsmount *mnt;
	struct dentry___410 *dentry;
};

struct file___410 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___411 f_path;
	struct inode___410 *f_inode;
	const struct file_operations___410 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___234 f_owner;
	const struct cred___378 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___410 *f_mapping;
	errseq_t f_wb_err;
};

struct user_struct___378;

struct cred___378 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___378 *session_keyring;
	struct key___378 *process_keyring;
	struct key___378 *thread_keyring;
	struct key___378 *request_key_auth;
	void *security;
	struct user_struct___378 *user;
	struct user_namespace___275 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___404;

struct kernfs_elem_dir___404 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___404 *root;
};

struct kernfs_node___405;

struct kernfs_syscall_ops___404;

struct kernfs_root___404 {
	struct kernfs_node___405 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___404 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___404 {
	struct kernfs_node___405 *target_kn;
};

struct kernfs_ops___404;

struct kernfs_elem_attr___404 {
	const struct kernfs_ops___404 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___405 *notify_next;
};

struct kernfs_node___405 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___405 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___404 dir;
		struct kernfs_elem_symlink___404 symlink;
		struct kernfs_elem_attr___404 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___404;

struct kernfs_ops___404 {
	int (*open)(struct kernfs_open_file___404 *);
	void (*release)(struct kernfs_open_file___404 *);
	int (*seq_show)(struct seq_file___349 *, void *);
	void * (*seq_start)(struct seq_file___349 *, loff_t *);
	void * (*seq_next)(struct seq_file___349 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___349 *, void *);
	ssize_t (*read)(struct kernfs_open_file___404 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___404 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___404 *, struct vm_area_struct___411 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___404 *, struct poll_table_struct___253 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___404 {
	int (*remount_fs)(struct kernfs_root___404 *, int *, char *);
	int (*show_options)(struct seq_file___349 *, struct kernfs_root___404 *);
	int (*mkdir)(struct kernfs_node___405 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___405 *);
	int (*rename)(struct kernfs_node___405 *, struct kernfs_node___405 *, const char *);
	int (*show_path)(struct seq_file___349 *, struct kernfs_node___405 *, struct kernfs_root___404 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___349;

struct seq_file___349 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___349 *op;
	int poll_event;
	const struct file___410 *file;
	void *private;
};

struct vm_operations_struct___398;

struct kernfs_open_file___404 {
	struct kernfs_node___405 *kn;
	struct file___410 *file;
	struct seq_file___349 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___398 *vm_ops;
};

struct vm_fault___398;

struct vm_operations_struct___398 {
	void (*open)(struct vm_area_struct___411 *);
	void (*close)(struct vm_area_struct___411 *);
	int (*split)(struct vm_area_struct___411 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___411 *);
	vm_fault_t (*fault)(struct vm_fault___398 *);
	vm_fault_t (*huge_fault)(struct vm_fault___398 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___398 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___411 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___398 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___398 *);
	int (*access)(struct vm_area_struct___411 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___411 *);
	int (*set_policy)(struct vm_area_struct___411 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___411 *, long unsigned int);
	struct page___411 * (*find_special_page)(struct vm_area_struct___411 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___263)(struct file___410 *, wait_queue_head_t *, struct poll_table_struct___253 *);

struct poll_table_struct___253 {
	poll_queue_proc___263 _qproc;
	__poll_t _key;
};

struct vm_area_struct___411 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___411 *vm_next;
	struct vm_area_struct___411 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___411 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___398 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___410 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sock___40;

struct kobj_ns_type_operations___39 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___40 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct net___67;

typedef struct {
	struct net___67 *net;
} possible_net_t___57;

struct proto___39;

struct sock_common___39 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___39 *skc_prot;
	possible_net_t___57 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___40 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___57;

struct sk_buff_head___55 {
	struct sk_buff___57 *next;
	struct sk_buff___57 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___39;

struct socket_wq___40;

struct dst_entry___39;

struct socket___41;

struct net_device___56;

struct sock___40 {
	struct sock_common___39 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___55 sk_error_queue;
	struct sk_buff_head___55 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___57 *head;
		struct sk_buff___57 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___39 *sk_filter;
	union {
		struct socket_wq___40 *sk_wq;
		struct socket_wq___40 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___39 *sk_rx_dst;
	struct dst_entry___39 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___57 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___55 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___411 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___39 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___234 *sk_peer_pid;
	const struct cred___378 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___41 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___147 *sk_memcg;
	void (*sk_state_change)(struct sock___40 *);
	void (*sk_data_ready)(struct sock___40 *);
	void (*sk_write_space)(struct sock___40 *);
	void (*sk_error_report)(struct sock___40 *);
	int (*sk_backlog_rcv)(struct sock___40 *, struct sk_buff___57 *);
	struct sk_buff___57 * (*sk_validate_xmit_skb)(struct sock___40 *, struct net_device___56 *, struct sk_buff___57 *);
	void (*sk_destruct)(struct sock___40 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kobject___398;

struct bin_attribute___374;

struct attribute_group___375 {
	const char *name;
	umode_t (*is_visible)(struct kobject___398 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___398 *, struct bin_attribute___374 *, int);
	struct attribute **attrs;
	struct bin_attribute___374 **bin_attrs;
};

struct kset___397;

struct kobj_type___397;

struct kobject___398 {
	const char *name;
	struct list_head entry;
	struct kobject___398 *parent;
	struct kset___397 *kset;
	struct kobj_type___397 *ktype;
	struct kernfs_node___405 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___374 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___410 *, struct kobject___398 *, struct bin_attribute___374 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___410 *, struct kobject___398 *, struct bin_attribute___374 *, char *, loff_t, size_t);
	int (*mmap)(struct file___410 *, struct kobject___398 *, struct bin_attribute___374 *, struct vm_area_struct___411 *);
};

struct sysfs_ops___397 {
	ssize_t (*show)(struct kobject___398 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___398 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___397;

struct kset___397 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___398 kobj;
	const struct kset_uevent_ops___397 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___397 {
	void (*release)(struct kobject___398 *);
	const struct sysfs_ops___397 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___39 * (*child_ns_type)(struct kobject___398 *);
	const void * (*namespace)(struct kobject___398 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___397 {
	int (* const filter)(struct kset___397 *, struct kobject___398 *);
	const char * (* const name)(struct kset___397 *, struct kobject___398 *);
	int (* const uevent)(struct kset___397 *, struct kobject___398 *, struct kobj_uevent_env *);
};

struct kobj_attribute___388 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___398 *, struct kobj_attribute___388 *, char *);
	ssize_t (*store)(struct kobject___398 *, struct kobj_attribute___388 *, const char *, size_t);
};

struct kernel_param___338;

struct kernel_param_ops___338 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___338 *);
	int (*get)(char *, const struct kernel_param___338 *);
	void (*free)(void *);
};

struct kparam_array___338;

struct kernel_param___338 {
	const char *name;
	struct module___340 *mod;
	const struct kernel_param_ops___338 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___338 *arr;
	};
};

struct kparam_array___338 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___338 *ops;
	void *elem;
};

struct module_kobject___338 {
	struct kobject___398 kobj;
	struct module___340 *mod;
	struct kobject___398 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___338 {
	struct module___340 *mod;
	struct latch_tree_node node;
};

struct module_layout___338 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___338 mtn;
};

struct module_attribute___338;

struct module___340 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___338 mkobj;
	struct module_attribute___338 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___398 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___338 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___338 core_layout;
	struct module_layout___338 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___338 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___338 *, struct module_kobject___338 *, char *);
	ssize_t (*store)(struct module_attribute___338 *, struct module_kobject___338 *, const char *, size_t);
	void (*setup)(struct module___340 *, const char *);
	int (*test)(struct module___340 *);
	void (*free)(struct module___340 *);
};

struct cgroup___259;

struct cgroup_subsys___259;

struct cgroup_subsys_state___259 {
	struct cgroup___259 *cgroup;
	struct cgroup_subsys___259 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___259 *parent;
};

struct cgroup_file___259 {
	struct kernfs_node___405 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___147;

struct mem_cgroup___147 {
	struct cgroup_subsys_state___259 css;
	struct mem_cgroup_id___13 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___259 events_file;
	struct cgroup_file___259 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___412 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___147 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct user_struct___378 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___378 *uid_keyring;
	struct key___378 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___411;

struct mm_struct___411 {
	struct {
		struct vm_area_struct___411 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___410 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___412 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___411 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___412 *owner;
		struct user_namespace___275 *user_ns;
		struct file___410 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___411 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___259;

struct nsproxy___305 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net___67 *net_ns;
	struct cgroup_namespace___259 *cgroup_ns;
};

struct signal_struct___285 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___412 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___412 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___234 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___234 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___411 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___234 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___204;

struct bio_list___204 {
	struct bio___204 *head;
	struct bio___204 *tail;
};

struct bdi_writeback_congested___204;

struct bdi_writeback___204 {
	struct backing_dev_info___204 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___204 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___259 *memcg_css;
	struct cgroup_subsys_state___259 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___378;

struct backing_dev_info___204 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___204 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___378 *dev;
	struct device___378 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___410 *debug_dir;
	struct dentry___410 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___259 {
	struct cgroup_subsys_state___259 *subsys[13];
	refcount_t refcount;
	struct css_set___259 *dom_cset;
	struct cgroup___259 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___259 *mg_src_cgrp;
	struct cgroup___259 *mg_dst_cgrp;
	struct css_set___259 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___410;

struct pipe_buffer___91;

struct pipe_inode_info___91 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___411 *tmp_page;
	struct fasync_struct___410 *fasync_readers;
	struct fasync_struct___410 *fasync_writers;
	struct pipe_buffer___91 *bufs;
	struct user_struct___378 *user;
};

struct vm_struct___314 {
	struct vm_struct___314 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___411 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___297 {
	struct task_struct___412 task;
	long unsigned int stack[8192];
};

struct address_space_operations___410;

struct address_space___410 {
	struct inode___410 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___412 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___410 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___398)(struct vm_area_struct___411 *, long unsigned int, const struct page___411 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___398)(struct page___411 *, void *);

struct dev_pagemap___398 {
	dev_page_fault_t___398 page_fault;
	dev_page_free_t___398 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___378 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___411 {
	struct task_struct___412 *task;
	struct core_thread___411 *next;
};

struct core_state___411 {
	atomic_t nr_threads;
	struct core_thread___411 dumper;
	struct completion startup;
};

struct vm_fault___398 {
	struct vm_area_struct___411 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___411 *cow_page;
	struct mem_cgroup___147 *memcg;
	struct page___411 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___411 prealloc_pte;
};

struct bio_vec___206 {
	struct page___411 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___177 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___206 *bvec;
		struct pipe_inode_info___91 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct msghdr___42 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___177 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___410 *msg_iocb;
};

struct kiocb___410 {
	struct file___410 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___410 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dentry_operations___410;

struct super_block___410;

struct dentry___410 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___410 *d_parent;
	struct qstr d_name;
	struct inode___410 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___410 *d_op;
	struct super_block___410 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___410;

struct block_device___410;

struct inode___410 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___410 *i_op;
	struct super_block___410 *i_sb;
	struct address_space___410 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___412 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___204 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___410 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___410 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___91 *i_pipe;
		struct block_device___410 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___410 {
	int (*d_revalidate)(struct dentry___410 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___410 *, unsigned int);
	int (*d_hash)(const struct dentry___410 *, struct qstr *);
	int (*d_compare)(const struct dentry___410 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___410 *);
	int (*d_init)(struct dentry___410 *);
	void (*d_release)(struct dentry___410 *);
	void (*d_prune)(struct dentry___410 *);
	void (*d_iput)(struct dentry___410 *, struct inode___410 *);
	char * (*d_dname)(struct dentry___410 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___411 *);
	int (*d_manage)(const struct path___411 *, bool);
	struct dentry___410 * (*d_real)(struct dentry___410 *, const struct inode___410 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___410;

struct mem_dqinfo___410 {
	struct quota_format_type___410 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___410;

struct quota_info___410 {
	unsigned int flags;
	struct rw_semaphore___412 dqio_sem;
	struct inode___410 *files[3];
	struct mem_dqinfo___410 info[3];
	const struct quota_format_ops___410 *ops[3];
};

struct rcuwait___410 {
	struct task_struct___412 *task;
};

struct percpu_rw_semaphore___410 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___412 rw_sem;
	struct rcuwait___410 writer;
	int readers_block;
};

struct sb_writers___410 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___410 rw_sem[3];
};

struct shrink_control___147;

struct shrinker___147 {
	long unsigned int (*count_objects)(struct shrinker___147 *, struct shrink_control___147 *);
	long unsigned int (*scan_objects)(struct shrinker___147 *, struct shrink_control___147 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___410;

struct super_operations___410;

struct dquot_operations___410;

struct quotactl_ops___410;

struct super_block___410 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___410 *s_type;
	const struct super_operations___410 *s_op;
	const struct dquot_operations___410 *dq_op;
	const struct quotactl_ops___410 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___410 *s_root;
	struct rw_semaphore___412 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___410 *s_bdev;
	struct backing_dev_info___204 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___410 s_dquot;
	struct sb_writers___410 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___410 *s_d_op;
	int cleancache_poolid;
	struct shrinker___147 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___275 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___147 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___147 *memcg;
};

struct iattr___410 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___410 *ia_file;
};

struct dquot___410 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___410 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___410 {
	int qf_fmt_id;
	const struct quota_format_ops___410 *qf_ops;
	struct module___340 *qf_owner;
	struct quota_format_type___410 *qf_next;
};

struct quota_format_ops___410 {
	int (*check_quota_file)(struct super_block___410 *, int);
	int (*read_file_info)(struct super_block___410 *, int);
	int (*write_file_info)(struct super_block___410 *, int);
	int (*free_file_info)(struct super_block___410 *, int);
	int (*read_dqblk)(struct dquot___410 *);
	int (*commit_dqblk)(struct dquot___410 *);
	int (*release_dqblk)(struct dquot___410 *);
	int (*get_next_id)(struct super_block___410 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___410 {
	int (*write_dquot)(struct dquot___410 *);
	struct dquot___410 * (*alloc_dquot)(struct super_block___410 *, int);
	void (*destroy_dquot)(struct dquot___410 *);
	int (*acquire_dquot)(struct dquot___410 *);
	int (*release_dquot)(struct dquot___410 *);
	int (*mark_dirty)(struct dquot___410 *);
	int (*write_info)(struct super_block___410 *, int);
	qsize_t * (*get_reserved_space)(struct inode___410 *);
	int (*get_projid)(struct inode___410 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___410 *, qsize_t *);
	int (*get_next_id)(struct super_block___410 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___410 {
	int (*quota_on)(struct super_block___410 *, int, int, const struct path___411 *);
	int (*quota_off)(struct super_block___410 *, int);
	int (*quota_enable)(struct super_block___410 *, unsigned int);
	int (*quota_disable)(struct super_block___410 *, unsigned int);
	int (*quota_sync)(struct super_block___410 *, int);
	int (*set_info)(struct super_block___410 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___410 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___410 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___410 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___410 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___410 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___167;

struct address_space_operations___410 {
	int (*writepage)(struct page___411 *, struct writeback_control___167 *);
	int (*readpage)(struct file___410 *, struct page___411 *);
	int (*writepages)(struct address_space___410 *, struct writeback_control___167 *);
	int (*set_page_dirty)(struct page___411 *);
	int (*readpages)(struct file___410 *, struct address_space___410 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___410 *, struct address_space___410 *, loff_t, unsigned int, unsigned int, struct page___411 **, void **);
	int (*write_end)(struct file___410 *, struct address_space___410 *, loff_t, unsigned int, unsigned int, struct page___411 *, void *);
	sector_t (*bmap)(struct address_space___410 *, sector_t);
	void (*invalidatepage)(struct page___411 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___411 *, gfp_t);
	void (*freepage)(struct page___411 *);
	ssize_t (*direct_IO)(struct kiocb___410 *, struct iov_iter___177 *);
	int (*migratepage)(struct address_space___410 *, struct page___411 *, struct page___411 *, enum migrate_mode);
	bool (*isolate_page)(struct page___411 *, isolate_mode_t);
	void (*putback_page)(struct page___411 *);
	int (*launder_page)(struct page___411 *);
	int (*is_partially_uptodate)(struct page___411 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___411 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___410 *, struct page___411 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___410 *, sector_t *);
	void (*swap_deactivate)(struct file___410 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___167 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___204 *wb;
	struct inode___410 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___410 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___410 *bd_inode;
	struct super_block___410 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___410 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___204 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___410 {
	struct dentry___410 * (*lookup)(struct inode___410 *, struct dentry___410 *, unsigned int);
	const char * (*get_link)(struct dentry___410 *, struct inode___410 *, struct delayed_call *);
	int (*permission)(struct inode___410 *, int);
	struct posix_acl * (*get_acl)(struct inode___410 *, int);
	int (*readlink)(struct dentry___410 *, char *, int);
	int (*create)(struct inode___410 *, struct dentry___410 *, umode_t, bool);
	int (*link)(struct dentry___410 *, struct inode___410 *, struct dentry___410 *);
	int (*unlink)(struct inode___410 *, struct dentry___410 *);
	int (*symlink)(struct inode___410 *, struct dentry___410 *, const char *);
	int (*mkdir)(struct inode___410 *, struct dentry___410 *, umode_t);
	int (*rmdir)(struct inode___410 *, struct dentry___410 *);
	int (*mknod)(struct inode___410 *, struct dentry___410 *, umode_t, dev_t);
	int (*rename)(struct inode___410 *, struct dentry___410 *, struct inode___410 *, struct dentry___410 *, unsigned int);
	int (*setattr)(struct dentry___410 *, struct iattr___410 *);
	int (*getattr)(const struct path___411 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___410 *, char *, size_t);
	int (*fiemap)(struct inode___410 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___410 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___410 *, struct dentry___410 *, struct file___410 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___410 *, struct dentry___410 *, umode_t);
	int (*set_acl)(struct inode___410 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___410 {
	void (*fl_copy_lock)(struct file_lock___410 *, struct file_lock___410 *);
	void (*fl_release_private)(struct file_lock___410 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___410;

struct file_lock___410 {
	struct file_lock___410 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___410 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___410 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___410 *fl_ops;
	const struct lock_manager_operations___410 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___410 {
	int (*lm_compare_owner)(struct file_lock___410 *, struct file_lock___410 *);
	long unsigned int (*lm_owner_key)(struct file_lock___410 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___410 *);
	int (*lm_grant)(struct file_lock___410 *, int);
	bool (*lm_break)(struct file_lock___410 *);
	int (*lm_change)(struct file_lock___410 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___410 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___410 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___410 *fa_next;
	struct file___410 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___410 {
	const char *name;
	int fs_flags;
	struct dentry___410 * (*mount)(struct file_system_type___410 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___410 *);
	struct module___340 *owner;
	struct file_system_type___410 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___410 {
	struct inode___410 * (*alloc_inode)(struct super_block___410 *);
	void (*destroy_inode)(struct inode___410 *);
	void (*dirty_inode)(struct inode___410 *, int);
	int (*write_inode)(struct inode___410 *, struct writeback_control___167 *);
	int (*drop_inode)(struct inode___410 *);
	void (*evict_inode)(struct inode___410 *);
	void (*put_super)(struct super_block___410 *);
	int (*sync_fs)(struct super_block___410 *, int);
	int (*freeze_super)(struct super_block___410 *);
	int (*freeze_fs)(struct super_block___410 *);
	int (*thaw_super)(struct super_block___410 *);
	int (*unfreeze_fs)(struct super_block___410 *);
	int (*statfs)(struct dentry___410 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___410 *, int *, char *);
	void (*umount_begin)(struct super_block___410 *);
	int (*show_options)(struct seq_file___349 *, struct dentry___410 *);
	int (*show_devname)(struct seq_file___349 *, struct dentry___410 *);
	int (*show_path)(struct seq_file___349 *, struct dentry___410 *);
	int (*show_stats)(struct seq_file___349 *, struct dentry___410 *);
	ssize_t (*quota_read)(struct super_block___410 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___410 *, int, const char *, size_t, loff_t);
	struct dquot___410 ** (*get_dquots)(struct inode___410 *);
	int (*bdev_try_to_free_page)(struct super_block___410 *, struct page___411 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___410 *, struct shrink_control___147 *);
	long int (*free_cached_objects)(struct super_block___410 *, struct shrink_control___147 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___204(struct bio___204 *);

struct bio_integrity_payload___204;

struct bio_set___204;

struct bio___204 {
	struct bio___204 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___204 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___204 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___206 *bi_io_vec;
	struct bio_set___204 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___206 bi_inline_vecs[0];
};

struct socket_wq___40 {
	wait_queue_head_t wait;
	struct fasync_struct___410 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___40;

struct socket___41 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___40 *wq;
	struct file___410 *file;
	struct sock___40 *sk;
	const struct proto_ops___40 *ops;
};

typedef int (*sk_read_actor_t___39)(read_descriptor_t *, struct sk_buff___57 *, unsigned int, size_t);

struct proto_ops___40 {
	int family;
	struct module___340 *owner;
	int (*release)(struct socket___41 *);
	int (*bind)(struct socket___41 *, struct sockaddr *, int);
	int (*connect)(struct socket___41 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___41 *, struct socket___41 *);
	int (*accept)(struct socket___41 *, struct socket___41 *, int, bool);
	int (*getname)(struct socket___41 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___410 *, struct socket___41 *, struct poll_table_struct___253 *);
	int (*ioctl)(struct socket___41 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___41 *, int);
	int (*shutdown)(struct socket___41 *, int);
	int (*setsockopt)(struct socket___41 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___41 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___41 *, struct msghdr___42 *, size_t);
	int (*recvmsg)(struct socket___41 *, struct msghdr___42 *, size_t, int);
	int (*mmap)(struct file___410 *, struct socket___41 *, struct vm_area_struct___411 *);
	ssize_t (*sendpage)(struct socket___41 *, struct page___411 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___41 *, loff_t *, struct pipe_inode_info___91 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___40 *, int);
	int (*peek_len)(struct socket___41 *);
	int (*read_sock)(struct sock___40 *, read_descriptor_t *, sk_read_actor_t___39);
	int (*sendpage_locked)(struct sock___40 *, struct page___411 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___40 *, struct msghdr___42 *, size_t);
	int (*set_rcvlowat)(struct sock___40 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct nf_bridge_info___55;

struct sk_buff___57 {
	union {
		struct {
			struct sk_buff___57 *next;
			struct sk_buff___57 *prev;
			union {
				struct net_device___56 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___40 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___57 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___55 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___55;

struct netns_frags___55 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___55 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_rules_ops___39;

struct fib_notifier_ops___39;

struct netns_ipv4___55 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___39 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___40 *fibnl;
	struct sock___40 **icmp_sk;
	struct sock___40 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___40 **tcp_sk;
	struct netns_frags___55 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___39 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___39 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___39 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___39;

struct dst_ops___66 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___66 *);
	struct dst_entry___39 * (*check)(struct dst_entry___39 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___39 *);
	unsigned int (*mtu)(const struct dst_entry___39 *);
	u32 * (*cow_metrics)(struct dst_entry___39 *, long unsigned int);
	void (*destroy)(struct dst_entry___39 *);
	void (*ifdown)(struct dst_entry___39 *, struct net_device___56 *, int);
	struct dst_entry___39 * (*negative_advice)(struct dst_entry___39 *);
	void (*link_failure)(struct sk_buff___57 *);
	void (*update_pmtu)(struct dst_entry___39 *, struct sock___40 *, struct sk_buff___57 *, u32);
	void (*redirect)(struct dst_entry___39 *, struct sock___40 *, struct sk_buff___57 *);
	int (*local_out)(struct net___67 *, struct sock___40 *, struct sk_buff___57 *);
	struct neighbour___39 * (*neigh_lookup)(const struct dst_entry___39 *, struct sk_buff___57 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___39 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___66 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___55 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___66 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___39 *fib6_rules_ops;
	struct sock___40 **icmp_sk;
	struct sock___40 *ndisc_sk;
	struct sock___40 *tcp_sk;
	struct sock___40 *igmp_sk;
	struct sock___40 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___39 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___39 *notifier_ops;
	struct fib_notifier_ops___39 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___40 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___40 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___55 {
	struct netns_frags___55 frags;
};

struct netns_xfrm___66 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___40 *nlsk;
	struct sock___40 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___66 xfrm4_dst_ops;
	struct dst_ops___66 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___49;

struct net___67 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___275 *user_ns;
	struct ucounts___275 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___29 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___40 *rtnl;
	struct sock___40 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___56 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___55 ipv4;
	struct netns_ipv6___66 ipv6;
	struct netns_sctp___40 sctp;
	struct netns_nf___4 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___55 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___40 *nfnl;
	struct sock___40 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___66 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___40 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___49 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___378 {
	int (*prepare)(struct device___378 *);
	void (*complete)(struct device___378 *);
	int (*suspend)(struct device___378 *);
	int (*resume)(struct device___378 *);
	int (*freeze)(struct device___378 *);
	int (*thaw)(struct device___378 *);
	int (*poweroff)(struct device___378 *);
	int (*restore)(struct device___378 *);
	int (*suspend_late)(struct device___378 *);
	int (*resume_early)(struct device___378 *);
	int (*freeze_late)(struct device___378 *);
	int (*thaw_early)(struct device___378 *);
	int (*poweroff_late)(struct device___378 *);
	int (*restore_early)(struct device___378 *);
	int (*suspend_noirq)(struct device___378 *);
	int (*resume_noirq)(struct device___378 *);
	int (*freeze_noirq)(struct device___378 *);
	int (*thaw_noirq)(struct device___378 *);
	int (*poweroff_noirq)(struct device___378 *);
	int (*restore_noirq)(struct device___378 *);
	int (*runtime_suspend)(struct device___378 *);
	int (*runtime_resume)(struct device___378 *);
	int (*runtime_idle)(struct device___378 *);
};

struct dev_pm_info___378 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___378 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___378;

struct bus_type___378;

struct device_driver___378;

struct dev_pm_domain___378;

struct dma_map_ops___150;

struct fwnode_handle___298;

struct class___378;

struct device___378 {
	struct device___378 *parent;
	struct device_private *p;
	struct kobject___398 kobj;
	const char *init_name;
	const struct device_type___378 *type;
	struct mutex mutex;
	struct bus_type___378 *bus;
	struct device_driver___378 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___378 power;
	struct dev_pm_domain___378 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___150 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___298 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___378 *class;
	const struct attribute_group___375 **groups;
	void (*release)(struct device___378 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___378 {
	struct dev_pm_ops___378 ops;
	void (*detach)(struct device___378 *, bool);
	int (*activate)(struct device___378 *);
	void (*sync)(struct device___378 *);
	void (*dismiss)(struct device___378 *);
};

struct bus_type___378 {
	const char *name;
	const char *dev_name;
	struct device___378 *dev_root;
	const struct attribute_group___375 **bus_groups;
	const struct attribute_group___375 **dev_groups;
	const struct attribute_group___375 **drv_groups;
	int (*match)(struct device___378 *, struct device_driver___378 *);
	int (*uevent)(struct device___378 *, struct kobj_uevent_env *);
	int (*probe)(struct device___378 *);
	int (*remove)(struct device___378 *);
	void (*shutdown)(struct device___378 *);
	int (*online)(struct device___378 *);
	int (*offline)(struct device___378 *);
	int (*suspend)(struct device___378 *, pm_message_t);
	int (*resume)(struct device___378 *);
	int (*num_vf)(struct device___378 *);
	int (*dma_configure)(struct device___378 *);
	const struct dev_pm_ops___378 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___378 {
	const char *name;
	struct bus_type___378 *bus;
	struct module___340 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___378 *);
	int (*remove)(struct device___378 *);
	void (*shutdown)(struct device___378 *);
	int (*suspend)(struct device___378 *, pm_message_t);
	int (*resume)(struct device___378 *);
	const struct attribute_group___375 **groups;
	const struct dev_pm_ops___378 *pm;
	void (*coredump)(struct device___378 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___378 {
	const char *name;
	const struct attribute_group___375 **groups;
	int (*uevent)(struct device___378 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___378 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___378 *);
	const struct dev_pm_ops___378 *pm;
};

struct class___378 {
	const char *name;
	struct module___340 *owner;
	const struct attribute_group___375 **class_groups;
	const struct attribute_group___375 **dev_groups;
	struct kobject___398 *dev_kobj;
	int (*dev_uevent)(struct device___378 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___378 *, umode_t *);
	void (*class_release)(struct class___378 *);
	void (*dev_release)(struct device___378 *);
	int (*shutdown_pre)(struct device___378 *);
	const struct kobj_ns_type_operations___39 *ns_type;
	const void * (*namespace)(struct device___378 *);
	const struct dev_pm_ops___378 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___150 {
	void * (*alloc)(struct device___378 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___378 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___378 *, struct vm_area_struct___411 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___378 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___378 *, struct page___411 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___378 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___378 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___378 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___378 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___378 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___378 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___378 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___378 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___378 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___378 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___378 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___378 *, u64);
	u64 (*get_required_mask)(struct device___378 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___298;

struct fwnode_handle___298 {
	struct fwnode_handle___298 *secondary;
	const struct fwnode_operations___298 *ops;
};

typedef void compound_page_dtor___398(struct page___411 *);

struct fwnode_reference_args___298;

struct fwnode_endpoint___298;

struct fwnode_operations___298 {
	struct fwnode_handle___298 * (*get)(struct fwnode_handle___298 *);
	void (*put)(struct fwnode_handle___298 *);
	bool (*device_is_available)(const struct fwnode_handle___298 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___298 *, const struct device___378 *);
	bool (*property_present)(const struct fwnode_handle___298 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___298 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___298 *, const char *, const char **, size_t);
	struct fwnode_handle___298 * (*get_parent)(const struct fwnode_handle___298 *);
	struct fwnode_handle___298 * (*get_next_child_node)(const struct fwnode_handle___298 *, struct fwnode_handle___298 *);
	struct fwnode_handle___298 * (*get_named_child_node)(const struct fwnode_handle___298 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___298 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___298 *);
	struct fwnode_handle___298 * (*graph_get_next_endpoint)(const struct fwnode_handle___298 *, struct fwnode_handle___298 *);
	struct fwnode_handle___298 * (*graph_get_remote_endpoint)(const struct fwnode_handle___298 *);
	struct fwnode_handle___298 * (*graph_get_port_parent)(struct fwnode_handle___298 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___298 *, struct fwnode_endpoint___298 *);
};

struct fwnode_endpoint___298 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___298 *local_fwnode;
};

struct fwnode_reference_args___298 {
	struct fwnode_handle___298 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___91;

struct pipe_buffer___91 {
	struct page___411 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___91 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___91 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___91 *, struct pipe_buffer___91 *);
	void (*release)(struct pipe_inode_info___91 *, struct pipe_buffer___91 *);
	int (*steal)(struct pipe_inode_info___91 *, struct pipe_buffer___91 *);
	union {
		bool (*get)(struct pipe_inode_info___91 *, struct pipe_buffer___91 *);
		struct {
			void (*get)(struct pipe_inode_info___91 *, struct pipe_buffer___91 *);
		} __UNIQUE_ID_rh_kabi_hide21;
		union {		};
	};
};

struct nf_bridge_info___55 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___55 = 0,
		BRNF_PROTO_8021Q___55 = 1,
		BRNF_PROTO_PPPOE___55 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___56 *physindev;
	struct net_device___56 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___55(struct sk_buff___57 **);

struct net_device_ops___55;

struct ethtool_ops___55;

struct l3mdev_ops___39;

struct xfrmdev_ops___55;

struct tlsdev_ops___55;

struct header_ops___55;

struct netdev_rx_queue___55;

struct mini_Qdisc___49;

struct netdev_queue___55;

struct Qdisc___49;

struct rtnl_link_ops___49;

struct dcbnl_rtnl_ops___55;

struct phy_device___9;

struct net_device___56 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___55 *netdev_ops;
	const struct ethtool_ops___55 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___39 *l3mdev_ops;
	const struct ndisc_ops___2 *ndisc_ops;
	const struct xfrmdev_ops___55 *xfrmdev_ops;
	const struct tlsdev_ops___55 *tlsdev_ops;
	const struct header_ops___55 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___397 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___2 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___55 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___49 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___55 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___49 *miniq_ingress;
	struct netdev_queue___55 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___55 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___49 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___49 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___55 = 0,
		NETREG_REGISTERED___55 = 1,
		NETREG_UNREGISTERING___55 = 2,
		NETREG_UNREGISTERED___55 = 3,
		NETREG_RELEASED___55 = 4,
		NETREG_DUMMY___55 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___55 = 0,
		RTNL_LINK_INITIALIZING___55 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___56 *);
	struct netpoll_info *npinfo;
	possible_net_t___57 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___378 dev;
	const struct attribute_group___375 *sysfs_groups[4];
	const struct attribute_group___375 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___49 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___55 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device___9 *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide35;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct ethtool_value {
	__u32 cmd;
	__u32 data;
};

enum tunable_id {
	ETHTOOL_ID_UNSPEC = 0,
	ETHTOOL_RX_COPYBREAK = 1,
	ETHTOOL_TX_COPYBREAK = 2,
	ETHTOOL_PFC_PREVENTION_TOUT = 3,
	__ETHTOOL_TUNABLE_COUNT = 4,
};

enum tunable_type_id {
	ETHTOOL_TUNABLE_UNSPEC = 0,
	ETHTOOL_TUNABLE_U8 = 1,
	ETHTOOL_TUNABLE_U16 = 2,
	ETHTOOL_TUNABLE_U32 = 3,
	ETHTOOL_TUNABLE_U64 = 4,
	ETHTOOL_TUNABLE_STRING = 5,
	ETHTOOL_TUNABLE_S8 = 6,
	ETHTOOL_TUNABLE_S16 = 7,
	ETHTOOL_TUNABLE_S32 = 8,
	ETHTOOL_TUNABLE_S64 = 9,
};

enum phy_tunable_id {
	ETHTOOL_PHY_ID_UNSPEC = 0,
	ETHTOOL_PHY_DOWNSHIFT = 1,
	__ETHTOOL_PHY_TUNABLE_COUNT = 2,
};

enum ethtool_stringset {
	ETH_SS_TEST = 0,
	ETH_SS_STATS = 1,
	ETH_SS_PRIV_FLAGS = 2,
	ETH_SS_NTUPLE_FILTERS = 3,
	ETH_SS_FEATURES = 4,
	ETH_SS_RSS_HASH_FUNCS = 5,
	ETH_SS_TUNABLES = 6,
	ETH_SS_PHY_STATS = 7,
	ETH_SS_PHY_TUNABLES = 8,
};

struct ethtool_gstrings {
	__u32 cmd;
	__u32 string_set;
	__u32 len;
	__u8 data[0];
};

struct ethtool_sset_info {
	__u32 cmd;
	__u32 reserved;
	__u64 sset_mask;
	__u32 data[0];
};

struct ethtool_perm_addr {
	__u32 cmd;
	__u32 size;
	__u8 data[0];
};

enum ethtool_flags {
	ETH_FLAG_TXVLAN = 128,
	ETH_FLAG_RXVLAN = 256,
	ETH_FLAG_LRO = 32768,
	ETH_FLAG_NTUPLE = 134217728,
	ETH_FLAG_RXHASH = 268435456,
};

struct ethtool_rxfh {
	__u32 cmd;
	__u32 rss_context;
	__u32 indir_size;
	__u32 key_size;
	__u8 hfunc;
	__u8 rsvd8[3];
	__u32 rsvd32;
	__u32 rss_config[0];
};

struct ethtool_get_features_block {
	__u32 available;
	__u32 requested;
	__u32 active;
	__u32 never_changed;
};

struct ethtool_gfeatures {
	__u32 cmd;
	__u32 size;
	struct ethtool_get_features_block features[0];
};

struct ethtool_set_features_block {
	__u32 valid;
	__u32 requested;
};

struct ethtool_sfeatures {
	__u32 cmd;
	__u32 size;
	struct ethtool_set_features_block features[0];
};

enum ethtool_sfeatures_retval_bits {
	ETHTOOL_F_UNSUPPORTED__BIT = 0,
	ETHTOOL_F_WISH__BIT = 1,
	ETHTOOL_F_COMPAT__BIT = 2,
};

struct ethtool_per_queue_op {
	__u32 cmd;
	__u32 sub_command;
	__u32 queue_mask[128];
	char data[0];
};

enum {
	ETH_RSS_HASH_TOP_BIT = 0,
	ETH_RSS_HASH_XOR_BIT = 1,
	ETH_RSS_HASH_CRC32_BIT = 2,
	ETH_RSS_HASH_FUNCS_COUNT = 3,
};

struct ethtool_ops___55 {
	int (*get_settings)(struct net_device___56 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___56 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___56 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___56 *);
	void (*get_regs)(struct net_device___56 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___56 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___56 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___56 *);
	void (*set_msglevel)(struct net_device___56 *, u32);
	int (*nway_reset)(struct net_device___56 *);
	u32 (*get_link)(struct net_device___56 *);
	int (*get_eeprom_len)(struct net_device___56 *);
	int (*get_eeprom)(struct net_device___56 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___56 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___56 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___56 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___56 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___56 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___56 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___56 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___56 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___56 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___56 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___56 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___56 *);
	void (*complete)(struct net_device___56 *);
	u32 (*get_priv_flags)(struct net_device___56 *);
	int (*set_priv_flags)(struct net_device___56 *, u32);
	int (*get_sset_count)(struct net_device___56 *, int);
	int (*get_rxnfc)(struct net_device___56 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___56 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___56 *, struct ethtool_flash *);
	int (*reset)(struct net_device___56 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___56 *);
	u32 (*get_rxfh_indir_size)(struct net_device___56 *);
	int (*get_rxfh)(struct net_device___56 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___56 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___56 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___56 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___56 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___56 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___56 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___56 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___56 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___56 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___56 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___56 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___56 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___56 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___56 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___56 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___56 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___56 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___56 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___56 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___56 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___56 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	int (*get_fecparam)(struct net_device___56 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___56 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___56 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___56 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___56 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct flow_rule;

struct ethtool_rx_flow_rule {
	struct flow_rule *rule;
	long unsigned int priv[0];
};

struct flow_match {
	struct flow_dissector *dissector;
	void *mask;
	void *key;
};

enum flow_action_id {
	FLOW_ACTION_ACCEPT = 0,
	FLOW_ACTION_DROP = 1,
	FLOW_ACTION_TRAP = 2,
	FLOW_ACTION_GOTO = 3,
	FLOW_ACTION_REDIRECT = 4,
	FLOW_ACTION_MIRRED = 5,
	FLOW_ACTION_VLAN_PUSH = 6,
	FLOW_ACTION_VLAN_POP = 7,
	FLOW_ACTION_VLAN_MANGLE = 8,
	FLOW_ACTION_TUNNEL_ENCAP = 9,
	FLOW_ACTION_TUNNEL_DECAP = 10,
	FLOW_ACTION_MANGLE = 11,
	FLOW_ACTION_ADD = 12,
	FLOW_ACTION_CSUM = 13,
	FLOW_ACTION_MARK = 14,
	FLOW_ACTION_WAKE = 15,
	FLOW_ACTION_QUEUE = 16,
	FLOW_ACTION_SAMPLE = 17,
};

enum flow_action_mangle_base {
	FLOW_ACT_MANGLE_UNSPEC = 0,
	FLOW_ACT_MANGLE_HDR_TYPE_ETH = 1,
	FLOW_ACT_MANGLE_HDR_TYPE_IP4 = 2,
	FLOW_ACT_MANGLE_HDR_TYPE_IP6 = 3,
	FLOW_ACT_MANGLE_HDR_TYPE_TCP = 4,
	FLOW_ACT_MANGLE_HDR_TYPE_UDP = 5,
};

struct ip_tunnel_info___2;

struct psample_group;

struct flow_action_entry {
	enum flow_action_id id;
	union {
		u32 chain_index;
		struct net_device___56 *dev;
		struct {
			u16 vid;
			__be16 proto;
			u8 prio;
		} vlan;
		struct {
			enum flow_action_mangle_base htype;
			u32 offset;
			u32 mask;
			u32 val;
		} mangle;
		const struct ip_tunnel_info___2 *tunnel;
		u32 csum_flags;
		u32 mark;
		struct {
			u32 ctx;
			u32 index;
			u8 vf;
		} queue;
		struct {
			struct psample_group *psample_group;
			u32 rate;
			u32 trunc_size;
			bool truncate;
		} sample;
	};
};

struct flow_action {
	unsigned int num_entries;
	struct flow_action_entry entries[0];
};

struct flow_rule {
	struct flow_match match;
	struct flow_action action;
};

struct ethtool_rx_flow_spec_input {
	const struct ethtool_rx_flow_spec *fs;
	u32 rss_ctx;
};

struct inet_frag_queue___55;

struct inet_frags___55 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___55 *, const void *);
	void (*destructor)(struct inet_frag_queue___55 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___55 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___57 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___57 *fragments_tail;
	struct sk_buff___57 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___55 *net;
	struct callback_head rcu;
};

struct fib_rule___39;

struct fib_lookup_arg___39;

struct fib_rules_ops___39 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___39 *, struct flowi *, int, struct fib_lookup_arg___39 *);
	bool (*suppress)(struct fib_rule___39 *, struct fib_lookup_arg___39 *);
	int (*match)(struct fib_rule___39 *, struct flowi *, int);
	int (*configure)(struct fib_rule___39 *, struct sk_buff___57 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___39 *);
	int (*compare)(struct fib_rule___39 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___39 *, struct sk_buff___57 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___39 *);
	void (*flush_cache)(struct fib_rules_ops___39 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___340 *owner;
	struct net___67 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___39 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___67 *);
	int (*fib_dump)(struct net___67 *, struct notifier_block *);
	struct module___340 *owner;
	struct callback_head rcu;
};

struct dst_entry___39 {
	struct net_device___56 *dev;
	struct dst_ops___66 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___57 *);
	int (*output)(struct net___67 *, struct sock___40 *, struct sk_buff___57 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___39;

struct neigh_parms___39;

struct neigh_ops___39;

struct neighbour___39 {
	struct neighbour___39 *next;
	struct neigh_table___39 *tbl;
	struct neigh_parms___39 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___55 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___39 *, struct sk_buff___57 *);
	const struct neigh_ops___39 *ops;
	struct callback_head rcu;
	struct net_device___56 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct ucounts___275 {
	struct hlist_node node;
	struct user_namespace___275 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_prog_aux___52;

struct bpf_prog___49 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___52 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

typedef int (*key_restrict_link_func_t___379)(struct key___378 *, const struct key_type *, const union key_payload *, struct key___378 *);

struct key_restriction___378;

struct key___378 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___412 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___378 *restrict_link;
};

struct key_restriction___378 {
	key_restrict_link_func_t___379 check;
	struct key___378 *key;
	struct key_type *keytype;
};

struct seq_operations___349 {
	void * (*start)(struct seq_file___349 *, loff_t *);
	void (*stop)(struct seq_file___349 *, void *);
	void * (*next)(struct seq_file___349 *, void *, loff_t *);
	int (*show)(struct seq_file___349 *, void *);
};

struct pernet_operations___56 {
	struct list_head list;
	int (*init)(struct net___67 *);
	void (*exit)(struct net___67 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___55 {
	int (*ieee_getets)(struct net_device___56 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___56 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___56 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___56 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___56 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___56 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___56 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___56 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___56 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___56 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___56 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___56 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___56 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___56 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___56 *);
	u8 (*setstate)(struct net_device___56 *, u8);
	void (*getpermhwaddr)(struct net_device___56 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___56 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___56 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___56 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___56 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___56 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___56 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___56 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___56 *, int, u8 *);
	void (*setpfccfg)(struct net_device___56 *, int, u8);
	void (*getpfccfg)(struct net_device___56 *, int, u8 *);
	u8 (*setall)(struct net_device___56 *);
	u8 (*getcap)(struct net_device___56 *, int, u8 *);
	int (*getnumtcs)(struct net_device___56 *, int, u8 *);
	int (*setnumtcs)(struct net_device___56 *, int, u8);
	u8 (*getpfcstate)(struct net_device___56 *);
	void (*setpfcstate)(struct net_device___56 *, u8);
	void (*getbcncfg)(struct net_device___56 *, int, u32 *);
	void (*setbcncfg)(struct net_device___56 *, int, u32);
	void (*getbcnrp)(struct net_device___56 *, int, u8 *);
	void (*setbcnrp)(struct net_device___56 *, int, u8);
	int (*setapp)(struct net_device___56 *, u8, u16, u8);
	int (*getapp)(struct net_device___56 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___56 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___56 *, int, u8);
	u8 (*getdcbx)(struct net_device___56 *);
	u8 (*setdcbx)(struct net_device___56 *, u8);
	int (*peer_getappinfo)(struct net_device___56 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___56 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___56 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___56 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___56 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___56 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___259 {
	refcount_t count;
	struct ns_common___29 ns;
	struct user_namespace___275 *user_ns;
	struct ucounts___275 *ucounts;
	struct css_set___259 *root_cset;
};

struct bpf_map___260;

struct bpf_map_ops___259 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___260 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___260 *, struct file___410 *);
	void (*map_free)(struct bpf_map___260 *);
	int (*map_get_next_key)(struct bpf_map___260 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___260 *);
	void * (*map_lookup_elem)(struct bpf_map___260 *, void *);
	int (*map_update_elem)(struct bpf_map___260 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___260 *, void *);
	int (*map_push_elem)(struct bpf_map___260 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___260 *, void *);
	int (*map_peek_elem)(struct bpf_map___260 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___260 *, struct file___410 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___260 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___260 *, void *, struct seq_file___349 *);
	int (*map_check_btf)(const struct bpf_map___260 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___260 {
	const struct bpf_map_ops___259 *ops;
	struct bpf_map___260 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___378 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___55;

struct bpf_map_dev_ops___55 {
	int (*map_get_next_key)(struct bpf_offloaded_map___55 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___55 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___55 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___55 *, void *);
};

struct bpf_offloaded_map___55 {
	struct bpf_map___260 map;
	struct net_device___56 *netdev;
	const struct bpf_map_dev_ops___55 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___49 {
	int (*test_run)(struct bpf_prog___49 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___49 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___49 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___49 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___49 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___49 *, u32 *);
};

struct bpf_prog_offload_ops___49 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___49 *);
	int (*translate)(struct bpf_prog___49 *);
	void (*destroy)(struct bpf_prog___49 *);
};

struct bpf_prog_offload___49 {
	struct bpf_prog___49 *prog;
	struct net_device___56 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___49 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___52 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___49 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___49 *ops;
	struct bpf_map___260 **used_maps;
	struct bpf_prog___49 *prog;
	struct user_struct___378 *user;
	u64 load_time;
	struct bpf_map___260 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___49 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___49 {
	struct bpf_prog___49 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___49 {
	struct callback_head rcu;
	struct bpf_prog_array_item___49 items[0];
};

struct cgroup_bpf___49 {
	struct bpf_prog_array___49 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___49 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___260;

typedef void (*kthread_work_func_t___260)(struct kthread_work___260 *);

struct kthread_worker___260;

struct kthread_work___260 {
	struct list_head node;
	kthread_work_func_t___260 func;
	struct kthread_worker___260 *worker;
	int canceling;
};

struct kthread_worker___260 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___412 *task;
	struct kthread_work___260 *current_work;
};

struct kthread_delayed_work___259 {
	struct kthread_work___260 work;
	struct timer_list timer;
};

struct psi_group___259 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___260 *poll_kworker;
	struct kthread_delayed_work___259 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___259;

struct cgroup_rstat_cpu___259;

struct cgroup___259 {
	struct cgroup_subsys_state___259 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___405 *kn;
	struct cgroup_file___259 procs_file;
	struct cgroup_file___259 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___259 *subsys[13];
	struct cgroup_root___259 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___259 *dom_cgrp;
	struct cgroup_rstat_cpu___259 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___49 bpf;
	atomic_t congestion_count;
	struct cgroup___259 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___259 psi;
	int ancestor_ids[0];
};

struct cftype___259;

struct cgroup_subsys___259 {
	struct cgroup_subsys_state___259 * (*css_alloc)(struct cgroup_subsys_state___259 *);
	int (*css_online)(struct cgroup_subsys_state___259 *);
	void (*css_offline)(struct cgroup_subsys_state___259 *);
	void (*css_released)(struct cgroup_subsys_state___259 *);
	void (*css_free)(struct cgroup_subsys_state___259 *);
	void (*css_reset)(struct cgroup_subsys_state___259 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___259 *, int);
	int (*css_extra_stat_show)(struct seq_file___349 *, struct cgroup_subsys_state___259 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___412 *);
	void (*cancel_fork)(struct task_struct___412 *);
	void (*fork)(struct task_struct___412 *);
	void (*exit)(struct task_struct___412 *);
	void (*free)(struct task_struct___412 *);
	void (*bind)(struct cgroup_subsys_state___259 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___259 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___259 *dfl_cftypes;
	struct cftype___259 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___259 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___259 *updated_children;
	struct cgroup___259 *updated_next;
};

struct cgroup_root___259 {
	struct kernfs_root___404 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___259 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___259 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___259 *ss;
	struct list_head node;
	struct kernfs_ops___404 *kf_ops;
	int (*open)(struct kernfs_open_file___404 *);
	void (*release)(struct kernfs_open_file___404 *);
	u64 (*read_u64)(struct cgroup_subsys_state___259 *, struct cftype___259 *);
	s64 (*read_s64)(struct cgroup_subsys_state___259 *, struct cftype___259 *);
	int (*seq_show)(struct seq_file___349 *, void *);
	void * (*seq_start)(struct seq_file___349 *, loff_t *);
	void * (*seq_next)(struct seq_file___349 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___349 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___259 *, struct cftype___259 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___259 *, struct cftype___259 *, s64);
	ssize_t (*write)(struct kernfs_open_file___404 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___404 *, struct poll_table_struct___253 *);
};

struct xdp_rxq_info___55 {
	struct net_device___56 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___55 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___56 *dev_rx;
};

struct netlink_callback___57 {
	struct sk_buff___57 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___57 *);
	int (*dump)(struct sk_buff___57 *, struct netlink_callback___57 *);
	int (*done)(struct netlink_callback___57 *);
	void *data;
	struct module___340 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___55 {
	int (*create)(struct sk_buff___57 *, struct net_device___56 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___57 *, unsigned char *);
	int (*cache)(const struct neighbour___39 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___56 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___55 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___55 *, int);
	int poll_owner;
	struct net_device___56 *dev;
	struct sk_buff___57 *gro_list;
	struct sk_buff___57 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct xdp_umem___2 {
	struct xsk_queue *fq;
	struct xsk_queue *cq;
	struct xdp_umem_page *pages;
	u64 chunk_mask;
	u64 size;
	u32 headroom;
	u32 chunk_size_nohr;
	struct user_struct___378 *user;
	struct pid___234 *pid;
	long unsigned int address;
	refcount_t users;
	struct work_struct work;
	struct page___411 **pgs;
	u32 npgs;
	struct net_device___56 *dev;
	struct xdp_umem_fq_reuse *fq_reuse;
	u16 queue_id;
	bool zc;
	spinlock_t xsk_list_lock;
	struct list_head xsk_list;
};

struct netdev_queue___55 {
	struct net_device___56 *dev;
	struct Qdisc___49 *qdisc;
	struct Qdisc___49 *qdisc_sleeping;
	struct kobject___398 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___56 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem___2 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___49 {
	struct sk_buff___57 *head;
	struct sk_buff___57 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___49;

struct Qdisc___49 {
	int (*enqueue)(struct sk_buff___57 *, struct Qdisc___49 *, struct sk_buff___57 **);
	struct sk_buff___57 * (*dequeue)(struct Qdisc___49 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___49 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___55 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___55 gso_skb;
	struct qdisc_skb_head___49 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___49 *next_sched;
	struct sk_buff_head___55 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___55 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___398 kobj;
	struct net_device___56 *dev;
	long: 64;
	struct xdp_rxq_info___55 xdp_rxq;
	union {
		struct xdp_umem___2 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___55)(struct net_device___56 *, struct sk_buff___57 *, struct net_device___56 *);

struct netdev_bpf___55 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___49 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___49 *prog;
			const struct bpf_prog_offload_ops___49 *ops;
		} verifier;
		struct {
			struct bpf_prog___49 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___55 *offmap;
		};
		struct {
			struct xdp_umem___2 *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___55 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___57 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___55 {
	int (*tls_dev_add)(struct net_device___56 *, struct sock___40 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___56 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___56 *, struct sock___40 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___55 {
	int (*ndo_init)(struct net_device___56 *);
	void (*ndo_uninit)(struct net_device___56 *);
	int (*ndo_open)(struct net_device___56 *);
	int (*ndo_stop)(struct net_device___56 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___57 *, struct net_device___56 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___57 *, struct net_device___56 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___56 *, struct sk_buff___57 *, struct net_device___56 *, select_queue_fallback_t___55);
	void (*ndo_change_rx_flags)(struct net_device___56 *, int);
	void (*ndo_set_rx_mode)(struct net_device___56 *);
	int (*ndo_set_mac_address)(struct net_device___56 *, void *);
	int (*ndo_validate_addr)(struct net_device___56 *);
	int (*ndo_do_ioctl)(struct net_device___56 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___56 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___56 *, int);
	int (*ndo_neigh_setup)(struct net_device___56 *, struct neigh_parms___39 *);
	void (*ndo_tx_timeout)(struct net_device___56 *);
	void (*ndo_get_stats64)(struct net_device___56 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___56 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___56 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___56 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___56 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___56 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___56 *);
	int (*ndo_netpoll_setup)(struct net_device___56 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___56 *);
	int (*ndo_set_vf_mac)(struct net_device___56 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___56 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___56 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___56 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___56 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___56 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___56 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___56 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___56 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___56 *, int, struct sk_buff___57 *);
	int (*ndo_set_vf_guid)(struct net_device___56 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___56 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___56 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___56 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___56 *, const struct sk_buff___57 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___56 *, struct net_device___56 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___56 *, struct net_device___56 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___56 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___56 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___56 *, struct neighbour___39 *);
	void (*ndo_neigh_destroy)(struct net_device___56 *, struct neighbour___39 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___56 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___56 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___56 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___57 *, struct netlink_callback___57 *, struct net_device___56 *, struct net_device___56 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___56 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___56 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___57 *, u32, u32, struct net_device___56 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___56 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___56 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___56 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___56 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___56 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___56 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___56 *, struct net_device___56 *);
	void (*ndo_dfwd_del_station)(struct net_device___56 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___56 *);
	int (*ndo_set_tx_maxrate)(struct net_device___56 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___56 *);
	int (*ndo_change_proto_down)(struct net_device___56 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___56 *, struct sk_buff___57 *);
	void (*ndo_set_rx_headroom)(struct net_device___56 *, int);
	int (*ndo_bpf)(struct net_device___56 *, struct netdev_bpf___55 *);
	int (*ndo_xdp_xmit)(struct net_device___56 *, int, struct xdp_frame___55 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___56 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___56 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___39 {
	possible_net_t___57 net;
	struct net_device___56 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___39 *);
	void (*neigh_cleanup)(struct neighbour___39 *);
	struct neigh_table___39 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___39 {
	u32 (*l3mdev_fib_table)(const struct net_device___56 *);
	struct sk_buff___57 * (*l3mdev_l3_rcv)(struct net_device___56 *, struct sk_buff___57 *, u16);
	struct sk_buff___57 * (*l3mdev_l3_out)(struct net_device___56 *, struct sock___40 *, struct sk_buff___57 *, u16);
	struct dst_entry___39 * (*l3mdev_link_scope_lookup)(const struct net_device___56 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct tcf_proto___49;

struct mini_Qdisc___49 {
	struct tcf_proto___49 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___49 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___56 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___67 *, struct net_device___56 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___56 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___56 *, struct list_head *);
	size_t (*get_size)(const struct net_device___56 *);
	int (*fill_info)(struct sk_buff___57 *, const struct net_device___56 *);
	size_t (*get_xstats_size)(const struct net_device___56 *);
	int (*fill_xstats)(struct sk_buff___57 *, const struct net_device___56 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___56 *, struct net_device___56 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___56 *, const struct net_device___56 *);
	int (*fill_slave_info)(struct sk_buff___57 *, const struct net_device___56 *, const struct net_device___56 *);
	struct net___67 * (*get_link_net)(const struct net_device___56 *);
	size_t (*get_linkxstats_size)(const struct net_device___56 *, int);
	int (*fill_linkxstats)(struct sk_buff___57 *, const struct net_device___56 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct mii_bus___9;

struct mdio_device___9 {
	struct device___378 dev;
	struct mii_bus___9 *bus;
	char modalias[32];
	int (*bus_match)(struct device___378 *, struct device_driver___378 *);
	void (*device_free)(struct mdio_device___9 *);
	void (*device_remove)(struct mdio_device___9 *);
	int addr;
	int flags;
	struct gpio_desc *reset;
	unsigned int reset_assert_delay;
	unsigned int reset_deassert_delay;
};

struct phy_driver___9;

struct phy_device___9 {
	struct mdio_device___9 mdio;
	struct phy_driver___9 *drv;
	u32 phy_id;
	struct phy_c45_device_ids c45_ids;
	unsigned int is_c45: 1;
	unsigned int is_internal: 1;
	unsigned int is_pseudo_fixed_link: 1;
	unsigned int has_fixups: 1;
	unsigned int suspended: 1;
	unsigned int sysfs_links: 1;
	unsigned int loopback_enabled: 1;
	unsigned int autoneg: 1;
	unsigned int link: 1;
	enum phy_state state;
	u32 dev_flags;
	phy_interface_t interface;
	int speed;
	int duplex;
	int pause;
	int asym_pause;
	u32 interrupts;
	u32 rh_reserved_supported;
	u32 rh_reserved_advertising;
	u32 rh_reserved_lp_advertising;
	u32 eee_broken_modes;
	int link_timeout;
	struct phy_led_trigger *phy_led_triggers;
	unsigned int phy_num_led_triggers;
	struct phy_led_trigger *last_triggered;
	struct phy_led_trigger *led_link_trigger;
	int irq;
	void *priv;
	struct work_struct phy_queue;
	struct delayed_work state_queue;
	struct mutex lock;
	struct phylink *phylink;
	struct net_device___56 *attached_dev;
	u8 mdix;
	u8 mdix_ctrl;
	long unsigned int supported[2];
	long unsigned int advertising[2];
	long unsigned int lp_advertising[2];
	void (*phy_link_change)(struct phy_device___9 *, bool, bool);
	void (*adjust_link)(struct net_device___56 *);
};

struct softnet_data___55 {
	struct list_head poll_list;
	struct sk_buff_head___55 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___55 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___49 *output_queue;
	struct Qdisc___49 **output_queue_tailp;
	struct sk_buff___57 *completion_queue;
	struct sk_buff_head___55 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___55 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___55 input_pkt_queue;
	struct napi_struct___55 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct mii_bus___9 {
	struct module___340 *owner;
	const char *name;
	char id[61];
	void *priv;
	int (*read)(struct mii_bus___9 *, int, int);
	int (*write)(struct mii_bus___9 *, int, int, u16);
	int (*reset)(struct mii_bus___9 *);
	struct mutex mdio_lock;
	struct device___378 *parent;
	enum {
		MDIOBUS_ALLOCATED___9 = 1,
		MDIOBUS_REGISTERED___9 = 2,
		MDIOBUS_UNREGISTERED___9 = 3,
		MDIOBUS_RELEASED___9 = 4,
	} state;
	struct device___378 dev;
	struct mdio_device___9 *mdio_map[32];
	u32 phy_mask;
	u32 phy_ignore_ta_mask;
	int irq[32];
	int reset_delay_us;
	struct gpio_desc *reset_gpiod;
};

struct mdio_driver_common___9 {
	struct device_driver___378 driver;
	int flags;
};

struct phy_driver___9 {
	struct mdio_driver_common___9 mdiodrv;
	u32 phy_id;
	char *name;
	u32 phy_id_mask;
	u32 rh_reserved_features;
	u32 flags;
	const void *driver_data;
	const long unsigned int * const features;
	int (*soft_reset)(struct phy_device___9 *);
	int (*config_init)(struct phy_device___9 *);
	int (*probe)(struct phy_device___9 *);
	int (*suspend)(struct phy_device___9 *);
	int (*resume)(struct phy_device___9 *);
	int (*config_aneg)(struct phy_device___9 *);
	int (*aneg_done)(struct phy_device___9 *);
	int (*read_status)(struct phy_device___9 *);
	int (*ack_interrupt)(struct phy_device___9 *);
	int (*config_intr)(struct phy_device___9 *);
	int (*did_interrupt)(struct phy_device___9 *);
	void (*remove)(struct phy_device___9 *);
	int (*match_phy_device)(struct phy_device___9 *);
	int (*ts_info)(struct phy_device___9 *, struct ethtool_ts_info *);
	int (*hwtstamp)(struct phy_device___9 *, struct ifreq *);
	bool (*rxtstamp)(struct phy_device___9 *, struct sk_buff___57 *, int);
	void (*txtstamp)(struct phy_device___9 *, struct sk_buff___57 *, int);
	int (*set_wol)(struct phy_device___9 *, struct ethtool_wolinfo *);
	void (*get_wol)(struct phy_device___9 *, struct ethtool_wolinfo *);
	void (*link_change_notify)(struct phy_device___9 *);
	int (*read_mmd)(struct phy_device___9 *, int, u16);
	int (*write_mmd)(struct phy_device___9 *, int, u16, u16);
	int (*read_page)(struct phy_device___9 *);
	int (*write_page)(struct phy_device___9 *, int);
	int (*module_info)(struct phy_device___9 *, struct ethtool_modinfo *);
	int (*module_eeprom)(struct phy_device___9 *, struct ethtool_eeprom *, u8 *);
	int (*get_sset_count)(struct phy_device___9 *);
	void (*get_strings)(struct phy_device___9 *, u8 *);
	void (*get_stats)(struct phy_device___9 *, struct ethtool_stats *, u64 *);
	int (*get_tunable)(struct phy_device___9 *, struct ethtool_tunable *, void *);
	int (*set_tunable)(struct phy_device___9 *, struct ethtool_tunable *, const void *);
	int (*set_loopback)(struct phy_device___9 *, bool);
};

struct bdi_writeback_congested___204 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___204 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___204 {
	struct bio___204 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___206 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___206 bip_inline_vecs[0];
};

struct bio_set___204 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___204 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___147 {
	struct mem_cgroup___147 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___147 {
	struct lruvec___411 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___147 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___147 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct gnet_dump___49 {
	spinlock_t *lock;
	struct sk_buff___57 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___49;

struct Qdisc_ops___49 {
	struct Qdisc_ops___49 *next;
	const struct Qdisc_class_ops___49 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___57 *, struct Qdisc___49 *, struct sk_buff___57 **);
	struct sk_buff___57 * (*dequeue)(struct Qdisc___49 *);
	struct sk_buff___57 * (*peek)(struct Qdisc___49 *);
	int (*init)(struct Qdisc___49 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___49 *);
	void (*destroy)(struct Qdisc___49 *);
	int (*change)(struct Qdisc___49 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___49 *);
	int (*change_tx_queue_len)(struct Qdisc___49 *, unsigned int);
	int (*dump)(struct Qdisc___49 *, struct sk_buff___57 *);
	int (*dump_stats)(struct Qdisc___49 *, struct gnet_dump___49 *);
	void (*ingress_block_set)(struct Qdisc___49 *, u32);
	void (*egress_block_set)(struct Qdisc___49 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___49 *);
	u32 (*egress_block_get)(struct Qdisc___49 *);
	struct module___340 *owner;
};

struct tcf_block___49;

struct Qdisc_class_ops___49 {
	unsigned int flags;
	struct netdev_queue___55 * (*select_queue)(struct Qdisc___49 *, struct tcmsg *);
	int (*graft)(struct Qdisc___49 *, long unsigned int, struct Qdisc___49 *, struct Qdisc___49 **, struct netlink_ext_ack *);
	struct Qdisc___49 * (*leaf)(struct Qdisc___49 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___49 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___49 *, u32);
	int (*change)(struct Qdisc___49 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___49 *, long unsigned int);
	void (*walk)(struct Qdisc___49 *, struct qdisc_walker *);
	struct tcf_block___49 * (*tcf_block)(struct Qdisc___49 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___49 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___49 *, long unsigned int);
	int (*dump)(struct Qdisc___49 *, long unsigned int, struct sk_buff___57 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___49 *, long unsigned int, struct gnet_dump___49 *);
};

struct tcf_chain___49;

struct tcf_block___49 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___67 *net;
	struct Qdisc___49 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___49 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___49;

struct tcf_proto_ops___49;

struct tcf_proto___49 {
	struct tcf_proto___49 *next;
	void *root;
	int (*classify)(struct sk_buff___57 *, const struct tcf_proto___49 *, struct tcf_result___49 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___49 *ops;
	struct tcf_chain___49 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___49 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___49 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___49 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___57 *, const struct tcf_proto___49 *, struct tcf_result___49 *);
	int (*init)(struct tcf_proto___49 *);
	void (*destroy)(struct tcf_proto___49 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___49 *, u32);
	void (*put)(struct tcf_proto___49 *, void *);
	int (*change)(struct net___67 *, struct sk_buff___57 *, struct tcf_proto___49 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___49 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___49 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___49 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___67 *, struct tcf_chain___49 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___67 *, struct tcf_proto___49 *, void *, struct sk_buff___57 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___57 *, struct net___67 *, void *);
	struct module___340 *owner;
	int flags;
};

struct tcf_chain___49 {
	struct mutex filter_chain_lock;
	struct tcf_proto___49 *filter_chain;
	struct list_head list;
	struct tcf_block___49 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___49 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___39 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___49 *prog;
};

struct bpf_redirect_info___49 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___260 *map;
	struct bpf_map___260 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___39;

struct neigh_hash_table___39;

struct neigh_table___39 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___56 *, __u32 *);
	bool (*key_eq)(const struct neighbour___39 *, const void *);
	int (*constructor)(struct neighbour___39 *);
	int (*pconstructor)(struct pneigh_entry___39 *);
	void (*pdestructor)(struct pneigh_entry___39 *);
	void (*proxy_redo)(struct sk_buff___57 *);
	char *id;
	struct neigh_parms___39 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___55 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___39 *nht;
	struct pneigh_entry___39 **phash_buckets;
};

struct neigh_ops___39 {
	int family;
	void (*solicit)(struct neighbour___39 *, struct sk_buff___57 *);
	void (*error_report)(struct neighbour___39 *, struct sk_buff___57 *);
	int (*output)(struct neighbour___39 *, struct sk_buff___57 *);
	int (*connected_output)(struct neighbour___39 *, struct sk_buff___57 *);
};

struct pneigh_entry___39 {
	struct pneigh_entry___39 *next;
	possible_net_t___57 net;
	struct net_device___56 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___39 {
	struct neighbour___39 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___39 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___39 *ctarget;
	struct net___67 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___39 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___39 *rule;
	u32 table;
	int flags;
};

struct proto___39 {
	void (*close)(struct sock___40 *, long int);
	int (*pre_connect)(struct sock___40 *, struct sockaddr *, int);
	int (*connect)(struct sock___40 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___40 *, int);
	struct sock___40 * (*accept)(struct sock___40 *, int, int *, bool);
	int (*ioctl)(struct sock___40 *, int, long unsigned int);
	int (*init)(struct sock___40 *);
	void (*destroy)(struct sock___40 *);
	void (*shutdown)(struct sock___40 *, int);
	int (*setsockopt)(struct sock___40 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___40 *, int, int, char *, int *);
	void (*keepalive)(struct sock___40 *, int);
	int (*sendmsg)(struct sock___40 *, struct msghdr___42 *, size_t);
	int (*recvmsg)(struct sock___40 *, struct msghdr___42 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___40 *, struct page___411 *, int, size_t, int);
	int (*bind)(struct sock___40 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___40 *, struct sk_buff___57 *);
	void (*release_cb)(struct sock___40 *);
	int (*hash)(struct sock___40 *);
	void (*unhash)(struct sock___40 *);
	void (*rehash)(struct sock___40 *);
	int (*get_port)(struct sock___40 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___40 *);
	bool (*stream_memory_read)(const struct sock___40 *);
	void (*enter_memory_pressure)(struct sock___40 *);
	void (*leave_memory_pressure)(struct sock___40 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___3 *rsk_prot;
	struct timewait_sock_ops___3 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___340 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___40 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct ethtool_link_usettings {
	struct ethtool_link_settings base;
	struct {
		__u32 supported[3];
		__u32 advertising[3];
		__u32 lp_advertising[3];
	} link_modes;
};

struct ethtool_rx_flow_key {
	struct flow_dissector_key_basic basic;
	union {
		struct flow_dissector_key_ipv4_addrs ipv4;
		struct flow_dissector_key_ipv6_addrs ipv6;
	};
	struct flow_dissector_key_ports tp;
	struct flow_dissector_key_ip ip;
	struct flow_dissector_key_vlan vlan;
	struct flow_dissector_key_eth_addrs eth_addrs;
	long: 48;
};

struct ethtool_rx_flow_match {
	struct flow_dissector dissector;
	int: 32;
	struct ethtool_rx_flow_key key;
	struct ethtool_rx_flow_key mask;
};

struct netdev_hw_addr {
	struct list_head list;
	unsigned char addr[32];
	unsigned char type;
	bool global_use;
	int sync_cnt;
	int refcount;
	int synced;
	struct callback_head callback_head;
};

struct module___341;

struct file___411;

struct kiocb___411;

struct iov_iter___178;

struct poll_table_struct___254;

struct vm_area_struct___412;

struct inode___411;

struct file_lock___411;

struct page___412;

struct pipe_inode_info___92;

struct seq_file___350;

struct file_operations___411 {
	struct module___341 *owner;
	loff_t (*llseek)(struct file___411 *, loff_t, int);
	ssize_t (*read)(struct file___411 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___411 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___411 *, struct iov_iter___178 *);
	ssize_t (*write_iter)(struct kiocb___411 *, struct iov_iter___178 *);
	int (*iopoll)(struct kiocb___411 *, bool);
	int (*iterate)(struct file___411 *, struct dir_context *);
	int (*iterate_shared)(struct file___411 *, struct dir_context *);
	__poll_t (*poll)(struct file___411 *, struct poll_table_struct___254 *);
	long int (*unlocked_ioctl)(struct file___411 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___411 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___411 *, struct vm_area_struct___412 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___411 *, struct file___411 *);
	int (*flush)(struct file___411 *, fl_owner_t);
	int (*release)(struct inode___411 *, struct file___411 *);
	int (*fsync)(struct file___411 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___411 *, int);
	int (*lock)(struct file___411 *, int, struct file_lock___411 *);
	ssize_t (*sendpage)(struct file___411 *, struct page___412 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___411 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___411 *, int, struct file_lock___411 *);
	ssize_t (*splice_write)(struct pipe_inode_info___92 *, struct file___411 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___411 *, loff_t *, struct pipe_inode_info___92 *, size_t, unsigned int);
	int (*setlease)(struct file___411 *, long int, struct file_lock___411 **, void **);
	long int (*fallocate)(struct file___411 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___350 *, struct file___411 *);
	ssize_t (*copy_file_range)(struct file___411 *, loff_t, struct file___411 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___411 *, loff_t, struct file___411 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___411 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___412 {
	u64 seqnum;
	struct vm_area_struct___412 *vmas[4];
};

struct page_frag___412 {
	struct page___412 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___412;

struct mem_cgroup___148;

struct pid___235;

struct cred___379;

struct nsproxy___306;

struct signal_struct___286;

struct bio_list___205;

struct backing_dev_info___205;

struct css_set___260;

struct vm_struct___315;

struct task_struct___413 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___413 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___412 *mm;
	struct mm_struct___412 *active_mm;
	struct vmacache___412 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___413 *real_parent;
	struct task_struct___413 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___413 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___148 *active_memcg;
	long int rh_reserved2;
	struct pid___235 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___235 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___235 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___379 *ptracer_cred;
	const struct cred___379 *real_cred;
	const struct cred___379 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___306 *nsproxy;
	struct signal_struct___286 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___413 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___205 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___205 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___260 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___92 *splice_pipe;
	struct page_frag___412 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___148 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___413 *oom_reaper_list;
	struct vm_struct___315 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___154 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct secondary_data___413 {
	void *stack;
	struct task_struct___413 *task;
	long int status;
};

typedef struct page___412 *pgtable_t___412;

struct address_space___411;

struct dev_pagemap___399;

struct page___412 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___411 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___412 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___412 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___412 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___399 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___148 *mem_cgroup;
};

struct pglist_data___412;

struct lruvec___412 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___412 *pgdat;
};

struct zone___412 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___412 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___412 {
	struct zone___412 *zone;
	int zone_idx;
};

struct zonelist___412 {
	struct zoneref___412 _zonerefs[25];
};

struct pglist_data___412 {
	struct zone___412 node_zones[3];
	struct zonelist___412 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___413 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___413 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___412 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___413 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___413 *owner;
};

struct blocking_notifier_head___412 {
	struct rw_semaphore___413 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___399;

struct vm_area_struct___412 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___412 *vm_next;
	struct vm_area_struct___412 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___412 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___399 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___411 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___412;

struct user_namespace___276;

struct mm_struct___412 {
	struct {
		struct vm_area_struct___412 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___411 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___413 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___412 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___413 *owner;
		struct user_namespace___276 *user_ns;
		struct file___411 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___412 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___411;

struct address_space___411 {
	struct inode___411 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___413 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___411 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___399)(struct vm_area_struct___412 *, long unsigned int, const struct page___412 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___399)(struct page___412 *, void *);

struct device___379;

struct dev_pagemap___399 {
	dev_page_fault_t___399 page_fault;
	dev_page_free_t___399 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___379 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct cgroup___260;

struct cgroup_subsys___260;

struct cgroup_subsys_state___260 {
	struct cgroup___260 *cgroup;
	struct cgroup_subsys___260 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___260 *parent;
};

struct kernfs_node___406;

struct cgroup_file___260 {
	struct kernfs_node___406 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___148;

struct mem_cgroup___148 {
	struct cgroup_subsys_state___260 css;
	struct mem_cgroup_id___13 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___260 events_file;
	struct cgroup_file___260 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___413 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___148 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry___411;

struct path___412 {
	struct vfsmount *mnt;
	struct dentry___411 *dentry;
};

struct fown_struct___235 {
	rwlock_t lock;
	struct pid___235 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___411 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___412 f_path;
	struct inode___411 *f_inode;
	const struct file_operations___411 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___235 f_owner;
	const struct cred___379 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___411 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___399;

struct vm_operations_struct___399 {
	void (*open)(struct vm_area_struct___412 *);
	void (*close)(struct vm_area_struct___412 *);
	int (*split)(struct vm_area_struct___412 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___412 *);
	vm_fault_t (*fault)(struct vm_fault___399 *);
	vm_fault_t (*huge_fault)(struct vm_fault___399 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___399 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___412 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___399 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___399 *);
	int (*access)(struct vm_area_struct___412 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___412 *);
	int (*set_policy)(struct vm_area_struct___412 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___412 *, long unsigned int);
	struct page___412 * (*find_special_page)(struct vm_area_struct___412 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___412 {
	struct task_struct___413 *task;
	struct core_thread___412 *next;
};

struct core_state___412 {
	atomic_t nr_threads;
	struct core_thread___412 dumper;
	struct completion startup;
};

struct key___379;

struct ucounts___276;

struct user_namespace___276 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___276 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___29 ns;
	long unsigned int flags;
	struct key___379 *persistent_keyring_register;
	struct rw_semaphore___413 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___276 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___399 {
	struct vm_area_struct___412 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___412 *cow_page;
	struct mem_cgroup___148 *memcg;
	struct page___412 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___412 prealloc_pte;
};

struct shrink_control___148 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___148 *memcg;
};

struct shrinker___148 {
	long unsigned int (*count_objects)(struct shrinker___148 *, struct shrink_control___148 *);
	long unsigned int (*scan_objects)(struct shrinker___148 *, struct shrink_control___148 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct pid_namespace___235;

struct upid___235 {
	int nr;
	struct pid_namespace___235 *ns;
};

struct pid_namespace___235 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___413 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___235 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___411 *proc_self;
	struct dentry___411 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___276 *user_ns;
	struct ucounts___276 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___29 ns;
};

struct pid___235 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___235 numbers[1];
};

struct user_struct___379 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___379 *uid_keyring;
	struct key___379 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___379 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___379 *session_keyring;
	struct key___379 *process_keyring;
	struct key___379 *thread_keyring;
	struct key___379 *request_key_auth;
	void *security;
	struct user_struct___379 *user;
	struct user_namespace___276 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___68;

struct cgroup_namespace___260;

struct nsproxy___306 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___235 *pid_ns_for_children;
	struct net___68 *net_ns;
	struct cgroup_namespace___260 *cgroup_ns;
};

struct signal_struct___286 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___413 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___413 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___235 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___235 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___412 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___235 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___205;

struct bio_list___205 {
	struct bio___205 *head;
	struct bio___205 *tail;
};

struct bdi_writeback_congested___205;

struct bdi_writeback___205 {
	struct backing_dev_info___205 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___205 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___260 *memcg_css;
	struct cgroup_subsys_state___260 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___205 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___205 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___379 *dev;
	struct device___379 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___411 *debug_dir;
	struct dentry___411 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___260 {
	struct cgroup_subsys_state___260 *subsys[13];
	refcount_t refcount;
	struct css_set___260 *dom_cset;
	struct cgroup___260 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___260 *mg_src_cgrp;
	struct cgroup___260 *mg_dst_cgrp;
	struct css_set___260 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___411;

struct pipe_buffer___92;

struct pipe_inode_info___92 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___412 *tmp_page;
	struct fasync_struct___411 *fasync_readers;
	struct fasync_struct___411 *fasync_writers;
	struct pipe_buffer___92 *bufs;
	struct user_struct___379 *user;
};

struct vm_struct___315 {
	struct vm_struct___315 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___412 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___298 {
	struct task_struct___413 task;
	long unsigned int stack[8192];
};

struct kset___398;

struct kobj_type___398;

struct kobject___399 {
	const char *name;
	struct list_head entry;
	struct kobject___399 *parent;
	struct kset___398 *kset;
	struct kobj_type___398 *ktype;
	struct kernfs_node___406 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___379 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___379 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___379;

struct bus_type___379;

struct device_driver___379;

struct dev_pm_domain___379;

struct dma_map_ops___151;

struct fwnode_handle___299;

struct class___379;

struct attribute_group___376;

struct device___379 {
	struct device___379 *parent;
	struct device_private *p;
	struct kobject___399 kobj;
	const char *init_name;
	const struct device_type___379 *type;
	struct mutex mutex;
	struct bus_type___379 *bus;
	struct device_driver___379 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___379 power;
	struct dev_pm_domain___379 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___151 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___299 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___379 *class;
	const struct attribute_group___376 **groups;
	void (*release)(struct device___379 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___411;

struct super_block___411;

struct dentry___411 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___411 *d_parent;
	struct qstr d_name;
	struct inode___411 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___411 *d_op;
	struct super_block___411 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___411;

struct block_device___411;

struct inode___411 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___411 *i_op;
	struct super_block___411 *i_sb;
	struct address_space___411 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___413 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___205 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___411 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___411 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___92 *i_pipe;
		struct block_device___411 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___411 {
	int (*d_revalidate)(struct dentry___411 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___411 *, unsigned int);
	int (*d_hash)(const struct dentry___411 *, struct qstr *);
	int (*d_compare)(const struct dentry___411 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___411 *);
	int (*d_init)(struct dentry___411 *);
	void (*d_release)(struct dentry___411 *);
	void (*d_prune)(struct dentry___411 *);
	void (*d_iput)(struct dentry___411 *, struct inode___411 *);
	char * (*d_dname)(struct dentry___411 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___412 *);
	int (*d_manage)(const struct path___412 *, bool);
	struct dentry___411 * (*d_real)(struct dentry___411 *, const struct inode___411 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___411;

struct mem_dqinfo___411 {
	struct quota_format_type___411 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___411;

struct quota_info___411 {
	unsigned int flags;
	struct rw_semaphore___413 dqio_sem;
	struct inode___411 *files[3];
	struct mem_dqinfo___411 info[3];
	const struct quota_format_ops___411 *ops[3];
};

struct rcuwait___411 {
	struct task_struct___413 *task;
};

struct percpu_rw_semaphore___411 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___413 rw_sem;
	struct rcuwait___411 writer;
	int readers_block;
};

struct sb_writers___411 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___411 rw_sem[3];
};

struct file_system_type___411;

struct super_operations___411;

struct dquot_operations___411;

struct quotactl_ops___411;

struct super_block___411 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___411 *s_type;
	const struct super_operations___411 *s_op;
	const struct dquot_operations___411 *dq_op;
	const struct quotactl_ops___411 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___411 *s_root;
	struct rw_semaphore___413 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___411 *s_bdev;
	struct backing_dev_info___205 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___411 s_dquot;
	struct sb_writers___411 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___411 *s_d_op;
	int cleancache_poolid;
	struct shrinker___148 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___276 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___411 {
	struct file___411 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___411 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___411 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___411 *ia_file;
};

struct dquot___411 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___411 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___411 {
	int qf_fmt_id;
	const struct quota_format_ops___411 *qf_ops;
	struct module___341 *qf_owner;
	struct quota_format_type___411 *qf_next;
};

struct quota_format_ops___411 {
	int (*check_quota_file)(struct super_block___411 *, int);
	int (*read_file_info)(struct super_block___411 *, int);
	int (*write_file_info)(struct super_block___411 *, int);
	int (*free_file_info)(struct super_block___411 *, int);
	int (*read_dqblk)(struct dquot___411 *);
	int (*commit_dqblk)(struct dquot___411 *);
	int (*release_dqblk)(struct dquot___411 *);
	int (*get_next_id)(struct super_block___411 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___411 {
	int (*write_dquot)(struct dquot___411 *);
	struct dquot___411 * (*alloc_dquot)(struct super_block___411 *, int);
	void (*destroy_dquot)(struct dquot___411 *);
	int (*acquire_dquot)(struct dquot___411 *);
	int (*release_dquot)(struct dquot___411 *);
	int (*mark_dirty)(struct dquot___411 *);
	int (*write_info)(struct super_block___411 *, int);
	qsize_t * (*get_reserved_space)(struct inode___411 *);
	int (*get_projid)(struct inode___411 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___411 *, qsize_t *);
	int (*get_next_id)(struct super_block___411 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___411 {
	int (*quota_on)(struct super_block___411 *, int, int, const struct path___412 *);
	int (*quota_off)(struct super_block___411 *, int);
	int (*quota_enable)(struct super_block___411 *, unsigned int);
	int (*quota_disable)(struct super_block___411 *, unsigned int);
	int (*quota_sync)(struct super_block___411 *, int);
	int (*set_info)(struct super_block___411 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___411 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___411 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___411 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___411 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___411 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___339 {
	struct kobject___399 kobj;
	struct module___341 *mod;
	struct kobject___399 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___339 {
	struct module___341 *mod;
	struct latch_tree_node node;
};

struct module_layout___339 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___339 mtn;
};

struct module_attribute___339;

struct kernel_param___339;

struct module___341 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___339 mkobj;
	struct module_attribute___339 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___399 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___339 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___339 core_layout;
	struct module_layout___339 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___168;

struct address_space_operations___411 {
	int (*writepage)(struct page___412 *, struct writeback_control___168 *);
	int (*readpage)(struct file___411 *, struct page___412 *);
	int (*writepages)(struct address_space___411 *, struct writeback_control___168 *);
	int (*set_page_dirty)(struct page___412 *);
	int (*readpages)(struct file___411 *, struct address_space___411 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___411 *, struct address_space___411 *, loff_t, unsigned int, unsigned int, struct page___412 **, void **);
	int (*write_end)(struct file___411 *, struct address_space___411 *, loff_t, unsigned int, unsigned int, struct page___412 *, void *);
	sector_t (*bmap)(struct address_space___411 *, sector_t);
	void (*invalidatepage)(struct page___412 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___412 *, gfp_t);
	void (*freepage)(struct page___412 *);
	ssize_t (*direct_IO)(struct kiocb___411 *, struct iov_iter___178 *);
	int (*migratepage)(struct address_space___411 *, struct page___412 *, struct page___412 *, enum migrate_mode);
	bool (*isolate_page)(struct page___412 *, isolate_mode_t);
	void (*putback_page)(struct page___412 *);
	int (*launder_page)(struct page___412 *);
	int (*is_partially_uptodate)(struct page___412 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___412 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___411 *, struct page___412 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___411 *, sector_t *);
	void (*swap_deactivate)(struct file___411 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___168 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___205 *wb;
	struct inode___411 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___207;

struct iov_iter___178 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___207 *bvec;
		struct pipe_inode_info___92 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___411 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___411 *bd_inode;
	struct super_block___411 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___411 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___205 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___411 {
	struct dentry___411 * (*lookup)(struct inode___411 *, struct dentry___411 *, unsigned int);
	const char * (*get_link)(struct dentry___411 *, struct inode___411 *, struct delayed_call *);
	int (*permission)(struct inode___411 *, int);
	struct posix_acl * (*get_acl)(struct inode___411 *, int);
	int (*readlink)(struct dentry___411 *, char *, int);
	int (*create)(struct inode___411 *, struct dentry___411 *, umode_t, bool);
	int (*link)(struct dentry___411 *, struct inode___411 *, struct dentry___411 *);
	int (*unlink)(struct inode___411 *, struct dentry___411 *);
	int (*symlink)(struct inode___411 *, struct dentry___411 *, const char *);
	int (*mkdir)(struct inode___411 *, struct dentry___411 *, umode_t);
	int (*rmdir)(struct inode___411 *, struct dentry___411 *);
	int (*mknod)(struct inode___411 *, struct dentry___411 *, umode_t, dev_t);
	int (*rename)(struct inode___411 *, struct dentry___411 *, struct inode___411 *, struct dentry___411 *, unsigned int);
	int (*setattr)(struct dentry___411 *, struct iattr___411 *);
	int (*getattr)(const struct path___412 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___411 *, char *, size_t);
	int (*fiemap)(struct inode___411 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___411 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___411 *, struct dentry___411 *, struct file___411 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___411 *, struct dentry___411 *, umode_t);
	int (*set_acl)(struct inode___411 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___411 {
	void (*fl_copy_lock)(struct file_lock___411 *, struct file_lock___411 *);
	void (*fl_release_private)(struct file_lock___411 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___411;

struct file_lock___411 {
	struct file_lock___411 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___411 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___411 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___411 *fl_ops;
	const struct lock_manager_operations___411 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___411 {
	int (*lm_compare_owner)(struct file_lock___411 *, struct file_lock___411 *);
	long unsigned int (*lm_owner_key)(struct file_lock___411 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___411 *);
	int (*lm_grant)(struct file_lock___411 *, int);
	bool (*lm_break)(struct file_lock___411 *);
	int (*lm_change)(struct file_lock___411 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___411 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___411 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___411 *fa_next;
	struct file___411 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___411 {
	const char *name;
	int fs_flags;
	struct dentry___411 * (*mount)(struct file_system_type___411 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___411 *);
	struct module___341 *owner;
	struct file_system_type___411 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___411 {
	struct inode___411 * (*alloc_inode)(struct super_block___411 *);
	void (*destroy_inode)(struct inode___411 *);
	void (*dirty_inode)(struct inode___411 *, int);
	int (*write_inode)(struct inode___411 *, struct writeback_control___168 *);
	int (*drop_inode)(struct inode___411 *);
	void (*evict_inode)(struct inode___411 *);
	void (*put_super)(struct super_block___411 *);
	int (*sync_fs)(struct super_block___411 *, int);
	int (*freeze_super)(struct super_block___411 *);
	int (*freeze_fs)(struct super_block___411 *);
	int (*thaw_super)(struct super_block___411 *);
	int (*unfreeze_fs)(struct super_block___411 *);
	int (*statfs)(struct dentry___411 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___411 *, int *, char *);
	void (*umount_begin)(struct super_block___411 *);
	int (*show_options)(struct seq_file___350 *, struct dentry___411 *);
	int (*show_devname)(struct seq_file___350 *, struct dentry___411 *);
	int (*show_path)(struct seq_file___350 *, struct dentry___411 *);
	int (*show_stats)(struct seq_file___350 *, struct dentry___411 *);
	ssize_t (*quota_read)(struct super_block___411 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___411 *, int, const char *, size_t, loff_t);
	struct dquot___411 ** (*get_dquots)(struct inode___411 *);
	int (*bdev_try_to_free_page)(struct super_block___411 *, struct page___412 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___411 *, struct shrink_control___148 *);
	long int (*free_cached_objects)(struct super_block___411 *, struct shrink_control___148 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___264)(struct file___411 *, wait_queue_head_t *, struct poll_table_struct___254 *);

struct poll_table_struct___254 {
	poll_queue_proc___264 _qproc;
	__poll_t _key;
};

struct seq_operations___350;

struct seq_file___350 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___350 *op;
	int poll_event;
	const struct file___411 *file;
	void *private;
};

typedef void bio_end_io_t___205(struct bio___205 *);

struct bio_vec___207 {
	struct page___412 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___205;

struct bio_set___205;

struct bio___205 {
	struct bio___205 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___205 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___205 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___207 *bi_io_vec;
	struct bio_set___205 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___207 bi_inline_vecs[0];
};

struct kobj_attribute___389 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___399 *, struct kobj_attribute___389 *, char *);
	ssize_t (*store)(struct kobject___399 *, struct kobj_attribute___389 *, const char *, size_t);
};

typedef void compound_page_dtor___399(struct page___412 *);

struct kernfs_root___405;

struct kernfs_elem_dir___405 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___405 *root;
};

struct kernfs_syscall_ops___405;

struct kernfs_root___405 {
	struct kernfs_node___406 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___405 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___405 {
	struct kernfs_node___406 *target_kn;
};

struct kernfs_ops___405;

struct kernfs_elem_attr___405 {
	const struct kernfs_ops___405 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___406 *notify_next;
};

struct kernfs_node___406 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___406 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___405 dir;
		struct kernfs_elem_symlink___405 symlink;
		struct kernfs_elem_attr___405 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___405;

struct kernfs_ops___405 {
	int (*open)(struct kernfs_open_file___405 *);
	void (*release)(struct kernfs_open_file___405 *);
	int (*seq_show)(struct seq_file___350 *, void *);
	void * (*seq_start)(struct seq_file___350 *, loff_t *);
	void * (*seq_next)(struct seq_file___350 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___350 *, void *);
	ssize_t (*read)(struct kernfs_open_file___405 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___405 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___405 *, struct vm_area_struct___412 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___405 *, struct poll_table_struct___254 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___405 {
	int (*remount_fs)(struct kernfs_root___405 *, int *, char *);
	int (*show_options)(struct seq_file___350 *, struct kernfs_root___405 *);
	int (*mkdir)(struct kernfs_node___406 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___406 *);
	int (*rename)(struct kernfs_node___406 *, struct kernfs_node___406 *, const char *);
	int (*show_path)(struct seq_file___350 *, struct kernfs_node___406 *, struct kernfs_root___405 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___405 {
	struct kernfs_node___406 *kn;
	struct file___411 *file;
	struct seq_file___350 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___399 *vm_ops;
};

struct sock___41;

struct kobj_ns_type_operations___40 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___41 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___68 *net;
} possible_net_t___58;

struct proto___40;

struct sock_common___40 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___40 *skc_prot;
	possible_net_t___58 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___41 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___58;

struct sk_buff_head___56 {
	struct sk_buff___58 *next;
	struct sk_buff___58 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___40;

struct socket_wq___41;

struct xfrm_policy___5;

struct dst_entry___40;

struct socket___42;

struct net_device___57;

struct sock___41 {
	struct sock_common___40 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___56 sk_error_queue;
	struct sk_buff_head___56 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___58 *head;
		struct sk_buff___58 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___40 *sk_filter;
	union {
		struct socket_wq___41 *sk_wq;
		struct socket_wq___41 *sk_wq_raw;
	};
	struct xfrm_policy___5 *sk_policy[2];
	struct dst_entry___40 *sk_rx_dst;
	struct dst_entry___40 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___58 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___56 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___412 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___40 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___235 *sk_peer_pid;
	const struct cred___379 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___42 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___148 *sk_memcg;
	void (*sk_state_change)(struct sock___41 *);
	void (*sk_data_ready)(struct sock___41 *);
	void (*sk_write_space)(struct sock___41 *);
	void (*sk_error_report)(struct sock___41 *);
	int (*sk_backlog_rcv)(struct sock___41 *, struct sk_buff___58 *);
	struct sk_buff___58 * (*sk_validate_xmit_skb)(struct sock___41 *, struct net_device___57 *, struct sk_buff___58 *);
	void (*sk_destruct)(struct sock___41 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct bin_attribute___375;

struct attribute_group___376 {
	const char *name;
	umode_t (*is_visible)(struct kobject___399 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___399 *, struct bin_attribute___375 *, int);
	struct attribute **attrs;
	struct bin_attribute___375 **bin_attrs;
};

struct bin_attribute___375 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___411 *, struct kobject___399 *, struct bin_attribute___375 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___411 *, struct kobject___399 *, struct bin_attribute___375 *, char *, loff_t, size_t);
	int (*mmap)(struct file___411 *, struct kobject___399 *, struct bin_attribute___375 *, struct vm_area_struct___412 *);
};

struct sysfs_ops___398 {
	ssize_t (*show)(struct kobject___399 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___399 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___398;

struct kset___398 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___399 kobj;
	const struct kset_uevent_ops___398 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___398 {
	void (*release)(struct kobject___399 *);
	const struct sysfs_ops___398 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___40 * (*child_ns_type)(struct kobject___399 *);
	const void * (*namespace)(struct kobject___399 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___398 {
	int (* const filter)(struct kset___398 *, struct kobject___399 *);
	const char * (* const name)(struct kset___398 *, struct kobject___399 *);
	int (* const uevent)(struct kset___398 *, struct kobject___399 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___339 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___339 *);
	int (*get)(char *, const struct kernel_param___339 *);
	void (*free)(void *);
};

struct kparam_array___339;

struct kernel_param___339 {
	const char *name;
	struct module___341 *mod;
	const struct kernel_param_ops___339 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___339 *arr;
	};
};

struct kparam_array___339 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___339 *ops;
	void *elem;
};

struct module_attribute___339 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___339 *, struct module_kobject___339 *, char *);
	ssize_t (*store)(struct module_attribute___339 *, struct module_kobject___339 *, const char *, size_t);
	void (*setup)(struct module___341 *, const char *);
	int (*test)(struct module___341 *);
	void (*free)(struct module___341 *);
};

struct msghdr___43 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___178 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___411 *msg_iocb;
};

struct socket_wq___41 {
	wait_queue_head_t wait;
	struct fasync_struct___411 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___41;

struct socket___42 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___41 *wq;
	struct file___411 *file;
	struct sock___41 *sk;
	const struct proto_ops___41 *ops;
};

typedef int (*sk_read_actor_t___40)(read_descriptor_t *, struct sk_buff___58 *, unsigned int, size_t);

struct proto_ops___41 {
	int family;
	struct module___341 *owner;
	int (*release)(struct socket___42 *);
	int (*bind)(struct socket___42 *, struct sockaddr *, int);
	int (*connect)(struct socket___42 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___42 *, struct socket___42 *);
	int (*accept)(struct socket___42 *, struct socket___42 *, int, bool);
	int (*getname)(struct socket___42 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___411 *, struct socket___42 *, struct poll_table_struct___254 *);
	int (*ioctl)(struct socket___42 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___42 *, int);
	int (*shutdown)(struct socket___42 *, int);
	int (*setsockopt)(struct socket___42 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___42 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___42 *, struct msghdr___43 *, size_t);
	int (*recvmsg)(struct socket___42 *, struct msghdr___43 *, size_t, int);
	int (*mmap)(struct file___411 *, struct socket___42 *, struct vm_area_struct___412 *);
	ssize_t (*sendpage)(struct socket___42 *, struct page___412 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___42 *, loff_t *, struct pipe_inode_info___92 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___41 *, int);
	int (*peek_len)(struct socket___42 *);
	int (*read_sock)(struct sock___41 *, read_descriptor_t *, sk_read_actor_t___40);
	int (*sendpage_locked)(struct sock___41 *, struct page___412 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___41 *, struct msghdr___43 *, size_t);
	int (*set_rcvlowat)(struct sock___41 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct sec_path___5;

struct nf_bridge_info___56;

struct sk_buff___58 {
	union {
		struct {
			struct sk_buff___58 *next;
			struct sk_buff___58 *prev;
			union {
				struct net_device___57 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___41 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___58 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path___5 *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___56 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___56;

struct netns_frags___56 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___56 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ip_ra_chain___19;

struct fib_rules_ops___40;

struct fib_notifier_ops___40;

struct netns_ipv4___56 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___19 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___40 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___41 *fibnl;
	struct sock___41 **icmp_sk;
	struct sock___41 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___41 **tcp_sk;
	struct netns_frags___56 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___40 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___40 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___40 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___40;

struct dst_ops___67 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___67 *);
	struct dst_entry___40 * (*check)(struct dst_entry___40 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___40 *);
	unsigned int (*mtu)(const struct dst_entry___40 *);
	u32 * (*cow_metrics)(struct dst_entry___40 *, long unsigned int);
	void (*destroy)(struct dst_entry___40 *);
	void (*ifdown)(struct dst_entry___40 *, struct net_device___57 *, int);
	struct dst_entry___40 * (*negative_advice)(struct dst_entry___40 *);
	void (*link_failure)(struct sk_buff___58 *);
	void (*update_pmtu)(struct dst_entry___40 *, struct sock___41 *, struct sk_buff___58 *, u32);
	void (*redirect)(struct dst_entry___40 *, struct sock___41 *, struct sk_buff___58 *);
	int (*local_out)(struct net___68 *, struct sock___41 *, struct sk_buff___58 *);
	struct neighbour___40 * (*neigh_lookup)(const struct dst_entry___40 *, struct sk_buff___58 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___40 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_info___6;

struct rt6_info___6;

struct fib6_table___6;

struct netns_ipv6___67 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___56 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info___6 *fib6_null_entry;
	struct rt6_info___6 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___6 *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___67 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info___6 *ip6_prohibit_entry;
	struct rt6_info___6 *ip6_blk_hole_entry;
	struct fib6_table___6 *fib6_local_tbl;
	struct fib_rules_ops___40 *fib6_rules_ops;
	struct sock___41 **icmp_sk;
	struct sock___41 *ndisc_sk;
	struct sock___41 *tcp_sk;
	struct sock___41 *igmp_sk;
	struct sock___41 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___40 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___40 *notifier_ops;
	struct fib_notifier_ops___40 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___41 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___41 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___56 {
	struct netns_frags___56 frags;
};

struct netns_xfrm___67 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___41 *nlsk;
	struct sock___41 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___67 xfrm4_dst_ops;
	struct dst_ops___67 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___50;

struct net___68 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___276 *user_ns;
	struct ucounts___276 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___29 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___41 *rtnl;
	struct sock___41 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___57 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___56 ipv4;
	struct netns_ipv6___67 ipv6;
	struct netns_sctp___41 sctp;
	struct netns_nf___4 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___56 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___41 *nfnl;
	struct sock___41 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___67 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___41 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___50 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___379 {
	int (*prepare)(struct device___379 *);
	void (*complete)(struct device___379 *);
	int (*suspend)(struct device___379 *);
	int (*resume)(struct device___379 *);
	int (*freeze)(struct device___379 *);
	int (*thaw)(struct device___379 *);
	int (*poweroff)(struct device___379 *);
	int (*restore)(struct device___379 *);
	int (*suspend_late)(struct device___379 *);
	int (*resume_early)(struct device___379 *);
	int (*freeze_late)(struct device___379 *);
	int (*thaw_early)(struct device___379 *);
	int (*poweroff_late)(struct device___379 *);
	int (*restore_early)(struct device___379 *);
	int (*suspend_noirq)(struct device___379 *);
	int (*resume_noirq)(struct device___379 *);
	int (*freeze_noirq)(struct device___379 *);
	int (*thaw_noirq)(struct device___379 *);
	int (*poweroff_noirq)(struct device___379 *);
	int (*restore_noirq)(struct device___379 *);
	int (*runtime_suspend)(struct device___379 *);
	int (*runtime_resume)(struct device___379 *);
	int (*runtime_idle)(struct device___379 *);
};

struct dev_pm_domain___379 {
	struct dev_pm_ops___379 ops;
	void (*detach)(struct device___379 *, bool);
	int (*activate)(struct device___379 *);
	void (*sync)(struct device___379 *);
	void (*dismiss)(struct device___379 *);
};

struct bus_type___379 {
	const char *name;
	const char *dev_name;
	struct device___379 *dev_root;
	const struct attribute_group___376 **bus_groups;
	const struct attribute_group___376 **dev_groups;
	const struct attribute_group___376 **drv_groups;
	int (*match)(struct device___379 *, struct device_driver___379 *);
	int (*uevent)(struct device___379 *, struct kobj_uevent_env *);
	int (*probe)(struct device___379 *);
	int (*remove)(struct device___379 *);
	void (*shutdown)(struct device___379 *);
	int (*online)(struct device___379 *);
	int (*offline)(struct device___379 *);
	int (*suspend)(struct device___379 *, pm_message_t);
	int (*resume)(struct device___379 *);
	int (*num_vf)(struct device___379 *);
	int (*dma_configure)(struct device___379 *);
	const struct dev_pm_ops___379 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___379 {
	const char *name;
	struct bus_type___379 *bus;
	struct module___341 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___379 *);
	int (*remove)(struct device___379 *);
	void (*shutdown)(struct device___379 *);
	int (*suspend)(struct device___379 *, pm_message_t);
	int (*resume)(struct device___379 *);
	const struct attribute_group___376 **groups;
	const struct dev_pm_ops___379 *pm;
	void (*coredump)(struct device___379 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___379 {
	const char *name;
	const struct attribute_group___376 **groups;
	int (*uevent)(struct device___379 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___379 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___379 *);
	const struct dev_pm_ops___379 *pm;
};

struct class___379 {
	const char *name;
	struct module___341 *owner;
	const struct attribute_group___376 **class_groups;
	const struct attribute_group___376 **dev_groups;
	struct kobject___399 *dev_kobj;
	int (*dev_uevent)(struct device___379 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___379 *, umode_t *);
	void (*class_release)(struct class___379 *);
	void (*dev_release)(struct device___379 *);
	int (*shutdown_pre)(struct device___379 *);
	const struct kobj_ns_type_operations___40 *ns_type;
	const void * (*namespace)(struct device___379 *);
	const struct dev_pm_ops___379 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___151 {
	void * (*alloc)(struct device___379 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___379 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___379 *, struct vm_area_struct___412 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___379 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___379 *, struct page___412 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___379 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___379 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___379 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___379 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___379 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___379 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___379 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___379 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___379 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___379 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___379 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___379 *, u64);
	u64 (*get_required_mask)(struct device___379 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___299;

struct fwnode_handle___299 {
	struct fwnode_handle___299 *secondary;
	const struct fwnode_operations___299 *ops;
};

struct fwnode_reference_args___299;

struct fwnode_endpoint___299;

struct fwnode_operations___299 {
	struct fwnode_handle___299 * (*get)(struct fwnode_handle___299 *);
	void (*put)(struct fwnode_handle___299 *);
	bool (*device_is_available)(const struct fwnode_handle___299 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___299 *, const struct device___379 *);
	bool (*property_present)(const struct fwnode_handle___299 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___299 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___299 *, const char *, const char **, size_t);
	struct fwnode_handle___299 * (*get_parent)(const struct fwnode_handle___299 *);
	struct fwnode_handle___299 * (*get_next_child_node)(const struct fwnode_handle___299 *, struct fwnode_handle___299 *);
	struct fwnode_handle___299 * (*get_named_child_node)(const struct fwnode_handle___299 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___299 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___299 *);
	struct fwnode_handle___299 * (*graph_get_next_endpoint)(const struct fwnode_handle___299 *, struct fwnode_handle___299 *);
	struct fwnode_handle___299 * (*graph_get_remote_endpoint)(const struct fwnode_handle___299 *);
	struct fwnode_handle___299 * (*graph_get_port_parent)(struct fwnode_handle___299 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___299 *, struct fwnode_endpoint___299 *);
};

struct fwnode_endpoint___299 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___299 *local_fwnode;
};

struct fwnode_reference_args___299 {
	struct fwnode_handle___299 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___92;

struct pipe_buffer___92 {
	struct page___412 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___92 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___92 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___92 *, struct pipe_buffer___92 *);
	void (*release)(struct pipe_inode_info___92 *, struct pipe_buffer___92 *);
	int (*steal)(struct pipe_inode_info___92 *, struct pipe_buffer___92 *);
	union {
		bool (*get)(struct pipe_inode_info___92 *, struct pipe_buffer___92 *);
		struct {
			void (*get)(struct pipe_inode_info___92 *, struct pipe_buffer___92 *);
		} __UNIQUE_ID_rh_kabi_hide21;
		union {		};
	};
};

struct nf_bridge_info___56 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___56 = 0,
		BRNF_PROTO_8021Q___56 = 1,
		BRNF_PROTO_PPPOE___56 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___57 *physindev;
	struct net_device___57 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___56(struct sk_buff___58 **);

struct net_device_ops___56;

struct ethtool_ops___56;

struct l3mdev_ops___40;

struct ndisc_ops___22;

struct xfrmdev_ops___56;

struct tlsdev_ops___56;

struct header_ops___56;

struct inet6_dev___22;

struct netdev_rx_queue___56;

struct mini_Qdisc___50;

struct netdev_queue___56;

struct Qdisc___50;

struct rtnl_link_ops___50;

struct dcbnl_rtnl_ops___56;

struct net_device___57 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___56 *netdev_ops;
	const struct ethtool_ops___56 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___40 *l3mdev_ops;
	const struct ndisc_ops___22 *ndisc_ops;
	const struct xfrmdev_ops___56 *xfrmdev_ops;
	const struct tlsdev_ops___56 *tlsdev_ops;
	const struct header_ops___56 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___398 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___22 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___56 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___50 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___56 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___50 *miniq_ingress;
	struct netdev_queue___56 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___56 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___50 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___50 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___56 = 0,
		NETREG_REGISTERED___56 = 1,
		NETREG_UNREGISTERING___56 = 2,
		NETREG_UNREGISTERED___56 = 3,
		NETREG_RELEASED___56 = 4,
		NETREG_DUMMY___56 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___56 = 0,
		RTNL_LINK_INITIALIZING___56 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___57 *);
	struct netpoll_info *npinfo;
	possible_net_t___58 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___379 dev;
	const struct attribute_group___376 *sysfs_groups[4];
	const struct attribute_group___376 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___50 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___56 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide35;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct xfrm_state___5;

struct sec_path___5 {
	refcount_t refcnt;
	int len;
	int olen;
	struct xfrm_state___5 *xvec[6];
	struct xfrm_offload ovec[1];
};

struct ethtool_ops___56 {
	int (*get_settings)(struct net_device___57 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___57 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___57 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___57 *);
	void (*get_regs)(struct net_device___57 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___57 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___57 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___57 *);
	void (*set_msglevel)(struct net_device___57 *, u32);
	int (*nway_reset)(struct net_device___57 *);
	u32 (*get_link)(struct net_device___57 *);
	int (*get_eeprom_len)(struct net_device___57 *);
	int (*get_eeprom)(struct net_device___57 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___57 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___57 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___57 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___57 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___57 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___57 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___57 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___57 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___57 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___57 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___57 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___57 *);
	void (*complete)(struct net_device___57 *);
	u32 (*get_priv_flags)(struct net_device___57 *);
	int (*set_priv_flags)(struct net_device___57 *, u32);
	int (*get_sset_count)(struct net_device___57 *, int);
	int (*get_rxnfc)(struct net_device___57 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___57 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___57 *, struct ethtool_flash *);
	int (*reset)(struct net_device___57 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___57 *);
	u32 (*get_rxfh_indir_size)(struct net_device___57 *);
	int (*get_rxfh)(struct net_device___57 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___57 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___57 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___57 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___57 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___57 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___57 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___57 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___57 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___57 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___57 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___57 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___57 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___57 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___57 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___57 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___57 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___57 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___57 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___57 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___57 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___57 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	int (*get_fecparam)(struct net_device___57 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___57 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___57 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___57 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___57 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___56;

struct inet_frags___56 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___56 *, const void *);
	void (*destructor)(struct inet_frag_queue___56 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___56 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___58 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___58 *fragments_tail;
	struct sk_buff___58 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___56 *net;
	struct callback_head rcu;
};

struct ip_ra_chain___19 {
	struct ip_ra_chain___19 *next;
	struct sock___41 *sk;
	union {
		void (*destructor)(struct sock___41 *);
		struct sock___41 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___40;

struct fib_lookup_arg___40;

struct fib_rules_ops___40 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___40 *, struct flowi *, int, struct fib_lookup_arg___40 *);
	bool (*suppress)(struct fib_rule___40 *, struct fib_lookup_arg___40 *);
	int (*match)(struct fib_rule___40 *, struct flowi *, int);
	int (*configure)(struct fib_rule___40 *, struct sk_buff___58 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___40 *);
	int (*compare)(struct fib_rule___40 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___40 *, struct sk_buff___58 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___40 *);
	void (*flush_cache)(struct fib_rules_ops___40 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___341 *owner;
	struct net___68 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___40 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___68 *);
	int (*fib_dump)(struct net___68 *, struct notifier_block *);
	struct module___341 *owner;
	struct callback_head rcu;
};

struct lwtunnel_state___3;

struct dst_entry___40 {
	struct net_device___57 *dev;
	struct dst_ops___67 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state___5 *xfrm;
	int (*input)(struct sk_buff___58 *);
	int (*output)(struct net___68 *, struct sock___41 *, struct sk_buff___58 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___3 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___40;

struct neigh_parms___40;

struct neigh_ops___40;

struct neighbour___40 {
	struct neighbour___40 *next;
	struct neigh_table___40 *tbl;
	struct neigh_parms___40 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___56 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___40 *, struct sk_buff___58 *);
	const struct neigh_ops___40 *ops;
	struct callback_head rcu;
	struct net_device___57 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct fib6_nh___6 {
	struct in6_addr nh_gw;
	struct net_device___57 *nh_dev;
	struct lwtunnel_state___3 *nh_lwtstate;
	unsigned int nh_flags;
	atomic_t nh_upper_bound;
	int nh_weight;
};

struct fib6_node___6;

struct fib6_info___6 {
	struct fib6_table___6 *fib6_table;
	struct fib6_info___6 *fib6_next;
	struct fib6_node___6 *fib6_node;
	struct list_head fib6_siblings;
	unsigned int fib6_nsiblings;
	atomic_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	struct rt6_info___6 **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
	long unsigned int last_probe;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 exception_bucket_flushed: 1;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 dst_host: 1;
	u8 fib6_destroying: 1;
	u8 unused: 2;
	struct fib6_nh___6 fib6_nh;
	struct callback_head rcu;
};

struct rt6_info___6 {
	struct dst_entry___40 dst;
	struct fib6_info___6 *from;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___22 *rt6i_idev;
	u32 rt6i_flags;
	struct rt6key rt6i_prefsrc;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct fib6_node___6 {
	struct fib6_node___6 *parent;
	struct fib6_node___6 *left;
	struct fib6_node___6 *right;
	struct fib6_info___6 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info___6 *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table___6 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node___6 tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

struct ucounts___276 {
	struct hlist_node node;
	struct user_namespace___276 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_prog_aux___53;

struct bpf_prog___50 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___53 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

typedef int (*key_restrict_link_func_t___380)(struct key___379 *, const struct key_type *, const union key_payload *, struct key___379 *);

struct key_restriction___379;

struct key___379 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___413 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___379 *restrict_link;
};

struct key_restriction___379 {
	key_restrict_link_func_t___380 check;
	struct key___379 *key;
	struct key_type *keytype;
};

struct seq_operations___350 {
	void * (*start)(struct seq_file___350 *, loff_t *);
	void (*stop)(struct seq_file___350 *, void *);
	void * (*next)(struct seq_file___350 *, void *, loff_t *);
	int (*show)(struct seq_file___350 *, void *);
};

struct pernet_operations___57 {
	struct list_head list;
	int (*init)(struct net___68 *);
	void (*exit)(struct net___68 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___56 {
	int (*ieee_getets)(struct net_device___57 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___57 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___57 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___57 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___57 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___57 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___57 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___57 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___57 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___57 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___57 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___57 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___57 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___57 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___57 *);
	u8 (*setstate)(struct net_device___57 *, u8);
	void (*getpermhwaddr)(struct net_device___57 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___57 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___57 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___57 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___57 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___57 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___57 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___57 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___57 *, int, u8 *);
	void (*setpfccfg)(struct net_device___57 *, int, u8);
	void (*getpfccfg)(struct net_device___57 *, int, u8 *);
	u8 (*setall)(struct net_device___57 *);
	u8 (*getcap)(struct net_device___57 *, int, u8 *);
	int (*getnumtcs)(struct net_device___57 *, int, u8 *);
	int (*setnumtcs)(struct net_device___57 *, int, u8);
	u8 (*getpfcstate)(struct net_device___57 *);
	void (*setpfcstate)(struct net_device___57 *, u8);
	void (*getbcncfg)(struct net_device___57 *, int, u32 *);
	void (*setbcncfg)(struct net_device___57 *, int, u32);
	void (*getbcnrp)(struct net_device___57 *, int, u8 *);
	void (*setbcnrp)(struct net_device___57 *, int, u8);
	int (*setapp)(struct net_device___57 *, u8, u16, u8);
	int (*getapp)(struct net_device___57 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___57 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___57 *, int, u8);
	u8 (*getdcbx)(struct net_device___57 *);
	u8 (*setdcbx)(struct net_device___57 *, u8);
	int (*peer_getappinfo)(struct net_device___57 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___57 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___57 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___57 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___57 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___57 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___260 {
	refcount_t count;
	struct ns_common___29 ns;
	struct user_namespace___276 *user_ns;
	struct ucounts___276 *ucounts;
	struct css_set___260 *root_cset;
};

struct bpf_map___261;

struct bpf_map_ops___260 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___261 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___261 *, struct file___411 *);
	void (*map_free)(struct bpf_map___261 *);
	int (*map_get_next_key)(struct bpf_map___261 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___261 *);
	void * (*map_lookup_elem)(struct bpf_map___261 *, void *);
	int (*map_update_elem)(struct bpf_map___261 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___261 *, void *);
	int (*map_push_elem)(struct bpf_map___261 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___261 *, void *);
	int (*map_peek_elem)(struct bpf_map___261 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___261 *, struct file___411 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___261 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___261 *, void *, struct seq_file___350 *);
	int (*map_check_btf)(const struct bpf_map___261 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___261 {
	const struct bpf_map_ops___260 *ops;
	struct bpf_map___261 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___379 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___56;

struct bpf_map_dev_ops___56 {
	int (*map_get_next_key)(struct bpf_offloaded_map___56 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___56 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___56 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___56 *, void *);
};

struct bpf_offloaded_map___56 {
	struct bpf_map___261 map;
	struct net_device___57 *netdev;
	const struct bpf_map_dev_ops___56 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___50 {
	int (*test_run)(struct bpf_prog___50 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___50 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___50 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___50 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___50 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___50 *, u32 *);
};

struct bpf_prog_offload_ops___50 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___50 *);
	int (*translate)(struct bpf_prog___50 *);
	void (*destroy)(struct bpf_prog___50 *);
};

struct bpf_prog_offload___50 {
	struct bpf_prog___50 *prog;
	struct net_device___57 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___50 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___53 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___50 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___50 *ops;
	struct bpf_map___261 **used_maps;
	struct bpf_prog___50 *prog;
	struct user_struct___379 *user;
	u64 load_time;
	struct bpf_map___261 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___50 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___50 {
	struct bpf_prog___50 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___50 {
	struct callback_head rcu;
	struct bpf_prog_array_item___50 items[0];
};

struct cgroup_bpf___50 {
	struct bpf_prog_array___50 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___50 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___261;

typedef void (*kthread_work_func_t___261)(struct kthread_work___261 *);

struct kthread_worker___261;

struct kthread_work___261 {
	struct list_head node;
	kthread_work_func_t___261 func;
	struct kthread_worker___261 *worker;
	int canceling;
};

struct kthread_worker___261 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___413 *task;
	struct kthread_work___261 *current_work;
};

struct kthread_delayed_work___260 {
	struct kthread_work___261 work;
	struct timer_list timer;
};

struct psi_group___260 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___261 *poll_kworker;
	struct kthread_delayed_work___260 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___260;

struct cgroup_rstat_cpu___260;

struct cgroup___260 {
	struct cgroup_subsys_state___260 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___406 *kn;
	struct cgroup_file___260 procs_file;
	struct cgroup_file___260 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___260 *subsys[13];
	struct cgroup_root___260 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___260 *dom_cgrp;
	struct cgroup_rstat_cpu___260 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___50 bpf;
	atomic_t congestion_count;
	struct cgroup___260 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___260 psi;
	int ancestor_ids[0];
};

struct cftype___260;

struct cgroup_subsys___260 {
	struct cgroup_subsys_state___260 * (*css_alloc)(struct cgroup_subsys_state___260 *);
	int (*css_online)(struct cgroup_subsys_state___260 *);
	void (*css_offline)(struct cgroup_subsys_state___260 *);
	void (*css_released)(struct cgroup_subsys_state___260 *);
	void (*css_free)(struct cgroup_subsys_state___260 *);
	void (*css_reset)(struct cgroup_subsys_state___260 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___260 *, int);
	int (*css_extra_stat_show)(struct seq_file___350 *, struct cgroup_subsys_state___260 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___413 *);
	void (*cancel_fork)(struct task_struct___413 *);
	void (*fork)(struct task_struct___413 *);
	void (*exit)(struct task_struct___413 *);
	void (*free)(struct task_struct___413 *);
	void (*bind)(struct cgroup_subsys_state___260 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___260 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___260 *dfl_cftypes;
	struct cftype___260 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___260 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___260 *updated_children;
	struct cgroup___260 *updated_next;
};

struct cgroup_root___260 {
	struct kernfs_root___405 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___260 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___260 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___260 *ss;
	struct list_head node;
	struct kernfs_ops___405 *kf_ops;
	int (*open)(struct kernfs_open_file___405 *);
	void (*release)(struct kernfs_open_file___405 *);
	u64 (*read_u64)(struct cgroup_subsys_state___260 *, struct cftype___260 *);
	s64 (*read_s64)(struct cgroup_subsys_state___260 *, struct cftype___260 *);
	int (*seq_show)(struct seq_file___350 *, void *);
	void * (*seq_start)(struct seq_file___350 *, loff_t *);
	void * (*seq_next)(struct seq_file___350 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___350 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___260 *, struct cftype___260 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___260 *, struct cftype___260 *, s64);
	ssize_t (*write)(struct kernfs_open_file___405 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___405 *, struct poll_table_struct___254 *);
};

struct xdp_rxq_info___56 {
	struct net_device___57 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___56 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___57 *dev_rx;
};

struct netlink_callback___58 {
	struct sk_buff___58 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___58 *);
	int (*dump)(struct sk_buff___58 *, struct netlink_callback___58 *);
	int (*done)(struct netlink_callback___58 *);
	void *data;
	struct module___341 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___56 {
	int (*create)(struct sk_buff___58 *, struct net_device___57 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___58 *, unsigned char *);
	int (*cache)(const struct neighbour___40 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___57 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___56 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___56 *, int);
	int poll_owner;
	struct net_device___57 *dev;
	struct sk_buff___58 *gro_list;
	struct sk_buff___58 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___56 {
	struct net_device___57 *dev;
	struct Qdisc___50 *qdisc;
	struct Qdisc___50 *qdisc_sleeping;
	struct kobject___399 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___57 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem___2 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___50 {
	struct sk_buff___58 *head;
	struct sk_buff___58 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___50;

struct Qdisc___50 {
	int (*enqueue)(struct sk_buff___58 *, struct Qdisc___50 *, struct sk_buff___58 **);
	struct sk_buff___58 * (*dequeue)(struct Qdisc___50 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___50 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___56 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___56 gso_skb;
	struct qdisc_skb_head___50 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___50 *next_sched;
	struct sk_buff_head___56 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___56 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___399 kobj;
	struct net_device___57 *dev;
	long: 64;
	struct xdp_rxq_info___56 xdp_rxq;
	union {
		struct xdp_umem___2 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___56)(struct net_device___57 *, struct sk_buff___58 *, struct net_device___57 *);

struct netdev_bpf___56 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___50 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___50 *prog;
			const struct bpf_prog_offload_ops___50 *ops;
		} verifier;
		struct {
			struct bpf_prog___50 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___56 *offmap;
		};
		struct {
			struct xdp_umem___2 *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___56 {
	int (*xdo_dev_state_add)(struct xfrm_state___5 *);
	void (*xdo_dev_state_delete)(struct xfrm_state___5 *);
	void (*xdo_dev_state_free)(struct xfrm_state___5 *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___58 *, struct xfrm_state___5 *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state___5 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct xfrm_state_offload___5 {
	struct net_device___57 *dev;
	long unsigned int offload_handle;
	unsigned int num_exthdrs;
	u8 flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct xfrm_replay___5;

struct xfrm_type___5;

struct xfrm_mode___5;

struct xfrm_type_offload___5;

struct xfrm_state___5 {
	possible_net_t___58 xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	refcount_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
		u32 output_mark;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	const char *geniv;
	struct xfrm_encap_tmpl *encap;
	xfrm_address_t *coaddr;
	struct xfrm_state___5 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	const struct xfrm_replay___5 *repl;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct tasklet_hrtimer mtimer;
	struct xfrm_state_offload___5 xso;
	long int saved_tmo;
	long unsigned int lastused;
	struct page_frag___412 xfrag;
	const struct xfrm_type___5 *type;
	struct xfrm_mode___5 *inner_mode;
	struct xfrm_mode___5 *inner_mode_iaf;
	struct xfrm_mode___5 *outer_mode;
	const struct xfrm_type_offload___5 *type_offload;
	struct xfrm_sec_ctx___2 *security;
	void *data;
	u32 output_mark_mask;
	u32 if_id;
};

struct tlsdev_ops___56 {
	int (*tls_dev_add)(struct net_device___57 *, struct sock___41 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___57 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___57 *, struct sock___41 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___56 {
	int (*ndo_init)(struct net_device___57 *);
	void (*ndo_uninit)(struct net_device___57 *);
	int (*ndo_open)(struct net_device___57 *);
	int (*ndo_stop)(struct net_device___57 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___58 *, struct net_device___57 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___58 *, struct net_device___57 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___57 *, struct sk_buff___58 *, struct net_device___57 *, select_queue_fallback_t___56);
	void (*ndo_change_rx_flags)(struct net_device___57 *, int);
	void (*ndo_set_rx_mode)(struct net_device___57 *);
	int (*ndo_set_mac_address)(struct net_device___57 *, void *);
	int (*ndo_validate_addr)(struct net_device___57 *);
	int (*ndo_do_ioctl)(struct net_device___57 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___57 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___57 *, int);
	int (*ndo_neigh_setup)(struct net_device___57 *, struct neigh_parms___40 *);
	void (*ndo_tx_timeout)(struct net_device___57 *);
	void (*ndo_get_stats64)(struct net_device___57 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___57 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___57 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___57 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___57 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___57 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___57 *);
	int (*ndo_netpoll_setup)(struct net_device___57 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___57 *);
	int (*ndo_set_vf_mac)(struct net_device___57 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___57 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___57 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___57 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___57 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___57 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___57 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___57 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___57 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___57 *, int, struct sk_buff___58 *);
	int (*ndo_set_vf_guid)(struct net_device___57 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___57 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___57 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___57 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___57 *, const struct sk_buff___58 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___57 *, struct net_device___57 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___57 *, struct net_device___57 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___57 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___57 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___57 *, struct neighbour___40 *);
	void (*ndo_neigh_destroy)(struct net_device___57 *, struct neighbour___40 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___57 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___57 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___57 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___58 *, struct netlink_callback___58 *, struct net_device___57 *, struct net_device___57 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___57 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___57 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___58 *, u32, u32, struct net_device___57 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___57 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___57 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___57 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___57 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___57 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___57 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___57 *, struct net_device___57 *);
	void (*ndo_dfwd_del_station)(struct net_device___57 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___57 *);
	int (*ndo_set_tx_maxrate)(struct net_device___57 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___57 *);
	int (*ndo_change_proto_down)(struct net_device___57 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___57 *, struct sk_buff___58 *);
	void (*ndo_set_rx_headroom)(struct net_device___57 *, int);
	int (*ndo_bpf)(struct net_device___57 *, struct netdev_bpf___56 *);
	int (*ndo_xdp_xmit)(struct net_device___57 *, int, struct xdp_frame___56 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___57 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___57 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___40 {
	possible_net_t___58 net;
	struct net_device___57 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___40 *);
	void (*neigh_cleanup)(struct neighbour___40 *);
	struct neigh_table___40 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___40 {
	u32 (*l3mdev_fib_table)(const struct net_device___57 *);
	struct sk_buff___58 * (*l3mdev_l3_rcv)(struct net_device___57 *, struct sk_buff___58 *, u16);
	struct sk_buff___58 * (*l3mdev_l3_out)(struct net_device___57 *, struct sock___41 *, struct sk_buff___58 *, u16);
	struct dst_entry___40 * (*l3mdev_link_scope_lookup)(const struct net_device___57 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct ndisc_ops___22 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___57 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___57 *, struct neighbour___40 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___57 *, u8, struct neighbour___40 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___57 *, struct sk_buff___58 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___68 *, struct net_device___57 *, const struct prefix_info *, struct inet6_dev___22 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___22;

struct ifacaddr6___6;

struct inet6_dev___22 {
	struct net_device___57 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___22 *mc_list;
	struct ifmcaddr6___22 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___6 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	u8 rndid[8];
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___40 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
};

struct tcf_proto___50;

struct mini_Qdisc___50 {
	struct tcf_proto___50 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___50 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___57 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___68 *, struct net_device___57 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___57 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___57 *, struct list_head *);
	size_t (*get_size)(const struct net_device___57 *);
	int (*fill_info)(struct sk_buff___58 *, const struct net_device___57 *);
	size_t (*get_xstats_size)(const struct net_device___57 *);
	int (*fill_xstats)(struct sk_buff___58 *, const struct net_device___57 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___57 *, struct net_device___57 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___57 *, const struct net_device___57 *);
	int (*fill_slave_info)(struct sk_buff___58 *, const struct net_device___57 *, const struct net_device___57 *);
	struct net___68 * (*get_link_net)(const struct net_device___57 *);
	size_t (*get_linkxstats_size)(const struct net_device___57 *, int);
	int (*fill_linkxstats)(struct sk_buff___58 *, const struct net_device___57 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___56 {
	struct list_head poll_list;
	struct sk_buff_head___56 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___56 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___50 *output_queue;
	struct Qdisc___50 **output_queue_tailp;
	struct sk_buff___58 *completion_queue;
	struct sk_buff_head___56 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___56 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___56 input_pkt_queue;
	struct napi_struct___56 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pneigh_entry___40;

struct neigh_hash_table___40;

struct neigh_table___40 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___57 *, __u32 *);
	bool (*key_eq)(const struct neighbour___40 *, const void *);
	int (*constructor)(struct neighbour___40 *);
	int (*pconstructor)(struct pneigh_entry___40 *);
	void (*pdestructor)(struct pneigh_entry___40 *);
	void (*proxy_redo)(struct sk_buff___58 *);
	char *id;
	struct neigh_parms___40 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___56 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___40 *nht;
	struct pneigh_entry___40 **phash_buckets;
};

struct neigh_ops___40 {
	int family;
	void (*solicit)(struct neighbour___40 *, struct sk_buff___58 *);
	void (*error_report)(struct neighbour___40 *, struct sk_buff___58 *);
	int (*output)(struct neighbour___40 *, struct sk_buff___58 *);
	int (*connected_output)(struct neighbour___40 *, struct sk_buff___58 *);
};

struct pneigh_entry___40 {
	struct pneigh_entry___40 *next;
	possible_net_t___58 net;
	struct net_device___57 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___40 {
	struct neighbour___40 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___3 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___68 *, struct sock___41 *, struct sk_buff___58 *);
	int (*orig_input)(struct sk_buff___58 *);
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	__u8 data[0];
};

struct bdi_writeback_congested___205 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___205 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___205 {
	struct bio___205 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___207 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___207 bip_inline_vecs[0];
};

struct bio_set___205 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___205 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___148 {
	struct mem_cgroup___148 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___148 {
	struct lruvec___412 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___148 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___148 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct gnet_dump___50 {
	spinlock_t *lock;
	struct sk_buff___58 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___50;

struct Qdisc_ops___50 {
	struct Qdisc_ops___50 *next;
	const struct Qdisc_class_ops___50 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___58 *, struct Qdisc___50 *, struct sk_buff___58 **);
	struct sk_buff___58 * (*dequeue)(struct Qdisc___50 *);
	struct sk_buff___58 * (*peek)(struct Qdisc___50 *);
	int (*init)(struct Qdisc___50 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___50 *);
	void (*destroy)(struct Qdisc___50 *);
	int (*change)(struct Qdisc___50 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___50 *);
	int (*change_tx_queue_len)(struct Qdisc___50 *, unsigned int);
	int (*dump)(struct Qdisc___50 *, struct sk_buff___58 *);
	int (*dump_stats)(struct Qdisc___50 *, struct gnet_dump___50 *);
	void (*ingress_block_set)(struct Qdisc___50 *, u32);
	void (*egress_block_set)(struct Qdisc___50 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___50 *);
	u32 (*egress_block_get)(struct Qdisc___50 *);
	struct module___341 *owner;
};

struct tcf_block___50;

struct Qdisc_class_ops___50 {
	unsigned int flags;
	struct netdev_queue___56 * (*select_queue)(struct Qdisc___50 *, struct tcmsg *);
	int (*graft)(struct Qdisc___50 *, long unsigned int, struct Qdisc___50 *, struct Qdisc___50 **, struct netlink_ext_ack *);
	struct Qdisc___50 * (*leaf)(struct Qdisc___50 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___50 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___50 *, u32);
	int (*change)(struct Qdisc___50 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___50 *, long unsigned int);
	void (*walk)(struct Qdisc___50 *, struct qdisc_walker *);
	struct tcf_block___50 * (*tcf_block)(struct Qdisc___50 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___50 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___50 *, long unsigned int);
	int (*dump)(struct Qdisc___50 *, long unsigned int, struct sk_buff___58 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___50 *, long unsigned int, struct gnet_dump___50 *);
};

struct tcf_chain___50;

struct tcf_block___50 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___68 *net;
	struct Qdisc___50 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___50 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___50;

struct tcf_proto_ops___50;

struct tcf_proto___50 {
	struct tcf_proto___50 *next;
	void *root;
	int (*classify)(struct sk_buff___58 *, const struct tcf_proto___50 *, struct tcf_result___50 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___50 *ops;
	struct tcf_chain___50 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___50 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___50 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___50 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___58 *, const struct tcf_proto___50 *, struct tcf_result___50 *);
	int (*init)(struct tcf_proto___50 *);
	void (*destroy)(struct tcf_proto___50 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___50 *, u32);
	void (*put)(struct tcf_proto___50 *, void *);
	int (*change)(struct net___68 *, struct sk_buff___58 *, struct tcf_proto___50 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___50 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___50 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___50 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___68 *, struct tcf_chain___50 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___68 *, struct tcf_proto___50 *, void *, struct sk_buff___58 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___58 *, struct net___68 *, void *);
	struct module___341 *owner;
	int flags;
};

struct tcf_chain___50 {
	struct mutex filter_chain_lock;
	struct tcf_proto___50 *filter_chain;
	struct list_head list;
	struct tcf_block___50 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___50 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___40 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___50 *prog;
};

struct bpf_redirect_info___50 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___261 *map;
	struct bpf_map___261 *map_to_flush;
	u32 kern_flags;
};

struct fib_rule___40 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___40 *ctarget;
	struct net___68 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___40 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___40 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___26;

struct timewait_sock_ops___24;

struct proto___40 {
	void (*close)(struct sock___41 *, long int);
	int (*pre_connect)(struct sock___41 *, struct sockaddr *, int);
	int (*connect)(struct sock___41 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___41 *, int);
	struct sock___41 * (*accept)(struct sock___41 *, int, int *, bool);
	int (*ioctl)(struct sock___41 *, int, long unsigned int);
	int (*init)(struct sock___41 *);
	void (*destroy)(struct sock___41 *);
	void (*shutdown)(struct sock___41 *, int);
	int (*setsockopt)(struct sock___41 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___41 *, int, int, char *, int *);
	void (*keepalive)(struct sock___41 *, int);
	int (*sendmsg)(struct sock___41 *, struct msghdr___43 *, size_t);
	int (*recvmsg)(struct sock___41 *, struct msghdr___43 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___41 *, struct page___412 *, int, size_t, int);
	int (*bind)(struct sock___41 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___41 *, struct sk_buff___58 *);
	void (*release_cb)(struct sock___41 *);
	int (*hash)(struct sock___41 *);
	void (*unhash)(struct sock___41 *);
	void (*rehash)(struct sock___41 *);
	int (*get_port)(struct sock___41 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___41 *);
	bool (*stream_memory_read)(const struct sock___41 *);
	void (*enter_memory_pressure)(struct sock___41 *);
	void (*leave_memory_pressure)(struct sock___41 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___26 *rsk_prot;
	struct timewait_sock_ops___24 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___341 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___41 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct xfrm_policy_queue___5 {
	struct sk_buff_head___56 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___5 {
	possible_net_t___58 xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	refcount_t refcnt;
	struct timer_list timer;
	atomic_t genid;
	u32 priority;
	u32 index;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___5 polq;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx___2 *security;
	struct xfrm_tmpl xfrm_vec[6];
	struct callback_head rcu;
	u32 if_id;
};

struct request_sock___27;

struct request_sock_ops___26 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___41 *, struct request_sock___27 *);
	void (*send_ack)(const struct sock___41 *, struct sk_buff___58 *, struct request_sock___27 *);
	void (*send_reset)(const struct sock___41 *, struct sk_buff___58 *);
	void (*destructor)(struct request_sock___27 *);
	void (*syn_ack_timeout)(const struct request_sock___27 *);
};

struct timewait_sock_ops___24 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___41 *, struct sock___41 *, void *);
	void (*twsk_destructor)(struct sock___41 *);
};

struct request_sock___27 {
	struct sock_common___40 __req_common;
	struct request_sock___27 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___26 *rsk_ops;
	struct sock___41 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___22 {
	struct in6_addr mca_addr;
	struct inet6_dev___22 *idev;
	struct ifmcaddr6___22 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___6 {
	struct in6_addr aca_addr;
	struct fib6_info___6 *aca_rt;
	struct ifacaddr6___6 *aca_next;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct ip6_ra_chain___22 {
	struct ip6_ra_chain___22 *next;
	struct sock___41 *sk;
	int sel;
	void (*destructor)(struct sock___41 *);
};

struct rtable___3 {
	struct dst_entry___40 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	__be32 rt_gateway;
	u32 rt_mtu_locked: 1;
	u32 rt_pmtu: 31;
	struct list_head rt_uncached;
	struct uncached_list *rt_uncached_list;
};

struct xfrm_replay___5 {
	void (*advance)(struct xfrm_state___5 *, __be32);
	int (*check)(struct xfrm_state___5 *, struct sk_buff___58 *, __be32);
	int (*recheck)(struct xfrm_state___5 *, struct sk_buff___58 *, __be32);
	void (*notify)(struct xfrm_state___5 *, int);
	int (*overflow)(struct xfrm_state___5 *, struct sk_buff___58 *);
};

struct xfrm_type___5 {
	char *description;
	struct module___341 *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___5 *);
	void (*destructor)(struct xfrm_state___5 *);
	int (*input)(struct xfrm_state___5 *, struct sk_buff___58 *);
	int (*output)(struct xfrm_state___5 *, struct sk_buff___58 *);
	int (*reject)(struct xfrm_state___5 *, struct sk_buff___58 *, const struct flowi *);
	int (*hdr_offset)(struct xfrm_state___5 *, struct sk_buff___58 *, u8 **);
	u32 (*get_mtu)(struct xfrm_state___5 *, int);
};

struct xfrm_state_afinfo___5;

struct xfrm_mode___5 {
	int (*input2)(struct xfrm_state___5 *, struct sk_buff___58 *);
	int (*input)(struct xfrm_state___5 *, struct sk_buff___58 *);
	int (*output2)(struct xfrm_state___5 *, struct sk_buff___58 *);
	int (*output)(struct xfrm_state___5 *, struct sk_buff___58 *);
	struct sk_buff___58 * (*gso_segment)(struct xfrm_state___5 *, struct sk_buff___58 *, netdev_features_t);
	void (*xmit)(struct xfrm_state___5 *, struct sk_buff___58 *);
	struct xfrm_state_afinfo___5 *afinfo;
	struct module___341 *owner;
	unsigned int encap;
	int flags;
};

struct xfrm_type_offload___5 {
	char *description;
	struct module___341 *owner;
	u8 proto;
	void (*encap)(struct xfrm_state___5 *, struct sk_buff___58 *);
	int (*input_tail)(struct xfrm_state___5 *, struct sk_buff___58 *);
	int (*xmit)(struct xfrm_state___5 *, struct sk_buff___58 *, netdev_features_t);
};

struct xfrm_dst___3 {
	union {
		struct dst_entry___40 dst;
		struct rtable___3 rt;
		struct rt6_info___6 rt6;
	} u;
	struct dst_entry___40 *route;
	struct dst_entry___40 *child;
	struct dst_entry___40 *path;
	struct xfrm_policy___5 *pols[2];
	int num_pols;
	int num_xfrms;
	u32 xfrm_genid;
	u32 policy_genid;
	u32 route_mtu_cached;
	u32 child_mtu_cached;
	u32 route_cookie;
	u32 path_cookie;
};

struct xfrm_state_afinfo___5 {
	unsigned int family;
	unsigned int proto;
	__be16 eth_proto;
	struct module___341 *owner;
	const struct xfrm_type___5 *type_map[256];
	const struct xfrm_type_offload___5 *type_offload_map[256];
	struct xfrm_mode___5 *mode_map[5];
	int (*init_flags)(struct xfrm_state___5 *);
	void (*init_tempsel)(struct xfrm_selector *, const struct flowi *);
	void (*init_temprop)(struct xfrm_state___5 *, const struct xfrm_tmpl *, const xfrm_address_t *, const xfrm_address_t *);
	int (*tmpl_sort)(struct xfrm_tmpl **, struct xfrm_tmpl **, int);
	int (*state_sort)(struct xfrm_state___5 **, struct xfrm_state___5 **, int);
	int (*output)(struct net___68 *, struct sock___41 *, struct sk_buff___58 *);
	int (*output_finish)(struct sock___41 *, struct sk_buff___58 *);
	int (*extract_input)(struct xfrm_state___5 *, struct sk_buff___58 *);
	int (*extract_output)(struct xfrm_state___5 *, struct sk_buff___58 *);
	int (*transport_finish)(struct sk_buff___58 *, int);
	void (*local_error)(struct sk_buff___58 *, u32);
};

struct ipv6_stub___3 {
	int (*ipv6_sock_mc_join)(struct sock___41 *, int, const struct in6_addr *);
	int (*ipv6_sock_mc_drop)(struct sock___41 *, int, const struct in6_addr *);
	int (*ipv6_dst_lookup)(struct net___68 *, struct sock___41 *, struct dst_entry___40 **, struct flowi6 *);
	struct fib6_table___6 * (*fib6_get_table)(struct net___68 *, u32);
	struct fib6_info___6 * (*fib6_lookup)(struct net___68 *, int, struct flowi6 *, int);
	struct fib6_info___6 * (*fib6_table_lookup)(struct net___68 *, struct fib6_table___6 *, int, struct flowi6 *, int);
	struct fib6_info___6 * (*fib6_multipath_select)(const struct net___68 *, struct fib6_info___6 *, struct flowi6 *, int, const struct sk_buff___58 *, int);
	u32 (*ip6_mtu_from_fib6)(struct fib6_info___6 *, struct in6_addr *, struct in6_addr *);
	void (*udpv6_encap_enable)();
	void (*ndisc_send_na)(struct net_device___57 *, const struct in6_addr *, const struct in6_addr *, bool, bool, bool, bool);
	struct neigh_table___40 *nd_tbl;
};

struct ipv6_bpf_stub___3 {
	int (*inet6_bind)(struct sock___41 *, struct sockaddr *, int, bool, bool);
	struct sock___41 * (*udp6_lib_lookup)(struct net___68 *, const struct in6_addr *, __be16, const struct in6_addr *, __be16, int, int, struct udp_table *, struct sk_buff___58 *);
};

struct ip_tunnel_encap_ops___3 {
	size_t (*encap_hlen)(struct ip_tunnel_encap *);
	int (*build_header)(struct sk_buff___58 *, struct ip_tunnel_encap *, u8 *, struct flowi4 *);
};

struct hw_port_info___3 {
	struct net_device___57 *lower_dev;
	u32 port_id;
};

struct metadata_dst___3 {
	struct dst_entry___40 dst;
	enum metadata_type type;
	union {
		struct ip_tunnel_info tun_info;
		struct hw_port_info___3 port_info;
	} u;
};

struct seq_net_private___3 {
	struct net___60 *net;
};

struct netlink_skb_parms___7 {
	struct scm_creds creds;
	__u32 portid;
	__u32 dst_group;
	__u32 flags;
	struct sock___2 *sk;
	bool nsid_is_set;
	int nsid;
};

enum {
	NDA_UNSPEC = 0,
	NDA_DST = 1,
	NDA_LLADDR = 2,
	NDA_CACHEINFO = 3,
	NDA_PROBES = 4,
	NDA_VLAN = 5,
	NDA_PORT = 6,
	NDA_VNI = 7,
	NDA_IFINDEX = 8,
	NDA_MASTER = 9,
	NDA_LINK_NETNSID = 10,
	NDA_SRC_VNI = 11,
	__NDA_MAX = 12,
};

struct nda_cacheinfo {
	__u32 ndm_confirmed;
	__u32 ndm_used;
	__u32 ndm_updated;
	__u32 ndm_refcnt;
};

struct ndt_stats {
	__u64 ndts_allocs;
	__u64 ndts_destroys;
	__u64 ndts_hash_grows;
	__u64 ndts_res_failed;
	__u64 ndts_lookups;
	__u64 ndts_hits;
	__u64 ndts_rcv_probes_mcast;
	__u64 ndts_rcv_probes_ucast;
	__u64 ndts_periodic_gc_runs;
	__u64 ndts_forced_gc_runs;
	__u64 ndts_table_fulls;
};

enum {
	NDTPA_UNSPEC = 0,
	NDTPA_IFINDEX = 1,
	NDTPA_REFCNT = 2,
	NDTPA_REACHABLE_TIME = 3,
	NDTPA_BASE_REACHABLE_TIME = 4,
	NDTPA_RETRANS_TIME = 5,
	NDTPA_GC_STALETIME = 6,
	NDTPA_DELAY_PROBE_TIME = 7,
	NDTPA_QUEUE_LEN = 8,
	NDTPA_APP_PROBES = 9,
	NDTPA_UCAST_PROBES = 10,
	NDTPA_MCAST_PROBES = 11,
	NDTPA_ANYCAST_DELAY = 12,
	NDTPA_PROXY_DELAY = 13,
	NDTPA_PROXY_QLEN = 14,
	NDTPA_LOCKTIME = 15,
	NDTPA_QUEUE_LENBYTES = 16,
	NDTPA_MCAST_REPROBES = 17,
	NDTPA_PAD = 18,
	__NDTPA_MAX = 19,
};

struct ndtmsg {
	__u8 ndtm_family;
	__u8 ndtm_pad1;
	__u16 ndtm_pad2;
};

struct ndt_config {
	__u16 ndtc_key_len;
	__u16 ndtc_entry_size;
	__u32 ndtc_entries;
	__u32 ndtc_last_flush;
	__u32 ndtc_last_rand;
	__u32 ndtc_hash_rnd;
	__u32 ndtc_hash_mask;
	__u32 ndtc_hash_chain_gc;
	__u32 ndtc_proxy_qlen;
};

enum {
	NDTA_UNSPEC = 0,
	NDTA_NAME = 1,
	NDTA_THRESH1 = 2,
	NDTA_THRESH2 = 3,
	NDTA_THRESH3 = 4,
	NDTA_CONFIG = 5,
	NDTA_PARMS = 6,
	NDTA_STATS = 7,
	NDTA_GC_INTERVAL = 8,
	NDTA_PAD = 9,
	__NDTA_MAX = 10,
};

struct in_ifaddr___2;

struct in_device {
	struct net_device___50 *dev;
	refcount_t refcnt;
	int dead;
	struct in_ifaddr___2 *ifa_list;
	struct ip_mc_list *mc_list;
	struct ip_mc_list **mc_hash;
	int mc_count;
	spinlock_t mc_tomb_lock;
	struct ip_mc_list *mc_tomb;
	long unsigned int mr_v1_seen;
	long unsigned int mr_v2_seen;
	long unsigned int mr_maxdelay;
	long unsigned int mr_qi;
	long unsigned int mr_qri;
	unsigned char mr_qrv;
	unsigned char mr_gq_running;
	unsigned char mr_ifc_count;
	struct timer_list mr_gq_timer;
	struct timer_list mr_ifc_timer;
	struct neigh_parms___32 *arp_parms;
	struct ipv4_devconf cnf;
	struct callback_head callback_head;
};

enum {
	RTN_UNSPEC = 0,
	RTN_UNICAST = 1,
	RTN_LOCAL = 2,
	RTN_BROADCAST = 3,
	RTN_ANYCAST = 4,
	RTN_MULTICAST = 5,
	RTN_BLACKHOLE = 6,
	RTN_UNREACHABLE = 7,
	RTN_PROHIBIT = 8,
	RTN_THROW = 9,
	RTN_NAT = 10,
	RTN_XRESOLVE = 11,
	__RTN_MAX = 12,
};

enum {
	NEIGH_ARP_TABLE = 0,
	NEIGH_ND_TABLE = 1,
	NEIGH_DN_TABLE = 2,
	NEIGH_NR_TABLES = 3,
	NEIGH_LINK_TABLE = 3,
};

struct neigh_seq_state {
	struct seq_net_private___3 p;
	struct neigh_table___32 *tbl;
	struct neigh_hash_table___32 *nht;
	void * (*neigh_sub_iter)(struct neigh_seq_state *, struct neighbour___32 *, loff_t *);
	unsigned int bucket;
	unsigned int flags;
};

struct neighbour_cb {
	long unsigned int sched_next;
	unsigned int flags;
};

enum netevent_notif_type {
	NETEVENT_NEIGH_UPDATE = 1,
	NETEVENT_REDIRECT = 2,
	NETEVENT_DELAY_PROBE_TIME_UPDATE = 3,
	NETEVENT_IPV4_MPATH_HASH_UPDATE = 4,
	NETEVENT_IPV6_MPATH_HASH_UPDATE = 5,
	NETEVENT_IPV4_FWD_UPDATE_PRIORITY_UPDATE = 6,
};

struct in_ifaddr___2 {
	struct hlist_node hash;
	struct in_ifaddr___2 *ifa_next;
	struct in_device *ifa_dev;
	struct callback_head callback_head;
	__be32 ifa_local;
	__be32 ifa_address;
	__be32 ifa_mask;
	__u32 ifa_rt_priority;
	__be32 ifa_broadcast;
	unsigned char ifa_scope;
	unsigned char ifa_prefixlen;
	__u32 ifa_flags;
	char ifa_label[16];
	__u32 ifa_valid_lft;
	__u32 ifa_preferred_lft;
	long unsigned int ifa_cstamp;
	long unsigned int ifa_tstamp;
};

struct ipv6_stub___4 {
	int (*ipv6_sock_mc_join)(struct sock___2 *, int, const struct in6_addr *);
	int (*ipv6_sock_mc_drop)(struct sock___2 *, int, const struct in6_addr *);
	int (*ipv6_dst_lookup)(struct net___60 *, struct sock___2 *, struct dst_entry___32 **, struct flowi6 *);
	struct fib6_table * (*fib6_get_table)(struct net___60 *, u32);
	struct fib6_info * (*fib6_lookup)(struct net___60 *, int, struct flowi6 *, int);
	struct fib6_info * (*fib6_table_lookup)(struct net___60 *, struct fib6_table *, int, struct flowi6 *, int);
	struct fib6_info * (*fib6_multipath_select)(const struct net___60 *, struct fib6_info *, struct flowi6 *, int, const struct sk_buff___50 *, int);
	u32 (*ip6_mtu_from_fib6)(struct fib6_info *, struct in6_addr *, struct in6_addr *);
	void (*udpv6_encap_enable)();
	void (*ndisc_send_na)(struct net_device___50 *, const struct in6_addr *, const struct in6_addr *, bool, bool, bool, bool);
	struct neigh_table___32 *nd_tbl;
};

struct ipv6_bpf_stub___4 {
	int (*inet6_bind)(struct sock___2 *, struct sockaddr *, int, bool, bool);
	struct sock___2 * (*udp6_lib_lookup)(struct net___60 *, const struct in6_addr *, __be16, const struct in6_addr *, __be16, int, int, struct udp_table *, struct sk_buff___50 *);
};

struct neigh_dump_filter {
	int master_idx;
	int dev_idx;
};

struct neigh_sysctl_table {
	struct ctl_table_header *sysctl_header;
	struct ctl_table neigh_vars[21];
};

struct module___342;

struct file___412;

struct kiocb___412;

struct iov_iter___179;

struct poll_table_struct___255;

struct vm_area_struct___413;

struct inode___412;

struct file_lock___412;

struct page___413;

struct pipe_inode_info___93;

struct seq_file___351;

struct file_operations___412 {
	struct module___342 *owner;
	loff_t (*llseek)(struct file___412 *, loff_t, int);
	ssize_t (*read)(struct file___412 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___412 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___412 *, struct iov_iter___179 *);
	ssize_t (*write_iter)(struct kiocb___412 *, struct iov_iter___179 *);
	int (*iopoll)(struct kiocb___412 *, bool);
	int (*iterate)(struct file___412 *, struct dir_context *);
	int (*iterate_shared)(struct file___412 *, struct dir_context *);
	__poll_t (*poll)(struct file___412 *, struct poll_table_struct___255 *);
	long int (*unlocked_ioctl)(struct file___412 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___412 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___412 *, struct vm_area_struct___413 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___412 *, struct file___412 *);
	int (*flush)(struct file___412 *, fl_owner_t);
	int (*release)(struct inode___412 *, struct file___412 *);
	int (*fsync)(struct file___412 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___412 *, int);
	int (*lock)(struct file___412 *, int, struct file_lock___412 *);
	ssize_t (*sendpage)(struct file___412 *, struct page___413 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___412 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___412 *, int, struct file_lock___412 *);
	ssize_t (*splice_write)(struct pipe_inode_info___93 *, struct file___412 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___412 *, loff_t *, struct pipe_inode_info___93 *, size_t, unsigned int);
	int (*setlease)(struct file___412 *, long int, struct file_lock___412 **, void **);
	long int (*fallocate)(struct file___412 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___351 *, struct file___412 *);
	ssize_t (*copy_file_range)(struct file___412 *, loff_t, struct file___412 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___412 *, loff_t, struct file___412 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___412 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___413 {
	u64 seqnum;
	struct vm_area_struct___413 *vmas[4];
};

struct page_frag___413 {
	struct page___413 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___413;

struct mem_cgroup___149;

struct cred___380;

struct nsproxy___307;

struct signal_struct___287;

struct bio_list___206;

struct backing_dev_info___206;

struct css_set___261;

struct vm_struct___316;

struct task_struct___414 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___414 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___413 *mm;
	struct mm_struct___413 *active_mm;
	struct vmacache___413 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___414 *real_parent;
	struct task_struct___414 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___414 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___149 *active_memcg;
	long int rh_reserved2;
	struct pid___235 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___235 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___235 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___380 *ptracer_cred;
	const struct cred___380 *real_cred;
	const struct cred___380 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___307 *nsproxy;
	struct signal_struct___287 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___414 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___206 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___206 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___261 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___93 *splice_pipe;
	struct page_frag___413 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___149 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___414 *oom_reaper_list;
	struct vm_struct___316 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___154 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rw_semaphore___414 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___414 *owner;
};

struct key___380;

struct ucounts___277;

struct user_namespace___277 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___277 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___29 ns;
	long unsigned int flags;
	struct key___380 *persistent_keyring_register;
	struct rw_semaphore___414 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___277 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___413 *pgtable_t___413;

struct address_space___412;

struct dev_pagemap___400;

struct page___413 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___412 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___413 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___413 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___413 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___400 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___149 *mem_cgroup;
};

struct pglist_data___413;

struct lruvec___413 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___413 *pgdat;
};

struct zone___413 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___413 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___413 {
	struct zone___413 *zone;
	int zone_idx;
};

struct zonelist___413 {
	struct zoneref___413 _zonerefs[25];
};

struct pglist_data___413 {
	struct zone___413 node_zones[3];
	struct zonelist___413 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___414 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___414 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___413 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___414 {
	void *stack;
	struct task_struct___414 *task;
	long int status;
};

struct blocking_notifier_head___413 {
	struct rw_semaphore___414 rwsem;
	struct notifier_block *head;
};

struct dentry___412;

struct path___413 {
	struct vfsmount *mnt;
	struct dentry___412 *dentry;
};

struct file___412 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___413 f_path;
	struct inode___412 *f_inode;
	const struct file_operations___412 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___235 f_owner;
	const struct cred___380 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___412 *f_mapping;
	errseq_t f_wb_err;
};

struct user_struct___380;

struct cred___380 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___380 *session_keyring;
	struct key___380 *process_keyring;
	struct key___380 *thread_keyring;
	struct key___380 *request_key_auth;
	void *security;
	struct user_struct___380 *user;
	struct user_namespace___277 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___406;

struct kernfs_elem_dir___406 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___406 *root;
};

struct kernfs_node___407;

struct kernfs_syscall_ops___406;

struct kernfs_root___406 {
	struct kernfs_node___407 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___406 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___406 {
	struct kernfs_node___407 *target_kn;
};

struct kernfs_ops___406;

struct kernfs_elem_attr___406 {
	const struct kernfs_ops___406 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___407 *notify_next;
};

struct kernfs_node___407 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___407 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___406 dir;
		struct kernfs_elem_symlink___406 symlink;
		struct kernfs_elem_attr___406 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___406;

struct kernfs_ops___406 {
	int (*open)(struct kernfs_open_file___406 *);
	void (*release)(struct kernfs_open_file___406 *);
	int (*seq_show)(struct seq_file___351 *, void *);
	void * (*seq_start)(struct seq_file___351 *, loff_t *);
	void * (*seq_next)(struct seq_file___351 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___351 *, void *);
	ssize_t (*read)(struct kernfs_open_file___406 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___406 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___406 *, struct vm_area_struct___413 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___406 *, struct poll_table_struct___255 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___406 {
	int (*remount_fs)(struct kernfs_root___406 *, int *, char *);
	int (*show_options)(struct seq_file___351 *, struct kernfs_root___406 *);
	int (*mkdir)(struct kernfs_node___407 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___407 *);
	int (*rename)(struct kernfs_node___407 *, struct kernfs_node___407 *, const char *);
	int (*show_path)(struct seq_file___351 *, struct kernfs_node___407 *, struct kernfs_root___406 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___351;

struct seq_file___351 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___351 *op;
	int poll_event;
	const struct file___412 *file;
	void *private;
};

struct vm_operations_struct___400;

struct kernfs_open_file___406 {
	struct kernfs_node___407 *kn;
	struct file___412 *file;
	struct seq_file___351 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___400 *vm_ops;
};

struct vm_fault___400;

struct vm_operations_struct___400 {
	void (*open)(struct vm_area_struct___413 *);
	void (*close)(struct vm_area_struct___413 *);
	int (*split)(struct vm_area_struct___413 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___413 *);
	vm_fault_t (*fault)(struct vm_fault___400 *);
	vm_fault_t (*huge_fault)(struct vm_fault___400 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___400 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___413 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___400 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___400 *);
	int (*access)(struct vm_area_struct___413 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___413 *);
	int (*set_policy)(struct vm_area_struct___413 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___413 *, long unsigned int);
	struct page___413 * (*find_special_page)(struct vm_area_struct___413 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___265)(struct file___412 *, wait_queue_head_t *, struct poll_table_struct___255 *);

struct poll_table_struct___255 {
	poll_queue_proc___265 _qproc;
	__poll_t _key;
};

struct vm_area_struct___413 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___413 *vm_next;
	struct vm_area_struct___413 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___413 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___400 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___412 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sock___42;

struct kobj_ns_type_operations___41 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___42 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct net___69;

typedef struct {
	struct net___69 *net;
} possible_net_t___59;

struct proto___41;

struct sock_common___41 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___41 *skc_prot;
	possible_net_t___59 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___42 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___59;

struct sk_buff_head___57 {
	struct sk_buff___59 *next;
	struct sk_buff___59 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___41;

struct socket_wq___42;

struct dst_entry___41;

struct socket___43;

struct net_device___58;

struct sock___42 {
	struct sock_common___41 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___57 sk_error_queue;
	struct sk_buff_head___57 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___59 *head;
		struct sk_buff___59 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___41 *sk_filter;
	union {
		struct socket_wq___42 *sk_wq;
		struct socket_wq___42 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___41 *sk_rx_dst;
	struct dst_entry___41 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___59 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___57 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___413 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___41 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___235 *sk_peer_pid;
	const struct cred___380 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___43 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___149 *sk_memcg;
	void (*sk_state_change)(struct sock___42 *);
	void (*sk_data_ready)(struct sock___42 *);
	void (*sk_write_space)(struct sock___42 *);
	void (*sk_error_report)(struct sock___42 *);
	int (*sk_backlog_rcv)(struct sock___42 *, struct sk_buff___59 *);
	struct sk_buff___59 * (*sk_validate_xmit_skb)(struct sock___42 *, struct net_device___58 *, struct sk_buff___59 *);
	void (*sk_destruct)(struct sock___42 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kobject___400;

struct bin_attribute___376;

struct attribute_group___377 {
	const char *name;
	umode_t (*is_visible)(struct kobject___400 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___400 *, struct bin_attribute___376 *, int);
	struct attribute **attrs;
	struct bin_attribute___376 **bin_attrs;
};

struct kset___399;

struct kobj_type___399;

struct kobject___400 {
	const char *name;
	struct list_head entry;
	struct kobject___400 *parent;
	struct kset___399 *kset;
	struct kobj_type___399 *ktype;
	struct kernfs_node___407 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___376 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___412 *, struct kobject___400 *, struct bin_attribute___376 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___412 *, struct kobject___400 *, struct bin_attribute___376 *, char *, loff_t, size_t);
	int (*mmap)(struct file___412 *, struct kobject___400 *, struct bin_attribute___376 *, struct vm_area_struct___413 *);
};

struct sysfs_ops___399 {
	ssize_t (*show)(struct kobject___400 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___400 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___399;

struct kset___399 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___400 kobj;
	const struct kset_uevent_ops___399 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___399 {
	void (*release)(struct kobject___400 *);
	const struct sysfs_ops___399 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___41 * (*child_ns_type)(struct kobject___400 *);
	const void * (*namespace)(struct kobject___400 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___399 {
	int (* const filter)(struct kset___399 *, struct kobject___400 *);
	const char * (* const name)(struct kset___399 *, struct kobject___400 *);
	int (* const uevent)(struct kset___399 *, struct kobject___400 *, struct kobj_uevent_env *);
};

struct kobj_attribute___390 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___400 *, struct kobj_attribute___390 *, char *);
	ssize_t (*store)(struct kobject___400 *, struct kobj_attribute___390 *, const char *, size_t);
};

struct kernel_param___340;

struct kernel_param_ops___340 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___340 *);
	int (*get)(char *, const struct kernel_param___340 *);
	void (*free)(void *);
};

struct kparam_array___340;

struct kernel_param___340 {
	const char *name;
	struct module___342 *mod;
	const struct kernel_param_ops___340 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___340 *arr;
	};
};

struct kparam_array___340 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___340 *ops;
	void *elem;
};

struct module_kobject___340 {
	struct kobject___400 kobj;
	struct module___342 *mod;
	struct kobject___400 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___340 {
	struct module___342 *mod;
	struct latch_tree_node node;
};

struct module_layout___340 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___340 mtn;
};

struct module_attribute___340;

struct module___342 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___340 mkobj;
	struct module_attribute___340 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___400 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___340 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___340 core_layout;
	struct module_layout___340 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___340 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___340 *, struct module_kobject___340 *, char *);
	ssize_t (*store)(struct module_attribute___340 *, struct module_kobject___340 *, const char *, size_t);
	void (*setup)(struct module___342 *, const char *);
	int (*test)(struct module___342 *);
	void (*free)(struct module___342 *);
};

struct cgroup___261;

struct cgroup_subsys___261;

struct cgroup_subsys_state___261 {
	struct cgroup___261 *cgroup;
	struct cgroup_subsys___261 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___261 *parent;
};

struct cgroup_file___261 {
	struct kernfs_node___407 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___149;

struct mem_cgroup___149 {
	struct cgroup_subsys_state___261 css;
	struct mem_cgroup_id___13 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___261 events_file;
	struct cgroup_file___261 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___414 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___149 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct user_struct___380 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___380 *uid_keyring;
	struct key___380 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___413;

struct mm_struct___413 {
	struct {
		struct vm_area_struct___413 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___412 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___414 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___413 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___414 *owner;
		struct user_namespace___277 *user_ns;
		struct file___412 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___413 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___261;

struct nsproxy___307 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net___69 *net_ns;
	struct cgroup_namespace___261 *cgroup_ns;
};

struct signal_struct___287 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___414 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___414 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___235 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___235 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___413 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___235 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___206;

struct bio_list___206 {
	struct bio___206 *head;
	struct bio___206 *tail;
};

struct bdi_writeback_congested___206;

struct bdi_writeback___206 {
	struct backing_dev_info___206 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___206 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___261 *memcg_css;
	struct cgroup_subsys_state___261 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___380;

struct backing_dev_info___206 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___206 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___380 *dev;
	struct device___380 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___412 *debug_dir;
	struct dentry___412 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___261 {
	struct cgroup_subsys_state___261 *subsys[13];
	refcount_t refcount;
	struct css_set___261 *dom_cset;
	struct cgroup___261 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___261 *mg_src_cgrp;
	struct cgroup___261 *mg_dst_cgrp;
	struct css_set___261 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___412;

struct pipe_buffer___93;

struct pipe_inode_info___93 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___413 *tmp_page;
	struct fasync_struct___412 *fasync_readers;
	struct fasync_struct___412 *fasync_writers;
	struct pipe_buffer___93 *bufs;
	struct user_struct___380 *user;
};

struct vm_struct___316 {
	struct vm_struct___316 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___413 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___299 {
	struct task_struct___414 task;
	long unsigned int stack[8192];
};

struct address_space_operations___412;

struct address_space___412 {
	struct inode___412 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___414 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___412 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___400)(struct vm_area_struct___413 *, long unsigned int, const struct page___413 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___400)(struct page___413 *, void *);

struct dev_pagemap___400 {
	dev_page_fault_t___400 page_fault;
	dev_page_free_t___400 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___380 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___413 {
	struct task_struct___414 *task;
	struct core_thread___413 *next;
};

struct core_state___413 {
	atomic_t nr_threads;
	struct core_thread___413 dumper;
	struct completion startup;
};

struct vm_fault___400 {
	struct vm_area_struct___413 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___413 *cow_page;
	struct mem_cgroup___149 *memcg;
	struct page___413 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___413 prealloc_pte;
};

struct crypto_async_request___23;

typedef void (*crypto_completion_t___23)(struct crypto_async_request___23 *, int);

struct crypto_tfm___23;

struct crypto_async_request___23 {
	struct list_head list;
	crypto_completion_t___23 complete;
	void *data;
	struct crypto_tfm___23 *tfm;
	u32 flags;
};

struct crypto_ablkcipher___23;

struct ablkcipher_request___23;

struct ablkcipher_tfm___23 {
	int (*setkey)(struct crypto_ablkcipher___23 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___23 *);
	int (*decrypt)(struct ablkcipher_request___23 *);
	struct crypto_ablkcipher___23 *base;
	unsigned int ivsize;
	unsigned int reqsize;
};

struct blkcipher_desc___23;

struct blkcipher_tfm___23 {
	void *iv;
	int (*setkey)(struct crypto_tfm___23 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___23 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___23 *, struct scatterlist *, struct scatterlist *, unsigned int);
};

struct cipher_tfm___23 {
	int (*cit_setkey)(struct crypto_tfm___23 *, const u8 *, unsigned int);
	void (*cit_encrypt_one)(struct crypto_tfm___23 *, u8 *, const u8 *);
	void (*cit_decrypt_one)(struct crypto_tfm___23 *, u8 *, const u8 *);
};

struct compress_tfm___23 {
	int (*cot_compress)(struct crypto_tfm___23 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*cot_decompress)(struct crypto_tfm___23 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___23;

struct crypto_tfm___23 {
	u32 crt_flags;
	union {
		struct ablkcipher_tfm___23 ablkcipher;
		struct blkcipher_tfm___23 blkcipher;
		struct cipher_tfm___23 cipher;
		struct compress_tfm___23 compress;
	} crt_u;
	void (*exit)(struct crypto_tfm___23 *);
	struct crypto_alg___23 *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct ablkcipher_request___23 {
	struct crypto_async_request___23 base;
	unsigned int nbytes;
	void *info;
	struct scatterlist *src;
	struct scatterlist *dst;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_blkcipher___23;

struct blkcipher_desc___23 {
	struct crypto_blkcipher___23 *tfm;
	void *info;
	u32 flags;
};

struct crypto_blkcipher___23 {
	struct crypto_tfm___23 base;
};

struct ablkcipher_alg___23 {
	int (*setkey)(struct crypto_ablkcipher___23 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___23 *);
	int (*decrypt)(struct ablkcipher_request___23 *);
	int (*givencrypt)(struct skcipher_givcrypt_request *);
	int (*givdecrypt)(struct skcipher_givcrypt_request *);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct crypto_ablkcipher___23 {
	struct crypto_tfm___23 base;
};

struct blkcipher_alg___23 {
	int (*setkey)(struct crypto_tfm___23 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___23 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___23 *, struct scatterlist *, struct scatterlist *, unsigned int);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct cipher_alg___23 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___23 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___23 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___23 *, u8 *, const u8 *);
};

struct compress_alg___23 {
	int (*coa_compress)(struct crypto_tfm___23 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___23 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___23 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type *cra_type;
	union {
		struct ablkcipher_alg___23 ablkcipher;
		struct blkcipher_alg___23 blkcipher;
		struct cipher_alg___23 cipher;
		struct compress_alg___23 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___23 *);
	void (*cra_exit)(struct crypto_tfm___23 *);
	void (*cra_destroy)(struct crypto_alg___23 *);
	struct module___342 *cra_module;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct crypto_cipher___7 {
	struct crypto_tfm___23 base;
};

struct bio_vec___208 {
	struct page___413 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___179 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___208 *bvec;
		struct pipe_inode_info___93 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct msghdr___44 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___179 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___412 *msg_iocb;
};

struct kiocb___412 {
	struct file___412 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___412 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dentry_operations___412;

struct super_block___412;

struct dentry___412 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___412 *d_parent;
	struct qstr d_name;
	struct inode___412 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___412 *d_op;
	struct super_block___412 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___412;

struct block_device___412;

struct inode___412 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___412 *i_op;
	struct super_block___412 *i_sb;
	struct address_space___412 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___414 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___206 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___412 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___412 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___93 *i_pipe;
		struct block_device___412 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___412 {
	int (*d_revalidate)(struct dentry___412 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___412 *, unsigned int);
	int (*d_hash)(const struct dentry___412 *, struct qstr *);
	int (*d_compare)(const struct dentry___412 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___412 *);
	int (*d_init)(struct dentry___412 *);
	void (*d_release)(struct dentry___412 *);
	void (*d_prune)(struct dentry___412 *);
	void (*d_iput)(struct dentry___412 *, struct inode___412 *);
	char * (*d_dname)(struct dentry___412 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___413 *);
	int (*d_manage)(const struct path___413 *, bool);
	struct dentry___412 * (*d_real)(struct dentry___412 *, const struct inode___412 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___412;

struct mem_dqinfo___412 {
	struct quota_format_type___412 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___412;

struct quota_info___412 {
	unsigned int flags;
	struct rw_semaphore___414 dqio_sem;
	struct inode___412 *files[3];
	struct mem_dqinfo___412 info[3];
	const struct quota_format_ops___412 *ops[3];
};

struct rcuwait___412 {
	struct task_struct___414 *task;
};

struct percpu_rw_semaphore___412 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___414 rw_sem;
	struct rcuwait___412 writer;
	int readers_block;
};

struct sb_writers___412 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___412 rw_sem[3];
};

struct shrink_control___149;

struct shrinker___149 {
	long unsigned int (*count_objects)(struct shrinker___149 *, struct shrink_control___149 *);
	long unsigned int (*scan_objects)(struct shrinker___149 *, struct shrink_control___149 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___412;

struct super_operations___412;

struct dquot_operations___412;

struct quotactl_ops___412;

struct super_block___412 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___412 *s_type;
	const struct super_operations___412 *s_op;
	const struct dquot_operations___412 *dq_op;
	const struct quotactl_ops___412 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___412 *s_root;
	struct rw_semaphore___414 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___412 *s_bdev;
	struct backing_dev_info___206 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___412 s_dquot;
	struct sb_writers___412 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___412 *s_d_op;
	int cleancache_poolid;
	struct shrinker___149 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___277 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___149 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___149 *memcg;
};

struct iattr___412 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___412 *ia_file;
};

struct dquot___412 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___412 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___412 {
	int qf_fmt_id;
	const struct quota_format_ops___412 *qf_ops;
	struct module___342 *qf_owner;
	struct quota_format_type___412 *qf_next;
};

struct quota_format_ops___412 {
	int (*check_quota_file)(struct super_block___412 *, int);
	int (*read_file_info)(struct super_block___412 *, int);
	int (*write_file_info)(struct super_block___412 *, int);
	int (*free_file_info)(struct super_block___412 *, int);
	int (*read_dqblk)(struct dquot___412 *);
	int (*commit_dqblk)(struct dquot___412 *);
	int (*release_dqblk)(struct dquot___412 *);
	int (*get_next_id)(struct super_block___412 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___412 {
	int (*write_dquot)(struct dquot___412 *);
	struct dquot___412 * (*alloc_dquot)(struct super_block___412 *, int);
	void (*destroy_dquot)(struct dquot___412 *);
	int (*acquire_dquot)(struct dquot___412 *);
	int (*release_dquot)(struct dquot___412 *);
	int (*mark_dirty)(struct dquot___412 *);
	int (*write_info)(struct super_block___412 *, int);
	qsize_t * (*get_reserved_space)(struct inode___412 *);
	int (*get_projid)(struct inode___412 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___412 *, qsize_t *);
	int (*get_next_id)(struct super_block___412 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___412 {
	int (*quota_on)(struct super_block___412 *, int, int, const struct path___413 *);
	int (*quota_off)(struct super_block___412 *, int);
	int (*quota_enable)(struct super_block___412 *, unsigned int);
	int (*quota_disable)(struct super_block___412 *, unsigned int);
	int (*quota_sync)(struct super_block___412 *, int);
	int (*set_info)(struct super_block___412 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___412 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___412 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___412 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___412 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___412 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___169;

struct address_space_operations___412 {
	int (*writepage)(struct page___413 *, struct writeback_control___169 *);
	int (*readpage)(struct file___412 *, struct page___413 *);
	int (*writepages)(struct address_space___412 *, struct writeback_control___169 *);
	int (*set_page_dirty)(struct page___413 *);
	int (*readpages)(struct file___412 *, struct address_space___412 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___412 *, struct address_space___412 *, loff_t, unsigned int, unsigned int, struct page___413 **, void **);
	int (*write_end)(struct file___412 *, struct address_space___412 *, loff_t, unsigned int, unsigned int, struct page___413 *, void *);
	sector_t (*bmap)(struct address_space___412 *, sector_t);
	void (*invalidatepage)(struct page___413 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___413 *, gfp_t);
	void (*freepage)(struct page___413 *);
	ssize_t (*direct_IO)(struct kiocb___412 *, struct iov_iter___179 *);
	int (*migratepage)(struct address_space___412 *, struct page___413 *, struct page___413 *, enum migrate_mode);
	bool (*isolate_page)(struct page___413 *, isolate_mode_t);
	void (*putback_page)(struct page___413 *);
	int (*launder_page)(struct page___413 *);
	int (*is_partially_uptodate)(struct page___413 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___413 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___412 *, struct page___413 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___412 *, sector_t *);
	void (*swap_deactivate)(struct file___412 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___169 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___206 *wb;
	struct inode___412 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___412 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___412 *bd_inode;
	struct super_block___412 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___412 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___206 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___412 {
	struct dentry___412 * (*lookup)(struct inode___412 *, struct dentry___412 *, unsigned int);
	const char * (*get_link)(struct dentry___412 *, struct inode___412 *, struct delayed_call *);
	int (*permission)(struct inode___412 *, int);
	struct posix_acl * (*get_acl)(struct inode___412 *, int);
	int (*readlink)(struct dentry___412 *, char *, int);
	int (*create)(struct inode___412 *, struct dentry___412 *, umode_t, bool);
	int (*link)(struct dentry___412 *, struct inode___412 *, struct dentry___412 *);
	int (*unlink)(struct inode___412 *, struct dentry___412 *);
	int (*symlink)(struct inode___412 *, struct dentry___412 *, const char *);
	int (*mkdir)(struct inode___412 *, struct dentry___412 *, umode_t);
	int (*rmdir)(struct inode___412 *, struct dentry___412 *);
	int (*mknod)(struct inode___412 *, struct dentry___412 *, umode_t, dev_t);
	int (*rename)(struct inode___412 *, struct dentry___412 *, struct inode___412 *, struct dentry___412 *, unsigned int);
	int (*setattr)(struct dentry___412 *, struct iattr___412 *);
	int (*getattr)(const struct path___413 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___412 *, char *, size_t);
	int (*fiemap)(struct inode___412 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___412 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___412 *, struct dentry___412 *, struct file___412 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___412 *, struct dentry___412 *, umode_t);
	int (*set_acl)(struct inode___412 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___412 {
	void (*fl_copy_lock)(struct file_lock___412 *, struct file_lock___412 *);
	void (*fl_release_private)(struct file_lock___412 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___412;

struct file_lock___412 {
	struct file_lock___412 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___412 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___412 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___412 *fl_ops;
	const struct lock_manager_operations___412 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___412 {
	int (*lm_compare_owner)(struct file_lock___412 *, struct file_lock___412 *);
	long unsigned int (*lm_owner_key)(struct file_lock___412 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___412 *);
	int (*lm_grant)(struct file_lock___412 *, int);
	bool (*lm_break)(struct file_lock___412 *);
	int (*lm_change)(struct file_lock___412 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___412 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___412 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___412 *fa_next;
	struct file___412 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___412 {
	const char *name;
	int fs_flags;
	struct dentry___412 * (*mount)(struct file_system_type___412 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___412 *);
	struct module___342 *owner;
	struct file_system_type___412 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___412 {
	struct inode___412 * (*alloc_inode)(struct super_block___412 *);
	void (*destroy_inode)(struct inode___412 *);
	void (*dirty_inode)(struct inode___412 *, int);
	int (*write_inode)(struct inode___412 *, struct writeback_control___169 *);
	int (*drop_inode)(struct inode___412 *);
	void (*evict_inode)(struct inode___412 *);
	void (*put_super)(struct super_block___412 *);
	int (*sync_fs)(struct super_block___412 *, int);
	int (*freeze_super)(struct super_block___412 *);
	int (*freeze_fs)(struct super_block___412 *);
	int (*thaw_super)(struct super_block___412 *);
	int (*unfreeze_fs)(struct super_block___412 *);
	int (*statfs)(struct dentry___412 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___412 *, int *, char *);
	void (*umount_begin)(struct super_block___412 *);
	int (*show_options)(struct seq_file___351 *, struct dentry___412 *);
	int (*show_devname)(struct seq_file___351 *, struct dentry___412 *);
	int (*show_path)(struct seq_file___351 *, struct dentry___412 *);
	int (*show_stats)(struct seq_file___351 *, struct dentry___412 *);
	ssize_t (*quota_read)(struct super_block___412 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___412 *, int, const char *, size_t, loff_t);
	struct dquot___412 ** (*get_dquots)(struct inode___412 *);
	int (*bdev_try_to_free_page)(struct super_block___412 *, struct page___413 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___412 *, struct shrink_control___149 *);
	long int (*free_cached_objects)(struct super_block___412 *, struct shrink_control___149 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___206(struct bio___206 *);

struct bio_integrity_payload___206;

struct bio_set___206;

struct bio___206 {
	struct bio___206 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___206 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___206 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___208 *bi_io_vec;
	struct bio_set___206 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___208 bi_inline_vecs[0];
};

struct socket_wq___42 {
	wait_queue_head_t wait;
	struct fasync_struct___412 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___42;

struct socket___43 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___42 *wq;
	struct file___412 *file;
	struct sock___42 *sk;
	const struct proto_ops___42 *ops;
};

typedef int (*sk_read_actor_t___41)(read_descriptor_t *, struct sk_buff___59 *, unsigned int, size_t);

struct proto_ops___42 {
	int family;
	struct module___342 *owner;
	int (*release)(struct socket___43 *);
	int (*bind)(struct socket___43 *, struct sockaddr *, int);
	int (*connect)(struct socket___43 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___43 *, struct socket___43 *);
	int (*accept)(struct socket___43 *, struct socket___43 *, int, bool);
	int (*getname)(struct socket___43 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___412 *, struct socket___43 *, struct poll_table_struct___255 *);
	int (*ioctl)(struct socket___43 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___43 *, int);
	int (*shutdown)(struct socket___43 *, int);
	int (*setsockopt)(struct socket___43 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___43 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___43 *, struct msghdr___44 *, size_t);
	int (*recvmsg)(struct socket___43 *, struct msghdr___44 *, size_t, int);
	int (*mmap)(struct file___412 *, struct socket___43 *, struct vm_area_struct___413 *);
	ssize_t (*sendpage)(struct socket___43 *, struct page___413 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___43 *, loff_t *, struct pipe_inode_info___93 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___42 *, int);
	int (*peek_len)(struct socket___43 *);
	int (*read_sock)(struct sock___42 *, read_descriptor_t *, sk_read_actor_t___41);
	int (*sendpage_locked)(struct sock___42 *, struct page___413 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___42 *, struct msghdr___44 *, size_t);
	int (*set_rcvlowat)(struct sock___42 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct nf_bridge_info___57;

struct sk_buff___59 {
	union {
		struct {
			struct sk_buff___59 *next;
			struct sk_buff___59 *prev;
			union {
				struct net_device___58 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___42 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___59 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___57 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___57;

struct netns_frags___57 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___57 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ip_ra_chain___20;

struct fib_rules_ops___41;

struct tcp_congestion_ops___4;

struct tcp_fastopen_context___4;

struct fib_notifier_ops___41;

struct netns_ipv4___57 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___20 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___41 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___42 *fibnl;
	struct sock___42 **icmp_sk;
	struct sock___42 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___42 **tcp_sk;
	struct netns_frags___57 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops___4 *tcp_congestion_control;
	struct tcp_fastopen_context___4 *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___41 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___41 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___41 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___41;

struct dst_ops___68 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___68 *);
	struct dst_entry___41 * (*check)(struct dst_entry___41 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___41 *);
	unsigned int (*mtu)(const struct dst_entry___41 *);
	u32 * (*cow_metrics)(struct dst_entry___41 *, long unsigned int);
	void (*destroy)(struct dst_entry___41 *);
	void (*ifdown)(struct dst_entry___41 *, struct net_device___58 *, int);
	struct dst_entry___41 * (*negative_advice)(struct dst_entry___41 *);
	void (*link_failure)(struct sk_buff___59 *);
	void (*update_pmtu)(struct dst_entry___41 *, struct sock___42 *, struct sk_buff___59 *, u32);
	void (*redirect)(struct dst_entry___41 *, struct sock___42 *, struct sk_buff___59 *);
	int (*local_out)(struct net___69 *, struct sock___42 *, struct sk_buff___59 *);
	struct neighbour___41 * (*neigh_lookup)(const struct dst_entry___41 *, struct sk_buff___59 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___41 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___68 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___57 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___68 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___41 *fib6_rules_ops;
	struct sock___42 **icmp_sk;
	struct sock___42 *ndisc_sk;
	struct sock___42 *tcp_sk;
	struct sock___42 *igmp_sk;
	struct sock___42 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___41 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___41 *notifier_ops;
	struct fib_notifier_ops___41 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___42 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___42 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___57 {
	struct netns_frags___57 frags;
};

struct netns_xfrm___68 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___42 *nlsk;
	struct sock___42 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___68 xfrm4_dst_ops;
	struct dst_ops___68 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___51;

struct net___69 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___277 *user_ns;
	struct ucounts___277 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___29 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___42 *rtnl;
	struct sock___42 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___58 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___57 ipv4;
	struct netns_ipv6___68 ipv6;
	struct netns_sctp___42 sctp;
	struct netns_nf___4 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___57 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___42 *nfnl;
	struct sock___42 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___68 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___42 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___51 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_info___380 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___380 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___380;

struct bus_type___380;

struct device_driver___380;

struct dev_pm_domain___380;

struct dma_map_ops___152;

struct fwnode_handle___300;

struct class___380;

struct device___380 {
	struct device___380 *parent;
	struct device_private *p;
	struct kobject___400 kobj;
	const char *init_name;
	const struct device_type___380 *type;
	struct mutex mutex;
	struct bus_type___380 *bus;
	struct device_driver___380 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___380 power;
	struct dev_pm_domain___380 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___152 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___300 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___380 *class;
	const struct attribute_group___377 **groups;
	void (*release)(struct device___380 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

typedef void compound_page_dtor___400(struct page___413 *);

struct dev_pm_ops___380 {
	int (*prepare)(struct device___380 *);
	void (*complete)(struct device___380 *);
	int (*suspend)(struct device___380 *);
	int (*resume)(struct device___380 *);
	int (*freeze)(struct device___380 *);
	int (*thaw)(struct device___380 *);
	int (*poweroff)(struct device___380 *);
	int (*restore)(struct device___380 *);
	int (*suspend_late)(struct device___380 *);
	int (*resume_early)(struct device___380 *);
	int (*freeze_late)(struct device___380 *);
	int (*thaw_early)(struct device___380 *);
	int (*poweroff_late)(struct device___380 *);
	int (*restore_early)(struct device___380 *);
	int (*suspend_noirq)(struct device___380 *);
	int (*resume_noirq)(struct device___380 *);
	int (*freeze_noirq)(struct device___380 *);
	int (*thaw_noirq)(struct device___380 *);
	int (*poweroff_noirq)(struct device___380 *);
	int (*restore_noirq)(struct device___380 *);
	int (*runtime_suspend)(struct device___380 *);
	int (*runtime_resume)(struct device___380 *);
	int (*runtime_idle)(struct device___380 *);
};

struct dev_pm_domain___380 {
	struct dev_pm_ops___380 ops;
	void (*detach)(struct device___380 *, bool);
	int (*activate)(struct device___380 *);
	void (*sync)(struct device___380 *);
	void (*dismiss)(struct device___380 *);
};

struct bus_type___380 {
	const char *name;
	const char *dev_name;
	struct device___380 *dev_root;
	const struct attribute_group___377 **bus_groups;
	const struct attribute_group___377 **dev_groups;
	const struct attribute_group___377 **drv_groups;
	int (*match)(struct device___380 *, struct device_driver___380 *);
	int (*uevent)(struct device___380 *, struct kobj_uevent_env *);
	int (*probe)(struct device___380 *);
	int (*remove)(struct device___380 *);
	void (*shutdown)(struct device___380 *);
	int (*online)(struct device___380 *);
	int (*offline)(struct device___380 *);
	int (*suspend)(struct device___380 *, pm_message_t);
	int (*resume)(struct device___380 *);
	int (*num_vf)(struct device___380 *);
	int (*dma_configure)(struct device___380 *);
	const struct dev_pm_ops___380 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___380 {
	const char *name;
	struct bus_type___380 *bus;
	struct module___342 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___380 *);
	int (*remove)(struct device___380 *);
	void (*shutdown)(struct device___380 *);
	int (*suspend)(struct device___380 *, pm_message_t);
	int (*resume)(struct device___380 *);
	const struct attribute_group___377 **groups;
	const struct dev_pm_ops___380 *pm;
	void (*coredump)(struct device___380 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___380 {
	const char *name;
	const struct attribute_group___377 **groups;
	int (*uevent)(struct device___380 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___380 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___380 *);
	const struct dev_pm_ops___380 *pm;
};

struct class___380 {
	const char *name;
	struct module___342 *owner;
	const struct attribute_group___377 **class_groups;
	const struct attribute_group___377 **dev_groups;
	struct kobject___400 *dev_kobj;
	int (*dev_uevent)(struct device___380 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___380 *, umode_t *);
	void (*class_release)(struct class___380 *);
	void (*dev_release)(struct device___380 *);
	int (*shutdown_pre)(struct device___380 *);
	const struct kobj_ns_type_operations___41 *ns_type;
	const void * (*namespace)(struct device___380 *);
	const struct dev_pm_ops___380 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___152 {
	void * (*alloc)(struct device___380 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___380 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___380 *, struct vm_area_struct___413 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___380 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___380 *, struct page___413 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___380 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___380 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___380 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___380 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___380 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___380 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___380 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___380 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___380 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___380 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___380 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___380 *, u64);
	u64 (*get_required_mask)(struct device___380 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___300;

struct fwnode_handle___300 {
	struct fwnode_handle___300 *secondary;
	const struct fwnode_operations___300 *ops;
};

struct fwnode_reference_args___300;

struct fwnode_endpoint___300;

struct fwnode_operations___300 {
	struct fwnode_handle___300 * (*get)(struct fwnode_handle___300 *);
	void (*put)(struct fwnode_handle___300 *);
	bool (*device_is_available)(const struct fwnode_handle___300 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___300 *, const struct device___380 *);
	bool (*property_present)(const struct fwnode_handle___300 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___300 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___300 *, const char *, const char **, size_t);
	struct fwnode_handle___300 * (*get_parent)(const struct fwnode_handle___300 *);
	struct fwnode_handle___300 * (*get_next_child_node)(const struct fwnode_handle___300 *, struct fwnode_handle___300 *);
	struct fwnode_handle___300 * (*get_named_child_node)(const struct fwnode_handle___300 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___300 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___300 *);
	struct fwnode_handle___300 * (*graph_get_next_endpoint)(const struct fwnode_handle___300 *, struct fwnode_handle___300 *);
	struct fwnode_handle___300 * (*graph_get_remote_endpoint)(const struct fwnode_handle___300 *);
	struct fwnode_handle___300 * (*graph_get_port_parent)(struct fwnode_handle___300 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___300 *, struct fwnode_endpoint___300 *);
};

struct fwnode_endpoint___300 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___300 *local_fwnode;
};

struct fwnode_reference_args___300 {
	struct fwnode_handle___300 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___93;

struct pipe_buffer___93 {
	struct page___413 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___93 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___93 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___93 *, struct pipe_buffer___93 *);
	void (*release)(struct pipe_inode_info___93 *, struct pipe_buffer___93 *);
	int (*steal)(struct pipe_inode_info___93 *, struct pipe_buffer___93 *);
	union {
		bool (*get)(struct pipe_inode_info___93 *, struct pipe_buffer___93 *);
		struct {
			void (*get)(struct pipe_inode_info___93 *, struct pipe_buffer___93 *);
		} __UNIQUE_ID_rh_kabi_hide21;
		union {		};
	};
};

struct nf_bridge_info___57 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___57 = 0,
		BRNF_PROTO_8021Q___57 = 1,
		BRNF_PROTO_PPPOE___57 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___58 *physindev;
	struct net_device___58 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___57(struct sk_buff___59 **);

struct net_device_ops___57;

struct ethtool_ops___57;

struct switchdev_ops___2;

struct l3mdev_ops___41;

struct ndisc_ops___23;

struct xfrmdev_ops___57;

struct tlsdev_ops___57;

struct header_ops___57;

struct inet6_dev___23;

struct netdev_rx_queue___57;

struct mini_Qdisc___51;

struct netdev_queue___57;

struct Qdisc___51;

struct rtnl_link_ops___51;

struct dcbnl_rtnl_ops___57;

struct net_device___58 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___57 *netdev_ops;
	const struct ethtool_ops___57 *ethtool_ops;
	const struct switchdev_ops___2 *switchdev_ops;
	const struct l3mdev_ops___41 *l3mdev_ops;
	const struct ndisc_ops___23 *ndisc_ops;
	const struct xfrmdev_ops___57 *xfrmdev_ops;
	const struct tlsdev_ops___57 *tlsdev_ops;
	const struct header_ops___57 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___399 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___23 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___57 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___51 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___57 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___51 *miniq_ingress;
	struct netdev_queue___57 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___57 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___51 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___51 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___57 = 0,
		NETREG_REGISTERED___57 = 1,
		NETREG_UNREGISTERING___57 = 2,
		NETREG_UNREGISTERED___57 = 3,
		NETREG_RELEASED___57 = 4,
		NETREG_DUMMY___57 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___57 = 0,
		RTNL_LINK_INITIALIZING___57 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___58 *);
	struct netpoll_info *npinfo;
	possible_net_t___59 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___380 dev;
	const struct attribute_group___377 *sysfs_groups[4];
	const struct attribute_group___377 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___51 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___57 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide35;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

typedef int (*key_restrict_link_func_t___381)(struct key___380 *, const struct key_type *, const union key_payload *, struct key___380 *);

struct key_restriction___380;

struct key___380 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___414 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___380 *restrict_link;
};

struct key_restriction___380 {
	key_restrict_link_func_t___381 check;
	struct key___380 *key;
	struct key_type *keytype;
};

struct cgroup_namespace___261 {
	refcount_t count;
	struct ns_common___29 ns;
	struct user_namespace___277 *user_ns;
	struct ucounts___277 *ucounts;
	struct css_set___261 *root_cset;
};

struct netlink_skb_parms___8 {
	struct scm_creds creds;
	__u32 portid;
	__u32 dst_group;
	__u32 flags;
	struct sock___42 *sk;
	bool nsid_is_set;
	int nsid;
};

struct netlink_kernel_cfg___4 {
	unsigned int groups;
	unsigned int flags;
	void (*input)(struct sk_buff___59 *);
	struct mutex *cb_mutex;
	int (*bind)(struct net___69 *, int);
	void (*unbind)(struct net___69 *, int);
	bool (*compare)(struct net___69 *, struct sock___42 *);
};

struct netlink_callback___59 {
	struct sk_buff___59 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___59 *);
	int (*dump)(struct sk_buff___59 *, struct netlink_callback___59 *);
	int (*done)(struct netlink_callback___59 *);
	void *data;
	struct module___342 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct netlink_dump_control {
	int (*start)(struct netlink_callback___59 *);
	int (*dump)(struct sk_buff___59 *, struct netlink_callback___59 *);
	int (*done)(struct netlink_callback___59 *);
	void *data;
	struct module___342 *module;
	u16 min_dump_alloc;
};

struct ethtool_ops___57 {
	int (*get_settings)(struct net_device___58 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___58 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___58 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___58 *);
	void (*get_regs)(struct net_device___58 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___58 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___58 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___58 *);
	void (*set_msglevel)(struct net_device___58 *, u32);
	int (*nway_reset)(struct net_device___58 *);
	u32 (*get_link)(struct net_device___58 *);
	int (*get_eeprom_len)(struct net_device___58 *);
	int (*get_eeprom)(struct net_device___58 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___58 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___58 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___58 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___58 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___58 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___58 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___58 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___58 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___58 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___58 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___58 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___58 *);
	void (*complete)(struct net_device___58 *);
	u32 (*get_priv_flags)(struct net_device___58 *);
	int (*set_priv_flags)(struct net_device___58 *, u32);
	int (*get_sset_count)(struct net_device___58 *, int);
	int (*get_rxnfc)(struct net_device___58 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___58 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___58 *, struct ethtool_flash *);
	int (*reset)(struct net_device___58 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___58 *);
	u32 (*get_rxfh_indir_size)(struct net_device___58 *);
	int (*get_rxfh)(struct net_device___58 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___58 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___58 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___58 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___58 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___58 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___58 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___58 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___58 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___58 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___58 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___58 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___58 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___58 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___58 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___58 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___58 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___58 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___58 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___58 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___58 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___58 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	int (*get_fecparam)(struct net_device___58 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___58 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___58 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___58 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___58 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___57;

struct inet_frags___57 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___57 *, const void *);
	void (*destructor)(struct inet_frag_queue___57 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___57 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___59 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___59 *fragments_tail;
	struct sk_buff___59 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___57 *net;
	struct callback_head rcu;
};

struct ip_ra_chain___20 {
	struct ip_ra_chain___20 *next;
	struct sock___42 *sk;
	union {
		void (*destructor)(struct sock___42 *);
		struct sock___42 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___41;

struct fib_lookup_arg___41;

struct fib_rules_ops___41 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___41 *, struct flowi *, int, struct fib_lookup_arg___41 *);
	bool (*suppress)(struct fib_rule___41 *, struct fib_lookup_arg___41 *);
	int (*match)(struct fib_rule___41 *, struct flowi *, int);
	int (*configure)(struct fib_rule___41 *, struct sk_buff___59 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___41 *);
	int (*compare)(struct fib_rule___41 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___41 *, struct sk_buff___59 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___41 *);
	void (*flush_cache)(struct fib_rules_ops___41 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___342 *owner;
	struct net___69 *fro_net;
	struct callback_head rcu;
};

struct tcp_congestion_ops___4 {
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___42 *);
	void (*release)(struct sock___42 *);
	u32 (*ssthresh)(struct sock___42 *);
	void (*cong_avoid)(struct sock___42 *, u32, u32);
	void (*set_state)(struct sock___42 *, u8);
	void (*cwnd_event)(struct sock___42 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___42 *, u32);
	u32 (*undo_cwnd)(struct sock___42 *);
	void (*pkts_acked)(struct sock___42 *, const struct ack_sample *);
	u32 (*min_tso_segs)(struct sock___42 *);
	u32 (*sndbuf_expand)(struct sock___42 *);
	void (*cong_control)(struct sock___42 *, const struct rate_sample *);
	size_t (*get_info)(struct sock___42 *, u32, int *, union tcp_cc_info *);
	char name[16];
	struct module___342 *owner;
};

struct tcp_fastopen_context___4 {
	struct crypto_cipher___7 *tfm;
	__u8 key[16];
	struct callback_head rcu;
};

struct fib_notifier_ops___41 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___69 *);
	int (*fib_dump)(struct net___69 *, struct notifier_block *);
	struct module___342 *owner;
	struct callback_head rcu;
};

struct dst_entry___41 {
	struct net_device___58 *dev;
	struct dst_ops___68 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___59 *);
	int (*output)(struct net___69 *, struct sock___42 *, struct sk_buff___59 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___41;

struct neigh_parms___41;

struct neigh_ops___41;

struct neighbour___41 {
	struct neighbour___41 *next;
	struct neigh_table___41 *tbl;
	struct neigh_parms___41 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___57 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___41 *, struct sk_buff___59 *);
	const struct neigh_ops___41 *ops;
	struct callback_head rcu;
	struct net_device___58 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct ucounts___277 {
	struct hlist_node node;
	struct user_namespace___277 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_prog_aux___54;

struct bpf_prog___51 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___54 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

struct seq_operations___351 {
	void * (*start)(struct seq_file___351 *, loff_t *);
	void (*stop)(struct seq_file___351 *, void *);
	void * (*next)(struct seq_file___351 *, void *, loff_t *);
	int (*show)(struct seq_file___351 *, void *);
};

struct pernet_operations___58 {
	struct list_head list;
	int (*init)(struct net___69 *);
	void (*exit)(struct net___69 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___57 {
	int (*ieee_getets)(struct net_device___58 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___58 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___58 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___58 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___58 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___58 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___58 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___58 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___58 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___58 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___58 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___58 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___58 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___58 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___58 *);
	u8 (*setstate)(struct net_device___58 *, u8);
	void (*getpermhwaddr)(struct net_device___58 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___58 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___58 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___58 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___58 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___58 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___58 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___58 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___58 *, int, u8 *);
	void (*setpfccfg)(struct net_device___58 *, int, u8);
	void (*getpfccfg)(struct net_device___58 *, int, u8 *);
	u8 (*setall)(struct net_device___58 *);
	u8 (*getcap)(struct net_device___58 *, int, u8 *);
	int (*getnumtcs)(struct net_device___58 *, int, u8 *);
	int (*setnumtcs)(struct net_device___58 *, int, u8);
	u8 (*getpfcstate)(struct net_device___58 *);
	void (*setpfcstate)(struct net_device___58 *, u8);
	void (*getbcncfg)(struct net_device___58 *, int, u32 *);
	void (*setbcncfg)(struct net_device___58 *, int, u32);
	void (*getbcnrp)(struct net_device___58 *, int, u8 *);
	void (*setbcnrp)(struct net_device___58 *, int, u8);
	int (*setapp)(struct net_device___58 *, u8, u16, u8);
	int (*getapp)(struct net_device___58 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___58 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___58 *, int, u8);
	u8 (*getdcbx)(struct net_device___58 *);
	u8 (*setdcbx)(struct net_device___58 *, u8);
	int (*peer_getappinfo)(struct net_device___58 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___58 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___58 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___58 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___58 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___58 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct bpf_map___262;

struct bpf_map_ops___261 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___262 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___262 *, struct file___412 *);
	void (*map_free)(struct bpf_map___262 *);
	int (*map_get_next_key)(struct bpf_map___262 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___262 *);
	void * (*map_lookup_elem)(struct bpf_map___262 *, void *);
	int (*map_update_elem)(struct bpf_map___262 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___262 *, void *);
	int (*map_push_elem)(struct bpf_map___262 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___262 *, void *);
	int (*map_peek_elem)(struct bpf_map___262 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___262 *, struct file___412 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___262 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___262 *, void *, struct seq_file___351 *);
	int (*map_check_btf)(const struct bpf_map___262 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___262 {
	const struct bpf_map_ops___261 *ops;
	struct bpf_map___262 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___380 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___57;

struct bpf_map_dev_ops___57 {
	int (*map_get_next_key)(struct bpf_offloaded_map___57 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___57 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___57 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___57 *, void *);
};

struct bpf_offloaded_map___57 {
	struct bpf_map___262 map;
	struct net_device___58 *netdev;
	const struct bpf_map_dev_ops___57 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___51 {
	int (*test_run)(struct bpf_prog___51 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___51 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___51 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___51 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___51 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___51 *, u32 *);
};

struct bpf_prog_offload_ops___51 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___51 *);
	int (*translate)(struct bpf_prog___51 *);
	void (*destroy)(struct bpf_prog___51 *);
};

struct bpf_prog_offload___51 {
	struct bpf_prog___51 *prog;
	struct net_device___58 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___51 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___54 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___51 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___51 *ops;
	struct bpf_map___262 **used_maps;
	struct bpf_prog___51 *prog;
	struct user_struct___380 *user;
	u64 load_time;
	struct bpf_map___262 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___51 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___51 {
	struct bpf_prog___51 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___51 {
	struct callback_head rcu;
	struct bpf_prog_array_item___51 items[0];
};

struct cgroup_bpf___51 {
	struct bpf_prog_array___51 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___51 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___262;

typedef void (*kthread_work_func_t___262)(struct kthread_work___262 *);

struct kthread_worker___262;

struct kthread_work___262 {
	struct list_head node;
	kthread_work_func_t___262 func;
	struct kthread_worker___262 *worker;
	int canceling;
};

struct kthread_worker___262 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___414 *task;
	struct kthread_work___262 *current_work;
};

struct kthread_delayed_work___261 {
	struct kthread_work___262 work;
	struct timer_list timer;
};

struct psi_group___261 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___262 *poll_kworker;
	struct kthread_delayed_work___261 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___261;

struct cgroup_rstat_cpu___261;

struct cgroup___261 {
	struct cgroup_subsys_state___261 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___407 *kn;
	struct cgroup_file___261 procs_file;
	struct cgroup_file___261 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___261 *subsys[13];
	struct cgroup_root___261 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___261 *dom_cgrp;
	struct cgroup_rstat_cpu___261 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___51 bpf;
	atomic_t congestion_count;
	struct cgroup___261 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___261 psi;
	int ancestor_ids[0];
};

struct cftype___261;

struct cgroup_subsys___261 {
	struct cgroup_subsys_state___261 * (*css_alloc)(struct cgroup_subsys_state___261 *);
	int (*css_online)(struct cgroup_subsys_state___261 *);
	void (*css_offline)(struct cgroup_subsys_state___261 *);
	void (*css_released)(struct cgroup_subsys_state___261 *);
	void (*css_free)(struct cgroup_subsys_state___261 *);
	void (*css_reset)(struct cgroup_subsys_state___261 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___261 *, int);
	int (*css_extra_stat_show)(struct seq_file___351 *, struct cgroup_subsys_state___261 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___414 *);
	void (*cancel_fork)(struct task_struct___414 *);
	void (*fork)(struct task_struct___414 *);
	void (*exit)(struct task_struct___414 *);
	void (*free)(struct task_struct___414 *);
	void (*bind)(struct cgroup_subsys_state___261 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___261 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___261 *dfl_cftypes;
	struct cftype___261 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___261 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___261 *updated_children;
	struct cgroup___261 *updated_next;
};

struct cgroup_root___261 {
	struct kernfs_root___406 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___261 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___261 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___261 *ss;
	struct list_head node;
	struct kernfs_ops___406 *kf_ops;
	int (*open)(struct kernfs_open_file___406 *);
	void (*release)(struct kernfs_open_file___406 *);
	u64 (*read_u64)(struct cgroup_subsys_state___261 *, struct cftype___261 *);
	s64 (*read_s64)(struct cgroup_subsys_state___261 *, struct cftype___261 *);
	int (*seq_show)(struct seq_file___351 *, void *);
	void * (*seq_start)(struct seq_file___351 *, loff_t *);
	void * (*seq_next)(struct seq_file___351 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___351 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___261 *, struct cftype___261 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___261 *, struct cftype___261 *, s64);
	ssize_t (*write)(struct kernfs_open_file___406 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___406 *, struct poll_table_struct___255 *);
};

struct xdp_rxq_info___57 {
	struct net_device___58 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___57 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___58 *dev_rx;
};

struct rtnl_link_stats {
	__u32 rx_packets;
	__u32 tx_packets;
	__u32 rx_bytes;
	__u32 tx_bytes;
	__u32 rx_errors;
	__u32 tx_errors;
	__u32 rx_dropped;
	__u32 tx_dropped;
	__u32 multicast;
	__u32 collisions;
	__u32 rx_length_errors;
	__u32 rx_over_errors;
	__u32 rx_crc_errors;
	__u32 rx_frame_errors;
	__u32 rx_fifo_errors;
	__u32 rx_missed_errors;
	__u32 tx_aborted_errors;
	__u32 tx_carrier_errors;
	__u32 tx_fifo_errors;
	__u32 tx_heartbeat_errors;
	__u32 tx_window_errors;
	__u32 rx_compressed;
	__u32 tx_compressed;
	__u32 rx_nohandler;
	char __rh_tail[0];
	__u32 __rh_reserved_1;
	__u32 __rh_reserved_2;
	__u32 __rh_reserved_3;
	__u32 __rh_reserved_4;
};

struct rtnl_link_ifmap {
	__u64 mem_start;
	__u64 mem_end;
	__u64 base_addr;
	__u16 irq;
	__u8 dma;
	__u8 port;
};

enum {
	IFLA_UNSPEC = 0,
	IFLA_ADDRESS = 1,
	IFLA_BROADCAST = 2,
	IFLA_IFNAME = 3,
	IFLA_MTU = 4,
	IFLA_LINK = 5,
	IFLA_QDISC = 6,
	IFLA_STATS = 7,
	IFLA_COST = 8,
	IFLA_PRIORITY = 9,
	IFLA_MASTER = 10,
	IFLA_WIRELESS = 11,
	IFLA_PROTINFO = 12,
	IFLA_TXQLEN = 13,
	IFLA_MAP = 14,
	IFLA_WEIGHT = 15,
	IFLA_OPERSTATE = 16,
	IFLA_LINKMODE = 17,
	IFLA_LINKINFO = 18,
	IFLA_NET_NS_PID = 19,
	IFLA_IFALIAS = 20,
	IFLA_NUM_VF = 21,
	IFLA_VFINFO_LIST = 22,
	IFLA_STATS64 = 23,
	IFLA_VF_PORTS = 24,
	IFLA_PORT_SELF = 25,
	IFLA_AF_SPEC = 26,
	IFLA_GROUP = 27,
	IFLA_NET_NS_FD = 28,
	IFLA_EXT_MASK = 29,
	IFLA_PROMISCUITY = 30,
	IFLA_NUM_TX_QUEUES = 31,
	IFLA_NUM_RX_QUEUES = 32,
	IFLA_CARRIER = 33,
	IFLA_PHYS_PORT_ID = 34,
	IFLA_CARRIER_CHANGES = 35,
	IFLA_PHYS_SWITCH_ID = 36,
	IFLA_LINK_NETNSID = 37,
	IFLA_PHYS_PORT_NAME = 38,
	IFLA_PROTO_DOWN = 39,
	IFLA_GSO_MAX_SEGS = 40,
	IFLA_GSO_MAX_SIZE = 41,
	IFLA_PAD = 42,
	IFLA_XDP = 43,
	IFLA_EVENT = 44,
	IFLA_NEW_NETNSID = 45,
	IFLA_IF_NETNSID = 46,
	IFLA_TARGET_NETNSID = 46,
	IFLA_CARRIER_UP_COUNT = 47,
	IFLA_CARRIER_DOWN_COUNT = 48,
	IFLA_NEW_IFINDEX = 49,
	__IFLA_MAX = 50,
};

enum {
	IFLA_BRPORT_UNSPEC = 0,
	IFLA_BRPORT_STATE = 1,
	IFLA_BRPORT_PRIORITY = 2,
	IFLA_BRPORT_COST = 3,
	IFLA_BRPORT_MODE = 4,
	IFLA_BRPORT_GUARD = 5,
	IFLA_BRPORT_PROTECT = 6,
	IFLA_BRPORT_FAST_LEAVE = 7,
	IFLA_BRPORT_LEARNING = 8,
	IFLA_BRPORT_UNICAST_FLOOD = 9,
	IFLA_BRPORT_PROXYARP = 10,
	IFLA_BRPORT_LEARNING_SYNC = 11,
	IFLA_BRPORT_PROXYARP_WIFI = 12,
	IFLA_BRPORT_ROOT_ID = 13,
	IFLA_BRPORT_BRIDGE_ID = 14,
	IFLA_BRPORT_DESIGNATED_PORT = 15,
	IFLA_BRPORT_DESIGNATED_COST = 16,
	IFLA_BRPORT_ID = 17,
	IFLA_BRPORT_NO = 18,
	IFLA_BRPORT_TOPOLOGY_CHANGE_ACK = 19,
	IFLA_BRPORT_CONFIG_PENDING = 20,
	IFLA_BRPORT_MESSAGE_AGE_TIMER = 21,
	IFLA_BRPORT_FORWARD_DELAY_TIMER = 22,
	IFLA_BRPORT_HOLD_TIMER = 23,
	IFLA_BRPORT_FLUSH = 24,
	IFLA_BRPORT_MULTICAST_ROUTER = 25,
	IFLA_BRPORT_PAD = 26,
	IFLA_BRPORT_MCAST_FLOOD = 27,
	IFLA_BRPORT_MCAST_TO_UCAST = 28,
	IFLA_BRPORT_VLAN_TUNNEL = 29,
	IFLA_BRPORT_BCAST_FLOOD = 30,
	IFLA_BRPORT_GROUP_FWD_MASK = 31,
	IFLA_BRPORT_NEIGH_SUPPRESS = 32,
	IFLA_BRPORT_ISOLATED = 33,
	__IFLA_BRPORT_MAX = 34,
};

enum {
	IFLA_INFO_UNSPEC = 0,
	IFLA_INFO_KIND = 1,
	IFLA_INFO_DATA = 2,
	IFLA_INFO_XSTATS = 3,
	IFLA_INFO_SLAVE_KIND = 4,
	IFLA_INFO_SLAVE_DATA = 5,
	__IFLA_INFO_MAX = 6,
};

enum {
	IFLA_VF_INFO_UNSPEC = 0,
	IFLA_VF_INFO = 1,
	__IFLA_VF_INFO_MAX = 2,
};

enum {
	IFLA_VF_UNSPEC = 0,
	IFLA_VF_MAC = 1,
	IFLA_VF_VLAN = 2,
	IFLA_VF_TX_RATE = 3,
	IFLA_VF_SPOOFCHK = 4,
	IFLA_VF_LINK_STATE = 5,
	IFLA_VF_RATE = 6,
	IFLA_VF_RSS_QUERY_EN = 7,
	IFLA_VF_STATS = 8,
	IFLA_VF_TRUST = 9,
	IFLA_VF_IB_NODE_GUID = 10,
	IFLA_VF_IB_PORT_GUID = 11,
	IFLA_VF_VLAN_LIST = 12,
	__IFLA_VF_MAX = 13,
};

struct ifla_vf_mac {
	__u32 vf;
	__u8 mac[32];
};

struct ifla_vf_vlan {
	__u32 vf;
	__u32 vlan;
	__u32 qos;
};

enum {
	IFLA_VF_VLAN_INFO_UNSPEC = 0,
	IFLA_VF_VLAN_INFO = 1,
	__IFLA_VF_VLAN_INFO_MAX = 2,
};

struct ifla_vf_vlan_info {
	__u32 vf;
	__u32 vlan;
	__u32 qos;
	__be16 vlan_proto;
};

struct ifla_vf_tx_rate {
	__u32 vf;
	__u32 rate;
};

struct ifla_vf_rate {
	__u32 vf;
	__u32 min_tx_rate;
	__u32 max_tx_rate;
};

struct ifla_vf_spoofchk {
	__u32 vf;
	__u32 setting;
};

struct ifla_vf_guid {
	__u32 vf;
	__u64 guid;
};

struct ifla_vf_link_state {
	__u32 vf;
	__u32 link_state;
};

struct ifla_vf_rss_query_en {
	__u32 vf;
	__u32 setting;
};

enum {
	IFLA_VF_STATS_RX_PACKETS = 0,
	IFLA_VF_STATS_TX_PACKETS = 1,
	IFLA_VF_STATS_RX_BYTES = 2,
	IFLA_VF_STATS_TX_BYTES = 3,
	IFLA_VF_STATS_BROADCAST = 4,
	IFLA_VF_STATS_MULTICAST = 5,
	IFLA_VF_STATS_PAD = 6,
	IFLA_VF_STATS_RX_DROPPED = 7,
	IFLA_VF_STATS_TX_DROPPED = 8,
	__IFLA_VF_STATS_MAX = 9,
};

struct ifla_vf_trust {
	__u32 vf;
	__u32 setting;
};

enum {
	IFLA_VF_PORT_UNSPEC = 0,
	IFLA_VF_PORT = 1,
	__IFLA_VF_PORT_MAX = 2,
};

enum {
	IFLA_PORT_UNSPEC = 0,
	IFLA_PORT_VF = 1,
	IFLA_PORT_PROFILE = 2,
	IFLA_PORT_VSI_TYPE = 3,
	IFLA_PORT_INSTANCE_UUID = 4,
	IFLA_PORT_HOST_UUID = 5,
	IFLA_PORT_REQUEST = 6,
	IFLA_PORT_RESPONSE = 7,
	__IFLA_PORT_MAX = 8,
};

struct if_stats_msg {
	__u8 family;
	__u8 pad1;
	__u16 pad2;
	__u32 ifindex;
	__u32 filter_mask;
};

enum {
	IFLA_STATS_UNSPEC = 0,
	IFLA_STATS_LINK_64 = 1,
	IFLA_STATS_LINK_XSTATS = 2,
	IFLA_STATS_LINK_XSTATS_SLAVE = 3,
	IFLA_STATS_LINK_OFFLOAD_XSTATS = 4,
	IFLA_STATS_AF_SPEC = 5,
	__IFLA_STATS_MAX = 6,
};

enum {
	IFLA_OFFLOAD_XSTATS_UNSPEC = 0,
	IFLA_OFFLOAD_XSTATS_CPU_HIT = 1,
	__IFLA_OFFLOAD_XSTATS_MAX = 2,
};

enum {
	XDP_ATTACHED_NONE = 0,
	XDP_ATTACHED_DRV = 1,
	XDP_ATTACHED_SKB = 2,
	XDP_ATTACHED_HW = 3,
	XDP_ATTACHED_MULTI = 4,
};

enum {
	IFLA_XDP_UNSPEC = 0,
	IFLA_XDP_FD = 1,
	IFLA_XDP_ATTACHED = 2,
	IFLA_XDP_FLAGS = 3,
	IFLA_XDP_PROG_ID = 4,
	IFLA_XDP_DRV_PROG_ID = 5,
	IFLA_XDP_SKB_PROG_ID = 6,
	IFLA_XDP_HW_PROG_ID = 7,
	__IFLA_XDP_MAX = 8,
};

enum {
	IFLA_EVENT_NONE = 0,
	IFLA_EVENT_REBOOT = 1,
	IFLA_EVENT_FEATURES = 2,
	IFLA_EVENT_BONDING_FAILOVER = 3,
	IFLA_EVENT_NOTIFY_PEERS = 4,
	IFLA_EVENT_IGMP_RESEND = 5,
	IFLA_EVENT_BONDING_OPTIONS = 6,
};

struct header_ops___57 {
	int (*create)(struct sk_buff___59 *, struct net_device___58 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___59 *, unsigned char *);
	int (*cache)(const struct neighbour___41 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___58 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___57 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___57 *, int);
	int poll_owner;
	struct net_device___58 *dev;
	struct sk_buff___59 *gro_list;
	struct sk_buff___59 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___57 {
	struct net_device___58 *dev;
	struct Qdisc___51 *qdisc;
	struct Qdisc___51 *qdisc_sleeping;
	struct kobject___400 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___58 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem___2 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___51 {
	struct sk_buff___59 *head;
	struct sk_buff___59 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___51;

struct Qdisc___51 {
	int (*enqueue)(struct sk_buff___59 *, struct Qdisc___51 *, struct sk_buff___59 **);
	struct sk_buff___59 * (*dequeue)(struct Qdisc___51 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___51 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___57 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___57 gso_skb;
	struct qdisc_skb_head___51 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___51 *next_sched;
	struct sk_buff_head___57 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___57 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___400 kobj;
	struct net_device___58 *dev;
	long: 64;
	struct xdp_rxq_info___57 xdp_rxq;
	union {
		struct xdp_umem___2 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___57)(struct net_device___58 *, struct sk_buff___59 *, struct net_device___58 *);

struct netdev_bpf___57 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___51 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___51 *prog;
			const struct bpf_prog_offload_ops___51 *ops;
		} verifier;
		struct {
			struct bpf_prog___51 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___57 *offmap;
		};
		struct {
			struct xdp_umem___2 *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___57 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___59 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___57 {
	int (*tls_dev_add)(struct net_device___58 *, struct sock___42 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___58 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___58 *, struct sock___42 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___57 {
	int (*ndo_init)(struct net_device___58 *);
	void (*ndo_uninit)(struct net_device___58 *);
	int (*ndo_open)(struct net_device___58 *);
	int (*ndo_stop)(struct net_device___58 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___59 *, struct net_device___58 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___59 *, struct net_device___58 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___58 *, struct sk_buff___59 *, struct net_device___58 *, select_queue_fallback_t___57);
	void (*ndo_change_rx_flags)(struct net_device___58 *, int);
	void (*ndo_set_rx_mode)(struct net_device___58 *);
	int (*ndo_set_mac_address)(struct net_device___58 *, void *);
	int (*ndo_validate_addr)(struct net_device___58 *);
	int (*ndo_do_ioctl)(struct net_device___58 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___58 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___58 *, int);
	int (*ndo_neigh_setup)(struct net_device___58 *, struct neigh_parms___41 *);
	void (*ndo_tx_timeout)(struct net_device___58 *);
	void (*ndo_get_stats64)(struct net_device___58 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___58 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___58 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___58 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___58 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___58 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___58 *);
	int (*ndo_netpoll_setup)(struct net_device___58 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___58 *);
	int (*ndo_set_vf_mac)(struct net_device___58 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___58 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___58 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___58 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___58 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___58 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___58 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___58 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___58 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___58 *, int, struct sk_buff___59 *);
	int (*ndo_set_vf_guid)(struct net_device___58 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___58 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___58 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___58 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___58 *, const struct sk_buff___59 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___58 *, struct net_device___58 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___58 *, struct net_device___58 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___58 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___58 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___58 *, struct neighbour___41 *);
	void (*ndo_neigh_destroy)(struct net_device___58 *, struct neighbour___41 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___58 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___58 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___58 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___59 *, struct netlink_callback___59 *, struct net_device___58 *, struct net_device___58 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___58 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___58 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___59 *, u32, u32, struct net_device___58 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___58 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___58 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___58 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___58 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___58 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___58 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___58 *, struct net_device___58 *);
	void (*ndo_dfwd_del_station)(struct net_device___58 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___58 *);
	int (*ndo_set_tx_maxrate)(struct net_device___58 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___58 *);
	int (*ndo_change_proto_down)(struct net_device___58 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___58 *, struct sk_buff___59 *);
	void (*ndo_set_rx_headroom)(struct net_device___58 *, int);
	int (*ndo_bpf)(struct net_device___58 *, struct netdev_bpf___57 *);
	int (*ndo_xdp_xmit)(struct net_device___58 *, int, struct xdp_frame___57 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___58 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___58 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___41 {
	possible_net_t___59 net;
	struct net_device___58 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___41 *);
	void (*neigh_cleanup)(struct neighbour___41 *);
	struct neigh_table___41 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct switchdev_attr___2;

struct switchdev_obj___2;

struct switchdev_ops___2 {
	int (*switchdev_port_attr_get)(struct net_device___58 *, struct switchdev_attr___2 *);
	int (*switchdev_port_attr_set)(struct net_device___58 *, const struct switchdev_attr___2 *, struct switchdev_trans *);
	int (*rh_reserved_switchdev_port_obj_add)(struct net_device___58 *, const struct switchdev_obj___2 *, struct switchdev_trans *);
	int (*rh_reserved_switchdev_port_obj_del)(struct net_device___58 *, const struct switchdev_obj___2 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t switchdev_ops_extended_size_rh;
	struct switchdev_ops_extended_rh switchdev_ops_extended_rh;
};

struct l3mdev_ops___41 {
	u32 (*l3mdev_fib_table)(const struct net_device___58 *);
	struct sk_buff___59 * (*l3mdev_l3_rcv)(struct net_device___58 *, struct sk_buff___59 *, u16);
	struct sk_buff___59 * (*l3mdev_l3_out)(struct net_device___58 *, struct sock___42 *, struct sk_buff___59 *, u16);
	struct dst_entry___41 * (*l3mdev_link_scope_lookup)(const struct net_device___58 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct ndisc_ops___23 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___58 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___58 *, struct neighbour___41 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___58 *, u8, struct neighbour___41 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___58 *, struct sk_buff___59 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___69 *, struct net_device___58 *, const struct prefix_info *, struct inet6_dev___23 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___23;

struct inet6_dev___23 {
	struct net_device___58 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___23 *mc_list;
	struct ifmcaddr6___23 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___6 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	u8 rndid[8];
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___41 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
};

struct tcf_proto___51;

struct mini_Qdisc___51 {
	struct tcf_proto___51 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___51 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___58 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___69 *, struct net_device___58 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___58 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___58 *, struct list_head *);
	size_t (*get_size)(const struct net_device___58 *);
	int (*fill_info)(struct sk_buff___59 *, const struct net_device___58 *);
	size_t (*get_xstats_size)(const struct net_device___58 *);
	int (*fill_xstats)(struct sk_buff___59 *, const struct net_device___58 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___58 *, struct net_device___58 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___58 *, const struct net_device___58 *);
	int (*fill_slave_info)(struct sk_buff___59 *, const struct net_device___58 *, const struct net_device___58 *);
	struct net___69 * (*get_link_net)(const struct net_device___58 *);
	size_t (*get_linkxstats_size)(const struct net_device___58 *, int);
	int (*fill_linkxstats)(struct sk_buff___59 *, const struct net_device___58 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct offload_callbacks___4 {
	struct sk_buff___59 * (*gso_segment)(struct sk_buff___59 *, netdev_features_t);
	struct sk_buff___59 ** (*gro_receive)(struct sk_buff___59 **, struct sk_buff___59 *);
	int (*gro_complete)(struct sk_buff___59 *, int);
};

struct netdev_notifier_info___4 {
	struct net_device___58 *dev;
	struct netlink_ext_ack *extack;
};

struct softnet_data___57 {
	struct list_head poll_list;
	struct sk_buff_head___57 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___57 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___51 *output_queue;
	struct Qdisc___51 **output_queue_tailp;
	struct sk_buff___59 *completion_queue;
	struct sk_buff_head___57 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___57 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___57 input_pkt_queue;
	struct napi_struct___57 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

enum {
	IFLA_BRIDGE_FLAGS = 0,
	IFLA_BRIDGE_MODE = 1,
	IFLA_BRIDGE_VLAN_INFO = 2,
	IFLA_BRIDGE_VLAN_TUNNEL_INFO = 3,
	__IFLA_BRIDGE_MAX = 4,
};

enum {
	BR_MCAST_DIR_RX = 0,
	BR_MCAST_DIR_TX = 1,
	BR_MCAST_DIR_SIZE = 2,
};

typedef int br_should_route_hook_t___2(struct sk_buff___59 *);

enum rtattr_type_t {
	RTA_UNSPEC = 0,
	RTA_DST = 1,
	RTA_SRC = 2,
	RTA_IIF = 3,
	RTA_OIF = 4,
	RTA_GATEWAY = 5,
	RTA_PRIORITY = 6,
	RTA_PREFSRC = 7,
	RTA_METRICS = 8,
	RTA_MULTIPATH = 9,
	RTA_PROTOINFO = 10,
	RTA_FLOW = 11,
	RTA_CACHEINFO = 12,
	RTA_SESSION = 13,
	RTA_MP_ALGO = 14,
	RTA_TABLE = 15,
	RTA_MARK = 16,
	RTA_MFC_STATS = 17,
	RTA_VIA = 18,
	RTA_NEWDST = 19,
	RTA_PREF = 20,
	RTA_ENCAP_TYPE = 21,
	RTA_ENCAP = 22,
	RTA_EXPIRES = 23,
	RTA_PAD = 24,
	RTA_UID = 25,
	RTA_TTL_PROPAGATE = 26,
	RTA_IP_PROTO = 27,
	RTA_SPORT = 28,
	RTA_DPORT = 29,
	__RTA_MAX = 30,
};

struct rta_cacheinfo {
	__u32 rta_clntref;
	__u32 rta_lastuse;
	__s32 rta_expires;
	__u32 rta_error;
	__u32 rta_used;
	__u32 rta_id;
	__u32 rta_ts;
	__u32 rta_tsage;
};

struct ifinfomsg {
	unsigned char ifi_family;
	unsigned char __ifi_pad;
	short unsigned int ifi_type;
	int ifi_index;
	unsigned int ifi_flags;
	unsigned int ifi_change;
};

typedef int (*rtnl_doit_func)(struct sk_buff___59 *, struct nlmsghdr *, struct netlink_ext_ack *);

typedef int (*rtnl_dumpit_func)(struct sk_buff___59 *, struct netlink_callback___59 *);

struct rtnl_af_ops {
	struct list_head list;
	int family;
	int (*fill_link_af)(struct sk_buff___59 *, const struct net_device___58 *, u32);
	size_t (*get_link_af_size)(const struct net_device___58 *, u32);
	int (*validate_link_af)(const struct net_device___58 *, const struct nlattr *);
	int (*set_link_af)(struct net_device___58 *, const struct nlattr *);
	int (*fill_stats_af)(struct sk_buff___59 *, const struct net_device___58 *);
	size_t (*get_stats_af_size)(const struct net_device___58 *);
};

struct fib_rule___41 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___41 *ctarget;
	struct net___69 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___41 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___41 *rule;
	u32 table;
	int flags;
};

struct bdi_writeback_congested___206 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___206 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___206 {
	struct bio___206 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___208 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___208 bip_inline_vecs[0];
};

struct bio_set___206 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___206 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___149 {
	struct mem_cgroup___149 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___149 {
	struct lruvec___413 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___149 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___149 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct gnet_dump___51 {
	spinlock_t *lock;
	struct sk_buff___59 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___51;

struct Qdisc_ops___51 {
	struct Qdisc_ops___51 *next;
	const struct Qdisc_class_ops___51 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___59 *, struct Qdisc___51 *, struct sk_buff___59 **);
	struct sk_buff___59 * (*dequeue)(struct Qdisc___51 *);
	struct sk_buff___59 * (*peek)(struct Qdisc___51 *);
	int (*init)(struct Qdisc___51 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___51 *);
	void (*destroy)(struct Qdisc___51 *);
	int (*change)(struct Qdisc___51 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___51 *);
	int (*change_tx_queue_len)(struct Qdisc___51 *, unsigned int);
	int (*dump)(struct Qdisc___51 *, struct sk_buff___59 *);
	int (*dump_stats)(struct Qdisc___51 *, struct gnet_dump___51 *);
	void (*ingress_block_set)(struct Qdisc___51 *, u32);
	void (*egress_block_set)(struct Qdisc___51 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___51 *);
	u32 (*egress_block_get)(struct Qdisc___51 *);
	struct module___342 *owner;
};

struct qdisc_walker___4;

struct tcf_block___51;

struct Qdisc_class_ops___51 {
	unsigned int flags;
	struct netdev_queue___57 * (*select_queue)(struct Qdisc___51 *, struct tcmsg *);
	int (*graft)(struct Qdisc___51 *, long unsigned int, struct Qdisc___51 *, struct Qdisc___51 **, struct netlink_ext_ack *);
	struct Qdisc___51 * (*leaf)(struct Qdisc___51 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___51 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___51 *, u32);
	int (*change)(struct Qdisc___51 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___51 *, long unsigned int);
	void (*walk)(struct Qdisc___51 *, struct qdisc_walker___4 *);
	struct tcf_block___51 * (*tcf_block)(struct Qdisc___51 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___51 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___51 *, long unsigned int);
	int (*dump)(struct Qdisc___51 *, long unsigned int, struct sk_buff___59 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___51 *, long unsigned int, struct gnet_dump___51 *);
};

struct qdisc_walker___4 {
	int stop;
	int skip;
	int count;
	int (*fn)(struct Qdisc___51 *, long unsigned int, struct qdisc_walker___4 *);
};

struct tcf_chain___51;

struct tcf_block___51 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___69 *net;
	struct Qdisc___51 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___51 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___51;

struct tcf_proto_ops___51;

struct tcf_proto___51 {
	struct tcf_proto___51 *next;
	void *root;
	int (*classify)(struct sk_buff___59 *, const struct tcf_proto___51 *, struct tcf_result___51 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___51 *ops;
	struct tcf_chain___51 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___51 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___51 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___51 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___59 *, const struct tcf_proto___51 *, struct tcf_result___51 *);
	int (*init)(struct tcf_proto___51 *);
	void (*destroy)(struct tcf_proto___51 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___51 *, u32);
	void (*put)(struct tcf_proto___51 *, void *);
	int (*change)(struct net___69 *, struct sk_buff___59 *, struct tcf_proto___51 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___51 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___51 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___51 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___69 *, struct tcf_chain___51 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___69 *, struct tcf_proto___51 *, void *, struct sk_buff___59 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___59 *, struct net___69 *, void *);
	struct module___342 *owner;
	int flags;
};

struct tcf_chain___51 {
	struct mutex filter_chain_lock;
	struct tcf_proto___51 *filter_chain;
	struct list_head list;
	struct tcf_block___51 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___51 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___41 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___51 *prog;
};

struct bpf_redirect_info___51 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___262 *map;
	struct bpf_map___262 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___41;

struct neigh_hash_table___41;

struct neigh_table___41 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___58 *, __u32 *);
	bool (*key_eq)(const struct neighbour___41 *, const void *);
	int (*constructor)(struct neighbour___41 *);
	int (*pconstructor)(struct pneigh_entry___41 *);
	void (*pdestructor)(struct pneigh_entry___41 *);
	void (*proxy_redo)(struct sk_buff___59 *);
	char *id;
	struct neigh_parms___41 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___57 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___41 *nht;
	struct pneigh_entry___41 **phash_buckets;
};

struct neigh_ops___41 {
	int family;
	void (*solicit)(struct neighbour___41 *, struct sk_buff___59 *);
	void (*error_report)(struct neighbour___41 *, struct sk_buff___59 *);
	int (*output)(struct neighbour___41 *, struct sk_buff___59 *);
	int (*connected_output)(struct neighbour___41 *, struct sk_buff___59 *);
};

struct pneigh_entry___41 {
	struct pneigh_entry___41 *next;
	possible_net_t___59 net;
	struct net_device___58 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___41 {
	struct neighbour___41 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct request_sock_ops___27;

struct timewait_sock_ops___25;

struct proto___41 {
	void (*close)(struct sock___42 *, long int);
	int (*pre_connect)(struct sock___42 *, struct sockaddr *, int);
	int (*connect)(struct sock___42 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___42 *, int);
	struct sock___42 * (*accept)(struct sock___42 *, int, int *, bool);
	int (*ioctl)(struct sock___42 *, int, long unsigned int);
	int (*init)(struct sock___42 *);
	void (*destroy)(struct sock___42 *);
	void (*shutdown)(struct sock___42 *, int);
	int (*setsockopt)(struct sock___42 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___42 *, int, int, char *, int *);
	void (*keepalive)(struct sock___42 *, int);
	int (*sendmsg)(struct sock___42 *, struct msghdr___44 *, size_t);
	int (*recvmsg)(struct sock___42 *, struct msghdr___44 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___42 *, struct page___413 *, int, size_t, int);
	int (*bind)(struct sock___42 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___42 *, struct sk_buff___59 *);
	void (*release_cb)(struct sock___42 *);
	int (*hash)(struct sock___42 *);
	void (*unhash)(struct sock___42 *);
	void (*rehash)(struct sock___42 *);
	int (*get_port)(struct sock___42 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___42 *);
	bool (*stream_memory_read)(const struct sock___42 *);
	void (*enter_memory_pressure)(struct sock___42 *);
	void (*leave_memory_pressure)(struct sock___42 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___27 *rsk_prot;
	struct timewait_sock_ops___25 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___342 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___42 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct request_sock___28;

struct request_sock_ops___27 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___42 *, struct request_sock___28 *);
	void (*send_ack)(const struct sock___42 *, struct sk_buff___59 *, struct request_sock___28 *);
	void (*send_reset)(const struct sock___42 *, struct sk_buff___59 *);
	void (*destructor)(struct request_sock___28 *);
	void (*syn_ack_timeout)(const struct request_sock___28 *);
};

struct timewait_sock_ops___25 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___42 *, struct sock___42 *, void *);
	void (*twsk_destructor)(struct sock___42 *);
};

struct request_sock___28 {
	struct sock_common___41 __req_common;
	struct request_sock___28 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___27 *rsk_ops;
	struct sock___42 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___23 {
	struct in6_addr mca_addr;
	struct inet6_dev___23 *idev;
	struct ifmcaddr6___23 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ip6_ra_chain___23 {
	struct ip6_ra_chain___23 *next;
	struct sock___42 *sk;
	int sel;
	void (*destructor)(struct sock___42 *);
};

struct switchdev_attr___2 {
	struct net_device___58 *orig_dev;
	enum switchdev_attr_id id;
	u32 flags;
	void *complete_priv;
	void (*complete)(struct net_device___58 *, int, void *);
	union {
		struct netdev_phys_item_id ppid;
		u8 stp_state;
		long unsigned int brport_flags;
		long unsigned int brport_flags_support;
		bool mrouter;
		clock_t ageing_time;
		bool vlan_filtering;
		bool mc_disabled;
	} u;
};

struct switchdev_obj___2 {
	struct net_device___58 *orig_dev;
	enum switchdev_obj_id id;
	u32 flags;
	void *complete_priv;
	void (*complete)(struct net_device___58 *, int, void *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct net_protocol___3 {
	int (*early_demux)(struct sk_buff___59 *);
	int (*early_demux_handler)(struct sk_buff___59 *);
	int (*handler)(struct sk_buff___59 *);
	void (*err_handler)(struct sk_buff___59 *, u32);
	unsigned int no_policy: 1;
	unsigned int netns_ok: 1;
	unsigned int icmp_strict_tag_validation: 1;
};

struct inet6_protocol___3 {
	void (*early_demux)(struct sk_buff___59 *);
	void (*early_demux_handler)(struct sk_buff___59 *);
	int (*handler)(struct sk_buff___59 *);
	void (*err_handler)(struct sk_buff___59 *, struct inet6_skb_parm *, u8, u8, int, __be32);
	unsigned int flags;
};

struct net_offload___3 {
	struct offload_callbacks___4 callbacks;
	unsigned int flags;
};

struct rtnl_link {
	rtnl_doit_func doit;
	rtnl_dumpit_func dumpit;
	struct module___342 *owner;
	unsigned int flags;
	struct callback_head rcu;
};

enum {
	IF_LINK_MODE_DEFAULT = 0,
	IF_LINK_MODE_DORMANT = 1,
};

enum lw_bits {
	LW_URGENT = 0,
};

struct module___343;

struct file___413;

struct kiocb___413;

struct iov_iter___180;

struct poll_table_struct___256;

struct vm_area_struct___414;

struct inode___413;

struct file_lock___413;

struct page___414;

struct pipe_inode_info___94;

struct seq_file___352;

struct file_operations___413 {
	struct module___343 *owner;
	loff_t (*llseek)(struct file___413 *, loff_t, int);
	ssize_t (*read)(struct file___413 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___413 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___413 *, struct iov_iter___180 *);
	ssize_t (*write_iter)(struct kiocb___413 *, struct iov_iter___180 *);
	int (*iopoll)(struct kiocb___413 *, bool);
	int (*iterate)(struct file___413 *, struct dir_context *);
	int (*iterate_shared)(struct file___413 *, struct dir_context *);
	__poll_t (*poll)(struct file___413 *, struct poll_table_struct___256 *);
	long int (*unlocked_ioctl)(struct file___413 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___413 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___413 *, struct vm_area_struct___414 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___413 *, struct file___413 *);
	int (*flush)(struct file___413 *, fl_owner_t);
	int (*release)(struct inode___413 *, struct file___413 *);
	int (*fsync)(struct file___413 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___413 *, int);
	int (*lock)(struct file___413 *, int, struct file_lock___413 *);
	ssize_t (*sendpage)(struct file___413 *, struct page___414 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___413 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___413 *, int, struct file_lock___413 *);
	ssize_t (*splice_write)(struct pipe_inode_info___94 *, struct file___413 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___413 *, loff_t *, struct pipe_inode_info___94 *, size_t, unsigned int);
	int (*setlease)(struct file___413 *, long int, struct file_lock___413 **, void **);
	long int (*fallocate)(struct file___413 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___352 *, struct file___413 *);
	ssize_t (*copy_file_range)(struct file___413 *, loff_t, struct file___413 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___413 *, loff_t, struct file___413 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___413 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___414 {
	u64 seqnum;
	struct vm_area_struct___414 *vmas[4];
};

struct page_frag___414 {
	struct page___414 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___414;

struct mem_cgroup___150;

struct pid___236;

struct cred___381;

struct nsproxy___308;

struct signal_struct___288;

struct bio_list___207;

struct backing_dev_info___207;

struct css_set___262;

struct vm_struct___317;

struct task_struct___415 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___415 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___414 *mm;
	struct mm_struct___414 *active_mm;
	struct vmacache___414 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___415 *real_parent;
	struct task_struct___415 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___415 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___150 *active_memcg;
	long int rh_reserved2;
	struct pid___236 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___236 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___236 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___381 *ptracer_cred;
	const struct cred___381 *real_cred;
	const struct cred___381 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___308 *nsproxy;
	struct signal_struct___288 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___415 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___207 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___207 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___262 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___94 *splice_pipe;
	struct page_frag___414 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___150 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___415 *oom_reaper_list;
	struct vm_struct___317 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___154 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rw_semaphore___415 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___415 *owner;
};

struct key___381;

struct ucounts___278;

struct user_namespace___278 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___278 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___29 ns;
	long unsigned int flags;
	struct key___381 *persistent_keyring_register;
	struct rw_semaphore___415 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___278 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___414 *pgtable_t___414;

struct address_space___413;

struct dev_pagemap___401;

struct page___414 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___413 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___414 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___414 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___414 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___401 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___150 *mem_cgroup;
};

struct pglist_data___414;

struct lruvec___414 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___414 *pgdat;
};

struct zone___414 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___414 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___414 {
	struct zone___414 *zone;
	int zone_idx;
};

struct zonelist___414 {
	struct zoneref___414 _zonerefs[25];
};

struct pglist_data___414 {
	struct zone___414 node_zones[3];
	struct zonelist___414 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___415 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___415 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___414 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___415 {
	void *stack;
	struct task_struct___415 *task;
	long int status;
};

struct blocking_notifier_head___414 {
	struct rw_semaphore___415 rwsem;
	struct notifier_block *head;
};

struct dentry___413;

struct path___414 {
	struct vfsmount *mnt;
	struct dentry___413 *dentry;
};

struct fown_struct___236 {
	rwlock_t lock;
	struct pid___236 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___413 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___414 f_path;
	struct inode___413 *f_inode;
	const struct file_operations___413 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___236 f_owner;
	const struct cred___381 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___413 *f_mapping;
	errseq_t f_wb_err;
};

struct user_struct___381;

struct cred___381 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___381 *session_keyring;
	struct key___381 *process_keyring;
	struct key___381 *thread_keyring;
	struct key___381 *request_key_auth;
	void *security;
	struct user_struct___381 *user;
	struct user_namespace___278 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___407;

struct kernfs_elem_dir___407 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___407 *root;
};

struct kernfs_node___408;

struct kernfs_syscall_ops___407;

struct kernfs_root___407 {
	struct kernfs_node___408 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___407 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___407 {
	struct kernfs_node___408 *target_kn;
};

struct kernfs_ops___407;

struct kernfs_elem_attr___407 {
	const struct kernfs_ops___407 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___408 *notify_next;
};

struct kernfs_node___408 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___408 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___407 dir;
		struct kernfs_elem_symlink___407 symlink;
		struct kernfs_elem_attr___407 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___407;

struct kernfs_ops___407 {
	int (*open)(struct kernfs_open_file___407 *);
	void (*release)(struct kernfs_open_file___407 *);
	int (*seq_show)(struct seq_file___352 *, void *);
	void * (*seq_start)(struct seq_file___352 *, loff_t *);
	void * (*seq_next)(struct seq_file___352 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___352 *, void *);
	ssize_t (*read)(struct kernfs_open_file___407 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___407 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___407 *, struct vm_area_struct___414 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___407 *, struct poll_table_struct___256 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___407 {
	int (*remount_fs)(struct kernfs_root___407 *, int *, char *);
	int (*show_options)(struct seq_file___352 *, struct kernfs_root___407 *);
	int (*mkdir)(struct kernfs_node___408 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___408 *);
	int (*rename)(struct kernfs_node___408 *, struct kernfs_node___408 *, const char *);
	int (*show_path)(struct seq_file___352 *, struct kernfs_node___408 *, struct kernfs_root___407 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___352;

struct seq_file___352 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___352 *op;
	int poll_event;
	const struct file___413 *file;
	void *private;
};

struct vm_operations_struct___401;

struct kernfs_open_file___407 {
	struct kernfs_node___408 *kn;
	struct file___413 *file;
	struct seq_file___352 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___401 *vm_ops;
};

struct vm_fault___401;

struct vm_operations_struct___401 {
	void (*open)(struct vm_area_struct___414 *);
	void (*close)(struct vm_area_struct___414 *);
	int (*split)(struct vm_area_struct___414 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___414 *);
	vm_fault_t (*fault)(struct vm_fault___401 *);
	vm_fault_t (*huge_fault)(struct vm_fault___401 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___401 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___414 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___401 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___401 *);
	int (*access)(struct vm_area_struct___414 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___414 *);
	int (*set_policy)(struct vm_area_struct___414 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___414 *, long unsigned int);
	struct page___414 * (*find_special_page)(struct vm_area_struct___414 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___266)(struct file___413 *, wait_queue_head_t *, struct poll_table_struct___256 *);

struct poll_table_struct___256 {
	poll_queue_proc___266 _qproc;
	__poll_t _key;
};

struct vm_area_struct___414 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___414 *vm_next;
	struct vm_area_struct___414 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___414 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___401 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___413 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sock___43;

struct kobj_ns_type_operations___42 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___43 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct net___70;

typedef struct {
	struct net___70 *net;
} possible_net_t___60;

struct proto___42;

struct sock_common___42 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___42 *skc_prot;
	possible_net_t___60 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___43 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___60;

struct sk_buff_head___58 {
	struct sk_buff___60 *next;
	struct sk_buff___60 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___42;

struct socket_wq___43;

struct xfrm_policy___6;

struct dst_entry___42;

struct socket___44;

struct net_device___59;

struct sock_reuseport___3;

struct sock___43 {
	struct sock_common___42 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___58 sk_error_queue;
	struct sk_buff_head___58 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___60 *head;
		struct sk_buff___60 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___42 *sk_filter;
	union {
		struct socket_wq___43 *sk_wq;
		struct socket_wq___43 *sk_wq_raw;
	};
	struct xfrm_policy___6 *sk_policy[2];
	struct dst_entry___42 *sk_rx_dst;
	struct dst_entry___42 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___60 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___58 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___414 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___42 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___236 *sk_peer_pid;
	const struct cred___381 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___44 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___150 *sk_memcg;
	void (*sk_state_change)(struct sock___43 *);
	void (*sk_data_ready)(struct sock___43 *);
	void (*sk_write_space)(struct sock___43 *);
	void (*sk_error_report)(struct sock___43 *);
	int (*sk_backlog_rcv)(struct sock___43 *, struct sk_buff___60 *);
	struct sk_buff___60 * (*sk_validate_xmit_skb)(struct sock___43 *, struct net_device___59 *, struct sk_buff___60 *);
	void (*sk_destruct)(struct sock___43 *);
	struct sock_reuseport___3 *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kobject___401;

struct bin_attribute___377;

struct attribute_group___378 {
	const char *name;
	umode_t (*is_visible)(struct kobject___401 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___401 *, struct bin_attribute___377 *, int);
	struct attribute **attrs;
	struct bin_attribute___377 **bin_attrs;
};

struct kset___400;

struct kobj_type___400;

struct kobject___401 {
	const char *name;
	struct list_head entry;
	struct kobject___401 *parent;
	struct kset___400 *kset;
	struct kobj_type___400 *ktype;
	struct kernfs_node___408 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___377 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___413 *, struct kobject___401 *, struct bin_attribute___377 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___413 *, struct kobject___401 *, struct bin_attribute___377 *, char *, loff_t, size_t);
	int (*mmap)(struct file___413 *, struct kobject___401 *, struct bin_attribute___377 *, struct vm_area_struct___414 *);
};

struct sysfs_ops___400 {
	ssize_t (*show)(struct kobject___401 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___401 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___400;

struct kset___400 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___401 kobj;
	const struct kset_uevent_ops___400 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___400 {
	void (*release)(struct kobject___401 *);
	const struct sysfs_ops___400 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___42 * (*child_ns_type)(struct kobject___401 *);
	const void * (*namespace)(struct kobject___401 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___400 {
	int (* const filter)(struct kset___400 *, struct kobject___401 *);
	const char * (* const name)(struct kset___400 *, struct kobject___401 *);
	int (* const uevent)(struct kset___400 *, struct kobject___401 *, struct kobj_uevent_env *);
};

struct kobj_attribute___391 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___401 *, struct kobj_attribute___391 *, char *);
	ssize_t (*store)(struct kobject___401 *, struct kobj_attribute___391 *, const char *, size_t);
};

struct kernel_param___341;

struct kernel_param_ops___341 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___341 *);
	int (*get)(char *, const struct kernel_param___341 *);
	void (*free)(void *);
};

struct kparam_array___341;

struct kernel_param___341 {
	const char *name;
	struct module___343 *mod;
	const struct kernel_param_ops___341 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___341 *arr;
	};
};

struct kparam_array___341 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___341 *ops;
	void *elem;
};

struct module_kobject___341 {
	struct kobject___401 kobj;
	struct module___343 *mod;
	struct kobject___401 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___341 {
	struct module___343 *mod;
	struct latch_tree_node node;
};

struct module_layout___341 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___341 mtn;
};

struct module_attribute___341;

struct module___343 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___341 mkobj;
	struct module_attribute___341 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___401 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___341 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___341 core_layout;
	struct module_layout___341 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___341 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___341 *, struct module_kobject___341 *, char *);
	ssize_t (*store)(struct module_attribute___341 *, struct module_kobject___341 *, const char *, size_t);
	void (*setup)(struct module___343 *, const char *);
	int (*test)(struct module___343 *);
	void (*free)(struct module___343 *);
};

struct core_state___414;

struct mm_struct___414 {
	struct {
		struct vm_area_struct___414 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___413 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___415 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___414 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___415 *owner;
		struct user_namespace___278 *user_ns;
		struct file___413 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___414 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___413;

struct address_space___413 {
	struct inode___413 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___415 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___413 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___401)(struct vm_area_struct___414 *, long unsigned int, const struct page___414 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___401)(struct page___414 *, void *);

struct device___381;

struct dev_pagemap___401 {
	dev_page_fault_t___401 page_fault;
	dev_page_free_t___401 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___381 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct cgroup___262;

struct cgroup_subsys___262;

struct cgroup_subsys_state___262 {
	struct cgroup___262 *cgroup;
	struct cgroup_subsys___262 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___262 *parent;
};

struct cgroup_file___262 {
	struct kernfs_node___408 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___150;

struct mem_cgroup___150 {
	struct cgroup_subsys_state___262 css;
	struct mem_cgroup_id___13 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___262 events_file;
	struct cgroup_file___262 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___415 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___150 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct core_thread___414 {
	struct task_struct___415 *task;
	struct core_thread___414 *next;
};

struct core_state___414 {
	atomic_t nr_threads;
	struct core_thread___414 dumper;
	struct completion startup;
};

struct vm_fault___401 {
	struct vm_area_struct___414 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___414 *cow_page;
	struct mem_cgroup___150 *memcg;
	struct page___414 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___414 prealloc_pte;
};

struct shrink_control___150 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___150 *memcg;
};

struct shrinker___150 {
	long unsigned int (*count_objects)(struct shrinker___150 *, struct shrink_control___150 *);
	long unsigned int (*scan_objects)(struct shrinker___150 *, struct shrink_control___150 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct pid_namespace___236;

struct upid___236 {
	int nr;
	struct pid_namespace___236 *ns;
};

struct pid_namespace___236 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___415 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___236 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___413 *proc_self;
	struct dentry___413 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___278 *user_ns;
	struct ucounts___278 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___29 ns;
};

struct pid___236 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___236 numbers[1];
};

struct user_struct___381 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___381 *uid_keyring;
	struct key___381 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cgroup_namespace___262;

struct nsproxy___308 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___236 *pid_ns_for_children;
	struct net___70 *net_ns;
	struct cgroup_namespace___262 *cgroup_ns;
};

struct signal_struct___288 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___415 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___415 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___236 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___236 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___414 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___236 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___207;

struct bio_list___207 {
	struct bio___207 *head;
	struct bio___207 *tail;
};

struct bdi_writeback_congested___207;

struct bdi_writeback___207 {
	struct backing_dev_info___207 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___207 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___262 *memcg_css;
	struct cgroup_subsys_state___262 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___207 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___207 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___381 *dev;
	struct device___381 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___413 *debug_dir;
	struct dentry___413 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___262 {
	struct cgroup_subsys_state___262 *subsys[13];
	refcount_t refcount;
	struct css_set___262 *dom_cset;
	struct cgroup___262 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___262 *mg_src_cgrp;
	struct cgroup___262 *mg_dst_cgrp;
	struct css_set___262 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___413;

struct pipe_buffer___94;

struct pipe_inode_info___94 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___414 *tmp_page;
	struct fasync_struct___413 *fasync_readers;
	struct fasync_struct___413 *fasync_writers;
	struct pipe_buffer___94 *bufs;
	struct user_struct___381 *user;
};

struct vm_struct___317 {
	struct vm_struct___317 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___414 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___300 {
	struct task_struct___415 task;
	long unsigned int stack[8192];
};

struct dev_pm_info___381 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___381 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___381;

struct bus_type___381;

struct device_driver___381;

struct dev_pm_domain___381;

struct dma_map_ops___153;

struct fwnode_handle___301;

struct class___381;

struct device___381 {
	struct device___381 *parent;
	struct device_private *p;
	struct kobject___401 kobj;
	const char *init_name;
	const struct device_type___381 *type;
	struct mutex mutex;
	struct bus_type___381 *bus;
	struct device_driver___381 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___381 power;
	struct dev_pm_domain___381 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___153 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___301 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___381 *class;
	const struct attribute_group___378 **groups;
	void (*release)(struct device___381 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___413;

struct super_block___413;

struct dentry___413 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___413 *d_parent;
	struct qstr d_name;
	struct inode___413 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___413 *d_op;
	struct super_block___413 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___413;

struct block_device___413;

struct inode___413 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___413 *i_op;
	struct super_block___413 *i_sb;
	struct address_space___413 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___415 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___207 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___413 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___413 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___94 *i_pipe;
		struct block_device___413 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___413 {
	int (*d_revalidate)(struct dentry___413 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___413 *, unsigned int);
	int (*d_hash)(const struct dentry___413 *, struct qstr *);
	int (*d_compare)(const struct dentry___413 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___413 *);
	int (*d_init)(struct dentry___413 *);
	void (*d_release)(struct dentry___413 *);
	void (*d_prune)(struct dentry___413 *);
	void (*d_iput)(struct dentry___413 *, struct inode___413 *);
	char * (*d_dname)(struct dentry___413 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___414 *);
	int (*d_manage)(const struct path___414 *, bool);
	struct dentry___413 * (*d_real)(struct dentry___413 *, const struct inode___413 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___413;

struct mem_dqinfo___413 {
	struct quota_format_type___413 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___413;

struct quota_info___413 {
	unsigned int flags;
	struct rw_semaphore___415 dqio_sem;
	struct inode___413 *files[3];
	struct mem_dqinfo___413 info[3];
	const struct quota_format_ops___413 *ops[3];
};

struct rcuwait___413 {
	struct task_struct___415 *task;
};

struct percpu_rw_semaphore___413 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___415 rw_sem;
	struct rcuwait___413 writer;
	int readers_block;
};

struct sb_writers___413 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___413 rw_sem[3];
};

struct file_system_type___413;

struct super_operations___413;

struct dquot_operations___413;

struct quotactl_ops___413;

struct super_block___413 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___413 *s_type;
	const struct super_operations___413 *s_op;
	const struct dquot_operations___413 *dq_op;
	const struct quotactl_ops___413 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___413 *s_root;
	struct rw_semaphore___415 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___413 *s_bdev;
	struct backing_dev_info___207 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___413 s_dquot;
	struct sb_writers___413 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___413 *s_d_op;
	int cleancache_poolid;
	struct shrinker___150 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___278 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___413 {
	struct file___413 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___413 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___413 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___413 *ia_file;
};

struct dquot___413 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___413 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___413 {
	int qf_fmt_id;
	const struct quota_format_ops___413 *qf_ops;
	struct module___343 *qf_owner;
	struct quota_format_type___413 *qf_next;
};

struct quota_format_ops___413 {
	int (*check_quota_file)(struct super_block___413 *, int);
	int (*read_file_info)(struct super_block___413 *, int);
	int (*write_file_info)(struct super_block___413 *, int);
	int (*free_file_info)(struct super_block___413 *, int);
	int (*read_dqblk)(struct dquot___413 *);
	int (*commit_dqblk)(struct dquot___413 *);
	int (*release_dqblk)(struct dquot___413 *);
	int (*get_next_id)(struct super_block___413 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___413 {
	int (*write_dquot)(struct dquot___413 *);
	struct dquot___413 * (*alloc_dquot)(struct super_block___413 *, int);
	void (*destroy_dquot)(struct dquot___413 *);
	int (*acquire_dquot)(struct dquot___413 *);
	int (*release_dquot)(struct dquot___413 *);
	int (*mark_dirty)(struct dquot___413 *);
	int (*write_info)(struct super_block___413 *, int);
	qsize_t * (*get_reserved_space)(struct inode___413 *);
	int (*get_projid)(struct inode___413 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___413 *, qsize_t *);
	int (*get_next_id)(struct super_block___413 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___413 {
	int (*quota_on)(struct super_block___413 *, int, int, const struct path___414 *);
	int (*quota_off)(struct super_block___413 *, int);
	int (*quota_enable)(struct super_block___413 *, unsigned int);
	int (*quota_disable)(struct super_block___413 *, unsigned int);
	int (*quota_sync)(struct super_block___413 *, int);
	int (*set_info)(struct super_block___413 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___413 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___413 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___413 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___413 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___413 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___170;

struct address_space_operations___413 {
	int (*writepage)(struct page___414 *, struct writeback_control___170 *);
	int (*readpage)(struct file___413 *, struct page___414 *);
	int (*writepages)(struct address_space___413 *, struct writeback_control___170 *);
	int (*set_page_dirty)(struct page___414 *);
	int (*readpages)(struct file___413 *, struct address_space___413 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___413 *, struct address_space___413 *, loff_t, unsigned int, unsigned int, struct page___414 **, void **);
	int (*write_end)(struct file___413 *, struct address_space___413 *, loff_t, unsigned int, unsigned int, struct page___414 *, void *);
	sector_t (*bmap)(struct address_space___413 *, sector_t);
	void (*invalidatepage)(struct page___414 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___414 *, gfp_t);
	void (*freepage)(struct page___414 *);
	ssize_t (*direct_IO)(struct kiocb___413 *, struct iov_iter___180 *);
	int (*migratepage)(struct address_space___413 *, struct page___414 *, struct page___414 *, enum migrate_mode);
	bool (*isolate_page)(struct page___414 *, isolate_mode_t);
	void (*putback_page)(struct page___414 *);
	int (*launder_page)(struct page___414 *);
	int (*is_partially_uptodate)(struct page___414 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___414 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___413 *, struct page___414 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___413 *, sector_t *);
	void (*swap_deactivate)(struct file___413 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___170 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___207 *wb;
	struct inode___413 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___209;

struct iov_iter___180 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___209 *bvec;
		struct pipe_inode_info___94 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___413 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___413 *bd_inode;
	struct super_block___413 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___413 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___207 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___413 {
	struct dentry___413 * (*lookup)(struct inode___413 *, struct dentry___413 *, unsigned int);
	const char * (*get_link)(struct dentry___413 *, struct inode___413 *, struct delayed_call *);
	int (*permission)(struct inode___413 *, int);
	struct posix_acl * (*get_acl)(struct inode___413 *, int);
	int (*readlink)(struct dentry___413 *, char *, int);
	int (*create)(struct inode___413 *, struct dentry___413 *, umode_t, bool);
	int (*link)(struct dentry___413 *, struct inode___413 *, struct dentry___413 *);
	int (*unlink)(struct inode___413 *, struct dentry___413 *);
	int (*symlink)(struct inode___413 *, struct dentry___413 *, const char *);
	int (*mkdir)(struct inode___413 *, struct dentry___413 *, umode_t);
	int (*rmdir)(struct inode___413 *, struct dentry___413 *);
	int (*mknod)(struct inode___413 *, struct dentry___413 *, umode_t, dev_t);
	int (*rename)(struct inode___413 *, struct dentry___413 *, struct inode___413 *, struct dentry___413 *, unsigned int);
	int (*setattr)(struct dentry___413 *, struct iattr___413 *);
	int (*getattr)(const struct path___414 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___413 *, char *, size_t);
	int (*fiemap)(struct inode___413 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___413 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___413 *, struct dentry___413 *, struct file___413 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___413 *, struct dentry___413 *, umode_t);
	int (*set_acl)(struct inode___413 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___413 {
	void (*fl_copy_lock)(struct file_lock___413 *, struct file_lock___413 *);
	void (*fl_release_private)(struct file_lock___413 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___413;

struct file_lock___413 {
	struct file_lock___413 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___413 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___413 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___413 *fl_ops;
	const struct lock_manager_operations___413 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___413 {
	int (*lm_compare_owner)(struct file_lock___413 *, struct file_lock___413 *);
	long unsigned int (*lm_owner_key)(struct file_lock___413 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___413 *);
	int (*lm_grant)(struct file_lock___413 *, int);
	bool (*lm_break)(struct file_lock___413 *);
	int (*lm_change)(struct file_lock___413 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___413 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___413 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___413 *fa_next;
	struct file___413 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___413 {
	const char *name;
	int fs_flags;
	struct dentry___413 * (*mount)(struct file_system_type___413 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___413 *);
	struct module___343 *owner;
	struct file_system_type___413 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___413 {
	struct inode___413 * (*alloc_inode)(struct super_block___413 *);
	void (*destroy_inode)(struct inode___413 *);
	void (*dirty_inode)(struct inode___413 *, int);
	int (*write_inode)(struct inode___413 *, struct writeback_control___170 *);
	int (*drop_inode)(struct inode___413 *);
	void (*evict_inode)(struct inode___413 *);
	void (*put_super)(struct super_block___413 *);
	int (*sync_fs)(struct super_block___413 *, int);
	int (*freeze_super)(struct super_block___413 *);
	int (*freeze_fs)(struct super_block___413 *);
	int (*thaw_super)(struct super_block___413 *);
	int (*unfreeze_fs)(struct super_block___413 *);
	int (*statfs)(struct dentry___413 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___413 *, int *, char *);
	void (*umount_begin)(struct super_block___413 *);
	int (*show_options)(struct seq_file___352 *, struct dentry___413 *);
	int (*show_devname)(struct seq_file___352 *, struct dentry___413 *);
	int (*show_path)(struct seq_file___352 *, struct dentry___413 *);
	int (*show_stats)(struct seq_file___352 *, struct dentry___413 *);
	ssize_t (*quota_read)(struct super_block___413 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___413 *, int, const char *, size_t, loff_t);
	struct dquot___413 ** (*get_dquots)(struct inode___413 *);
	int (*bdev_try_to_free_page)(struct super_block___413 *, struct page___414 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___413 *, struct shrink_control___150 *);
	long int (*free_cached_objects)(struct super_block___413 *, struct shrink_control___150 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___207(struct bio___207 *);

struct bio_vec___209 {
	struct page___414 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___207;

struct bio_set___207;

struct bio___207 {
	struct bio___207 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___207 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___207 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___209 *bi_io_vec;
	struct bio_set___207 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___209 bi_inline_vecs[0];
};

typedef void compound_page_dtor___401(struct page___414 *);

struct crypto_async_request___24;

typedef void (*crypto_completion_t___24)(struct crypto_async_request___24 *, int);

struct crypto_tfm___24;

struct crypto_async_request___24 {
	struct list_head list;
	crypto_completion_t___24 complete;
	void *data;
	struct crypto_tfm___24 *tfm;
	u32 flags;
};

struct crypto_ablkcipher___24;

struct ablkcipher_request___24;

struct ablkcipher_tfm___24 {
	int (*setkey)(struct crypto_ablkcipher___24 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___24 *);
	int (*decrypt)(struct ablkcipher_request___24 *);
	struct crypto_ablkcipher___24 *base;
	unsigned int ivsize;
	unsigned int reqsize;
};

struct blkcipher_desc___24;

struct blkcipher_tfm___24 {
	void *iv;
	int (*setkey)(struct crypto_tfm___24 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___24 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___24 *, struct scatterlist *, struct scatterlist *, unsigned int);
};

struct cipher_tfm___24 {
	int (*cit_setkey)(struct crypto_tfm___24 *, const u8 *, unsigned int);
	void (*cit_encrypt_one)(struct crypto_tfm___24 *, u8 *, const u8 *);
	void (*cit_decrypt_one)(struct crypto_tfm___24 *, u8 *, const u8 *);
};

struct compress_tfm___24 {
	int (*cot_compress)(struct crypto_tfm___24 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*cot_decompress)(struct crypto_tfm___24 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___24;

struct crypto_tfm___24 {
	u32 crt_flags;
	union {
		struct ablkcipher_tfm___24 ablkcipher;
		struct blkcipher_tfm___24 blkcipher;
		struct cipher_tfm___24 cipher;
		struct compress_tfm___24 compress;
	} crt_u;
	void (*exit)(struct crypto_tfm___24 *);
	struct crypto_alg___24 *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct ablkcipher_request___24 {
	struct crypto_async_request___24 base;
	unsigned int nbytes;
	void *info;
	struct scatterlist *src;
	struct scatterlist *dst;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_blkcipher___24;

struct blkcipher_desc___24 {
	struct crypto_blkcipher___24 *tfm;
	void *info;
	u32 flags;
};

struct crypto_blkcipher___24 {
	struct crypto_tfm___24 base;
};

struct ablkcipher_alg___24 {
	int (*setkey)(struct crypto_ablkcipher___24 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___24 *);
	int (*decrypt)(struct ablkcipher_request___24 *);
	int (*givencrypt)(struct skcipher_givcrypt_request *);
	int (*givdecrypt)(struct skcipher_givcrypt_request *);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct crypto_ablkcipher___24 {
	struct crypto_tfm___24 base;
};

struct blkcipher_alg___24 {
	int (*setkey)(struct crypto_tfm___24 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___24 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___24 *, struct scatterlist *, struct scatterlist *, unsigned int);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct cipher_alg___24 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___24 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___24 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___24 *, u8 *, const u8 *);
};

struct compress_alg___24 {
	int (*coa_compress)(struct crypto_tfm___24 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___24 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___24 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type *cra_type;
	union {
		struct ablkcipher_alg___24 ablkcipher;
		struct blkcipher_alg___24 blkcipher;
		struct cipher_alg___24 cipher;
		struct compress_alg___24 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___24 *);
	void (*cra_exit)(struct crypto_tfm___24 *);
	void (*cra_destroy)(struct crypto_alg___24 *);
	struct module___343 *cra_module;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct crypto_cipher___8 {
	struct crypto_tfm___24 base;
};

struct msghdr___45 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___180 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___413 *msg_iocb;
};

struct socket_wq___43 {
	wait_queue_head_t wait;
	struct fasync_struct___413 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___43;

struct socket___44 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___43 *wq;
	struct file___413 *file;
	struct sock___43 *sk;
	const struct proto_ops___43 *ops;
};

typedef int (*sk_read_actor_t___42)(read_descriptor_t *, struct sk_buff___60 *, unsigned int, size_t);

struct proto_ops___43 {
	int family;
	struct module___343 *owner;
	int (*release)(struct socket___44 *);
	int (*bind)(struct socket___44 *, struct sockaddr *, int);
	int (*connect)(struct socket___44 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___44 *, struct socket___44 *);
	int (*accept)(struct socket___44 *, struct socket___44 *, int, bool);
	int (*getname)(struct socket___44 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___413 *, struct socket___44 *, struct poll_table_struct___256 *);
	int (*ioctl)(struct socket___44 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___44 *, int);
	int (*shutdown)(struct socket___44 *, int);
	int (*setsockopt)(struct socket___44 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___44 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___44 *, struct msghdr___45 *, size_t);
	int (*recvmsg)(struct socket___44 *, struct msghdr___45 *, size_t, int);
	int (*mmap)(struct file___413 *, struct socket___44 *, struct vm_area_struct___414 *);
	ssize_t (*sendpage)(struct socket___44 *, struct page___414 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___44 *, loff_t *, struct pipe_inode_info___94 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___43 *, int);
	int (*peek_len)(struct socket___44 *);
	int (*read_sock)(struct sock___43 *, read_descriptor_t *, sk_read_actor_t___42);
	int (*sendpage_locked)(struct sock___43 *, struct page___414 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___43 *, struct msghdr___45 *, size_t);
	int (*set_rcvlowat)(struct sock___43 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct sec_path___6;

struct nf_bridge_info___58;

struct sk_buff___60 {
	union {
		struct {
			struct sk_buff___60 *next;
			struct sk_buff___60 *prev;
			union {
				struct net_device___59 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___43 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___60 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path___6 *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___58 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___58;

struct netns_frags___58 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___58 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ip_ra_chain___21;

struct fib_rules_ops___42;

struct tcp_congestion_ops___5;

struct tcp_fastopen_context___5;

struct fib_notifier_ops___42;

struct netns_ipv4___58 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___21 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___42 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___43 *fibnl;
	struct sock___43 **icmp_sk;
	struct sock___43 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___43 **tcp_sk;
	struct netns_frags___58 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops___5 *tcp_congestion_control;
	struct tcp_fastopen_context___5 *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___42 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___42 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___42 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___42;

struct dst_ops___69 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___69 *);
	struct dst_entry___42 * (*check)(struct dst_entry___42 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___42 *);
	unsigned int (*mtu)(const struct dst_entry___42 *);
	u32 * (*cow_metrics)(struct dst_entry___42 *, long unsigned int);
	void (*destroy)(struct dst_entry___42 *);
	void (*ifdown)(struct dst_entry___42 *, struct net_device___59 *, int);
	struct dst_entry___42 * (*negative_advice)(struct dst_entry___42 *);
	void (*link_failure)(struct sk_buff___60 *);
	void (*update_pmtu)(struct dst_entry___42 *, struct sock___43 *, struct sk_buff___60 *, u32);
	void (*redirect)(struct dst_entry___42 *, struct sock___43 *, struct sk_buff___60 *);
	int (*local_out)(struct net___70 *, struct sock___43 *, struct sk_buff___60 *);
	struct neighbour___42 * (*neigh_lookup)(const struct dst_entry___42 *, struct sk_buff___60 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___42 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_info___7;

struct rt6_info___7;

struct fib6_table___7;

struct netns_ipv6___69 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___58 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info___7 *fib6_null_entry;
	struct rt6_info___7 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___7 *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___69 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info___7 *ip6_prohibit_entry;
	struct rt6_info___7 *ip6_blk_hole_entry;
	struct fib6_table___7 *fib6_local_tbl;
	struct fib_rules_ops___42 *fib6_rules_ops;
	struct sock___43 **icmp_sk;
	struct sock___43 *ndisc_sk;
	struct sock___43 *tcp_sk;
	struct sock___43 *igmp_sk;
	struct sock___43 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___42 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___42 *notifier_ops;
	struct fib_notifier_ops___42 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___43 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___43 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___58 {
	struct netns_frags___58 frags;
};

struct netns_xfrm___69 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___43 *nlsk;
	struct sock___43 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___69 xfrm4_dst_ops;
	struct dst_ops___69 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___52;

struct net___70 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___278 *user_ns;
	struct ucounts___278 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___29 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___43 *rtnl;
	struct sock___43 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___59 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___58 ipv4;
	struct netns_ipv6___69 ipv6;
	struct netns_sctp___43 sctp;
	struct netns_nf___4 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___58 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___43 *nfnl;
	struct sock___43 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___69 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___43 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___52 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___381 {
	int (*prepare)(struct device___381 *);
	void (*complete)(struct device___381 *);
	int (*suspend)(struct device___381 *);
	int (*resume)(struct device___381 *);
	int (*freeze)(struct device___381 *);
	int (*thaw)(struct device___381 *);
	int (*poweroff)(struct device___381 *);
	int (*restore)(struct device___381 *);
	int (*suspend_late)(struct device___381 *);
	int (*resume_early)(struct device___381 *);
	int (*freeze_late)(struct device___381 *);
	int (*thaw_early)(struct device___381 *);
	int (*poweroff_late)(struct device___381 *);
	int (*restore_early)(struct device___381 *);
	int (*suspend_noirq)(struct device___381 *);
	int (*resume_noirq)(struct device___381 *);
	int (*freeze_noirq)(struct device___381 *);
	int (*thaw_noirq)(struct device___381 *);
	int (*poweroff_noirq)(struct device___381 *);
	int (*restore_noirq)(struct device___381 *);
	int (*runtime_suspend)(struct device___381 *);
	int (*runtime_resume)(struct device___381 *);
	int (*runtime_idle)(struct device___381 *);
};

struct dev_pm_domain___381 {
	struct dev_pm_ops___381 ops;
	void (*detach)(struct device___381 *, bool);
	int (*activate)(struct device___381 *);
	void (*sync)(struct device___381 *);
	void (*dismiss)(struct device___381 *);
};

struct bus_type___381 {
	const char *name;
	const char *dev_name;
	struct device___381 *dev_root;
	const struct attribute_group___378 **bus_groups;
	const struct attribute_group___378 **dev_groups;
	const struct attribute_group___378 **drv_groups;
	int (*match)(struct device___381 *, struct device_driver___381 *);
	int (*uevent)(struct device___381 *, struct kobj_uevent_env *);
	int (*probe)(struct device___381 *);
	int (*remove)(struct device___381 *);
	void (*shutdown)(struct device___381 *);
	int (*online)(struct device___381 *);
	int (*offline)(struct device___381 *);
	int (*suspend)(struct device___381 *, pm_message_t);
	int (*resume)(struct device___381 *);
	int (*num_vf)(struct device___381 *);
	int (*dma_configure)(struct device___381 *);
	const struct dev_pm_ops___381 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___381 {
	const char *name;
	struct bus_type___381 *bus;
	struct module___343 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___381 *);
	int (*remove)(struct device___381 *);
	void (*shutdown)(struct device___381 *);
	int (*suspend)(struct device___381 *, pm_message_t);
	int (*resume)(struct device___381 *);
	const struct attribute_group___378 **groups;
	const struct dev_pm_ops___381 *pm;
	void (*coredump)(struct device___381 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___381 {
	const char *name;
	const struct attribute_group___378 **groups;
	int (*uevent)(struct device___381 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___381 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___381 *);
	const struct dev_pm_ops___381 *pm;
};

struct class___381 {
	const char *name;
	struct module___343 *owner;
	const struct attribute_group___378 **class_groups;
	const struct attribute_group___378 **dev_groups;
	struct kobject___401 *dev_kobj;
	int (*dev_uevent)(struct device___381 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___381 *, umode_t *);
	void (*class_release)(struct class___381 *);
	void (*dev_release)(struct device___381 *);
	int (*shutdown_pre)(struct device___381 *);
	const struct kobj_ns_type_operations___42 *ns_type;
	const void * (*namespace)(struct device___381 *);
	const struct dev_pm_ops___381 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___153 {
	void * (*alloc)(struct device___381 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___381 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___381 *, struct vm_area_struct___414 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___381 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___381 *, struct page___414 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___381 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___381 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___381 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___381 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___381 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___381 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___381 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___381 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___381 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___381 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___381 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___381 *, u64);
	u64 (*get_required_mask)(struct device___381 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___301;

struct fwnode_handle___301 {
	struct fwnode_handle___301 *secondary;
	const struct fwnode_operations___301 *ops;
};

struct fwnode_reference_args___301;

struct fwnode_endpoint___301;

struct fwnode_operations___301 {
	struct fwnode_handle___301 * (*get)(struct fwnode_handle___301 *);
	void (*put)(struct fwnode_handle___301 *);
	bool (*device_is_available)(const struct fwnode_handle___301 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___301 *, const struct device___381 *);
	bool (*property_present)(const struct fwnode_handle___301 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___301 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___301 *, const char *, const char **, size_t);
	struct fwnode_handle___301 * (*get_parent)(const struct fwnode_handle___301 *);
	struct fwnode_handle___301 * (*get_next_child_node)(const struct fwnode_handle___301 *, struct fwnode_handle___301 *);
	struct fwnode_handle___301 * (*get_named_child_node)(const struct fwnode_handle___301 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___301 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___301 *);
	struct fwnode_handle___301 * (*graph_get_next_endpoint)(const struct fwnode_handle___301 *, struct fwnode_handle___301 *);
	struct fwnode_handle___301 * (*graph_get_remote_endpoint)(const struct fwnode_handle___301 *);
	struct fwnode_handle___301 * (*graph_get_port_parent)(struct fwnode_handle___301 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___301 *, struct fwnode_endpoint___301 *);
};

struct fwnode_endpoint___301 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___301 *local_fwnode;
};

struct fwnode_reference_args___301 {
	struct fwnode_handle___301 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___94;

struct pipe_buffer___94 {
	struct page___414 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___94 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___94 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___94 *, struct pipe_buffer___94 *);
	void (*release)(struct pipe_inode_info___94 *, struct pipe_buffer___94 *);
	int (*steal)(struct pipe_inode_info___94 *, struct pipe_buffer___94 *);
	union {
		bool (*get)(struct pipe_inode_info___94 *, struct pipe_buffer___94 *);
		struct {
			void (*get)(struct pipe_inode_info___94 *, struct pipe_buffer___94 *);
		} __UNIQUE_ID_rh_kabi_hide21;
		union {		};
	};
};

struct nf_bridge_info___58 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___58 = 0,
		BRNF_PROTO_8021Q___58 = 1,
		BRNF_PROTO_PPPOE___58 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___59 *physindev;
	struct net_device___59 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___58(struct sk_buff___60 **);

struct net_device_ops___58;

struct ethtool_ops___58;

struct l3mdev_ops___42;

struct ndisc_ops___24;

struct xfrmdev_ops___58;

struct tlsdev_ops___58;

struct header_ops___58;

struct in_device___3;

struct inet6_dev___24;

struct netdev_rx_queue___58;

struct mini_Qdisc___52;

struct netdev_queue___58;

struct Qdisc___52;

struct rtnl_link_ops___52;

struct dcbnl_rtnl_ops___58;

struct net_device___59 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___58 *netdev_ops;
	const struct ethtool_ops___58 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___42 *l3mdev_ops;
	const struct ndisc_ops___24 *ndisc_ops;
	const struct xfrmdev_ops___58 *xfrmdev_ops;
	const struct tlsdev_ops___58 *tlsdev_ops;
	const struct header_ops___58 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___400 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device___3 *ip_ptr;
	struct inet6_dev___24 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___58 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___52 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___58 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___52 *miniq_ingress;
	struct netdev_queue___58 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___58 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___52 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___52 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___58 = 0,
		NETREG_REGISTERED___58 = 1,
		NETREG_UNREGISTERING___58 = 2,
		NETREG_UNREGISTERED___58 = 3,
		NETREG_RELEASED___58 = 4,
		NETREG_DUMMY___58 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___58 = 0,
		RTNL_LINK_INITIALIZING___58 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___59 *);
	struct netpoll_info *npinfo;
	possible_net_t___60 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___381 dev;
	const struct attribute_group___378 *sysfs_groups[4];
	const struct attribute_group___378 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___52 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___58 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide35;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct skb_frag_struct___8 {
	struct {
		struct page___414 *p;
	} page;
	__u32 page_offset;
	__u32 size;
};

typedef struct skb_frag_struct___8 skb_frag_t___8;

struct mmpin___3 {
	struct user_struct___381 *user;
	unsigned int num_pg;
};

struct ubuf_info___3 {
	void (*callback)(struct ubuf_info___3 *, bool);
	union {
		struct {
			long unsigned int desc;
			void *ctx;
		};
		struct {
			u32 id;
			u16 len;
			u16 zerocopy: 1;
			u32 bytelen;
		};
	};
	refcount_t refcnt;
	struct mmpin___3 mmp;
};

struct skb_shared_info___8 {
	__u8 __unused;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___60 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___8 frags[16];
};

struct xfrm_state___6;

struct sec_path___6 {
	refcount_t refcnt;
	int len;
	int olen;
	struct xfrm_state___6 *xvec[6];
	struct xfrm_offload ovec[1];
};

typedef int (*key_restrict_link_func_t___382)(struct key___381 *, const struct key_type *, const union key_payload *, struct key___381 *);

struct key_restriction___381;

struct key___381 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___415 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___381 *restrict_link;
};

struct key_restriction___381 {
	key_restrict_link_func_t___382 check;
	struct key___381 *key;
	struct key_type *keytype;
};

struct cgroup_namespace___262 {
	refcount_t count;
	struct ns_common___29 ns;
	struct user_namespace___278 *user_ns;
	struct ucounts___278 *ucounts;
	struct css_set___262 *root_cset;
};

struct netlink_callback___60 {
	struct sk_buff___60 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___60 *);
	int (*dump)(struct sk_buff___60 *, struct netlink_callback___60 *);
	int (*done)(struct netlink_callback___60 *);
	void *data;
	struct module___343 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct ucounts___278 {
	struct hlist_node node;
	struct user_namespace___278 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct seq_operations___352 {
	void * (*start)(struct seq_file___352 *, loff_t *);
	void (*stop)(struct seq_file___352 *, void *);
	void * (*next)(struct seq_file___352 *, void *, loff_t *);
	int (*show)(struct seq_file___352 *, void *);
};

struct inet_frag_queue___58;

struct inet_frags___58 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___58 *, const void *);
	void (*destructor)(struct inet_frag_queue___58 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___58 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___60 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___60 *fragments_tail;
	struct sk_buff___60 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___58 *net;
	struct callback_head rcu;
};

struct ip_ra_chain___21 {
	struct ip_ra_chain___21 *next;
	struct sock___43 *sk;
	union {
		void (*destructor)(struct sock___43 *);
		struct sock___43 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___42;

struct fib_lookup_arg___42;

struct fib_rules_ops___42 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___42 *, struct flowi *, int, struct fib_lookup_arg___42 *);
	bool (*suppress)(struct fib_rule___42 *, struct fib_lookup_arg___42 *);
	int (*match)(struct fib_rule___42 *, struct flowi *, int);
	int (*configure)(struct fib_rule___42 *, struct sk_buff___60 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___42 *);
	int (*compare)(struct fib_rule___42 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___42 *, struct sk_buff___60 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___42 *);
	void (*flush_cache)(struct fib_rules_ops___42 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___343 *owner;
	struct net___70 *fro_net;
	struct callback_head rcu;
};

struct tcp_congestion_ops___5 {
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___43 *);
	void (*release)(struct sock___43 *);
	u32 (*ssthresh)(struct sock___43 *);
	void (*cong_avoid)(struct sock___43 *, u32, u32);
	void (*set_state)(struct sock___43 *, u8);
	void (*cwnd_event)(struct sock___43 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___43 *, u32);
	u32 (*undo_cwnd)(struct sock___43 *);
	void (*pkts_acked)(struct sock___43 *, const struct ack_sample *);
	u32 (*min_tso_segs)(struct sock___43 *);
	u32 (*sndbuf_expand)(struct sock___43 *);
	void (*cong_control)(struct sock___43 *, const struct rate_sample *);
	size_t (*get_info)(struct sock___43 *, u32, int *, union tcp_cc_info *);
	char name[16];
	struct module___343 *owner;
};

struct tcp_fastopen_context___5 {
	struct crypto_cipher___8 *tfm;
	__u8 key[16];
	struct callback_head rcu;
};

struct fib_notifier_ops___42 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___70 *);
	int (*fib_dump)(struct net___70 *, struct notifier_block *);
	struct module___343 *owner;
	struct callback_head rcu;
};

struct lwtunnel_state___4;

struct dst_entry___42 {
	struct net_device___59 *dev;
	struct dst_ops___69 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state___6 *xfrm;
	int (*input)(struct sk_buff___60 *);
	int (*output)(struct net___70 *, struct sock___43 *, struct sk_buff___60 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___4 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___42;

struct neigh_parms___42;

struct neigh_ops___42;

struct neighbour___42 {
	struct neighbour___42 *next;
	struct neigh_table___42 *tbl;
	struct neigh_parms___42 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___58 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___42 *, struct sk_buff___60 *);
	const struct neigh_ops___42 *ops;
	struct callback_head rcu;
	struct net_device___59 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct fib6_nh___7 {
	struct in6_addr nh_gw;
	struct net_device___59 *nh_dev;
	struct lwtunnel_state___4 *nh_lwtstate;
	unsigned int nh_flags;
	atomic_t nh_upper_bound;
	int nh_weight;
};

struct fib6_node___7;

struct fib6_info___7 {
	struct fib6_table___7 *fib6_table;
	struct fib6_info___7 *fib6_next;
	struct fib6_node___7 *fib6_node;
	struct list_head fib6_siblings;
	unsigned int fib6_nsiblings;
	atomic_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	struct rt6_info___7 **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
	long unsigned int last_probe;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 exception_bucket_flushed: 1;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 dst_host: 1;
	u8 fib6_destroying: 1;
	u8 unused: 2;
	struct fib6_nh___7 fib6_nh;
	struct callback_head rcu;
};

struct rt6_info___7 {
	struct dst_entry___42 dst;
	struct fib6_info___7 *from;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___24 *rt6i_idev;
	u32 rt6i_flags;
	struct rt6key rt6i_prefsrc;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct fib6_node___7 {
	struct fib6_node___7 *parent;
	struct fib6_node___7 *left;
	struct fib6_node___7 *right;
	struct fib6_info___7 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info___7 *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table___7 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node___7 tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

struct seg6_pernet_data {
	struct mutex lock;
	struct in6_addr *tun_src;
};

struct bpf_prog_aux___55;

struct bpf_prog___52 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___55 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

struct pernet_operations___59 {
	struct list_head list;
	int (*init)(struct net___70 *);
	void (*exit)(struct net___70 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct ethtool_ops___58 {
	int (*get_settings)(struct net_device___59 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___59 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___59 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___59 *);
	void (*get_regs)(struct net_device___59 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___59 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___59 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___59 *);
	void (*set_msglevel)(struct net_device___59 *, u32);
	int (*nway_reset)(struct net_device___59 *);
	u32 (*get_link)(struct net_device___59 *);
	int (*get_eeprom_len)(struct net_device___59 *);
	int (*get_eeprom)(struct net_device___59 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___59 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___59 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___59 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___59 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___59 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___59 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___59 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___59 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___59 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___59 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___59 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___59 *);
	void (*complete)(struct net_device___59 *);
	u32 (*get_priv_flags)(struct net_device___59 *);
	int (*set_priv_flags)(struct net_device___59 *, u32);
	int (*get_sset_count)(struct net_device___59 *, int);
	int (*get_rxnfc)(struct net_device___59 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___59 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___59 *, struct ethtool_flash *);
	int (*reset)(struct net_device___59 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___59 *);
	u32 (*get_rxfh_indir_size)(struct net_device___59 *);
	int (*get_rxfh)(struct net_device___59 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___59 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___59 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___59 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___59 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___59 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___59 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___59 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___59 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___59 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___59 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___59 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___59 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___59 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___59 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___59 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___59 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___59 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___59 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___59 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___59 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___59 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	int (*get_fecparam)(struct net_device___59 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___59 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___59 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___59 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___59 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct dcbnl_rtnl_ops___58 {
	int (*ieee_getets)(struct net_device___59 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___59 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___59 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___59 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___59 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___59 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___59 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___59 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___59 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___59 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___59 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___59 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___59 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___59 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___59 *);
	u8 (*setstate)(struct net_device___59 *, u8);
	void (*getpermhwaddr)(struct net_device___59 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___59 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___59 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___59 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___59 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___59 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___59 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___59 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___59 *, int, u8 *);
	void (*setpfccfg)(struct net_device___59 *, int, u8);
	void (*getpfccfg)(struct net_device___59 *, int, u8 *);
	u8 (*setall)(struct net_device___59 *);
	u8 (*getcap)(struct net_device___59 *, int, u8 *);
	int (*getnumtcs)(struct net_device___59 *, int, u8 *);
	int (*setnumtcs)(struct net_device___59 *, int, u8);
	u8 (*getpfcstate)(struct net_device___59 *);
	void (*setpfcstate)(struct net_device___59 *, u8);
	void (*getbcncfg)(struct net_device___59 *, int, u32 *);
	void (*setbcncfg)(struct net_device___59 *, int, u32);
	void (*getbcnrp)(struct net_device___59 *, int, u8 *);
	void (*setbcnrp)(struct net_device___59 *, int, u8);
	int (*setapp)(struct net_device___59 *, u8, u16, u8);
	int (*getapp)(struct net_device___59 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___59 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___59 *, int, u8);
	u8 (*getdcbx)(struct net_device___59 *);
	u8 (*setdcbx)(struct net_device___59 *, u8);
	int (*peer_getappinfo)(struct net_device___59 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___59 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___59 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___59 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___59 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___59 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

enum bpf_adj_room_mode {
	BPF_ADJ_ROOM_NET = 0,
};

enum bpf_hdr_start_off {
	BPF_HDR_START_MAC = 0,
	BPF_HDR_START_NET = 1,
};

struct bpf_tunnel_key {
	__u32 tunnel_id;
	union {
		__u32 remote_ipv4;
		__u32 remote_ipv6[4];
	};
	__u8 tunnel_tos;
	__u8 tunnel_ttl;
	__u16 tunnel_ext;
	__u32 tunnel_label;
};

struct bpf_xfrm_state {
	__u32 reqid;
	__u32 spi;
	__u16 family;
	__u16 ext;
	union {
		__u32 remote_ipv4;
		__u32 remote_ipv6[4];
	};
};

struct bpf_sock {
	__u32 bound_dev_if;
	__u32 family;
	__u32 type;
	__u32 protocol;
	__u32 mark;
	__u32 priority;
	__u32 src_ip4;
	__u32 src_ip6[4];
	__u32 src_port;
};

struct bpf_sock_tuple {
	union {
		struct {
			__be32 saddr;
			__be32 daddr;
			__be16 sport;
			__be16 dport;
		} ipv4;
		struct {
			__be32 saddr[4];
			__be32 daddr[4];
			__be16 sport;
			__be16 dport;
		} ipv6;
	};
};

enum sk_action {
	SK_DROP = 0,
	SK_PASS = 1,
};

struct sk_msg_md {
	union {
		void *data;
	};
	union {
		void *data_end;
	};
	__u32 family;
	__u32 remote_ip4;
	__u32 local_ip4;
	__u32 remote_ip6[4];
	__u32 local_ip6[4];
	__u32 remote_port;
	__u32 local_port;
	__u32 size;
};

struct bpf_sock_addr {
	__u32 user_family;
	__u32 user_ip4;
	__u32 user_ip6[4];
	__u32 user_port;
	__u32 family;
	__u32 type;
	__u32 protocol;
	__u32 msg_src_ip4;
	__u32 msg_src_ip6[4];
};

struct bpf_sock_ops {
	__u32 op;
	union {
		__u32 args[4];
		__u32 reply;
		__u32 replylong[4];
	};
	__u32 family;
	__u32 remote_ip4;
	__u32 local_ip4;
	__u32 remote_ip6[4];
	__u32 local_ip6[4];
	__u32 remote_port;
	__u32 local_port;
	__u32 is_fullsock;
	__u32 snd_cwnd;
	__u32 srtt_us;
	__u32 bpf_sock_ops_cb_flags;
	__u32 state;
	__u32 rtt_min;
	__u32 snd_ssthresh;
	__u32 rcv_nxt;
	__u32 snd_nxt;
	__u32 snd_una;
	__u32 mss_cache;
	__u32 ecn_flags;
	__u32 rate_delivered;
	__u32 rate_interval_us;
	__u32 packets_out;
	__u32 retrans_out;
	__u32 total_retrans;
	__u32 segs_in;
	__u32 data_segs_in;
	__u32 segs_out;
	__u32 data_segs_out;
	__u32 lost_out;
	__u32 sacked_out;
	__u32 sk_txhash;
	__u64 bytes_received;
	__u64 bytes_acked;
};

enum {
	BPF_SOCK_OPS_VOID = 0,
	BPF_SOCK_OPS_TIMEOUT_INIT = 1,
	BPF_SOCK_OPS_RWND_INIT = 2,
	BPF_SOCK_OPS_TCP_CONNECT_CB = 3,
	BPF_SOCK_OPS_ACTIVE_ESTABLISHED_CB = 4,
	BPF_SOCK_OPS_PASSIVE_ESTABLISHED_CB = 5,
	BPF_SOCK_OPS_NEEDS_ECN = 6,
	BPF_SOCK_OPS_BASE_RTT = 7,
	BPF_SOCK_OPS_RTO_CB = 8,
	BPF_SOCK_OPS_RETRANS_CB = 9,
	BPF_SOCK_OPS_STATE_CB = 10,
	BPF_SOCK_OPS_TCP_LISTEN_CB = 11,
};

enum {
	BPF_FIB_LKUP_RET_SUCCESS = 0,
	BPF_FIB_LKUP_RET_BLACKHOLE = 1,
	BPF_FIB_LKUP_RET_UNREACHABLE = 2,
	BPF_FIB_LKUP_RET_PROHIBIT = 3,
	BPF_FIB_LKUP_RET_NOT_FWDED = 4,
	BPF_FIB_LKUP_RET_FWD_DISABLED = 5,
	BPF_FIB_LKUP_RET_UNSUPP_LWT = 6,
	BPF_FIB_LKUP_RET_NO_NEIGH = 7,
	BPF_FIB_LKUP_RET_FRAG_NEEDED = 8,
};

struct bpf_fib_lookup {
	__u8 family;
	__u8 l4_protocol;
	__be16 sport;
	__be16 dport;
	__u16 tot_len;
	__u32 ifindex;
	union {
		__u8 tos;
		__be32 flowinfo;
		__u32 rt_metric;
	};
	union {
		__be32 ipv4_src;
		__u32 ipv6_src[4];
	};
	union {
		__be32 ipv4_dst;
		__u32 ipv6_dst[4];
	};
	__be16 h_vlan_proto;
	__be16 h_vlan_TCI;
	__u8 smac[6];
	__u8 dmac[6];
};

struct bpf_map___263;

struct bpf_map_ops___262 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___263 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___263 *, struct file___413 *);
	void (*map_free)(struct bpf_map___263 *);
	int (*map_get_next_key)(struct bpf_map___263 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___263 *);
	void * (*map_lookup_elem)(struct bpf_map___263 *, void *);
	int (*map_update_elem)(struct bpf_map___263 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___263 *, void *);
	int (*map_push_elem)(struct bpf_map___263 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___263 *, void *);
	int (*map_peek_elem)(struct bpf_map___263 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___263 *, struct file___413 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___263 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___263 *, void *, struct seq_file___352 *);
	int (*map_check_btf)(const struct bpf_map___263 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___263 {
	const struct bpf_map_ops___262 *ops;
	struct bpf_map___263 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___381 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___58;

struct bpf_map_dev_ops___58 {
	int (*map_get_next_key)(struct bpf_offloaded_map___58 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___58 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___58 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___58 *, void *);
};

struct bpf_offloaded_map___58 {
	struct bpf_map___263 map;
	struct net_device___59 *netdev;
	const struct bpf_map_dev_ops___58 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___52 {
	int (*test_run)(struct bpf_prog___52 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___52 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___52 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___52 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___52 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___52 *, u32 *);
};

struct bpf_prog_offload_ops___52 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___52 *);
	int (*translate)(struct bpf_prog___52 *);
	void (*destroy)(struct bpf_prog___52 *);
};

struct bpf_prog_offload___52 {
	struct bpf_prog___52 *prog;
	struct net_device___59 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___52 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___55 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___52 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___52 *ops;
	struct bpf_map___263 **used_maps;
	struct bpf_prog___52 *prog;
	struct user_struct___381 *user;
	u64 load_time;
	struct bpf_map___263 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___52 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_array___4 {
	struct bpf_map___263 map;
	u32 elem_size;
	u32 index_mask;
	enum bpf_prog_type owner_prog_type;
	bool owner_jited;
	union {
		char value[0];
		void *ptrs[0];
		void *pptrs[0];
	};
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_array_item___52 {
	struct bpf_prog___52 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___52 {
	struct callback_head rcu;
	struct bpf_prog_array_item___52 items[0];
};

struct cgroup_bpf___52 {
	struct bpf_prog_array___52 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___52 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___263;

typedef void (*kthread_work_func_t___263)(struct kthread_work___263 *);

struct kthread_worker___263;

struct kthread_work___263 {
	struct list_head node;
	kthread_work_func_t___263 func;
	struct kthread_worker___263 *worker;
	int canceling;
};

struct kthread_worker___263 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___415 *task;
	struct kthread_work___263 *current_work;
};

struct kthread_delayed_work___262 {
	struct kthread_work___263 work;
	struct timer_list timer;
};

struct psi_group___262 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___263 *poll_kworker;
	struct kthread_delayed_work___262 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___262;

struct cgroup_rstat_cpu___262;

struct cgroup___262 {
	struct cgroup_subsys_state___262 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___408 *kn;
	struct cgroup_file___262 procs_file;
	struct cgroup_file___262 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___262 *subsys[13];
	struct cgroup_root___262 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___262 *dom_cgrp;
	struct cgroup_rstat_cpu___262 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___52 bpf;
	atomic_t congestion_count;
	struct cgroup___262 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___262 psi;
	int ancestor_ids[0];
};

struct cftype___262;

struct cgroup_subsys___262 {
	struct cgroup_subsys_state___262 * (*css_alloc)(struct cgroup_subsys_state___262 *);
	int (*css_online)(struct cgroup_subsys_state___262 *);
	void (*css_offline)(struct cgroup_subsys_state___262 *);
	void (*css_released)(struct cgroup_subsys_state___262 *);
	void (*css_free)(struct cgroup_subsys_state___262 *);
	void (*css_reset)(struct cgroup_subsys_state___262 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___262 *, int);
	int (*css_extra_stat_show)(struct seq_file___352 *, struct cgroup_subsys_state___262 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___415 *);
	void (*cancel_fork)(struct task_struct___415 *);
	void (*fork)(struct task_struct___415 *);
	void (*exit)(struct task_struct___415 *);
	void (*free)(struct task_struct___415 *);
	void (*bind)(struct cgroup_subsys_state___262 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___262 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___262 *dfl_cftypes;
	struct cftype___262 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___262 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___262 *updated_children;
	struct cgroup___262 *updated_next;
};

struct cgroup_root___262 {
	struct kernfs_root___407 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___262 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___262 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___262 *ss;
	struct list_head node;
	struct kernfs_ops___407 *kf_ops;
	int (*open)(struct kernfs_open_file___407 *);
	void (*release)(struct kernfs_open_file___407 *);
	u64 (*read_u64)(struct cgroup_subsys_state___262 *, struct cftype___262 *);
	s64 (*read_s64)(struct cgroup_subsys_state___262 *, struct cftype___262 *);
	int (*seq_show)(struct seq_file___352 *, void *);
	void * (*seq_start)(struct seq_file___352 *, loff_t *);
	void * (*seq_next)(struct seq_file___352 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___352 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___262 *, struct cftype___262 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___262 *, struct cftype___262 *, s64);
	ssize_t (*write)(struct kernfs_open_file___407 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___407 *, struct poll_table_struct___256 *);
};

struct xdp_rxq_info___58 {
	struct net_device___59 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_buff___4 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	long unsigned int handle;
	struct xdp_rxq_info___58 *rxq;
};

struct xdp_frame___58 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___59 *dev_rx;
};

struct header_ops___58 {
	int (*create)(struct sk_buff___60 *, struct net_device___59 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___60 *, unsigned char *);
	int (*cache)(const struct neighbour___42 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___59 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___58 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___58 *, int);
	int poll_owner;
	struct net_device___59 *dev;
	struct sk_buff___60 *gro_list;
	struct sk_buff___60 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct xdp_umem___3 {
	struct xsk_queue *fq;
	struct xsk_queue *cq;
	struct xdp_umem_page *pages;
	u64 chunk_mask;
	u64 size;
	u32 headroom;
	u32 chunk_size_nohr;
	struct user_struct___381 *user;
	struct pid___236 *pid;
	long unsigned int address;
	refcount_t users;
	struct work_struct work;
	struct page___414 **pgs;
	u32 npgs;
	struct net_device___59 *dev;
	struct xdp_umem_fq_reuse *fq_reuse;
	u16 queue_id;
	bool zc;
	spinlock_t xsk_list_lock;
	struct list_head xsk_list;
};

struct netdev_queue___58 {
	struct net_device___59 *dev;
	struct Qdisc___52 *qdisc;
	struct Qdisc___52 *qdisc_sleeping;
	struct kobject___401 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___59 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem___3 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___52 {
	struct sk_buff___60 *head;
	struct sk_buff___60 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___52;

struct Qdisc___52 {
	int (*enqueue)(struct sk_buff___60 *, struct Qdisc___52 *, struct sk_buff___60 **);
	struct sk_buff___60 * (*dequeue)(struct Qdisc___52 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___52 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___58 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___58 gso_skb;
	struct qdisc_skb_head___52 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___52 *next_sched;
	struct sk_buff_head___58 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___58 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___401 kobj;
	struct net_device___59 *dev;
	long: 64;
	struct xdp_rxq_info___58 xdp_rxq;
	union {
		struct xdp_umem___3 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___58)(struct net_device___59 *, struct sk_buff___60 *, struct net_device___59 *);

struct netdev_bpf___58 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___52 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___52 *prog;
			const struct bpf_prog_offload_ops___52 *ops;
		} verifier;
		struct {
			struct bpf_prog___52 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___58 *offmap;
		};
		struct {
			struct xdp_umem___3 *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___58 {
	int (*xdo_dev_state_add)(struct xfrm_state___6 *);
	void (*xdo_dev_state_delete)(struct xfrm_state___6 *);
	void (*xdo_dev_state_free)(struct xfrm_state___6 *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___60 *, struct xfrm_state___6 *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state___6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct xfrm_state_offload___6 {
	struct net_device___59 *dev;
	long unsigned int offload_handle;
	unsigned int num_exthdrs;
	u8 flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct xfrm_replay___6;

struct xfrm_type___6;

struct xfrm_mode___6;

struct xfrm_type_offload___6;

struct xfrm_state___6 {
	possible_net_t___60 xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	refcount_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
		u32 output_mark;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	const char *geniv;
	struct xfrm_encap_tmpl *encap;
	xfrm_address_t *coaddr;
	struct xfrm_state___6 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	const struct xfrm_replay___6 *repl;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct tasklet_hrtimer mtimer;
	struct xfrm_state_offload___6 xso;
	long int saved_tmo;
	long unsigned int lastused;
	struct page_frag___414 xfrag;
	const struct xfrm_type___6 *type;
	struct xfrm_mode___6 *inner_mode;
	struct xfrm_mode___6 *inner_mode_iaf;
	struct xfrm_mode___6 *outer_mode;
	const struct xfrm_type_offload___6 *type_offload;
	struct xfrm_sec_ctx___2 *security;
	void *data;
	u32 output_mark_mask;
	u32 if_id;
};

struct tlsdev_ops___58 {
	int (*tls_dev_add)(struct net_device___59 *, struct sock___43 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___59 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___59 *, struct sock___43 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___58 {
	int (*ndo_init)(struct net_device___59 *);
	void (*ndo_uninit)(struct net_device___59 *);
	int (*ndo_open)(struct net_device___59 *);
	int (*ndo_stop)(struct net_device___59 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___60 *, struct net_device___59 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___60 *, struct net_device___59 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___59 *, struct sk_buff___60 *, struct net_device___59 *, select_queue_fallback_t___58);
	void (*ndo_change_rx_flags)(struct net_device___59 *, int);
	void (*ndo_set_rx_mode)(struct net_device___59 *);
	int (*ndo_set_mac_address)(struct net_device___59 *, void *);
	int (*ndo_validate_addr)(struct net_device___59 *);
	int (*ndo_do_ioctl)(struct net_device___59 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___59 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___59 *, int);
	int (*ndo_neigh_setup)(struct net_device___59 *, struct neigh_parms___42 *);
	void (*ndo_tx_timeout)(struct net_device___59 *);
	void (*ndo_get_stats64)(struct net_device___59 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___59 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___59 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___59 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___59 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___59 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___59 *);
	int (*ndo_netpoll_setup)(struct net_device___59 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___59 *);
	int (*ndo_set_vf_mac)(struct net_device___59 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___59 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___59 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___59 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___59 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___59 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___59 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___59 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___59 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___59 *, int, struct sk_buff___60 *);
	int (*ndo_set_vf_guid)(struct net_device___59 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___59 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___59 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___59 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___59 *, const struct sk_buff___60 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___59 *, struct net_device___59 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___59 *, struct net_device___59 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___59 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___59 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___59 *, struct neighbour___42 *);
	void (*ndo_neigh_destroy)(struct net_device___59 *, struct neighbour___42 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___59 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___59 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___59 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___60 *, struct netlink_callback___60 *, struct net_device___59 *, struct net_device___59 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___59 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___59 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___60 *, u32, u32, struct net_device___59 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___59 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___59 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___59 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___59 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___59 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___59 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___59 *, struct net_device___59 *);
	void (*ndo_dfwd_del_station)(struct net_device___59 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___59 *);
	int (*ndo_set_tx_maxrate)(struct net_device___59 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___59 *);
	int (*ndo_change_proto_down)(struct net_device___59 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___59 *, struct sk_buff___60 *);
	void (*ndo_set_rx_headroom)(struct net_device___59 *, int);
	int (*ndo_bpf)(struct net_device___59 *, struct netdev_bpf___58 *);
	int (*ndo_xdp_xmit)(struct net_device___59 *, int, struct xdp_frame___58 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___59 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___59 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___42 {
	possible_net_t___60 net;
	struct net_device___59 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___42 *);
	void (*neigh_cleanup)(struct neighbour___42 *);
	struct neigh_table___42 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___42 {
	u32 (*l3mdev_fib_table)(const struct net_device___59 *);
	struct sk_buff___60 * (*l3mdev_l3_rcv)(struct net_device___59 *, struct sk_buff___60 *, u16);
	struct sk_buff___60 * (*l3mdev_l3_out)(struct net_device___59 *, struct sock___43 *, struct sk_buff___60 *, u16);
	struct dst_entry___42 * (*l3mdev_link_scope_lookup)(const struct net_device___59 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct ndisc_ops___24 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___59 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___59 *, struct neighbour___42 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___59 *, u8, struct neighbour___42 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___59 *, struct sk_buff___60 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___70 *, struct net_device___59 *, const struct prefix_info *, struct inet6_dev___24 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct in_ifaddr___3;

struct in_device___3 {
	struct net_device___59 *dev;
	refcount_t refcnt;
	int dead;
	struct in_ifaddr___3 *ifa_list;
	struct ip_mc_list *mc_list;
	struct ip_mc_list **mc_hash;
	int mc_count;
	spinlock_t mc_tomb_lock;
	struct ip_mc_list *mc_tomb;
	long unsigned int mr_v1_seen;
	long unsigned int mr_v2_seen;
	long unsigned int mr_maxdelay;
	long unsigned int mr_qi;
	long unsigned int mr_qri;
	unsigned char mr_qrv;
	unsigned char mr_gq_running;
	unsigned char mr_ifc_count;
	struct timer_list mr_gq_timer;
	struct timer_list mr_ifc_timer;
	struct neigh_parms___42 *arp_parms;
	struct ipv4_devconf cnf;
	struct callback_head callback_head;
};

struct ifmcaddr6___24;

struct ifacaddr6___7;

struct inet6_dev___24 {
	struct net_device___59 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___24 *mc_list;
	struct ifmcaddr6___24 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___7 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	u8 rndid[8];
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___42 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
};

struct tcf_proto___52;

struct mini_Qdisc___52 {
	struct tcf_proto___52 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___52 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___59 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___70 *, struct net_device___59 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___59 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___59 *, struct list_head *);
	size_t (*get_size)(const struct net_device___59 *);
	int (*fill_info)(struct sk_buff___60 *, const struct net_device___59 *);
	size_t (*get_xstats_size)(const struct net_device___59 *);
	int (*fill_xstats)(struct sk_buff___60 *, const struct net_device___59 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___59 *, struct net_device___59 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___59 *, const struct net_device___59 *);
	int (*fill_slave_info)(struct sk_buff___60 *, const struct net_device___59 *, const struct net_device___59 *);
	struct net___70 * (*get_link_net)(const struct net_device___59 *);
	size_t (*get_linkxstats_size)(const struct net_device___59 *, int);
	int (*fill_linkxstats)(struct sk_buff___60 *, const struct net_device___59 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct offload_callbacks___5 {
	struct sk_buff___60 * (*gso_segment)(struct sk_buff___60 *, netdev_features_t);
	struct sk_buff___60 ** (*gro_receive)(struct sk_buff___60 **, struct sk_buff___60 *);
	int (*gro_complete)(struct sk_buff___60 *, int);
};

struct softnet_data___58 {
	struct list_head poll_list;
	struct sk_buff_head___58 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___58 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___52 *output_queue;
	struct Qdisc___52 **output_queue_tailp;
	struct sk_buff___60 *completion_queue;
	struct sk_buff_head___58 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___58 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___58 input_pkt_queue;
	struct napi_struct___58 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bdi_writeback_congested___207 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___207 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___207 {
	struct bio___207 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___209 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___209 bip_inline_vecs[0];
};

struct bio_set___207 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___207 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___150 {
	struct mem_cgroup___150 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___150 {
	struct lruvec___414 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___150 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___150 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

enum rt_scope_t {
	RT_SCOPE_UNIVERSE = 0,
	RT_SCOPE_SITE = 200,
	RT_SCOPE_LINK = 253,
	RT_SCOPE_HOST = 254,
	RT_SCOPE_NOWHERE = 255,
};

enum rt_class_t {
	RT_TABLE_UNSPEC = 0,
	RT_TABLE_COMPAT = 252,
	RT_TABLE_DEFAULT = 253,
	RT_TABLE_MAIN = 254,
	RT_TABLE_LOCAL = 255,
	RT_TABLE_MAX = 4294967295,
};

struct gnet_dump___52 {
	spinlock_t *lock;
	struct sk_buff___60 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___52;

struct Qdisc_ops___52 {
	struct Qdisc_ops___52 *next;
	const struct Qdisc_class_ops___52 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___60 *, struct Qdisc___52 *, struct sk_buff___60 **);
	struct sk_buff___60 * (*dequeue)(struct Qdisc___52 *);
	struct sk_buff___60 * (*peek)(struct Qdisc___52 *);
	int (*init)(struct Qdisc___52 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___52 *);
	void (*destroy)(struct Qdisc___52 *);
	int (*change)(struct Qdisc___52 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___52 *);
	int (*change_tx_queue_len)(struct Qdisc___52 *, unsigned int);
	int (*dump)(struct Qdisc___52 *, struct sk_buff___60 *);
	int (*dump_stats)(struct Qdisc___52 *, struct gnet_dump___52 *);
	void (*ingress_block_set)(struct Qdisc___52 *, u32);
	void (*egress_block_set)(struct Qdisc___52 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___52 *);
	u32 (*egress_block_get)(struct Qdisc___52 *);
	struct module___343 *owner;
};

struct tcf_block___52;

struct Qdisc_class_ops___52 {
	unsigned int flags;
	struct netdev_queue___58 * (*select_queue)(struct Qdisc___52 *, struct tcmsg *);
	int (*graft)(struct Qdisc___52 *, long unsigned int, struct Qdisc___52 *, struct Qdisc___52 **, struct netlink_ext_ack *);
	struct Qdisc___52 * (*leaf)(struct Qdisc___52 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___52 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___52 *, u32);
	int (*change)(struct Qdisc___52 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___52 *, long unsigned int);
	void (*walk)(struct Qdisc___52 *, struct qdisc_walker *);
	struct tcf_block___52 * (*tcf_block)(struct Qdisc___52 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___52 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___52 *, long unsigned int);
	int (*dump)(struct Qdisc___52 *, long unsigned int, struct sk_buff___60 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___52 *, long unsigned int, struct gnet_dump___52 *);
};

struct tcf_chain___52;

struct tcf_block___52 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___70 *net;
	struct Qdisc___52 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___52 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___52;

struct tcf_proto_ops___52;

struct tcf_proto___52 {
	struct tcf_proto___52 *next;
	void *root;
	int (*classify)(struct sk_buff___60 *, const struct tcf_proto___52 *, struct tcf_result___52 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___52 *ops;
	struct tcf_chain___52 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___52 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___52 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___52 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___60 *, const struct tcf_proto___52 *, struct tcf_result___52 *);
	int (*init)(struct tcf_proto___52 *);
	void (*destroy)(struct tcf_proto___52 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___52 *, u32);
	void (*put)(struct tcf_proto___52 *, void *);
	int (*change)(struct net___70 *, struct sk_buff___60 *, struct tcf_proto___52 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___52 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___52 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___52 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___70 *, struct tcf_chain___52 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___70 *, struct tcf_proto___52 *, void *, struct sk_buff___60 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___60 *, struct net___70 *, void *);
	struct module___343 *owner;
	int flags;
};

struct tcf_chain___52 {
	struct mutex filter_chain_lock;
	struct tcf_proto___52 *filter_chain;
	struct list_head list;
	struct tcf_block___52 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___52 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___42 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___52 *prog;
};

struct bpf_redirect_info___52 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___263 *map;
	struct bpf_map___263 *map_to_flush;
	u32 kern_flags;
};

typedef int (*bpf_aux_classic_check_t)(struct sock_filter *, unsigned int);

struct bpf_sock_addr_kern___2 {
	struct sock___43 *sk;
	struct sockaddr *uaddr;
	u64 tmp_reg;
	void *t_ctx;
};

struct bpf_sock_ops_kern___2 {
	struct sock___43 *sk;
	u32 op;
	union {
		u32 args[4];
		u32 reply;
		u32 replylong[4];
	};
	u32 is_fullsock;
	u64 temp;
};

struct pneigh_entry___42;

struct neigh_hash_table___42;

struct neigh_table___42 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___59 *, __u32 *);
	bool (*key_eq)(const struct neighbour___42 *, const void *);
	int (*constructor)(struct neighbour___42 *);
	int (*pconstructor)(struct pneigh_entry___42 *);
	void (*pdestructor)(struct pneigh_entry___42 *);
	void (*proxy_redo)(struct sk_buff___60 *);
	char *id;
	struct neigh_parms___42 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___58 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___42 *nht;
	struct pneigh_entry___42 **phash_buckets;
};

struct neigh_ops___42 {
	int family;
	void (*solicit)(struct neighbour___42 *, struct sk_buff___60 *);
	void (*error_report)(struct neighbour___42 *, struct sk_buff___60 *);
	int (*output)(struct neighbour___42 *, struct sk_buff___60 *);
	int (*connected_output)(struct neighbour___42 *, struct sk_buff___60 *);
};

struct pneigh_entry___42 {
	struct pneigh_entry___42 *next;
	possible_net_t___60 net;
	struct net_device___59 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___42 {
	struct neighbour___42 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___4 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___70 *, struct sock___43 *, struct sk_buff___60 *);
	int (*orig_input)(struct sk_buff___60 *);
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	__u8 data[0];
};

struct fib_rule___42 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___42 *ctarget;
	struct net___70 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___42 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___42 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___28;

struct timewait_sock_ops___26;

struct proto___42 {
	void (*close)(struct sock___43 *, long int);
	int (*pre_connect)(struct sock___43 *, struct sockaddr *, int);
	int (*connect)(struct sock___43 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___43 *, int);
	struct sock___43 * (*accept)(struct sock___43 *, int, int *, bool);
	int (*ioctl)(struct sock___43 *, int, long unsigned int);
	int (*init)(struct sock___43 *);
	void (*destroy)(struct sock___43 *);
	void (*shutdown)(struct sock___43 *, int);
	int (*setsockopt)(struct sock___43 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___43 *, int, int, char *, int *);
	void (*keepalive)(struct sock___43 *, int);
	int (*sendmsg)(struct sock___43 *, struct msghdr___45 *, size_t);
	int (*recvmsg)(struct sock___43 *, struct msghdr___45 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___43 *, struct page___414 *, int, size_t, int);
	int (*bind)(struct sock___43 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___43 *, struct sk_buff___60 *);
	void (*release_cb)(struct sock___43 *);
	int (*hash)(struct sock___43 *);
	void (*unhash)(struct sock___43 *);
	void (*rehash)(struct sock___43 *);
	int (*get_port)(struct sock___43 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___43 *);
	bool (*stream_memory_read)(const struct sock___43 *);
	void (*enter_memory_pressure)(struct sock___43 *);
	void (*leave_memory_pressure)(struct sock___43 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___28 *rsk_prot;
	struct timewait_sock_ops___26 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___343 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___43 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct xfrm_policy_queue___6 {
	struct sk_buff_head___58 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___6 {
	possible_net_t___60 xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	refcount_t refcnt;
	struct timer_list timer;
	atomic_t genid;
	u32 priority;
	u32 index;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___6 polq;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx___2 *security;
	struct xfrm_tmpl xfrm_vec[6];
	struct callback_head rcu;
	u32 if_id;
};

struct sock_reuseport___3 {
	struct callback_head rcu;
	u16 max_socks;
	u16 num_socks;
	unsigned int reuseport_id;
	bool bind_inany;
	struct bpf_prog___52 *prog;
	struct sock___43 *socks[0];
};

struct request_sock___29;

struct request_sock_ops___28 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___43 *, struct request_sock___29 *);
	void (*send_ack)(const struct sock___43 *, struct sk_buff___60 *, struct request_sock___29 *);
	void (*send_reset)(const struct sock___43 *, struct sk_buff___60 *);
	void (*destructor)(struct request_sock___29 *);
	void (*syn_ack_timeout)(const struct request_sock___29 *);
};

struct timewait_sock_ops___26 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___43 *, struct sock___43 *, void *);
	void (*twsk_destructor)(struct sock___43 *);
};

struct request_sock___29 {
	struct sock_common___42 __req_common;
	struct request_sock___29 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___28 *rsk_ops;
	struct sock___43 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct fastopen_queue___3 {
	struct request_sock___29 *rskq_rst_head;
	struct request_sock___29 *rskq_rst_tail;
	spinlock_t lock;
	int qlen;
	int max_qlen;
	struct tcp_fastopen_context___5 *ctx;
};

struct request_sock_queue___3 {
	spinlock_t rskq_lock;
	u8 rskq_defer_accept;
	u32 synflood_warned;
	atomic_t qlen;
	atomic_t young;
	struct request_sock___29 *rskq_accept_head;
	struct request_sock___29 *rskq_accept_tail;
	struct fastopen_queue___3 fastopenq;
};

struct inet_cork___6 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___42 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
	__u16 gso_size;
	u64 transmit_time;
};

struct inet_cork_full___6 {
	struct inet_cork___6 base;
	struct flowi fl;
};

struct ipv6_pinfo___6;

struct inet_sock___6 {
	struct sock___43 sk;
	struct ipv6_pinfo___6 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	__be16 inet_sport;
	__u16 inet_id;
	struct ip_options_rcu *inet_opt;
	int rx_dst_ifindex;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 bind_address_no_port: 1;
	__u8 defer_connect: 1;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___6 cork;
};

struct ipv6_fl_socklist___5;

struct ipv6_pinfo___6 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
			__u16 recvfragsize: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 repflow: 1;
	__u16 pmtudisc: 3;
	__u16 padding: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u16 autoflowlabel: 1;
	__u16 autoflowlabel_set: 1;
	__u8 min_hopcount;
	__u8 tclass;
	__be32 rcv_flowinfo;
	__u32 dst_cookie;
	__u32 rx_dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___5 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___60 *pktoptions;
	struct sk_buff___60 *rxpmtu;
	struct inet6_cork cork;
};

struct inet_connection_sock_af_ops___3 {
	int (*queue_xmit)(struct sock___43 *, struct sk_buff___60 *, struct flowi *);
	void (*send_check)(struct sock___43 *, struct sk_buff___60 *);
	int (*rebuild_header)(struct sock___43 *);
	void (*sk_rx_dst_set)(struct sock___43 *, const struct sk_buff___60 *);
	int (*conn_request)(struct sock___43 *, struct sk_buff___60 *);
	struct sock___43 * (*syn_recv_sock)(const struct sock___43 *, struct sk_buff___60 *, struct request_sock___29 *, struct dst_entry___42 *, struct request_sock___29 *, bool *);
	u16 net_header_len;
	u16 net_frag_header_len;
	u16 sockaddr_len;
	int (*setsockopt)(struct sock___43 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___43 *, int, int, char *, int *);
	void (*addr2sockaddr)(struct sock___43 *, struct sockaddr *);
	void (*mtu_reduced)(struct sock___43 *);
};

struct inet_bind_bucket___3;

struct tcp_ulp_ops___3;

struct inet_connection_sock___3 {
	struct inet_sock___6 icsk_inet;
	struct request_sock_queue___3 icsk_accept_queue;
	struct inet_bind_bucket___3 *icsk_bind_hash;
	long unsigned int icsk_timeout;
	struct timer_list icsk_retransmit_timer;
	struct timer_list icsk_delack_timer;
	__u32 icsk_rto;
	__u32 icsk_pmtu_cookie;
	const struct tcp_congestion_ops___5 *icsk_ca_ops;
	const struct inet_connection_sock_af_ops___3 *icsk_af_ops;
	const struct tcp_ulp_ops___3 *icsk_ulp_ops;
	void *icsk_ulp_data;
	void (*icsk_clean_acked)(struct sock___43 *, u32);
	struct hlist_node icsk_listen_portaddr_node;
	unsigned int (*icsk_sync_mss)(struct sock___43 *, u32);
	__u8 icsk_ca_state: 6;
	__u8 icsk_ca_setsockopt: 1;
	__u8 icsk_ca_dst_locked: 1;
	__u8 icsk_retransmits;
	__u8 icsk_pending;
	__u8 icsk_backoff;
	__u8 icsk_syn_retries;
	__u8 icsk_probes_out;
	__u16 icsk_ext_hdr_len;
	struct {
		__u8 pending;
		__u8 quick;
		__u8 pingpong;
		__u8 blocked;
		__u32 ato;
		long unsigned int timeout;
		__u32 lrcvtime;
		__u16 last_seg_size;
		__u16 rcv_mss;
	} icsk_ack;
	struct {
		int enabled;
		int search_high;
		int search_low;
		int probe_size;
		u32 probe_timestamp;
	} icsk_mtup;
	u32 icsk_user_timeout;
	u64 icsk_ca_priv[11];
};

struct inet_bind_bucket___3 {
	possible_net_t___60 ib_net;
	short unsigned int port;
	signed char fastreuse;
	signed char fastreuseport;
	kuid_t fastuid;
	struct in6_addr fast_v6_rcv_saddr;
	__be32 fast_rcv_saddr;
	short unsigned int fast_sk_family;
	bool fast_ipv6_only;
	struct hlist_node node;
	struct hlist_head owners;
};

struct tcp_ulp_ops___3 {
	struct list_head list;
	int (*init)(struct sock___43 *);
	void (*release)(struct sock___43 *);
	char name[16];
	struct module___343 *owner;
};

struct tcp_sock_af_ops___3;

struct tcp_fastopen_request___3;

struct tcp_sock___3 {
	struct inet_connection_sock___3 inet_conn;
	u16 tcp_header_len;
	u16 gso_segs;
	__be32 pred_flags;
	u64 bytes_received;
	u32 segs_in;
	u32 data_segs_in;
	u32 rcv_nxt;
	u32 copied_seq;
	u32 rcv_wup;
	u32 snd_nxt;
	u32 segs_out;
	u32 data_segs_out;
	u64 bytes_acked;
	u32 snd_una;
	u32 snd_sml;
	u32 rcv_tstamp;
	u32 lsndtime;
	u32 last_oow_ack_time;
	u32 compressed_ack_rcv_nxt;
	u32 tsoffset;
	struct list_head tsq_node;
	struct list_head tsorted_sent_queue;
	u32 snd_wl1;
	u32 snd_wnd;
	u32 max_window;
	u32 mss_cache;
	u32 window_clamp;
	u32 rcv_ssthresh;
	struct tcp_rack rack;
	u16 advmss;
	u8 compressed_ack;
	u32 chrono_start;
	u32 chrono_stat[3];
	u8 chrono_type: 2;
	u8 rate_app_limited: 1;
	u8 fastopen_connect: 1;
	u8 fastopen_no_cookie: 1;
	u8 is_sack_reneg: 1;
	u8 unused: 2;
	u8 nonagle: 4;
	u8 thin_lto: 1;
	u8 recvmsg_inq: 1;
	u8 repair: 1;
	u8 frto: 1;
	u8 repair_queue;
	u8 syn_data: 1;
	u8 syn_fastopen: 1;
	u8 syn_fastopen_exp: 1;
	u8 syn_fastopen_ch: 1;
	u8 syn_data_acked: 1;
	u8 save_syn: 1;
	u8 is_cwnd_limited: 1;
	u8 syn_smc: 1;
	u32 tlp_high_seq;
	u64 tcp_mstamp;
	u32 srtt_us;
	u32 mdev_us;
	u32 mdev_max_us;
	u32 rttvar_us;
	u32 rtt_seq;
	struct minmax rtt_min;
	u32 packets_out;
	u32 retrans_out;
	u32 max_packets_out;
	u32 max_packets_seq;
	u16 urg_data;
	u8 ecn_flags;
	u8 keepalive_probes;
	u32 reordering;
	u32 snd_up;
	struct tcp_options_received rx_opt;
	u32 snd_ssthresh;
	u32 snd_cwnd;
	u32 snd_cwnd_cnt;
	u32 snd_cwnd_clamp;
	u32 snd_cwnd_used;
	u32 snd_cwnd_stamp;
	u32 prior_cwnd;
	u32 prr_delivered;
	u32 prr_out;
	u32 delivered;
	u32 delivered_ce;
	u32 lost;
	u32 app_limited;
	u64 first_tx_mstamp;
	u64 delivered_mstamp;
	u32 rate_delivered;
	u32 rate_interval_us;
	u32 rcv_wnd;
	u32 write_seq;
	u32 notsent_lowat;
	u32 pushed_seq;
	u32 lost_out;
	u32 sacked_out;
	struct hrtimer pacing_timer;
	struct hrtimer compressed_ack_timer;
	struct sk_buff___60 *lost_skb_hint;
	struct sk_buff___60 *retransmit_skb_hint;
	struct rb_root out_of_order_queue;
	struct sk_buff___60 *ooo_last_skb;
	struct tcp_sack_block duplicate_sack[1];
	struct tcp_sack_block selective_acks[4];
	struct tcp_sack_block recv_sack_cache[4];
	struct sk_buff___60 *highest_sack;
	int lost_cnt_hint;
	u32 prior_ssthresh;
	u32 high_seq;
	u32 retrans_stamp;
	u32 undo_marker;
	int undo_retrans;
	u32 total_retrans;
	u32 urg_seq;
	unsigned int keepalive_time;
	unsigned int keepalive_intvl;
	int linger2;
	u8 bpf_sock_ops_cb_flags;
	struct {
		u32 rtt_us;
		u32 seq;
		u64 time;
	} rcv_rtt_est;
	struct {
		u32 space;
		u32 seq;
		u64 time;
	} rcvq_space;
	struct {
		u32 probe_seq_start;
		u32 probe_seq_end;
	} mtu_probe;
	u32 mtu_info;
	const struct tcp_sock_af_ops___3 *af_specific;
	struct tcp_md5sig_info *md5sig_info;
	struct tcp_fastopen_request___3 *fastopen_req;
	struct request_sock___29 *fastopen_rsk;
	u32 *saved_syn;
};

struct tcp_sock_af_ops___3 {
	struct tcp_md5sig_key * (*md5_lookup)(const struct sock___43 *, const struct sock___43 *);
	int (*calc_md5_hash)(char *, const struct tcp_md5sig_key *, const struct sock___43 *, const struct sk_buff___60 *);
	int (*md5_parse)(struct sock___43 *, int, char *, int);
};

struct tcp_fastopen_request___3 {
	struct tcp_fastopen_cookie cookie;
	struct msghdr___45 *data;
	size_t size;
	int copied;
};

struct ip6_flowlabel___5;

struct ipv6_fl_socklist___5 {
	struct ipv6_fl_socklist___5 *next;
	struct ip6_flowlabel___5 *fl;
	struct callback_head rcu;
};

struct ifmcaddr6___24 {
	struct in6_addr mca_addr;
	struct inet6_dev___24 *idev;
	struct ifmcaddr6___24 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___7 {
	struct in6_addr aca_addr;
	struct fib6_info___7 *aca_rt;
	struct ifacaddr6___7 *aca_next;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct ip6_ra_chain___24 {
	struct ip6_ra_chain___24 *next;
	struct sock___43 *sk;
	int sel;
	void (*destructor)(struct sock___43 *);
};

struct ip6_flowlabel___5 {
	struct ip6_flowlabel___5 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___236 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___70 *fl_net;
};

struct rtable___4;

struct fib_nh_exception {
	struct fib_nh_exception *fnhe_next;
	int fnhe_genid;
	__be32 fnhe_daddr;
	u32 fnhe_pmtu;
	bool fnhe_mtu_locked;
	__be32 fnhe_gw;
	long unsigned int fnhe_expires;
	struct rtable___4 *fnhe_rth_input;
	struct rtable___4 *fnhe_rth_output;
	long unsigned int fnhe_stamp;
	struct callback_head rcu;
};

struct rtable___4 {
	struct dst_entry___42 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	__be32 rt_gateway;
	u32 rt_mtu_locked: 1;
	u32 rt_pmtu: 31;
	struct list_head rt_uncached;
	struct uncached_list *rt_uncached_list;
};

struct fnhe_hash_bucket {
	struct fib_nh_exception *chain;
};

struct fib_info;

struct fib_nh {
	struct net_device___59 *nh_dev;
	struct hlist_node nh_hash;
	struct fib_info *nh_parent;
	unsigned int nh_flags;
	unsigned char nh_scope;
	int nh_weight;
	atomic_t nh_upper_bound;
	__u32 nh_tclassid;
	int nh_oif;
	__be32 nh_gw;
	__be32 nh_saddr;
	int nh_saddr_genid;
	struct rtable___4 **nh_pcpu_rth_output;
	struct rtable___4 *nh_rth_input;
	struct fnhe_hash_bucket *nh_exceptions;
	struct lwtunnel_state___4 *nh_lwtstate;
};

struct fib_info {
	struct hlist_node fib_hash;
	struct hlist_node fib_lhash;
	struct net___70 *fib_net;
	int fib_treeref;
	refcount_t fib_clntref;
	unsigned int fib_flags;
	unsigned char fib_dead;
	unsigned char fib_protocol;
	unsigned char fib_scope;
	unsigned char fib_type;
	__be32 fib_prefsrc;
	u32 fib_tb_id;
	u32 fib_priority;
	struct dst_metrics *fib_metrics;
	int fib_nhs;
	struct callback_head rcu;
	struct fib_nh fib_nh[0];
};

struct fib_result {
	__be32 prefix;
	unsigned char prefixlen;
	unsigned char nh_sel;
	unsigned char type;
	unsigned char scope;
	u32 tclassid;
	struct fib_info *fi;
	struct fib_table *table;
	struct hlist_head *fa_head;
};

struct net_protocol___4 {
	int (*early_demux)(struct sk_buff___60 *);
	int (*early_demux_handler)(struct sk_buff___60 *);
	int (*handler)(struct sk_buff___60 *);
	void (*err_handler)(struct sk_buff___60 *, u32);
	unsigned int no_policy: 1;
	unsigned int netns_ok: 1;
	unsigned int icmp_strict_tag_validation: 1;
};

struct inet6_protocol___4 {
	void (*early_demux)(struct sk_buff___60 *);
	void (*early_demux_handler)(struct sk_buff___60 *);
	int (*handler)(struct sk_buff___60 *);
	void (*err_handler)(struct sk_buff___60 *, struct inet6_skb_parm *, u8, u8, int, __be32);
	unsigned int flags;
};

struct net_offload___4 {
	struct offload_callbacks___5 callbacks;
	unsigned int flags;
};

struct tcp_skb_cb {
	__u32 seq;
	__u32 end_seq;
	union {
		__u32 tcp_tw_isn;
		struct {
			u16 tcp_gso_segs;
			u16 tcp_gso_size;
		};
	};
	__u8 tcp_flags;
	__u8 sacked;
	__u8 ip_dsfield;
	__u8 txstamp_ack: 1;
	__u8 eor: 1;
	__u8 has_rxtstamp: 1;
	__u8 unused: 5;
	__u32 ack_seq;
	union {
		struct {
			__u32 in_flight: 30;
			__u32 is_app_limited: 1;
			__u32 unused: 1;
			__u32 delivered;
			u64 first_tx_mstamp;
			u64 delivered_mstamp;
		} tx;
		union {
			struct inet_skb_parm h4;
			struct inet6_skb_parm h6;
		} header;
		struct {
			__u32 flags;
			struct sock___43 *sk_redir;
			void *data_end;
		} bpf;
	};
};

struct sk_msg_sg {
	u32 start;
	u32 curr;
	u32 end;
	u32 size;
	u32 copybreak;
	bool copy[16];
	struct scatterlist data[17];
};

struct sk_msg {
	struct sk_msg_sg sg;
	void *data;
	void *data_end;
	u32 apply_bytes;
	u32 cork_bytes;
	u32 flags;
	struct sk_buff___60 *skb;
	struct sock___43 *sk_redir;
	struct sock___43 *sk;
	struct list_head list;
};

struct ipv6_stub___5 {
	int (*ipv6_sock_mc_join)(struct sock___43 *, int, const struct in6_addr *);
	int (*ipv6_sock_mc_drop)(struct sock___43 *, int, const struct in6_addr *);
	int (*ipv6_dst_lookup)(struct net___70 *, struct sock___43 *, struct dst_entry___42 **, struct flowi6 *);
	struct fib6_table___7 * (*fib6_get_table)(struct net___70 *, u32);
	struct fib6_info___7 * (*fib6_lookup)(struct net___70 *, int, struct flowi6 *, int);
	struct fib6_info___7 * (*fib6_table_lookup)(struct net___70 *, struct fib6_table___7 *, int, struct flowi6 *, int);
	struct fib6_info___7 * (*fib6_multipath_select)(const struct net___70 *, struct fib6_info___7 *, struct flowi6 *, int, const struct sk_buff___60 *, int);
	u32 (*ip6_mtu_from_fib6)(struct fib6_info___7 *, struct in6_addr *, struct in6_addr *);
	void (*udpv6_encap_enable)();
	void (*ndisc_send_na)(struct net_device___59 *, const struct in6_addr *, const struct in6_addr *, bool, bool, bool, bool);
	struct neigh_table___42 *nd_tbl;
};

struct ipv6_bpf_stub___5 {
	int (*inet6_bind)(struct sock___43 *, struct sockaddr *, int, bool, bool);
	struct sock___43 * (*udp6_lib_lookup)(struct net___70 *, const struct in6_addr *, __be16, const struct in6_addr *, __be16, int, int, struct udp_table *, struct sk_buff___60 *);
};

struct ip_tunnel_encap_ops___4 {
	size_t (*encap_hlen)(struct ip_tunnel_encap *);
	int (*build_header)(struct sk_buff___60 *, struct ip_tunnel_encap *, u8 *, struct flowi4 *);
};

struct hw_port_info___4 {
	struct net_device___59 *lower_dev;
	u32 port_id;
};

struct metadata_dst___4 {
	struct dst_entry___42 dst;
	enum metadata_type type;
	union {
		struct ip_tunnel_info tun_info;
		struct hw_port_info___4 port_info;
	} u;
};

struct xfrm_replay___6 {
	void (*advance)(struct xfrm_state___6 *, __be32);
	int (*check)(struct xfrm_state___6 *, struct sk_buff___60 *, __be32);
	int (*recheck)(struct xfrm_state___6 *, struct sk_buff___60 *, __be32);
	void (*notify)(struct xfrm_state___6 *, int);
	int (*overflow)(struct xfrm_state___6 *, struct sk_buff___60 *);
};

struct xfrm_type___6 {
	char *description;
	struct module___343 *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___6 *);
	void (*destructor)(struct xfrm_state___6 *);
	int (*input)(struct xfrm_state___6 *, struct sk_buff___60 *);
	int (*output)(struct xfrm_state___6 *, struct sk_buff___60 *);
	int (*reject)(struct xfrm_state___6 *, struct sk_buff___60 *, const struct flowi *);
	int (*hdr_offset)(struct xfrm_state___6 *, struct sk_buff___60 *, u8 **);
	u32 (*get_mtu)(struct xfrm_state___6 *, int);
};

struct xfrm_state_afinfo___6;

struct xfrm_mode___6 {
	int (*input2)(struct xfrm_state___6 *, struct sk_buff___60 *);
	int (*input)(struct xfrm_state___6 *, struct sk_buff___60 *);
	int (*output2)(struct xfrm_state___6 *, struct sk_buff___60 *);
	int (*output)(struct xfrm_state___6 *, struct sk_buff___60 *);
	struct sk_buff___60 * (*gso_segment)(struct xfrm_state___6 *, struct sk_buff___60 *, netdev_features_t);
	void (*xmit)(struct xfrm_state___6 *, struct sk_buff___60 *);
	struct xfrm_state_afinfo___6 *afinfo;
	struct module___343 *owner;
	unsigned int encap;
	int flags;
};

struct xfrm_type_offload___6 {
	char *description;
	struct module___343 *owner;
	u8 proto;
	void (*encap)(struct xfrm_state___6 *, struct sk_buff___60 *);
	int (*input_tail)(struct xfrm_state___6 *, struct sk_buff___60 *);
	int (*xmit)(struct xfrm_state___6 *, struct sk_buff___60 *, netdev_features_t);
};

struct xfrm_state_afinfo___6 {
	unsigned int family;
	unsigned int proto;
	__be16 eth_proto;
	struct module___343 *owner;
	const struct xfrm_type___6 *type_map[256];
	const struct xfrm_type_offload___6 *type_offload_map[256];
	struct xfrm_mode___6 *mode_map[5];
	int (*init_flags)(struct xfrm_state___6 *);
	void (*init_tempsel)(struct xfrm_selector *, const struct flowi *);
	void (*init_temprop)(struct xfrm_state___6 *, const struct xfrm_tmpl *, const xfrm_address_t *, const xfrm_address_t *);
	int (*tmpl_sort)(struct xfrm_tmpl **, struct xfrm_tmpl **, int);
	int (*state_sort)(struct xfrm_state___6 **, struct xfrm_state___6 **, int);
	int (*output)(struct net___70 *, struct sock___43 *, struct sk_buff___60 *);
	int (*output_finish)(struct sock___43 *, struct sk_buff___60 *);
	int (*extract_input)(struct xfrm_state___6 *, struct sk_buff___60 *);
	int (*extract_output)(struct xfrm_state___6 *, struct sk_buff___60 *);
	int (*transport_finish)(struct sk_buff___60 *, int);
	void (*local_error)(struct sk_buff___60 *, u32);
};

struct _bpf_dtab_netdev {
	struct net_device___59 *dev;
};

struct xdp_sock___2 {
	struct sock___43 sk;
	struct xsk_queue *rx;
	struct net_device___59 *dev;
	struct xdp_umem___3 *umem;
	struct list_head flush_node;
	u16 queue_id;
	long: 48;
	long: 64;
	long: 64;
	long: 64;
	struct xsk_queue *tx;
	struct list_head list;
	bool zc;
	struct mutex mutex;
	spinlock_t tx_completion_lock;
	u64 rx_dropped;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct in_ifaddr___3 {
	struct hlist_node hash;
	struct in_ifaddr___3 *ifa_next;
	struct in_device___3 *ifa_dev;
	struct callback_head callback_head;
	__be32 ifa_local;
	__be32 ifa_address;
	__be32 ifa_mask;
	__u32 ifa_rt_priority;
	__be32 ifa_broadcast;
	unsigned char ifa_scope;
	unsigned char ifa_prefixlen;
	__u32 ifa_flags;
	char ifa_label[16];
	__u32 ifa_valid_lft;
	__u32 ifa_preferred_lft;
	long unsigned int ifa_cstamp;
	long unsigned int ifa_tstamp;
};

struct ipv6_sr_hdr {
	__u8 nexthdr;
	__u8 hdrlen;
	__u8 type;
	__u8 segments_left;
	__u8 first_segment;
	__u8 flags;
	__u16 tag;
	struct in6_addr segments[0];
};

struct seg6_bpf_srh_state {
	struct ipv6_sr_hdr *srh;
	u16 hdrlen;
	bool valid;
};

struct bpf_scratchpad {
	union {
		__be32 diff[128];
		u8 buff[512];
	};
};

struct sk_reuseport_kern {
	struct sk_buff___60 *skb;
	struct sock___43 *sk;
	struct sock___43 *selected_sk;
	void *data_end;
	u32 hash;
	u32 reuseport_id;
	bool bind_inany;
};

struct bpf_dtab_netdev___2;

struct bpf_cpu_map_entry___2;

struct module___344;

struct file___414;

struct kiocb___414;

struct iov_iter___181;

struct poll_table_struct___257;

struct vm_area_struct___415;

struct inode___414;

struct file_lock___414;

struct page___415;

struct pipe_inode_info___95;

struct seq_file___353;

struct file_operations___414 {
	struct module___344 *owner;
	loff_t (*llseek)(struct file___414 *, loff_t, int);
	ssize_t (*read)(struct file___414 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___414 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___414 *, struct iov_iter___181 *);
	ssize_t (*write_iter)(struct kiocb___414 *, struct iov_iter___181 *);
	int (*iopoll)(struct kiocb___414 *, bool);
	int (*iterate)(struct file___414 *, struct dir_context *);
	int (*iterate_shared)(struct file___414 *, struct dir_context *);
	__poll_t (*poll)(struct file___414 *, struct poll_table_struct___257 *);
	long int (*unlocked_ioctl)(struct file___414 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___414 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___414 *, struct vm_area_struct___415 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___414 *, struct file___414 *);
	int (*flush)(struct file___414 *, fl_owner_t);
	int (*release)(struct inode___414 *, struct file___414 *);
	int (*fsync)(struct file___414 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___414 *, int);
	int (*lock)(struct file___414 *, int, struct file_lock___414 *);
	ssize_t (*sendpage)(struct file___414 *, struct page___415 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___414 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___414 *, int, struct file_lock___414 *);
	ssize_t (*splice_write)(struct pipe_inode_info___95 *, struct file___414 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___414 *, loff_t *, struct pipe_inode_info___95 *, size_t, unsigned int);
	int (*setlease)(struct file___414 *, long int, struct file_lock___414 **, void **);
	long int (*fallocate)(struct file___414 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___353 *, struct file___414 *);
	ssize_t (*copy_file_range)(struct file___414 *, loff_t, struct file___414 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___414 *, loff_t, struct file___414 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___414 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___415 {
	u64 seqnum;
	struct vm_area_struct___415 *vmas[4];
};

struct page_frag___415 {
	struct page___415 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___415;

struct mem_cgroup___151;

struct cred___382;

struct nsproxy___309;

struct signal_struct___289;

struct bio_list___208;

struct backing_dev_info___208;

struct css_set___263;

struct vm_struct___318;

struct task_struct___416 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___416 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___415 *mm;
	struct mm_struct___415 *active_mm;
	struct vmacache___415 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___416 *real_parent;
	struct task_struct___416 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___416 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___151 *active_memcg;
	long int rh_reserved2;
	struct pid___236 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___236 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___236 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___382 *ptracer_cred;
	const struct cred___382 *real_cred;
	const struct cred___382 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___309 *nsproxy;
	struct signal_struct___289 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___416 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___208 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___208 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___263 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___95 *splice_pipe;
	struct page_frag___415 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___151 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___416 *oom_reaper_list;
	struct vm_struct___318 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___154 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___415 *pgtable_t___415;

struct address_space___414;

struct dev_pagemap___402;

struct page___415 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___414 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___415 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___415 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___415 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___402 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___151 *mem_cgroup;
};

struct pglist_data___415;

struct lruvec___415 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___415 *pgdat;
};

struct zone___415 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___415 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___415 {
	struct zone___415 *zone;
	int zone_idx;
};

struct zonelist___415 {
	struct zoneref___415 _zonerefs[25];
};

struct pglist_data___415 {
	struct zone___415 node_zones[3];
	struct zonelist___415 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___416 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___416 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___415 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___416 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___416 *owner;
};

struct secondary_data___416 {
	void *stack;
	struct task_struct___416 *task;
	long int status;
};

struct blocking_notifier_head___415 {
	struct rw_semaphore___416 rwsem;
	struct notifier_block *head;
};

struct cgroup___263;

struct cgroup_subsys___263;

struct cgroup_subsys_state___263 {
	struct cgroup___263 *cgroup;
	struct cgroup_subsys___263 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___263 *parent;
};

struct kernfs_node___409;

struct cgroup_file___263 {
	struct kernfs_node___409 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___151;

struct mem_cgroup___151 {
	struct cgroup_subsys_state___263 css;
	struct mem_cgroup_id___13 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___263 events_file;
	struct cgroup_file___263 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___416 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___151 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct key___382;

struct ucounts___279;

struct user_namespace___279 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___279 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___29 ns;
	long unsigned int flags;
	struct key___382 *persistent_keyring_register;
	struct rw_semaphore___416 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___279 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct user_struct___382 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___382 *uid_keyring;
	struct key___382 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___402;

struct vm_area_struct___415 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___415 *vm_next;
	struct vm_area_struct___415 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___415 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___402 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___414 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___415;

struct mm_struct___415 {
	struct {
		struct vm_area_struct___415 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___414 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___416 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___415 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___416 *owner;
		struct user_namespace___279 *user_ns;
		struct file___414 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___415 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___382 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___382 *session_keyring;
	struct key___382 *process_keyring;
	struct key___382 *thread_keyring;
	struct key___382 *request_key_auth;
	void *security;
	struct user_struct___382 *user;
	struct user_namespace___279 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___71;

struct cgroup_namespace___263;

struct nsproxy___309 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net___71 *net_ns;
	struct cgroup_namespace___263 *cgroup_ns;
};

struct signal_struct___289 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___416 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___416 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___236 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___236 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___415 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___236 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___208;

struct bio_list___208 {
	struct bio___208 *head;
	struct bio___208 *tail;
};

struct bdi_writeback_congested___208;

struct bdi_writeback___208 {
	struct backing_dev_info___208 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___208 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___263 *memcg_css;
	struct cgroup_subsys_state___263 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___382;

struct dentry___414;

struct backing_dev_info___208 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___208 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___382 *dev;
	struct device___382 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___414 *debug_dir;
	struct dentry___414 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___263 {
	struct cgroup_subsys_state___263 *subsys[13];
	refcount_t refcount;
	struct css_set___263 *dom_cset;
	struct cgroup___263 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___263 *mg_src_cgrp;
	struct cgroup___263 *mg_dst_cgrp;
	struct css_set___263 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___414;

struct pipe_buffer___95;

struct pipe_inode_info___95 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___415 *tmp_page;
	struct fasync_struct___414 *fasync_readers;
	struct fasync_struct___414 *fasync_writers;
	struct pipe_buffer___95 *bufs;
	struct user_struct___382 *user;
};

struct vm_struct___318 {
	struct vm_struct___318 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___415 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___301 {
	struct task_struct___416 task;
	long unsigned int stack[8192];
};

struct address_space_operations___414;

struct address_space___414 {
	struct inode___414 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___416 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___414 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___402)(struct vm_area_struct___415 *, long unsigned int, const struct page___415 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___402)(struct page___415 *, void *);

struct dev_pagemap___402 {
	dev_page_fault_t___402 page_fault;
	dev_page_free_t___402 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___382 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___415 {
	struct vfsmount *mnt;
	struct dentry___414 *dentry;
};

struct file___414 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___415 f_path;
	struct inode___414 *f_inode;
	const struct file_operations___414 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___236 f_owner;
	const struct cred___382 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___414 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___402;

struct vm_operations_struct___402 {
	void (*open)(struct vm_area_struct___415 *);
	void (*close)(struct vm_area_struct___415 *);
	int (*split)(struct vm_area_struct___415 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___415 *);
	vm_fault_t (*fault)(struct vm_fault___402 *);
	vm_fault_t (*huge_fault)(struct vm_fault___402 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___402 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___415 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___402 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___402 *);
	int (*access)(struct vm_area_struct___415 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___415 *);
	int (*set_policy)(struct vm_area_struct___415 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___415 *, long unsigned int);
	struct page___415 * (*find_special_page)(struct vm_area_struct___415 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___415 {
	struct task_struct___416 *task;
	struct core_thread___415 *next;
};

struct core_state___415 {
	atomic_t nr_threads;
	struct core_thread___415 dumper;
	struct completion startup;
};

struct vm_fault___402 {
	struct vm_area_struct___415 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___415 *cow_page;
	struct mem_cgroup___151 *memcg;
	struct page___415 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___415 prealloc_pte;
};

struct kset___401;

struct kobj_type___401;

struct kobject___402 {
	const char *name;
	struct list_head entry;
	struct kobject___402 *parent;
	struct kset___401 *kset;
	struct kobj_type___401 *ktype;
	struct kernfs_node___409 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___342 {
	struct kobject___402 kobj;
	struct module___344 *mod;
	struct kobject___402 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___342 {
	struct module___344 *mod;
	struct latch_tree_node node;
};

struct module_layout___342 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___342 mtn;
};

struct module_attribute___342;

struct kernel_param___342;

struct module___344 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___342 mkobj;
	struct module_attribute___342 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___402 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___342 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___342 core_layout;
	struct module_layout___342 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bio_vec___210 {
	struct page___415 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___181 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___210 *bvec;
		struct pipe_inode_info___95 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct msghdr___46 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___181 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___414 *msg_iocb;
};

struct kiocb___414 {
	struct file___414 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___414 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dentry_operations___414;

struct super_block___414;

struct dentry___414 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___414 *d_parent;
	struct qstr d_name;
	struct inode___414 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___414 *d_op;
	struct super_block___414 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___414;

struct block_device___414;

struct inode___414 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___414 *i_op;
	struct super_block___414 *i_sb;
	struct address_space___414 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___416 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___208 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___414 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___414 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___95 *i_pipe;
		struct block_device___414 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___414 {
	int (*d_revalidate)(struct dentry___414 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___414 *, unsigned int);
	int (*d_hash)(const struct dentry___414 *, struct qstr *);
	int (*d_compare)(const struct dentry___414 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___414 *);
	int (*d_init)(struct dentry___414 *);
	void (*d_release)(struct dentry___414 *);
	void (*d_prune)(struct dentry___414 *);
	void (*d_iput)(struct dentry___414 *, struct inode___414 *);
	char * (*d_dname)(struct dentry___414 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___415 *);
	int (*d_manage)(const struct path___415 *, bool);
	struct dentry___414 * (*d_real)(struct dentry___414 *, const struct inode___414 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___414;

struct mem_dqinfo___414 {
	struct quota_format_type___414 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___414;

struct quota_info___414 {
	unsigned int flags;
	struct rw_semaphore___416 dqio_sem;
	struct inode___414 *files[3];
	struct mem_dqinfo___414 info[3];
	const struct quota_format_ops___414 *ops[3];
};

struct rcuwait___414 {
	struct task_struct___416 *task;
};

struct percpu_rw_semaphore___414 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___416 rw_sem;
	struct rcuwait___414 writer;
	int readers_block;
};

struct sb_writers___414 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___414 rw_sem[3];
};

struct shrink_control___151;

struct shrinker___151 {
	long unsigned int (*count_objects)(struct shrinker___151 *, struct shrink_control___151 *);
	long unsigned int (*scan_objects)(struct shrinker___151 *, struct shrink_control___151 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___414;

struct super_operations___414;

struct dquot_operations___414;

struct quotactl_ops___414;

struct super_block___414 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___414 *s_type;
	const struct super_operations___414 *s_op;
	const struct dquot_operations___414 *dq_op;
	const struct quotactl_ops___414 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___414 *s_root;
	struct rw_semaphore___416 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___414 *s_bdev;
	struct backing_dev_info___208 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___414 s_dquot;
	struct sb_writers___414 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___414 *s_d_op;
	int cleancache_poolid;
	struct shrinker___151 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___279 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___151 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___151 *memcg;
};

struct iattr___414 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___414 *ia_file;
};

struct dquot___414 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___414 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___414 {
	int qf_fmt_id;
	const struct quota_format_ops___414 *qf_ops;
	struct module___344 *qf_owner;
	struct quota_format_type___414 *qf_next;
};

struct quota_format_ops___414 {
	int (*check_quota_file)(struct super_block___414 *, int);
	int (*read_file_info)(struct super_block___414 *, int);
	int (*write_file_info)(struct super_block___414 *, int);
	int (*free_file_info)(struct super_block___414 *, int);
	int (*read_dqblk)(struct dquot___414 *);
	int (*commit_dqblk)(struct dquot___414 *);
	int (*release_dqblk)(struct dquot___414 *);
	int (*get_next_id)(struct super_block___414 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___414 {
	int (*write_dquot)(struct dquot___414 *);
	struct dquot___414 * (*alloc_dquot)(struct super_block___414 *, int);
	void (*destroy_dquot)(struct dquot___414 *);
	int (*acquire_dquot)(struct dquot___414 *);
	int (*release_dquot)(struct dquot___414 *);
	int (*mark_dirty)(struct dquot___414 *);
	int (*write_info)(struct super_block___414 *, int);
	qsize_t * (*get_reserved_space)(struct inode___414 *);
	int (*get_projid)(struct inode___414 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___414 *, qsize_t *);
	int (*get_next_id)(struct super_block___414 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___414 {
	int (*quota_on)(struct super_block___414 *, int, int, const struct path___415 *);
	int (*quota_off)(struct super_block___414 *, int);
	int (*quota_enable)(struct super_block___414 *, unsigned int);
	int (*quota_disable)(struct super_block___414 *, unsigned int);
	int (*quota_sync)(struct super_block___414 *, int);
	int (*set_info)(struct super_block___414 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___414 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___414 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___414 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___414 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___414 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___171;

struct address_space_operations___414 {
	int (*writepage)(struct page___415 *, struct writeback_control___171 *);
	int (*readpage)(struct file___414 *, struct page___415 *);
	int (*writepages)(struct address_space___414 *, struct writeback_control___171 *);
	int (*set_page_dirty)(struct page___415 *);
	int (*readpages)(struct file___414 *, struct address_space___414 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___414 *, struct address_space___414 *, loff_t, unsigned int, unsigned int, struct page___415 **, void **);
	int (*write_end)(struct file___414 *, struct address_space___414 *, loff_t, unsigned int, unsigned int, struct page___415 *, void *);
	sector_t (*bmap)(struct address_space___414 *, sector_t);
	void (*invalidatepage)(struct page___415 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___415 *, gfp_t);
	void (*freepage)(struct page___415 *);
	ssize_t (*direct_IO)(struct kiocb___414 *, struct iov_iter___181 *);
	int (*migratepage)(struct address_space___414 *, struct page___415 *, struct page___415 *, enum migrate_mode);
	bool (*isolate_page)(struct page___415 *, isolate_mode_t);
	void (*putback_page)(struct page___415 *);
	int (*launder_page)(struct page___415 *);
	int (*is_partially_uptodate)(struct page___415 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___415 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___414 *, struct page___415 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___414 *, sector_t *);
	void (*swap_deactivate)(struct file___414 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___171 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___208 *wb;
	struct inode___414 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___414 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___414 *bd_inode;
	struct super_block___414 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___414 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___208 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___414 {
	struct dentry___414 * (*lookup)(struct inode___414 *, struct dentry___414 *, unsigned int);
	const char * (*get_link)(struct dentry___414 *, struct inode___414 *, struct delayed_call *);
	int (*permission)(struct inode___414 *, int);
	struct posix_acl * (*get_acl)(struct inode___414 *, int);
	int (*readlink)(struct dentry___414 *, char *, int);
	int (*create)(struct inode___414 *, struct dentry___414 *, umode_t, bool);
	int (*link)(struct dentry___414 *, struct inode___414 *, struct dentry___414 *);
	int (*unlink)(struct inode___414 *, struct dentry___414 *);
	int (*symlink)(struct inode___414 *, struct dentry___414 *, const char *);
	int (*mkdir)(struct inode___414 *, struct dentry___414 *, umode_t);
	int (*rmdir)(struct inode___414 *, struct dentry___414 *);
	int (*mknod)(struct inode___414 *, struct dentry___414 *, umode_t, dev_t);
	int (*rename)(struct inode___414 *, struct dentry___414 *, struct inode___414 *, struct dentry___414 *, unsigned int);
	int (*setattr)(struct dentry___414 *, struct iattr___414 *);
	int (*getattr)(const struct path___415 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___414 *, char *, size_t);
	int (*fiemap)(struct inode___414 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___414 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___414 *, struct dentry___414 *, struct file___414 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___414 *, struct dentry___414 *, umode_t);
	int (*set_acl)(struct inode___414 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___414 {
	void (*fl_copy_lock)(struct file_lock___414 *, struct file_lock___414 *);
	void (*fl_release_private)(struct file_lock___414 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___414;

struct file_lock___414 {
	struct file_lock___414 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___414 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___414 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___414 *fl_ops;
	const struct lock_manager_operations___414 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___414 {
	int (*lm_compare_owner)(struct file_lock___414 *, struct file_lock___414 *);
	long unsigned int (*lm_owner_key)(struct file_lock___414 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___414 *);
	int (*lm_grant)(struct file_lock___414 *, int);
	bool (*lm_break)(struct file_lock___414 *);
	int (*lm_change)(struct file_lock___414 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___414 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___414 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___414 *fa_next;
	struct file___414 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___414 {
	const char *name;
	int fs_flags;
	struct dentry___414 * (*mount)(struct file_system_type___414 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___414 *);
	struct module___344 *owner;
	struct file_system_type___414 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___414 {
	struct inode___414 * (*alloc_inode)(struct super_block___414 *);
	void (*destroy_inode)(struct inode___414 *);
	void (*dirty_inode)(struct inode___414 *, int);
	int (*write_inode)(struct inode___414 *, struct writeback_control___171 *);
	int (*drop_inode)(struct inode___414 *);
	void (*evict_inode)(struct inode___414 *);
	void (*put_super)(struct super_block___414 *);
	int (*sync_fs)(struct super_block___414 *, int);
	int (*freeze_super)(struct super_block___414 *);
	int (*freeze_fs)(struct super_block___414 *);
	int (*thaw_super)(struct super_block___414 *);
	int (*unfreeze_fs)(struct super_block___414 *);
	int (*statfs)(struct dentry___414 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___414 *, int *, char *);
	void (*umount_begin)(struct super_block___414 *);
	int (*show_options)(struct seq_file___353 *, struct dentry___414 *);
	int (*show_devname)(struct seq_file___353 *, struct dentry___414 *);
	int (*show_path)(struct seq_file___353 *, struct dentry___414 *);
	int (*show_stats)(struct seq_file___353 *, struct dentry___414 *);
	ssize_t (*quota_read)(struct super_block___414 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___414 *, int, const char *, size_t, loff_t);
	struct dquot___414 ** (*get_dquots)(struct inode___414 *);
	int (*bdev_try_to_free_page)(struct super_block___414 *, struct page___415 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___414 *, struct shrink_control___151 *);
	long int (*free_cached_objects)(struct super_block___414 *, struct shrink_control___151 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___267)(struct file___414 *, wait_queue_head_t *, struct poll_table_struct___257 *);

struct poll_table_struct___257 {
	poll_queue_proc___267 _qproc;
	__poll_t _key;
};

struct seq_operations___353;

struct seq_file___353 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___353 *op;
	int poll_event;
	const struct file___414 *file;
	void *private;
};

typedef void bio_end_io_t___208(struct bio___208 *);

struct bio_integrity_payload___208;

struct bio_set___208;

struct bio___208 {
	struct bio___208 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___208 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___208 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___210 *bi_io_vec;
	struct bio_set___208 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___210 bi_inline_vecs[0];
};

struct socket_wq___44 {
	wait_queue_head_t wait;
	struct fasync_struct___414 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct sock___44;

struct proto_ops___44;

struct socket___45 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___44 *wq;
	struct file___414 *file;
	struct sock___44 *sk;
	const struct proto_ops___44 *ops;
};

typedef struct {
	struct net___71 *net;
} possible_net_t___61;

struct proto___43;

struct sock_common___43 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___43 *skc_prot;
	possible_net_t___61 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___44 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___61;

struct sk_buff_head___59 {
	struct sk_buff___61 *next;
	struct sk_buff___61 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___43;

struct dst_entry___43;

struct net_device___60;

struct sock___44 {
	struct sock_common___43 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___59 sk_error_queue;
	struct sk_buff_head___59 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___61 *head;
		struct sk_buff___61 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___43 *sk_filter;
	union {
		struct socket_wq___44 *sk_wq;
		struct socket_wq___44 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___43 *sk_rx_dst;
	struct dst_entry___43 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___61 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___59 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___415 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___43 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___236 *sk_peer_pid;
	const struct cred___382 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___45 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___151 *sk_memcg;
	void (*sk_state_change)(struct sock___44 *);
	void (*sk_data_ready)(struct sock___44 *);
	void (*sk_write_space)(struct sock___44 *);
	void (*sk_error_report)(struct sock___44 *);
	int (*sk_backlog_rcv)(struct sock___44 *, struct sk_buff___61 *);
	struct sk_buff___61 * (*sk_validate_xmit_skb)(struct sock___44 *, struct net_device___60 *, struct sk_buff___61 *);
	void (*sk_destruct)(struct sock___44 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

typedef int (*sk_read_actor_t___43)(read_descriptor_t *, struct sk_buff___61 *, unsigned int, size_t);

struct proto_ops___44 {
	int family;
	struct module___344 *owner;
	int (*release)(struct socket___45 *);
	int (*bind)(struct socket___45 *, struct sockaddr *, int);
	int (*connect)(struct socket___45 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___45 *, struct socket___45 *);
	int (*accept)(struct socket___45 *, struct socket___45 *, int, bool);
	int (*getname)(struct socket___45 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___414 *, struct socket___45 *, struct poll_table_struct___257 *);
	int (*ioctl)(struct socket___45 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___45 *, int);
	int (*shutdown)(struct socket___45 *, int);
	int (*setsockopt)(struct socket___45 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___45 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___45 *, struct msghdr___46 *, size_t);
	int (*recvmsg)(struct socket___45 *, struct msghdr___46 *, size_t, int);
	int (*mmap)(struct file___414 *, struct socket___45 *, struct vm_area_struct___415 *);
	ssize_t (*sendpage)(struct socket___45 *, struct page___415 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___45 *, loff_t *, struct pipe_inode_info___95 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___44 *, int);
	int (*peek_len)(struct socket___45 *);
	int (*read_sock)(struct sock___44 *, read_descriptor_t *, sk_read_actor_t___43);
	int (*sendpage_locked)(struct sock___44 *, struct page___415 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___44 *, struct msghdr___46 *, size_t);
	int (*set_rcvlowat)(struct sock___44 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct nf_bridge_info___59;

struct sk_buff___61 {
	union {
		struct {
			struct sk_buff___61 *next;
			struct sk_buff___61 *prev;
			union {
				struct net_device___60 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___44 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___61 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___59 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___59;

struct netns_frags___59 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___59 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_rules_ops___43;

struct fib_notifier_ops___43;

struct netns_ipv4___59 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___43 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___44 *fibnl;
	struct sock___44 **icmp_sk;
	struct sock___44 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___44 **tcp_sk;
	struct netns_frags___59 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___43 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___43 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___43 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___43;

struct dst_ops___70 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___70 *);
	struct dst_entry___43 * (*check)(struct dst_entry___43 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___43 *);
	unsigned int (*mtu)(const struct dst_entry___43 *);
	u32 * (*cow_metrics)(struct dst_entry___43 *, long unsigned int);
	void (*destroy)(struct dst_entry___43 *);
	void (*ifdown)(struct dst_entry___43 *, struct net_device___60 *, int);
	struct dst_entry___43 * (*negative_advice)(struct dst_entry___43 *);
	void (*link_failure)(struct sk_buff___61 *);
	void (*update_pmtu)(struct dst_entry___43 *, struct sock___44 *, struct sk_buff___61 *, u32);
	void (*redirect)(struct dst_entry___43 *, struct sock___44 *, struct sk_buff___61 *);
	int (*local_out)(struct net___71 *, struct sock___44 *, struct sk_buff___61 *);
	struct neighbour___43 * (*neigh_lookup)(const struct dst_entry___43 *, struct sk_buff___61 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___43 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___70 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___59 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___70 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___43 *fib6_rules_ops;
	struct sock___44 **icmp_sk;
	struct sock___44 *ndisc_sk;
	struct sock___44 *tcp_sk;
	struct sock___44 *igmp_sk;
	struct sock___44 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___43 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___43 *notifier_ops;
	struct fib_notifier_ops___43 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___44 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___44 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___59 {
	struct netns_frags___59 frags;
};

struct netns_xfrm___70 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___44 *nlsk;
	struct sock___44 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___70 xfrm4_dst_ops;
	struct dst_ops___70 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___53;

struct net___71 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___279 *user_ns;
	struct ucounts___279 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___29 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___44 *rtnl;
	struct sock___44 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___60 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___59 ipv4;
	struct netns_ipv6___70 ipv6;
	struct netns_sctp___44 sctp;
	struct netns_nf___4 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___59 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___44 *nfnl;
	struct sock___44 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___70 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___44 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___53 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kernfs_root___408;

struct kernfs_elem_dir___408 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___408 *root;
};

struct kernfs_syscall_ops___408;

struct kernfs_root___408 {
	struct kernfs_node___409 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___408 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___408 {
	struct kernfs_node___409 *target_kn;
};

struct kernfs_ops___408;

struct kernfs_elem_attr___408 {
	const struct kernfs_ops___408 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___409 *notify_next;
};

struct kernfs_node___409 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___409 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___408 dir;
		struct kernfs_elem_symlink___408 symlink;
		struct kernfs_elem_attr___408 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___408;

struct kernfs_ops___408 {
	int (*open)(struct kernfs_open_file___408 *);
	void (*release)(struct kernfs_open_file___408 *);
	int (*seq_show)(struct seq_file___353 *, void *);
	void * (*seq_start)(struct seq_file___353 *, loff_t *);
	void * (*seq_next)(struct seq_file___353 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___353 *, void *);
	ssize_t (*read)(struct kernfs_open_file___408 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___408 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___408 *, struct vm_area_struct___415 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___408 *, struct poll_table_struct___257 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___408 {
	int (*remount_fs)(struct kernfs_root___408 *, int *, char *);
	int (*show_options)(struct seq_file___353 *, struct kernfs_root___408 *);
	int (*mkdir)(struct kernfs_node___409 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___409 *);
	int (*rename)(struct kernfs_node___409 *, struct kernfs_node___409 *, const char *);
	int (*show_path)(struct seq_file___353 *, struct kernfs_node___409 *, struct kernfs_root___408 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___408 {
	struct kernfs_node___409 *kn;
	struct file___414 *file;
	struct seq_file___353 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___402 *vm_ops;
};

struct kobj_ns_type_operations___43 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___44 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___378;

struct attribute_group___379 {
	const char *name;
	umode_t (*is_visible)(struct kobject___402 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___402 *, struct bin_attribute___378 *, int);
	struct attribute **attrs;
	struct bin_attribute___378 **bin_attrs;
};

struct bin_attribute___378 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___414 *, struct kobject___402 *, struct bin_attribute___378 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___414 *, struct kobject___402 *, struct bin_attribute___378 *, char *, loff_t, size_t);
	int (*mmap)(struct file___414 *, struct kobject___402 *, struct bin_attribute___378 *, struct vm_area_struct___415 *);
};

struct sysfs_ops___401 {
	ssize_t (*show)(struct kobject___402 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___402 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___401;

struct kset___401 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___402 kobj;
	const struct kset_uevent_ops___401 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___401 {
	void (*release)(struct kobject___402 *);
	const struct sysfs_ops___401 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___43 * (*child_ns_type)(struct kobject___402 *);
	const void * (*namespace)(struct kobject___402 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___401 {
	int (* const filter)(struct kset___401 *, struct kobject___402 *);
	const char * (* const name)(struct kset___401 *, struct kobject___402 *);
	int (* const uevent)(struct kset___401 *, struct kobject___402 *, struct kobj_uevent_env *);
};

struct kobj_attribute___392 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___402 *, struct kobj_attribute___392 *, char *);
	ssize_t (*store)(struct kobject___402 *, struct kobj_attribute___392 *, const char *, size_t);
};

struct dev_pm_ops___382 {
	int (*prepare)(struct device___382 *);
	void (*complete)(struct device___382 *);
	int (*suspend)(struct device___382 *);
	int (*resume)(struct device___382 *);
	int (*freeze)(struct device___382 *);
	int (*thaw)(struct device___382 *);
	int (*poweroff)(struct device___382 *);
	int (*restore)(struct device___382 *);
	int (*suspend_late)(struct device___382 *);
	int (*resume_early)(struct device___382 *);
	int (*freeze_late)(struct device___382 *);
	int (*thaw_early)(struct device___382 *);
	int (*poweroff_late)(struct device___382 *);
	int (*restore_early)(struct device___382 *);
	int (*suspend_noirq)(struct device___382 *);
	int (*resume_noirq)(struct device___382 *);
	int (*freeze_noirq)(struct device___382 *);
	int (*thaw_noirq)(struct device___382 *);
	int (*poweroff_noirq)(struct device___382 *);
	int (*restore_noirq)(struct device___382 *);
	int (*runtime_suspend)(struct device___382 *);
	int (*runtime_resume)(struct device___382 *);
	int (*runtime_idle)(struct device___382 *);
};

struct dev_pm_info___382 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___382 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___382;

struct bus_type___382;

struct device_driver___382;

struct dev_pm_domain___382;

struct dma_map_ops___154;

struct fwnode_handle___302;

struct class___382;

struct device___382 {
	struct device___382 *parent;
	struct device_private *p;
	struct kobject___402 kobj;
	const char *init_name;
	const struct device_type___382 *type;
	struct mutex mutex;
	struct bus_type___382 *bus;
	struct device_driver___382 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___382 power;
	struct dev_pm_domain___382 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___154 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___302 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___382 *class;
	const struct attribute_group___379 **groups;
	void (*release)(struct device___382 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___382 {
	struct dev_pm_ops___382 ops;
	void (*detach)(struct device___382 *, bool);
	int (*activate)(struct device___382 *);
	void (*sync)(struct device___382 *);
	void (*dismiss)(struct device___382 *);
};

struct bus_type___382 {
	const char *name;
	const char *dev_name;
	struct device___382 *dev_root;
	const struct attribute_group___379 **bus_groups;
	const struct attribute_group___379 **dev_groups;
	const struct attribute_group___379 **drv_groups;
	int (*match)(struct device___382 *, struct device_driver___382 *);
	int (*uevent)(struct device___382 *, struct kobj_uevent_env *);
	int (*probe)(struct device___382 *);
	int (*remove)(struct device___382 *);
	void (*shutdown)(struct device___382 *);
	int (*online)(struct device___382 *);
	int (*offline)(struct device___382 *);
	int (*suspend)(struct device___382 *, pm_message_t);
	int (*resume)(struct device___382 *);
	int (*num_vf)(struct device___382 *);
	int (*dma_configure)(struct device___382 *);
	const struct dev_pm_ops___382 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___382 {
	const char *name;
	struct bus_type___382 *bus;
	struct module___344 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___382 *);
	int (*remove)(struct device___382 *);
	void (*shutdown)(struct device___382 *);
	int (*suspend)(struct device___382 *, pm_message_t);
	int (*resume)(struct device___382 *);
	const struct attribute_group___379 **groups;
	const struct dev_pm_ops___382 *pm;
	void (*coredump)(struct device___382 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___382 {
	const char *name;
	const struct attribute_group___379 **groups;
	int (*uevent)(struct device___382 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___382 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___382 *);
	const struct dev_pm_ops___382 *pm;
};

struct class___382 {
	const char *name;
	struct module___344 *owner;
	const struct attribute_group___379 **class_groups;
	const struct attribute_group___379 **dev_groups;
	struct kobject___402 *dev_kobj;
	int (*dev_uevent)(struct device___382 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___382 *, umode_t *);
	void (*class_release)(struct class___382 *);
	void (*dev_release)(struct device___382 *);
	int (*shutdown_pre)(struct device___382 *);
	const struct kobj_ns_type_operations___43 *ns_type;
	const void * (*namespace)(struct device___382 *);
	const struct dev_pm_ops___382 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___154 {
	void * (*alloc)(struct device___382 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___382 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___382 *, struct vm_area_struct___415 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___382 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___382 *, struct page___415 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___382 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___382 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___382 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___382 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___382 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___382 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___382 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___382 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___382 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___382 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___382 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___382 *, u64);
	u64 (*get_required_mask)(struct device___382 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___302;

struct fwnode_handle___302 {
	struct fwnode_handle___302 *secondary;
	const struct fwnode_operations___302 *ops;
};

typedef void compound_page_dtor___402(struct page___415 *);

struct fwnode_reference_args___302;

struct fwnode_endpoint___302;

struct fwnode_operations___302 {
	struct fwnode_handle___302 * (*get)(struct fwnode_handle___302 *);
	void (*put)(struct fwnode_handle___302 *);
	bool (*device_is_available)(const struct fwnode_handle___302 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___302 *, const struct device___382 *);
	bool (*property_present)(const struct fwnode_handle___302 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___302 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___302 *, const char *, const char **, size_t);
	struct fwnode_handle___302 * (*get_parent)(const struct fwnode_handle___302 *);
	struct fwnode_handle___302 * (*get_next_child_node)(const struct fwnode_handle___302 *, struct fwnode_handle___302 *);
	struct fwnode_handle___302 * (*get_named_child_node)(const struct fwnode_handle___302 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___302 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___302 *);
	struct fwnode_handle___302 * (*graph_get_next_endpoint)(const struct fwnode_handle___302 *, struct fwnode_handle___302 *);
	struct fwnode_handle___302 * (*graph_get_remote_endpoint)(const struct fwnode_handle___302 *);
	struct fwnode_handle___302 * (*graph_get_port_parent)(struct fwnode_handle___302 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___302 *, struct fwnode_endpoint___302 *);
};

struct fwnode_endpoint___302 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___302 *local_fwnode;
};

struct fwnode_reference_args___302 {
	struct fwnode_handle___302 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___95;

struct pipe_buffer___95 {
	struct page___415 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___95 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___95 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___95 *, struct pipe_buffer___95 *);
	void (*release)(struct pipe_inode_info___95 *, struct pipe_buffer___95 *);
	int (*steal)(struct pipe_inode_info___95 *, struct pipe_buffer___95 *);
	union {
		bool (*get)(struct pipe_inode_info___95 *, struct pipe_buffer___95 *);
		struct {
			void (*get)(struct pipe_inode_info___95 *, struct pipe_buffer___95 *);
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
};

struct nf_bridge_info___59 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___59 = 0,
		BRNF_PROTO_8021Q___59 = 1,
		BRNF_PROTO_PPPOE___59 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___60 *physindev;
	struct net_device___60 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___59(struct sk_buff___61 **);

struct net_device_ops___59;

struct ethtool_ops___59;

struct l3mdev_ops___43;

struct xfrmdev_ops___59;

struct tlsdev_ops___59;

struct header_ops___59;

struct netdev_rx_queue___59;

struct mini_Qdisc___53;

struct netdev_queue___59;

struct Qdisc___53;

struct rtnl_link_ops___53;

struct dcbnl_rtnl_ops___59;

struct net_device___60 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___59 *netdev_ops;
	const struct ethtool_ops___59 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___43 *l3mdev_ops;
	const struct ndisc_ops___2 *ndisc_ops;
	const struct xfrmdev_ops___59 *xfrmdev_ops;
	const struct tlsdev_ops___59 *tlsdev_ops;
	const struct header_ops___59 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___401 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___2 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___59 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___53 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___59 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___53 *miniq_ingress;
	struct netdev_queue___59 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___59 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___53 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___53 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___59 = 0,
		NETREG_REGISTERED___59 = 1,
		NETREG_UNREGISTERING___59 = 2,
		NETREG_UNREGISTERED___59 = 3,
		NETREG_RELEASED___59 = 4,
		NETREG_DUMMY___59 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___59 = 0,
		RTNL_LINK_INITIALIZING___59 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___60 *);
	struct netpoll_info *npinfo;
	possible_net_t___61 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___382 dev;
	const struct attribute_group___379 *sysfs_groups[4];
	const struct attribute_group___379 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___53 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___59 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide35;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

typedef int (*key_restrict_link_func_t___383)(struct key___382 *, const struct key_type *, const union key_payload *, struct key___382 *);

struct key_restriction___382;

struct key___382 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___416 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___382 *restrict_link;
};

struct key_restriction___382 {
	key_restrict_link_func_t___383 check;
	struct key___382 *key;
	struct key_type *keytype;
};

struct cgroup_namespace___263 {
	refcount_t count;
	struct ns_common___29 ns;
	struct user_namespace___279 *user_ns;
	struct ucounts___279 *ucounts;
	struct css_set___263 *root_cset;
};

struct netlink_skb_parms___9 {
	struct scm_creds creds;
	__u32 portid;
	__u32 dst_group;
	__u32 flags;
	struct sock___44 *sk;
	bool nsid_is_set;
	int nsid;
};

struct netlink_kernel_cfg___5 {
	unsigned int groups;
	unsigned int flags;
	void (*input)(struct sk_buff___61 *);
	struct mutex *cb_mutex;
	int (*bind)(struct net___71 *, int);
	void (*unbind)(struct net___71 *, int);
	bool (*compare)(struct net___71 *, struct sock___44 *);
};

struct netlink_callback___61 {
	struct sk_buff___61 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___61 *);
	int (*dump)(struct sk_buff___61 *, struct netlink_callback___61 *);
	int (*done)(struct netlink_callback___61 *);
	void *data;
	struct module___344 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct inet_frag_queue___59;

struct inet_frags___59 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___59 *, const void *);
	void (*destructor)(struct inet_frag_queue___59 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___59 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___61 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___61 *fragments_tail;
	struct sk_buff___61 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___59 *net;
	struct callback_head rcu;
};

struct fib_rule___43;

struct fib_lookup_arg___43;

struct fib_rules_ops___43 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___43 *, struct flowi *, int, struct fib_lookup_arg___43 *);
	bool (*suppress)(struct fib_rule___43 *, struct fib_lookup_arg___43 *);
	int (*match)(struct fib_rule___43 *, struct flowi *, int);
	int (*configure)(struct fib_rule___43 *, struct sk_buff___61 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___43 *);
	int (*compare)(struct fib_rule___43 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___43 *, struct sk_buff___61 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___43 *);
	void (*flush_cache)(struct fib_rules_ops___43 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___344 *owner;
	struct net___71 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___43 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___71 *);
	int (*fib_dump)(struct net___71 *, struct notifier_block *);
	struct module___344 *owner;
	struct callback_head rcu;
};

struct dst_entry___43 {
	struct net_device___60 *dev;
	struct dst_ops___70 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___61 *);
	int (*output)(struct net___71 *, struct sock___44 *, struct sk_buff___61 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___43;

struct neigh_parms___43;

struct neigh_ops___43;

struct neighbour___43 {
	struct neighbour___43 *next;
	struct neigh_table___43 *tbl;
	struct neigh_parms___43 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___59 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___43 *, struct sk_buff___61 *);
	const struct neigh_ops___43 *ops;
	struct callback_head rcu;
	struct net_device___60 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct ucounts___279 {
	struct hlist_node node;
	struct user_namespace___279 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_prog_aux___56;

struct bpf_prog___53 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___56 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

struct seq_operations___353 {
	void * (*start)(struct seq_file___353 *, loff_t *);
	void (*stop)(struct seq_file___353 *, void *);
	void * (*next)(struct seq_file___353 *, void *, loff_t *);
	int (*show)(struct seq_file___353 *, void *);
};

struct pernet_operations___60 {
	struct list_head list;
	int (*init)(struct net___71 *);
	void (*exit)(struct net___71 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct kernel_param_ops___342 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___342 *);
	int (*get)(char *, const struct kernel_param___342 *);
	void (*free)(void *);
};

struct kparam_array___342;

struct kernel_param___342 {
	const char *name;
	struct module___344 *mod;
	const struct kernel_param_ops___342 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___342 *arr;
	};
};

struct kparam_array___342 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___342 *ops;
	void *elem;
};

struct module_attribute___342 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___342 *, struct module_kobject___342 *, char *);
	ssize_t (*store)(struct module_attribute___342 *, struct module_kobject___342 *, const char *, size_t);
	void (*setup)(struct module___344 *, const char *);
	int (*test)(struct module___344 *);
	void (*free)(struct module___344 *);
};

struct ethtool_ops___59 {
	int (*get_settings)(struct net_device___60 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___60 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___60 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___60 *);
	void (*get_regs)(struct net_device___60 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___60 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___60 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___60 *);
	void (*set_msglevel)(struct net_device___60 *, u32);
	int (*nway_reset)(struct net_device___60 *);
	u32 (*get_link)(struct net_device___60 *);
	int (*get_eeprom_len)(struct net_device___60 *);
	int (*get_eeprom)(struct net_device___60 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___60 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___60 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___60 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___60 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___60 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___60 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___60 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___60 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___60 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___60 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___60 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___60 *);
	void (*complete)(struct net_device___60 *);
	u32 (*get_priv_flags)(struct net_device___60 *);
	int (*set_priv_flags)(struct net_device___60 *, u32);
	int (*get_sset_count)(struct net_device___60 *, int);
	int (*get_rxnfc)(struct net_device___60 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___60 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___60 *, struct ethtool_flash *);
	int (*reset)(struct net_device___60 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___60 *);
	u32 (*get_rxfh_indir_size)(struct net_device___60 *);
	int (*get_rxfh)(struct net_device___60 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___60 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___60 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___60 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___60 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___60 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___60 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___60 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___60 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___60 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___60 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___60 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___60 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___60 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___60 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___60 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___60 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___60 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___60 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___60 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___60 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___60 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	int (*get_fecparam)(struct net_device___60 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___60 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___60 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___60 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___60 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct dcbnl_rtnl_ops___59 {
	int (*ieee_getets)(struct net_device___60 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___60 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___60 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___60 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___60 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___60 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___60 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___60 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___60 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___60 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___60 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___60 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___60 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___60 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___60 *);
	u8 (*setstate)(struct net_device___60 *, u8);
	void (*getpermhwaddr)(struct net_device___60 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___60 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___60 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___60 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___60 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___60 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___60 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___60 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___60 *, int, u8 *);
	void (*setpfccfg)(struct net_device___60 *, int, u8);
	void (*getpfccfg)(struct net_device___60 *, int, u8 *);
	u8 (*setall)(struct net_device___60 *);
	u8 (*getcap)(struct net_device___60 *, int, u8 *);
	int (*getnumtcs)(struct net_device___60 *, int, u8 *);
	int (*setnumtcs)(struct net_device___60 *, int, u8);
	u8 (*getpfcstate)(struct net_device___60 *);
	void (*setpfcstate)(struct net_device___60 *, u8);
	void (*getbcncfg)(struct net_device___60 *, int, u32 *);
	void (*setbcncfg)(struct net_device___60 *, int, u32);
	void (*getbcnrp)(struct net_device___60 *, int, u8 *);
	void (*setbcnrp)(struct net_device___60 *, int, u8);
	int (*setapp)(struct net_device___60 *, u8, u16, u8);
	int (*getapp)(struct net_device___60 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___60 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___60 *, int, u8);
	u8 (*getdcbx)(struct net_device___60 *);
	u8 (*setdcbx)(struct net_device___60 *, u8);
	int (*peer_getappinfo)(struct net_device___60 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___60 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___60 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___60 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___60 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___60 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct bpf_map___264;

struct bpf_map_ops___263 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___264 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___264 *, struct file___414 *);
	void (*map_free)(struct bpf_map___264 *);
	int (*map_get_next_key)(struct bpf_map___264 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___264 *);
	void * (*map_lookup_elem)(struct bpf_map___264 *, void *);
	int (*map_update_elem)(struct bpf_map___264 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___264 *, void *);
	int (*map_push_elem)(struct bpf_map___264 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___264 *, void *);
	int (*map_peek_elem)(struct bpf_map___264 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___264 *, struct file___414 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___264 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___264 *, void *, struct seq_file___353 *);
	int (*map_check_btf)(const struct bpf_map___264 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___264 {
	const struct bpf_map_ops___263 *ops;
	struct bpf_map___264 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___382 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___59;

struct bpf_map_dev_ops___59 {
	int (*map_get_next_key)(struct bpf_offloaded_map___59 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___59 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___59 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___59 *, void *);
};

struct bpf_offloaded_map___59 {
	struct bpf_map___264 map;
	struct net_device___60 *netdev;
	const struct bpf_map_dev_ops___59 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___53 {
	int (*test_run)(struct bpf_prog___53 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___53 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___53 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___53 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___53 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___53 *, u32 *);
};

struct bpf_prog_offload_ops___53 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___53 *);
	int (*translate)(struct bpf_prog___53 *);
	void (*destroy)(struct bpf_prog___53 *);
};

struct bpf_prog_offload___53 {
	struct bpf_prog___53 *prog;
	struct net_device___60 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___53 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___56 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___53 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___53 *ops;
	struct bpf_map___264 **used_maps;
	struct bpf_prog___53 *prog;
	struct user_struct___382 *user;
	u64 load_time;
	struct bpf_map___264 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___53 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___53 {
	struct bpf_prog___53 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___53 {
	struct callback_head rcu;
	struct bpf_prog_array_item___53 items[0];
};

struct cgroup_bpf___53 {
	struct bpf_prog_array___53 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___53 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___264;

typedef void (*kthread_work_func_t___264)(struct kthread_work___264 *);

struct kthread_worker___264;

struct kthread_work___264 {
	struct list_head node;
	kthread_work_func_t___264 func;
	struct kthread_worker___264 *worker;
	int canceling;
};

struct kthread_worker___264 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___416 *task;
	struct kthread_work___264 *current_work;
};

struct kthread_delayed_work___263 {
	struct kthread_work___264 work;
	struct timer_list timer;
};

struct psi_group___263 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___264 *poll_kworker;
	struct kthread_delayed_work___263 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___263;

struct cgroup_rstat_cpu___263;

struct cgroup___263 {
	struct cgroup_subsys_state___263 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___409 *kn;
	struct cgroup_file___263 procs_file;
	struct cgroup_file___263 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___263 *subsys[13];
	struct cgroup_root___263 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___263 *dom_cgrp;
	struct cgroup_rstat_cpu___263 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___53 bpf;
	atomic_t congestion_count;
	struct cgroup___263 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___263 psi;
	int ancestor_ids[0];
};

struct cftype___263;

struct cgroup_subsys___263 {
	struct cgroup_subsys_state___263 * (*css_alloc)(struct cgroup_subsys_state___263 *);
	int (*css_online)(struct cgroup_subsys_state___263 *);
	void (*css_offline)(struct cgroup_subsys_state___263 *);
	void (*css_released)(struct cgroup_subsys_state___263 *);
	void (*css_free)(struct cgroup_subsys_state___263 *);
	void (*css_reset)(struct cgroup_subsys_state___263 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___263 *, int);
	int (*css_extra_stat_show)(struct seq_file___353 *, struct cgroup_subsys_state___263 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___416 *);
	void (*cancel_fork)(struct task_struct___416 *);
	void (*fork)(struct task_struct___416 *);
	void (*exit)(struct task_struct___416 *);
	void (*free)(struct task_struct___416 *);
	void (*bind)(struct cgroup_subsys_state___263 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___263 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___263 *dfl_cftypes;
	struct cftype___263 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___263 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___263 *updated_children;
	struct cgroup___263 *updated_next;
};

struct cgroup_root___263 {
	struct kernfs_root___408 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___263 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___263 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___263 *ss;
	struct list_head node;
	struct kernfs_ops___408 *kf_ops;
	int (*open)(struct kernfs_open_file___408 *);
	void (*release)(struct kernfs_open_file___408 *);
	u64 (*read_u64)(struct cgroup_subsys_state___263 *, struct cftype___263 *);
	s64 (*read_s64)(struct cgroup_subsys_state___263 *, struct cftype___263 *);
	int (*seq_show)(struct seq_file___353 *, void *);
	void * (*seq_start)(struct seq_file___353 *, loff_t *);
	void * (*seq_next)(struct seq_file___353 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___353 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___263 *, struct cftype___263 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___263 *, struct cftype___263 *, s64);
	ssize_t (*write)(struct kernfs_open_file___408 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___408 *, struct poll_table_struct___257 *);
};

struct xdp_rxq_info___59 {
	struct net_device___60 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___59 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___60 *dev_rx;
};

struct header_ops___59 {
	int (*create)(struct sk_buff___61 *, struct net_device___60 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___61 *, unsigned char *);
	int (*cache)(const struct neighbour___43 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___60 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___59 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___59 *, int);
	int poll_owner;
	struct net_device___60 *dev;
	struct sk_buff___61 *gro_list;
	struct sk_buff___61 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___59 {
	struct net_device___60 *dev;
	struct Qdisc___53 *qdisc;
	struct Qdisc___53 *qdisc_sleeping;
	struct kobject___402 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___60 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem___3 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___53 {
	struct sk_buff___61 *head;
	struct sk_buff___61 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___53;

struct Qdisc___53 {
	int (*enqueue)(struct sk_buff___61 *, struct Qdisc___53 *, struct sk_buff___61 **);
	struct sk_buff___61 * (*dequeue)(struct Qdisc___53 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___53 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___59 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___59 gso_skb;
	struct qdisc_skb_head___53 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___53 *next_sched;
	struct sk_buff_head___59 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___59 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___402 kobj;
	struct net_device___60 *dev;
	long: 64;
	struct xdp_rxq_info___59 xdp_rxq;
	union {
		struct xdp_umem___3 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___59)(struct net_device___60 *, struct sk_buff___61 *, struct net_device___60 *);

struct netdev_bpf___59 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___53 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___53 *prog;
			const struct bpf_prog_offload_ops___53 *ops;
		} verifier;
		struct {
			struct bpf_prog___53 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___59 *offmap;
		};
		struct {
			struct xdp_umem___3 *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___59 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___61 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___59 {
	int (*tls_dev_add)(struct net_device___60 *, struct sock___44 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___60 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___60 *, struct sock___44 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___59 {
	int (*ndo_init)(struct net_device___60 *);
	void (*ndo_uninit)(struct net_device___60 *);
	int (*ndo_open)(struct net_device___60 *);
	int (*ndo_stop)(struct net_device___60 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___61 *, struct net_device___60 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___61 *, struct net_device___60 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___60 *, struct sk_buff___61 *, struct net_device___60 *, select_queue_fallback_t___59);
	void (*ndo_change_rx_flags)(struct net_device___60 *, int);
	void (*ndo_set_rx_mode)(struct net_device___60 *);
	int (*ndo_set_mac_address)(struct net_device___60 *, void *);
	int (*ndo_validate_addr)(struct net_device___60 *);
	int (*ndo_do_ioctl)(struct net_device___60 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___60 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___60 *, int);
	int (*ndo_neigh_setup)(struct net_device___60 *, struct neigh_parms___43 *);
	void (*ndo_tx_timeout)(struct net_device___60 *);
	void (*ndo_get_stats64)(struct net_device___60 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___60 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___60 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___60 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___60 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___60 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___60 *);
	int (*ndo_netpoll_setup)(struct net_device___60 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___60 *);
	int (*ndo_set_vf_mac)(struct net_device___60 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___60 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___60 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___60 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___60 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___60 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___60 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___60 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___60 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___60 *, int, struct sk_buff___61 *);
	int (*ndo_set_vf_guid)(struct net_device___60 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___60 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___60 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___60 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___60 *, const struct sk_buff___61 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___60 *, struct net_device___60 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___60 *, struct net_device___60 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___60 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___60 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___60 *, struct neighbour___43 *);
	void (*ndo_neigh_destroy)(struct net_device___60 *, struct neighbour___43 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___60 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___60 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___60 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___61 *, struct netlink_callback___61 *, struct net_device___60 *, struct net_device___60 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___60 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___60 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___61 *, u32, u32, struct net_device___60 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___60 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___60 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___60 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___60 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___60 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___60 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___60 *, struct net_device___60 *);
	void (*ndo_dfwd_del_station)(struct net_device___60 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___60 *);
	int (*ndo_set_tx_maxrate)(struct net_device___60 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___60 *);
	int (*ndo_change_proto_down)(struct net_device___60 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___60 *, struct sk_buff___61 *);
	void (*ndo_set_rx_headroom)(struct net_device___60 *, int);
	int (*ndo_bpf)(struct net_device___60 *, struct netdev_bpf___59 *);
	int (*ndo_xdp_xmit)(struct net_device___60 *, int, struct xdp_frame___59 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___60 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___60 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___43 {
	possible_net_t___61 net;
	struct net_device___60 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___43 *);
	void (*neigh_cleanup)(struct neighbour___43 *);
	struct neigh_table___43 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___43 {
	u32 (*l3mdev_fib_table)(const struct net_device___60 *);
	struct sk_buff___61 * (*l3mdev_l3_rcv)(struct net_device___60 *, struct sk_buff___61 *, u16);
	struct sk_buff___61 * (*l3mdev_l3_out)(struct net_device___60 *, struct sock___44 *, struct sk_buff___61 *, u16);
	struct dst_entry___43 * (*l3mdev_link_scope_lookup)(const struct net_device___60 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct tcf_proto___53;

struct mini_Qdisc___53 {
	struct tcf_proto___53 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___53 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___60 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___71 *, struct net_device___60 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___60 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___60 *, struct list_head *);
	size_t (*get_size)(const struct net_device___60 *);
	int (*fill_info)(struct sk_buff___61 *, const struct net_device___60 *);
	size_t (*get_xstats_size)(const struct net_device___60 *);
	int (*fill_xstats)(struct sk_buff___61 *, const struct net_device___60 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___60 *, struct net_device___60 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___60 *, const struct net_device___60 *);
	int (*fill_slave_info)(struct sk_buff___61 *, const struct net_device___60 *, const struct net_device___60 *);
	struct net___71 * (*get_link_net)(const struct net_device___60 *);
	size_t (*get_linkxstats_size)(const struct net_device___60 *, int);
	int (*fill_linkxstats)(struct sk_buff___61 *, const struct net_device___60 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___59 {
	struct list_head poll_list;
	struct sk_buff_head___59 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___59 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___53 *output_queue;
	struct Qdisc___53 **output_queue_tailp;
	struct sk_buff___61 *completion_queue;
	struct sk_buff_head___59 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___59 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___59 input_pkt_queue;
	struct napi_struct___59 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bdi_writeback_congested___208 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___208 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___208 {
	struct bio___208 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___210 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___210 bip_inline_vecs[0];
};

struct bio_set___208 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___208 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___151 {
	struct mem_cgroup___151 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___151 {
	struct lruvec___415 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___151 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___151 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct gnet_dump___53 {
	spinlock_t *lock;
	struct sk_buff___61 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___53;

struct Qdisc_ops___53 {
	struct Qdisc_ops___53 *next;
	const struct Qdisc_class_ops___53 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___61 *, struct Qdisc___53 *, struct sk_buff___61 **);
	struct sk_buff___61 * (*dequeue)(struct Qdisc___53 *);
	struct sk_buff___61 * (*peek)(struct Qdisc___53 *);
	int (*init)(struct Qdisc___53 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___53 *);
	void (*destroy)(struct Qdisc___53 *);
	int (*change)(struct Qdisc___53 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___53 *);
	int (*change_tx_queue_len)(struct Qdisc___53 *, unsigned int);
	int (*dump)(struct Qdisc___53 *, struct sk_buff___61 *);
	int (*dump_stats)(struct Qdisc___53 *, struct gnet_dump___53 *);
	void (*ingress_block_set)(struct Qdisc___53 *, u32);
	void (*egress_block_set)(struct Qdisc___53 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___53 *);
	u32 (*egress_block_get)(struct Qdisc___53 *);
	struct module___344 *owner;
};

struct tcf_block___53;

struct Qdisc_class_ops___53 {
	unsigned int flags;
	struct netdev_queue___59 * (*select_queue)(struct Qdisc___53 *, struct tcmsg *);
	int (*graft)(struct Qdisc___53 *, long unsigned int, struct Qdisc___53 *, struct Qdisc___53 **, struct netlink_ext_ack *);
	struct Qdisc___53 * (*leaf)(struct Qdisc___53 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___53 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___53 *, u32);
	int (*change)(struct Qdisc___53 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___53 *, long unsigned int);
	void (*walk)(struct Qdisc___53 *, struct qdisc_walker *);
	struct tcf_block___53 * (*tcf_block)(struct Qdisc___53 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___53 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___53 *, long unsigned int);
	int (*dump)(struct Qdisc___53 *, long unsigned int, struct sk_buff___61 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___53 *, long unsigned int, struct gnet_dump___53 *);
};

struct tcf_chain___53;

struct tcf_block___53 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___71 *net;
	struct Qdisc___53 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___53 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___53;

struct tcf_proto_ops___53;

struct tcf_proto___53 {
	struct tcf_proto___53 *next;
	void *root;
	int (*classify)(struct sk_buff___61 *, const struct tcf_proto___53 *, struct tcf_result___53 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___53 *ops;
	struct tcf_chain___53 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___53 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___53 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___53 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___61 *, const struct tcf_proto___53 *, struct tcf_result___53 *);
	int (*init)(struct tcf_proto___53 *);
	void (*destroy)(struct tcf_proto___53 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___53 *, u32);
	void (*put)(struct tcf_proto___53 *, void *);
	int (*change)(struct net___71 *, struct sk_buff___61 *, struct tcf_proto___53 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___53 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___53 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___53 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___71 *, struct tcf_chain___53 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___71 *, struct tcf_proto___53 *, void *, struct sk_buff___61 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___61 *, struct net___71 *, void *);
	struct module___344 *owner;
	int flags;
};

struct tcf_chain___53 {
	struct mutex filter_chain_lock;
	struct tcf_proto___53 *filter_chain;
	struct list_head list;
	struct tcf_block___53 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___53 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___43 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___53 *prog;
};

struct bpf_redirect_info___53 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___264 *map;
	struct bpf_map___264 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___43;

struct neigh_hash_table___43;

struct neigh_table___43 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___60 *, __u32 *);
	bool (*key_eq)(const struct neighbour___43 *, const void *);
	int (*constructor)(struct neighbour___43 *);
	int (*pconstructor)(struct pneigh_entry___43 *);
	void (*pdestructor)(struct pneigh_entry___43 *);
	void (*proxy_redo)(struct sk_buff___61 *);
	char *id;
	struct neigh_parms___43 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___59 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___43 *nht;
	struct pneigh_entry___43 **phash_buckets;
};

struct neigh_ops___43 {
	int family;
	void (*solicit)(struct neighbour___43 *, struct sk_buff___61 *);
	void (*error_report)(struct neighbour___43 *, struct sk_buff___61 *);
	int (*output)(struct neighbour___43 *, struct sk_buff___61 *);
	int (*connected_output)(struct neighbour___43 *, struct sk_buff___61 *);
};

struct pneigh_entry___43 {
	struct pneigh_entry___43 *next;
	possible_net_t___61 net;
	struct net_device___60 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___43 {
	struct neighbour___43 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___43 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___43 *ctarget;
	struct net___71 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___43 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___43 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___29;

struct timewait_sock_ops___27;

struct proto___43 {
	void (*close)(struct sock___44 *, long int);
	int (*pre_connect)(struct sock___44 *, struct sockaddr *, int);
	int (*connect)(struct sock___44 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___44 *, int);
	struct sock___44 * (*accept)(struct sock___44 *, int, int *, bool);
	int (*ioctl)(struct sock___44 *, int, long unsigned int);
	int (*init)(struct sock___44 *);
	void (*destroy)(struct sock___44 *);
	void (*shutdown)(struct sock___44 *, int);
	int (*setsockopt)(struct sock___44 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___44 *, int, int, char *, int *);
	void (*keepalive)(struct sock___44 *, int);
	int (*sendmsg)(struct sock___44 *, struct msghdr___46 *, size_t);
	int (*recvmsg)(struct sock___44 *, struct msghdr___46 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___44 *, struct page___415 *, int, size_t, int);
	int (*bind)(struct sock___44 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___44 *, struct sk_buff___61 *);
	void (*release_cb)(struct sock___44 *);
	int (*hash)(struct sock___44 *);
	void (*unhash)(struct sock___44 *);
	void (*rehash)(struct sock___44 *);
	int (*get_port)(struct sock___44 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___44 *);
	bool (*stream_memory_read)(const struct sock___44 *);
	void (*enter_memory_pressure)(struct sock___44 *);
	void (*leave_memory_pressure)(struct sock___44 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___29 *rsk_prot;
	struct timewait_sock_ops___27 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___344 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___44 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct request_sock___30;

struct request_sock_ops___29 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___44 *, struct request_sock___30 *);
	void (*send_ack)(const struct sock___44 *, struct sk_buff___61 *, struct request_sock___30 *);
	void (*send_reset)(const struct sock___44 *, struct sk_buff___61 *);
	void (*destructor)(struct request_sock___30 *);
	void (*syn_ack_timeout)(const struct request_sock___30 *);
};

struct timewait_sock_ops___27 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___44 *, struct sock___44 *, void *);
	void (*twsk_destructor)(struct sock___44 *);
};

struct request_sock___30 {
	struct sock_common___43 __req_common;
	struct request_sock___30 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___29 *rsk_ops;
	struct sock___44 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct sock_diag_req {
	__u8 sdiag_family;
	__u8 sdiag_protocol;
};

struct sock_diag_handler {
	__u8 family;
	int (*dump)(struct sk_buff___61 *, struct nlmsghdr *);
	int (*get_info)(struct sk_buff___61 *, struct sock___44 *);
	int (*destroy)(struct sk_buff___61 *, struct nlmsghdr *);
};

struct broadcast_sk {
	struct sock___44 *sk;
	struct work_struct work;
};

typedef int gifconf_func_t(struct net_device___3 *, char *, int, int);

struct hwtstamp_config {
	int flags;
	int tx_type;
	int rx_filter;
};

enum hwtstamp_tx_types {
	HWTSTAMP_TX_OFF = 0,
	HWTSTAMP_TX_ON = 1,
	HWTSTAMP_TX_ONESTEP_SYNC = 2,
};

enum hwtstamp_rx_filters {
	HWTSTAMP_FILTER_NONE = 0,
	HWTSTAMP_FILTER_ALL = 1,
	HWTSTAMP_FILTER_SOME = 2,
	HWTSTAMP_FILTER_PTP_V1_L4_EVENT = 3,
	HWTSTAMP_FILTER_PTP_V1_L4_SYNC = 4,
	HWTSTAMP_FILTER_PTP_V1_L4_DELAY_REQ = 5,
	HWTSTAMP_FILTER_PTP_V2_L4_EVENT = 6,
	HWTSTAMP_FILTER_PTP_V2_L4_SYNC = 7,
	HWTSTAMP_FILTER_PTP_V2_L4_DELAY_REQ = 8,
	HWTSTAMP_FILTER_PTP_V2_L2_EVENT = 9,
	HWTSTAMP_FILTER_PTP_V2_L2_SYNC = 10,
	HWTSTAMP_FILTER_PTP_V2_L2_DELAY_REQ = 11,
	HWTSTAMP_FILTER_PTP_V2_EVENT = 12,
	HWTSTAMP_FILTER_PTP_V2_SYNC = 13,
	HWTSTAMP_FILTER_PTP_V2_DELAY_REQ = 14,
	HWTSTAMP_FILTER_NTP_ALL = 15,
};

struct tso_t {
	int next_frag_idx;
	void *data;
	size_t size;
	u16 ip_id;
	bool ipv6;
	u32 tcp_seq;
};

struct module___345;

struct file___415;

struct kiocb___415;

struct iov_iter___182;

struct poll_table_struct___258;

struct vm_area_struct___416;

struct inode___415;

struct file_lock___415;

struct page___416;

struct pipe_inode_info___96;

struct seq_file___354;

struct file_operations___415 {
	struct module___345 *owner;
	loff_t (*llseek)(struct file___415 *, loff_t, int);
	ssize_t (*read)(struct file___415 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___415 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___415 *, struct iov_iter___182 *);
	ssize_t (*write_iter)(struct kiocb___415 *, struct iov_iter___182 *);
	int (*iopoll)(struct kiocb___415 *, bool);
	int (*iterate)(struct file___415 *, struct dir_context *);
	int (*iterate_shared)(struct file___415 *, struct dir_context *);
	__poll_t (*poll)(struct file___415 *, struct poll_table_struct___258 *);
	long int (*unlocked_ioctl)(struct file___415 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___415 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___415 *, struct vm_area_struct___416 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___415 *, struct file___415 *);
	int (*flush)(struct file___415 *, fl_owner_t);
	int (*release)(struct inode___415 *, struct file___415 *);
	int (*fsync)(struct file___415 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___415 *, int);
	int (*lock)(struct file___415 *, int, struct file_lock___415 *);
	ssize_t (*sendpage)(struct file___415 *, struct page___416 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___415 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___415 *, int, struct file_lock___415 *);
	ssize_t (*splice_write)(struct pipe_inode_info___96 *, struct file___415 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___415 *, loff_t *, struct pipe_inode_info___96 *, size_t, unsigned int);
	int (*setlease)(struct file___415 *, long int, struct file_lock___415 **, void **);
	long int (*fallocate)(struct file___415 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___354 *, struct file___415 *);
	ssize_t (*copy_file_range)(struct file___415 *, loff_t, struct file___415 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___415 *, loff_t, struct file___415 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___415 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___416 {
	u64 seqnum;
	struct vm_area_struct___416 *vmas[4];
};

struct page_frag___416 {
	struct page___416 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___416;

struct mem_cgroup___152;

struct cred___383;

struct nsproxy___310;

struct signal_struct___290;

struct bio_list___209;

struct backing_dev_info___209;

struct css_set___264;

struct vm_struct___319;

struct task_struct___417 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___417 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___416 *mm;
	struct mm_struct___416 *active_mm;
	struct vmacache___416 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___417 *real_parent;
	struct task_struct___417 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___417 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___152 *active_memcg;
	long int rh_reserved2;
	struct pid___236 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___236 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___236 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___383 *ptracer_cred;
	const struct cred___383 *real_cred;
	const struct cred___383 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___310 *nsproxy;
	struct signal_struct___290 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___417 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___209 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___209 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___264 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___96 *splice_pipe;
	struct page_frag___416 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___152 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___417 *oom_reaper_list;
	struct vm_struct___319 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___154 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rw_semaphore___417 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___417 *owner;
};

struct key___383;

struct ucounts___280;

struct user_namespace___280 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___280 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___29 ns;
	long unsigned int flags;
	struct key___383 *persistent_keyring_register;
	struct rw_semaphore___417 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___280 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct secondary_data___417 {
	void *stack;
	struct task_struct___417 *task;
	long int status;
};

typedef struct page___416 *pgtable_t___416;

struct address_space___415;

struct dev_pagemap___403;

struct page___416 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___415 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___416 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___416 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___416 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___403 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___152 *mem_cgroup;
};

struct pglist_data___416;

struct lruvec___416 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___416 *pgdat;
};

struct zone___416 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___416 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___416 {
	struct zone___416 *zone;
	int zone_idx;
};

struct zonelist___416 {
	struct zoneref___416 _zonerefs[25];
};

struct pglist_data___416 {
	struct zone___416 node_zones[3];
	struct zonelist___416 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___417 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___417 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___416 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___416 {
	struct rw_semaphore___417 rwsem;
	struct notifier_block *head;
};

struct cgroup___264;

struct cgroup_subsys___264;

struct cgroup_subsys_state___264 {
	struct cgroup___264 *cgroup;
	struct cgroup_subsys___264 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___264 *parent;
};

struct kernfs_node___410;

struct cgroup_file___264 {
	struct kernfs_node___410 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___152;

struct mem_cgroup___152 {
	struct cgroup_subsys_state___264 css;
	struct mem_cgroup_id___21 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___264 events_file;
	struct cgroup_file___264 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___417 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___152 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct user_struct___383 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___383 *uid_keyring;
	struct key___383 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___403;

struct vm_area_struct___416 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___416 *vm_next;
	struct vm_area_struct___416 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___416 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___403 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___415 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___416;

struct mm_struct___416 {
	struct {
		struct vm_area_struct___416 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___415 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___417 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___416 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___417 *owner;
		struct user_namespace___280 *user_ns;
		struct file___415 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___416 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___383 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___383 *session_keyring;
	struct key___383 *process_keyring;
	struct key___383 *thread_keyring;
	struct key___383 *request_key_auth;
	void *security;
	struct user_struct___383 *user;
	struct user_namespace___280 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___72;

struct cgroup_namespace___264;

struct nsproxy___310 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net___72 *net_ns;
	struct cgroup_namespace___264 *cgroup_ns;
};

struct signal_struct___290 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___417 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___417 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___236 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___236 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___416 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___236 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___209;

struct bio_list___209 {
	struct bio___209 *head;
	struct bio___209 *tail;
};

struct bdi_writeback_congested___209;

struct bdi_writeback___209 {
	struct backing_dev_info___209 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___209 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___264 *memcg_css;
	struct cgroup_subsys_state___264 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___383;

struct dentry___415;

struct backing_dev_info___209 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___209 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___383 *dev;
	struct device___383 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___415 *debug_dir;
	struct dentry___415 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___264 {
	struct cgroup_subsys_state___264 *subsys[13];
	refcount_t refcount;
	struct css_set___264 *dom_cset;
	struct cgroup___264 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___264 *mg_src_cgrp;
	struct cgroup___264 *mg_dst_cgrp;
	struct css_set___264 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___415;

struct pipe_buffer___96;

struct pipe_inode_info___96 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___416 *tmp_page;
	struct fasync_struct___415 *fasync_readers;
	struct fasync_struct___415 *fasync_writers;
	struct pipe_buffer___96 *bufs;
	struct user_struct___383 *user;
};

struct vm_struct___319 {
	struct vm_struct___319 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___416 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___302 {
	struct task_struct___417 task;
	long unsigned int stack[8192];
};

struct address_space_operations___415;

struct address_space___415 {
	struct inode___415 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___417 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___415 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___403)(struct vm_area_struct___416 *, long unsigned int, const struct page___416 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___403)(struct page___416 *, void *);

struct dev_pagemap___403 {
	dev_page_fault_t___403 page_fault;
	dev_page_free_t___403 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___383 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___416 {
	struct vfsmount *mnt;
	struct dentry___415 *dentry;
};

struct file___415 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___416 f_path;
	struct inode___415 *f_inode;
	const struct file_operations___415 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___236 f_owner;
	const struct cred___383 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___415 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___403;

struct vm_operations_struct___403 {
	void (*open)(struct vm_area_struct___416 *);
	void (*close)(struct vm_area_struct___416 *);
	int (*split)(struct vm_area_struct___416 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___416 *);
	vm_fault_t (*fault)(struct vm_fault___403 *);
	vm_fault_t (*huge_fault)(struct vm_fault___403 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___403 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___416 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___403 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___403 *);
	int (*access)(struct vm_area_struct___416 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___416 *);
	int (*set_policy)(struct vm_area_struct___416 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___416 *, long unsigned int);
	struct page___416 * (*find_special_page)(struct vm_area_struct___416 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___416 {
	struct task_struct___417 *task;
	struct core_thread___416 *next;
};

struct core_state___416 {
	atomic_t nr_threads;
	struct core_thread___416 dumper;
	struct completion startup;
};

struct vm_fault___403 {
	struct vm_area_struct___416 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___416 *cow_page;
	struct mem_cgroup___152 *memcg;
	struct page___416 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___416 prealloc_pte;
};

struct kset___402;

struct kobj_type___402;

struct kobject___403 {
	const char *name;
	struct list_head entry;
	struct kobject___403 *parent;
	struct kset___402 *kset;
	struct kobj_type___402 *ktype;
	struct kernfs_node___410 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___343 {
	struct kobject___403 kobj;
	struct module___345 *mod;
	struct kobject___403 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___343 {
	struct module___345 *mod;
	struct latch_tree_node node;
};

struct module_layout___343 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___343 mtn;
};

struct module_attribute___343;

struct kernel_param___343;

struct module___345 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___343 mkobj;
	struct module_attribute___343 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___403 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___343 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___343 core_layout;
	struct module_layout___343 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bio_vec___211 {
	struct page___416 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___182 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___211 *bvec;
		struct pipe_inode_info___96 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct msghdr___47 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___182 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___415 *msg_iocb;
};

struct kiocb___415 {
	struct file___415 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___415 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dentry_operations___415;

struct super_block___415;

struct dentry___415 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___415 *d_parent;
	struct qstr d_name;
	struct inode___415 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___415 *d_op;
	struct super_block___415 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___415;

struct block_device___415;

struct inode___415 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___415 *i_op;
	struct super_block___415 *i_sb;
	struct address_space___415 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___417 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___209 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___415 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___415 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___96 *i_pipe;
		struct block_device___415 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___415 {
	int (*d_revalidate)(struct dentry___415 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___415 *, unsigned int);
	int (*d_hash)(const struct dentry___415 *, struct qstr *);
	int (*d_compare)(const struct dentry___415 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___415 *);
	int (*d_init)(struct dentry___415 *);
	void (*d_release)(struct dentry___415 *);
	void (*d_prune)(struct dentry___415 *);
	void (*d_iput)(struct dentry___415 *, struct inode___415 *);
	char * (*d_dname)(struct dentry___415 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___416 *);
	int (*d_manage)(const struct path___416 *, bool);
	struct dentry___415 * (*d_real)(struct dentry___415 *, const struct inode___415 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___415;

struct mem_dqinfo___415 {
	struct quota_format_type___415 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___415;

struct quota_info___415 {
	unsigned int flags;
	struct rw_semaphore___417 dqio_sem;
	struct inode___415 *files[3];
	struct mem_dqinfo___415 info[3];
	const struct quota_format_ops___415 *ops[3];
};

struct rcuwait___415 {
	struct task_struct___417 *task;
};

struct percpu_rw_semaphore___415 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___417 rw_sem;
	struct rcuwait___415 writer;
	int readers_block;
};

struct sb_writers___415 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___415 rw_sem[3];
};

struct shrink_control___152;

struct shrinker___152 {
	long unsigned int (*count_objects)(struct shrinker___152 *, struct shrink_control___152 *);
	long unsigned int (*scan_objects)(struct shrinker___152 *, struct shrink_control___152 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___415;

struct super_operations___415;

struct dquot_operations___415;

struct quotactl_ops___415;

struct super_block___415 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___415 *s_type;
	const struct super_operations___415 *s_op;
	const struct dquot_operations___415 *dq_op;
	const struct quotactl_ops___415 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___415 *s_root;
	struct rw_semaphore___417 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___415 *s_bdev;
	struct backing_dev_info___209 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___415 s_dquot;
	struct sb_writers___415 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___415 *s_d_op;
	int cleancache_poolid;
	struct shrinker___152 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___280 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___152 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___152 *memcg;
};

struct iattr___415 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___415 *ia_file;
};

struct dquot___415 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___415 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___415 {
	int qf_fmt_id;
	const struct quota_format_ops___415 *qf_ops;
	struct module___345 *qf_owner;
	struct quota_format_type___415 *qf_next;
};

struct quota_format_ops___415 {
	int (*check_quota_file)(struct super_block___415 *, int);
	int (*read_file_info)(struct super_block___415 *, int);
	int (*write_file_info)(struct super_block___415 *, int);
	int (*free_file_info)(struct super_block___415 *, int);
	int (*read_dqblk)(struct dquot___415 *);
	int (*commit_dqblk)(struct dquot___415 *);
	int (*release_dqblk)(struct dquot___415 *);
	int (*get_next_id)(struct super_block___415 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___415 {
	int (*write_dquot)(struct dquot___415 *);
	struct dquot___415 * (*alloc_dquot)(struct super_block___415 *, int);
	void (*destroy_dquot)(struct dquot___415 *);
	int (*acquire_dquot)(struct dquot___415 *);
	int (*release_dquot)(struct dquot___415 *);
	int (*mark_dirty)(struct dquot___415 *);
	int (*write_info)(struct super_block___415 *, int);
	qsize_t * (*get_reserved_space)(struct inode___415 *);
	int (*get_projid)(struct inode___415 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___415 *, qsize_t *);
	int (*get_next_id)(struct super_block___415 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___415 {
	int (*quota_on)(struct super_block___415 *, int, int, const struct path___416 *);
	int (*quota_off)(struct super_block___415 *, int);
	int (*quota_enable)(struct super_block___415 *, unsigned int);
	int (*quota_disable)(struct super_block___415 *, unsigned int);
	int (*quota_sync)(struct super_block___415 *, int);
	int (*set_info)(struct super_block___415 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___415 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___415 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___415 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___415 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___415 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___172;

struct address_space_operations___415 {
	int (*writepage)(struct page___416 *, struct writeback_control___172 *);
	int (*readpage)(struct file___415 *, struct page___416 *);
	int (*writepages)(struct address_space___415 *, struct writeback_control___172 *);
	int (*set_page_dirty)(struct page___416 *);
	int (*readpages)(struct file___415 *, struct address_space___415 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___415 *, struct address_space___415 *, loff_t, unsigned int, unsigned int, struct page___416 **, void **);
	int (*write_end)(struct file___415 *, struct address_space___415 *, loff_t, unsigned int, unsigned int, struct page___416 *, void *);
	sector_t (*bmap)(struct address_space___415 *, sector_t);
	void (*invalidatepage)(struct page___416 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___416 *, gfp_t);
	void (*freepage)(struct page___416 *);
	ssize_t (*direct_IO)(struct kiocb___415 *, struct iov_iter___182 *);
	int (*migratepage)(struct address_space___415 *, struct page___416 *, struct page___416 *, enum migrate_mode);
	bool (*isolate_page)(struct page___416 *, isolate_mode_t);
	void (*putback_page)(struct page___416 *);
	int (*launder_page)(struct page___416 *);
	int (*is_partially_uptodate)(struct page___416 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___416 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___415 *, struct page___416 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___415 *, sector_t *);
	void (*swap_deactivate)(struct file___415 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___172 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___209 *wb;
	struct inode___415 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___415 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___415 *bd_inode;
	struct super_block___415 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___415 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___209 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___415 {
	struct dentry___415 * (*lookup)(struct inode___415 *, struct dentry___415 *, unsigned int);
	const char * (*get_link)(struct dentry___415 *, struct inode___415 *, struct delayed_call *);
	int (*permission)(struct inode___415 *, int);
	struct posix_acl * (*get_acl)(struct inode___415 *, int);
	int (*readlink)(struct dentry___415 *, char *, int);
	int (*create)(struct inode___415 *, struct dentry___415 *, umode_t, bool);
	int (*link)(struct dentry___415 *, struct inode___415 *, struct dentry___415 *);
	int (*unlink)(struct inode___415 *, struct dentry___415 *);
	int (*symlink)(struct inode___415 *, struct dentry___415 *, const char *);
	int (*mkdir)(struct inode___415 *, struct dentry___415 *, umode_t);
	int (*rmdir)(struct inode___415 *, struct dentry___415 *);
	int (*mknod)(struct inode___415 *, struct dentry___415 *, umode_t, dev_t);
	int (*rename)(struct inode___415 *, struct dentry___415 *, struct inode___415 *, struct dentry___415 *, unsigned int);
	int (*setattr)(struct dentry___415 *, struct iattr___415 *);
	int (*getattr)(const struct path___416 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___415 *, char *, size_t);
	int (*fiemap)(struct inode___415 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___415 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___415 *, struct dentry___415 *, struct file___415 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___415 *, struct dentry___415 *, umode_t);
	int (*set_acl)(struct inode___415 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___415 {
	void (*fl_copy_lock)(struct file_lock___415 *, struct file_lock___415 *);
	void (*fl_release_private)(struct file_lock___415 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___415;

struct file_lock___415 {
	struct file_lock___415 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___415 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___415 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___415 *fl_ops;
	const struct lock_manager_operations___415 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___415 {
	int (*lm_compare_owner)(struct file_lock___415 *, struct file_lock___415 *);
	long unsigned int (*lm_owner_key)(struct file_lock___415 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___415 *);
	int (*lm_grant)(struct file_lock___415 *, int);
	bool (*lm_break)(struct file_lock___415 *);
	int (*lm_change)(struct file_lock___415 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___415 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___415 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___415 *fa_next;
	struct file___415 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___415 {
	const char *name;
	int fs_flags;
	struct dentry___415 * (*mount)(struct file_system_type___415 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___415 *);
	struct module___345 *owner;
	struct file_system_type___415 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___415 {
	struct inode___415 * (*alloc_inode)(struct super_block___415 *);
	void (*destroy_inode)(struct inode___415 *);
	void (*dirty_inode)(struct inode___415 *, int);
	int (*write_inode)(struct inode___415 *, struct writeback_control___172 *);
	int (*drop_inode)(struct inode___415 *);
	void (*evict_inode)(struct inode___415 *);
	void (*put_super)(struct super_block___415 *);
	int (*sync_fs)(struct super_block___415 *, int);
	int (*freeze_super)(struct super_block___415 *);
	int (*freeze_fs)(struct super_block___415 *);
	int (*thaw_super)(struct super_block___415 *);
	int (*unfreeze_fs)(struct super_block___415 *);
	int (*statfs)(struct dentry___415 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___415 *, int *, char *);
	void (*umount_begin)(struct super_block___415 *);
	int (*show_options)(struct seq_file___354 *, struct dentry___415 *);
	int (*show_devname)(struct seq_file___354 *, struct dentry___415 *);
	int (*show_path)(struct seq_file___354 *, struct dentry___415 *);
	int (*show_stats)(struct seq_file___354 *, struct dentry___415 *);
	ssize_t (*quota_read)(struct super_block___415 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___415 *, int, const char *, size_t, loff_t);
	struct dquot___415 ** (*get_dquots)(struct inode___415 *);
	int (*bdev_try_to_free_page)(struct super_block___415 *, struct page___416 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___415 *, struct shrink_control___152 *);
	long int (*free_cached_objects)(struct super_block___415 *, struct shrink_control___152 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___268)(struct file___415 *, wait_queue_head_t *, struct poll_table_struct___258 *);

struct poll_table_struct___258 {
	poll_queue_proc___268 _qproc;
	__poll_t _key;
};

struct seq_operations___354;

struct seq_file___354 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___354 *op;
	int poll_event;
	const struct file___415 *file;
	void *private;
};

typedef void bio_end_io_t___209(struct bio___209 *);

struct bio_integrity_payload___209;

struct bio_set___209;

struct bio___209 {
	struct bio___209 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___209 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___209 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___211 *bi_io_vec;
	struct bio_set___209 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___211 bi_inline_vecs[0];
};

struct socket_wq___45 {
	wait_queue_head_t wait;
	struct fasync_struct___415 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct sock___45;

struct proto_ops___45;

struct socket___46 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___45 *wq;
	struct file___415 *file;
	struct sock___45 *sk;
	const struct proto_ops___45 *ops;
};

typedef struct {
	struct net___72 *net;
} possible_net_t___62;

struct proto___44;

struct sock_common___44 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___44 *skc_prot;
	possible_net_t___62 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___45 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___62;

struct sk_buff_head___60 {
	struct sk_buff___62 *next;
	struct sk_buff___62 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___44;

struct dst_entry___44;

struct net_device___61;

struct sock_reuseport___4;

struct sock___45 {
	struct sock_common___44 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___60 sk_error_queue;
	struct sk_buff_head___60 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___62 *head;
		struct sk_buff___62 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___44 *sk_filter;
	union {
		struct socket_wq___45 *sk_wq;
		struct socket_wq___45 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___44 *sk_rx_dst;
	struct dst_entry___44 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___62 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___60 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___416 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___44 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___236 *sk_peer_pid;
	const struct cred___383 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___46 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___152 *sk_memcg;
	void (*sk_state_change)(struct sock___45 *);
	void (*sk_data_ready)(struct sock___45 *);
	void (*sk_write_space)(struct sock___45 *);
	void (*sk_error_report)(struct sock___45 *);
	int (*sk_backlog_rcv)(struct sock___45 *, struct sk_buff___62 *);
	struct sk_buff___62 * (*sk_validate_xmit_skb)(struct sock___45 *, struct net_device___61 *, struct sk_buff___62 *);
	void (*sk_destruct)(struct sock___45 *);
	struct sock_reuseport___4 *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

typedef int (*sk_read_actor_t___44)(read_descriptor_t *, struct sk_buff___62 *, unsigned int, size_t);

struct proto_ops___45 {
	int family;
	struct module___345 *owner;
	int (*release)(struct socket___46 *);
	int (*bind)(struct socket___46 *, struct sockaddr *, int);
	int (*connect)(struct socket___46 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___46 *, struct socket___46 *);
	int (*accept)(struct socket___46 *, struct socket___46 *, int, bool);
	int (*getname)(struct socket___46 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___415 *, struct socket___46 *, struct poll_table_struct___258 *);
	int (*ioctl)(struct socket___46 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___46 *, int);
	int (*shutdown)(struct socket___46 *, int);
	int (*setsockopt)(struct socket___46 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___46 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___46 *, struct msghdr___47 *, size_t);
	int (*recvmsg)(struct socket___46 *, struct msghdr___47 *, size_t, int);
	int (*mmap)(struct file___415 *, struct socket___46 *, struct vm_area_struct___416 *);
	ssize_t (*sendpage)(struct socket___46 *, struct page___416 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___46 *, loff_t *, struct pipe_inode_info___96 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___45 *, int);
	int (*peek_len)(struct socket___46 *);
	int (*read_sock)(struct sock___45 *, read_descriptor_t *, sk_read_actor_t___44);
	int (*sendpage_locked)(struct sock___45 *, struct page___416 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___45 *, struct msghdr___47 *, size_t);
	int (*set_rcvlowat)(struct sock___45 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct nf_bridge_info___60;

struct sk_buff___62 {
	union {
		struct {
			struct sk_buff___62 *next;
			struct sk_buff___62 *prev;
			union {
				struct net_device___61 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___45 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___62 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___60 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___60;

struct netns_frags___60 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___60 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_rules_ops___44;

struct fib_notifier_ops___44;

struct netns_ipv4___60 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___44 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___45 *fibnl;
	struct sock___45 **icmp_sk;
	struct sock___45 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___45 **tcp_sk;
	struct netns_frags___60 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___44 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___44 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___44 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___44;

struct dst_ops___71 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___71 *);
	struct dst_entry___44 * (*check)(struct dst_entry___44 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___44 *);
	unsigned int (*mtu)(const struct dst_entry___44 *);
	u32 * (*cow_metrics)(struct dst_entry___44 *, long unsigned int);
	void (*destroy)(struct dst_entry___44 *);
	void (*ifdown)(struct dst_entry___44 *, struct net_device___61 *, int);
	struct dst_entry___44 * (*negative_advice)(struct dst_entry___44 *);
	void (*link_failure)(struct sk_buff___62 *);
	void (*update_pmtu)(struct dst_entry___44 *, struct sock___45 *, struct sk_buff___62 *, u32);
	void (*redirect)(struct dst_entry___44 *, struct sock___45 *, struct sk_buff___62 *);
	int (*local_out)(struct net___72 *, struct sock___45 *, struct sk_buff___62 *);
	struct neighbour___44 * (*neigh_lookup)(const struct dst_entry___44 *, struct sk_buff___62 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___44 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___71 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___60 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___71 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___44 *fib6_rules_ops;
	struct sock___45 **icmp_sk;
	struct sock___45 *ndisc_sk;
	struct sock___45 *tcp_sk;
	struct sock___45 *igmp_sk;
	struct sock___45 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___44 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___44 *notifier_ops;
	struct fib_notifier_ops___44 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___45 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___45 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___60 {
	struct netns_frags___60 frags;
};

struct netns_xfrm___71 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___45 *nlsk;
	struct sock___45 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___71 xfrm4_dst_ops;
	struct dst_ops___71 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___54;

struct net___72 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___280 *user_ns;
	struct ucounts___280 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___29 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___45 *rtnl;
	struct sock___45 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___61 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___60 ipv4;
	struct netns_ipv6___71 ipv6;
	struct netns_sctp___45 sctp;
	struct netns_nf___4 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___60 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___45 *nfnl;
	struct sock___45 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___71 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___45 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___54 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kernfs_root___409;

struct kernfs_elem_dir___409 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___409 *root;
};

struct kernfs_syscall_ops___409;

struct kernfs_root___409 {
	struct kernfs_node___410 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___409 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___409 {
	struct kernfs_node___410 *target_kn;
};

struct kernfs_ops___409;

struct kernfs_elem_attr___409 {
	const struct kernfs_ops___409 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___410 *notify_next;
};

struct kernfs_node___410 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___410 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___409 dir;
		struct kernfs_elem_symlink___409 symlink;
		struct kernfs_elem_attr___409 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___409;

struct kernfs_ops___409 {
	int (*open)(struct kernfs_open_file___409 *);
	void (*release)(struct kernfs_open_file___409 *);
	int (*seq_show)(struct seq_file___354 *, void *);
	void * (*seq_start)(struct seq_file___354 *, loff_t *);
	void * (*seq_next)(struct seq_file___354 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___354 *, void *);
	ssize_t (*read)(struct kernfs_open_file___409 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___409 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___409 *, struct vm_area_struct___416 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___409 *, struct poll_table_struct___258 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___409 {
	int (*remount_fs)(struct kernfs_root___409 *, int *, char *);
	int (*show_options)(struct seq_file___354 *, struct kernfs_root___409 *);
	int (*mkdir)(struct kernfs_node___410 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___410 *);
	int (*rename)(struct kernfs_node___410 *, struct kernfs_node___410 *, const char *);
	int (*show_path)(struct seq_file___354 *, struct kernfs_node___410 *, struct kernfs_root___409 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___409 {
	struct kernfs_node___410 *kn;
	struct file___415 *file;
	struct seq_file___354 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___403 *vm_ops;
};

struct kobj_ns_type_operations___44 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___45 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___379;

struct attribute_group___380 {
	const char *name;
	umode_t (*is_visible)(struct kobject___403 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___403 *, struct bin_attribute___379 *, int);
	struct attribute **attrs;
	struct bin_attribute___379 **bin_attrs;
};

struct bin_attribute___379 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___415 *, struct kobject___403 *, struct bin_attribute___379 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___415 *, struct kobject___403 *, struct bin_attribute___379 *, char *, loff_t, size_t);
	int (*mmap)(struct file___415 *, struct kobject___403 *, struct bin_attribute___379 *, struct vm_area_struct___416 *);
};

struct sysfs_ops___402 {
	ssize_t (*show)(struct kobject___403 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___403 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___402;

struct kset___402 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___403 kobj;
	const struct kset_uevent_ops___402 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___402 {
	void (*release)(struct kobject___403 *);
	const struct sysfs_ops___402 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___44 * (*child_ns_type)(struct kobject___403 *);
	const void * (*namespace)(struct kobject___403 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___402 {
	int (* const filter)(struct kset___402 *, struct kobject___403 *);
	const char * (* const name)(struct kset___402 *, struct kobject___403 *);
	int (* const uevent)(struct kset___402 *, struct kobject___403 *, struct kobj_uevent_env *);
};

struct kobj_attribute___393 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___403 *, struct kobj_attribute___393 *, char *);
	ssize_t (*store)(struct kobject___403 *, struct kobj_attribute___393 *, const char *, size_t);
};

struct dev_pm_ops___383 {
	int (*prepare)(struct device___383 *);
	void (*complete)(struct device___383 *);
	int (*suspend)(struct device___383 *);
	int (*resume)(struct device___383 *);
	int (*freeze)(struct device___383 *);
	int (*thaw)(struct device___383 *);
	int (*poweroff)(struct device___383 *);
	int (*restore)(struct device___383 *);
	int (*suspend_late)(struct device___383 *);
	int (*resume_early)(struct device___383 *);
	int (*freeze_late)(struct device___383 *);
	int (*thaw_early)(struct device___383 *);
	int (*poweroff_late)(struct device___383 *);
	int (*restore_early)(struct device___383 *);
	int (*suspend_noirq)(struct device___383 *);
	int (*resume_noirq)(struct device___383 *);
	int (*freeze_noirq)(struct device___383 *);
	int (*thaw_noirq)(struct device___383 *);
	int (*poweroff_noirq)(struct device___383 *);
	int (*restore_noirq)(struct device___383 *);
	int (*runtime_suspend)(struct device___383 *);
	int (*runtime_resume)(struct device___383 *);
	int (*runtime_idle)(struct device___383 *);
};

struct dev_pm_info___383 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___383 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___383;

struct bus_type___383;

struct device_driver___383;

struct dev_pm_domain___383;

struct dma_map_ops___155;

struct fwnode_handle___303;

struct class___383;

struct device___383 {
	struct device___383 *parent;
	struct device_private *p;
	struct kobject___403 kobj;
	const char *init_name;
	const struct device_type___383 *type;
	struct mutex mutex;
	struct bus_type___383 *bus;
	struct device_driver___383 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___383 power;
	struct dev_pm_domain___383 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___155 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___303 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___383 *class;
	const struct attribute_group___380 **groups;
	void (*release)(struct device___383 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___383 {
	struct dev_pm_ops___383 ops;
	void (*detach)(struct device___383 *, bool);
	int (*activate)(struct device___383 *);
	void (*sync)(struct device___383 *);
	void (*dismiss)(struct device___383 *);
};

struct bus_type___383 {
	const char *name;
	const char *dev_name;
	struct device___383 *dev_root;
	const struct attribute_group___380 **bus_groups;
	const struct attribute_group___380 **dev_groups;
	const struct attribute_group___380 **drv_groups;
	int (*match)(struct device___383 *, struct device_driver___383 *);
	int (*uevent)(struct device___383 *, struct kobj_uevent_env *);
	int (*probe)(struct device___383 *);
	int (*remove)(struct device___383 *);
	void (*shutdown)(struct device___383 *);
	int (*online)(struct device___383 *);
	int (*offline)(struct device___383 *);
	int (*suspend)(struct device___383 *, pm_message_t);
	int (*resume)(struct device___383 *);
	int (*num_vf)(struct device___383 *);
	int (*dma_configure)(struct device___383 *);
	const struct dev_pm_ops___383 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___383 {
	const char *name;
	struct bus_type___383 *bus;
	struct module___345 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___383 *);
	int (*remove)(struct device___383 *);
	void (*shutdown)(struct device___383 *);
	int (*suspend)(struct device___383 *, pm_message_t);
	int (*resume)(struct device___383 *);
	const struct attribute_group___380 **groups;
	const struct dev_pm_ops___383 *pm;
	void (*coredump)(struct device___383 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___383 {
	const char *name;
	const struct attribute_group___380 **groups;
	int (*uevent)(struct device___383 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___383 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___383 *);
	const struct dev_pm_ops___383 *pm;
};

struct class___383 {
	const char *name;
	struct module___345 *owner;
	const struct attribute_group___380 **class_groups;
	const struct attribute_group___380 **dev_groups;
	struct kobject___403 *dev_kobj;
	int (*dev_uevent)(struct device___383 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___383 *, umode_t *);
	void (*class_release)(struct class___383 *);
	void (*dev_release)(struct device___383 *);
	int (*shutdown_pre)(struct device___383 *);
	const struct kobj_ns_type_operations___44 *ns_type;
	const void * (*namespace)(struct device___383 *);
	const struct dev_pm_ops___383 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___155 {
	void * (*alloc)(struct device___383 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___383 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___383 *, struct vm_area_struct___416 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___383 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___383 *, struct page___416 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___383 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___383 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___383 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___383 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___383 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___383 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___383 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___383 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___383 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___383 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___383 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___383 *, u64);
	u64 (*get_required_mask)(struct device___383 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___303;

struct fwnode_handle___303 {
	struct fwnode_handle___303 *secondary;
	const struct fwnode_operations___303 *ops;
};

typedef void compound_page_dtor___403(struct page___416 *);

struct fwnode_reference_args___303;

struct fwnode_endpoint___303;

struct fwnode_operations___303 {
	struct fwnode_handle___303 * (*get)(struct fwnode_handle___303 *);
	void (*put)(struct fwnode_handle___303 *);
	bool (*device_is_available)(const struct fwnode_handle___303 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___303 *, const struct device___383 *);
	bool (*property_present)(const struct fwnode_handle___303 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___303 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___303 *, const char *, const char **, size_t);
	struct fwnode_handle___303 * (*get_parent)(const struct fwnode_handle___303 *);
	struct fwnode_handle___303 * (*get_next_child_node)(const struct fwnode_handle___303 *, struct fwnode_handle___303 *);
	struct fwnode_handle___303 * (*get_named_child_node)(const struct fwnode_handle___303 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___303 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___303 *);
	struct fwnode_handle___303 * (*graph_get_next_endpoint)(const struct fwnode_handle___303 *, struct fwnode_handle___303 *);
	struct fwnode_handle___303 * (*graph_get_remote_endpoint)(const struct fwnode_handle___303 *);
	struct fwnode_handle___303 * (*graph_get_port_parent)(struct fwnode_handle___303 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___303 *, struct fwnode_endpoint___303 *);
};

struct fwnode_endpoint___303 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___303 *local_fwnode;
};

struct fwnode_reference_args___303 {
	struct fwnode_handle___303 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___96;

struct pipe_buffer___96 {
	struct page___416 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___96 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___96 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___96 *, struct pipe_buffer___96 *);
	void (*release)(struct pipe_inode_info___96 *, struct pipe_buffer___96 *);
	int (*steal)(struct pipe_inode_info___96 *, struct pipe_buffer___96 *);
	union {
		bool (*get)(struct pipe_inode_info___96 *, struct pipe_buffer___96 *);
		struct {
			void (*get)(struct pipe_inode_info___96 *, struct pipe_buffer___96 *);
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
};

struct nf_bridge_info___60 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___60 = 0,
		BRNF_PROTO_8021Q___60 = 1,
		BRNF_PROTO_PPPOE___60 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___61 *physindev;
	struct net_device___61 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___60(struct sk_buff___62 **);

struct net_device_ops___60;

struct ethtool_ops___60;

struct l3mdev_ops___44;

struct xfrmdev_ops___60;

struct tlsdev_ops___60;

struct header_ops___60;

struct netdev_rx_queue___60;

struct mini_Qdisc___54;

struct netdev_queue___60;

struct Qdisc___54;

struct rtnl_link_ops___54;

struct dcbnl_rtnl_ops___60;

struct net_device___61 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___60 *netdev_ops;
	const struct ethtool_ops___60 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___44 *l3mdev_ops;
	const struct ndisc_ops___2 *ndisc_ops;
	const struct xfrmdev_ops___60 *xfrmdev_ops;
	const struct tlsdev_ops___60 *tlsdev_ops;
	const struct header_ops___60 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___402 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___2 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___60 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___54 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___60 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___54 *miniq_ingress;
	struct netdev_queue___60 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___60 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___54 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___54 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___60 = 0,
		NETREG_REGISTERED___60 = 1,
		NETREG_UNREGISTERING___60 = 2,
		NETREG_UNREGISTERED___60 = 3,
		NETREG_RELEASED___60 = 4,
		NETREG_DUMMY___60 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___60 = 0,
		RTNL_LINK_INITIALIZING___60 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___61 *);
	struct netpoll_info *npinfo;
	possible_net_t___62 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___383 dev;
	const struct attribute_group___380 *sysfs_groups[4];
	const struct attribute_group___380 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___54 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___60 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide35;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct kernel_param_ops___343 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___343 *);
	int (*get)(char *, const struct kernel_param___343 *);
	void (*free)(void *);
};

struct kparam_array___343;

struct kernel_param___343 {
	const char *name;
	struct module___345 *mod;
	const struct kernel_param_ops___343 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___343 *arr;
	};
};

struct kparam_array___343 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___343 *ops;
	void *elem;
};

struct module_attribute___343 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___343 *, struct module_kobject___343 *, char *);
	ssize_t (*store)(struct module_attribute___343 *, struct module_kobject___343 *, const char *, size_t);
	void (*setup)(struct module___345 *, const char *);
	int (*test)(struct module___345 *);
	void (*free)(struct module___345 *);
};

struct ethtool_ops___60 {
	int (*get_settings)(struct net_device___61 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___61 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___61 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___61 *);
	void (*get_regs)(struct net_device___61 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___61 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___61 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___61 *);
	void (*set_msglevel)(struct net_device___61 *, u32);
	int (*nway_reset)(struct net_device___61 *);
	u32 (*get_link)(struct net_device___61 *);
	int (*get_eeprom_len)(struct net_device___61 *);
	int (*get_eeprom)(struct net_device___61 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___61 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___61 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___61 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___61 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___61 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___61 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___61 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___61 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___61 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___61 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___61 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___61 *);
	void (*complete)(struct net_device___61 *);
	u32 (*get_priv_flags)(struct net_device___61 *);
	int (*set_priv_flags)(struct net_device___61 *, u32);
	int (*get_sset_count)(struct net_device___61 *, int);
	int (*get_rxnfc)(struct net_device___61 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___61 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___61 *, struct ethtool_flash *);
	int (*reset)(struct net_device___61 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___61 *);
	u32 (*get_rxfh_indir_size)(struct net_device___61 *);
	int (*get_rxfh)(struct net_device___61 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___61 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___61 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___61 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___61 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___61 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___61 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___61 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___61 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___61 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___61 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___61 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___61 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___61 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___61 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___61 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___61 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___61 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___61 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___61 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___61 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___61 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	int (*get_fecparam)(struct net_device___61 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___61 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___61 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___61 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___61 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___60;

struct inet_frags___60 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___60 *, const void *);
	void (*destructor)(struct inet_frag_queue___60 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___60 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___62 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___62 *fragments_tail;
	struct sk_buff___62 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___60 *net;
	struct callback_head rcu;
};

struct fib_rule___44;

struct fib_lookup_arg___44;

struct fib_rules_ops___44 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___44 *, struct flowi *, int, struct fib_lookup_arg___44 *);
	bool (*suppress)(struct fib_rule___44 *, struct fib_lookup_arg___44 *);
	int (*match)(struct fib_rule___44 *, struct flowi *, int);
	int (*configure)(struct fib_rule___44 *, struct sk_buff___62 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___44 *);
	int (*compare)(struct fib_rule___44 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___44 *, struct sk_buff___62 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___44 *);
	void (*flush_cache)(struct fib_rules_ops___44 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___345 *owner;
	struct net___72 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___44 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___72 *);
	int (*fib_dump)(struct net___72 *, struct notifier_block *);
	struct module___345 *owner;
	struct callback_head rcu;
};

struct dst_entry___44 {
	struct net_device___61 *dev;
	struct dst_ops___71 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___62 *);
	int (*output)(struct net___72 *, struct sock___45 *, struct sk_buff___62 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___44;

struct neigh_parms___44;

struct neigh_ops___44;

struct neighbour___44 {
	struct neighbour___44 *next;
	struct neigh_table___44 *tbl;
	struct neigh_parms___44 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___60 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___44 *, struct sk_buff___62 *);
	const struct neigh_ops___44 *ops;
	struct callback_head rcu;
	struct net_device___61 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct ucounts___280 {
	struct hlist_node node;
	struct user_namespace___280 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_prog_aux___57;

struct bpf_prog___54 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___57 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

typedef int (*key_restrict_link_func_t___384)(struct key___383 *, const struct key_type *, const union key_payload *, struct key___383 *);

struct key_restriction___383;

struct key___383 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___417 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___383 *restrict_link;
};

struct key_restriction___383 {
	key_restrict_link_func_t___384 check;
	struct key___383 *key;
	struct key_type *keytype;
};

struct seq_operations___354 {
	void * (*start)(struct seq_file___354 *, loff_t *);
	void (*stop)(struct seq_file___354 *, void *);
	void * (*next)(struct seq_file___354 *, void *, loff_t *);
	int (*show)(struct seq_file___354 *, void *);
};

struct pernet_operations___61 {
	struct list_head list;
	int (*init)(struct net___72 *);
	void (*exit)(struct net___72 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___60 {
	int (*ieee_getets)(struct net_device___61 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___61 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___61 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___61 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___61 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___61 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___61 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___61 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___61 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___61 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___61 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___61 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___61 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___61 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___61 *);
	u8 (*setstate)(struct net_device___61 *, u8);
	void (*getpermhwaddr)(struct net_device___61 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___61 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___61 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___61 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___61 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___61 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___61 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___61 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___61 *, int, u8 *);
	void (*setpfccfg)(struct net_device___61 *, int, u8);
	void (*getpfccfg)(struct net_device___61 *, int, u8 *);
	u8 (*setall)(struct net_device___61 *);
	u8 (*getcap)(struct net_device___61 *, int, u8 *);
	int (*getnumtcs)(struct net_device___61 *, int, u8 *);
	int (*setnumtcs)(struct net_device___61 *, int, u8);
	u8 (*getpfcstate)(struct net_device___61 *);
	void (*setpfcstate)(struct net_device___61 *, u8);
	void (*getbcncfg)(struct net_device___61 *, int, u32 *);
	void (*setbcncfg)(struct net_device___61 *, int, u32);
	void (*getbcnrp)(struct net_device___61 *, int, u8 *);
	void (*setbcnrp)(struct net_device___61 *, int, u8);
	int (*setapp)(struct net_device___61 *, u8, u16, u8);
	int (*getapp)(struct net_device___61 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___61 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___61 *, int, u8);
	u8 (*getdcbx)(struct net_device___61 *);
	u8 (*setdcbx)(struct net_device___61 *, u8);
	int (*peer_getappinfo)(struct net_device___61 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___61 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___61 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___61 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___61 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___61 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___264 {
	refcount_t count;
	struct ns_common___29 ns;
	struct user_namespace___280 *user_ns;
	struct ucounts___280 *ucounts;
	struct css_set___264 *root_cset;
};

struct bpf_map___265;

struct bpf_map_ops___264 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___265 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___265 *, struct file___415 *);
	void (*map_free)(struct bpf_map___265 *);
	int (*map_get_next_key)(struct bpf_map___265 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___265 *);
	void * (*map_lookup_elem)(struct bpf_map___265 *, void *);
	int (*map_update_elem)(struct bpf_map___265 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___265 *, void *);
	int (*map_push_elem)(struct bpf_map___265 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___265 *, void *);
	int (*map_peek_elem)(struct bpf_map___265 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___265 *, struct file___415 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___265 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___265 *, void *, struct seq_file___354 *);
	int (*map_check_btf)(const struct bpf_map___265 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___265 {
	const struct bpf_map_ops___264 *ops;
	struct bpf_map___265 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___383 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___60;

struct bpf_map_dev_ops___60 {
	int (*map_get_next_key)(struct bpf_offloaded_map___60 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___60 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___60 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___60 *, void *);
};

struct bpf_offloaded_map___60 {
	struct bpf_map___265 map;
	struct net_device___61 *netdev;
	const struct bpf_map_dev_ops___60 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___54 {
	int (*test_run)(struct bpf_prog___54 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___54 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___54 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___54 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___54 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___54 *, u32 *);
};

struct bpf_prog_offload_ops___54 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___54 *);
	int (*translate)(struct bpf_prog___54 *);
	void (*destroy)(struct bpf_prog___54 *);
};

struct bpf_prog_offload___54 {
	struct bpf_prog___54 *prog;
	struct net_device___61 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___54 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___57 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___54 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___54 *ops;
	struct bpf_map___265 **used_maps;
	struct bpf_prog___54 *prog;
	struct user_struct___383 *user;
	u64 load_time;
	struct bpf_map___265 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___54 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___54 {
	struct bpf_prog___54 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___54 {
	struct callback_head rcu;
	struct bpf_prog_array_item___54 items[0];
};

struct cgroup_bpf___54 {
	struct bpf_prog_array___54 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___54 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___265;

typedef void (*kthread_work_func_t___265)(struct kthread_work___265 *);

struct kthread_worker___265;

struct kthread_work___265 {
	struct list_head node;
	kthread_work_func_t___265 func;
	struct kthread_worker___265 *worker;
	int canceling;
};

struct kthread_worker___265 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___417 *task;
	struct kthread_work___265 *current_work;
};

struct kthread_delayed_work___264 {
	struct kthread_work___265 work;
	struct timer_list timer;
};

struct psi_group___264 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___265 *poll_kworker;
	struct kthread_delayed_work___264 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___264;

struct cgroup_rstat_cpu___264;

struct cgroup___264 {
	struct cgroup_subsys_state___264 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___410 *kn;
	struct cgroup_file___264 procs_file;
	struct cgroup_file___264 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___264 *subsys[13];
	struct cgroup_root___264 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___264 *dom_cgrp;
	struct cgroup_rstat_cpu___264 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___54 bpf;
	atomic_t congestion_count;
	struct cgroup___264 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___264 psi;
	int ancestor_ids[0];
};

struct cftype___264;

struct cgroup_subsys___264 {
	struct cgroup_subsys_state___264 * (*css_alloc)(struct cgroup_subsys_state___264 *);
	int (*css_online)(struct cgroup_subsys_state___264 *);
	void (*css_offline)(struct cgroup_subsys_state___264 *);
	void (*css_released)(struct cgroup_subsys_state___264 *);
	void (*css_free)(struct cgroup_subsys_state___264 *);
	void (*css_reset)(struct cgroup_subsys_state___264 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___264 *, int);
	int (*css_extra_stat_show)(struct seq_file___354 *, struct cgroup_subsys_state___264 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___417 *);
	void (*cancel_fork)(struct task_struct___417 *);
	void (*fork)(struct task_struct___417 *);
	void (*exit)(struct task_struct___417 *);
	void (*free)(struct task_struct___417 *);
	void (*bind)(struct cgroup_subsys_state___264 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___264 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___264 *dfl_cftypes;
	struct cftype___264 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___264 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___264 *updated_children;
	struct cgroup___264 *updated_next;
};

struct cgroup_root___264 {
	struct kernfs_root___409 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___264 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___264 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___264 *ss;
	struct list_head node;
	struct kernfs_ops___409 *kf_ops;
	int (*open)(struct kernfs_open_file___409 *);
	void (*release)(struct kernfs_open_file___409 *);
	u64 (*read_u64)(struct cgroup_subsys_state___264 *, struct cftype___264 *);
	s64 (*read_s64)(struct cgroup_subsys_state___264 *, struct cftype___264 *);
	int (*seq_show)(struct seq_file___354 *, void *);
	void * (*seq_start)(struct seq_file___354 *, loff_t *);
	void * (*seq_next)(struct seq_file___354 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___354 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___264 *, struct cftype___264 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___264 *, struct cftype___264 *, s64);
	ssize_t (*write)(struct kernfs_open_file___409 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___409 *, struct poll_table_struct___258 *);
};

struct xdp_rxq_info___60 {
	struct net_device___61 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___60 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___61 *dev_rx;
};

struct netlink_callback___62 {
	struct sk_buff___62 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___62 *);
	int (*dump)(struct sk_buff___62 *, struct netlink_callback___62 *);
	int (*done)(struct netlink_callback___62 *);
	void *data;
	struct module___345 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___60 {
	int (*create)(struct sk_buff___62 *, struct net_device___61 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___62 *, unsigned char *);
	int (*cache)(const struct neighbour___44 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___61 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___60 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___60 *, int);
	int poll_owner;
	struct net_device___61 *dev;
	struct sk_buff___62 *gro_list;
	struct sk_buff___62 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___60 {
	struct net_device___61 *dev;
	struct Qdisc___54 *qdisc;
	struct Qdisc___54 *qdisc_sleeping;
	struct kobject___403 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___61 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem___3 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___54 {
	struct sk_buff___62 *head;
	struct sk_buff___62 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___54;

struct Qdisc___54 {
	int (*enqueue)(struct sk_buff___62 *, struct Qdisc___54 *, struct sk_buff___62 **);
	struct sk_buff___62 * (*dequeue)(struct Qdisc___54 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___54 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___60 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___60 gso_skb;
	struct qdisc_skb_head___54 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___54 *next_sched;
	struct sk_buff_head___60 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___60 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___403 kobj;
	struct net_device___61 *dev;
	long: 64;
	struct xdp_rxq_info___60 xdp_rxq;
	union {
		struct xdp_umem___3 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___60)(struct net_device___61 *, struct sk_buff___62 *, struct net_device___61 *);

struct netdev_bpf___60 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___54 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___54 *prog;
			const struct bpf_prog_offload_ops___54 *ops;
		} verifier;
		struct {
			struct bpf_prog___54 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___60 *offmap;
		};
		struct {
			struct xdp_umem___3 *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___60 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___62 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___60 {
	int (*tls_dev_add)(struct net_device___61 *, struct sock___45 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___61 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___61 *, struct sock___45 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___60 {
	int (*ndo_init)(struct net_device___61 *);
	void (*ndo_uninit)(struct net_device___61 *);
	int (*ndo_open)(struct net_device___61 *);
	int (*ndo_stop)(struct net_device___61 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___62 *, struct net_device___61 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___62 *, struct net_device___61 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___61 *, struct sk_buff___62 *, struct net_device___61 *, select_queue_fallback_t___60);
	void (*ndo_change_rx_flags)(struct net_device___61 *, int);
	void (*ndo_set_rx_mode)(struct net_device___61 *);
	int (*ndo_set_mac_address)(struct net_device___61 *, void *);
	int (*ndo_validate_addr)(struct net_device___61 *);
	int (*ndo_do_ioctl)(struct net_device___61 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___61 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___61 *, int);
	int (*ndo_neigh_setup)(struct net_device___61 *, struct neigh_parms___44 *);
	void (*ndo_tx_timeout)(struct net_device___61 *);
	void (*ndo_get_stats64)(struct net_device___61 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___61 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___61 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___61 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___61 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___61 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___61 *);
	int (*ndo_netpoll_setup)(struct net_device___61 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___61 *);
	int (*ndo_set_vf_mac)(struct net_device___61 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___61 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___61 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___61 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___61 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___61 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___61 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___61 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___61 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___61 *, int, struct sk_buff___62 *);
	int (*ndo_set_vf_guid)(struct net_device___61 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___61 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___61 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___61 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___61 *, const struct sk_buff___62 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___61 *, struct net_device___61 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___61 *, struct net_device___61 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___61 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___61 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___61 *, struct neighbour___44 *);
	void (*ndo_neigh_destroy)(struct net_device___61 *, struct neighbour___44 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___61 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___61 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___61 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___62 *, struct netlink_callback___62 *, struct net_device___61 *, struct net_device___61 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___61 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___61 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___62 *, u32, u32, struct net_device___61 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___61 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___61 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___61 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___61 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___61 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___61 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___61 *, struct net_device___61 *);
	void (*ndo_dfwd_del_station)(struct net_device___61 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___61 *);
	int (*ndo_set_tx_maxrate)(struct net_device___61 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___61 *);
	int (*ndo_change_proto_down)(struct net_device___61 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___61 *, struct sk_buff___62 *);
	void (*ndo_set_rx_headroom)(struct net_device___61 *, int);
	int (*ndo_bpf)(struct net_device___61 *, struct netdev_bpf___60 *);
	int (*ndo_xdp_xmit)(struct net_device___61 *, int, struct xdp_frame___60 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___61 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___61 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___44 {
	possible_net_t___62 net;
	struct net_device___61 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___44 *);
	void (*neigh_cleanup)(struct neighbour___44 *);
	struct neigh_table___44 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___44 {
	u32 (*l3mdev_fib_table)(const struct net_device___61 *);
	struct sk_buff___62 * (*l3mdev_l3_rcv)(struct net_device___61 *, struct sk_buff___62 *, u16);
	struct sk_buff___62 * (*l3mdev_l3_out)(struct net_device___61 *, struct sock___45 *, struct sk_buff___62 *, u16);
	struct dst_entry___44 * (*l3mdev_link_scope_lookup)(const struct net_device___61 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct tcf_proto___54;

struct mini_Qdisc___54 {
	struct tcf_proto___54 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___54 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___61 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___72 *, struct net_device___61 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___61 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___61 *, struct list_head *);
	size_t (*get_size)(const struct net_device___61 *);
	int (*fill_info)(struct sk_buff___62 *, const struct net_device___61 *);
	size_t (*get_xstats_size)(const struct net_device___61 *);
	int (*fill_xstats)(struct sk_buff___62 *, const struct net_device___61 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___61 *, struct net_device___61 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___61 *, const struct net_device___61 *);
	int (*fill_slave_info)(struct sk_buff___62 *, const struct net_device___61 *, const struct net_device___61 *);
	struct net___72 * (*get_link_net)(const struct net_device___61 *);
	size_t (*get_linkxstats_size)(const struct net_device___61 *, int);
	int (*fill_linkxstats)(struct sk_buff___62 *, const struct net_device___61 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___60 {
	struct list_head poll_list;
	struct sk_buff_head___60 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___60 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___54 *output_queue;
	struct Qdisc___54 **output_queue_tailp;
	struct sk_buff___62 *completion_queue;
	struct sk_buff_head___60 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___60 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___60 input_pkt_queue;
	struct napi_struct___60 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct gnet_dump___54 {
	spinlock_t *lock;
	struct sk_buff___62 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___54;

struct Qdisc_ops___54 {
	struct Qdisc_ops___54 *next;
	const struct Qdisc_class_ops___54 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___62 *, struct Qdisc___54 *, struct sk_buff___62 **);
	struct sk_buff___62 * (*dequeue)(struct Qdisc___54 *);
	struct sk_buff___62 * (*peek)(struct Qdisc___54 *);
	int (*init)(struct Qdisc___54 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___54 *);
	void (*destroy)(struct Qdisc___54 *);
	int (*change)(struct Qdisc___54 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___54 *);
	int (*change_tx_queue_len)(struct Qdisc___54 *, unsigned int);
	int (*dump)(struct Qdisc___54 *, struct sk_buff___62 *);
	int (*dump_stats)(struct Qdisc___54 *, struct gnet_dump___54 *);
	void (*ingress_block_set)(struct Qdisc___54 *, u32);
	void (*egress_block_set)(struct Qdisc___54 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___54 *);
	u32 (*egress_block_get)(struct Qdisc___54 *);
	struct module___345 *owner;
};

struct tcf_block___54;

struct Qdisc_class_ops___54 {
	unsigned int flags;
	struct netdev_queue___60 * (*select_queue)(struct Qdisc___54 *, struct tcmsg *);
	int (*graft)(struct Qdisc___54 *, long unsigned int, struct Qdisc___54 *, struct Qdisc___54 **, struct netlink_ext_ack *);
	struct Qdisc___54 * (*leaf)(struct Qdisc___54 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___54 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___54 *, u32);
	int (*change)(struct Qdisc___54 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___54 *, long unsigned int);
	void (*walk)(struct Qdisc___54 *, struct qdisc_walker *);
	struct tcf_block___54 * (*tcf_block)(struct Qdisc___54 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___54 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___54 *, long unsigned int);
	int (*dump)(struct Qdisc___54 *, long unsigned int, struct sk_buff___62 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___54 *, long unsigned int, struct gnet_dump___54 *);
};

struct tcf_chain___54;

struct tcf_block___54 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___72 *net;
	struct Qdisc___54 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___54 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___54;

struct tcf_proto_ops___54;

struct tcf_proto___54 {
	struct tcf_proto___54 *next;
	void *root;
	int (*classify)(struct sk_buff___62 *, const struct tcf_proto___54 *, struct tcf_result___54 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___54 *ops;
	struct tcf_chain___54 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___54 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___54 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___54 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___62 *, const struct tcf_proto___54 *, struct tcf_result___54 *);
	int (*init)(struct tcf_proto___54 *);
	void (*destroy)(struct tcf_proto___54 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___54 *, u32);
	void (*put)(struct tcf_proto___54 *, void *);
	int (*change)(struct net___72 *, struct sk_buff___62 *, struct tcf_proto___54 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___54 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___54 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___54 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___72 *, struct tcf_chain___54 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___72 *, struct tcf_proto___54 *, void *, struct sk_buff___62 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___62 *, struct net___72 *, void *);
	struct module___345 *owner;
	int flags;
};

struct tcf_chain___54 {
	struct mutex filter_chain_lock;
	struct tcf_proto___54 *filter_chain;
	struct list_head list;
	struct tcf_block___54 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___54 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___44 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___54 *prog;
};

struct bpf_redirect_info___54 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___265 *map;
	struct bpf_map___265 *map_to_flush;
	u32 kern_flags;
};

struct bdi_writeback_congested___209 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___209 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___209 {
	struct bio___209 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___211 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___211 bip_inline_vecs[0];
};

struct bio_set___209 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___209 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___152 {
	struct mem_cgroup___152 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___152 {
	struct lruvec___416 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___152 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___152 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct pneigh_entry___44;

struct neigh_hash_table___44;

struct neigh_table___44 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___61 *, __u32 *);
	bool (*key_eq)(const struct neighbour___44 *, const void *);
	int (*constructor)(struct neighbour___44 *);
	int (*pconstructor)(struct pneigh_entry___44 *);
	void (*pdestructor)(struct pneigh_entry___44 *);
	void (*proxy_redo)(struct sk_buff___62 *);
	char *id;
	struct neigh_parms___44 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___60 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___44 *nht;
	struct pneigh_entry___44 **phash_buckets;
};

struct neigh_ops___44 {
	int family;
	void (*solicit)(struct neighbour___44 *, struct sk_buff___62 *);
	void (*error_report)(struct neighbour___44 *, struct sk_buff___62 *);
	int (*output)(struct neighbour___44 *, struct sk_buff___62 *);
	int (*connected_output)(struct neighbour___44 *, struct sk_buff___62 *);
};

struct pneigh_entry___44 {
	struct pneigh_entry___44 *next;
	possible_net_t___62 net;
	struct net_device___61 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___44 {
	struct neighbour___44 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___44 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___44 *ctarget;
	struct net___72 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___44 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___44 *rule;
	u32 table;
	int flags;
};

struct proto___44 {
	void (*close)(struct sock___45 *, long int);
	int (*pre_connect)(struct sock___45 *, struct sockaddr *, int);
	int (*connect)(struct sock___45 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___45 *, int);
	struct sock___45 * (*accept)(struct sock___45 *, int, int *, bool);
	int (*ioctl)(struct sock___45 *, int, long unsigned int);
	int (*init)(struct sock___45 *);
	void (*destroy)(struct sock___45 *);
	void (*shutdown)(struct sock___45 *, int);
	int (*setsockopt)(struct sock___45 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___45 *, int, int, char *, int *);
	void (*keepalive)(struct sock___45 *, int);
	int (*sendmsg)(struct sock___45 *, struct msghdr___47 *, size_t);
	int (*recvmsg)(struct sock___45 *, struct msghdr___47 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___45 *, struct page___416 *, int, size_t, int);
	int (*bind)(struct sock___45 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___45 *, struct sk_buff___62 *);
	void (*release_cb)(struct sock___45 *);
	int (*hash)(struct sock___45 *);
	void (*unhash)(struct sock___45 *);
	void (*rehash)(struct sock___45 *);
	int (*get_port)(struct sock___45 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___45 *);
	bool (*stream_memory_read)(const struct sock___45 *);
	void (*enter_memory_pressure)(struct sock___45 *);
	void (*leave_memory_pressure)(struct sock___45 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___3 *rsk_prot;
	struct timewait_sock_ops___3 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___345 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___45 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct sock_reuseport___4 {
	struct callback_head rcu;
	u16 max_socks;
	u16 num_socks;
	unsigned int reuseport_id;
	bool bind_inany;
	struct bpf_prog___54 *prog;
	struct sock___45 *socks[0];
};

struct module___346;

struct file___416;

struct kiocb___416;

struct iov_iter___183;

struct vm_area_struct___417;

struct inode___416;

struct file_lock___416;

struct page___417;

struct pipe_inode_info___97;

struct seq_file___355;

struct file_operations___416 {
	struct module___346 *owner;
	loff_t (*llseek)(struct file___416 *, loff_t, int);
	ssize_t (*read)(struct file___416 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___416 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___416 *, struct iov_iter___183 *);
	ssize_t (*write_iter)(struct kiocb___416 *, struct iov_iter___183 *);
	int (*iopoll)(struct kiocb___416 *, bool);
	int (*iterate)(struct file___416 *, struct dir_context *);
	int (*iterate_shared)(struct file___416 *, struct dir_context *);
	__poll_t (*poll)(struct file___416 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___416 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___416 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___416 *, struct vm_area_struct___417 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___416 *, struct file___416 *);
	int (*flush)(struct file___416 *, fl_owner_t);
	int (*release)(struct inode___416 *, struct file___416 *);
	int (*fsync)(struct file___416 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___416 *, int);
	int (*lock)(struct file___416 *, int, struct file_lock___416 *);
	ssize_t (*sendpage)(struct file___416 *, struct page___417 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___416 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___416 *, int, struct file_lock___416 *);
	ssize_t (*splice_write)(struct pipe_inode_info___97 *, struct file___416 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___416 *, loff_t *, struct pipe_inode_info___97 *, size_t, unsigned int);
	int (*setlease)(struct file___416 *, long int, struct file_lock___416 **, void **);
	long int (*fallocate)(struct file___416 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___355 *, struct file___416 *);
	ssize_t (*copy_file_range)(struct file___416 *, loff_t, struct file___416 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___416 *, loff_t, struct file___416 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___416 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___417 {
	u64 seqnum;
	struct vm_area_struct___417 *vmas[4];
};

struct page_frag___417 {
	struct page___417 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___417;

struct cred___384;

struct nsproxy___311;

struct signal_struct___291;

struct css_set___265;

struct vm_struct___320;

struct task_struct___418 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___418 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___417 *mm;
	struct mm_struct___417 *active_mm;
	struct vmacache___417 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___418 *real_parent;
	struct task_struct___418 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___418 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___236 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___236 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___236 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___384 *ptracer_cred;
	const struct cred___384 *real_cred;
	const struct cred___384 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___311 *nsproxy;
	struct signal_struct___291 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___418 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___265 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___97 *splice_pipe;
	struct page_frag___417 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___418 *oom_reaper_list;
	struct vm_struct___320 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___154 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct secondary_data___418 {
	void *stack;
	struct task_struct___418 *task;
	long int status;
};

struct rw_semaphore___418 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___418 *owner;
};

struct key___384;

struct ucounts___281;

struct user_namespace___281 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___281 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___29 ns;
	long unsigned int flags;
	struct key___384 *persistent_keyring_register;
	struct rw_semaphore___418 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___281 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___417 *pgtable_t___417;

struct address_space___416;

struct dev_pagemap___404;

struct page___417 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___416 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___417 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___417 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___417 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___404 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___417;

struct lruvec___417 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___417 *pgdat;
};

struct zone___417 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___417 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___417 {
	struct zone___417 *zone;
	int zone_idx;
};

struct zonelist___417 {
	struct zoneref___417 _zonerefs[25];
};

struct pglist_data___417 {
	struct zone___417 node_zones[3];
	struct zonelist___417 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___418 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___418 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___417 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___417 {
	struct rw_semaphore___418 rwsem;
	struct notifier_block *head;
};

struct user_struct___384 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___384 *uid_keyring;
	struct key___384 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___404;

struct vm_area_struct___417 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___417 *vm_next;
	struct vm_area_struct___417 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___417 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___404 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___416 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___417;

struct mm_struct___417 {
	struct {
		struct vm_area_struct___417 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___416 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___418 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___417 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___418 *owner;
		struct user_namespace___281 *user_ns;
		struct file___416 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___417 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___384 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___384 *session_keyring;
	struct key___384 *process_keyring;
	struct key___384 *thread_keyring;
	struct key___384 *request_key_auth;
	void *security;
	struct user_struct___384 *user;
	struct user_namespace___281 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___73;

struct cgroup_namespace___265;

struct nsproxy___311 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net___73 *net_ns;
	struct cgroup_namespace___265 *cgroup_ns;
};

struct signal_struct___291 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___418 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___418 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___236 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___236 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___417 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___236 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___265;

struct cgroup___265;

struct css_set___265 {
	struct cgroup_subsys_state___265 *subsys[13];
	refcount_t refcount;
	struct css_set___265 *dom_cset;
	struct cgroup___265 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___265 *mg_src_cgrp;
	struct cgroup___265 *mg_dst_cgrp;
	struct css_set___265 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___416;

struct pipe_buffer___97;

struct pipe_inode_info___97 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___417 *tmp_page;
	struct fasync_struct___416 *fasync_readers;
	struct fasync_struct___416 *fasync_writers;
	struct pipe_buffer___97 *bufs;
	struct user_struct___384 *user;
};

struct vm_struct___320 {
	struct vm_struct___320 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___417 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___303 {
	struct task_struct___418 task;
	long unsigned int stack[8192];
};

struct address_space_operations___416;

struct address_space___416 {
	struct inode___416 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___418 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___416 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___404)(struct vm_area_struct___417 *, long unsigned int, const struct page___417 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___404)(struct page___417 *, void *);

struct device___384;

struct dev_pagemap___404 {
	dev_page_fault_t___404 page_fault;
	dev_page_free_t___404 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___384 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct dentry___416;

struct path___417 {
	struct vfsmount *mnt;
	struct dentry___416 *dentry;
};

struct file___416 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___417 f_path;
	struct inode___416 *f_inode;
	const struct file_operations___416 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___236 f_owner;
	const struct cred___384 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___416 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___404;

struct vm_operations_struct___404 {
	void (*open)(struct vm_area_struct___417 *);
	void (*close)(struct vm_area_struct___417 *);
	int (*split)(struct vm_area_struct___417 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___417 *);
	vm_fault_t (*fault)(struct vm_fault___404 *);
	vm_fault_t (*huge_fault)(struct vm_fault___404 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___404 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___417 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___404 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___404 *);
	int (*access)(struct vm_area_struct___417 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___417 *);
	int (*set_policy)(struct vm_area_struct___417 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___417 *, long unsigned int);
	struct page___417 * (*find_special_page)(struct vm_area_struct___417 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___417 {
	struct task_struct___418 *task;
	struct core_thread___417 *next;
};

struct core_state___417 {
	atomic_t nr_threads;
	struct core_thread___417 dumper;
	struct completion startup;
};

struct vm_fault___404 {
	struct vm_area_struct___417 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___417 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___417 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___417 prealloc_pte;
};

struct kset___403;

struct kobj_type___403;

struct kernfs_node___411;

struct kobject___404 {
	const char *name;
	struct list_head entry;
	struct kobject___404 *parent;
	struct kset___403 *kset;
	struct kobj_type___403 *ktype;
	struct kernfs_node___411 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___344 {
	struct kobject___404 kobj;
	struct module___346 *mod;
	struct kobject___404 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___344 {
	struct module___346 *mod;
	struct latch_tree_node node;
};

struct module_layout___344 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___344 mtn;
};

struct module_attribute___344;

struct kernel_param___344;

struct module___346 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___344 mkobj;
	struct module_attribute___344 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___404 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___344 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___344 core_layout;
	struct module_layout___344 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide38;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide39;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct iov_iter___183 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___3 *bvec;
		struct pipe_inode_info___97 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct kiocb___416 {
	struct file___416 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___416 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dentry_operations___416;

struct super_block___416;

struct dentry___416 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___416 *d_parent;
	struct qstr d_name;
	struct inode___416 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___416 *d_op;
	struct super_block___416 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___416;

struct block_device___416;

struct inode___416 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___416 *i_op;
	struct super_block___416 *i_sb;
	struct address_space___416 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___418 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___416 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___416 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___97 *i_pipe;
		struct block_device___416 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___416 {
	int (*d_revalidate)(struct dentry___416 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___416 *, unsigned int);
	int (*d_hash)(const struct dentry___416 *, struct qstr *);
	int (*d_compare)(const struct dentry___416 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___416 *);
	int (*d_init)(struct dentry___416 *);
	void (*d_release)(struct dentry___416 *);
	void (*d_prune)(struct dentry___416 *);
	void (*d_iput)(struct dentry___416 *, struct inode___416 *);
	char * (*d_dname)(struct dentry___416 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___417 *);
	int (*d_manage)(const struct path___417 *, bool);
	struct dentry___416 * (*d_real)(struct dentry___416 *, const struct inode___416 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___416;

struct mem_dqinfo___416 {
	struct quota_format_type___416 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___416;

struct quota_info___416 {
	unsigned int flags;
	struct rw_semaphore___418 dqio_sem;
	struct inode___416 *files[3];
	struct mem_dqinfo___416 info[3];
	const struct quota_format_ops___416 *ops[3];
};

struct rcuwait___416 {
	struct task_struct___418 *task;
};

struct percpu_rw_semaphore___416 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___418 rw_sem;
	struct rcuwait___416 writer;
	int readers_block;
};

struct sb_writers___416 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___416 rw_sem[3];
};

struct file_system_type___416;

struct super_operations___416;

struct dquot_operations___416;

struct quotactl_ops___416;

struct super_block___416 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___416 *s_type;
	const struct super_operations___416 *s_op;
	const struct dquot_operations___416 *dq_op;
	const struct quotactl_ops___416 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___416 *s_root;
	struct rw_semaphore___418 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___416 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___416 s_dquot;
	struct sb_writers___416 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___416 *s_d_op;
	int cleancache_poolid;
	struct shrinker___152 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___281 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct iattr___416 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___416 *ia_file;
};

struct dquot___416 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___416 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___416 {
	int qf_fmt_id;
	const struct quota_format_ops___416 *qf_ops;
	struct module___346 *qf_owner;
	struct quota_format_type___416 *qf_next;
};

struct quota_format_ops___416 {
	int (*check_quota_file)(struct super_block___416 *, int);
	int (*read_file_info)(struct super_block___416 *, int);
	int (*write_file_info)(struct super_block___416 *, int);
	int (*free_file_info)(struct super_block___416 *, int);
	int (*read_dqblk)(struct dquot___416 *);
	int (*commit_dqblk)(struct dquot___416 *);
	int (*release_dqblk)(struct dquot___416 *);
	int (*get_next_id)(struct super_block___416 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___416 {
	int (*write_dquot)(struct dquot___416 *);
	struct dquot___416 * (*alloc_dquot)(struct super_block___416 *, int);
	void (*destroy_dquot)(struct dquot___416 *);
	int (*acquire_dquot)(struct dquot___416 *);
	int (*release_dquot)(struct dquot___416 *);
	int (*mark_dirty)(struct dquot___416 *);
	int (*write_info)(struct super_block___416 *, int);
	qsize_t * (*get_reserved_space)(struct inode___416 *);
	int (*get_projid)(struct inode___416 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___416 *, qsize_t *);
	int (*get_next_id)(struct super_block___416 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___416 {
	int (*quota_on)(struct super_block___416 *, int, int, const struct path___417 *);
	int (*quota_off)(struct super_block___416 *, int);
	int (*quota_enable)(struct super_block___416 *, unsigned int);
	int (*quota_disable)(struct super_block___416 *, unsigned int);
	int (*quota_sync)(struct super_block___416 *, int);
	int (*set_info)(struct super_block___416 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___416 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___416 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___416 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___416 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___416 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___416 {
	int (*writepage)(struct page___417 *, struct writeback_control___3 *);
	int (*readpage)(struct file___416 *, struct page___417 *);
	int (*writepages)(struct address_space___416 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___417 *);
	int (*readpages)(struct file___416 *, struct address_space___416 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___416 *, struct address_space___416 *, loff_t, unsigned int, unsigned int, struct page___417 **, void **);
	int (*write_end)(struct file___416 *, struct address_space___416 *, loff_t, unsigned int, unsigned int, struct page___417 *, void *);
	sector_t (*bmap)(struct address_space___416 *, sector_t);
	void (*invalidatepage)(struct page___417 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___417 *, gfp_t);
	void (*freepage)(struct page___417 *);
	ssize_t (*direct_IO)(struct kiocb___416 *, struct iov_iter___183 *);
	int (*migratepage)(struct address_space___416 *, struct page___417 *, struct page___417 *, enum migrate_mode);
	bool (*isolate_page)(struct page___417 *, isolate_mode_t);
	void (*putback_page)(struct page___417 *);
	int (*launder_page)(struct page___417 *);
	int (*is_partially_uptodate)(struct page___417 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___417 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___416 *, struct page___417 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___416 *, sector_t *);
	void (*swap_deactivate)(struct file___416 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___416 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___416 *bd_inode;
	struct super_block___416 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___416 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___416 {
	struct dentry___416 * (*lookup)(struct inode___416 *, struct dentry___416 *, unsigned int);
	const char * (*get_link)(struct dentry___416 *, struct inode___416 *, struct delayed_call *);
	int (*permission)(struct inode___416 *, int);
	struct posix_acl * (*get_acl)(struct inode___416 *, int);
	int (*readlink)(struct dentry___416 *, char *, int);
	int (*create)(struct inode___416 *, struct dentry___416 *, umode_t, bool);
	int (*link)(struct dentry___416 *, struct inode___416 *, struct dentry___416 *);
	int (*unlink)(struct inode___416 *, struct dentry___416 *);
	int (*symlink)(struct inode___416 *, struct dentry___416 *, const char *);
	int (*mkdir)(struct inode___416 *, struct dentry___416 *, umode_t);
	int (*rmdir)(struct inode___416 *, struct dentry___416 *);
	int (*mknod)(struct inode___416 *, struct dentry___416 *, umode_t, dev_t);
	int (*rename)(struct inode___416 *, struct dentry___416 *, struct inode___416 *, struct dentry___416 *, unsigned int);
	int (*setattr)(struct dentry___416 *, struct iattr___416 *);
	int (*getattr)(const struct path___417 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___416 *, char *, size_t);
	int (*fiemap)(struct inode___416 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___416 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___416 *, struct dentry___416 *, struct file___416 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___416 *, struct dentry___416 *, umode_t);
	int (*set_acl)(struct inode___416 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___416 {
	void (*fl_copy_lock)(struct file_lock___416 *, struct file_lock___416 *);
	void (*fl_release_private)(struct file_lock___416 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___416;

struct file_lock___416 {
	struct file_lock___416 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___416 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___416 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___416 *fl_ops;
	const struct lock_manager_operations___416 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___416 {
	int (*lm_compare_owner)(struct file_lock___416 *, struct file_lock___416 *);
	long unsigned int (*lm_owner_key)(struct file_lock___416 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___416 *);
	int (*lm_grant)(struct file_lock___416 *, int);
	bool (*lm_break)(struct file_lock___416 *);
	int (*lm_change)(struct file_lock___416 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___416 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___416 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___416 *fa_next;
	struct file___416 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___416 {
	const char *name;
	int fs_flags;
	struct dentry___416 * (*mount)(struct file_system_type___416 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___416 *);
	struct module___346 *owner;
	struct file_system_type___416 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___416 {
	struct inode___416 * (*alloc_inode)(struct super_block___416 *);
	void (*destroy_inode)(struct inode___416 *);
	void (*dirty_inode)(struct inode___416 *, int);
	int (*write_inode)(struct inode___416 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___416 *);
	void (*evict_inode)(struct inode___416 *);
	void (*put_super)(struct super_block___416 *);
	int (*sync_fs)(struct super_block___416 *, int);
	int (*freeze_super)(struct super_block___416 *);
	int (*freeze_fs)(struct super_block___416 *);
	int (*thaw_super)(struct super_block___416 *);
	int (*unfreeze_fs)(struct super_block___416 *);
	int (*statfs)(struct dentry___416 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___416 *, int *, char *);
	void (*umount_begin)(struct super_block___416 *);
	int (*show_options)(struct seq_file___355 *, struct dentry___416 *);
	int (*show_devname)(struct seq_file___355 *, struct dentry___416 *);
	int (*show_path)(struct seq_file___355 *, struct dentry___416 *);
	int (*show_stats)(struct seq_file___355 *, struct dentry___416 *);
	ssize_t (*quota_read)(struct super_block___416 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___416 *, int, const char *, size_t, loff_t);
	struct dquot___416 ** (*get_dquots)(struct inode___416 *);
	int (*bdev_try_to_free_page)(struct super_block___416 *, struct page___417 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___416 *, struct shrink_control___152 *);
	long int (*free_cached_objects)(struct super_block___416 *, struct shrink_control___152 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___355;

struct seq_file___355 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___355 *op;
	int poll_event;
	const struct file___416 *file;
	void *private;
};

struct net_device___62;

struct nf_bridge_info___61;

struct sk_buff___63 {
	union {
		struct {
			struct sk_buff___63 *next;
			struct sk_buff___63 *prev;
			union {
				struct net_device___62 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___45 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___63 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___61 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___61;

struct netns_frags___61 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___61 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_notifier_ops___45;

struct netns_ipv4___61 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct sock *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock **tcp_sk;
	struct netns_frags___61 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___45 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___45 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct dst_ops___72 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___72 *);
	struct dst_entry___2 * (*check)(struct dst_entry___2 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___2 *);
	unsigned int (*mtu)(const struct dst_entry___2 *);
	u32 * (*cow_metrics)(struct dst_entry___2 *, long unsigned int);
	void (*destroy)(struct dst_entry___2 *);
	void (*ifdown)(struct dst_entry___2 *, struct net_device___62 *, int);
	struct dst_entry___2 * (*negative_advice)(struct dst_entry___2 *);
	void (*link_failure)(struct sk_buff___63 *);
	void (*update_pmtu)(struct dst_entry___2 *, struct sock *, struct sk_buff___63 *, u32);
	void (*redirect)(struct dst_entry___2 *, struct sock *, struct sk_buff___63 *);
	int (*local_out)(struct net___73 *, struct sock *, struct sk_buff___63 *);
	struct neighbour___2 * (*neigh_lookup)(const struct dst_entry___2 *, struct sk_buff___63 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___2 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___72 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___61 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___72 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct sock *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___45 *notifier_ops;
	struct fib_notifier_ops___45 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_nf_frag___61 {
	struct netns_frags___61 frags;
};

struct netns_xfrm___72 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___72 xfrm4_dst_ops;
	struct dst_ops___72 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct net___73 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___281 *user_ns;
	struct ucounts___281 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___29 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___62 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___61 ipv4;
	struct netns_ipv6___72 ipv6;
	struct netns_sctp___45 sctp;
	struct netns_nf___4 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___61 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock *nfnl;
	struct sock *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___72 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kernfs_root___410;

struct kernfs_elem_dir___410 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___410 *root;
};

struct kernfs_syscall_ops___410;

struct kernfs_root___410 {
	struct kernfs_node___411 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___410 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___410 {
	struct kernfs_node___411 *target_kn;
};

struct kernfs_ops___410;

struct kernfs_elem_attr___410 {
	const struct kernfs_ops___410 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___411 *notify_next;
};

struct kernfs_node___411 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___411 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___410 dir;
		struct kernfs_elem_symlink___410 symlink;
		struct kernfs_elem_attr___410 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___410;

struct kernfs_ops___410 {
	int (*open)(struct kernfs_open_file___410 *);
	void (*release)(struct kernfs_open_file___410 *);
	int (*seq_show)(struct seq_file___355 *, void *);
	void * (*seq_start)(struct seq_file___355 *, loff_t *);
	void * (*seq_next)(struct seq_file___355 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___355 *, void *);
	ssize_t (*read)(struct kernfs_open_file___410 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___410 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___410 *, struct vm_area_struct___417 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___410 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___410 {
	int (*remount_fs)(struct kernfs_root___410 *, int *, char *);
	int (*show_options)(struct seq_file___355 *, struct kernfs_root___410 *);
	int (*mkdir)(struct kernfs_node___411 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___411 *);
	int (*rename)(struct kernfs_node___411 *, struct kernfs_node___411 *, const char *);
	int (*show_path)(struct seq_file___355 *, struct kernfs_node___411 *, struct kernfs_root___410 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___410 {
	struct kernfs_node___411 *kn;
	struct file___416 *file;
	struct seq_file___355 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___404 *vm_ops;
};

struct bin_attribute___380;

struct attribute_group___381 {
	const char *name;
	umode_t (*is_visible)(struct kobject___404 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___404 *, struct bin_attribute___380 *, int);
	struct attribute **attrs;
	struct bin_attribute___380 **bin_attrs;
};

struct bin_attribute___380 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___416 *, struct kobject___404 *, struct bin_attribute___380 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___416 *, struct kobject___404 *, struct bin_attribute___380 *, char *, loff_t, size_t);
	int (*mmap)(struct file___416 *, struct kobject___404 *, struct bin_attribute___380 *, struct vm_area_struct___417 *);
};

struct sysfs_ops___403 {
	ssize_t (*show)(struct kobject___404 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___404 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___403;

struct kset___403 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___404 kobj;
	const struct kset_uevent_ops___403 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___403 {
	void (*release)(struct kobject___404 *);
	const struct sysfs_ops___403 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___44 * (*child_ns_type)(struct kobject___404 *);
	const void * (*namespace)(struct kobject___404 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___403 {
	int (* const filter)(struct kset___403 *, struct kobject___404 *);
	const char * (* const name)(struct kset___403 *, struct kobject___404 *);
	int (* const uevent)(struct kset___403 *, struct kobject___404 *, struct kobj_uevent_env *);
};

struct kobj_attribute___394 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___404 *, struct kobj_attribute___394 *, char *);
	ssize_t (*store)(struct kobject___404 *, struct kobj_attribute___394 *, const char *, size_t);
};

struct dev_pm_ops___384 {
	int (*prepare)(struct device___384 *);
	void (*complete)(struct device___384 *);
	int (*suspend)(struct device___384 *);
	int (*resume)(struct device___384 *);
	int (*freeze)(struct device___384 *);
	int (*thaw)(struct device___384 *);
	int (*poweroff)(struct device___384 *);
	int (*restore)(struct device___384 *);
	int (*suspend_late)(struct device___384 *);
	int (*resume_early)(struct device___384 *);
	int (*freeze_late)(struct device___384 *);
	int (*thaw_early)(struct device___384 *);
	int (*poweroff_late)(struct device___384 *);
	int (*restore_early)(struct device___384 *);
	int (*suspend_noirq)(struct device___384 *);
	int (*resume_noirq)(struct device___384 *);
	int (*freeze_noirq)(struct device___384 *);
	int (*thaw_noirq)(struct device___384 *);
	int (*poweroff_noirq)(struct device___384 *);
	int (*restore_noirq)(struct device___384 *);
	int (*runtime_suspend)(struct device___384 *);
	int (*runtime_resume)(struct device___384 *);
	int (*runtime_idle)(struct device___384 *);
};

struct dev_pm_info___384 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___384 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___384;

struct bus_type___384;

struct device_driver___384;

struct dev_pm_domain___384;

struct dma_map_ops___156;

struct fwnode_handle___304;

struct class___384;

struct device___384 {
	struct device___384 *parent;
	struct device_private *p;
	struct kobject___404 kobj;
	const char *init_name;
	const struct device_type___384 *type;
	struct mutex mutex;
	struct bus_type___384 *bus;
	struct device_driver___384 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___384 power;
	struct dev_pm_domain___384 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___156 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___304 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___384 *class;
	const struct attribute_group___381 **groups;
	void (*release)(struct device___384 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___384 {
	struct dev_pm_ops___384 ops;
	void (*detach)(struct device___384 *, bool);
	int (*activate)(struct device___384 *);
	void (*sync)(struct device___384 *);
	void (*dismiss)(struct device___384 *);
};

struct bus_type___384 {
	const char *name;
	const char *dev_name;
	struct device___384 *dev_root;
	const struct attribute_group___381 **bus_groups;
	const struct attribute_group___381 **dev_groups;
	const struct attribute_group___381 **drv_groups;
	int (*match)(struct device___384 *, struct device_driver___384 *);
	int (*uevent)(struct device___384 *, struct kobj_uevent_env *);
	int (*probe)(struct device___384 *);
	int (*remove)(struct device___384 *);
	void (*shutdown)(struct device___384 *);
	int (*online)(struct device___384 *);
	int (*offline)(struct device___384 *);
	int (*suspend)(struct device___384 *, pm_message_t);
	int (*resume)(struct device___384 *);
	int (*num_vf)(struct device___384 *);
	int (*dma_configure)(struct device___384 *);
	const struct dev_pm_ops___384 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___384 {
	const char *name;
	struct bus_type___384 *bus;
	struct module___346 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___384 *);
	int (*remove)(struct device___384 *);
	void (*shutdown)(struct device___384 *);
	int (*suspend)(struct device___384 *, pm_message_t);
	int (*resume)(struct device___384 *);
	const struct attribute_group___381 **groups;
	const struct dev_pm_ops___384 *pm;
	void (*coredump)(struct device___384 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___384 {
	const char *name;
	const struct attribute_group___381 **groups;
	int (*uevent)(struct device___384 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___384 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___384 *);
	const struct dev_pm_ops___384 *pm;
};

struct class___384 {
	const char *name;
	struct module___346 *owner;
	const struct attribute_group___381 **class_groups;
	const struct attribute_group___381 **dev_groups;
	struct kobject___404 *dev_kobj;
	int (*dev_uevent)(struct device___384 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___384 *, umode_t *);
	void (*class_release)(struct class___384 *);
	void (*dev_release)(struct device___384 *);
	int (*shutdown_pre)(struct device___384 *);
	const struct kobj_ns_type_operations___44 *ns_type;
	const void * (*namespace)(struct device___384 *);
	const struct dev_pm_ops___384 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___156 {
	void * (*alloc)(struct device___384 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___384 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___384 *, struct vm_area_struct___417 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___384 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___384 *, struct page___417 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___384 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___384 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___384 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___384 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___384 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___384 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___384 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___384 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___384 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___384 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___384 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___384 *, u64);
	u64 (*get_required_mask)(struct device___384 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___304;

struct fwnode_handle___304 {
	struct fwnode_handle___304 *secondary;
	const struct fwnode_operations___304 *ops;
};

typedef void compound_page_dtor___404(struct page___417 *);

struct fwnode_reference_args___304;

struct fwnode_endpoint___304;

struct fwnode_operations___304 {
	struct fwnode_handle___304 * (*get)(struct fwnode_handle___304 *);
	void (*put)(struct fwnode_handle___304 *);
	bool (*device_is_available)(const struct fwnode_handle___304 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___304 *, const struct device___384 *);
	bool (*property_present)(const struct fwnode_handle___304 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___304 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___304 *, const char *, const char **, size_t);
	struct fwnode_handle___304 * (*get_parent)(const struct fwnode_handle___304 *);
	struct fwnode_handle___304 * (*get_next_child_node)(const struct fwnode_handle___304 *, struct fwnode_handle___304 *);
	struct fwnode_handle___304 * (*get_named_child_node)(const struct fwnode_handle___304 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___304 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___304 *);
	struct fwnode_handle___304 * (*graph_get_next_endpoint)(const struct fwnode_handle___304 *, struct fwnode_handle___304 *);
	struct fwnode_handle___304 * (*graph_get_remote_endpoint)(const struct fwnode_handle___304 *);
	struct fwnode_handle___304 * (*graph_get_port_parent)(struct fwnode_handle___304 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___304 *, struct fwnode_endpoint___304 *);
};

struct fwnode_endpoint___304 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___304 *local_fwnode;
};

struct fwnode_reference_args___304 {
	struct fwnode_handle___304 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___97;

struct pipe_buffer___97 {
	struct page___417 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___97 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___97 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___97 *, struct pipe_buffer___97 *);
	void (*release)(struct pipe_inode_info___97 *, struct pipe_buffer___97 *);
	int (*steal)(struct pipe_inode_info___97 *, struct pipe_buffer___97 *);
	union {
		bool (*get)(struct pipe_inode_info___97 *, struct pipe_buffer___97 *);
		struct {
			void (*get)(struct pipe_inode_info___97 *, struct pipe_buffer___97 *);
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
};

struct nf_bridge_info___61 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___61 = 0,
		BRNF_PROTO_8021Q___61 = 1,
		BRNF_PROTO_PPPOE___61 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___62 *physindev;
	struct net_device___62 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___61(struct sk_buff___63 **);

typedef struct {
	struct net___73 *net;
} possible_net_t___63;

struct net_device_ops___61;

struct ethtool_ops___61;

struct xfrmdev_ops___61;

struct tlsdev_ops___61;

struct header_ops___61;

struct netdev_rx_queue___61;

struct netdev_queue___61;

struct dcbnl_rtnl_ops___61;

struct net_device___62 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___61 *netdev_ops;
	const struct ethtool_ops___61 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___2 *l3mdev_ops;
	const struct ndisc_ops___2 *ndisc_ops;
	const struct xfrmdev_ops___61 *xfrmdev_ops;
	const struct tlsdev_ops___61 *tlsdev_ops;
	const struct header_ops___61 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___403 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___2 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___61 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___61 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___2 *miniq_ingress;
	struct netdev_queue___61 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___61 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___2 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___2 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___61 = 0,
		NETREG_REGISTERED___61 = 1,
		NETREG_UNREGISTERING___61 = 2,
		NETREG_UNREGISTERED___61 = 3,
		NETREG_RELEASED___61 = 4,
		NETREG_DUMMY___61 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___61 = 0,
		RTNL_LINK_INITIALIZING___61 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___62 *);
	struct netpoll_info *npinfo;
	possible_net_t___63 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___384 dev;
	const struct attribute_group___381 *sysfs_groups[4];
	const struct attribute_group___381 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___2 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___61 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct sk_buff_head___61 {
	struct sk_buff___63 *next;
	struct sk_buff___63 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct ethtool_ops___61 {
	int (*get_settings)(struct net_device___62 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___62 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___62 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___62 *);
	void (*get_regs)(struct net_device___62 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___62 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___62 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___62 *);
	void (*set_msglevel)(struct net_device___62 *, u32);
	int (*nway_reset)(struct net_device___62 *);
	u32 (*get_link)(struct net_device___62 *);
	int (*get_eeprom_len)(struct net_device___62 *);
	int (*get_eeprom)(struct net_device___62 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___62 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___62 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___62 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___62 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___62 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___62 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___62 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___62 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___62 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___62 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___62 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___62 *);
	void (*complete)(struct net_device___62 *);
	u32 (*get_priv_flags)(struct net_device___62 *);
	int (*set_priv_flags)(struct net_device___62 *, u32);
	int (*get_sset_count)(struct net_device___62 *, int);
	int (*get_rxnfc)(struct net_device___62 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___62 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___62 *, struct ethtool_flash *);
	int (*reset)(struct net_device___62 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___62 *);
	u32 (*get_rxfh_indir_size)(struct net_device___62 *);
	int (*get_rxfh)(struct net_device___62 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___62 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___62 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___62 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___62 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___62 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___62 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___62 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___62 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___62 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___62 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___62 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___62 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___62 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___62 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___62 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___62 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___62 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___62 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___62 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___62 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___62 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	int (*get_fecparam)(struct net_device___62 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___62 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___62 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___62 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___62 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___61;

struct inet_frags___61 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___61 *, const void *);
	void (*destructor)(struct inet_frag_queue___61 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___61 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___63 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___63 *fragments_tail;
	struct sk_buff___63 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___61 *net;
	struct callback_head rcu;
};

struct fib_notifier_ops___45 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___73 *);
	int (*fib_dump)(struct net___73 *, struct notifier_block *);
	struct module___346 *owner;
	struct callback_head rcu;
};

struct ucounts___281 {
	struct hlist_node node;
	struct user_namespace___281 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

typedef int (*key_restrict_link_func_t___385)(struct key___384 *, const struct key_type *, const union key_payload *, struct key___384 *);

struct key_restriction___384;

struct key___384 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___418 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___384 *restrict_link;
};

struct key_restriction___384 {
	key_restrict_link_func_t___385 check;
	struct key___384 *key;
	struct key_type *keytype;
};

struct seq_operations___355 {
	void * (*start)(struct seq_file___355 *, loff_t *);
	void (*stop)(struct seq_file___355 *, void *);
	void * (*next)(struct seq_file___355 *, void *, loff_t *);
	int (*show)(struct seq_file___355 *, void *);
};

struct pernet_operations___62 {
	struct list_head list;
	int (*init)(struct net___73 *);
	void (*exit)(struct net___73 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___61 {
	int (*ieee_getets)(struct net_device___62 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___62 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___62 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___62 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___62 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___62 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___62 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___62 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___62 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___62 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___62 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___62 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___62 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___62 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___62 *);
	u8 (*setstate)(struct net_device___62 *, u8);
	void (*getpermhwaddr)(struct net_device___62 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___62 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___62 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___62 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___62 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___62 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___62 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___62 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___62 *, int, u8 *);
	void (*setpfccfg)(struct net_device___62 *, int, u8);
	void (*getpfccfg)(struct net_device___62 *, int, u8 *);
	u8 (*setall)(struct net_device___62 *);
	u8 (*getcap)(struct net_device___62 *, int, u8 *);
	int (*getnumtcs)(struct net_device___62 *, int, u8 *);
	int (*setnumtcs)(struct net_device___62 *, int, u8);
	u8 (*getpfcstate)(struct net_device___62 *);
	void (*setpfcstate)(struct net_device___62 *, u8);
	void (*getbcncfg)(struct net_device___62 *, int, u32 *);
	void (*setbcncfg)(struct net_device___62 *, int, u32);
	void (*getbcnrp)(struct net_device___62 *, int, u8 *);
	void (*setbcnrp)(struct net_device___62 *, int, u8);
	int (*setapp)(struct net_device___62 *, u8, u16, u8);
	int (*getapp)(struct net_device___62 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___62 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___62 *, int, u8);
	u8 (*getdcbx)(struct net_device___62 *);
	u8 (*setdcbx)(struct net_device___62 *, u8);
	int (*peer_getappinfo)(struct net_device___62 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___62 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___62 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___62 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___62 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___62 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___265 {
	refcount_t count;
	struct ns_common___29 ns;
	struct user_namespace___281 *user_ns;
	struct ucounts___281 *ucounts;
	struct css_set___265 *root_cset;
};

struct bpf_map___266;

struct bpf_map_ops___265 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___266 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___266 *, struct file___416 *);
	void (*map_free)(struct bpf_map___266 *);
	int (*map_get_next_key)(struct bpf_map___266 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___266 *);
	void * (*map_lookup_elem)(struct bpf_map___266 *, void *);
	int (*map_update_elem)(struct bpf_map___266 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___266 *, void *);
	int (*map_push_elem)(struct bpf_map___266 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___266 *, void *);
	int (*map_peek_elem)(struct bpf_map___266 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___266 *, struct file___416 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___266 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___266 *, void *, struct seq_file___355 *);
	int (*map_check_btf)(const struct bpf_map___266 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___266 {
	const struct bpf_map_ops___265 *ops;
	struct bpf_map___266 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___384 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___61;

struct bpf_map_dev_ops___61 {
	int (*map_get_next_key)(struct bpf_offloaded_map___61 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___61 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___61 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___61 *, void *);
};

struct bpf_offloaded_map___61 {
	struct bpf_map___266 map;
	struct net_device___62 *netdev;
	const struct bpf_map_dev_ops___61 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___266;

typedef void (*kthread_work_func_t___266)(struct kthread_work___266 *);

struct kthread_worker___266;

struct kthread_work___266 {
	struct list_head node;
	kthread_work_func_t___266 func;
	struct kthread_worker___266 *worker;
	int canceling;
};

struct kthread_worker___266 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___418 *task;
	struct kthread_work___266 *current_work;
};

struct kthread_delayed_work___265 {
	struct kthread_work___266 work;
	struct timer_list timer;
};

struct psi_group___265 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___266 *poll_kworker;
	struct kthread_delayed_work___265 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___265 {
	struct kernfs_node___411 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___265;

struct cgroup_subsys_state___265 {
	struct cgroup___265 *cgroup;
	struct cgroup_subsys___265 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___265 *parent;
};

struct cgroup_root___265;

struct cgroup_rstat_cpu___265;

struct cgroup___265 {
	struct cgroup_subsys_state___265 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___411 *kn;
	struct cgroup_file___265 procs_file;
	struct cgroup_file___265 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___265 *subsys[13];
	struct cgroup_root___265 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___265 *dom_cgrp;
	struct cgroup_rstat_cpu___265 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___54 bpf;
	atomic_t congestion_count;
	struct cgroup___265 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___265 psi;
	int ancestor_ids[0];
};

struct cftype___265;

struct cgroup_subsys___265 {
	struct cgroup_subsys_state___265 * (*css_alloc)(struct cgroup_subsys_state___265 *);
	int (*css_online)(struct cgroup_subsys_state___265 *);
	void (*css_offline)(struct cgroup_subsys_state___265 *);
	void (*css_released)(struct cgroup_subsys_state___265 *);
	void (*css_free)(struct cgroup_subsys_state___265 *);
	void (*css_reset)(struct cgroup_subsys_state___265 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___265 *, int);
	int (*css_extra_stat_show)(struct seq_file___355 *, struct cgroup_subsys_state___265 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___418 *);
	void (*cancel_fork)(struct task_struct___418 *);
	void (*fork)(struct task_struct___418 *);
	void (*exit)(struct task_struct___418 *);
	void (*free)(struct task_struct___418 *);
	void (*bind)(struct cgroup_subsys_state___265 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___265 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___265 *dfl_cftypes;
	struct cftype___265 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___265 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___265 *updated_children;
	struct cgroup___265 *updated_next;
};

struct cgroup_root___265 {
	struct kernfs_root___410 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___265 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___265 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___265 *ss;
	struct list_head node;
	struct kernfs_ops___410 *kf_ops;
	int (*open)(struct kernfs_open_file___410 *);
	void (*release)(struct kernfs_open_file___410 *);
	u64 (*read_u64)(struct cgroup_subsys_state___265 *, struct cftype___265 *);
	s64 (*read_s64)(struct cgroup_subsys_state___265 *, struct cftype___265 *);
	int (*seq_show)(struct seq_file___355 *, void *);
	void * (*seq_start)(struct seq_file___355 *, loff_t *);
	void * (*seq_next)(struct seq_file___355 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___355 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___265 *, struct cftype___265 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___265 *, struct cftype___265 *, s64);
	ssize_t (*write)(struct kernfs_open_file___410 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___410 *, struct poll_table_struct___6 *);
};

struct xdp_rxq_info___61 {
	struct net_device___62 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___61 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___62 *dev_rx;
};

struct netlink_callback___63 {
	struct sk_buff___63 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___63 *);
	int (*dump)(struct sk_buff___63 *, struct netlink_callback___63 *);
	int (*done)(struct netlink_callback___63 *);
	void *data;
	struct module___346 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___61 {
	int (*create)(struct sk_buff___63 *, struct net_device___62 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___63 *, unsigned char *);
	int (*cache)(const struct neighbour___2 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___62 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___61 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___61 *, int);
	int poll_owner;
	struct net_device___62 *dev;
	struct sk_buff___63 *gro_list;
	struct sk_buff___63 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___61 {
	struct net_device___62 *dev;
	struct Qdisc___2 *qdisc;
	struct Qdisc___2 *qdisc_sleeping;
	struct kobject___404 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___62 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct netdev_rx_queue___61 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___404 kobj;
	struct net_device___62 *dev;
	long: 64;
	struct xdp_rxq_info___61 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___61)(struct net_device___62 *, struct sk_buff___63 *, struct net_device___62 *);

struct netdev_bpf___61 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___54 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___54 *prog;
			const struct bpf_prog_offload_ops___54 *ops;
		} verifier;
		struct {
			struct bpf_prog___54 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___61 *offmap;
		};
		struct {
			struct xdp_umem___3 *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___61 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___63 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___61 {
	int (*tls_dev_add)(struct net_device___62 *, struct sock *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___62 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___62 *, struct sock *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___61 {
	int (*ndo_init)(struct net_device___62 *);
	void (*ndo_uninit)(struct net_device___62 *);
	int (*ndo_open)(struct net_device___62 *);
	int (*ndo_stop)(struct net_device___62 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___63 *, struct net_device___62 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___63 *, struct net_device___62 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___62 *, struct sk_buff___63 *, struct net_device___62 *, select_queue_fallback_t___61);
	void (*ndo_change_rx_flags)(struct net_device___62 *, int);
	void (*ndo_set_rx_mode)(struct net_device___62 *);
	int (*ndo_set_mac_address)(struct net_device___62 *, void *);
	int (*ndo_validate_addr)(struct net_device___62 *);
	int (*ndo_do_ioctl)(struct net_device___62 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___62 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___62 *, int);
	int (*ndo_neigh_setup)(struct net_device___62 *, struct neigh_parms___3 *);
	void (*ndo_tx_timeout)(struct net_device___62 *);
	void (*ndo_get_stats64)(struct net_device___62 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___62 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___62 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___62 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___62 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___62 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___62 *);
	int (*ndo_netpoll_setup)(struct net_device___62 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___62 *);
	int (*ndo_set_vf_mac)(struct net_device___62 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___62 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___62 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___62 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___62 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___62 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___62 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___62 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___62 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___62 *, int, struct sk_buff___63 *);
	int (*ndo_set_vf_guid)(struct net_device___62 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___62 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___62 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___62 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___62 *, const struct sk_buff___63 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___62 *, struct net_device___62 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___62 *, struct net_device___62 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___62 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___62 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___62 *, struct neighbour___2 *);
	void (*ndo_neigh_destroy)(struct net_device___62 *, struct neighbour___2 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___62 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___62 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___62 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___63 *, struct netlink_callback___63 *, struct net_device___62 *, struct net_device___62 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___62 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___62 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___63 *, u32, u32, struct net_device___62 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___62 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___62 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___62 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___62 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___62 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___62 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___62 *, struct net_device___62 *);
	void (*ndo_dfwd_del_station)(struct net_device___62 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___62 *);
	int (*ndo_set_tx_maxrate)(struct net_device___62 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___62 *);
	int (*ndo_change_proto_down)(struct net_device___62 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___62 *, struct sk_buff___63 *);
	void (*ndo_set_rx_headroom)(struct net_device___62 *, int);
	int (*ndo_bpf)(struct net_device___62 *, struct netdev_bpf___61 *);
	int (*ndo_xdp_xmit)(struct net_device___62 *, int, struct xdp_frame___61 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___62 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___62 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct softnet_data___61 {
	struct list_head poll_list;
	struct sk_buff_head___61 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___61 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___2 *output_queue;
	struct Qdisc___2 **output_queue_tailp;
	struct sk_buff___63 *completion_queue;
	struct sk_buff_head___61 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___61 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___61 input_pkt_queue;
	struct napi_struct___61 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kernel_param_ops___344 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___344 *);
	int (*get)(char *, const struct kernel_param___344 *);
	void (*free)(void *);
};

struct kparam_array___344;

struct kernel_param___344 {
	const char *name;
	struct module___346 *mod;
	const struct kernel_param_ops___344 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___344 *arr;
	};
};

struct kparam_array___344 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___344 *ops;
	void *elem;
};

struct module_attribute___344 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___344 *, struct module_kobject___344 *, char *);
	ssize_t (*store)(struct module_attribute___344 *, struct module_kobject___344 *, const char *, size_t);
	void (*setup)(struct module___346 *, const char *);
	int (*test)(struct module___346 *);
	void (*free)(struct module___346 *);
};

struct fib_notifier_info {
	struct net___73 *net;
	int family;
	struct netlink_ext_ack *extack;
};

enum fib_event_type {
	FIB_EVENT_ENTRY_REPLACE = 0,
	FIB_EVENT_ENTRY_APPEND = 1,
	FIB_EVENT_ENTRY_ADD = 2,
	FIB_EVENT_ENTRY_DEL = 3,
	FIB_EVENT_RULE_ADD = 4,
	FIB_EVENT_RULE_DEL = 5,
	FIB_EVENT_NH_ADD = 6,
	FIB_EVENT_NH_DEL = 7,
	FIB_EVENT_VIF_ADD = 8,
	FIB_EVENT_VIF_DEL = 9,
};

struct zero_copy_allocator {
	void (*free)(struct zero_copy_allocator *, long unsigned int);
};

struct xdp_attachment_info {
	struct bpf_prog___54 *prog;
	u32 flags;
};

struct pp_alloc_cache {
	u32 count;
	void *cache[128];
};

struct page_pool_params {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___383 *dev;
	enum dma_data_direction dma_dir;
};

struct page_pool {
	struct callback_head rcu;
	struct page_pool_params p;
	long: 64;
	long: 64;
	struct pp_alloc_cache alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
};

struct xdp_mem_allocator {
	struct xdp_mem_info mem;
	union {
		void *allocator;
		struct page_pool *page_pool;
		struct zero_copy_allocator *zc_alloc;
	};
	struct rhash_head node;
	struct callback_head rcu;
};

struct flow_match_basic {
	struct flow_dissector_key_basic *key;
	struct flow_dissector_key_basic *mask;
};

struct flow_match_control {
	struct flow_dissector_key_control *key;
	struct flow_dissector_key_control *mask;
};

struct flow_match_eth_addrs {
	struct flow_dissector_key_eth_addrs *key;
	struct flow_dissector_key_eth_addrs *mask;
};

struct flow_match_vlan {
	struct flow_dissector_key_vlan *key;
	struct flow_dissector_key_vlan *mask;
};

struct flow_match_ipv4_addrs {
	struct flow_dissector_key_ipv4_addrs *key;
	struct flow_dissector_key_ipv4_addrs *mask;
};

struct flow_match_ipv6_addrs {
	struct flow_dissector_key_ipv6_addrs *key;
	struct flow_dissector_key_ipv6_addrs *mask;
};

struct flow_match_ip {
	struct flow_dissector_key_ip *key;
	struct flow_dissector_key_ip *mask;
};

struct flow_match_ports {
	struct flow_dissector_key_ports *key;
	struct flow_dissector_key_ports *mask;
};

struct flow_match_icmp {
	struct flow_dissector_key_icmp *key;
	struct flow_dissector_key_icmp *mask;
};

struct flow_match_tcp {
	struct flow_dissector_key_tcp *key;
	struct flow_dissector_key_tcp *mask;
};

struct flow_match_mpls {
	struct flow_dissector_key_mpls *key;
	struct flow_dissector_key_mpls *mask;
};

struct flow_match_enc_keyid {
	struct flow_dissector_key_keyid *key;
	struct flow_dissector_key_keyid *mask;
};

struct flow_match_enc_opts {
	struct flow_dissector_key_enc_opts *key;
	struct flow_dissector_key_enc_opts *mask;
};

struct class_attribute___4 {
	struct attribute attr;
	ssize_t (*show)(struct class___375 *, struct class_attribute___4 *, char *);
	ssize_t (*store)(struct class___375 *, struct class_attribute___4 *, const char *, size_t);
};

struct device_attribute___62 {
	struct attribute attr;
	ssize_t (*show)(struct device___375 *, struct device_attribute___62 *, char *);
	ssize_t (*store)(struct device___375 *, struct device_attribute___62 *, const char *, size_t);
};

struct rx_queue_attribute {
	struct attribute attr;
	ssize_t (*show)(struct netdev_rx_queue___52 *, char *);
	ssize_t (*store)(struct netdev_rx_queue___52 *, const char *, size_t);
};

struct node___224 {
	struct device___375 dev;
};

struct netdev_queue_attribute {
	struct attribute attr;
	ssize_t (*show)(struct netdev_queue___52 *, char *);
	ssize_t (*store)(struct netdev_queue___52 *, const char *, size_t);
};

struct page_pool_params___2 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___326 *dev;
	enum dma_data_direction dma_dir;
};

struct page_pool___2 {
	struct callback_head rcu;
	struct page_pool_params___2 p;
	long: 64;
	long: 64;
	struct pp_alloc_cache alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
};

struct packet_type___2 {
	__be16 type;
	struct net_device___62 *dev;
	int (*func)(struct sk_buff___63 *, struct net_device___62 *, struct packet_type___2 *, struct net_device___62 *);
	bool (*id_match)(struct packet_type___2 *, struct sock *);
	void *af_packet_priv;
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module___347;

struct file___417;

struct kiocb___417;

struct iov_iter___184;

struct poll_table_struct___259;

struct vm_area_struct___418;

struct inode___417;

struct file_lock___417;

struct page___418;

struct pipe_inode_info___98;

struct seq_file___356;

struct file_operations___417 {
	struct module___347 *owner;
	loff_t (*llseek)(struct file___417 *, loff_t, int);
	ssize_t (*read)(struct file___417 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___417 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___417 *, struct iov_iter___184 *);
	ssize_t (*write_iter)(struct kiocb___417 *, struct iov_iter___184 *);
	int (*iopoll)(struct kiocb___417 *, bool);
	int (*iterate)(struct file___417 *, struct dir_context *);
	int (*iterate_shared)(struct file___417 *, struct dir_context *);
	__poll_t (*poll)(struct file___417 *, struct poll_table_struct___259 *);
	long int (*unlocked_ioctl)(struct file___417 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___417 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___417 *, struct vm_area_struct___418 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___417 *, struct file___417 *);
	int (*flush)(struct file___417 *, fl_owner_t);
	int (*release)(struct inode___417 *, struct file___417 *);
	int (*fsync)(struct file___417 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___417 *, int);
	int (*lock)(struct file___417 *, int, struct file_lock___417 *);
	ssize_t (*sendpage)(struct file___417 *, struct page___418 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___417 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___417 *, int, struct file_lock___417 *);
	ssize_t (*splice_write)(struct pipe_inode_info___98 *, struct file___417 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___417 *, loff_t *, struct pipe_inode_info___98 *, size_t, unsigned int);
	int (*setlease)(struct file___417 *, long int, struct file_lock___417 **, void **);
	long int (*fallocate)(struct file___417 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___356 *, struct file___417 *);
	ssize_t (*copy_file_range)(struct file___417 *, loff_t, struct file___417 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___417 *, loff_t, struct file___417 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___417 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___418 {
	u64 seqnum;
	struct vm_area_struct___418 *vmas[4];
};

struct page_frag___418 {
	struct page___418 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___418;

struct mem_cgroup___153;

struct cred___385;

struct nsproxy___312;

struct signal_struct___292;

struct bio_list___210;

struct backing_dev_info___210;

struct css_set___266;

struct vm_struct___321;

struct task_struct___419 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___419 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___418 *mm;
	struct mm_struct___418 *active_mm;
	struct vmacache___418 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___419 *real_parent;
	struct task_struct___419 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___419 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___153 *active_memcg;
	long int rh_reserved2;
	struct pid___236 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___236 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___236 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___385 *ptracer_cred;
	const struct cred___385 *real_cred;
	const struct cred___385 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___312 *nsproxy;
	struct signal_struct___292 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___419 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___210 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___210 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___266 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___98 *splice_pipe;
	struct page_frag___418 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___153 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___419 *oom_reaper_list;
	struct vm_struct___321 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___154 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct secondary_data___419 {
	void *stack;
	struct task_struct___419 *task;
	long int status;
};

struct dentry___417;

struct path___418 {
	struct vfsmount *mnt;
	struct dentry___417 *dentry;
};

struct address_space___417;

struct file___417 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___418 f_path;
	struct inode___417 *f_inode;
	const struct file_operations___417 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___236 f_owner;
	const struct cred___385 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___417 *f_mapping;
	errseq_t f_wb_err;
};

struct bpf_map___267;

struct bpf_map_ops___266 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___267 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___267 *, struct file___417 *);
	void (*map_free)(struct bpf_map___267 *);
	int (*map_get_next_key)(struct bpf_map___267 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___267 *);
	void * (*map_lookup_elem)(struct bpf_map___267 *, void *);
	int (*map_update_elem)(struct bpf_map___267 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___267 *, void *);
	int (*map_push_elem)(struct bpf_map___267 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___267 *, void *);
	int (*map_peek_elem)(struct bpf_map___267 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___267 *, struct file___417 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___267 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___267 *, void *, struct seq_file___356 *);
	int (*map_check_btf)(const struct bpf_map___267 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct user_struct___385;

struct bpf_map___267 {
	const struct bpf_map_ops___266 *ops;
	struct bpf_map___267 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___385 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct seq_operations___356;

struct seq_file___356 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___356 *op;
	int poll_event;
	const struct file___417 *file;
	void *private;
};

struct key___385;

struct user_struct___385 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___385 *uid_keyring;
	struct key___385 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bpf_offloaded_map___62;

struct bpf_map_dev_ops___62 {
	int (*map_get_next_key)(struct bpf_offloaded_map___62 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___62 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___62 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___62 *, void *);
};

struct net_device___63;

struct bpf_offloaded_map___62 {
	struct bpf_map___267 map;
	struct net_device___63 *netdev;
	const struct bpf_map_dev_ops___62 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___64;

typedef rx_handler_result_t rx_handler_func_t___62(struct sk_buff___64 **);

struct net___74;

typedef struct {
	struct net___74 *net;
} possible_net_t___64;

struct kset___404;

struct kobj_type___404;

struct kernfs_node___412;

struct kobject___405 {
	const char *name;
	struct list_head entry;
	struct kobject___405 *parent;
	struct kset___404 *kset;
	struct kobj_type___404 *ktype;
	struct kernfs_node___412 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___385;

struct dev_pm_info___385 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___385 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___385;

struct bus_type___385;

struct device_driver___385;

struct dev_pm_domain___385;

struct dma_map_ops___157;

struct fwnode_handle___305;

struct class___385;

struct attribute_group___382;

struct device___385 {
	struct device___385 *parent;
	struct device_private *p;
	struct kobject___405 kobj;
	const char *init_name;
	const struct device_type___385 *type;
	struct mutex mutex;
	struct bus_type___385 *bus;
	struct device_driver___385 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___385 power;
	struct dev_pm_domain___385 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___157 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___305 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___385 *class;
	const struct attribute_group___382 **groups;
	void (*release)(struct device___385 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct net_device_ops___62;

struct ethtool_ops___62;

struct l3mdev_ops___45;

struct ndisc_ops___25;

struct xfrmdev_ops___62;

struct tlsdev_ops___62;

struct header_ops___62;

struct inet6_dev___25;

struct netdev_rx_queue___62;

struct bpf_prog___55;

struct mini_Qdisc___55;

struct netdev_queue___62;

struct Qdisc___55;

struct rtnl_link_ops___55;

struct dcbnl_rtnl_ops___62;

struct net_device___63 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___62 *netdev_ops;
	const struct ethtool_ops___62 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___45 *l3mdev_ops;
	const struct ndisc_ops___25 *ndisc_ops;
	const struct xfrmdev_ops___62 *xfrmdev_ops;
	const struct tlsdev_ops___62 *tlsdev_ops;
	const struct header_ops___62 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___404 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___25 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___62 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___55 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___62 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___55 *miniq_ingress;
	struct netdev_queue___62 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___62 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___55 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___55 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___62 = 0,
		NETREG_REGISTERED___62 = 1,
		NETREG_UNREGISTERING___62 = 2,
		NETREG_UNREGISTERED___62 = 3,
		NETREG_RELEASED___62 = 4,
		NETREG_DUMMY___62 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___62 = 0,
		RTNL_LINK_INITIALIZING___62 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___63 *);
	struct netpoll_info *npinfo;
	possible_net_t___64 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___385 dev;
	const struct attribute_group___382 *sysfs_groups[4];
	const struct attribute_group___382 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___55 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___62 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide35;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct bpf_prog_ops___55 {
	int (*test_run)(struct bpf_prog___55 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_aux___58;

struct bpf_prog___55 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___58 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

struct bpf_verifier_ops___55 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___55 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___55 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___55 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___55 *, u32 *);
};

struct bpf_prog_offload_ops___55 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___55 *);
	int (*translate)(struct bpf_prog___55 *);
	void (*destroy)(struct bpf_prog___55 *);
};

struct bpf_prog_offload___55 {
	struct bpf_prog___55 *prog;
	struct net_device___63 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___55 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___58 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___55 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___55 *ops;
	struct bpf_map___267 **used_maps;
	struct bpf_prog___55 *prog;
	struct user_struct___385 *user;
	u64 load_time;
	struct bpf_map___267 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___55 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___55 {
	struct bpf_prog___55 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___55 {
	struct callback_head rcu;
	struct bpf_prog_array_item___55 items[0];
};

struct rw_semaphore___419 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___419 *owner;
};

struct ucounts___282;

struct user_namespace___282 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___282 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___29 ns;
	long unsigned int flags;
	struct key___385 *persistent_keyring_register;
	struct rw_semaphore___419 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___282 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___418 *pgtable_t___418;

struct dev_pagemap___405;

struct page___418 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___417 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___418 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___418 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___418 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___405 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___153 *mem_cgroup;
};

struct pglist_data___418;

struct lruvec___418 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___418 *pgdat;
};

struct zone___418 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___418 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___418 {
	struct zone___418 *zone;
	int zone_idx;
};

struct zonelist___418 {
	struct zoneref___418 _zonerefs[25];
};

struct pglist_data___418 {
	struct zone___418 node_zones[3];
	struct zonelist___418 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___419 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___419 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___418 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___418 {
	struct rw_semaphore___419 rwsem;
	struct notifier_block *head;
};

struct cgroup___266;

struct cgroup_subsys___266;

struct cgroup_subsys_state___266 {
	struct cgroup___266 *cgroup;
	struct cgroup_subsys___266 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___266 *parent;
};

struct cgroup_file___266 {
	struct kernfs_node___412 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___153;

struct mem_cgroup___153 {
	struct cgroup_subsys_state___266 css;
	struct mem_cgroup_id___21 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___266 events_file;
	struct cgroup_file___266 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___419 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___153 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct vm_operations_struct___405;

struct vm_area_struct___418 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___418 *vm_next;
	struct vm_area_struct___418 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___418 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___405 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___417 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___418;

struct mm_struct___418 {
	struct {
		struct vm_area_struct___418 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___417 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___419 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___418 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___419 *owner;
		struct user_namespace___282 *user_ns;
		struct file___417 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___418 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___385 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___385 *session_keyring;
	struct key___385 *process_keyring;
	struct key___385 *thread_keyring;
	struct key___385 *request_key_auth;
	void *security;
	struct user_struct___385 *user;
	struct user_namespace___282 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___266;

struct nsproxy___312 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net___74 *net_ns;
	struct cgroup_namespace___266 *cgroup_ns;
};

struct signal_struct___292 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___419 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___419 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___236 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___236 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___418 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___236 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___210;

struct bio_list___210 {
	struct bio___210 *head;
	struct bio___210 *tail;
};

struct bdi_writeback_congested___210;

struct bdi_writeback___210 {
	struct backing_dev_info___210 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___210 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___266 *memcg_css;
	struct cgroup_subsys_state___266 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___210 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___210 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___385 *dev;
	struct device___385 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___417 *debug_dir;
	struct dentry___417 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___266 {
	struct cgroup_subsys_state___266 *subsys[13];
	refcount_t refcount;
	struct css_set___266 *dom_cset;
	struct cgroup___266 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___266 *mg_src_cgrp;
	struct cgroup___266 *mg_dst_cgrp;
	struct css_set___266 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___417;

struct pipe_buffer___98;

struct pipe_inode_info___98 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___418 *tmp_page;
	struct fasync_struct___417 *fasync_readers;
	struct fasync_struct___417 *fasync_writers;
	struct pipe_buffer___98 *bufs;
	struct user_struct___385 *user;
};

struct vm_struct___321 {
	struct vm_struct___321 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___418 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___304 {
	struct task_struct___419 task;
	long unsigned int stack[8192];
};

struct address_space_operations___417;

struct address_space___417 {
	struct inode___417 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___419 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___417 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___405)(struct vm_area_struct___418 *, long unsigned int, const struct page___418 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___405)(struct page___418 *, void *);

struct dev_pagemap___405 {
	dev_page_fault_t___405 page_fault;
	dev_page_free_t___405 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___385 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct vm_fault___405;

struct vm_operations_struct___405 {
	void (*open)(struct vm_area_struct___418 *);
	void (*close)(struct vm_area_struct___418 *);
	int (*split)(struct vm_area_struct___418 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___418 *);
	vm_fault_t (*fault)(struct vm_fault___405 *);
	vm_fault_t (*huge_fault)(struct vm_fault___405 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___405 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___418 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___405 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___405 *);
	int (*access)(struct vm_area_struct___418 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___418 *);
	int (*set_policy)(struct vm_area_struct___418 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___418 *, long unsigned int);
	struct page___418 * (*find_special_page)(struct vm_area_struct___418 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___418 {
	struct task_struct___419 *task;
	struct core_thread___418 *next;
};

struct core_state___418 {
	atomic_t nr_threads;
	struct core_thread___418 dumper;
	struct completion startup;
};

struct vm_fault___405 {
	struct vm_area_struct___418 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___418 *cow_page;
	struct mem_cgroup___153 *memcg;
	struct page___418 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___418 prealloc_pte;
};

struct crypto_async_request___25;

typedef void (*crypto_completion_t___25)(struct crypto_async_request___25 *, int);

struct crypto_tfm___25;

struct crypto_async_request___25 {
	struct list_head list;
	crypto_completion_t___25 complete;
	void *data;
	struct crypto_tfm___25 *tfm;
	u32 flags;
};

struct crypto_ablkcipher___25;

struct ablkcipher_request___25;

struct ablkcipher_tfm___25 {
	int (*setkey)(struct crypto_ablkcipher___25 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___25 *);
	int (*decrypt)(struct ablkcipher_request___25 *);
	struct crypto_ablkcipher___25 *base;
	unsigned int ivsize;
	unsigned int reqsize;
};

struct blkcipher_desc___25;

struct blkcipher_tfm___25 {
	void *iv;
	int (*setkey)(struct crypto_tfm___25 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___25 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___25 *, struct scatterlist *, struct scatterlist *, unsigned int);
};

struct cipher_tfm___25 {
	int (*cit_setkey)(struct crypto_tfm___25 *, const u8 *, unsigned int);
	void (*cit_encrypt_one)(struct crypto_tfm___25 *, u8 *, const u8 *);
	void (*cit_decrypt_one)(struct crypto_tfm___25 *, u8 *, const u8 *);
};

struct compress_tfm___25 {
	int (*cot_compress)(struct crypto_tfm___25 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*cot_decompress)(struct crypto_tfm___25 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___25;

struct crypto_tfm___25 {
	u32 crt_flags;
	union {
		struct ablkcipher_tfm___25 ablkcipher;
		struct blkcipher_tfm___25 blkcipher;
		struct cipher_tfm___25 cipher;
		struct compress_tfm___25 compress;
	} crt_u;
	void (*exit)(struct crypto_tfm___25 *);
	struct crypto_alg___25 *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct ablkcipher_request___25 {
	struct crypto_async_request___25 base;
	unsigned int nbytes;
	void *info;
	struct scatterlist *src;
	struct scatterlist *dst;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_blkcipher___25;

struct blkcipher_desc___25 {
	struct crypto_blkcipher___25 *tfm;
	void *info;
	u32 flags;
};

struct crypto_blkcipher___25 {
	struct crypto_tfm___25 base;
};

struct ablkcipher_alg___25 {
	int (*setkey)(struct crypto_ablkcipher___25 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___25 *);
	int (*decrypt)(struct ablkcipher_request___25 *);
	int (*givencrypt)(struct skcipher_givcrypt_request *);
	int (*givdecrypt)(struct skcipher_givcrypt_request *);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct crypto_ablkcipher___25 {
	struct crypto_tfm___25 base;
};

struct blkcipher_alg___25 {
	int (*setkey)(struct crypto_tfm___25 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___25 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___25 *, struct scatterlist *, struct scatterlist *, unsigned int);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct cipher_alg___25 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___25 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___25 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___25 *, u8 *, const u8 *);
};

struct compress_alg___25 {
	int (*coa_compress)(struct crypto_tfm___25 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___25 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___25 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type *cra_type;
	union {
		struct ablkcipher_alg___25 ablkcipher;
		struct blkcipher_alg___25 blkcipher;
		struct cipher_alg___25 cipher;
		struct compress_alg___25 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___25 *);
	void (*cra_exit)(struct crypto_tfm___25 *);
	void (*cra_destroy)(struct crypto_alg___25 *);
	struct module___347 *cra_module;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___345 {
	struct kobject___405 kobj;
	struct module___347 *mod;
	struct kobject___405 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___345 {
	struct module___347 *mod;
	struct latch_tree_node node;
};

struct module_layout___345 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___345 mtn;
};

struct module_attribute___345;

struct kernel_param___345;

struct module___347 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___345 mkobj;
	struct module_attribute___345 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___405 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___345 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___345 core_layout;
	struct module_layout___345 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct crypto_cipher___9 {
	struct crypto_tfm___25 base;
};

struct bio_vec___212 {
	struct page___418 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___184 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___212 *bvec;
		struct pipe_inode_info___98 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct msghdr___48 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___184 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___417 *msg_iocb;
};

struct kiocb___417 {
	struct file___417 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___417 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dentry_operations___417;

struct super_block___417;

struct dentry___417 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___417 *d_parent;
	struct qstr d_name;
	struct inode___417 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___417 *d_op;
	struct super_block___417 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___417;

struct block_device___417;

struct inode___417 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___417 *i_op;
	struct super_block___417 *i_sb;
	struct address_space___417 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___419 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___210 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___417 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___417 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___98 *i_pipe;
		struct block_device___417 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___417 {
	int (*d_revalidate)(struct dentry___417 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___417 *, unsigned int);
	int (*d_hash)(const struct dentry___417 *, struct qstr *);
	int (*d_compare)(const struct dentry___417 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___417 *);
	int (*d_init)(struct dentry___417 *);
	void (*d_release)(struct dentry___417 *);
	void (*d_prune)(struct dentry___417 *);
	void (*d_iput)(struct dentry___417 *, struct inode___417 *);
	char * (*d_dname)(struct dentry___417 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___418 *);
	int (*d_manage)(const struct path___418 *, bool);
	struct dentry___417 * (*d_real)(struct dentry___417 *, const struct inode___417 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___417;

struct mem_dqinfo___417 {
	struct quota_format_type___417 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___417;

struct quota_info___417 {
	unsigned int flags;
	struct rw_semaphore___419 dqio_sem;
	struct inode___417 *files[3];
	struct mem_dqinfo___417 info[3];
	const struct quota_format_ops___417 *ops[3];
};

struct rcuwait___417 {
	struct task_struct___419 *task;
};

struct percpu_rw_semaphore___417 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___419 rw_sem;
	struct rcuwait___417 writer;
	int readers_block;
};

struct sb_writers___417 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___417 rw_sem[3];
};

struct shrink_control___153;

struct shrinker___153 {
	long unsigned int (*count_objects)(struct shrinker___153 *, struct shrink_control___153 *);
	long unsigned int (*scan_objects)(struct shrinker___153 *, struct shrink_control___153 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___417;

struct super_operations___417;

struct dquot_operations___417;

struct quotactl_ops___417;

struct super_block___417 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___417 *s_type;
	const struct super_operations___417 *s_op;
	const struct dquot_operations___417 *dq_op;
	const struct quotactl_ops___417 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___417 *s_root;
	struct rw_semaphore___419 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___417 *s_bdev;
	struct backing_dev_info___210 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___417 s_dquot;
	struct sb_writers___417 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___417 *s_d_op;
	int cleancache_poolid;
	struct shrinker___153 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___282 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___153 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___153 *memcg;
};

struct iattr___417 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___417 *ia_file;
};

struct dquot___417 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___417 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___417 {
	int qf_fmt_id;
	const struct quota_format_ops___417 *qf_ops;
	struct module___347 *qf_owner;
	struct quota_format_type___417 *qf_next;
};

struct quota_format_ops___417 {
	int (*check_quota_file)(struct super_block___417 *, int);
	int (*read_file_info)(struct super_block___417 *, int);
	int (*write_file_info)(struct super_block___417 *, int);
	int (*free_file_info)(struct super_block___417 *, int);
	int (*read_dqblk)(struct dquot___417 *);
	int (*commit_dqblk)(struct dquot___417 *);
	int (*release_dqblk)(struct dquot___417 *);
	int (*get_next_id)(struct super_block___417 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___417 {
	int (*write_dquot)(struct dquot___417 *);
	struct dquot___417 * (*alloc_dquot)(struct super_block___417 *, int);
	void (*destroy_dquot)(struct dquot___417 *);
	int (*acquire_dquot)(struct dquot___417 *);
	int (*release_dquot)(struct dquot___417 *);
	int (*mark_dirty)(struct dquot___417 *);
	int (*write_info)(struct super_block___417 *, int);
	qsize_t * (*get_reserved_space)(struct inode___417 *);
	int (*get_projid)(struct inode___417 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___417 *, qsize_t *);
	int (*get_next_id)(struct super_block___417 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___417 {
	int (*quota_on)(struct super_block___417 *, int, int, const struct path___418 *);
	int (*quota_off)(struct super_block___417 *, int);
	int (*quota_enable)(struct super_block___417 *, unsigned int);
	int (*quota_disable)(struct super_block___417 *, unsigned int);
	int (*quota_sync)(struct super_block___417 *, int);
	int (*set_info)(struct super_block___417 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___417 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___417 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___417 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___417 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___417 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___173;

struct address_space_operations___417 {
	int (*writepage)(struct page___418 *, struct writeback_control___173 *);
	int (*readpage)(struct file___417 *, struct page___418 *);
	int (*writepages)(struct address_space___417 *, struct writeback_control___173 *);
	int (*set_page_dirty)(struct page___418 *);
	int (*readpages)(struct file___417 *, struct address_space___417 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___417 *, struct address_space___417 *, loff_t, unsigned int, unsigned int, struct page___418 **, void **);
	int (*write_end)(struct file___417 *, struct address_space___417 *, loff_t, unsigned int, unsigned int, struct page___418 *, void *);
	sector_t (*bmap)(struct address_space___417 *, sector_t);
	void (*invalidatepage)(struct page___418 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___418 *, gfp_t);
	void (*freepage)(struct page___418 *);
	ssize_t (*direct_IO)(struct kiocb___417 *, struct iov_iter___184 *);
	int (*migratepage)(struct address_space___417 *, struct page___418 *, struct page___418 *, enum migrate_mode);
	bool (*isolate_page)(struct page___418 *, isolate_mode_t);
	void (*putback_page)(struct page___418 *);
	int (*launder_page)(struct page___418 *);
	int (*is_partially_uptodate)(struct page___418 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___418 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___417 *, struct page___418 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___417 *, sector_t *);
	void (*swap_deactivate)(struct file___417 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___173 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___210 *wb;
	struct inode___417 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___417 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___417 *bd_inode;
	struct super_block___417 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___417 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___210 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___417 {
	struct dentry___417 * (*lookup)(struct inode___417 *, struct dentry___417 *, unsigned int);
	const char * (*get_link)(struct dentry___417 *, struct inode___417 *, struct delayed_call *);
	int (*permission)(struct inode___417 *, int);
	struct posix_acl * (*get_acl)(struct inode___417 *, int);
	int (*readlink)(struct dentry___417 *, char *, int);
	int (*create)(struct inode___417 *, struct dentry___417 *, umode_t, bool);
	int (*link)(struct dentry___417 *, struct inode___417 *, struct dentry___417 *);
	int (*unlink)(struct inode___417 *, struct dentry___417 *);
	int (*symlink)(struct inode___417 *, struct dentry___417 *, const char *);
	int (*mkdir)(struct inode___417 *, struct dentry___417 *, umode_t);
	int (*rmdir)(struct inode___417 *, struct dentry___417 *);
	int (*mknod)(struct inode___417 *, struct dentry___417 *, umode_t, dev_t);
	int (*rename)(struct inode___417 *, struct dentry___417 *, struct inode___417 *, struct dentry___417 *, unsigned int);
	int (*setattr)(struct dentry___417 *, struct iattr___417 *);
	int (*getattr)(const struct path___418 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___417 *, char *, size_t);
	int (*fiemap)(struct inode___417 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___417 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___417 *, struct dentry___417 *, struct file___417 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___417 *, struct dentry___417 *, umode_t);
	int (*set_acl)(struct inode___417 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___417 {
	void (*fl_copy_lock)(struct file_lock___417 *, struct file_lock___417 *);
	void (*fl_release_private)(struct file_lock___417 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___417;

struct file_lock___417 {
	struct file_lock___417 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___417 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___417 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___417 *fl_ops;
	const struct lock_manager_operations___417 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___417 {
	int (*lm_compare_owner)(struct file_lock___417 *, struct file_lock___417 *);
	long unsigned int (*lm_owner_key)(struct file_lock___417 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___417 *);
	int (*lm_grant)(struct file_lock___417 *, int);
	bool (*lm_break)(struct file_lock___417 *);
	int (*lm_change)(struct file_lock___417 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___417 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___417 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___417 *fa_next;
	struct file___417 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___417 {
	const char *name;
	int fs_flags;
	struct dentry___417 * (*mount)(struct file_system_type___417 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___417 *);
	struct module___347 *owner;
	struct file_system_type___417 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___417 {
	struct inode___417 * (*alloc_inode)(struct super_block___417 *);
	void (*destroy_inode)(struct inode___417 *);
	void (*dirty_inode)(struct inode___417 *, int);
	int (*write_inode)(struct inode___417 *, struct writeback_control___173 *);
	int (*drop_inode)(struct inode___417 *);
	void (*evict_inode)(struct inode___417 *);
	void (*put_super)(struct super_block___417 *);
	int (*sync_fs)(struct super_block___417 *, int);
	int (*freeze_super)(struct super_block___417 *);
	int (*freeze_fs)(struct super_block___417 *);
	int (*thaw_super)(struct super_block___417 *);
	int (*unfreeze_fs)(struct super_block___417 *);
	int (*statfs)(struct dentry___417 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___417 *, int *, char *);
	void (*umount_begin)(struct super_block___417 *);
	int (*show_options)(struct seq_file___356 *, struct dentry___417 *);
	int (*show_devname)(struct seq_file___356 *, struct dentry___417 *);
	int (*show_path)(struct seq_file___356 *, struct dentry___417 *);
	int (*show_stats)(struct seq_file___356 *, struct dentry___417 *);
	ssize_t (*quota_read)(struct super_block___417 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___417 *, int, const char *, size_t, loff_t);
	struct dquot___417 ** (*get_dquots)(struct inode___417 *);
	int (*bdev_try_to_free_page)(struct super_block___417 *, struct page___418 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___417 *, struct shrink_control___153 *);
	long int (*free_cached_objects)(struct super_block___417 *, struct shrink_control___153 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___269)(struct file___417 *, wait_queue_head_t *, struct poll_table_struct___259 *);

struct poll_table_struct___259 {
	poll_queue_proc___269 _qproc;
	__poll_t _key;
};

typedef void bio_end_io_t___210(struct bio___210 *);

struct bio_integrity_payload___210;

struct bio_set___210;

struct bio___210 {
	struct bio___210 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___210 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___210 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___212 *bi_io_vec;
	struct bio_set___210 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___212 bi_inline_vecs[0];
};

struct socket_wq___46 {
	wait_queue_head_t wait;
	struct fasync_struct___417 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct sock___46;

struct proto_ops___46;

struct socket___47 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___46 *wq;
	struct file___417 *file;
	struct sock___46 *sk;
	const struct proto_ops___46 *ops;
};

struct proto___45;

struct sock_common___45 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___45 *skc_prot;
	possible_net_t___64 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___46 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff_head___62 {
	struct sk_buff___64 *next;
	struct sk_buff___64 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___45;

struct dst_entry___45;

struct sock___46 {
	struct sock_common___45 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___62 sk_error_queue;
	struct sk_buff_head___62 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___64 *head;
		struct sk_buff___64 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___45 *sk_filter;
	union {
		struct socket_wq___46 *sk_wq;
		struct socket_wq___46 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___45 *sk_rx_dst;
	struct dst_entry___45 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___64 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___62 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___418 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___45 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___236 *sk_peer_pid;
	const struct cred___385 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___47 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___153 *sk_memcg;
	void (*sk_state_change)(struct sock___46 *);
	void (*sk_data_ready)(struct sock___46 *);
	void (*sk_write_space)(struct sock___46 *);
	void (*sk_error_report)(struct sock___46 *);
	int (*sk_backlog_rcv)(struct sock___46 *, struct sk_buff___64 *);
	struct sk_buff___64 * (*sk_validate_xmit_skb)(struct sock___46 *, struct net_device___63 *, struct sk_buff___64 *);
	void (*sk_destruct)(struct sock___46 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

typedef int (*sk_read_actor_t___45)(read_descriptor_t *, struct sk_buff___64 *, unsigned int, size_t);

struct proto_ops___46 {
	int family;
	struct module___347 *owner;
	int (*release)(struct socket___47 *);
	int (*bind)(struct socket___47 *, struct sockaddr *, int);
	int (*connect)(struct socket___47 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___47 *, struct socket___47 *);
	int (*accept)(struct socket___47 *, struct socket___47 *, int, bool);
	int (*getname)(struct socket___47 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___417 *, struct socket___47 *, struct poll_table_struct___259 *);
	int (*ioctl)(struct socket___47 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___47 *, int);
	int (*shutdown)(struct socket___47 *, int);
	int (*setsockopt)(struct socket___47 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___47 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___47 *, struct msghdr___48 *, size_t);
	int (*recvmsg)(struct socket___47 *, struct msghdr___48 *, size_t, int);
	int (*mmap)(struct file___417 *, struct socket___47 *, struct vm_area_struct___418 *);
	ssize_t (*sendpage)(struct socket___47 *, struct page___418 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___47 *, loff_t *, struct pipe_inode_info___98 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___46 *, int);
	int (*peek_len)(struct socket___47 *);
	int (*read_sock)(struct sock___46 *, read_descriptor_t *, sk_read_actor_t___45);
	int (*sendpage_locked)(struct sock___46 *, struct page___418 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___46 *, struct msghdr___48 *, size_t);
	int (*set_rcvlowat)(struct sock___46 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct nf_bridge_info___62;

struct sk_buff___64 {
	union {
		struct {
			struct sk_buff___64 *next;
			struct sk_buff___64 *prev;
			union {
				struct net_device___63 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___46 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___64 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___62 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___62;

struct netns_frags___62 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___62 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ip_ra_chain___22;

struct fib_rules_ops___45;

struct tcp_congestion_ops___6;

struct tcp_fastopen_context___6;

struct fib_notifier_ops___46;

struct netns_ipv4___62 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___22 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___45 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___46 *fibnl;
	struct sock___46 **icmp_sk;
	struct sock___46 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___46 **tcp_sk;
	struct netns_frags___62 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops___6 *tcp_congestion_control;
	struct tcp_fastopen_context___6 *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___45 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___46 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___46 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___45;

struct dst_ops___73 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___73 *);
	struct dst_entry___45 * (*check)(struct dst_entry___45 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___45 *);
	unsigned int (*mtu)(const struct dst_entry___45 *);
	u32 * (*cow_metrics)(struct dst_entry___45 *, long unsigned int);
	void (*destroy)(struct dst_entry___45 *);
	void (*ifdown)(struct dst_entry___45 *, struct net_device___63 *, int);
	struct dst_entry___45 * (*negative_advice)(struct dst_entry___45 *);
	void (*link_failure)(struct sk_buff___64 *);
	void (*update_pmtu)(struct dst_entry___45 *, struct sock___46 *, struct sk_buff___64 *, u32);
	void (*redirect)(struct dst_entry___45 *, struct sock___46 *, struct sk_buff___64 *);
	int (*local_out)(struct net___74 *, struct sock___46 *, struct sk_buff___64 *);
	struct neighbour___45 * (*neigh_lookup)(const struct dst_entry___45 *, struct sk_buff___64 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___45 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___73 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___62 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___73 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___45 *fib6_rules_ops;
	struct sock___46 **icmp_sk;
	struct sock___46 *ndisc_sk;
	struct sock___46 *tcp_sk;
	struct sock___46 *igmp_sk;
	struct sock___46 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___45 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___46 *notifier_ops;
	struct fib_notifier_ops___46 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___46 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___46 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___62 {
	struct netns_frags___62 frags;
};

struct netns_xfrm___73 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___46 *nlsk;
	struct sock___46 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___73 xfrm4_dst_ops;
	struct dst_ops___73 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct net___74 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___282 *user_ns;
	struct ucounts___282 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___29 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___46 *rtnl;
	struct sock___46 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___63 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___62 ipv4;
	struct netns_ipv6___73 ipv6;
	struct netns_sctp___46 sctp;
	struct netns_nf___4 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___62 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___46 *nfnl;
	struct sock___46 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___73 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___46 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___55 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kernfs_root___411;

struct kernfs_elem_dir___411 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___411 *root;
};

struct kernfs_syscall_ops___411;

struct kernfs_root___411 {
	struct kernfs_node___412 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___411 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___411 {
	struct kernfs_node___412 *target_kn;
};

struct kernfs_ops___411;

struct kernfs_elem_attr___411 {
	const struct kernfs_ops___411 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___412 *notify_next;
};

struct kernfs_node___412 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___412 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___411 dir;
		struct kernfs_elem_symlink___411 symlink;
		struct kernfs_elem_attr___411 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___411;

struct kernfs_ops___411 {
	int (*open)(struct kernfs_open_file___411 *);
	void (*release)(struct kernfs_open_file___411 *);
	int (*seq_show)(struct seq_file___356 *, void *);
	void * (*seq_start)(struct seq_file___356 *, loff_t *);
	void * (*seq_next)(struct seq_file___356 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___356 *, void *);
	ssize_t (*read)(struct kernfs_open_file___411 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___411 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___411 *, struct vm_area_struct___418 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___411 *, struct poll_table_struct___259 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___411 {
	int (*remount_fs)(struct kernfs_root___411 *, int *, char *);
	int (*show_options)(struct seq_file___356 *, struct kernfs_root___411 *);
	int (*mkdir)(struct kernfs_node___412 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___412 *);
	int (*rename)(struct kernfs_node___412 *, struct kernfs_node___412 *, const char *);
	int (*show_path)(struct seq_file___356 *, struct kernfs_node___412 *, struct kernfs_root___411 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___411 {
	struct kernfs_node___412 *kn;
	struct file___417 *file;
	struct seq_file___356 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___405 *vm_ops;
};

struct kobj_ns_type_operations___45 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___46 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___381;

struct attribute_group___382 {
	const char *name;
	umode_t (*is_visible)(struct kobject___405 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___405 *, struct bin_attribute___381 *, int);
	struct attribute **attrs;
	struct bin_attribute___381 **bin_attrs;
};

struct bin_attribute___381 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___417 *, struct kobject___405 *, struct bin_attribute___381 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___417 *, struct kobject___405 *, struct bin_attribute___381 *, char *, loff_t, size_t);
	int (*mmap)(struct file___417 *, struct kobject___405 *, struct bin_attribute___381 *, struct vm_area_struct___418 *);
};

struct sysfs_ops___404 {
	ssize_t (*show)(struct kobject___405 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___405 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___404;

struct kset___404 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___405 kobj;
	const struct kset_uevent_ops___404 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___404 {
	void (*release)(struct kobject___405 *);
	const struct sysfs_ops___404 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___45 * (*child_ns_type)(struct kobject___405 *);
	const void * (*namespace)(struct kobject___405 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___404 {
	int (* const filter)(struct kset___404 *, struct kobject___405 *);
	const char * (* const name)(struct kset___404 *, struct kobject___405 *);
	int (* const uevent)(struct kset___404 *, struct kobject___405 *, struct kobj_uevent_env *);
};

struct kobj_attribute___395 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___405 *, struct kobj_attribute___395 *, char *);
	ssize_t (*store)(struct kobject___405 *, struct kobj_attribute___395 *, const char *, size_t);
};

struct dev_pm_ops___385 {
	int (*prepare)(struct device___385 *);
	void (*complete)(struct device___385 *);
	int (*suspend)(struct device___385 *);
	int (*resume)(struct device___385 *);
	int (*freeze)(struct device___385 *);
	int (*thaw)(struct device___385 *);
	int (*poweroff)(struct device___385 *);
	int (*restore)(struct device___385 *);
	int (*suspend_late)(struct device___385 *);
	int (*resume_early)(struct device___385 *);
	int (*freeze_late)(struct device___385 *);
	int (*thaw_early)(struct device___385 *);
	int (*poweroff_late)(struct device___385 *);
	int (*restore_early)(struct device___385 *);
	int (*suspend_noirq)(struct device___385 *);
	int (*resume_noirq)(struct device___385 *);
	int (*freeze_noirq)(struct device___385 *);
	int (*thaw_noirq)(struct device___385 *);
	int (*poweroff_noirq)(struct device___385 *);
	int (*restore_noirq)(struct device___385 *);
	int (*runtime_suspend)(struct device___385 *);
	int (*runtime_resume)(struct device___385 *);
	int (*runtime_idle)(struct device___385 *);
};

struct dev_pm_domain___385 {
	struct dev_pm_ops___385 ops;
	void (*detach)(struct device___385 *, bool);
	int (*activate)(struct device___385 *);
	void (*sync)(struct device___385 *);
	void (*dismiss)(struct device___385 *);
};

struct bus_type___385 {
	const char *name;
	const char *dev_name;
	struct device___385 *dev_root;
	const struct attribute_group___382 **bus_groups;
	const struct attribute_group___382 **dev_groups;
	const struct attribute_group___382 **drv_groups;
	int (*match)(struct device___385 *, struct device_driver___385 *);
	int (*uevent)(struct device___385 *, struct kobj_uevent_env *);
	int (*probe)(struct device___385 *);
	int (*remove)(struct device___385 *);
	void (*shutdown)(struct device___385 *);
	int (*online)(struct device___385 *);
	int (*offline)(struct device___385 *);
	int (*suspend)(struct device___385 *, pm_message_t);
	int (*resume)(struct device___385 *);
	int (*num_vf)(struct device___385 *);
	int (*dma_configure)(struct device___385 *);
	const struct dev_pm_ops___385 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___385 {
	const char *name;
	struct bus_type___385 *bus;
	struct module___347 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___385 *);
	int (*remove)(struct device___385 *);
	void (*shutdown)(struct device___385 *);
	int (*suspend)(struct device___385 *, pm_message_t);
	int (*resume)(struct device___385 *);
	const struct attribute_group___382 **groups;
	const struct dev_pm_ops___385 *pm;
	void (*coredump)(struct device___385 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___385 {
	const char *name;
	const struct attribute_group___382 **groups;
	int (*uevent)(struct device___385 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___385 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___385 *);
	const struct dev_pm_ops___385 *pm;
};

struct class___385 {
	const char *name;
	struct module___347 *owner;
	const struct attribute_group___382 **class_groups;
	const struct attribute_group___382 **dev_groups;
	struct kobject___405 *dev_kobj;
	int (*dev_uevent)(struct device___385 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___385 *, umode_t *);
	void (*class_release)(struct class___385 *);
	void (*dev_release)(struct device___385 *);
	int (*shutdown_pre)(struct device___385 *);
	const struct kobj_ns_type_operations___45 *ns_type;
	const void * (*namespace)(struct device___385 *);
	const struct dev_pm_ops___385 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___157 {
	void * (*alloc)(struct device___385 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___385 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___385 *, struct vm_area_struct___418 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___385 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___385 *, struct page___418 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___385 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___385 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___385 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___385 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___385 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___385 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___385 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___385 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___385 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___385 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___385 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___385 *, u64);
	u64 (*get_required_mask)(struct device___385 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___305;

struct fwnode_handle___305 {
	struct fwnode_handle___305 *secondary;
	const struct fwnode_operations___305 *ops;
};

typedef void compound_page_dtor___405(struct page___418 *);

struct fwnode_reference_args___305;

struct fwnode_endpoint___305;

struct fwnode_operations___305 {
	struct fwnode_handle___305 * (*get)(struct fwnode_handle___305 *);
	void (*put)(struct fwnode_handle___305 *);
	bool (*device_is_available)(const struct fwnode_handle___305 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___305 *, const struct device___385 *);
	bool (*property_present)(const struct fwnode_handle___305 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___305 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___305 *, const char *, const char **, size_t);
	struct fwnode_handle___305 * (*get_parent)(const struct fwnode_handle___305 *);
	struct fwnode_handle___305 * (*get_next_child_node)(const struct fwnode_handle___305 *, struct fwnode_handle___305 *);
	struct fwnode_handle___305 * (*get_named_child_node)(const struct fwnode_handle___305 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___305 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___305 *);
	struct fwnode_handle___305 * (*graph_get_next_endpoint)(const struct fwnode_handle___305 *, struct fwnode_handle___305 *);
	struct fwnode_handle___305 * (*graph_get_remote_endpoint)(const struct fwnode_handle___305 *);
	struct fwnode_handle___305 * (*graph_get_port_parent)(struct fwnode_handle___305 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___305 *, struct fwnode_endpoint___305 *);
};

struct fwnode_endpoint___305 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___305 *local_fwnode;
};

struct fwnode_reference_args___305 {
	struct fwnode_handle___305 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___98;

struct pipe_buffer___98 {
	struct page___418 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___98 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___98 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___98 *, struct pipe_buffer___98 *);
	void (*release)(struct pipe_inode_info___98 *, struct pipe_buffer___98 *);
	int (*steal)(struct pipe_inode_info___98 *, struct pipe_buffer___98 *);
	union {
		bool (*get)(struct pipe_inode_info___98 *, struct pipe_buffer___98 *);
		struct {
			void (*get)(struct pipe_inode_info___98 *, struct pipe_buffer___98 *);
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
};

struct nf_bridge_info___62 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___62 = 0,
		BRNF_PROTO_8021Q___62 = 1,
		BRNF_PROTO_PPPOE___62 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___63 *physindev;
	struct net_device___63 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

struct kernel_param_ops___345 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___345 *);
	int (*get)(char *, const struct kernel_param___345 *);
	void (*free)(void *);
};

struct kparam_array___345;

struct kernel_param___345 {
	const char *name;
	struct module___347 *mod;
	const struct kernel_param_ops___345 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___345 *arr;
	};
};

struct kparam_array___345 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___345 *ops;
	void *elem;
};

struct module_attribute___345 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___345 *, struct module_kobject___345 *, char *);
	ssize_t (*store)(struct module_attribute___345 *, struct module_kobject___345 *, const char *, size_t);
	void (*setup)(struct module___347 *, const char *);
	int (*test)(struct module___347 *);
	void (*free)(struct module___347 *);
};

struct ethtool_ops___62 {
	int (*get_settings)(struct net_device___63 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___63 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___63 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___63 *);
	void (*get_regs)(struct net_device___63 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___63 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___63 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___63 *);
	void (*set_msglevel)(struct net_device___63 *, u32);
	int (*nway_reset)(struct net_device___63 *);
	u32 (*get_link)(struct net_device___63 *);
	int (*get_eeprom_len)(struct net_device___63 *);
	int (*get_eeprom)(struct net_device___63 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___63 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___63 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___63 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___63 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___63 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___63 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___63 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___63 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___63 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___63 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___63 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___63 *);
	void (*complete)(struct net_device___63 *);
	u32 (*get_priv_flags)(struct net_device___63 *);
	int (*set_priv_flags)(struct net_device___63 *, u32);
	int (*get_sset_count)(struct net_device___63 *, int);
	int (*get_rxnfc)(struct net_device___63 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___63 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___63 *, struct ethtool_flash *);
	int (*reset)(struct net_device___63 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___63 *);
	u32 (*get_rxfh_indir_size)(struct net_device___63 *);
	int (*get_rxfh)(struct net_device___63 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___63 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___63 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___63 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___63 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___63 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___63 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___63 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___63 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___63 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___63 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___63 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___63 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___63 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___63 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___63 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___63 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___63 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___63 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___63 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___63 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___63 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	int (*get_fecparam)(struct net_device___63 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___63 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___63 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___63 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___63 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___62;

struct inet_frags___62 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___62 *, const void *);
	void (*destructor)(struct inet_frag_queue___62 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___62 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___64 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___64 *fragments_tail;
	struct sk_buff___64 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___62 *net;
	struct callback_head rcu;
};

struct ip_ra_chain___22 {
	struct ip_ra_chain___22 *next;
	struct sock___46 *sk;
	union {
		void (*destructor)(struct sock___46 *);
		struct sock___46 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___45;

struct fib_lookup_arg___45;

struct fib_rules_ops___45 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___45 *, struct flowi *, int, struct fib_lookup_arg___45 *);
	bool (*suppress)(struct fib_rule___45 *, struct fib_lookup_arg___45 *);
	int (*match)(struct fib_rule___45 *, struct flowi *, int);
	int (*configure)(struct fib_rule___45 *, struct sk_buff___64 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___45 *);
	int (*compare)(struct fib_rule___45 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___45 *, struct sk_buff___64 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___45 *);
	void (*flush_cache)(struct fib_rules_ops___45 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___347 *owner;
	struct net___74 *fro_net;
	struct callback_head rcu;
};

struct tcp_congestion_ops___6 {
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___46 *);
	void (*release)(struct sock___46 *);
	u32 (*ssthresh)(struct sock___46 *);
	void (*cong_avoid)(struct sock___46 *, u32, u32);
	void (*set_state)(struct sock___46 *, u8);
	void (*cwnd_event)(struct sock___46 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___46 *, u32);
	u32 (*undo_cwnd)(struct sock___46 *);
	void (*pkts_acked)(struct sock___46 *, const struct ack_sample *);
	u32 (*min_tso_segs)(struct sock___46 *);
	u32 (*sndbuf_expand)(struct sock___46 *);
	void (*cong_control)(struct sock___46 *, const struct rate_sample *);
	size_t (*get_info)(struct sock___46 *, u32, int *, union tcp_cc_info *);
	char name[16];
	struct module___347 *owner;
};

struct tcp_fastopen_context___6 {
	struct crypto_cipher___9 *tfm;
	__u8 key[16];
	struct callback_head rcu;
};

struct fib_notifier_ops___46 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___74 *);
	int (*fib_dump)(struct net___74 *, struct notifier_block *);
	struct module___347 *owner;
	struct callback_head rcu;
};

struct dst_entry___45 {
	struct net_device___63 *dev;
	struct dst_ops___73 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___64 *);
	int (*output)(struct net___74 *, struct sock___46 *, struct sk_buff___64 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___45;

struct neigh_parms___45;

struct neigh_ops___45;

struct neighbour___45 {
	struct neighbour___45 *next;
	struct neigh_table___45 *tbl;
	struct neigh_parms___45 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___62 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___45 *, struct sk_buff___64 *);
	const struct neigh_ops___45 *ops;
	struct callback_head rcu;
	struct net_device___63 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct ucounts___282 {
	struct hlist_node node;
	struct user_namespace___282 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

typedef int (*key_restrict_link_func_t___386)(struct key___385 *, const struct key_type *, const union key_payload *, struct key___385 *);

struct key_restriction___385;

struct key___385 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___419 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___385 *restrict_link;
};

struct key_restriction___385 {
	key_restrict_link_func_t___386 check;
	struct key___385 *key;
	struct key_type *keytype;
};

struct seq_operations___356 {
	void * (*start)(struct seq_file___356 *, loff_t *);
	void (*stop)(struct seq_file___356 *, void *);
	void * (*next)(struct seq_file___356 *, void *, loff_t *);
	int (*show)(struct seq_file___356 *, void *);
};

struct pernet_operations___63 {
	struct list_head list;
	int (*init)(struct net___74 *);
	void (*exit)(struct net___74 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___62 {
	int (*ieee_getets)(struct net_device___63 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___63 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___63 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___63 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___63 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___63 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___63 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___63 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___63 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___63 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___63 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___63 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___63 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___63 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___63 *);
	u8 (*setstate)(struct net_device___63 *, u8);
	void (*getpermhwaddr)(struct net_device___63 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___63 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___63 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___63 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___63 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___63 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___63 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___63 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___63 *, int, u8 *);
	void (*setpfccfg)(struct net_device___63 *, int, u8);
	void (*getpfccfg)(struct net_device___63 *, int, u8 *);
	u8 (*setall)(struct net_device___63 *);
	u8 (*getcap)(struct net_device___63 *, int, u8 *);
	int (*getnumtcs)(struct net_device___63 *, int, u8 *);
	int (*setnumtcs)(struct net_device___63 *, int, u8);
	u8 (*getpfcstate)(struct net_device___63 *);
	void (*setpfcstate)(struct net_device___63 *, u8);
	void (*getbcncfg)(struct net_device___63 *, int, u32 *);
	void (*setbcncfg)(struct net_device___63 *, int, u32);
	void (*getbcnrp)(struct net_device___63 *, int, u8 *);
	void (*setbcnrp)(struct net_device___63 *, int, u8);
	int (*setapp)(struct net_device___63 *, u8, u16, u8);
	int (*getapp)(struct net_device___63 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___63 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___63 *, int, u8);
	u8 (*getdcbx)(struct net_device___63 *);
	u8 (*setdcbx)(struct net_device___63 *, u8);
	int (*peer_getappinfo)(struct net_device___63 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___63 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___63 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___63 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___63 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___63 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___266 {
	refcount_t count;
	struct ns_common___29 ns;
	struct user_namespace___282 *user_ns;
	struct ucounts___282 *ucounts;
	struct css_set___266 *root_cset;
};

struct cgroup_bpf___55 {
	struct bpf_prog_array___55 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___55 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___267;

typedef void (*kthread_work_func_t___267)(struct kthread_work___267 *);

struct kthread_worker___267;

struct kthread_work___267 {
	struct list_head node;
	kthread_work_func_t___267 func;
	struct kthread_worker___267 *worker;
	int canceling;
};

struct kthread_worker___267 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___419 *task;
	struct kthread_work___267 *current_work;
};

struct kthread_delayed_work___266 {
	struct kthread_work___267 work;
	struct timer_list timer;
};

struct psi_group___266 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___267 *poll_kworker;
	struct kthread_delayed_work___266 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___266;

struct cgroup_rstat_cpu___266;

struct cgroup___266 {
	struct cgroup_subsys_state___266 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___412 *kn;
	struct cgroup_file___266 procs_file;
	struct cgroup_file___266 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___266 *subsys[13];
	struct cgroup_root___266 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___266 *dom_cgrp;
	struct cgroup_rstat_cpu___266 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___55 bpf;
	atomic_t congestion_count;
	struct cgroup___266 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___266 psi;
	int ancestor_ids[0];
};

struct cftype___266;

struct cgroup_subsys___266 {
	struct cgroup_subsys_state___266 * (*css_alloc)(struct cgroup_subsys_state___266 *);
	int (*css_online)(struct cgroup_subsys_state___266 *);
	void (*css_offline)(struct cgroup_subsys_state___266 *);
	void (*css_released)(struct cgroup_subsys_state___266 *);
	void (*css_free)(struct cgroup_subsys_state___266 *);
	void (*css_reset)(struct cgroup_subsys_state___266 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___266 *, int);
	int (*css_extra_stat_show)(struct seq_file___356 *, struct cgroup_subsys_state___266 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___419 *);
	void (*cancel_fork)(struct task_struct___419 *);
	void (*fork)(struct task_struct___419 *);
	void (*exit)(struct task_struct___419 *);
	void (*free)(struct task_struct___419 *);
	void (*bind)(struct cgroup_subsys_state___266 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___266 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___266 *dfl_cftypes;
	struct cftype___266 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___266 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___266 *updated_children;
	struct cgroup___266 *updated_next;
};

struct cgroup_root___266 {
	struct kernfs_root___411 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___266 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___266 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___266 *ss;
	struct list_head node;
	struct kernfs_ops___411 *kf_ops;
	int (*open)(struct kernfs_open_file___411 *);
	void (*release)(struct kernfs_open_file___411 *);
	u64 (*read_u64)(struct cgroup_subsys_state___266 *, struct cftype___266 *);
	s64 (*read_s64)(struct cgroup_subsys_state___266 *, struct cftype___266 *);
	int (*seq_show)(struct seq_file___356 *, void *);
	void * (*seq_start)(struct seq_file___356 *, loff_t *);
	void * (*seq_next)(struct seq_file___356 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___356 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___266 *, struct cftype___266 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___266 *, struct cftype___266 *, s64);
	ssize_t (*write)(struct kernfs_open_file___411 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___411 *, struct poll_table_struct___259 *);
};

struct xdp_rxq_info___62 {
	struct net_device___63 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___62 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___63 *dev_rx;
};

struct netlink_callback___64 {
	struct sk_buff___64 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___64 *);
	int (*dump)(struct sk_buff___64 *, struct netlink_callback___64 *);
	int (*done)(struct netlink_callback___64 *);
	void *data;
	struct module___347 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___62 {
	int (*create)(struct sk_buff___64 *, struct net_device___63 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___64 *, unsigned char *);
	int (*cache)(const struct neighbour___45 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___63 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___62 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___62 *, int);
	int poll_owner;
	struct net_device___63 *dev;
	struct sk_buff___64 *gro_list;
	struct sk_buff___64 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___62 {
	struct net_device___63 *dev;
	struct Qdisc___55 *qdisc;
	struct Qdisc___55 *qdisc_sleeping;
	struct kobject___405 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___63 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem___3 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___55 {
	struct sk_buff___64 *head;
	struct sk_buff___64 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___55;

struct Qdisc___55 {
	int (*enqueue)(struct sk_buff___64 *, struct Qdisc___55 *, struct sk_buff___64 **);
	struct sk_buff___64 * (*dequeue)(struct Qdisc___55 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___55 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___62 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___62 gso_skb;
	struct qdisc_skb_head___55 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___55 *next_sched;
	struct sk_buff_head___62 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___62 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___405 kobj;
	struct net_device___63 *dev;
	long: 64;
	struct xdp_rxq_info___62 xdp_rxq;
	union {
		struct xdp_umem___3 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___62)(struct net_device___63 *, struct sk_buff___64 *, struct net_device___63 *);

struct netdev_bpf___62 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___55 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___55 *prog;
			const struct bpf_prog_offload_ops___55 *ops;
		} verifier;
		struct {
			struct bpf_prog___55 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___62 *offmap;
		};
		struct {
			struct xdp_umem___3 *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___62 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___64 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___62 {
	int (*tls_dev_add)(struct net_device___63 *, struct sock___46 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___63 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___63 *, struct sock___46 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___62 {
	int (*ndo_init)(struct net_device___63 *);
	void (*ndo_uninit)(struct net_device___63 *);
	int (*ndo_open)(struct net_device___63 *);
	int (*ndo_stop)(struct net_device___63 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___64 *, struct net_device___63 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___64 *, struct net_device___63 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___63 *, struct sk_buff___64 *, struct net_device___63 *, select_queue_fallback_t___62);
	void (*ndo_change_rx_flags)(struct net_device___63 *, int);
	void (*ndo_set_rx_mode)(struct net_device___63 *);
	int (*ndo_set_mac_address)(struct net_device___63 *, void *);
	int (*ndo_validate_addr)(struct net_device___63 *);
	int (*ndo_do_ioctl)(struct net_device___63 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___63 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___63 *, int);
	int (*ndo_neigh_setup)(struct net_device___63 *, struct neigh_parms___45 *);
	void (*ndo_tx_timeout)(struct net_device___63 *);
	void (*ndo_get_stats64)(struct net_device___63 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___63 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___63 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___63 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___63 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___63 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___63 *);
	int (*ndo_netpoll_setup)(struct net_device___63 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___63 *);
	int (*ndo_set_vf_mac)(struct net_device___63 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___63 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___63 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___63 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___63 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___63 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___63 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___63 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___63 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___63 *, int, struct sk_buff___64 *);
	int (*ndo_set_vf_guid)(struct net_device___63 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___63 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___63 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___63 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___63 *, const struct sk_buff___64 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___63 *, struct net_device___63 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___63 *, struct net_device___63 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___63 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___63 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___63 *, struct neighbour___45 *);
	void (*ndo_neigh_destroy)(struct net_device___63 *, struct neighbour___45 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___63 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___63 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___63 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___64 *, struct netlink_callback___64 *, struct net_device___63 *, struct net_device___63 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___63 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___63 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___64 *, u32, u32, struct net_device___63 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___63 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___63 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___63 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___63 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___63 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___63 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___63 *, struct net_device___63 *);
	void (*ndo_dfwd_del_station)(struct net_device___63 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___63 *);
	int (*ndo_set_tx_maxrate)(struct net_device___63 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___63 *);
	int (*ndo_change_proto_down)(struct net_device___63 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___63 *, struct sk_buff___64 *);
	void (*ndo_set_rx_headroom)(struct net_device___63 *, int);
	int (*ndo_bpf)(struct net_device___63 *, struct netdev_bpf___62 *);
	int (*ndo_xdp_xmit)(struct net_device___63 *, int, struct xdp_frame___62 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___63 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___63 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___45 {
	possible_net_t___64 net;
	struct net_device___63 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___45 *);
	void (*neigh_cleanup)(struct neighbour___45 *);
	struct neigh_table___45 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___45 {
	u32 (*l3mdev_fib_table)(const struct net_device___63 *);
	struct sk_buff___64 * (*l3mdev_l3_rcv)(struct net_device___63 *, struct sk_buff___64 *, u16);
	struct sk_buff___64 * (*l3mdev_l3_out)(struct net_device___63 *, struct sock___46 *, struct sk_buff___64 *, u16);
	struct dst_entry___45 * (*l3mdev_link_scope_lookup)(const struct net_device___63 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct ndisc_ops___25 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___63 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___63 *, struct neighbour___45 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___63 *, u8, struct neighbour___45 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___63 *, struct sk_buff___64 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___74 *, struct net_device___63 *, const struct prefix_info *, struct inet6_dev___25 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___25;

struct inet6_dev___25 {
	struct net_device___63 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___25 *mc_list;
	struct ifmcaddr6___25 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___7 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	u8 rndid[8];
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___45 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
};

struct tcf_proto___55;

struct mini_Qdisc___55 {
	struct tcf_proto___55 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___55 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___63 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___74 *, struct net_device___63 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___63 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___63 *, struct list_head *);
	size_t (*get_size)(const struct net_device___63 *);
	int (*fill_info)(struct sk_buff___64 *, const struct net_device___63 *);
	size_t (*get_xstats_size)(const struct net_device___63 *);
	int (*fill_xstats)(struct sk_buff___64 *, const struct net_device___63 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___63 *, struct net_device___63 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___63 *, const struct net_device___63 *);
	int (*fill_slave_info)(struct sk_buff___64 *, const struct net_device___63 *, const struct net_device___63 *);
	struct net___74 * (*get_link_net)(const struct net_device___63 *);
	size_t (*get_linkxstats_size)(const struct net_device___63 *, int);
	int (*fill_linkxstats)(struct sk_buff___64 *, const struct net_device___63 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___62 {
	struct list_head poll_list;
	struct sk_buff_head___62 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___62 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___55 *output_queue;
	struct Qdisc___55 **output_queue_tailp;
	struct sk_buff___64 *completion_queue;
	struct sk_buff_head___62 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___62 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___62 input_pkt_queue;
	struct napi_struct___62 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct gnet_dump___55 {
	spinlock_t *lock;
	struct sk_buff___64 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___55;

struct Qdisc_ops___55 {
	struct Qdisc_ops___55 *next;
	const struct Qdisc_class_ops___55 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___64 *, struct Qdisc___55 *, struct sk_buff___64 **);
	struct sk_buff___64 * (*dequeue)(struct Qdisc___55 *);
	struct sk_buff___64 * (*peek)(struct Qdisc___55 *);
	int (*init)(struct Qdisc___55 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___55 *);
	void (*destroy)(struct Qdisc___55 *);
	int (*change)(struct Qdisc___55 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___55 *);
	int (*change_tx_queue_len)(struct Qdisc___55 *, unsigned int);
	int (*dump)(struct Qdisc___55 *, struct sk_buff___64 *);
	int (*dump_stats)(struct Qdisc___55 *, struct gnet_dump___55 *);
	void (*ingress_block_set)(struct Qdisc___55 *, u32);
	void (*egress_block_set)(struct Qdisc___55 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___55 *);
	u32 (*egress_block_get)(struct Qdisc___55 *);
	struct module___347 *owner;
};

struct tcf_block___55;

struct Qdisc_class_ops___55 {
	unsigned int flags;
	struct netdev_queue___62 * (*select_queue)(struct Qdisc___55 *, struct tcmsg *);
	int (*graft)(struct Qdisc___55 *, long unsigned int, struct Qdisc___55 *, struct Qdisc___55 **, struct netlink_ext_ack *);
	struct Qdisc___55 * (*leaf)(struct Qdisc___55 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___55 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___55 *, u32);
	int (*change)(struct Qdisc___55 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___55 *, long unsigned int);
	void (*walk)(struct Qdisc___55 *, struct qdisc_walker *);
	struct tcf_block___55 * (*tcf_block)(struct Qdisc___55 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___55 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___55 *, long unsigned int);
	int (*dump)(struct Qdisc___55 *, long unsigned int, struct sk_buff___64 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___55 *, long unsigned int, struct gnet_dump___55 *);
};

struct tcf_chain___55;

struct tcf_block___55 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___74 *net;
	struct Qdisc___55 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___55 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___55;

struct tcf_proto_ops___55;

struct tcf_proto___55 {
	struct tcf_proto___55 *next;
	void *root;
	int (*classify)(struct sk_buff___64 *, const struct tcf_proto___55 *, struct tcf_result___55 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___55 *ops;
	struct tcf_chain___55 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___55 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___55 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___55 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___64 *, const struct tcf_proto___55 *, struct tcf_result___55 *);
	int (*init)(struct tcf_proto___55 *);
	void (*destroy)(struct tcf_proto___55 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___55 *, u32);
	void (*put)(struct tcf_proto___55 *, void *);
	int (*change)(struct net___74 *, struct sk_buff___64 *, struct tcf_proto___55 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___55 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___55 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___55 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___74 *, struct tcf_chain___55 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___74 *, struct tcf_proto___55 *, void *, struct sk_buff___64 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___64 *, struct net___74 *, void *);
	struct module___347 *owner;
	int flags;
};

struct tcf_chain___55 {
	struct mutex filter_chain_lock;
	struct tcf_proto___55 *filter_chain;
	struct list_head list;
	struct tcf_block___55 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___55 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___45 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___55 *prog;
};

struct bpf_redirect_info___55 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___267 *map;
	struct bpf_map___267 *map_to_flush;
	u32 kern_flags;
};

struct bdi_writeback_congested___210 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___210 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___210 {
	struct bio___210 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___212 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___212 bip_inline_vecs[0];
};

struct bio_set___210 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___210 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___153 {
	struct mem_cgroup___153 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___153 {
	struct lruvec___418 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___153 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___153 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct pneigh_entry___45;

struct neigh_hash_table___45;

struct neigh_table___45 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___63 *, __u32 *);
	bool (*key_eq)(const struct neighbour___45 *, const void *);
	int (*constructor)(struct neighbour___45 *);
	int (*pconstructor)(struct pneigh_entry___45 *);
	void (*pdestructor)(struct pneigh_entry___45 *);
	void (*proxy_redo)(struct sk_buff___64 *);
	char *id;
	struct neigh_parms___45 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___62 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___45 *nht;
	struct pneigh_entry___45 **phash_buckets;
};

struct neigh_ops___45 {
	int family;
	void (*solicit)(struct neighbour___45 *, struct sk_buff___64 *);
	void (*error_report)(struct neighbour___45 *, struct sk_buff___64 *);
	int (*output)(struct neighbour___45 *, struct sk_buff___64 *);
	int (*connected_output)(struct neighbour___45 *, struct sk_buff___64 *);
};

struct pneigh_entry___45 {
	struct pneigh_entry___45 *next;
	possible_net_t___64 net;
	struct net_device___63 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___45 {
	struct neighbour___45 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___45 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___45 *ctarget;
	struct net___74 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___45 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___45 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___30;

struct timewait_sock_ops___28;

struct proto___45 {
	void (*close)(struct sock___46 *, long int);
	int (*pre_connect)(struct sock___46 *, struct sockaddr *, int);
	int (*connect)(struct sock___46 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___46 *, int);
	struct sock___46 * (*accept)(struct sock___46 *, int, int *, bool);
	int (*ioctl)(struct sock___46 *, int, long unsigned int);
	int (*init)(struct sock___46 *);
	void (*destroy)(struct sock___46 *);
	void (*shutdown)(struct sock___46 *, int);
	int (*setsockopt)(struct sock___46 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___46 *, int, int, char *, int *);
	void (*keepalive)(struct sock___46 *, int);
	int (*sendmsg)(struct sock___46 *, struct msghdr___48 *, size_t);
	int (*recvmsg)(struct sock___46 *, struct msghdr___48 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___46 *, struct page___418 *, int, size_t, int);
	int (*bind)(struct sock___46 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___46 *, struct sk_buff___64 *);
	void (*release_cb)(struct sock___46 *);
	int (*hash)(struct sock___46 *);
	void (*unhash)(struct sock___46 *);
	void (*rehash)(struct sock___46 *);
	int (*get_port)(struct sock___46 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___46 *);
	bool (*stream_memory_read)(const struct sock___46 *);
	void (*enter_memory_pressure)(struct sock___46 *);
	void (*leave_memory_pressure)(struct sock___46 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___30 *rsk_prot;
	struct timewait_sock_ops___28 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___347 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___46 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct request_sock___31;

struct request_sock_ops___30 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___46 *, struct request_sock___31 *);
	void (*send_ack)(const struct sock___46 *, struct sk_buff___64 *, struct request_sock___31 *);
	void (*send_reset)(const struct sock___46 *, struct sk_buff___64 *);
	void (*destructor)(struct request_sock___31 *);
	void (*syn_ack_timeout)(const struct request_sock___31 *);
};

struct timewait_sock_ops___28 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___46 *, struct sock___46 *, void *);
	void (*twsk_destructor)(struct sock___46 *);
};

struct request_sock___31 {
	struct sock_common___45 __req_common;
	struct request_sock___31 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___30 *rsk_ops;
	struct sock___46 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___25 {
	struct in6_addr mca_addr;
	struct inet6_dev___25 *idev;
	struct ifmcaddr6___25 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ip6_ra_chain___25 {
	struct ip6_ra_chain___25 *next;
	struct sock___46 *sk;
	int sel;
	void (*destructor)(struct sock___46 *);
};

struct tcp_skb_cb___2 {
	__u32 seq;
	__u32 end_seq;
	union {
		__u32 tcp_tw_isn;
		struct {
			u16 tcp_gso_segs;
			u16 tcp_gso_size;
		};
	};
	__u8 tcp_flags;
	__u8 sacked;
	__u8 ip_dsfield;
	__u8 txstamp_ack: 1;
	__u8 eor: 1;
	__u8 has_rxtstamp: 1;
	__u8 unused: 5;
	__u32 ack_seq;
	union {
		struct {
			__u32 in_flight: 30;
			__u32 is_app_limited: 1;
			__u32 unused: 1;
			__u32 delivered;
			u64 first_tx_mstamp;
			u64 delivered_mstamp;
		} tx;
		union {
			struct inet_skb_parm h4;
			struct inet6_skb_parm h6;
		} header;
		struct {
			__u32 flags;
			struct sock___46 *sk_redir;
			void *data_end;
		} bpf;
	};
};

struct strp_stats {
	long long unsigned int msgs;
	long long unsigned int bytes;
	unsigned int mem_fail;
	unsigned int need_more_hdr;
	unsigned int msg_too_big;
	unsigned int msg_timeouts;
	unsigned int bad_hdr_len;
};

struct strparser;

struct strp_callbacks {
	int (*parse_msg)(struct strparser *, struct sk_buff___64 *);
	void (*rcv_msg)(struct strparser *, struct sk_buff___64 *);
	int (*read_sock_done)(struct strparser *, int);
	void (*abort_parser)(struct strparser *, int);
	void (*lock)(struct strparser *);
	void (*unlock)(struct strparser *);
};

struct strparser {
	struct sock___46 *sk;
	u32 stopped: 1;
	u32 paused: 1;
	u32 aborted: 1;
	u32 interrupted: 1;
	u32 unrecov_intr: 1;
	struct sk_buff___64 **skb_nextp;
	struct sk_buff___64 *skb_head;
	unsigned int need_bytes;
	struct delayed_work msg_timer_work;
	struct work_struct work;
	struct strp_stats stats;
	struct strp_callbacks cb;
};

enum __sk_action {
	__SK_DROP = 0,
	__SK_PASS = 1,
	__SK_REDIRECT = 2,
	__SK_NONE = 3,
};

struct sk_msg___2 {
	struct sk_msg_sg sg;
	void *data;
	void *data_end;
	u32 apply_bytes;
	u32 cork_bytes;
	u32 flags;
	struct sk_buff___64 *skb;
	struct sock___46 *sk_redir;
	struct sock___46 *sk;
	struct list_head list;
};

struct sk_psock_progs {
	struct bpf_prog___55 *msg_parser;
	struct bpf_prog___55 *skb_parser;
	struct bpf_prog___55 *skb_verdict;
};

enum sk_psock_state_bits {
	SK_PSOCK_TX_ENABLED = 0,
};

struct sk_psock_link {
	struct list_head list;
	struct bpf_map___267 *map;
	void *link_raw;
};

struct sk_psock_parser {
	struct strparser strp;
	bool enabled;
	void (*saved_data_ready)(struct sock___46 *);
};

struct sk_psock_work_state {
	struct sk_buff___64 *skb;
	u32 len;
	u32 off;
};

struct sk_psock {
	struct sock___46 *sk;
	struct sock___46 *sk_redir;
	u32 apply_bytes;
	u32 cork_bytes;
	u32 eval;
	struct sk_msg___2 *cork;
	struct sk_psock_progs progs;
	struct sk_psock_parser parser;
	struct sk_buff_head___62 ingress_skb;
	struct list_head ingress_msg;
	long unsigned int state;
	struct list_head link;
	spinlock_t link_lock;
	refcount_t refcnt;
	void (*saved_unhash)(struct sock___46 *);
	void (*saved_close)(struct sock___46 *, long int);
	void (*saved_write_space)(struct sock___46 *);
	struct proto___45 *sk_proto;
	struct sk_psock_work_state work_state;
	struct work_struct work;
	union {
		struct callback_head rcu;
		struct work_struct gc;
	};
};

struct module___348;

struct file___418;

struct kiocb___418;

struct iov_iter___185;

struct poll_table_struct___260;

struct vm_area_struct___419;

struct inode___418;

struct file_lock___418;

struct page___419;

struct pipe_inode_info___99;

struct seq_file___357;

struct file_operations___418 {
	struct module___348 *owner;
	loff_t (*llseek)(struct file___418 *, loff_t, int);
	ssize_t (*read)(struct file___418 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___418 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___418 *, struct iov_iter___185 *);
	ssize_t (*write_iter)(struct kiocb___418 *, struct iov_iter___185 *);
	int (*iopoll)(struct kiocb___418 *, bool);
	int (*iterate)(struct file___418 *, struct dir_context *);
	int (*iterate_shared)(struct file___418 *, struct dir_context *);
	__poll_t (*poll)(struct file___418 *, struct poll_table_struct___260 *);
	long int (*unlocked_ioctl)(struct file___418 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___418 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___418 *, struct vm_area_struct___419 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___418 *, struct file___418 *);
	int (*flush)(struct file___418 *, fl_owner_t);
	int (*release)(struct inode___418 *, struct file___418 *);
	int (*fsync)(struct file___418 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___418 *, int);
	int (*lock)(struct file___418 *, int, struct file_lock___418 *);
	ssize_t (*sendpage)(struct file___418 *, struct page___419 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___418 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___418 *, int, struct file_lock___418 *);
	ssize_t (*splice_write)(struct pipe_inode_info___99 *, struct file___418 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___418 *, loff_t *, struct pipe_inode_info___99 *, size_t, unsigned int);
	int (*setlease)(struct file___418 *, long int, struct file_lock___418 **, void **);
	long int (*fallocate)(struct file___418 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___357 *, struct file___418 *);
	ssize_t (*copy_file_range)(struct file___418 *, loff_t, struct file___418 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___418 *, loff_t, struct file___418 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___418 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernel_param___346;

struct kernel_param_ops___346 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___346 *);
	int (*get)(char *, const struct kernel_param___346 *);
	void (*free)(void *);
};

struct kparam_array___346;

struct kernel_param___346 {
	const char *name;
	struct module___348 *mod;
	const struct kernel_param_ops___346 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___346 *arr;
	};
};

struct kparam_array___346 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___346 *ops;
	void *elem;
};

struct kset___405;

struct kobj_type___405;

struct kernfs_node___413;

struct kobject___406 {
	const char *name;
	struct list_head entry;
	struct kobject___406 *parent;
	struct kset___405 *kset;
	struct kobj_type___405 *ktype;
	struct kernfs_node___413 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___346 {
	struct kobject___406 kobj;
	struct module___348 *mod;
	struct kobject___406 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___346 {
	struct module___348 *mod;
	struct latch_tree_node node;
};

struct module_layout___346 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___346 mtn;
};

struct module_attribute___346;

struct module___348 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___346 mkobj;
	struct module_attribute___346 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___406 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___346 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___346 core_layout;
	struct module_layout___346 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide53;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide54;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct vmacache___419 {
	u64 seqnum;
	struct vm_area_struct___419 *vmas[4];
};

struct page_frag___419 {
	struct page___419 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___419;

struct mem_cgroup___154;

struct pid___237;

struct cred___386;

struct nsproxy___313;

struct signal_struct___293;

struct bio_list___211;

struct backing_dev_info___211;

struct css_set___267;

struct vm_struct___322;

struct task_struct___420 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___420 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___419 *mm;
	struct mm_struct___419 *active_mm;
	struct vmacache___419 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___420 *real_parent;
	struct task_struct___420 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___420 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___154 *active_memcg;
	long int rh_reserved2;
	struct pid___237 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___237 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___237 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___386 *ptracer_cred;
	const struct cred___386 *real_cred;
	const struct cred___386 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___313 *nsproxy;
	struct signal_struct___293 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___420 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___211 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___211 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___267 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___99 *splice_pipe;
	struct page_frag___419 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___154 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___420 *oom_reaper_list;
	struct vm_struct___322 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___154 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct secondary_data___420 {
	void *stack;
	struct task_struct___420 *task;
	long int status;
};

struct rw_semaphore___420 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___420 *owner;
};

struct key___386;

struct ucounts___283;

struct user_namespace___283 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___283 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___29 ns;
	long unsigned int flags;
	struct key___386 *persistent_keyring_register;
	struct rw_semaphore___420 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___283 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___419 *pgtable_t___419;

struct address_space___418;

struct dev_pagemap___406;

struct page___419 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___418 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___419 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___419 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___419 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___406 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___154 *mem_cgroup;
};

struct pglist_data___419;

struct lruvec___419 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___419 *pgdat;
};

struct zone___419 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___419 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___419 {
	struct zone___419 *zone;
	int zone_idx;
};

struct zonelist___419 {
	struct zoneref___419 _zonerefs[25];
};

struct pglist_data___419 {
	struct zone___419 node_zones[3];
	struct zonelist___419 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___420 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___420 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___419 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___419 {
	struct rw_semaphore___420 rwsem;
	struct notifier_block *head;
};

struct cgroup___267;

struct cgroup_subsys___267;

struct cgroup_subsys_state___267 {
	struct cgroup___267 *cgroup;
	struct cgroup_subsys___267 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___267 *parent;
};

struct cgroup_file___267 {
	struct kernfs_node___413 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___154;

struct mem_cgroup___154 {
	struct cgroup_subsys_state___267 css;
	struct mem_cgroup_id___16 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___267 events_file;
	struct cgroup_file___267 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___420 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___154 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___237;

struct upid___237 {
	int nr;
	struct pid_namespace___237 *ns;
};

struct dentry___418;

struct pid_namespace___237 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___420 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___237 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___418 *proc_self;
	struct dentry___418 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___283 *user_ns;
	struct ucounts___283 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___29 ns;
};

struct pid___237 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___237 numbers[1];
};

struct user_struct___386 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___386 *uid_keyring;
	struct key___386 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___406;

struct vm_area_struct___419 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___419 *vm_next;
	struct vm_area_struct___419 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___419 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___406 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___418 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___419;

struct mm_struct___419 {
	struct {
		struct vm_area_struct___419 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___418 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___420 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___419 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___420 *owner;
		struct user_namespace___283 *user_ns;
		struct file___418 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___419 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___386 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___386 *session_keyring;
	struct key___386 *process_keyring;
	struct key___386 *thread_keyring;
	struct key___386 *request_key_auth;
	void *security;
	struct user_struct___386 *user;
	struct user_namespace___283 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___75;

struct cgroup_namespace___267;

struct nsproxy___313 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___237 *pid_ns_for_children;
	struct net___75 *net_ns;
	struct cgroup_namespace___267 *cgroup_ns;
};

struct signal_struct___293 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___420 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___420 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___237 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___237 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___419 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___237 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___211;

struct bio_list___211 {
	struct bio___211 *head;
	struct bio___211 *tail;
};

struct bdi_writeback_congested___211;

struct bdi_writeback___211 {
	struct backing_dev_info___211 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___211 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___267 *memcg_css;
	struct cgroup_subsys_state___267 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___386;

struct backing_dev_info___211 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___211 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___386 *dev;
	struct device___386 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___418 *debug_dir;
	struct dentry___418 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___267 {
	struct cgroup_subsys_state___267 *subsys[13];
	refcount_t refcount;
	struct css_set___267 *dom_cset;
	struct cgroup___267 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___267 *mg_src_cgrp;
	struct cgroup___267 *mg_dst_cgrp;
	struct css_set___267 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___418;

struct pipe_buffer___99;

struct pipe_inode_info___99 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___419 *tmp_page;
	struct fasync_struct___418 *fasync_readers;
	struct fasync_struct___418 *fasync_writers;
	struct pipe_buffer___99 *bufs;
	struct user_struct___386 *user;
};

struct vm_struct___322 {
	struct vm_struct___322 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___419 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___305 {
	struct task_struct___420 task;
	long unsigned int stack[8192];
};

struct address_space_operations___418;

struct address_space___418 {
	struct inode___418 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___420 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___418 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___406)(struct vm_area_struct___419 *, long unsigned int, const struct page___419 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___406)(struct page___419 *, void *);

struct dev_pagemap___406 {
	dev_page_fault_t___406 page_fault;
	dev_page_free_t___406 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___386 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___419 {
	struct vfsmount *mnt;
	struct dentry___418 *dentry;
};

struct fown_struct___237 {
	rwlock_t lock;
	struct pid___237 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___418 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___419 f_path;
	struct inode___418 *f_inode;
	const struct file_operations___418 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___237 f_owner;
	const struct cred___386 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___418 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___406;

struct vm_operations_struct___406 {
	void (*open)(struct vm_area_struct___419 *);
	void (*close)(struct vm_area_struct___419 *);
	int (*split)(struct vm_area_struct___419 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___419 *);
	vm_fault_t (*fault)(struct vm_fault___406 *);
	vm_fault_t (*huge_fault)(struct vm_fault___406 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___406 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___419 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___406 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___406 *);
	int (*access)(struct vm_area_struct___419 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___419 *);
	int (*set_policy)(struct vm_area_struct___419 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___419 *, long unsigned int);
	struct page___419 * (*find_special_page)(struct vm_area_struct___419 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___419 {
	struct task_struct___420 *task;
	struct core_thread___419 *next;
};

struct core_state___419 {
	atomic_t nr_threads;
	struct core_thread___419 dumper;
	struct completion startup;
};

struct vm_fault___406 {
	struct vm_area_struct___419 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___419 *cow_page;
	struct mem_cgroup___154 *memcg;
	struct page___419 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___419 prealloc_pte;
};

struct crypto_async_request___26;

typedef void (*crypto_completion_t___26)(struct crypto_async_request___26 *, int);

struct crypto_tfm___26;

struct crypto_async_request___26 {
	struct list_head list;
	crypto_completion_t___26 complete;
	void *data;
	struct crypto_tfm___26 *tfm;
	u32 flags;
};

struct crypto_ablkcipher___26;

struct ablkcipher_request___26;

struct ablkcipher_tfm___26 {
	int (*setkey)(struct crypto_ablkcipher___26 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___26 *);
	int (*decrypt)(struct ablkcipher_request___26 *);
	struct crypto_ablkcipher___26 *base;
	unsigned int ivsize;
	unsigned int reqsize;
};

struct blkcipher_desc___26;

struct blkcipher_tfm___26 {
	void *iv;
	int (*setkey)(struct crypto_tfm___26 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___26 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___26 *, struct scatterlist *, struct scatterlist *, unsigned int);
};

struct cipher_tfm___26 {
	int (*cit_setkey)(struct crypto_tfm___26 *, const u8 *, unsigned int);
	void (*cit_encrypt_one)(struct crypto_tfm___26 *, u8 *, const u8 *);
	void (*cit_decrypt_one)(struct crypto_tfm___26 *, u8 *, const u8 *);
};

struct compress_tfm___26 {
	int (*cot_compress)(struct crypto_tfm___26 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*cot_decompress)(struct crypto_tfm___26 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___26;

struct crypto_tfm___26 {
	u32 crt_flags;
	union {
		struct ablkcipher_tfm___26 ablkcipher;
		struct blkcipher_tfm___26 blkcipher;
		struct cipher_tfm___26 cipher;
		struct compress_tfm___26 compress;
	} crt_u;
	void (*exit)(struct crypto_tfm___26 *);
	struct crypto_alg___26 *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct ablkcipher_request___26 {
	struct crypto_async_request___26 base;
	unsigned int nbytes;
	void *info;
	struct scatterlist *src;
	struct scatterlist *dst;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_blkcipher___26;

struct blkcipher_desc___26 {
	struct crypto_blkcipher___26 *tfm;
	void *info;
	u32 flags;
};

struct crypto_blkcipher___26 {
	struct crypto_tfm___26 base;
};

struct ablkcipher_alg___26 {
	int (*setkey)(struct crypto_ablkcipher___26 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___26 *);
	int (*decrypt)(struct ablkcipher_request___26 *);
	int (*givencrypt)(struct skcipher_givcrypt_request *);
	int (*givdecrypt)(struct skcipher_givcrypt_request *);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct crypto_ablkcipher___26 {
	struct crypto_tfm___26 base;
};

struct blkcipher_alg___26 {
	int (*setkey)(struct crypto_tfm___26 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___26 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___26 *, struct scatterlist *, struct scatterlist *, unsigned int);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct cipher_alg___26 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___26 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___26 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___26 *, u8 *, const u8 *);
};

struct compress_alg___26 {
	int (*coa_compress)(struct crypto_tfm___26 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___26 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___26 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type *cra_type;
	union {
		struct ablkcipher_alg___26 ablkcipher;
		struct blkcipher_alg___26 blkcipher;
		struct cipher_alg___26 cipher;
		struct compress_alg___26 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___26 *);
	void (*cra_exit)(struct crypto_tfm___26 *);
	void (*cra_destroy)(struct crypto_alg___26 *);
	struct module___348 *cra_module;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct crypto_cipher___10 {
	struct crypto_tfm___26 base;
};

struct bio_vec___213 {
	struct page___419 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___185 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___213 *bvec;
		struct pipe_inode_info___99 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct msghdr___49 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___185 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___418 *msg_iocb;
};

struct kiocb___418 {
	struct file___418 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___418 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dentry_operations___418;

struct super_block___418;

struct dentry___418 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___418 *d_parent;
	struct qstr d_name;
	struct inode___418 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___418 *d_op;
	struct super_block___418 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___418;

struct block_device___418;

struct inode___418 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___418 *i_op;
	struct super_block___418 *i_sb;
	struct address_space___418 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___420 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___211 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___418 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___418 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___99 *i_pipe;
		struct block_device___418 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___418 {
	int (*d_revalidate)(struct dentry___418 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___418 *, unsigned int);
	int (*d_hash)(const struct dentry___418 *, struct qstr *);
	int (*d_compare)(const struct dentry___418 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___418 *);
	int (*d_init)(struct dentry___418 *);
	void (*d_release)(struct dentry___418 *);
	void (*d_prune)(struct dentry___418 *);
	void (*d_iput)(struct dentry___418 *, struct inode___418 *);
	char * (*d_dname)(struct dentry___418 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___419 *);
	int (*d_manage)(const struct path___419 *, bool);
	struct dentry___418 * (*d_real)(struct dentry___418 *, const struct inode___418 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___418;

struct mem_dqinfo___418 {
	struct quota_format_type___418 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___418;

struct quota_info___418 {
	unsigned int flags;
	struct rw_semaphore___420 dqio_sem;
	struct inode___418 *files[3];
	struct mem_dqinfo___418 info[3];
	const struct quota_format_ops___418 *ops[3];
};

struct rcuwait___418 {
	struct task_struct___420 *task;
};

struct percpu_rw_semaphore___418 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___420 rw_sem;
	struct rcuwait___418 writer;
	int readers_block;
};

struct sb_writers___418 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___418 rw_sem[3];
};

struct shrink_control___154;

struct shrinker___154 {
	long unsigned int (*count_objects)(struct shrinker___154 *, struct shrink_control___154 *);
	long unsigned int (*scan_objects)(struct shrinker___154 *, struct shrink_control___154 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___418;

struct super_operations___418;

struct dquot_operations___418;

struct quotactl_ops___418;

struct super_block___418 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___418 *s_type;
	const struct super_operations___418 *s_op;
	const struct dquot_operations___418 *dq_op;
	const struct quotactl_ops___418 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___418 *s_root;
	struct rw_semaphore___420 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___418 *s_bdev;
	struct backing_dev_info___211 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___418 s_dquot;
	struct sb_writers___418 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___418 *s_d_op;
	int cleancache_poolid;
	struct shrinker___154 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___283 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___154 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___154 *memcg;
};

struct iattr___418 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___418 *ia_file;
};

struct dquot___418 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___418 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___418 {
	int qf_fmt_id;
	const struct quota_format_ops___418 *qf_ops;
	struct module___348 *qf_owner;
	struct quota_format_type___418 *qf_next;
};

struct quota_format_ops___418 {
	int (*check_quota_file)(struct super_block___418 *, int);
	int (*read_file_info)(struct super_block___418 *, int);
	int (*write_file_info)(struct super_block___418 *, int);
	int (*free_file_info)(struct super_block___418 *, int);
	int (*read_dqblk)(struct dquot___418 *);
	int (*commit_dqblk)(struct dquot___418 *);
	int (*release_dqblk)(struct dquot___418 *);
	int (*get_next_id)(struct super_block___418 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___418 {
	int (*write_dquot)(struct dquot___418 *);
	struct dquot___418 * (*alloc_dquot)(struct super_block___418 *, int);
	void (*destroy_dquot)(struct dquot___418 *);
	int (*acquire_dquot)(struct dquot___418 *);
	int (*release_dquot)(struct dquot___418 *);
	int (*mark_dirty)(struct dquot___418 *);
	int (*write_info)(struct super_block___418 *, int);
	qsize_t * (*get_reserved_space)(struct inode___418 *);
	int (*get_projid)(struct inode___418 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___418 *, qsize_t *);
	int (*get_next_id)(struct super_block___418 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___418 {
	int (*quota_on)(struct super_block___418 *, int, int, const struct path___419 *);
	int (*quota_off)(struct super_block___418 *, int);
	int (*quota_enable)(struct super_block___418 *, unsigned int);
	int (*quota_disable)(struct super_block___418 *, unsigned int);
	int (*quota_sync)(struct super_block___418 *, int);
	int (*set_info)(struct super_block___418 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___418 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___418 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___418 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___418 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___418 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___174;

struct address_space_operations___418 {
	int (*writepage)(struct page___419 *, struct writeback_control___174 *);
	int (*readpage)(struct file___418 *, struct page___419 *);
	int (*writepages)(struct address_space___418 *, struct writeback_control___174 *);
	int (*set_page_dirty)(struct page___419 *);
	int (*readpages)(struct file___418 *, struct address_space___418 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___418 *, struct address_space___418 *, loff_t, unsigned int, unsigned int, struct page___419 **, void **);
	int (*write_end)(struct file___418 *, struct address_space___418 *, loff_t, unsigned int, unsigned int, struct page___419 *, void *);
	sector_t (*bmap)(struct address_space___418 *, sector_t);
	void (*invalidatepage)(struct page___419 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___419 *, gfp_t);
	void (*freepage)(struct page___419 *);
	ssize_t (*direct_IO)(struct kiocb___418 *, struct iov_iter___185 *);
	int (*migratepage)(struct address_space___418 *, struct page___419 *, struct page___419 *, enum migrate_mode);
	bool (*isolate_page)(struct page___419 *, isolate_mode_t);
	void (*putback_page)(struct page___419 *);
	int (*launder_page)(struct page___419 *);
	int (*is_partially_uptodate)(struct page___419 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___419 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___418 *, struct page___419 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___418 *, sector_t *);
	void (*swap_deactivate)(struct file___418 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___174 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___211 *wb;
	struct inode___418 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___418 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___418 *bd_inode;
	struct super_block___418 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___418 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___211 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___418 {
	struct dentry___418 * (*lookup)(struct inode___418 *, struct dentry___418 *, unsigned int);
	const char * (*get_link)(struct dentry___418 *, struct inode___418 *, struct delayed_call *);
	int (*permission)(struct inode___418 *, int);
	struct posix_acl * (*get_acl)(struct inode___418 *, int);
	int (*readlink)(struct dentry___418 *, char *, int);
	int (*create)(struct inode___418 *, struct dentry___418 *, umode_t, bool);
	int (*link)(struct dentry___418 *, struct inode___418 *, struct dentry___418 *);
	int (*unlink)(struct inode___418 *, struct dentry___418 *);
	int (*symlink)(struct inode___418 *, struct dentry___418 *, const char *);
	int (*mkdir)(struct inode___418 *, struct dentry___418 *, umode_t);
	int (*rmdir)(struct inode___418 *, struct dentry___418 *);
	int (*mknod)(struct inode___418 *, struct dentry___418 *, umode_t, dev_t);
	int (*rename)(struct inode___418 *, struct dentry___418 *, struct inode___418 *, struct dentry___418 *, unsigned int);
	int (*setattr)(struct dentry___418 *, struct iattr___418 *);
	int (*getattr)(const struct path___419 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___418 *, char *, size_t);
	int (*fiemap)(struct inode___418 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___418 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___418 *, struct dentry___418 *, struct file___418 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___418 *, struct dentry___418 *, umode_t);
	int (*set_acl)(struct inode___418 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___418 {
	void (*fl_copy_lock)(struct file_lock___418 *, struct file_lock___418 *);
	void (*fl_release_private)(struct file_lock___418 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___418;

struct file_lock___418 {
	struct file_lock___418 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___418 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___418 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___418 *fl_ops;
	const struct lock_manager_operations___418 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___418 {
	int (*lm_compare_owner)(struct file_lock___418 *, struct file_lock___418 *);
	long unsigned int (*lm_owner_key)(struct file_lock___418 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___418 *);
	int (*lm_grant)(struct file_lock___418 *, int);
	bool (*lm_break)(struct file_lock___418 *);
	int (*lm_change)(struct file_lock___418 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___418 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___418 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___418 *fa_next;
	struct file___418 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___418 {
	const char *name;
	int fs_flags;
	struct dentry___418 * (*mount)(struct file_system_type___418 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___418 *);
	struct module___348 *owner;
	struct file_system_type___418 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___418 {
	struct inode___418 * (*alloc_inode)(struct super_block___418 *);
	void (*destroy_inode)(struct inode___418 *);
	void (*dirty_inode)(struct inode___418 *, int);
	int (*write_inode)(struct inode___418 *, struct writeback_control___174 *);
	int (*drop_inode)(struct inode___418 *);
	void (*evict_inode)(struct inode___418 *);
	void (*put_super)(struct super_block___418 *);
	int (*sync_fs)(struct super_block___418 *, int);
	int (*freeze_super)(struct super_block___418 *);
	int (*freeze_fs)(struct super_block___418 *);
	int (*thaw_super)(struct super_block___418 *);
	int (*unfreeze_fs)(struct super_block___418 *);
	int (*statfs)(struct dentry___418 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___418 *, int *, char *);
	void (*umount_begin)(struct super_block___418 *);
	int (*show_options)(struct seq_file___357 *, struct dentry___418 *);
	int (*show_devname)(struct seq_file___357 *, struct dentry___418 *);
	int (*show_path)(struct seq_file___357 *, struct dentry___418 *);
	int (*show_stats)(struct seq_file___357 *, struct dentry___418 *);
	ssize_t (*quota_read)(struct super_block___418 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___418 *, int, const char *, size_t, loff_t);
	struct dquot___418 ** (*get_dquots)(struct inode___418 *);
	int (*bdev_try_to_free_page)(struct super_block___418 *, struct page___419 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___418 *, struct shrink_control___154 *);
	long int (*free_cached_objects)(struct super_block___418 *, struct shrink_control___154 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___270)(struct file___418 *, wait_queue_head_t *, struct poll_table_struct___260 *);

struct poll_table_struct___260 {
	poll_queue_proc___270 _qproc;
	__poll_t _key;
};

struct seq_operations___357;

struct seq_file___357 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___357 *op;
	int poll_event;
	const struct file___418 *file;
	void *private;
};

typedef void bio_end_io_t___211(struct bio___211 *);

struct bio_integrity_payload___211;

struct bio_set___211;

struct bio___211 {
	struct bio___211 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___211 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___211 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___213 *bi_io_vec;
	struct bio_set___211 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___213 bi_inline_vecs[0];
};

struct socket_wq___47 {
	wait_queue_head_t wait;
	struct fasync_struct___418 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct sock___47;

struct proto_ops___47;

struct socket___48 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___47 *wq;
	struct file___418 *file;
	struct sock___47 *sk;
	const struct proto_ops___47 *ops;
};

typedef struct {
	struct net___75 *net;
} possible_net_t___65;

struct proto___46;

struct sock_common___46 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___46 *skc_prot;
	possible_net_t___65 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___47 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___65;

struct sk_buff_head___63 {
	struct sk_buff___65 *next;
	struct sk_buff___65 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___46;

struct dst_entry___46;

struct net_device___64;

struct sock___47 {
	struct sock_common___46 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___63 sk_error_queue;
	struct sk_buff_head___63 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___65 *head;
		struct sk_buff___65 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___46 *sk_filter;
	union {
		struct socket_wq___47 *sk_wq;
		struct socket_wq___47 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___46 *sk_rx_dst;
	struct dst_entry___46 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___65 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___63 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___419 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___46 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___237 *sk_peer_pid;
	const struct cred___386 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___48 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___154 *sk_memcg;
	void (*sk_state_change)(struct sock___47 *);
	void (*sk_data_ready)(struct sock___47 *);
	void (*sk_write_space)(struct sock___47 *);
	void (*sk_error_report)(struct sock___47 *);
	int (*sk_backlog_rcv)(struct sock___47 *, struct sk_buff___65 *);
	struct sk_buff___65 * (*sk_validate_xmit_skb)(struct sock___47 *, struct net_device___64 *, struct sk_buff___65 *);
	void (*sk_destruct)(struct sock___47 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

typedef int (*sk_read_actor_t___46)(read_descriptor_t *, struct sk_buff___65 *, unsigned int, size_t);

struct proto_ops___47 {
	int family;
	struct module___348 *owner;
	int (*release)(struct socket___48 *);
	int (*bind)(struct socket___48 *, struct sockaddr *, int);
	int (*connect)(struct socket___48 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___48 *, struct socket___48 *);
	int (*accept)(struct socket___48 *, struct socket___48 *, int, bool);
	int (*getname)(struct socket___48 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___418 *, struct socket___48 *, struct poll_table_struct___260 *);
	int (*ioctl)(struct socket___48 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___48 *, int);
	int (*shutdown)(struct socket___48 *, int);
	int (*setsockopt)(struct socket___48 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___48 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___48 *, struct msghdr___49 *, size_t);
	int (*recvmsg)(struct socket___48 *, struct msghdr___49 *, size_t, int);
	int (*mmap)(struct file___418 *, struct socket___48 *, struct vm_area_struct___419 *);
	ssize_t (*sendpage)(struct socket___48 *, struct page___419 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___48 *, loff_t *, struct pipe_inode_info___99 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___47 *, int);
	int (*peek_len)(struct socket___48 *);
	int (*read_sock)(struct sock___47 *, read_descriptor_t *, sk_read_actor_t___46);
	int (*sendpage_locked)(struct sock___47 *, struct page___419 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___47 *, struct msghdr___49 *, size_t);
	int (*set_rcvlowat)(struct sock___47 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct nf_bridge_info___63;

struct sk_buff___65 {
	union {
		struct {
			struct sk_buff___65 *next;
			struct sk_buff___65 *prev;
			union {
				struct net_device___64 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___47 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___65 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___63 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___63;

struct netns_frags___63 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___63 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ip_ra_chain___23;

struct fib_rules_ops___46;

struct tcp_congestion_ops___7;

struct tcp_fastopen_context___7;

struct fib_notifier_ops___47;

struct netns_ipv4___63 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___23 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___46 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___47 *fibnl;
	struct sock___47 **icmp_sk;
	struct sock___47 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___47 **tcp_sk;
	struct netns_frags___63 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops___7 *tcp_congestion_control;
	struct tcp_fastopen_context___7 *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___46 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___47 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___47 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___46;

struct dst_ops___74 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___74 *);
	struct dst_entry___46 * (*check)(struct dst_entry___46 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___46 *);
	unsigned int (*mtu)(const struct dst_entry___46 *);
	u32 * (*cow_metrics)(struct dst_entry___46 *, long unsigned int);
	void (*destroy)(struct dst_entry___46 *);
	void (*ifdown)(struct dst_entry___46 *, struct net_device___64 *, int);
	struct dst_entry___46 * (*negative_advice)(struct dst_entry___46 *);
	void (*link_failure)(struct sk_buff___65 *);
	void (*update_pmtu)(struct dst_entry___46 *, struct sock___47 *, struct sk_buff___65 *, u32);
	void (*redirect)(struct dst_entry___46 *, struct sock___47 *, struct sk_buff___65 *);
	int (*local_out)(struct net___75 *, struct sock___47 *, struct sk_buff___65 *);
	struct neighbour___46 * (*neigh_lookup)(const struct dst_entry___46 *, struct sk_buff___65 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___46 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___74 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___63 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___74 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___46 *fib6_rules_ops;
	struct sock___47 **icmp_sk;
	struct sock___47 *ndisc_sk;
	struct sock___47 *tcp_sk;
	struct sock___47 *igmp_sk;
	struct sock___47 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___46 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___47 *notifier_ops;
	struct fib_notifier_ops___47 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___47 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___47 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___63 {
	struct netns_frags___63 frags;
};

struct netns_xfrm___74 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___47 *nlsk;
	struct sock___47 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___74 xfrm4_dst_ops;
	struct dst_ops___74 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___56;

struct net___75 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___283 *user_ns;
	struct ucounts___283 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___29 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___47 *rtnl;
	struct sock___47 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___64 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___63 ipv4;
	struct netns_ipv6___74 ipv6;
	struct netns_sctp___47 sctp;
	struct netns_nf___4 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___63 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___47 *nfnl;
	struct sock___47 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___74 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___47 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___56 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kernfs_root___412;

struct kernfs_elem_dir___412 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___412 *root;
};

struct kernfs_syscall_ops___412;

struct kernfs_root___412 {
	struct kernfs_node___413 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___412 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___412 {
	struct kernfs_node___413 *target_kn;
};

struct kernfs_ops___412;

struct kernfs_elem_attr___412 {
	const struct kernfs_ops___412 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___413 *notify_next;
};

struct kernfs_node___413 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___413 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___412 dir;
		struct kernfs_elem_symlink___412 symlink;
		struct kernfs_elem_attr___412 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___412;

struct kernfs_ops___412 {
	int (*open)(struct kernfs_open_file___412 *);
	void (*release)(struct kernfs_open_file___412 *);
	int (*seq_show)(struct seq_file___357 *, void *);
	void * (*seq_start)(struct seq_file___357 *, loff_t *);
	void * (*seq_next)(struct seq_file___357 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___357 *, void *);
	ssize_t (*read)(struct kernfs_open_file___412 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___412 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___412 *, struct vm_area_struct___419 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___412 *, struct poll_table_struct___260 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___412 {
	int (*remount_fs)(struct kernfs_root___412 *, int *, char *);
	int (*show_options)(struct seq_file___357 *, struct kernfs_root___412 *);
	int (*mkdir)(struct kernfs_node___413 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___413 *);
	int (*rename)(struct kernfs_node___413 *, struct kernfs_node___413 *, const char *);
	int (*show_path)(struct seq_file___357 *, struct kernfs_node___413 *, struct kernfs_root___412 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___412 {
	struct kernfs_node___413 *kn;
	struct file___418 *file;
	struct seq_file___357 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___406 *vm_ops;
};

struct kobj_ns_type_operations___46 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___47 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___382;

struct attribute_group___383 {
	const char *name;
	umode_t (*is_visible)(struct kobject___406 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___406 *, struct bin_attribute___382 *, int);
	struct attribute **attrs;
	struct bin_attribute___382 **bin_attrs;
};

struct bin_attribute___382 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___418 *, struct kobject___406 *, struct bin_attribute___382 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___418 *, struct kobject___406 *, struct bin_attribute___382 *, char *, loff_t, size_t);
	int (*mmap)(struct file___418 *, struct kobject___406 *, struct bin_attribute___382 *, struct vm_area_struct___419 *);
};

struct sysfs_ops___405 {
	ssize_t (*show)(struct kobject___406 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___406 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___405;

struct kset___405 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___406 kobj;
	const struct kset_uevent_ops___405 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___405 {
	void (*release)(struct kobject___406 *);
	const struct sysfs_ops___405 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___46 * (*child_ns_type)(struct kobject___406 *);
	const void * (*namespace)(struct kobject___406 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___405 {
	int (* const filter)(struct kset___405 *, struct kobject___406 *);
	const char * (* const name)(struct kset___405 *, struct kobject___406 *);
	int (* const uevent)(struct kset___405 *, struct kobject___406 *, struct kobj_uevent_env *);
};

struct kobj_attribute___396 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___406 *, struct kobj_attribute___396 *, char *);
	ssize_t (*store)(struct kobject___406 *, struct kobj_attribute___396 *, const char *, size_t);
};

struct dev_pm_ops___386 {
	int (*prepare)(struct device___386 *);
	void (*complete)(struct device___386 *);
	int (*suspend)(struct device___386 *);
	int (*resume)(struct device___386 *);
	int (*freeze)(struct device___386 *);
	int (*thaw)(struct device___386 *);
	int (*poweroff)(struct device___386 *);
	int (*restore)(struct device___386 *);
	int (*suspend_late)(struct device___386 *);
	int (*resume_early)(struct device___386 *);
	int (*freeze_late)(struct device___386 *);
	int (*thaw_early)(struct device___386 *);
	int (*poweroff_late)(struct device___386 *);
	int (*restore_early)(struct device___386 *);
	int (*suspend_noirq)(struct device___386 *);
	int (*resume_noirq)(struct device___386 *);
	int (*freeze_noirq)(struct device___386 *);
	int (*thaw_noirq)(struct device___386 *);
	int (*poweroff_noirq)(struct device___386 *);
	int (*restore_noirq)(struct device___386 *);
	int (*runtime_suspend)(struct device___386 *);
	int (*runtime_resume)(struct device___386 *);
	int (*runtime_idle)(struct device___386 *);
};

struct dev_pm_info___386 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___386 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___386;

struct bus_type___386;

struct device_driver___386;

struct dev_pm_domain___386;

struct dma_map_ops___158;

struct fwnode_handle___306;

struct class___386;

struct device___386 {
	struct device___386 *parent;
	struct device_private *p;
	struct kobject___406 kobj;
	const char *init_name;
	const struct device_type___386 *type;
	struct mutex mutex;
	struct bus_type___386 *bus;
	struct device_driver___386 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___386 power;
	struct dev_pm_domain___386 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___158 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___306 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___386 *class;
	const struct attribute_group___383 **groups;
	void (*release)(struct device___386 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___386 {
	struct dev_pm_ops___386 ops;
	void (*detach)(struct device___386 *, bool);
	int (*activate)(struct device___386 *);
	void (*sync)(struct device___386 *);
	void (*dismiss)(struct device___386 *);
};

struct bus_type___386 {
	const char *name;
	const char *dev_name;
	struct device___386 *dev_root;
	const struct attribute_group___383 **bus_groups;
	const struct attribute_group___383 **dev_groups;
	const struct attribute_group___383 **drv_groups;
	int (*match)(struct device___386 *, struct device_driver___386 *);
	int (*uevent)(struct device___386 *, struct kobj_uevent_env *);
	int (*probe)(struct device___386 *);
	int (*remove)(struct device___386 *);
	void (*shutdown)(struct device___386 *);
	int (*online)(struct device___386 *);
	int (*offline)(struct device___386 *);
	int (*suspend)(struct device___386 *, pm_message_t);
	int (*resume)(struct device___386 *);
	int (*num_vf)(struct device___386 *);
	int (*dma_configure)(struct device___386 *);
	const struct dev_pm_ops___386 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___386 {
	const char *name;
	struct bus_type___386 *bus;
	struct module___348 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___386 *);
	int (*remove)(struct device___386 *);
	void (*shutdown)(struct device___386 *);
	int (*suspend)(struct device___386 *, pm_message_t);
	int (*resume)(struct device___386 *);
	const struct attribute_group___383 **groups;
	const struct dev_pm_ops___386 *pm;
	void (*coredump)(struct device___386 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___386 {
	const char *name;
	const struct attribute_group___383 **groups;
	int (*uevent)(struct device___386 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___386 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___386 *);
	const struct dev_pm_ops___386 *pm;
};

struct class___386 {
	const char *name;
	struct module___348 *owner;
	const struct attribute_group___383 **class_groups;
	const struct attribute_group___383 **dev_groups;
	struct kobject___406 *dev_kobj;
	int (*dev_uevent)(struct device___386 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___386 *, umode_t *);
	void (*class_release)(struct class___386 *);
	void (*dev_release)(struct device___386 *);
	int (*shutdown_pre)(struct device___386 *);
	const struct kobj_ns_type_operations___46 *ns_type;
	const void * (*namespace)(struct device___386 *);
	const struct dev_pm_ops___386 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___158 {
	void * (*alloc)(struct device___386 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___386 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___386 *, struct vm_area_struct___419 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___386 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___386 *, struct page___419 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___386 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___386 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___386 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___386 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___386 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___386 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___386 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___386 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___386 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___386 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___386 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___386 *, u64);
	u64 (*get_required_mask)(struct device___386 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___306;

struct fwnode_handle___306 {
	struct fwnode_handle___306 *secondary;
	const struct fwnode_operations___306 *ops;
};

typedef void compound_page_dtor___406(struct page___419 *);

struct fwnode_reference_args___306;

struct fwnode_endpoint___306;

struct fwnode_operations___306 {
	struct fwnode_handle___306 * (*get)(struct fwnode_handle___306 *);
	void (*put)(struct fwnode_handle___306 *);
	bool (*device_is_available)(const struct fwnode_handle___306 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___306 *, const struct device___386 *);
	bool (*property_present)(const struct fwnode_handle___306 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___306 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___306 *, const char *, const char **, size_t);
	struct fwnode_handle___306 * (*get_parent)(const struct fwnode_handle___306 *);
	struct fwnode_handle___306 * (*get_next_child_node)(const struct fwnode_handle___306 *, struct fwnode_handle___306 *);
	struct fwnode_handle___306 * (*get_named_child_node)(const struct fwnode_handle___306 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___306 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___306 *);
	struct fwnode_handle___306 * (*graph_get_next_endpoint)(const struct fwnode_handle___306 *, struct fwnode_handle___306 *);
	struct fwnode_handle___306 * (*graph_get_remote_endpoint)(const struct fwnode_handle___306 *);
	struct fwnode_handle___306 * (*graph_get_port_parent)(struct fwnode_handle___306 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___306 *, struct fwnode_endpoint___306 *);
};

struct fwnode_endpoint___306 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___306 *local_fwnode;
};

struct fwnode_reference_args___306 {
	struct fwnode_handle___306 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___99;

struct pipe_buffer___99 {
	struct page___419 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___99 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___99 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___99 *, struct pipe_buffer___99 *);
	void (*release)(struct pipe_inode_info___99 *, struct pipe_buffer___99 *);
	int (*steal)(struct pipe_inode_info___99 *, struct pipe_buffer___99 *);
	union {
		bool (*get)(struct pipe_inode_info___99 *, struct pipe_buffer___99 *);
		struct {
			void (*get)(struct pipe_inode_info___99 *, struct pipe_buffer___99 *);
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
};

struct nf_bridge_info___63 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___63 = 0,
		BRNF_PROTO_8021Q___63 = 1,
		BRNF_PROTO_PPPOE___63 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___64 *physindev;
	struct net_device___64 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___63(struct sk_buff___65 **);

struct net_device_ops___63;

struct ethtool_ops___63;

struct l3mdev_ops___46;

struct ndisc_ops___26;

struct xfrmdev_ops___63;

struct tlsdev_ops___63;

struct header_ops___63;

struct in_device___4;

struct inet6_dev___26;

struct netdev_rx_queue___63;

struct mini_Qdisc___56;

struct netdev_queue___63;

struct Qdisc___56;

struct netpoll_info___3;

struct rtnl_link_ops___56;

struct dcbnl_rtnl_ops___63;

struct net_device___64 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___63 *netdev_ops;
	const struct ethtool_ops___63 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___46 *l3mdev_ops;
	const struct ndisc_ops___26 *ndisc_ops;
	const struct xfrmdev_ops___63 *xfrmdev_ops;
	const struct tlsdev_ops___63 *tlsdev_ops;
	const struct header_ops___63 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___405 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device___4 *ip_ptr;
	struct inet6_dev___26 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___63 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___56 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___63 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___56 *miniq_ingress;
	struct netdev_queue___63 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___63 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___56 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___56 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___63 = 0,
		NETREG_REGISTERED___63 = 1,
		NETREG_UNREGISTERING___63 = 2,
		NETREG_UNREGISTERED___63 = 3,
		NETREG_RELEASED___63 = 4,
		NETREG_DUMMY___63 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___63 = 0,
		RTNL_LINK_INITIALIZING___63 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___64 *);
	struct netpoll_info___3 *npinfo;
	possible_net_t___65 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___386 dev;
	const struct attribute_group___383 *sysfs_groups[4];
	const struct attribute_group___383 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___56 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___63 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct skb_frag_struct___9 {
	struct {
		struct page___419 *p;
	} page;
	__u32 page_offset;
	__u32 size;
};

typedef struct skb_frag_struct___9 skb_frag_t___9;

struct skb_shared_info___9 {
	__u8 __unused;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___65 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___9 frags[16];
};

struct ethtool_ops___63 {
	int (*get_settings)(struct net_device___64 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___64 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___64 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___64 *);
	void (*get_regs)(struct net_device___64 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___64 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___64 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___64 *);
	void (*set_msglevel)(struct net_device___64 *, u32);
	int (*nway_reset)(struct net_device___64 *);
	u32 (*get_link)(struct net_device___64 *);
	int (*get_eeprom_len)(struct net_device___64 *);
	int (*get_eeprom)(struct net_device___64 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___64 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___64 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___64 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___64 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___64 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___64 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___64 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___64 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___64 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___64 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___64 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___64 *);
	void (*complete)(struct net_device___64 *);
	u32 (*get_priv_flags)(struct net_device___64 *);
	int (*set_priv_flags)(struct net_device___64 *, u32);
	int (*get_sset_count)(struct net_device___64 *, int);
	int (*get_rxnfc)(struct net_device___64 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___64 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___64 *, struct ethtool_flash *);
	int (*reset)(struct net_device___64 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___64 *);
	u32 (*get_rxfh_indir_size)(struct net_device___64 *);
	int (*get_rxfh)(struct net_device___64 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___64 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___64 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___64 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___64 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___64 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___64 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___64 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___64 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___64 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___64 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___64 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___64 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___64 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___64 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___64 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___64 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___64 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___64 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___64 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___64 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___64 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	int (*get_fecparam)(struct net_device___64 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___64 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___64 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___64 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___64 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___63;

struct inet_frags___63 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___63 *, const void *);
	void (*destructor)(struct inet_frag_queue___63 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___63 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___65 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___65 *fragments_tail;
	struct sk_buff___65 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___63 *net;
	struct callback_head rcu;
};

struct ip_ra_chain___23 {
	struct ip_ra_chain___23 *next;
	struct sock___47 *sk;
	union {
		void (*destructor)(struct sock___47 *);
		struct sock___47 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___46;

struct fib_lookup_arg___46;

struct fib_rules_ops___46 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___46 *, struct flowi *, int, struct fib_lookup_arg___46 *);
	bool (*suppress)(struct fib_rule___46 *, struct fib_lookup_arg___46 *);
	int (*match)(struct fib_rule___46 *, struct flowi *, int);
	int (*configure)(struct fib_rule___46 *, struct sk_buff___65 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___46 *);
	int (*compare)(struct fib_rule___46 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___46 *, struct sk_buff___65 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___46 *);
	void (*flush_cache)(struct fib_rules_ops___46 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___348 *owner;
	struct net___75 *fro_net;
	struct callback_head rcu;
};

struct tcp_congestion_ops___7 {
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___47 *);
	void (*release)(struct sock___47 *);
	u32 (*ssthresh)(struct sock___47 *);
	void (*cong_avoid)(struct sock___47 *, u32, u32);
	void (*set_state)(struct sock___47 *, u8);
	void (*cwnd_event)(struct sock___47 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___47 *, u32);
	u32 (*undo_cwnd)(struct sock___47 *);
	void (*pkts_acked)(struct sock___47 *, const struct ack_sample *);
	u32 (*min_tso_segs)(struct sock___47 *);
	u32 (*sndbuf_expand)(struct sock___47 *);
	void (*cong_control)(struct sock___47 *, const struct rate_sample *);
	size_t (*get_info)(struct sock___47 *, u32, int *, union tcp_cc_info *);
	char name[16];
	struct module___348 *owner;
};

struct tcp_fastopen_context___7 {
	struct crypto_cipher___10 *tfm;
	__u8 key[16];
	struct callback_head rcu;
};

struct fib_notifier_ops___47 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___75 *);
	int (*fib_dump)(struct net___75 *, struct notifier_block *);
	struct module___348 *owner;
	struct callback_head rcu;
};

struct dst_entry___46 {
	struct net_device___64 *dev;
	struct dst_ops___74 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___65 *);
	int (*output)(struct net___75 *, struct sock___47 *, struct sk_buff___65 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___46;

struct neigh_parms___46;

struct neigh_ops___46;

struct neighbour___46 {
	struct neighbour___46 *next;
	struct neigh_table___46 *tbl;
	struct neigh_parms___46 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___63 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___46 *, struct sk_buff___65 *);
	const struct neigh_ops___46 *ops;
	struct callback_head rcu;
	struct net_device___64 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct ucounts___283 {
	struct hlist_node node;
	struct user_namespace___283 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_prog_aux___59;

struct bpf_prog___56 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___59 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

typedef int (*key_restrict_link_func_t___387)(struct key___386 *, const struct key_type *, const union key_payload *, struct key___386 *);

struct key_restriction___386;

struct key___386 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___420 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___386 *restrict_link;
};

struct key_restriction___386 {
	key_restrict_link_func_t___387 check;
	struct key___386 *key;
	struct key_type *keytype;
};

struct seq_operations___357 {
	void * (*start)(struct seq_file___357 *, loff_t *);
	void (*stop)(struct seq_file___357 *, void *);
	void * (*next)(struct seq_file___357 *, void *, loff_t *);
	int (*show)(struct seq_file___357 *, void *);
};

struct pernet_operations___64 {
	struct list_head list;
	int (*init)(struct net___75 *);
	void (*exit)(struct net___75 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___63 {
	int (*ieee_getets)(struct net_device___64 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___64 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___64 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___64 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___64 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___64 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___64 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___64 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___64 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___64 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___64 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___64 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___64 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___64 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___64 *);
	u8 (*setstate)(struct net_device___64 *, u8);
	void (*getpermhwaddr)(struct net_device___64 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___64 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___64 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___64 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___64 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___64 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___64 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___64 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___64 *, int, u8 *);
	void (*setpfccfg)(struct net_device___64 *, int, u8);
	void (*getpfccfg)(struct net_device___64 *, int, u8 *);
	u8 (*setall)(struct net_device___64 *);
	u8 (*getcap)(struct net_device___64 *, int, u8 *);
	int (*getnumtcs)(struct net_device___64 *, int, u8 *);
	int (*setnumtcs)(struct net_device___64 *, int, u8);
	u8 (*getpfcstate)(struct net_device___64 *);
	void (*setpfcstate)(struct net_device___64 *, u8);
	void (*getbcncfg)(struct net_device___64 *, int, u32 *);
	void (*setbcncfg)(struct net_device___64 *, int, u32);
	void (*getbcnrp)(struct net_device___64 *, int, u8 *);
	void (*setbcnrp)(struct net_device___64 *, int, u8);
	int (*setapp)(struct net_device___64 *, u8, u16, u8);
	int (*getapp)(struct net_device___64 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___64 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___64 *, int, u8);
	u8 (*getdcbx)(struct net_device___64 *);
	u8 (*setdcbx)(struct net_device___64 *, u8);
	int (*peer_getappinfo)(struct net_device___64 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___64 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___64 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___64 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___64 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___64 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___267 {
	refcount_t count;
	struct ns_common___29 ns;
	struct user_namespace___283 *user_ns;
	struct ucounts___283 *ucounts;
	struct css_set___267 *root_cset;
};

struct bpf_map___268;

struct bpf_map_ops___267 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___268 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___268 *, struct file___418 *);
	void (*map_free)(struct bpf_map___268 *);
	int (*map_get_next_key)(struct bpf_map___268 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___268 *);
	void * (*map_lookup_elem)(struct bpf_map___268 *, void *);
	int (*map_update_elem)(struct bpf_map___268 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___268 *, void *);
	int (*map_push_elem)(struct bpf_map___268 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___268 *, void *);
	int (*map_peek_elem)(struct bpf_map___268 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___268 *, struct file___418 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___268 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___268 *, void *, struct seq_file___357 *);
	int (*map_check_btf)(const struct bpf_map___268 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___268 {
	const struct bpf_map_ops___267 *ops;
	struct bpf_map___268 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___386 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___63;

struct bpf_map_dev_ops___63 {
	int (*map_get_next_key)(struct bpf_offloaded_map___63 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___63 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___63 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___63 *, void *);
};

struct bpf_offloaded_map___63 {
	struct bpf_map___268 map;
	struct net_device___64 *netdev;
	const struct bpf_map_dev_ops___63 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___56 {
	int (*test_run)(struct bpf_prog___56 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___56 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___56 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___56 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___56 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___56 *, u32 *);
};

struct bpf_prog_offload_ops___56 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___56 *);
	int (*translate)(struct bpf_prog___56 *);
	void (*destroy)(struct bpf_prog___56 *);
};

struct bpf_prog_offload___56 {
	struct bpf_prog___56 *prog;
	struct net_device___64 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___56 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___59 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___56 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___56 *ops;
	struct bpf_map___268 **used_maps;
	struct bpf_prog___56 *prog;
	struct user_struct___386 *user;
	u64 load_time;
	struct bpf_map___268 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___56 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___56 {
	struct bpf_prog___56 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___56 {
	struct callback_head rcu;
	struct bpf_prog_array_item___56 items[0];
};

struct cgroup_bpf___56 {
	struct bpf_prog_array___56 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___56 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___268;

typedef void (*kthread_work_func_t___268)(struct kthread_work___268 *);

struct kthread_worker___268;

struct kthread_work___268 {
	struct list_head node;
	kthread_work_func_t___268 func;
	struct kthread_worker___268 *worker;
	int canceling;
};

struct kthread_worker___268 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___420 *task;
	struct kthread_work___268 *current_work;
};

struct kthread_delayed_work___267 {
	struct kthread_work___268 work;
	struct timer_list timer;
};

struct psi_group___267 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___268 *poll_kworker;
	struct kthread_delayed_work___267 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___267;

struct cgroup_rstat_cpu___267;

struct cgroup___267 {
	struct cgroup_subsys_state___267 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___413 *kn;
	struct cgroup_file___267 procs_file;
	struct cgroup_file___267 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___267 *subsys[13];
	struct cgroup_root___267 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___267 *dom_cgrp;
	struct cgroup_rstat_cpu___267 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___56 bpf;
	atomic_t congestion_count;
	struct cgroup___267 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___267 psi;
	int ancestor_ids[0];
};

struct cftype___267;

struct cgroup_subsys___267 {
	struct cgroup_subsys_state___267 * (*css_alloc)(struct cgroup_subsys_state___267 *);
	int (*css_online)(struct cgroup_subsys_state___267 *);
	void (*css_offline)(struct cgroup_subsys_state___267 *);
	void (*css_released)(struct cgroup_subsys_state___267 *);
	void (*css_free)(struct cgroup_subsys_state___267 *);
	void (*css_reset)(struct cgroup_subsys_state___267 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___267 *, int);
	int (*css_extra_stat_show)(struct seq_file___357 *, struct cgroup_subsys_state___267 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___420 *);
	void (*cancel_fork)(struct task_struct___420 *);
	void (*fork)(struct task_struct___420 *);
	void (*exit)(struct task_struct___420 *);
	void (*free)(struct task_struct___420 *);
	void (*bind)(struct cgroup_subsys_state___267 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___267 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___267 *dfl_cftypes;
	struct cftype___267 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___267 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___267 *updated_children;
	struct cgroup___267 *updated_next;
};

struct cgroup_root___267 {
	struct kernfs_root___412 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___267 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___267 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___267 *ss;
	struct list_head node;
	struct kernfs_ops___412 *kf_ops;
	int (*open)(struct kernfs_open_file___412 *);
	void (*release)(struct kernfs_open_file___412 *);
	u64 (*read_u64)(struct cgroup_subsys_state___267 *, struct cftype___267 *);
	s64 (*read_s64)(struct cgroup_subsys_state___267 *, struct cftype___267 *);
	int (*seq_show)(struct seq_file___357 *, void *);
	void * (*seq_start)(struct seq_file___357 *, loff_t *);
	void * (*seq_next)(struct seq_file___357 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___357 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___267 *, struct cftype___267 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___267 *, struct cftype___267 *, s64);
	ssize_t (*write)(struct kernfs_open_file___412 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___412 *, struct poll_table_struct___260 *);
};

struct xdp_rxq_info___63 {
	struct net_device___64 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___63 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___64 *dev_rx;
};

struct netlink_callback___65 {
	struct sk_buff___65 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___65 *);
	int (*dump)(struct sk_buff___65 *, struct netlink_callback___65 *);
	int (*done)(struct netlink_callback___65 *);
	void *data;
	struct module___348 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___63 {
	int (*create)(struct sk_buff___65 *, struct net_device___64 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___65 *, unsigned char *);
	int (*cache)(const struct neighbour___46 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___64 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___63 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___63 *, int);
	int poll_owner;
	struct net_device___64 *dev;
	struct sk_buff___65 *gro_list;
	struct sk_buff___65 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___63 {
	struct net_device___64 *dev;
	struct Qdisc___56 *qdisc;
	struct Qdisc___56 *qdisc_sleeping;
	struct kobject___406 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___64 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___56 {
	struct sk_buff___65 *head;
	struct sk_buff___65 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___56;

struct Qdisc___56 {
	int (*enqueue)(struct sk_buff___65 *, struct Qdisc___56 *, struct sk_buff___65 **);
	struct sk_buff___65 * (*dequeue)(struct Qdisc___56 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___56 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___63 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___63 gso_skb;
	struct qdisc_skb_head___56 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___56 *next_sched;
	struct sk_buff_head___63 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___63 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___406 kobj;
	struct net_device___64 *dev;
	long: 64;
	struct xdp_rxq_info___63 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___63)(struct net_device___64 *, struct sk_buff___65 *, struct net_device___64 *);

struct netdev_bpf___63 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___56 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___56 *prog;
			const struct bpf_prog_offload_ops___56 *ops;
		} verifier;
		struct {
			struct bpf_prog___56 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___63 *offmap;
		};
		struct {
			struct xdp_umem___3 *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___63 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___65 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___63 {
	int (*tls_dev_add)(struct net_device___64 *, struct sock___47 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___64 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___64 *, struct sock___47 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___63 {
	int (*ndo_init)(struct net_device___64 *);
	void (*ndo_uninit)(struct net_device___64 *);
	int (*ndo_open)(struct net_device___64 *);
	int (*ndo_stop)(struct net_device___64 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___65 *, struct net_device___64 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___65 *, struct net_device___64 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___64 *, struct sk_buff___65 *, struct net_device___64 *, select_queue_fallback_t___63);
	void (*ndo_change_rx_flags)(struct net_device___64 *, int);
	void (*ndo_set_rx_mode)(struct net_device___64 *);
	int (*ndo_set_mac_address)(struct net_device___64 *, void *);
	int (*ndo_validate_addr)(struct net_device___64 *);
	int (*ndo_do_ioctl)(struct net_device___64 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___64 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___64 *, int);
	int (*ndo_neigh_setup)(struct net_device___64 *, struct neigh_parms___46 *);
	void (*ndo_tx_timeout)(struct net_device___64 *);
	void (*ndo_get_stats64)(struct net_device___64 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___64 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___64 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___64 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___64 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___64 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___64 *);
	int (*ndo_netpoll_setup)(struct net_device___64 *, struct netpoll_info___3 *);
	void (*ndo_netpoll_cleanup)(struct net_device___64 *);
	int (*ndo_set_vf_mac)(struct net_device___64 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___64 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___64 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___64 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___64 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___64 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___64 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___64 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___64 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___64 *, int, struct sk_buff___65 *);
	int (*ndo_set_vf_guid)(struct net_device___64 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___64 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___64 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___64 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___64 *, const struct sk_buff___65 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___64 *, struct net_device___64 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___64 *, struct net_device___64 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___64 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___64 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___64 *, struct neighbour___46 *);
	void (*ndo_neigh_destroy)(struct net_device___64 *, struct neighbour___46 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___64 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___64 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___64 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___65 *, struct netlink_callback___65 *, struct net_device___64 *, struct net_device___64 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___64 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___64 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___65 *, u32, u32, struct net_device___64 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___64 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___64 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___64 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___64 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___64 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___64 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___64 *, struct net_device___64 *);
	void (*ndo_dfwd_del_station)(struct net_device___64 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___64 *);
	int (*ndo_set_tx_maxrate)(struct net_device___64 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___64 *);
	int (*ndo_change_proto_down)(struct net_device___64 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___64 *, struct sk_buff___65 *);
	void (*ndo_set_rx_headroom)(struct net_device___64 *, int);
	int (*ndo_bpf)(struct net_device___64 *, struct netdev_bpf___63 *);
	int (*ndo_xdp_xmit)(struct net_device___64 *, int, struct xdp_frame___63 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___64 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___64 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___46 {
	possible_net_t___65 net;
	struct net_device___64 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___46 *);
	void (*neigh_cleanup)(struct neighbour___46 *);
	struct neigh_table___46 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct netpoll___2;

struct netpoll_info___3 {
	refcount_t refcnt;
	struct semaphore dev_lock;
	struct sk_buff_head___63 txq;
	struct delayed_work tx_work;
	struct netpoll___2 *netpoll;
	struct callback_head rcu;
};

struct l3mdev_ops___46 {
	u32 (*l3mdev_fib_table)(const struct net_device___64 *);
	struct sk_buff___65 * (*l3mdev_l3_rcv)(struct net_device___64 *, struct sk_buff___65 *, u16);
	struct sk_buff___65 * (*l3mdev_l3_out)(struct net_device___64 *, struct sock___47 *, struct sk_buff___65 *, u16);
	struct dst_entry___46 * (*l3mdev_link_scope_lookup)(const struct net_device___64 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct ndisc_ops___26 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___64 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___64 *, struct neighbour___46 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___64 *, u8, struct neighbour___46 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___64 *, struct sk_buff___65 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___75 *, struct net_device___64 *, const struct prefix_info *, struct inet6_dev___26 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct in_ifaddr___4;

struct in_device___4 {
	struct net_device___64 *dev;
	refcount_t refcnt;
	int dead;
	struct in_ifaddr___4 *ifa_list;
	struct ip_mc_list *mc_list;
	struct ip_mc_list **mc_hash;
	int mc_count;
	spinlock_t mc_tomb_lock;
	struct ip_mc_list *mc_tomb;
	long unsigned int mr_v1_seen;
	long unsigned int mr_v2_seen;
	long unsigned int mr_maxdelay;
	long unsigned int mr_qi;
	long unsigned int mr_qri;
	unsigned char mr_qrv;
	unsigned char mr_gq_running;
	unsigned char mr_ifc_count;
	struct timer_list mr_gq_timer;
	struct timer_list mr_ifc_timer;
	struct neigh_parms___46 *arp_parms;
	struct ipv4_devconf cnf;
	struct callback_head callback_head;
};

struct ifmcaddr6___26;

struct inet6_dev___26 {
	struct net_device___64 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___26 *mc_list;
	struct ifmcaddr6___26 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___7 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	u8 rndid[8];
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___46 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
};

struct tcf_proto___56;

struct mini_Qdisc___56 {
	struct tcf_proto___56 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___56 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___64 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___75 *, struct net_device___64 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___64 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___64 *, struct list_head *);
	size_t (*get_size)(const struct net_device___64 *);
	int (*fill_info)(struct sk_buff___65 *, const struct net_device___64 *);
	size_t (*get_xstats_size)(const struct net_device___64 *);
	int (*fill_xstats)(struct sk_buff___65 *, const struct net_device___64 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___64 *, struct net_device___64 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___64 *, const struct net_device___64 *);
	int (*fill_slave_info)(struct sk_buff___65 *, const struct net_device___64 *, const struct net_device___64 *);
	struct net___75 * (*get_link_net)(const struct net_device___64 *);
	size_t (*get_linkxstats_size)(const struct net_device___64 *, int);
	int (*fill_linkxstats)(struct sk_buff___65 *, const struct net_device___64 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___63 {
	struct list_head poll_list;
	struct sk_buff_head___63 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___63 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___56 *output_queue;
	struct Qdisc___56 **output_queue_tailp;
	struct sk_buff___65 *completion_queue;
	struct sk_buff_head___63 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___63 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___63 input_pkt_queue;
	struct napi_struct___63 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct in_ifaddr___4 {
	struct hlist_node hash;
	struct in_ifaddr___4 *ifa_next;
	struct in_device___4 *ifa_dev;
	struct callback_head callback_head;
	__be32 ifa_local;
	__be32 ifa_address;
	__be32 ifa_mask;
	__u32 ifa_rt_priority;
	__be32 ifa_broadcast;
	unsigned char ifa_scope;
	unsigned char ifa_prefixlen;
	__u32 ifa_flags;
	char ifa_label[16];
	__u32 ifa_valid_lft;
	__u32 ifa_preferred_lft;
	long unsigned int ifa_cstamp;
	long unsigned int ifa_tstamp;
};

struct netpoll___2 {
	struct net_device___64 *dev;
	char dev_name[16];
	const char *name;
	union inet_addr local_ip;
	union inet_addr remote_ip;
	bool ipv6;
	u16 local_port;
	u16 remote_port;
	u8 remote_mac[6];
	struct work_struct cleanup_work;
};

struct bdi_writeback_congested___211 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___211 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___211 {
	struct bio___211 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___213 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___213 bip_inline_vecs[0];
};

struct bio_set___211 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___211 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___154 {
	struct mem_cgroup___154 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___154 {
	struct lruvec___419 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___154 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___154 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct module_attribute___346 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___346 *, struct module_kobject___346 *, char *);
	ssize_t (*store)(struct module_attribute___346 *, struct module_kobject___346 *, const char *, size_t);
	void (*setup)(struct module___348 *, const char *);
	int (*test)(struct module___348 *);
	void (*free)(struct module___348 *);
};

struct gnet_dump___56 {
	spinlock_t *lock;
	struct sk_buff___65 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___56;

struct Qdisc_ops___56 {
	struct Qdisc_ops___56 *next;
	const struct Qdisc_class_ops___56 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___65 *, struct Qdisc___56 *, struct sk_buff___65 **);
	struct sk_buff___65 * (*dequeue)(struct Qdisc___56 *);
	struct sk_buff___65 * (*peek)(struct Qdisc___56 *);
	int (*init)(struct Qdisc___56 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___56 *);
	void (*destroy)(struct Qdisc___56 *);
	int (*change)(struct Qdisc___56 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___56 *);
	int (*change_tx_queue_len)(struct Qdisc___56 *, unsigned int);
	int (*dump)(struct Qdisc___56 *, struct sk_buff___65 *);
	int (*dump_stats)(struct Qdisc___56 *, struct gnet_dump___56 *);
	void (*ingress_block_set)(struct Qdisc___56 *, u32);
	void (*egress_block_set)(struct Qdisc___56 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___56 *);
	u32 (*egress_block_get)(struct Qdisc___56 *);
	struct module___348 *owner;
};

struct tcf_block___56;

struct Qdisc_class_ops___56 {
	unsigned int flags;
	struct netdev_queue___63 * (*select_queue)(struct Qdisc___56 *, struct tcmsg *);
	int (*graft)(struct Qdisc___56 *, long unsigned int, struct Qdisc___56 *, struct Qdisc___56 **, struct netlink_ext_ack *);
	struct Qdisc___56 * (*leaf)(struct Qdisc___56 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___56 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___56 *, u32);
	int (*change)(struct Qdisc___56 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___56 *, long unsigned int);
	void (*walk)(struct Qdisc___56 *, struct qdisc_walker *);
	struct tcf_block___56 * (*tcf_block)(struct Qdisc___56 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___56 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___56 *, long unsigned int);
	int (*dump)(struct Qdisc___56 *, long unsigned int, struct sk_buff___65 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___56 *, long unsigned int, struct gnet_dump___56 *);
};

struct tcf_chain___56;

struct tcf_block___56 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___75 *net;
	struct Qdisc___56 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___56 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___56;

struct tcf_proto_ops___56;

struct tcf_proto___56 {
	struct tcf_proto___56 *next;
	void *root;
	int (*classify)(struct sk_buff___65 *, const struct tcf_proto___56 *, struct tcf_result___56 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___56 *ops;
	struct tcf_chain___56 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___56 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___56 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___56 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___65 *, const struct tcf_proto___56 *, struct tcf_result___56 *);
	int (*init)(struct tcf_proto___56 *);
	void (*destroy)(struct tcf_proto___56 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___56 *, u32);
	void (*put)(struct tcf_proto___56 *, void *);
	int (*change)(struct net___75 *, struct sk_buff___65 *, struct tcf_proto___56 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___56 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___56 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___56 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___75 *, struct tcf_chain___56 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___75 *, struct tcf_proto___56 *, void *, struct sk_buff___65 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___65 *, struct net___75 *, void *);
	struct module___348 *owner;
	int flags;
};

struct tcf_chain___56 {
	struct mutex filter_chain_lock;
	struct tcf_proto___56 *filter_chain;
	struct list_head list;
	struct tcf_block___56 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___56 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___46 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___56 *prog;
};

struct bpf_redirect_info___56 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___268 *map;
	struct bpf_map___268 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___46;

struct neigh_hash_table___46;

struct neigh_table___46 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___64 *, __u32 *);
	bool (*key_eq)(const struct neighbour___46 *, const void *);
	int (*constructor)(struct neighbour___46 *);
	int (*pconstructor)(struct pneigh_entry___46 *);
	void (*pdestructor)(struct pneigh_entry___46 *);
	void (*proxy_redo)(struct sk_buff___65 *);
	char *id;
	struct neigh_parms___46 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___63 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___46 *nht;
	struct pneigh_entry___46 **phash_buckets;
};

struct neigh_ops___46 {
	int family;
	void (*solicit)(struct neighbour___46 *, struct sk_buff___65 *);
	void (*error_report)(struct neighbour___46 *, struct sk_buff___65 *);
	int (*output)(struct neighbour___46 *, struct sk_buff___65 *);
	int (*connected_output)(struct neighbour___46 *, struct sk_buff___65 *);
};

struct pneigh_entry___46 {
	struct pneigh_entry___46 *next;
	possible_net_t___65 net;
	struct net_device___64 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___46 {
	struct neighbour___46 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___46 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___46 *ctarget;
	struct net___75 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___46 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___46 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___31;

struct timewait_sock_ops___29;

struct proto___46 {
	void (*close)(struct sock___47 *, long int);
	int (*pre_connect)(struct sock___47 *, struct sockaddr *, int);
	int (*connect)(struct sock___47 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___47 *, int);
	struct sock___47 * (*accept)(struct sock___47 *, int, int *, bool);
	int (*ioctl)(struct sock___47 *, int, long unsigned int);
	int (*init)(struct sock___47 *);
	void (*destroy)(struct sock___47 *);
	void (*shutdown)(struct sock___47 *, int);
	int (*setsockopt)(struct sock___47 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___47 *, int, int, char *, int *);
	void (*keepalive)(struct sock___47 *, int);
	int (*sendmsg)(struct sock___47 *, struct msghdr___49 *, size_t);
	int (*recvmsg)(struct sock___47 *, struct msghdr___49 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___47 *, struct page___419 *, int, size_t, int);
	int (*bind)(struct sock___47 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___47 *, struct sk_buff___65 *);
	void (*release_cb)(struct sock___47 *);
	int (*hash)(struct sock___47 *);
	void (*unhash)(struct sock___47 *);
	void (*rehash)(struct sock___47 *);
	int (*get_port)(struct sock___47 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___47 *);
	bool (*stream_memory_read)(const struct sock___47 *);
	void (*enter_memory_pressure)(struct sock___47 *);
	void (*leave_memory_pressure)(struct sock___47 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___31 *rsk_prot;
	struct timewait_sock_ops___29 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___348 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___47 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct request_sock___32;

struct request_sock_ops___31 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___47 *, struct request_sock___32 *);
	void (*send_ack)(const struct sock___47 *, struct sk_buff___65 *, struct request_sock___32 *);
	void (*send_reset)(const struct sock___47 *, struct sk_buff___65 *);
	void (*destructor)(struct request_sock___32 *);
	void (*syn_ack_timeout)(const struct request_sock___32 *);
};

struct timewait_sock_ops___29 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___47 *, struct sock___47 *, void *);
	void (*twsk_destructor)(struct sock___47 *);
};

struct request_sock___32 {
	struct sock_common___46 __req_common;
	struct request_sock___32 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___31 *rsk_ops;
	struct sock___47 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct inet6_ifaddr {
	struct in6_addr addr;
	__u32 prefix_len;
	__u32 rt_priority;
	__u32 valid_lft;
	__u32 prefered_lft;
	refcount_t refcnt;
	spinlock_t lock;
	int state;
	__u32 flags;
	__u8 dad_probes;
	__u8 stable_privacy_retry;
	__u16 scope;
	__u64 dad_nonce;
	long unsigned int cstamp;
	long unsigned int tstamp;
	struct delayed_work dad_work;
	struct inet6_dev___26 *idev;
	struct fib6_info *rt;
	struct hlist_node addr_lst;
	struct list_head if_list;
	struct list_head tmp_list;
	struct inet6_ifaddr *ifpub;
	int regen_count;
	bool tokenized;
	struct callback_head rcu;
	struct in6_addr peer_addr;
};

struct ifmcaddr6___26 {
	struct in6_addr mca_addr;
	struct inet6_dev___26 *idev;
	struct ifmcaddr6___26 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ip6_ra_chain___26 {
	struct ip6_ra_chain___26 *next;
	struct sock___47 *sk;
	int sel;
	void (*destructor)(struct sock___47 *);
};

struct ipv6_stub___6 {
	int (*ipv6_sock_mc_join)(struct sock___47 *, int, const struct in6_addr *);
	int (*ipv6_sock_mc_drop)(struct sock___47 *, int, const struct in6_addr *);
	int (*ipv6_dst_lookup)(struct net___75 *, struct sock___47 *, struct dst_entry___46 **, struct flowi6 *);
	struct fib6_table * (*fib6_get_table)(struct net___75 *, u32);
	struct fib6_info * (*fib6_lookup)(struct net___75 *, int, struct flowi6 *, int);
	struct fib6_info * (*fib6_table_lookup)(struct net___75 *, struct fib6_table *, int, struct flowi6 *, int);
	struct fib6_info * (*fib6_multipath_select)(const struct net___75 *, struct fib6_info *, struct flowi6 *, int, const struct sk_buff___65 *, int);
	u32 (*ip6_mtu_from_fib6)(struct fib6_info *, struct in6_addr *, struct in6_addr *);
	void (*udpv6_encap_enable)();
	void (*ndisc_send_na)(struct net_device___64 *, const struct in6_addr *, const struct in6_addr *, bool, bool, bool, bool);
	struct neigh_table___46 *nd_tbl;
};

struct ipv6_bpf_stub___6 {
	int (*inet6_bind)(struct sock___47 *, struct sockaddr *, int, bool, bool);
	struct sock___47 * (*udp6_lib_lookup)(struct net___75 *, const struct in6_addr *, __be16, const struct in6_addr *, __be16, int, int, struct udp_table *, struct sk_buff___65 *);
};

struct module___349;

struct file___419;

struct kiocb___419;

struct iov_iter___186;

struct poll_table_struct___261;

struct vm_area_struct___420;

struct inode___419;

struct file_lock___419;

struct page___420;

struct pipe_inode_info___100;

struct seq_file___358;

struct file_operations___419 {
	struct module___349 *owner;
	loff_t (*llseek)(struct file___419 *, loff_t, int);
	ssize_t (*read)(struct file___419 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___419 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___419 *, struct iov_iter___186 *);
	ssize_t (*write_iter)(struct kiocb___419 *, struct iov_iter___186 *);
	int (*iopoll)(struct kiocb___419 *, bool);
	int (*iterate)(struct file___419 *, struct dir_context *);
	int (*iterate_shared)(struct file___419 *, struct dir_context *);
	__poll_t (*poll)(struct file___419 *, struct poll_table_struct___261 *);
	long int (*unlocked_ioctl)(struct file___419 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___419 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___419 *, struct vm_area_struct___420 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___419 *, struct file___419 *);
	int (*flush)(struct file___419 *, fl_owner_t);
	int (*release)(struct inode___419 *, struct file___419 *);
	int (*fsync)(struct file___419 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___419 *, int);
	int (*lock)(struct file___419 *, int, struct file_lock___419 *);
	ssize_t (*sendpage)(struct file___419 *, struct page___420 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___419 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___419 *, int, struct file_lock___419 *);
	ssize_t (*splice_write)(struct pipe_inode_info___100 *, struct file___419 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___419 *, loff_t *, struct pipe_inode_info___100 *, size_t, unsigned int);
	int (*setlease)(struct file___419 *, long int, struct file_lock___419 **, void **);
	long int (*fallocate)(struct file___419 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___358 *, struct file___419 *);
	ssize_t (*copy_file_range)(struct file___419 *, loff_t, struct file___419 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___419 *, loff_t, struct file___419 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___419 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___420 {
	u64 seqnum;
	struct vm_area_struct___420 *vmas[4];
};

struct page_frag___420 {
	struct page___420 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___420;

struct mem_cgroup___155;

struct cred___387;

struct nsproxy___314;

struct signal_struct___294;

struct bio_list___212;

struct backing_dev_info___212;

struct css_set___268;

struct vm_struct___323;

struct task_struct___421 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___421 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___420 *mm;
	struct mm_struct___420 *active_mm;
	struct vmacache___420 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___421 *real_parent;
	struct task_struct___421 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___421 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___155 *active_memcg;
	long int rh_reserved2;
	struct pid___237 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___237 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___237 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___387 *ptracer_cred;
	const struct cred___387 *real_cred;
	const struct cred___387 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___314 *nsproxy;
	struct signal_struct___294 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___421 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___212 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___212 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___268 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___100 *splice_pipe;
	struct page_frag___420 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___155 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___421 *oom_reaper_list;
	struct vm_struct___323 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___154 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___420 *pgtable_t___420;

struct address_space___419;

struct dev_pagemap___407;

struct page___420 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___419 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___420 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___420 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___420 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___407 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___155 *mem_cgroup;
};

struct pglist_data___420;

struct lruvec___420 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___420 *pgdat;
};

struct zone___420 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___420 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___420 {
	struct zone___420 *zone;
	int zone_idx;
};

struct zonelist___420 {
	struct zoneref___420 _zonerefs[25];
};

struct pglist_data___420 {
	struct zone___420 node_zones[3];
	struct zonelist___420 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___421 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___421 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___420 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___421 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___421 *owner;
};

struct secondary_data___421 {
	void *stack;
	struct task_struct___421 *task;
	long int status;
};

struct blocking_notifier_head___420 {
	struct rw_semaphore___421 rwsem;
	struct notifier_block *head;
};

struct cgroup___268;

struct cgroup_subsys___268;

struct cgroup_subsys_state___268 {
	struct cgroup___268 *cgroup;
	struct cgroup_subsys___268 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___268 *parent;
};

struct kernfs_node___414;

struct cgroup_file___268 {
	struct kernfs_node___414 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___155;

struct mem_cgroup___155 {
	struct cgroup_subsys_state___268 css;
	struct mem_cgroup_id___13 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___268 events_file;
	struct cgroup_file___268 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___421 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___155 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct key___387;

struct ucounts___284;

struct user_namespace___284 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___284 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___29 ns;
	long unsigned int flags;
	struct key___387 *persistent_keyring_register;
	struct rw_semaphore___421 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___284 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dentry___419;

struct path___420 {
	struct vfsmount *mnt;
	struct dentry___419 *dentry;
};

struct file___419 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___420 f_path;
	struct inode___419 *f_inode;
	const struct file_operations___419 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___237 f_owner;
	const struct cred___387 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___419 *f_mapping;
	errseq_t f_wb_err;
};

struct user_struct___387;

struct cred___387 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___387 *session_keyring;
	struct key___387 *process_keyring;
	struct key___387 *thread_keyring;
	struct key___387 *request_key_auth;
	void *security;
	struct user_struct___387 *user;
	struct user_namespace___284 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___413;

struct kernfs_elem_dir___413 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___413 *root;
};

struct kernfs_syscall_ops___413;

struct kernfs_root___413 {
	struct kernfs_node___414 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___413 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___413 {
	struct kernfs_node___414 *target_kn;
};

struct kernfs_ops___413;

struct kernfs_elem_attr___413 {
	const struct kernfs_ops___413 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___414 *notify_next;
};

struct kernfs_node___414 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___414 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___413 dir;
		struct kernfs_elem_symlink___413 symlink;
		struct kernfs_elem_attr___413 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___413;

struct kernfs_ops___413 {
	int (*open)(struct kernfs_open_file___413 *);
	void (*release)(struct kernfs_open_file___413 *);
	int (*seq_show)(struct seq_file___358 *, void *);
	void * (*seq_start)(struct seq_file___358 *, loff_t *);
	void * (*seq_next)(struct seq_file___358 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___358 *, void *);
	ssize_t (*read)(struct kernfs_open_file___413 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___413 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___413 *, struct vm_area_struct___420 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___413 *, struct poll_table_struct___261 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___413 {
	int (*remount_fs)(struct kernfs_root___413 *, int *, char *);
	int (*show_options)(struct seq_file___358 *, struct kernfs_root___413 *);
	int (*mkdir)(struct kernfs_node___414 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___414 *);
	int (*rename)(struct kernfs_node___414 *, struct kernfs_node___414 *, const char *);
	int (*show_path)(struct seq_file___358 *, struct kernfs_node___414 *, struct kernfs_root___413 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___358;

struct seq_file___358 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___358 *op;
	int poll_event;
	const struct file___419 *file;
	void *private;
};

struct vm_operations_struct___407;

struct kernfs_open_file___413 {
	struct kernfs_node___414 *kn;
	struct file___419 *file;
	struct seq_file___358 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___407 *vm_ops;
};

struct vm_fault___407;

struct vm_operations_struct___407 {
	void (*open)(struct vm_area_struct___420 *);
	void (*close)(struct vm_area_struct___420 *);
	int (*split)(struct vm_area_struct___420 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___420 *);
	vm_fault_t (*fault)(struct vm_fault___407 *);
	vm_fault_t (*huge_fault)(struct vm_fault___407 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___407 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___420 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___407 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___407 *);
	int (*access)(struct vm_area_struct___420 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___420 *);
	int (*set_policy)(struct vm_area_struct___420 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___420 *, long unsigned int);
	struct page___420 * (*find_special_page)(struct vm_area_struct___420 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___271)(struct file___419 *, wait_queue_head_t *, struct poll_table_struct___261 *);

struct poll_table_struct___261 {
	poll_queue_proc___271 _qproc;
	__poll_t _key;
};

struct vm_area_struct___420 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___420 *vm_next;
	struct vm_area_struct___420 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___420 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___407 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___419 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sock___48;

struct kobj_ns_type_operations___47 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___48 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct net___76;

typedef struct {
	struct net___76 *net;
} possible_net_t___66;

struct proto___47;

struct sock_common___47 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___47 *skc_prot;
	possible_net_t___66 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___48 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___66;

struct sk_buff_head___64 {
	struct sk_buff___66 *next;
	struct sk_buff___66 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___47;

struct socket_wq___48;

struct dst_entry___47;

struct socket___49;

struct net_device___65;

struct sock___48 {
	struct sock_common___47 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___64 sk_error_queue;
	struct sk_buff_head___64 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___66 *head;
		struct sk_buff___66 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___47 *sk_filter;
	union {
		struct socket_wq___48 *sk_wq;
		struct socket_wq___48 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___47 *sk_rx_dst;
	struct dst_entry___47 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___66 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___64 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___420 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___47 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___237 *sk_peer_pid;
	const struct cred___387 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___49 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___155 *sk_memcg;
	void (*sk_state_change)(struct sock___48 *);
	void (*sk_data_ready)(struct sock___48 *);
	void (*sk_write_space)(struct sock___48 *);
	void (*sk_error_report)(struct sock___48 *);
	int (*sk_backlog_rcv)(struct sock___48 *, struct sk_buff___66 *);
	struct sk_buff___66 * (*sk_validate_xmit_skb)(struct sock___48 *, struct net_device___65 *, struct sk_buff___66 *);
	void (*sk_destruct)(struct sock___48 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kobject___407;

struct bin_attribute___383;

struct attribute_group___384 {
	const char *name;
	umode_t (*is_visible)(struct kobject___407 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___407 *, struct bin_attribute___383 *, int);
	struct attribute **attrs;
	struct bin_attribute___383 **bin_attrs;
};

struct kset___406;

struct kobj_type___406;

struct kobject___407 {
	const char *name;
	struct list_head entry;
	struct kobject___407 *parent;
	struct kset___406 *kset;
	struct kobj_type___406 *ktype;
	struct kernfs_node___414 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___383 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___419 *, struct kobject___407 *, struct bin_attribute___383 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___419 *, struct kobject___407 *, struct bin_attribute___383 *, char *, loff_t, size_t);
	int (*mmap)(struct file___419 *, struct kobject___407 *, struct bin_attribute___383 *, struct vm_area_struct___420 *);
};

struct sysfs_ops___406 {
	ssize_t (*show)(struct kobject___407 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___407 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___406;

struct kset___406 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___407 kobj;
	const struct kset_uevent_ops___406 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___406 {
	void (*release)(struct kobject___407 *);
	const struct sysfs_ops___406 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___47 * (*child_ns_type)(struct kobject___407 *);
	const void * (*namespace)(struct kobject___407 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___406 {
	int (* const filter)(struct kset___406 *, struct kobject___407 *);
	const char * (* const name)(struct kset___406 *, struct kobject___407 *);
	int (* const uevent)(struct kset___406 *, struct kobject___407 *, struct kobj_uevent_env *);
};

struct kobj_attribute___397 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___407 *, struct kobj_attribute___397 *, char *);
	ssize_t (*store)(struct kobject___407 *, struct kobj_attribute___397 *, const char *, size_t);
};

struct kernel_param___347;

struct kernel_param_ops___347 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___347 *);
	int (*get)(char *, const struct kernel_param___347 *);
	void (*free)(void *);
};

struct kparam_array___347;

struct kernel_param___347 {
	const char *name;
	struct module___349 *mod;
	const struct kernel_param_ops___347 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___347 *arr;
	};
};

struct kparam_array___347 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___347 *ops;
	void *elem;
};

struct module_kobject___347 {
	struct kobject___407 kobj;
	struct module___349 *mod;
	struct kobject___407 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___347 {
	struct module___349 *mod;
	struct latch_tree_node node;
};

struct module_layout___347 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___347 mtn;
};

struct module_attribute___347;

struct module___349 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___347 mkobj;
	struct module_attribute___347 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___407 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___347 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___347 core_layout;
	struct module_layout___347 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___347 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___347 *, struct module_kobject___347 *, char *);
	ssize_t (*store)(struct module_attribute___347 *, struct module_kobject___347 *, const char *, size_t);
	void (*setup)(struct module___349 *, const char *);
	int (*test)(struct module___349 *);
	void (*free)(struct module___349 *);
};

struct user_struct___387 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___387 *uid_keyring;
	struct key___387 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___420;

struct mm_struct___420 {
	struct {
		struct vm_area_struct___420 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___419 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___421 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___420 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___421 *owner;
		struct user_namespace___284 *user_ns;
		struct file___419 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___420 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___268;

struct nsproxy___314 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net___76 *net_ns;
	struct cgroup_namespace___268 *cgroup_ns;
};

struct signal_struct___294 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___421 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___421 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___237 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___237 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___420 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___237 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___212;

struct bio_list___212 {
	struct bio___212 *head;
	struct bio___212 *tail;
};

struct bdi_writeback_congested___212;

struct bdi_writeback___212 {
	struct backing_dev_info___212 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___212 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___268 *memcg_css;
	struct cgroup_subsys_state___268 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___387;

struct backing_dev_info___212 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___212 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___387 *dev;
	struct device___387 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___419 *debug_dir;
	struct dentry___419 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___268 {
	struct cgroup_subsys_state___268 *subsys[13];
	refcount_t refcount;
	struct css_set___268 *dom_cset;
	struct cgroup___268 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___268 *mg_src_cgrp;
	struct cgroup___268 *mg_dst_cgrp;
	struct css_set___268 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___419;

struct pipe_buffer___100;

struct pipe_inode_info___100 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___420 *tmp_page;
	struct fasync_struct___419 *fasync_readers;
	struct fasync_struct___419 *fasync_writers;
	struct pipe_buffer___100 *bufs;
	struct user_struct___387 *user;
};

struct vm_struct___323 {
	struct vm_struct___323 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___420 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___306 {
	struct task_struct___421 task;
	long unsigned int stack[8192];
};

struct address_space_operations___419;

struct address_space___419 {
	struct inode___419 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___421 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___419 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___407)(struct vm_area_struct___420 *, long unsigned int, const struct page___420 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___407)(struct page___420 *, void *);

struct dev_pagemap___407 {
	dev_page_fault_t___407 page_fault;
	dev_page_free_t___407 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___387 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___420 {
	struct task_struct___421 *task;
	struct core_thread___420 *next;
};

struct core_state___420 {
	atomic_t nr_threads;
	struct core_thread___420 dumper;
	struct completion startup;
};

struct vm_fault___407 {
	struct vm_area_struct___420 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___420 *cow_page;
	struct mem_cgroup___155 *memcg;
	struct page___420 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___420 prealloc_pte;
};

struct bio_vec___214 {
	struct page___420 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___186 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___214 *bvec;
		struct pipe_inode_info___100 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct msghdr___50 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___186 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___419 *msg_iocb;
};

struct kiocb___419 {
	struct file___419 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___419 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct inet_frags___64;

struct netns_frags___64 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___64 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct inet_frag_queue___64;

struct inet_frags___64 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___64 *, const void *);
	void (*destructor)(struct inet_frag_queue___64 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___64 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___66 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___66 *fragments_tail;
	struct sk_buff___66 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___64 *net;
	struct callback_head rcu;
};

struct nf_bridge_info___64;

struct sk_buff___66 {
	union {
		struct {
			struct sk_buff___66 *next;
			struct sk_buff___66 *prev;
			union {
				struct net_device___65 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___48 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___66 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___64 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct fib_rules_ops___47;

struct fib_notifier_ops___48;

struct netns_ipv4___64 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___47 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___48 *fibnl;
	struct sock___48 **icmp_sk;
	struct sock___48 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___48 **tcp_sk;
	struct netns_frags___64 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___47 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___48 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___48 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct fib_rule___47;

struct fib_lookup_arg___47;

struct fib_rules_ops___47 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___47 *, struct flowi *, int, struct fib_lookup_arg___47 *);
	bool (*suppress)(struct fib_rule___47 *, struct fib_lookup_arg___47 *);
	int (*match)(struct fib_rule___47 *, struct flowi *, int);
	int (*configure)(struct fib_rule___47 *, struct sk_buff___66 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___47 *);
	int (*compare)(struct fib_rule___47 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___47 *, struct sk_buff___66 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___47 *);
	void (*flush_cache)(struct fib_rules_ops___47 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___349 *owner;
	struct net___76 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___48 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___76 *);
	int (*fib_dump)(struct net___76 *, struct notifier_block *);
	struct module___349 *owner;
	struct callback_head rcu;
};

struct neighbour___47;

struct dst_ops___75 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___75 *);
	struct dst_entry___47 * (*check)(struct dst_entry___47 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___47 *);
	unsigned int (*mtu)(const struct dst_entry___47 *);
	u32 * (*cow_metrics)(struct dst_entry___47 *, long unsigned int);
	void (*destroy)(struct dst_entry___47 *);
	void (*ifdown)(struct dst_entry___47 *, struct net_device___65 *, int);
	struct dst_entry___47 * (*negative_advice)(struct dst_entry___47 *);
	void (*link_failure)(struct sk_buff___66 *);
	void (*update_pmtu)(struct dst_entry___47 *, struct sock___48 *, struct sk_buff___66 *, u32);
	void (*redirect)(struct dst_entry___47 *, struct sock___48 *, struct sk_buff___66 *);
	int (*local_out)(struct net___76 *, struct sock___48 *, struct sk_buff___66 *);
	struct neighbour___47 * (*neigh_lookup)(const struct dst_entry___47 *, struct sk_buff___66 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___47 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct lwtunnel_state___5;

struct dst_entry___47 {
	struct net_device___65 *dev;
	struct dst_ops___75 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___66 *);
	int (*output)(struct net___76 *, struct sock___48 *, struct sk_buff___66 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___5 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

typedef rx_handler_result_t rx_handler_func_t___64(struct sk_buff___66 **);

struct dev_pm_info___387 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___387 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___387;

struct bus_type___387;

struct device_driver___387;

struct dev_pm_domain___387;

struct dma_map_ops___159;

struct fwnode_handle___307;

struct class___387;

struct device___387 {
	struct device___387 *parent;
	struct device_private *p;
	struct kobject___407 kobj;
	const char *init_name;
	const struct device_type___387 *type;
	struct mutex mutex;
	struct bus_type___387 *bus;
	struct device_driver___387 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___387 power;
	struct dev_pm_domain___387 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___159 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___307 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___387 *class;
	const struct attribute_group___384 **groups;
	void (*release)(struct device___387 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct net_device_ops___64;

struct ethtool_ops___64;

struct l3mdev_ops___47;

struct ndisc_ops___27;

struct xfrmdev_ops___64;

struct tlsdev_ops___64;

struct header_ops___64;

struct inet6_dev___27;

struct netdev_rx_queue___64;

struct bpf_prog___57;

struct mini_Qdisc___57;

struct netdev_queue___64;

struct Qdisc___57;

struct rtnl_link_ops___57;

struct dcbnl_rtnl_ops___64;

struct net_device___65 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___64 *netdev_ops;
	const struct ethtool_ops___64 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___47 *l3mdev_ops;
	const struct ndisc_ops___27 *ndisc_ops;
	const struct xfrmdev_ops___64 *xfrmdev_ops;
	const struct tlsdev_ops___64 *tlsdev_ops;
	const struct header_ops___64 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___406 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___27 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___64 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___57 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___64 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___57 *miniq_ingress;
	struct netdev_queue___64 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___64 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___57 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___57 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___64 = 0,
		NETREG_REGISTERED___64 = 1,
		NETREG_UNREGISTERING___64 = 2,
		NETREG_UNREGISTERED___64 = 3,
		NETREG_RELEASED___64 = 4,
		NETREG_DUMMY___64 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___64 = 0,
		RTNL_LINK_INITIALIZING___64 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___65 *);
	struct netpoll_info *npinfo;
	possible_net_t___66 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___387 dev;
	const struct attribute_group___384 *sysfs_groups[4];
	const struct attribute_group___384 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___57 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___64 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide35;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct fib6_info___8;

struct rt6_info___8;

struct fib6_table___8;

struct netns_ipv6___75 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___64 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info___8 *fib6_null_entry;
	struct rt6_info___8 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___8 *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___75 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info___8 *ip6_prohibit_entry;
	struct rt6_info___8 *ip6_blk_hole_entry;
	struct fib6_table___8 *fib6_local_tbl;
	struct fib_rules_ops___47 *fib6_rules_ops;
	struct sock___48 **icmp_sk;
	struct sock___48 *ndisc_sk;
	struct sock___48 *tcp_sk;
	struct sock___48 *igmp_sk;
	struct sock___48 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___47 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___48 *notifier_ops;
	struct fib_notifier_ops___48 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___48 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___48 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___64 {
	struct netns_frags___64 frags;
};

struct netns_xfrm___75 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___48 *nlsk;
	struct sock___48 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___75 xfrm4_dst_ops;
	struct dst_ops___75 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct net___76 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___284 *user_ns;
	struct ucounts___284 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___29 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___48 *rtnl;
	struct sock___48 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___65 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___64 ipv4;
	struct netns_ipv6___75 ipv6;
	struct netns_sctp___48 sctp;
	struct netns_nf___4 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___64 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___48 *nfnl;
	struct sock___48 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___75 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___48 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___57 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neigh_table___47;

struct neigh_parms___47;

struct neigh_ops___47;

struct neighbour___47 {
	struct neighbour___47 *next;
	struct neigh_table___47 *tbl;
	struct neigh_parms___47 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___64 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___47 *, struct sk_buff___66 *);
	const struct neigh_ops___47 *ops;
	struct callback_head rcu;
	struct net_device___65 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct fib6_nh___8 {
	struct in6_addr nh_gw;
	struct net_device___65 *nh_dev;
	struct lwtunnel_state___5 *nh_lwtstate;
	unsigned int nh_flags;
	atomic_t nh_upper_bound;
	int nh_weight;
};

struct fib6_node___8;

struct fib6_info___8 {
	struct fib6_table___8 *fib6_table;
	struct fib6_info___8 *fib6_next;
	struct fib6_node___8 *fib6_node;
	struct list_head fib6_siblings;
	unsigned int fib6_nsiblings;
	atomic_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	struct rt6_info___8 **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
	long unsigned int last_probe;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 exception_bucket_flushed: 1;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 dst_host: 1;
	u8 fib6_destroying: 1;
	u8 unused: 2;
	struct fib6_nh___8 fib6_nh;
	struct callback_head rcu;
};

struct rt6_info___8 {
	struct dst_entry___47 dst;
	struct fib6_info___8 *from;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___27 *rt6i_idev;
	u32 rt6i_flags;
	struct rt6key rt6i_prefsrc;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct fib6_node___8 {
	struct fib6_node___8 *parent;
	struct fib6_node___8 *left;
	struct fib6_node___8 *right;
	struct fib6_info___8 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info___8 *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table___8 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node___8 tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

struct dentry_operations___419;

struct super_block___419;

struct dentry___419 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___419 *d_parent;
	struct qstr d_name;
	struct inode___419 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___419 *d_op;
	struct super_block___419 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___419;

struct block_device___419;

struct inode___419 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___419 *i_op;
	struct super_block___419 *i_sb;
	struct address_space___419 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___421 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___212 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___419 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___419 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___100 *i_pipe;
		struct block_device___419 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___419 {
	int (*d_revalidate)(struct dentry___419 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___419 *, unsigned int);
	int (*d_hash)(const struct dentry___419 *, struct qstr *);
	int (*d_compare)(const struct dentry___419 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___419 *);
	int (*d_init)(struct dentry___419 *);
	void (*d_release)(struct dentry___419 *);
	void (*d_prune)(struct dentry___419 *);
	void (*d_iput)(struct dentry___419 *, struct inode___419 *);
	char * (*d_dname)(struct dentry___419 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___420 *);
	int (*d_manage)(const struct path___420 *, bool);
	struct dentry___419 * (*d_real)(struct dentry___419 *, const struct inode___419 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___419;

struct mem_dqinfo___419 {
	struct quota_format_type___419 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___419;

struct quota_info___419 {
	unsigned int flags;
	struct rw_semaphore___421 dqio_sem;
	struct inode___419 *files[3];
	struct mem_dqinfo___419 info[3];
	const struct quota_format_ops___419 *ops[3];
};

struct rcuwait___419 {
	struct task_struct___421 *task;
};

struct percpu_rw_semaphore___419 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___421 rw_sem;
	struct rcuwait___419 writer;
	int readers_block;
};

struct sb_writers___419 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___419 rw_sem[3];
};

struct shrink_control___155;

struct shrinker___155 {
	long unsigned int (*count_objects)(struct shrinker___155 *, struct shrink_control___155 *);
	long unsigned int (*scan_objects)(struct shrinker___155 *, struct shrink_control___155 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___419;

struct super_operations___419;

struct dquot_operations___419;

struct quotactl_ops___419;

struct super_block___419 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___419 *s_type;
	const struct super_operations___419 *s_op;
	const struct dquot_operations___419 *dq_op;
	const struct quotactl_ops___419 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___419 *s_root;
	struct rw_semaphore___421 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___419 *s_bdev;
	struct backing_dev_info___212 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___419 s_dquot;
	struct sb_writers___419 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___419 *s_d_op;
	int cleancache_poolid;
	struct shrinker___155 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___284 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___155 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___155 *memcg;
};

struct iattr___419 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___419 *ia_file;
};

struct dquot___419 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___419 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___419 {
	int qf_fmt_id;
	const struct quota_format_ops___419 *qf_ops;
	struct module___349 *qf_owner;
	struct quota_format_type___419 *qf_next;
};

struct quota_format_ops___419 {
	int (*check_quota_file)(struct super_block___419 *, int);
	int (*read_file_info)(struct super_block___419 *, int);
	int (*write_file_info)(struct super_block___419 *, int);
	int (*free_file_info)(struct super_block___419 *, int);
	int (*read_dqblk)(struct dquot___419 *);
	int (*commit_dqblk)(struct dquot___419 *);
	int (*release_dqblk)(struct dquot___419 *);
	int (*get_next_id)(struct super_block___419 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___419 {
	int (*write_dquot)(struct dquot___419 *);
	struct dquot___419 * (*alloc_dquot)(struct super_block___419 *, int);
	void (*destroy_dquot)(struct dquot___419 *);
	int (*acquire_dquot)(struct dquot___419 *);
	int (*release_dquot)(struct dquot___419 *);
	int (*mark_dirty)(struct dquot___419 *);
	int (*write_info)(struct super_block___419 *, int);
	qsize_t * (*get_reserved_space)(struct inode___419 *);
	int (*get_projid)(struct inode___419 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___419 *, qsize_t *);
	int (*get_next_id)(struct super_block___419 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___419 {
	int (*quota_on)(struct super_block___419 *, int, int, const struct path___420 *);
	int (*quota_off)(struct super_block___419 *, int);
	int (*quota_enable)(struct super_block___419 *, unsigned int);
	int (*quota_disable)(struct super_block___419 *, unsigned int);
	int (*quota_sync)(struct super_block___419 *, int);
	int (*set_info)(struct super_block___419 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___419 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___419 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___419 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___419 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___419 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___175;

struct address_space_operations___419 {
	int (*writepage)(struct page___420 *, struct writeback_control___175 *);
	int (*readpage)(struct file___419 *, struct page___420 *);
	int (*writepages)(struct address_space___419 *, struct writeback_control___175 *);
	int (*set_page_dirty)(struct page___420 *);
	int (*readpages)(struct file___419 *, struct address_space___419 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___419 *, struct address_space___419 *, loff_t, unsigned int, unsigned int, struct page___420 **, void **);
	int (*write_end)(struct file___419 *, struct address_space___419 *, loff_t, unsigned int, unsigned int, struct page___420 *, void *);
	sector_t (*bmap)(struct address_space___419 *, sector_t);
	void (*invalidatepage)(struct page___420 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___420 *, gfp_t);
	void (*freepage)(struct page___420 *);
	ssize_t (*direct_IO)(struct kiocb___419 *, struct iov_iter___186 *);
	int (*migratepage)(struct address_space___419 *, struct page___420 *, struct page___420 *, enum migrate_mode);
	bool (*isolate_page)(struct page___420 *, isolate_mode_t);
	void (*putback_page)(struct page___420 *);
	int (*launder_page)(struct page___420 *);
	int (*is_partially_uptodate)(struct page___420 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___420 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___419 *, struct page___420 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___419 *, sector_t *);
	void (*swap_deactivate)(struct file___419 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___175 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___212 *wb;
	struct inode___419 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___419 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___419 *bd_inode;
	struct super_block___419 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___419 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___212 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___419 {
	struct dentry___419 * (*lookup)(struct inode___419 *, struct dentry___419 *, unsigned int);
	const char * (*get_link)(struct dentry___419 *, struct inode___419 *, struct delayed_call *);
	int (*permission)(struct inode___419 *, int);
	struct posix_acl * (*get_acl)(struct inode___419 *, int);
	int (*readlink)(struct dentry___419 *, char *, int);
	int (*create)(struct inode___419 *, struct dentry___419 *, umode_t, bool);
	int (*link)(struct dentry___419 *, struct inode___419 *, struct dentry___419 *);
	int (*unlink)(struct inode___419 *, struct dentry___419 *);
	int (*symlink)(struct inode___419 *, struct dentry___419 *, const char *);
	int (*mkdir)(struct inode___419 *, struct dentry___419 *, umode_t);
	int (*rmdir)(struct inode___419 *, struct dentry___419 *);
	int (*mknod)(struct inode___419 *, struct dentry___419 *, umode_t, dev_t);
	int (*rename)(struct inode___419 *, struct dentry___419 *, struct inode___419 *, struct dentry___419 *, unsigned int);
	int (*setattr)(struct dentry___419 *, struct iattr___419 *);
	int (*getattr)(const struct path___420 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___419 *, char *, size_t);
	int (*fiemap)(struct inode___419 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___419 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___419 *, struct dentry___419 *, struct file___419 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___419 *, struct dentry___419 *, umode_t);
	int (*set_acl)(struct inode___419 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___419 {
	void (*fl_copy_lock)(struct file_lock___419 *, struct file_lock___419 *);
	void (*fl_release_private)(struct file_lock___419 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___419;

struct file_lock___419 {
	struct file_lock___419 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___419 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___419 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___419 *fl_ops;
	const struct lock_manager_operations___419 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___419 {
	int (*lm_compare_owner)(struct file_lock___419 *, struct file_lock___419 *);
	long unsigned int (*lm_owner_key)(struct file_lock___419 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___419 *);
	int (*lm_grant)(struct file_lock___419 *, int);
	bool (*lm_break)(struct file_lock___419 *);
	int (*lm_change)(struct file_lock___419 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___419 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___419 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___419 *fa_next;
	struct file___419 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___419 {
	const char *name;
	int fs_flags;
	struct dentry___419 * (*mount)(struct file_system_type___419 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___419 *);
	struct module___349 *owner;
	struct file_system_type___419 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___419 {
	struct inode___419 * (*alloc_inode)(struct super_block___419 *);
	void (*destroy_inode)(struct inode___419 *);
	void (*dirty_inode)(struct inode___419 *, int);
	int (*write_inode)(struct inode___419 *, struct writeback_control___175 *);
	int (*drop_inode)(struct inode___419 *);
	void (*evict_inode)(struct inode___419 *);
	void (*put_super)(struct super_block___419 *);
	int (*sync_fs)(struct super_block___419 *, int);
	int (*freeze_super)(struct super_block___419 *);
	int (*freeze_fs)(struct super_block___419 *);
	int (*thaw_super)(struct super_block___419 *);
	int (*unfreeze_fs)(struct super_block___419 *);
	int (*statfs)(struct dentry___419 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___419 *, int *, char *);
	void (*umount_begin)(struct super_block___419 *);
	int (*show_options)(struct seq_file___358 *, struct dentry___419 *);
	int (*show_devname)(struct seq_file___358 *, struct dentry___419 *);
	int (*show_path)(struct seq_file___358 *, struct dentry___419 *);
	int (*show_stats)(struct seq_file___358 *, struct dentry___419 *);
	ssize_t (*quota_read)(struct super_block___419 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___419 *, int, const char *, size_t, loff_t);
	struct dquot___419 ** (*get_dquots)(struct inode___419 *);
	int (*bdev_try_to_free_page)(struct super_block___419 *, struct page___420 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___419 *, struct shrink_control___155 *);
	long int (*free_cached_objects)(struct super_block___419 *, struct shrink_control___155 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___212(struct bio___212 *);

struct bio_integrity_payload___212;

struct bio_set___212;

struct bio___212 {
	struct bio___212 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___212 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___212 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___214 *bi_io_vec;
	struct bio_set___212 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___214 bi_inline_vecs[0];
};

struct socket_wq___48 {
	wait_queue_head_t wait;
	struct fasync_struct___419 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___48;

struct socket___49 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___48 *wq;
	struct file___419 *file;
	struct sock___48 *sk;
	const struct proto_ops___48 *ops;
};

typedef int (*sk_read_actor_t___47)(read_descriptor_t *, struct sk_buff___66 *, unsigned int, size_t);

struct proto_ops___48 {
	int family;
	struct module___349 *owner;
	int (*release)(struct socket___49 *);
	int (*bind)(struct socket___49 *, struct sockaddr *, int);
	int (*connect)(struct socket___49 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___49 *, struct socket___49 *);
	int (*accept)(struct socket___49 *, struct socket___49 *, int, bool);
	int (*getname)(struct socket___49 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___419 *, struct socket___49 *, struct poll_table_struct___261 *);
	int (*ioctl)(struct socket___49 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___49 *, int);
	int (*shutdown)(struct socket___49 *, int);
	int (*setsockopt)(struct socket___49 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___49 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___49 *, struct msghdr___50 *, size_t);
	int (*recvmsg)(struct socket___49 *, struct msghdr___50 *, size_t, int);
	int (*mmap)(struct file___419 *, struct socket___49 *, struct vm_area_struct___420 *);
	ssize_t (*sendpage)(struct socket___49 *, struct page___420 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___49 *, loff_t *, struct pipe_inode_info___100 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___48 *, int);
	int (*peek_len)(struct socket___49 *);
	int (*read_sock)(struct sock___48 *, read_descriptor_t *, sk_read_actor_t___47);
	int (*sendpage_locked)(struct sock___48 *, struct page___420 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___48 *, struct msghdr___50 *, size_t);
	int (*set_rcvlowat)(struct sock___48 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct dev_pm_ops___387 {
	int (*prepare)(struct device___387 *);
	void (*complete)(struct device___387 *);
	int (*suspend)(struct device___387 *);
	int (*resume)(struct device___387 *);
	int (*freeze)(struct device___387 *);
	int (*thaw)(struct device___387 *);
	int (*poweroff)(struct device___387 *);
	int (*restore)(struct device___387 *);
	int (*suspend_late)(struct device___387 *);
	int (*resume_early)(struct device___387 *);
	int (*freeze_late)(struct device___387 *);
	int (*thaw_early)(struct device___387 *);
	int (*poweroff_late)(struct device___387 *);
	int (*restore_early)(struct device___387 *);
	int (*suspend_noirq)(struct device___387 *);
	int (*resume_noirq)(struct device___387 *);
	int (*freeze_noirq)(struct device___387 *);
	int (*thaw_noirq)(struct device___387 *);
	int (*poweroff_noirq)(struct device___387 *);
	int (*restore_noirq)(struct device___387 *);
	int (*runtime_suspend)(struct device___387 *);
	int (*runtime_resume)(struct device___387 *);
	int (*runtime_idle)(struct device___387 *);
};

struct dev_pm_domain___387 {
	struct dev_pm_ops___387 ops;
	void (*detach)(struct device___387 *, bool);
	int (*activate)(struct device___387 *);
	void (*sync)(struct device___387 *);
	void (*dismiss)(struct device___387 *);
};

struct bus_type___387 {
	const char *name;
	const char *dev_name;
	struct device___387 *dev_root;
	const struct attribute_group___384 **bus_groups;
	const struct attribute_group___384 **dev_groups;
	const struct attribute_group___384 **drv_groups;
	int (*match)(struct device___387 *, struct device_driver___387 *);
	int (*uevent)(struct device___387 *, struct kobj_uevent_env *);
	int (*probe)(struct device___387 *);
	int (*remove)(struct device___387 *);
	void (*shutdown)(struct device___387 *);
	int (*online)(struct device___387 *);
	int (*offline)(struct device___387 *);
	int (*suspend)(struct device___387 *, pm_message_t);
	int (*resume)(struct device___387 *);
	int (*num_vf)(struct device___387 *);
	int (*dma_configure)(struct device___387 *);
	const struct dev_pm_ops___387 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___387 {
	const char *name;
	struct bus_type___387 *bus;
	struct module___349 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___387 *);
	int (*remove)(struct device___387 *);
	void (*shutdown)(struct device___387 *);
	int (*suspend)(struct device___387 *, pm_message_t);
	int (*resume)(struct device___387 *);
	const struct attribute_group___384 **groups;
	const struct dev_pm_ops___387 *pm;
	void (*coredump)(struct device___387 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___387 {
	const char *name;
	const struct attribute_group___384 **groups;
	int (*uevent)(struct device___387 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___387 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___387 *);
	const struct dev_pm_ops___387 *pm;
};

struct class___387 {
	const char *name;
	struct module___349 *owner;
	const struct attribute_group___384 **class_groups;
	const struct attribute_group___384 **dev_groups;
	struct kobject___407 *dev_kobj;
	int (*dev_uevent)(struct device___387 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___387 *, umode_t *);
	void (*class_release)(struct class___387 *);
	void (*dev_release)(struct device___387 *);
	int (*shutdown_pre)(struct device___387 *);
	const struct kobj_ns_type_operations___47 *ns_type;
	const void * (*namespace)(struct device___387 *);
	const struct dev_pm_ops___387 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___159 {
	void * (*alloc)(struct device___387 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___387 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___387 *, struct vm_area_struct___420 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___387 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___387 *, struct page___420 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___387 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___387 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___387 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___387 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___387 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___387 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___387 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___387 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___387 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___387 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___387 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___387 *, u64);
	u64 (*get_required_mask)(struct device___387 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___307;

struct fwnode_handle___307 {
	struct fwnode_handle___307 *secondary;
	const struct fwnode_operations___307 *ops;
};

typedef void compound_page_dtor___407(struct page___420 *);

struct fwnode_reference_args___307;

struct fwnode_endpoint___307;

struct fwnode_operations___307 {
	struct fwnode_handle___307 * (*get)(struct fwnode_handle___307 *);
	void (*put)(struct fwnode_handle___307 *);
	bool (*device_is_available)(const struct fwnode_handle___307 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___307 *, const struct device___387 *);
	bool (*property_present)(const struct fwnode_handle___307 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___307 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___307 *, const char *, const char **, size_t);
	struct fwnode_handle___307 * (*get_parent)(const struct fwnode_handle___307 *);
	struct fwnode_handle___307 * (*get_next_child_node)(const struct fwnode_handle___307 *, struct fwnode_handle___307 *);
	struct fwnode_handle___307 * (*get_named_child_node)(const struct fwnode_handle___307 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___307 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___307 *);
	struct fwnode_handle___307 * (*graph_get_next_endpoint)(const struct fwnode_handle___307 *, struct fwnode_handle___307 *);
	struct fwnode_handle___307 * (*graph_get_remote_endpoint)(const struct fwnode_handle___307 *);
	struct fwnode_handle___307 * (*graph_get_port_parent)(struct fwnode_handle___307 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___307 *, struct fwnode_endpoint___307 *);
};

struct fwnode_endpoint___307 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___307 *local_fwnode;
};

struct fwnode_reference_args___307 {
	struct fwnode_handle___307 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___100;

struct pipe_buffer___100 {
	struct page___420 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___100 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___100 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___100 *, struct pipe_buffer___100 *);
	void (*release)(struct pipe_inode_info___100 *, struct pipe_buffer___100 *);
	int (*steal)(struct pipe_inode_info___100 *, struct pipe_buffer___100 *);
	union {
		bool (*get)(struct pipe_inode_info___100 *, struct pipe_buffer___100 *);
		struct {
			void (*get)(struct pipe_inode_info___100 *, struct pipe_buffer___100 *);
		} __UNIQUE_ID_rh_kabi_hide21;
		union {		};
	};
};

struct nf_bridge_info___64 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___64 = 0,
		BRNF_PROTO_8021Q___64 = 1,
		BRNF_PROTO_PPPOE___64 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___65 *physindev;
	struct net_device___65 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

struct ucounts___284 {
	struct hlist_node node;
	struct user_namespace___284 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_prog_aux___60;

struct bpf_prog___57 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___60 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

typedef int (*key_restrict_link_func_t___388)(struct key___387 *, const struct key_type *, const union key_payload *, struct key___387 *);

struct key_restriction___387;

struct key___387 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___421 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___387 *restrict_link;
};

struct key_restriction___387 {
	key_restrict_link_func_t___388 check;
	struct key___387 *key;
	struct key_type *keytype;
};

struct seq_operations___358 {
	void * (*start)(struct seq_file___358 *, loff_t *);
	void (*stop)(struct seq_file___358 *, void *);
	void * (*next)(struct seq_file___358 *, void *, loff_t *);
	int (*show)(struct seq_file___358 *, void *);
};

struct pernet_operations___65 {
	struct list_head list;
	int (*init)(struct net___76 *);
	void (*exit)(struct net___76 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct ethtool_ops___64 {
	int (*get_settings)(struct net_device___65 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___65 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___65 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___65 *);
	void (*get_regs)(struct net_device___65 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___65 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___65 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___65 *);
	void (*set_msglevel)(struct net_device___65 *, u32);
	int (*nway_reset)(struct net_device___65 *);
	u32 (*get_link)(struct net_device___65 *);
	int (*get_eeprom_len)(struct net_device___65 *);
	int (*get_eeprom)(struct net_device___65 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___65 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___65 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___65 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___65 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___65 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___65 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___65 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___65 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___65 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___65 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___65 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___65 *);
	void (*complete)(struct net_device___65 *);
	u32 (*get_priv_flags)(struct net_device___65 *);
	int (*set_priv_flags)(struct net_device___65 *, u32);
	int (*get_sset_count)(struct net_device___65 *, int);
	int (*get_rxnfc)(struct net_device___65 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___65 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___65 *, struct ethtool_flash *);
	int (*reset)(struct net_device___65 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___65 *);
	u32 (*get_rxfh_indir_size)(struct net_device___65 *);
	int (*get_rxfh)(struct net_device___65 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___65 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___65 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___65 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___65 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___65 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___65 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___65 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___65 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___65 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___65 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___65 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___65 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___65 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___65 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___65 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___65 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___65 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___65 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___65 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___65 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___65 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	int (*get_fecparam)(struct net_device___65 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___65 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___65 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___65 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___65 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct dcbnl_rtnl_ops___64 {
	int (*ieee_getets)(struct net_device___65 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___65 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___65 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___65 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___65 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___65 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___65 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___65 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___65 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___65 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___65 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___65 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___65 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___65 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___65 *);
	u8 (*setstate)(struct net_device___65 *, u8);
	void (*getpermhwaddr)(struct net_device___65 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___65 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___65 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___65 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___65 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___65 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___65 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___65 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___65 *, int, u8 *);
	void (*setpfccfg)(struct net_device___65 *, int, u8);
	void (*getpfccfg)(struct net_device___65 *, int, u8 *);
	u8 (*setall)(struct net_device___65 *);
	u8 (*getcap)(struct net_device___65 *, int, u8 *);
	int (*getnumtcs)(struct net_device___65 *, int, u8 *);
	int (*setnumtcs)(struct net_device___65 *, int, u8);
	u8 (*getpfcstate)(struct net_device___65 *);
	void (*setpfcstate)(struct net_device___65 *, u8);
	void (*getbcncfg)(struct net_device___65 *, int, u32 *);
	void (*setbcncfg)(struct net_device___65 *, int, u32);
	void (*getbcnrp)(struct net_device___65 *, int, u8 *);
	void (*setbcnrp)(struct net_device___65 *, int, u8);
	int (*setapp)(struct net_device___65 *, u8, u16, u8);
	int (*getapp)(struct net_device___65 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___65 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___65 *, int, u8);
	u8 (*getdcbx)(struct net_device___65 *);
	u8 (*setdcbx)(struct net_device___65 *, u8);
	int (*peer_getappinfo)(struct net_device___65 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___65 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___65 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___65 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___65 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___65 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___268 {
	refcount_t count;
	struct ns_common___29 ns;
	struct user_namespace___284 *user_ns;
	struct ucounts___284 *ucounts;
	struct css_set___268 *root_cset;
};

struct bpf_map___269;

struct bpf_map_ops___268 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___269 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___269 *, struct file___419 *);
	void (*map_free)(struct bpf_map___269 *);
	int (*map_get_next_key)(struct bpf_map___269 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___269 *);
	void * (*map_lookup_elem)(struct bpf_map___269 *, void *);
	int (*map_update_elem)(struct bpf_map___269 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___269 *, void *);
	int (*map_push_elem)(struct bpf_map___269 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___269 *, void *);
	int (*map_peek_elem)(struct bpf_map___269 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___269 *, struct file___419 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___269 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___269 *, void *, struct seq_file___358 *);
	int (*map_check_btf)(const struct bpf_map___269 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___269 {
	const struct bpf_map_ops___268 *ops;
	struct bpf_map___269 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___387 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___64;

struct bpf_map_dev_ops___64 {
	int (*map_get_next_key)(struct bpf_offloaded_map___64 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___64 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___64 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___64 *, void *);
};

struct bpf_offloaded_map___64 {
	struct bpf_map___269 map;
	struct net_device___65 *netdev;
	const struct bpf_map_dev_ops___64 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___57 {
	int (*test_run)(struct bpf_prog___57 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___57 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___57 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___57 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___57 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___57 *, u32 *);
};

struct bpf_prog_offload_ops___57 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___57 *);
	int (*translate)(struct bpf_prog___57 *);
	void (*destroy)(struct bpf_prog___57 *);
};

struct bpf_prog_offload___57 {
	struct bpf_prog___57 *prog;
	struct net_device___65 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___57 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___60 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___57 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___57 *ops;
	struct bpf_map___269 **used_maps;
	struct bpf_prog___57 *prog;
	struct user_struct___387 *user;
	u64 load_time;
	struct bpf_map___269 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___57 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___57 {
	struct bpf_prog___57 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___57 {
	struct callback_head rcu;
	struct bpf_prog_array_item___57 items[0];
};

struct cgroup_bpf___57 {
	struct bpf_prog_array___57 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___57 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___269;

typedef void (*kthread_work_func_t___269)(struct kthread_work___269 *);

struct kthread_worker___269;

struct kthread_work___269 {
	struct list_head node;
	kthread_work_func_t___269 func;
	struct kthread_worker___269 *worker;
	int canceling;
};

struct kthread_worker___269 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___421 *task;
	struct kthread_work___269 *current_work;
};

struct kthread_delayed_work___268 {
	struct kthread_work___269 work;
	struct timer_list timer;
};

struct psi_group___268 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___269 *poll_kworker;
	struct kthread_delayed_work___268 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___268;

struct cgroup_rstat_cpu___268;

struct cgroup___268 {
	struct cgroup_subsys_state___268 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___414 *kn;
	struct cgroup_file___268 procs_file;
	struct cgroup_file___268 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___268 *subsys[13];
	struct cgroup_root___268 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___268 *dom_cgrp;
	struct cgroup_rstat_cpu___268 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___57 bpf;
	atomic_t congestion_count;
	struct cgroup___268 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___268 psi;
	int ancestor_ids[0];
};

struct cftype___268;

struct cgroup_subsys___268 {
	struct cgroup_subsys_state___268 * (*css_alloc)(struct cgroup_subsys_state___268 *);
	int (*css_online)(struct cgroup_subsys_state___268 *);
	void (*css_offline)(struct cgroup_subsys_state___268 *);
	void (*css_released)(struct cgroup_subsys_state___268 *);
	void (*css_free)(struct cgroup_subsys_state___268 *);
	void (*css_reset)(struct cgroup_subsys_state___268 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___268 *, int);
	int (*css_extra_stat_show)(struct seq_file___358 *, struct cgroup_subsys_state___268 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___421 *);
	void (*cancel_fork)(struct task_struct___421 *);
	void (*fork)(struct task_struct___421 *);
	void (*exit)(struct task_struct___421 *);
	void (*free)(struct task_struct___421 *);
	void (*bind)(struct cgroup_subsys_state___268 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___268 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___268 *dfl_cftypes;
	struct cftype___268 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___268 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___268 *updated_children;
	struct cgroup___268 *updated_next;
};

struct cgroup_root___268 {
	struct kernfs_root___413 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___268 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___268 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___268 *ss;
	struct list_head node;
	struct kernfs_ops___413 *kf_ops;
	int (*open)(struct kernfs_open_file___413 *);
	void (*release)(struct kernfs_open_file___413 *);
	u64 (*read_u64)(struct cgroup_subsys_state___268 *, struct cftype___268 *);
	s64 (*read_s64)(struct cgroup_subsys_state___268 *, struct cftype___268 *);
	int (*seq_show)(struct seq_file___358 *, void *);
	void * (*seq_start)(struct seq_file___358 *, loff_t *);
	void * (*seq_next)(struct seq_file___358 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___358 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___268 *, struct cftype___268 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___268 *, struct cftype___268 *, s64);
	ssize_t (*write)(struct kernfs_open_file___413 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___413 *, struct poll_table_struct___261 *);
};

struct xdp_rxq_info___64 {
	struct net_device___65 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___64 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___65 *dev_rx;
};

struct netlink_skb_parms___10 {
	struct scm_creds creds;
	__u32 portid;
	__u32 dst_group;
	__u32 flags;
	struct sock___48 *sk;
	bool nsid_is_set;
	int nsid;
};

struct netlink_callback___66 {
	struct sk_buff___66 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___66 *);
	int (*dump)(struct sk_buff___66 *, struct netlink_callback___66 *);
	int (*done)(struct netlink_callback___66 *);
	void *data;
	struct module___349 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___64 {
	int (*create)(struct sk_buff___66 *, struct net_device___65 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___66 *, unsigned char *);
	int (*cache)(const struct neighbour___47 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___65 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___64 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___64 *, int);
	int poll_owner;
	struct net_device___65 *dev;
	struct sk_buff___66 *gro_list;
	struct sk_buff___66 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___64 {
	struct net_device___65 *dev;
	struct Qdisc___57 *qdisc;
	struct Qdisc___57 *qdisc_sleeping;
	struct kobject___407 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___65 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem___3 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___57 {
	struct sk_buff___66 *head;
	struct sk_buff___66 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___57;

struct Qdisc___57 {
	int (*enqueue)(struct sk_buff___66 *, struct Qdisc___57 *, struct sk_buff___66 **);
	struct sk_buff___66 * (*dequeue)(struct Qdisc___57 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___57 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___64 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___64 gso_skb;
	struct qdisc_skb_head___57 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___57 *next_sched;
	struct sk_buff_head___64 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___64 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___407 kobj;
	struct net_device___65 *dev;
	long: 64;
	struct xdp_rxq_info___64 xdp_rxq;
	union {
		struct xdp_umem___3 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___64)(struct net_device___65 *, struct sk_buff___66 *, struct net_device___65 *);

struct netdev_bpf___64 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___57 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___57 *prog;
			const struct bpf_prog_offload_ops___57 *ops;
		} verifier;
		struct {
			struct bpf_prog___57 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___64 *offmap;
		};
		struct {
			struct xdp_umem___3 *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___64 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___66 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___64 {
	int (*tls_dev_add)(struct net_device___65 *, struct sock___48 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___65 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___65 *, struct sock___48 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___64 {
	int (*ndo_init)(struct net_device___65 *);
	void (*ndo_uninit)(struct net_device___65 *);
	int (*ndo_open)(struct net_device___65 *);
	int (*ndo_stop)(struct net_device___65 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___66 *, struct net_device___65 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___66 *, struct net_device___65 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___65 *, struct sk_buff___66 *, struct net_device___65 *, select_queue_fallback_t___64);
	void (*ndo_change_rx_flags)(struct net_device___65 *, int);
	void (*ndo_set_rx_mode)(struct net_device___65 *);
	int (*ndo_set_mac_address)(struct net_device___65 *, void *);
	int (*ndo_validate_addr)(struct net_device___65 *);
	int (*ndo_do_ioctl)(struct net_device___65 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___65 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___65 *, int);
	int (*ndo_neigh_setup)(struct net_device___65 *, struct neigh_parms___47 *);
	void (*ndo_tx_timeout)(struct net_device___65 *);
	void (*ndo_get_stats64)(struct net_device___65 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___65 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___65 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___65 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___65 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___65 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___65 *);
	int (*ndo_netpoll_setup)(struct net_device___65 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___65 *);
	int (*ndo_set_vf_mac)(struct net_device___65 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___65 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___65 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___65 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___65 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___65 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___65 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___65 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___65 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___65 *, int, struct sk_buff___66 *);
	int (*ndo_set_vf_guid)(struct net_device___65 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___65 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___65 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___65 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___65 *, const struct sk_buff___66 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___65 *, struct net_device___65 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___65 *, struct net_device___65 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___65 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___65 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___65 *, struct neighbour___47 *);
	void (*ndo_neigh_destroy)(struct net_device___65 *, struct neighbour___47 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___65 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___65 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___65 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___66 *, struct netlink_callback___66 *, struct net_device___65 *, struct net_device___65 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___65 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___65 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___66 *, u32, u32, struct net_device___65 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___65 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___65 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___65 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___65 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___65 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___65 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___65 *, struct net_device___65 *);
	void (*ndo_dfwd_del_station)(struct net_device___65 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___65 *);
	int (*ndo_set_tx_maxrate)(struct net_device___65 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___65 *);
	int (*ndo_change_proto_down)(struct net_device___65 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___65 *, struct sk_buff___66 *);
	void (*ndo_set_rx_headroom)(struct net_device___65 *, int);
	int (*ndo_bpf)(struct net_device___65 *, struct netdev_bpf___64 *);
	int (*ndo_xdp_xmit)(struct net_device___65 *, int, struct xdp_frame___64 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___65 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___65 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___47 {
	possible_net_t___66 net;
	struct net_device___65 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___47 *);
	void (*neigh_cleanup)(struct neighbour___47 *);
	struct neigh_table___47 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___47 {
	u32 (*l3mdev_fib_table)(const struct net_device___65 *);
	struct sk_buff___66 * (*l3mdev_l3_rcv)(struct net_device___65 *, struct sk_buff___66 *, u16);
	struct sk_buff___66 * (*l3mdev_l3_out)(struct net_device___65 *, struct sock___48 *, struct sk_buff___66 *, u16);
	struct dst_entry___47 * (*l3mdev_link_scope_lookup)(const struct net_device___65 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct ndisc_ops___27 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___65 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___65 *, struct neighbour___47 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___65 *, u8, struct neighbour___47 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___65 *, struct sk_buff___66 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___76 *, struct net_device___65 *, const struct prefix_info *, struct inet6_dev___27 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___27;

struct ifacaddr6___8;

struct inet6_dev___27 {
	struct net_device___65 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___27 *mc_list;
	struct ifmcaddr6___27 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___8 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	u8 rndid[8];
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___47 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
};

struct tcf_proto___57;

struct mini_Qdisc___57 {
	struct tcf_proto___57 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___57 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___65 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___76 *, struct net_device___65 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___65 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___65 *, struct list_head *);
	size_t (*get_size)(const struct net_device___65 *);
	int (*fill_info)(struct sk_buff___66 *, const struct net_device___65 *);
	size_t (*get_xstats_size)(const struct net_device___65 *);
	int (*fill_xstats)(struct sk_buff___66 *, const struct net_device___65 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___65 *, struct net_device___65 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___65 *, const struct net_device___65 *);
	int (*fill_slave_info)(struct sk_buff___66 *, const struct net_device___65 *, const struct net_device___65 *);
	struct net___76 * (*get_link_net)(const struct net_device___65 *);
	size_t (*get_linkxstats_size)(const struct net_device___65 *, int);
	int (*fill_linkxstats)(struct sk_buff___66 *, const struct net_device___65 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct netdev_notifier_info___5 {
	struct net_device___65 *dev;
	struct netlink_ext_ack *extack;
};

struct softnet_data___64 {
	struct list_head poll_list;
	struct sk_buff_head___64 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___64 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___57 *output_queue;
	struct Qdisc___57 **output_queue_tailp;
	struct sk_buff___66 *completion_queue;
	struct sk_buff_head___64 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___64 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___64 input_pkt_queue;
	struct napi_struct___64 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bdi_writeback_congested___212 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___212 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___212 {
	struct bio___212 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___214 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___214 bip_inline_vecs[0];
};

struct bio_set___212 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___212 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___155 {
	struct mem_cgroup___155 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___155 {
	struct lruvec___420 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___155 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___155 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct gnet_dump___57 {
	spinlock_t *lock;
	struct sk_buff___66 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___57;

struct Qdisc_ops___57 {
	struct Qdisc_ops___57 *next;
	const struct Qdisc_class_ops___57 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___66 *, struct Qdisc___57 *, struct sk_buff___66 **);
	struct sk_buff___66 * (*dequeue)(struct Qdisc___57 *);
	struct sk_buff___66 * (*peek)(struct Qdisc___57 *);
	int (*init)(struct Qdisc___57 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___57 *);
	void (*destroy)(struct Qdisc___57 *);
	int (*change)(struct Qdisc___57 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___57 *);
	int (*change_tx_queue_len)(struct Qdisc___57 *, unsigned int);
	int (*dump)(struct Qdisc___57 *, struct sk_buff___66 *);
	int (*dump_stats)(struct Qdisc___57 *, struct gnet_dump___57 *);
	void (*ingress_block_set)(struct Qdisc___57 *, u32);
	void (*egress_block_set)(struct Qdisc___57 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___57 *);
	u32 (*egress_block_get)(struct Qdisc___57 *);
	struct module___349 *owner;
};

struct tcf_block___57;

struct Qdisc_class_ops___57 {
	unsigned int flags;
	struct netdev_queue___64 * (*select_queue)(struct Qdisc___57 *, struct tcmsg *);
	int (*graft)(struct Qdisc___57 *, long unsigned int, struct Qdisc___57 *, struct Qdisc___57 **, struct netlink_ext_ack *);
	struct Qdisc___57 * (*leaf)(struct Qdisc___57 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___57 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___57 *, u32);
	int (*change)(struct Qdisc___57 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___57 *, long unsigned int);
	void (*walk)(struct Qdisc___57 *, struct qdisc_walker *);
	struct tcf_block___57 * (*tcf_block)(struct Qdisc___57 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___57 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___57 *, long unsigned int);
	int (*dump)(struct Qdisc___57 *, long unsigned int, struct sk_buff___66 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___57 *, long unsigned int, struct gnet_dump___57 *);
};

struct tcf_chain___57;

struct tcf_block___57 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___76 *net;
	struct Qdisc___57 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___57 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___57;

struct tcf_proto_ops___57;

struct tcf_proto___57 {
	struct tcf_proto___57 *next;
	void *root;
	int (*classify)(struct sk_buff___66 *, const struct tcf_proto___57 *, struct tcf_result___57 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___57 *ops;
	struct tcf_chain___57 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___57 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___57 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___57 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___66 *, const struct tcf_proto___57 *, struct tcf_result___57 *);
	int (*init)(struct tcf_proto___57 *);
	void (*destroy)(struct tcf_proto___57 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___57 *, u32);
	void (*put)(struct tcf_proto___57 *, void *);
	int (*change)(struct net___76 *, struct sk_buff___66 *, struct tcf_proto___57 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___57 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___57 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___57 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___76 *, struct tcf_chain___57 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___76 *, struct tcf_proto___57 *, void *, struct sk_buff___66 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___66 *, struct net___76 *, void *);
	struct module___349 *owner;
	int flags;
};

struct tcf_chain___57 {
	struct mutex filter_chain_lock;
	struct tcf_proto___57 *filter_chain;
	struct list_head list;
	struct tcf_block___57 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___57 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___47 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___57 *prog;
};

struct bpf_redirect_info___57 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___269 *map;
	struct bpf_map___269 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___47;

struct neigh_hash_table___47;

struct neigh_table___47 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___65 *, __u32 *);
	bool (*key_eq)(const struct neighbour___47 *, const void *);
	int (*constructor)(struct neighbour___47 *);
	int (*pconstructor)(struct pneigh_entry___47 *);
	void (*pdestructor)(struct pneigh_entry___47 *);
	void (*proxy_redo)(struct sk_buff___66 *);
	char *id;
	struct neigh_parms___47 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___64 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___47 *nht;
	struct pneigh_entry___47 **phash_buckets;
};

struct neigh_ops___47 {
	int family;
	void (*solicit)(struct neighbour___47 *, struct sk_buff___66 *);
	void (*error_report)(struct neighbour___47 *, struct sk_buff___66 *);
	int (*output)(struct neighbour___47 *, struct sk_buff___66 *);
	int (*connected_output)(struct neighbour___47 *, struct sk_buff___66 *);
};

struct pneigh_entry___47 {
	struct pneigh_entry___47 *next;
	possible_net_t___66 net;
	struct net_device___65 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___47 {
	struct neighbour___47 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___5 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___76 *, struct sock___48 *, struct sk_buff___66 *);
	int (*orig_input)(struct sk_buff___66 *);
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	__u8 data[0];
};

struct fib_rule_uid_range {
	__u32 start;
	__u32 end;
};

enum {
	FRA_UNSPEC = 0,
	FRA_DST = 1,
	FRA_SRC = 2,
	FRA_IIFNAME = 3,
	FRA_GOTO = 4,
	FRA_UNUSED2 = 5,
	FRA_PRIORITY = 6,
	FRA_UNUSED3 = 7,
	FRA_UNUSED4 = 8,
	FRA_UNUSED5 = 9,
	FRA_FWMARK = 10,
	FRA_FLOW = 11,
	FRA_TUN_ID = 12,
	FRA_SUPPRESS_IFGROUP = 13,
	FRA_SUPPRESS_PREFIXLEN = 14,
	FRA_TABLE = 15,
	FRA_FWMASK = 16,
	FRA_OIFNAME = 17,
	FRA_PAD = 18,
	FRA_L3MDEV = 19,
	FRA_UID_RANGE = 20,
	FRA_PROTOCOL = 21,
	FRA_IP_PROTO = 22,
	FRA_SPORT_RANGE = 23,
	FRA_DPORT_RANGE = 24,
	__FRA_MAX = 25,
};

enum {
	FR_ACT_UNSPEC = 0,
	FR_ACT_TO_TBL = 1,
	FR_ACT_GOTO = 2,
	FR_ACT_NOP = 3,
	FR_ACT_RES3 = 4,
	FR_ACT_RES4 = 5,
	FR_ACT_BLACKHOLE = 6,
	FR_ACT_UNREACHABLE = 7,
	FR_ACT_PROHIBIT = 8,
	__FR_ACT_MAX = 9,
};

struct fib_notifier_info___2 {
	struct net___76 *net;
	int family;
	struct netlink_ext_ack *extack;
};

struct fib_rule___47 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___47 *ctarget;
	struct net___76 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___47 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___47 *rule;
	u32 table;
	int flags;
};

struct fib_rule_notifier_info {
	struct fib_notifier_info___2 info;
	struct fib_rule___47 *rule;
};

struct request_sock_ops___32;

struct timewait_sock_ops___30;

struct proto___47 {
	void (*close)(struct sock___48 *, long int);
	int (*pre_connect)(struct sock___48 *, struct sockaddr *, int);
	int (*connect)(struct sock___48 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___48 *, int);
	struct sock___48 * (*accept)(struct sock___48 *, int, int *, bool);
	int (*ioctl)(struct sock___48 *, int, long unsigned int);
	int (*init)(struct sock___48 *);
	void (*destroy)(struct sock___48 *);
	void (*shutdown)(struct sock___48 *, int);
	int (*setsockopt)(struct sock___48 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___48 *, int, int, char *, int *);
	void (*keepalive)(struct sock___48 *, int);
	int (*sendmsg)(struct sock___48 *, struct msghdr___50 *, size_t);
	int (*recvmsg)(struct sock___48 *, struct msghdr___50 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___48 *, struct page___420 *, int, size_t, int);
	int (*bind)(struct sock___48 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___48 *, struct sk_buff___66 *);
	void (*release_cb)(struct sock___48 *);
	int (*hash)(struct sock___48 *);
	void (*unhash)(struct sock___48 *);
	void (*rehash)(struct sock___48 *);
	int (*get_port)(struct sock___48 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___48 *);
	bool (*stream_memory_read)(const struct sock___48 *);
	void (*enter_memory_pressure)(struct sock___48 *);
	void (*leave_memory_pressure)(struct sock___48 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___32 *rsk_prot;
	struct timewait_sock_ops___30 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___349 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___48 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct request_sock___33;

struct request_sock_ops___32 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___48 *, struct request_sock___33 *);
	void (*send_ack)(const struct sock___48 *, struct sk_buff___66 *, struct request_sock___33 *);
	void (*send_reset)(const struct sock___48 *, struct sk_buff___66 *);
	void (*destructor)(struct request_sock___33 *);
	void (*syn_ack_timeout)(const struct request_sock___33 *);
};

struct timewait_sock_ops___30 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___48 *, struct sock___48 *, void *);
	void (*twsk_destructor)(struct sock___48 *);
};

struct request_sock___33 {
	struct sock_common___47 __req_common;
	struct request_sock___33 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___32 *rsk_ops;
	struct sock___48 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___27 {
	struct in6_addr mca_addr;
	struct inet6_dev___27 *idev;
	struct ifmcaddr6___27 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___8 {
	struct in6_addr aca_addr;
	struct fib6_info___8 *aca_rt;
	struct ifacaddr6___8 *aca_next;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct ip6_ra_chain___27 {
	struct ip6_ra_chain___27 *next;
	struct sock___48 *sk;
	int sel;
	void (*destructor)(struct sock___48 *);
};

struct ipv6_stub___7 {
	int (*ipv6_sock_mc_join)(struct sock___48 *, int, const struct in6_addr *);
	int (*ipv6_sock_mc_drop)(struct sock___48 *, int, const struct in6_addr *);
	int (*ipv6_dst_lookup)(struct net___76 *, struct sock___48 *, struct dst_entry___47 **, struct flowi6 *);
	struct fib6_table___8 * (*fib6_get_table)(struct net___76 *, u32);
	struct fib6_info___8 * (*fib6_lookup)(struct net___76 *, int, struct flowi6 *, int);
	struct fib6_info___8 * (*fib6_table_lookup)(struct net___76 *, struct fib6_table___8 *, int, struct flowi6 *, int);
	struct fib6_info___8 * (*fib6_multipath_select)(const struct net___76 *, struct fib6_info___8 *, struct flowi6 *, int, const struct sk_buff___66 *, int);
	u32 (*ip6_mtu_from_fib6)(struct fib6_info___8 *, struct in6_addr *, struct in6_addr *);
	void (*udpv6_encap_enable)();
	void (*ndisc_send_na)(struct net_device___65 *, const struct in6_addr *, const struct in6_addr *, bool, bool, bool, bool);
	struct neigh_table___47 *nd_tbl;
};

struct ipv6_bpf_stub___7 {
	int (*inet6_bind)(struct sock___48 *, struct sockaddr *, int, bool, bool);
	struct sock___48 * (*udp6_lib_lookup)(struct net___76 *, const struct in6_addr *, __be16, const struct in6_addr *, __be16, int, int, struct udp_table *, struct sk_buff___66 *);
};

struct ip_tunnel_encap_ops___5 {
	size_t (*encap_hlen)(struct ip_tunnel_encap *);
	int (*build_header)(struct sk_buff___66 *, struct ip_tunnel_encap *, u8 *, struct flowi4 *);
};

struct module___350;

struct file___420;

struct kiocb___420;

struct iov_iter___187;

struct poll_table_struct___262;

struct vm_area_struct___421;

struct inode___420;

struct file_lock___420;

struct page___421;

struct pipe_inode_info___101;

struct seq_file___359;

struct file_operations___420 {
	struct module___350 *owner;
	loff_t (*llseek)(struct file___420 *, loff_t, int);
	ssize_t (*read)(struct file___420 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___420 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___420 *, struct iov_iter___187 *);
	ssize_t (*write_iter)(struct kiocb___420 *, struct iov_iter___187 *);
	int (*iopoll)(struct kiocb___420 *, bool);
	int (*iterate)(struct file___420 *, struct dir_context *);
	int (*iterate_shared)(struct file___420 *, struct dir_context *);
	__poll_t (*poll)(struct file___420 *, struct poll_table_struct___262 *);
	long int (*unlocked_ioctl)(struct file___420 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___420 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___420 *, struct vm_area_struct___421 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___420 *, struct file___420 *);
	int (*flush)(struct file___420 *, fl_owner_t);
	int (*release)(struct inode___420 *, struct file___420 *);
	int (*fsync)(struct file___420 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___420 *, int);
	int (*lock)(struct file___420 *, int, struct file_lock___420 *);
	ssize_t (*sendpage)(struct file___420 *, struct page___421 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___420 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___420 *, int, struct file_lock___420 *);
	ssize_t (*splice_write)(struct pipe_inode_info___101 *, struct file___420 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___420 *, loff_t *, struct pipe_inode_info___101 *, size_t, unsigned int);
	int (*setlease)(struct file___420 *, long int, struct file_lock___420 **, void **);
	long int (*fallocate)(struct file___420 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___359 *, struct file___420 *);
	ssize_t (*copy_file_range)(struct file___420 *, loff_t, struct file___420 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___420 *, loff_t, struct file___420 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___420 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___421 {
	u64 seqnum;
	struct vm_area_struct___421 *vmas[4];
};

struct page_frag___421 {
	struct page___421 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___155;

struct debug_info___155 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___155 *hbp_break[16];
	struct perf_event___155 *hbp_watch[16];
};

struct thread_struct___155 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___155 debug;
	long: 64;
};

struct mm_struct___421;

struct mem_cgroup___156;

struct pid___238;

struct cred___388;

struct nsproxy___315;

struct signal_struct___295;

struct bio_list___213;

struct backing_dev_info___213;

struct css_set___269;

struct perf_event_context___155;

struct vm_struct___324;

struct task_struct___422 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___422 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___421 *mm;
	struct mm_struct___421 *active_mm;
	struct vmacache___421 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___422 *real_parent;
	struct task_struct___422 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___422 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___156 *active_memcg;
	long int rh_reserved2;
	struct pid___238 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___238 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___238 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___388 *ptracer_cred;
	const struct cred___388 *real_cred;
	const struct cred___388 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___315 *nsproxy;
	struct signal_struct___295 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___422 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___213 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___213 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___269 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___155 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___101 *splice_pipe;
	struct page_frag___421 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___156 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___422 *oom_reaper_list;
	struct vm_struct___324 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___155 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___155 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___422 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___155)(struct perf_event___155 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___155;

struct fasync_struct___420;

struct pid_namespace___238;

struct bpf_prog___58;

struct trace_event_call___146;

struct perf_cgroup___155;

struct perf_event___155 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___155 *group_leader;
	struct pmu___155 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___155 hw;
	struct perf_event_context___155 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___155 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___422 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___420 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___155 *);
	struct callback_head callback_head;
	struct pid_namespace___238 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___155 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___155 orig_overflow_handler;
	struct bpf_prog___58 *prog;
	struct trace_event_call___146 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___155 *cgrp;
	struct list_head sb_list;
};

struct secondary_data___422 {
	void *stack;
	struct task_struct___422 *task;
	long int status;
};

struct rw_semaphore___422 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___422 *owner;
};

struct key___388;

struct ucounts___285;

struct user_namespace___285 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___285 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___29 ns;
	long unsigned int flags;
	struct key___388 *persistent_keyring_register;
	struct rw_semaphore___422 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___285 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___421 *pgtable_t___421;

struct address_space___420;

struct dev_pagemap___408;

struct page___421 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___420 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___421 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___421 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___421 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___408 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___156 *mem_cgroup;
};

struct pglist_data___421;

struct lruvec___421 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___421 *pgdat;
};

struct zone___421 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___421 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___421 {
	struct zone___421 *zone;
	int zone_idx;
};

struct zonelist___421 {
	struct zoneref___421 _zonerefs[25];
};

struct pglist_data___421 {
	struct zone___421 node_zones[3];
	struct zonelist___421 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___422 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___422 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___421 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___421 {
	struct rw_semaphore___422 rwsem;
	struct notifier_block *head;
};

struct cgroup___269;

struct cgroup_subsys___269;

struct cgroup_subsys_state___269 {
	struct cgroup___269 *cgroup;
	struct cgroup_subsys___269 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___269 *parent;
};

struct kernfs_node___415;

struct cgroup_file___269 {
	struct kernfs_node___415 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___156;

struct mem_cgroup___156 {
	struct cgroup_subsys_state___269 css;
	struct mem_cgroup_id___14 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___269 events_file;
	struct cgroup_file___269 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___422 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___156 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct upid___238 {
	int nr;
	struct pid_namespace___238 *ns;
};

struct dentry___420;

struct pid_namespace___238 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___422 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___238 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___420 *proc_self;
	struct dentry___420 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___285 *user_ns;
	struct ucounts___285 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___29 ns;
};

struct pid___238 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___238 numbers[1];
};

struct user_struct___388 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___388 *uid_keyring;
	struct key___388 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___408;

struct vm_area_struct___421 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___421 *vm_next;
	struct vm_area_struct___421 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___421 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___408 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___420 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___421;

struct mm_struct___421 {
	struct {
		struct vm_area_struct___421 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___420 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___422 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___421 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___422 *owner;
		struct user_namespace___285 *user_ns;
		struct file___420 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___421 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___388 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___388 *session_keyring;
	struct key___388 *process_keyring;
	struct key___388 *thread_keyring;
	struct key___388 *request_key_auth;
	void *security;
	struct user_struct___388 *user;
	struct user_namespace___285 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___77;

struct cgroup_namespace___269;

struct nsproxy___315 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___238 *pid_ns_for_children;
	struct net___77 *net_ns;
	struct cgroup_namespace___269 *cgroup_ns;
};

struct signal_struct___295 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___422 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___422 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___238 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___238 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___421 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___238 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___213;

struct bio_list___213 {
	struct bio___213 *head;
	struct bio___213 *tail;
};

struct bdi_writeback_congested___213;

struct bdi_writeback___213 {
	struct backing_dev_info___213 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___213 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___269 *memcg_css;
	struct cgroup_subsys_state___269 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___388;

struct backing_dev_info___213 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___213 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___388 *dev;
	struct device___388 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___420 *debug_dir;
	struct dentry___420 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___269 {
	struct cgroup_subsys_state___269 *subsys[13];
	refcount_t refcount;
	struct css_set___269 *dom_cset;
	struct cgroup___269 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___269 *mg_src_cgrp;
	struct cgroup___269 *mg_dst_cgrp;
	struct css_set___269 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___155 {
	struct pmu___155 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___422 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___155 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___101;

struct pipe_inode_info___101 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___421 *tmp_page;
	struct fasync_struct___420 *fasync_readers;
	struct fasync_struct___420 *fasync_writers;
	struct pipe_buffer___101 *bufs;
	struct user_struct___388 *user;
};

struct vm_struct___324 {
	struct vm_struct___324 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___421 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___307 {
	struct task_struct___422 task;
	long unsigned int stack[8192];
};

struct address_space_operations___420;

struct address_space___420 {
	struct inode___420 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___422 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___420 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___408)(struct vm_area_struct___421 *, long unsigned int, const struct page___421 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___408)(struct page___421 *, void *);

struct dev_pagemap___408 {
	dev_page_fault_t___408 page_fault;
	dev_page_free_t___408 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___388 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___421 {
	struct vfsmount *mnt;
	struct dentry___420 *dentry;
};

struct fown_struct___238 {
	rwlock_t lock;
	struct pid___238 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___420 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___421 f_path;
	struct inode___420 *f_inode;
	const struct file_operations___420 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___238 f_owner;
	const struct cred___388 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___420 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___408;

struct vm_operations_struct___408 {
	void (*open)(struct vm_area_struct___421 *);
	void (*close)(struct vm_area_struct___421 *);
	int (*split)(struct vm_area_struct___421 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___421 *);
	vm_fault_t (*fault)(struct vm_fault___408 *);
	vm_fault_t (*huge_fault)(struct vm_fault___408 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___408 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___421 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___408 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___408 *);
	int (*access)(struct vm_area_struct___421 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___421 *);
	int (*set_policy)(struct vm_area_struct___421 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___421 *, long unsigned int);
	struct page___421 * (*find_special_page)(struct vm_area_struct___421 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___421 {
	struct task_struct___422 *task;
	struct core_thread___421 *next;
};

struct core_state___421 {
	atomic_t nr_threads;
	struct core_thread___421 dumper;
	struct completion startup;
};

struct vm_fault___408 {
	struct vm_area_struct___421 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___421 *cow_page;
	struct mem_cgroup___156 *memcg;
	struct page___421 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___421 prealloc_pte;
};

struct crypto_async_request___27;

typedef void (*crypto_completion_t___27)(struct crypto_async_request___27 *, int);

struct crypto_tfm___27;

struct crypto_async_request___27 {
	struct list_head list;
	crypto_completion_t___27 complete;
	void *data;
	struct crypto_tfm___27 *tfm;
	u32 flags;
};

struct crypto_ablkcipher___27;

struct ablkcipher_request___27;

struct ablkcipher_tfm___27 {
	int (*setkey)(struct crypto_ablkcipher___27 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___27 *);
	int (*decrypt)(struct ablkcipher_request___27 *);
	struct crypto_ablkcipher___27 *base;
	unsigned int ivsize;
	unsigned int reqsize;
};

struct blkcipher_desc___27;

struct blkcipher_tfm___27 {
	void *iv;
	int (*setkey)(struct crypto_tfm___27 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___27 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___27 *, struct scatterlist *, struct scatterlist *, unsigned int);
};

struct cipher_tfm___27 {
	int (*cit_setkey)(struct crypto_tfm___27 *, const u8 *, unsigned int);
	void (*cit_encrypt_one)(struct crypto_tfm___27 *, u8 *, const u8 *);
	void (*cit_decrypt_one)(struct crypto_tfm___27 *, u8 *, const u8 *);
};

struct compress_tfm___27 {
	int (*cot_compress)(struct crypto_tfm___27 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*cot_decompress)(struct crypto_tfm___27 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___27;

struct crypto_tfm___27 {
	u32 crt_flags;
	union {
		struct ablkcipher_tfm___27 ablkcipher;
		struct blkcipher_tfm___27 blkcipher;
		struct cipher_tfm___27 cipher;
		struct compress_tfm___27 compress;
	} crt_u;
	void (*exit)(struct crypto_tfm___27 *);
	struct crypto_alg___27 *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct ablkcipher_request___27 {
	struct crypto_async_request___27 base;
	unsigned int nbytes;
	void *info;
	struct scatterlist *src;
	struct scatterlist *dst;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_blkcipher___27;

struct blkcipher_desc___27 {
	struct crypto_blkcipher___27 *tfm;
	void *info;
	u32 flags;
};

struct crypto_blkcipher___27 {
	struct crypto_tfm___27 base;
};

struct ablkcipher_alg___27 {
	int (*setkey)(struct crypto_ablkcipher___27 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___27 *);
	int (*decrypt)(struct ablkcipher_request___27 *);
	int (*givencrypt)(struct skcipher_givcrypt_request *);
	int (*givdecrypt)(struct skcipher_givcrypt_request *);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct crypto_ablkcipher___27 {
	struct crypto_tfm___27 base;
};

struct blkcipher_alg___27 {
	int (*setkey)(struct crypto_tfm___27 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___27 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___27 *, struct scatterlist *, struct scatterlist *, unsigned int);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct cipher_alg___27 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___27 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___27 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___27 *, u8 *, const u8 *);
};

struct compress_alg___27 {
	int (*coa_compress)(struct crypto_tfm___27 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___27 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___27 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type *cra_type;
	union {
		struct ablkcipher_alg___27 ablkcipher;
		struct blkcipher_alg___27 blkcipher;
		struct cipher_alg___27 cipher;
		struct compress_alg___27 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___27 *);
	void (*cra_exit)(struct crypto_tfm___27 *);
	void (*cra_destroy)(struct crypto_alg___27 *);
	struct module___350 *cra_module;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___407;

struct kobj_type___407;

struct kobject___408 {
	const char *name;
	struct list_head entry;
	struct kobject___408 *parent;
	struct kset___407 *kset;
	struct kobj_type___407 *ktype;
	struct kernfs_node___415 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___348 {
	struct kobject___408 kobj;
	struct module___350 *mod;
	struct kobject___408 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___348 {
	struct module___350 *mod;
	struct latch_tree_node node;
};

struct module_layout___348 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___348 mtn;
};

struct module_attribute___348;

struct kernel_param___348;

struct module___350 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___348 mkobj;
	struct module_attribute___348 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___408 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___348 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___348 core_layout;
	struct module_layout___348 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___146 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide40;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide41;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct crypto_cipher___11 {
	struct crypto_tfm___27 base;
};

struct bio_vec___215 {
	struct page___421 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___187 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___215 *bvec;
		struct pipe_inode_info___101 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct msghdr___51 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___187 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___420 *msg_iocb;
};

struct kiocb___420 {
	struct file___420 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___420 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dentry_operations___420;

struct super_block___420;

struct dentry___420 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___420 *d_parent;
	struct qstr d_name;
	struct inode___420 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___420 *d_op;
	struct super_block___420 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___420;

struct block_device___420;

struct inode___420 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___420 *i_op;
	struct super_block___420 *i_sb;
	struct address_space___420 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___422 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___213 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___420 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___420 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___101 *i_pipe;
		struct block_device___420 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___420 {
	int (*d_revalidate)(struct dentry___420 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___420 *, unsigned int);
	int (*d_hash)(const struct dentry___420 *, struct qstr *);
	int (*d_compare)(const struct dentry___420 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___420 *);
	int (*d_init)(struct dentry___420 *);
	void (*d_release)(struct dentry___420 *);
	void (*d_prune)(struct dentry___420 *);
	void (*d_iput)(struct dentry___420 *, struct inode___420 *);
	char * (*d_dname)(struct dentry___420 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___421 *);
	int (*d_manage)(const struct path___421 *, bool);
	struct dentry___420 * (*d_real)(struct dentry___420 *, const struct inode___420 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___420;

struct mem_dqinfo___420 {
	struct quota_format_type___420 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___420;

struct quota_info___420 {
	unsigned int flags;
	struct rw_semaphore___422 dqio_sem;
	struct inode___420 *files[3];
	struct mem_dqinfo___420 info[3];
	const struct quota_format_ops___420 *ops[3];
};

struct rcuwait___420 {
	struct task_struct___422 *task;
};

struct percpu_rw_semaphore___420 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___422 rw_sem;
	struct rcuwait___420 writer;
	int readers_block;
};

struct sb_writers___420 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___420 rw_sem[3];
};

struct shrink_control___156;

struct shrinker___156 {
	long unsigned int (*count_objects)(struct shrinker___156 *, struct shrink_control___156 *);
	long unsigned int (*scan_objects)(struct shrinker___156 *, struct shrink_control___156 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___420;

struct super_operations___420;

struct dquot_operations___420;

struct quotactl_ops___420;

struct super_block___420 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___420 *s_type;
	const struct super_operations___420 *s_op;
	const struct dquot_operations___420 *dq_op;
	const struct quotactl_ops___420 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___420 *s_root;
	struct rw_semaphore___422 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___420 *s_bdev;
	struct backing_dev_info___213 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___420 s_dquot;
	struct sb_writers___420 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___420 *s_d_op;
	int cleancache_poolid;
	struct shrinker___156 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___285 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___156 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___156 *memcg;
};

struct iattr___420 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___420 *ia_file;
};

struct dquot___420 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___420 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___420 {
	int qf_fmt_id;
	const struct quota_format_ops___420 *qf_ops;
	struct module___350 *qf_owner;
	struct quota_format_type___420 *qf_next;
};

struct quota_format_ops___420 {
	int (*check_quota_file)(struct super_block___420 *, int);
	int (*read_file_info)(struct super_block___420 *, int);
	int (*write_file_info)(struct super_block___420 *, int);
	int (*free_file_info)(struct super_block___420 *, int);
	int (*read_dqblk)(struct dquot___420 *);
	int (*commit_dqblk)(struct dquot___420 *);
	int (*release_dqblk)(struct dquot___420 *);
	int (*get_next_id)(struct super_block___420 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___420 {
	int (*write_dquot)(struct dquot___420 *);
	struct dquot___420 * (*alloc_dquot)(struct super_block___420 *, int);
	void (*destroy_dquot)(struct dquot___420 *);
	int (*acquire_dquot)(struct dquot___420 *);
	int (*release_dquot)(struct dquot___420 *);
	int (*mark_dirty)(struct dquot___420 *);
	int (*write_info)(struct super_block___420 *, int);
	qsize_t * (*get_reserved_space)(struct inode___420 *);
	int (*get_projid)(struct inode___420 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___420 *, qsize_t *);
	int (*get_next_id)(struct super_block___420 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___420 {
	int (*quota_on)(struct super_block___420 *, int, int, const struct path___421 *);
	int (*quota_off)(struct super_block___420 *, int);
	int (*quota_enable)(struct super_block___420 *, unsigned int);
	int (*quota_disable)(struct super_block___420 *, unsigned int);
	int (*quota_sync)(struct super_block___420 *, int);
	int (*set_info)(struct super_block___420 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___420 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___420 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___420 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___420 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___420 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___176;

struct address_space_operations___420 {
	int (*writepage)(struct page___421 *, struct writeback_control___176 *);
	int (*readpage)(struct file___420 *, struct page___421 *);
	int (*writepages)(struct address_space___420 *, struct writeback_control___176 *);
	int (*set_page_dirty)(struct page___421 *);
	int (*readpages)(struct file___420 *, struct address_space___420 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___420 *, struct address_space___420 *, loff_t, unsigned int, unsigned int, struct page___421 **, void **);
	int (*write_end)(struct file___420 *, struct address_space___420 *, loff_t, unsigned int, unsigned int, struct page___421 *, void *);
	sector_t (*bmap)(struct address_space___420 *, sector_t);
	void (*invalidatepage)(struct page___421 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___421 *, gfp_t);
	void (*freepage)(struct page___421 *);
	ssize_t (*direct_IO)(struct kiocb___420 *, struct iov_iter___187 *);
	int (*migratepage)(struct address_space___420 *, struct page___421 *, struct page___421 *, enum migrate_mode);
	bool (*isolate_page)(struct page___421 *, isolate_mode_t);
	void (*putback_page)(struct page___421 *);
	int (*launder_page)(struct page___421 *);
	int (*is_partially_uptodate)(struct page___421 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___421 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___420 *, struct page___421 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___420 *, sector_t *);
	void (*swap_deactivate)(struct file___420 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___176 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___213 *wb;
	struct inode___420 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___420 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___420 *bd_inode;
	struct super_block___420 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___420 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___213 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___420 {
	struct dentry___420 * (*lookup)(struct inode___420 *, struct dentry___420 *, unsigned int);
	const char * (*get_link)(struct dentry___420 *, struct inode___420 *, struct delayed_call *);
	int (*permission)(struct inode___420 *, int);
	struct posix_acl * (*get_acl)(struct inode___420 *, int);
	int (*readlink)(struct dentry___420 *, char *, int);
	int (*create)(struct inode___420 *, struct dentry___420 *, umode_t, bool);
	int (*link)(struct dentry___420 *, struct inode___420 *, struct dentry___420 *);
	int (*unlink)(struct inode___420 *, struct dentry___420 *);
	int (*symlink)(struct inode___420 *, struct dentry___420 *, const char *);
	int (*mkdir)(struct inode___420 *, struct dentry___420 *, umode_t);
	int (*rmdir)(struct inode___420 *, struct dentry___420 *);
	int (*mknod)(struct inode___420 *, struct dentry___420 *, umode_t, dev_t);
	int (*rename)(struct inode___420 *, struct dentry___420 *, struct inode___420 *, struct dentry___420 *, unsigned int);
	int (*setattr)(struct dentry___420 *, struct iattr___420 *);
	int (*getattr)(const struct path___421 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___420 *, char *, size_t);
	int (*fiemap)(struct inode___420 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___420 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___420 *, struct dentry___420 *, struct file___420 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___420 *, struct dentry___420 *, umode_t);
	int (*set_acl)(struct inode___420 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___420 {
	void (*fl_copy_lock)(struct file_lock___420 *, struct file_lock___420 *);
	void (*fl_release_private)(struct file_lock___420 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___420;

struct file_lock___420 {
	struct file_lock___420 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___420 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___420 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___420 *fl_ops;
	const struct lock_manager_operations___420 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___420 {
	int (*lm_compare_owner)(struct file_lock___420 *, struct file_lock___420 *);
	long unsigned int (*lm_owner_key)(struct file_lock___420 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___420 *);
	int (*lm_grant)(struct file_lock___420 *, int);
	bool (*lm_break)(struct file_lock___420 *);
	int (*lm_change)(struct file_lock___420 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___420 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___420 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___420 *fa_next;
	struct file___420 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___420 {
	const char *name;
	int fs_flags;
	struct dentry___420 * (*mount)(struct file_system_type___420 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___420 *);
	struct module___350 *owner;
	struct file_system_type___420 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___420 {
	struct inode___420 * (*alloc_inode)(struct super_block___420 *);
	void (*destroy_inode)(struct inode___420 *);
	void (*dirty_inode)(struct inode___420 *, int);
	int (*write_inode)(struct inode___420 *, struct writeback_control___176 *);
	int (*drop_inode)(struct inode___420 *);
	void (*evict_inode)(struct inode___420 *);
	void (*put_super)(struct super_block___420 *);
	int (*sync_fs)(struct super_block___420 *, int);
	int (*freeze_super)(struct super_block___420 *);
	int (*freeze_fs)(struct super_block___420 *);
	int (*thaw_super)(struct super_block___420 *);
	int (*unfreeze_fs)(struct super_block___420 *);
	int (*statfs)(struct dentry___420 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___420 *, int *, char *);
	void (*umount_begin)(struct super_block___420 *);
	int (*show_options)(struct seq_file___359 *, struct dentry___420 *);
	int (*show_devname)(struct seq_file___359 *, struct dentry___420 *);
	int (*show_path)(struct seq_file___359 *, struct dentry___420 *);
	int (*show_stats)(struct seq_file___359 *, struct dentry___420 *);
	ssize_t (*quota_read)(struct super_block___420 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___420 *, int, const char *, size_t, loff_t);
	struct dquot___420 ** (*get_dquots)(struct inode___420 *);
	int (*bdev_try_to_free_page)(struct super_block___420 *, struct page___421 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___420 *, struct shrink_control___156 *);
	long int (*free_cached_objects)(struct super_block___420 *, struct shrink_control___156 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___272)(struct file___420 *, wait_queue_head_t *, struct poll_table_struct___262 *);

struct poll_table_struct___262 {
	poll_queue_proc___272 _qproc;
	__poll_t _key;
};

struct seq_operations___359;

struct seq_file___359 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___359 *op;
	int poll_event;
	const struct file___420 *file;
	void *private;
};

typedef void bio_end_io_t___213(struct bio___213 *);

struct bio_integrity_payload___213;

struct bio_set___213;

struct bio___213 {
	struct bio___213 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___213 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___213 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___215 *bi_io_vec;
	struct bio_set___213 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___215 bi_inline_vecs[0];
};

struct socket_wq___49 {
	wait_queue_head_t wait;
	struct fasync_struct___420 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct sock___49;

struct proto_ops___49;

struct socket___50 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___49 *wq;
	struct file___420 *file;
	struct sock___49 *sk;
	const struct proto_ops___49 *ops;
};

typedef struct {
	struct net___77 *net;
} possible_net_t___67;

struct proto___48;

struct sock_common___48 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___48 *skc_prot;
	possible_net_t___67 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___49 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___67;

struct sk_buff_head___65 {
	struct sk_buff___67 *next;
	struct sk_buff___67 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___48;

struct dst_entry___48;

struct net_device___66;

struct sock___49 {
	struct sock_common___48 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___65 sk_error_queue;
	struct sk_buff_head___65 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___67 *head;
		struct sk_buff___67 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___48 *sk_filter;
	union {
		struct socket_wq___49 *sk_wq;
		struct socket_wq___49 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___48 *sk_rx_dst;
	struct dst_entry___48 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___67 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___65 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___421 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___48 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___238 *sk_peer_pid;
	const struct cred___388 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___50 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___156 *sk_memcg;
	void (*sk_state_change)(struct sock___49 *);
	void (*sk_data_ready)(struct sock___49 *);
	void (*sk_write_space)(struct sock___49 *);
	void (*sk_error_report)(struct sock___49 *);
	int (*sk_backlog_rcv)(struct sock___49 *, struct sk_buff___67 *);
	struct sk_buff___67 * (*sk_validate_xmit_skb)(struct sock___49 *, struct net_device___66 *, struct sk_buff___67 *);
	void (*sk_destruct)(struct sock___49 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

typedef int (*sk_read_actor_t___48)(read_descriptor_t *, struct sk_buff___67 *, unsigned int, size_t);

struct proto_ops___49 {
	int family;
	struct module___350 *owner;
	int (*release)(struct socket___50 *);
	int (*bind)(struct socket___50 *, struct sockaddr *, int);
	int (*connect)(struct socket___50 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___50 *, struct socket___50 *);
	int (*accept)(struct socket___50 *, struct socket___50 *, int, bool);
	int (*getname)(struct socket___50 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___420 *, struct socket___50 *, struct poll_table_struct___262 *);
	int (*ioctl)(struct socket___50 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___50 *, int);
	int (*shutdown)(struct socket___50 *, int);
	int (*setsockopt)(struct socket___50 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___50 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___50 *, struct msghdr___51 *, size_t);
	int (*recvmsg)(struct socket___50 *, struct msghdr___51 *, size_t, int);
	int (*mmap)(struct file___420 *, struct socket___50 *, struct vm_area_struct___421 *);
	ssize_t (*sendpage)(struct socket___50 *, struct page___421 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___50 *, loff_t *, struct pipe_inode_info___101 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___49 *, int);
	int (*peek_len)(struct socket___50 *);
	int (*read_sock)(struct sock___49 *, read_descriptor_t *, sk_read_actor_t___48);
	int (*sendpage_locked)(struct sock___49 *, struct page___421 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___49 *, struct msghdr___51 *, size_t);
	int (*set_rcvlowat)(struct sock___49 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct nf_bridge_info___65;

struct sk_buff___67 {
	union {
		struct {
			struct sk_buff___67 *next;
			struct sk_buff___67 *prev;
			union {
				struct net_device___66 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___49 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___67 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___65 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___65;

struct netns_frags___65 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___65 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ip_ra_chain___24;

struct fib_rules_ops___48;

struct tcp_congestion_ops___8;

struct tcp_fastopen_context___8;

struct fib_notifier_ops___49;

struct netns_ipv4___65 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___24 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___48 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___49 *fibnl;
	struct sock___49 **icmp_sk;
	struct sock___49 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___49 **tcp_sk;
	struct netns_frags___65 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops___8 *tcp_congestion_control;
	struct tcp_fastopen_context___8 *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___48 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___49 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___49 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___48;

struct dst_ops___76 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___76 *);
	struct dst_entry___48 * (*check)(struct dst_entry___48 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___48 *);
	unsigned int (*mtu)(const struct dst_entry___48 *);
	u32 * (*cow_metrics)(struct dst_entry___48 *, long unsigned int);
	void (*destroy)(struct dst_entry___48 *);
	void (*ifdown)(struct dst_entry___48 *, struct net_device___66 *, int);
	struct dst_entry___48 * (*negative_advice)(struct dst_entry___48 *);
	void (*link_failure)(struct sk_buff___67 *);
	void (*update_pmtu)(struct dst_entry___48 *, struct sock___49 *, struct sk_buff___67 *, u32);
	void (*redirect)(struct dst_entry___48 *, struct sock___49 *, struct sk_buff___67 *);
	int (*local_out)(struct net___77 *, struct sock___49 *, struct sk_buff___67 *);
	struct neighbour___48 * (*neigh_lookup)(const struct dst_entry___48 *, struct sk_buff___67 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___48 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_info___9;

struct rt6_info___9;

struct fib6_table___9;

struct netns_ipv6___76 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___65 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info___9 *fib6_null_entry;
	struct rt6_info___9 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___9 *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___76 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info___9 *ip6_prohibit_entry;
	struct rt6_info___9 *ip6_blk_hole_entry;
	struct fib6_table___9 *fib6_local_tbl;
	struct fib_rules_ops___48 *fib6_rules_ops;
	struct sock___49 **icmp_sk;
	struct sock___49 *ndisc_sk;
	struct sock___49 *tcp_sk;
	struct sock___49 *igmp_sk;
	struct sock___49 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___48 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___49 *notifier_ops;
	struct fib_notifier_ops___49 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___49 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___49 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___65 {
	struct netns_frags___65 frags;
};

struct netns_xfrm___76 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___49 *nlsk;
	struct sock___49 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___76 xfrm4_dst_ops;
	struct dst_ops___76 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct net___77 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___285 *user_ns;
	struct ucounts___285 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___29 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___49 *rtnl;
	struct sock___49 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___66 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___65 ipv4;
	struct netns_ipv6___76 ipv6;
	struct netns_sctp___49 sctp;
	struct netns_nf___4 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___65 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___49 *nfnl;
	struct sock___49 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___76 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___49 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___58 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kernfs_root___414;

struct kernfs_elem_dir___414 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___414 *root;
};

struct kernfs_syscall_ops___414;

struct kernfs_root___414 {
	struct kernfs_node___415 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___414 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___414 {
	struct kernfs_node___415 *target_kn;
};

struct kernfs_ops___414;

struct kernfs_elem_attr___414 {
	const struct kernfs_ops___414 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___415 *notify_next;
};

struct kernfs_node___415 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___415 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___414 dir;
		struct kernfs_elem_symlink___414 symlink;
		struct kernfs_elem_attr___414 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___414;

struct kernfs_ops___414 {
	int (*open)(struct kernfs_open_file___414 *);
	void (*release)(struct kernfs_open_file___414 *);
	int (*seq_show)(struct seq_file___359 *, void *);
	void * (*seq_start)(struct seq_file___359 *, loff_t *);
	void * (*seq_next)(struct seq_file___359 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___359 *, void *);
	ssize_t (*read)(struct kernfs_open_file___414 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___414 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___414 *, struct vm_area_struct___421 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___414 *, struct poll_table_struct___262 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___414 {
	int (*remount_fs)(struct kernfs_root___414 *, int *, char *);
	int (*show_options)(struct seq_file___359 *, struct kernfs_root___414 *);
	int (*mkdir)(struct kernfs_node___415 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___415 *);
	int (*rename)(struct kernfs_node___415 *, struct kernfs_node___415 *, const char *);
	int (*show_path)(struct seq_file___359 *, struct kernfs_node___415 *, struct kernfs_root___414 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___414 {
	struct kernfs_node___415 *kn;
	struct file___420 *file;
	struct seq_file___359 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___408 *vm_ops;
};

struct kobj_ns_type_operations___48 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___49 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___384;

struct attribute_group___385 {
	const char *name;
	umode_t (*is_visible)(struct kobject___408 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___408 *, struct bin_attribute___384 *, int);
	struct attribute **attrs;
	struct bin_attribute___384 **bin_attrs;
};

struct bin_attribute___384 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___420 *, struct kobject___408 *, struct bin_attribute___384 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___420 *, struct kobject___408 *, struct bin_attribute___384 *, char *, loff_t, size_t);
	int (*mmap)(struct file___420 *, struct kobject___408 *, struct bin_attribute___384 *, struct vm_area_struct___421 *);
};

struct sysfs_ops___407 {
	ssize_t (*show)(struct kobject___408 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___408 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___407;

struct kset___407 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___408 kobj;
	const struct kset_uevent_ops___407 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___407 {
	void (*release)(struct kobject___408 *);
	const struct sysfs_ops___407 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___48 * (*child_ns_type)(struct kobject___408 *);
	const void * (*namespace)(struct kobject___408 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___407 {
	int (* const filter)(struct kset___407 *, struct kobject___408 *);
	const char * (* const name)(struct kset___407 *, struct kobject___408 *);
	int (* const uevent)(struct kset___407 *, struct kobject___408 *, struct kobj_uevent_env *);
};

struct kobj_attribute___398 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___408 *, struct kobj_attribute___398 *, char *);
	ssize_t (*store)(struct kobject___408 *, struct kobj_attribute___398 *, const char *, size_t);
};

struct dev_pm_ops___388 {
	int (*prepare)(struct device___388 *);
	void (*complete)(struct device___388 *);
	int (*suspend)(struct device___388 *);
	int (*resume)(struct device___388 *);
	int (*freeze)(struct device___388 *);
	int (*thaw)(struct device___388 *);
	int (*poweroff)(struct device___388 *);
	int (*restore)(struct device___388 *);
	int (*suspend_late)(struct device___388 *);
	int (*resume_early)(struct device___388 *);
	int (*freeze_late)(struct device___388 *);
	int (*thaw_early)(struct device___388 *);
	int (*poweroff_late)(struct device___388 *);
	int (*restore_early)(struct device___388 *);
	int (*suspend_noirq)(struct device___388 *);
	int (*resume_noirq)(struct device___388 *);
	int (*freeze_noirq)(struct device___388 *);
	int (*thaw_noirq)(struct device___388 *);
	int (*poweroff_noirq)(struct device___388 *);
	int (*restore_noirq)(struct device___388 *);
	int (*runtime_suspend)(struct device___388 *);
	int (*runtime_resume)(struct device___388 *);
	int (*runtime_idle)(struct device___388 *);
};

struct dev_pm_info___388 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___388 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___388;

struct bus_type___388;

struct device_driver___388;

struct dev_pm_domain___388;

struct dma_map_ops___160;

struct fwnode_handle___308;

struct class___388;

struct device___388 {
	struct device___388 *parent;
	struct device_private *p;
	struct kobject___408 kobj;
	const char *init_name;
	const struct device_type___388 *type;
	struct mutex mutex;
	struct bus_type___388 *bus;
	struct device_driver___388 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___388 power;
	struct dev_pm_domain___388 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___160 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___308 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___388 *class;
	const struct attribute_group___385 **groups;
	void (*release)(struct device___388 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___388 {
	struct dev_pm_ops___388 ops;
	void (*detach)(struct device___388 *, bool);
	int (*activate)(struct device___388 *);
	void (*sync)(struct device___388 *);
	void (*dismiss)(struct device___388 *);
};

struct bus_type___388 {
	const char *name;
	const char *dev_name;
	struct device___388 *dev_root;
	const struct attribute_group___385 **bus_groups;
	const struct attribute_group___385 **dev_groups;
	const struct attribute_group___385 **drv_groups;
	int (*match)(struct device___388 *, struct device_driver___388 *);
	int (*uevent)(struct device___388 *, struct kobj_uevent_env *);
	int (*probe)(struct device___388 *);
	int (*remove)(struct device___388 *);
	void (*shutdown)(struct device___388 *);
	int (*online)(struct device___388 *);
	int (*offline)(struct device___388 *);
	int (*suspend)(struct device___388 *, pm_message_t);
	int (*resume)(struct device___388 *);
	int (*num_vf)(struct device___388 *);
	int (*dma_configure)(struct device___388 *);
	const struct dev_pm_ops___388 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___388 {
	const char *name;
	struct bus_type___388 *bus;
	struct module___350 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___388 *);
	int (*remove)(struct device___388 *);
	void (*shutdown)(struct device___388 *);
	int (*suspend)(struct device___388 *, pm_message_t);
	int (*resume)(struct device___388 *);
	const struct attribute_group___385 **groups;
	const struct dev_pm_ops___388 *pm;
	void (*coredump)(struct device___388 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___388 {
	const char *name;
	const struct attribute_group___385 **groups;
	int (*uevent)(struct device___388 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___388 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___388 *);
	const struct dev_pm_ops___388 *pm;
};

struct class___388 {
	const char *name;
	struct module___350 *owner;
	const struct attribute_group___385 **class_groups;
	const struct attribute_group___385 **dev_groups;
	struct kobject___408 *dev_kobj;
	int (*dev_uevent)(struct device___388 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___388 *, umode_t *);
	void (*class_release)(struct class___388 *);
	void (*dev_release)(struct device___388 *);
	int (*shutdown_pre)(struct device___388 *);
	const struct kobj_ns_type_operations___48 *ns_type;
	const void * (*namespace)(struct device___388 *);
	const struct dev_pm_ops___388 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___160 {
	void * (*alloc)(struct device___388 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___388 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___388 *, struct vm_area_struct___421 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___388 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___388 *, struct page___421 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___388 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___388 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___388 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___388 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___388 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___388 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___388 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___388 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___388 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___388 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___388 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___388 *, u64);
	u64 (*get_required_mask)(struct device___388 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___308;

struct fwnode_handle___308 {
	struct fwnode_handle___308 *secondary;
	const struct fwnode_operations___308 *ops;
};

typedef void compound_page_dtor___408(struct page___421 *);

struct fwnode_reference_args___308;

struct fwnode_endpoint___308;

struct fwnode_operations___308 {
	struct fwnode_handle___308 * (*get)(struct fwnode_handle___308 *);
	void (*put)(struct fwnode_handle___308 *);
	bool (*device_is_available)(const struct fwnode_handle___308 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___308 *, const struct device___388 *);
	bool (*property_present)(const struct fwnode_handle___308 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___308 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___308 *, const char *, const char **, size_t);
	struct fwnode_handle___308 * (*get_parent)(const struct fwnode_handle___308 *);
	struct fwnode_handle___308 * (*get_next_child_node)(const struct fwnode_handle___308 *, struct fwnode_handle___308 *);
	struct fwnode_handle___308 * (*get_named_child_node)(const struct fwnode_handle___308 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___308 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___308 *);
	struct fwnode_handle___308 * (*graph_get_next_endpoint)(const struct fwnode_handle___308 *, struct fwnode_handle___308 *);
	struct fwnode_handle___308 * (*graph_get_remote_endpoint)(const struct fwnode_handle___308 *);
	struct fwnode_handle___308 * (*graph_get_port_parent)(struct fwnode_handle___308 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___308 *, struct fwnode_endpoint___308 *);
};

struct fwnode_endpoint___308 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___308 *local_fwnode;
};

struct fwnode_reference_args___308 {
	struct fwnode_handle___308 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___101;

struct pipe_buffer___101 {
	struct page___421 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___101 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___101 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___101 *, struct pipe_buffer___101 *);
	void (*release)(struct pipe_inode_info___101 *, struct pipe_buffer___101 *);
	int (*steal)(struct pipe_inode_info___101 *, struct pipe_buffer___101 *);
	union {
		bool (*get)(struct pipe_inode_info___101 *, struct pipe_buffer___101 *);
		struct {
			void (*get)(struct pipe_inode_info___101 *, struct pipe_buffer___101 *);
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
};

struct nf_bridge_info___65 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___65 = 0,
		BRNF_PROTO_8021Q___65 = 1,
		BRNF_PROTO_PPPOE___65 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___66 *physindev;
	struct net_device___66 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___65(struct sk_buff___67 **);

struct net_device_ops___65;

struct ethtool_ops___65;

struct l3mdev_ops___48;

struct ndisc_ops___28;

struct xfrmdev_ops___65;

struct tlsdev_ops___65;

struct header_ops___65;

struct in_device___5;

struct inet6_dev___28;

struct netdev_rx_queue___65;

struct mini_Qdisc___58;

struct netdev_queue___65;

struct Qdisc___58;

struct netpoll_info___4;

struct rtnl_link_ops___58;

struct dcbnl_rtnl_ops___65;

struct net_device___66 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___65 *netdev_ops;
	const struct ethtool_ops___65 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___48 *l3mdev_ops;
	const struct ndisc_ops___28 *ndisc_ops;
	const struct xfrmdev_ops___65 *xfrmdev_ops;
	const struct tlsdev_ops___65 *tlsdev_ops;
	const struct header_ops___65 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___407 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device___5 *ip_ptr;
	struct inet6_dev___28 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___65 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___58 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___65 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___58 *miniq_ingress;
	struct netdev_queue___65 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___65 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___58 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___58 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___65 = 0,
		NETREG_REGISTERED___65 = 1,
		NETREG_UNREGISTERING___65 = 2,
		NETREG_UNREGISTERED___65 = 3,
		NETREG_RELEASED___65 = 4,
		NETREG_DUMMY___65 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___65 = 0,
		RTNL_LINK_INITIALIZING___65 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___66 *);
	struct netpoll_info___4 *npinfo;
	possible_net_t___67 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___388 dev;
	const struct attribute_group___385 *sysfs_groups[4];
	const struct attribute_group___385 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___58 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___65 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct skb_frag_struct___10 {
	struct {
		struct page___421 *p;
	} page;
	__u32 page_offset;
	__u32 size;
};

typedef struct skb_frag_struct___10 skb_frag_t___10;

struct skb_shared_info___10 {
	__u8 __unused;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___67 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___10 frags[16];
};

struct ethtool_ops___65 {
	int (*get_settings)(struct net_device___66 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___66 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___66 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___66 *);
	void (*get_regs)(struct net_device___66 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___66 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___66 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___66 *);
	void (*set_msglevel)(struct net_device___66 *, u32);
	int (*nway_reset)(struct net_device___66 *);
	u32 (*get_link)(struct net_device___66 *);
	int (*get_eeprom_len)(struct net_device___66 *);
	int (*get_eeprom)(struct net_device___66 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___66 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___66 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___66 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___66 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___66 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___66 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___66 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___66 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___66 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___66 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___66 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___66 *);
	void (*complete)(struct net_device___66 *);
	u32 (*get_priv_flags)(struct net_device___66 *);
	int (*set_priv_flags)(struct net_device___66 *, u32);
	int (*get_sset_count)(struct net_device___66 *, int);
	int (*get_rxnfc)(struct net_device___66 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___66 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___66 *, struct ethtool_flash *);
	int (*reset)(struct net_device___66 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___66 *);
	u32 (*get_rxfh_indir_size)(struct net_device___66 *);
	int (*get_rxfh)(struct net_device___66 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___66 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___66 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___66 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___66 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___66 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___66 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___66 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___66 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___66 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___66 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___66 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___66 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___66 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___66 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___66 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___66 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___66 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___66 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___66 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___66 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___66 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	int (*get_fecparam)(struct net_device___66 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___66 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___66 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___66 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___66 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___65;

struct inet_frags___65 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___65 *, const void *);
	void (*destructor)(struct inet_frag_queue___65 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___65 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___67 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___67 *fragments_tail;
	struct sk_buff___67 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___65 *net;
	struct callback_head rcu;
};

struct ip_ra_chain___24 {
	struct ip_ra_chain___24 *next;
	struct sock___49 *sk;
	union {
		void (*destructor)(struct sock___49 *);
		struct sock___49 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___48;

struct fib_lookup_arg___48;

struct fib_rules_ops___48 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___48 *, struct flowi *, int, struct fib_lookup_arg___48 *);
	bool (*suppress)(struct fib_rule___48 *, struct fib_lookup_arg___48 *);
	int (*match)(struct fib_rule___48 *, struct flowi *, int);
	int (*configure)(struct fib_rule___48 *, struct sk_buff___67 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___48 *);
	int (*compare)(struct fib_rule___48 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___48 *, struct sk_buff___67 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___48 *);
	void (*flush_cache)(struct fib_rules_ops___48 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___350 *owner;
	struct net___77 *fro_net;
	struct callback_head rcu;
};

struct tcp_congestion_ops___8 {
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___49 *);
	void (*release)(struct sock___49 *);
	u32 (*ssthresh)(struct sock___49 *);
	void (*cong_avoid)(struct sock___49 *, u32, u32);
	void (*set_state)(struct sock___49 *, u8);
	void (*cwnd_event)(struct sock___49 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___49 *, u32);
	u32 (*undo_cwnd)(struct sock___49 *);
	void (*pkts_acked)(struct sock___49 *, const struct ack_sample *);
	u32 (*min_tso_segs)(struct sock___49 *);
	u32 (*sndbuf_expand)(struct sock___49 *);
	void (*cong_control)(struct sock___49 *, const struct rate_sample *);
	size_t (*get_info)(struct sock___49 *, u32, int *, union tcp_cc_info *);
	char name[16];
	struct module___350 *owner;
};

struct tcp_fastopen_context___8 {
	struct crypto_cipher___11 *tfm;
	__u8 key[16];
	struct callback_head rcu;
};

struct fib_notifier_ops___49 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___77 *);
	int (*fib_dump)(struct net___77 *, struct notifier_block *);
	struct module___350 *owner;
	struct callback_head rcu;
};

struct dst_entry___48 {
	struct net_device___66 *dev;
	struct dst_ops___76 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___67 *);
	int (*output)(struct net___77 *, struct sock___49 *, struct sk_buff___67 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___48;

struct neigh_parms___48;

struct neigh_ops___48;

struct neighbour___48 {
	struct neighbour___48 *next;
	struct neigh_table___48 *tbl;
	struct neigh_parms___48 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___65 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___48 *, struct sk_buff___67 *);
	const struct neigh_ops___48 *ops;
	struct callback_head rcu;
	struct net_device___66 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct fib6_nh___9 {
	struct in6_addr nh_gw;
	struct net_device___66 *nh_dev;
	struct lwtunnel_state *nh_lwtstate;
	unsigned int nh_flags;
	atomic_t nh_upper_bound;
	int nh_weight;
};

struct fib6_node___9;

struct fib6_info___9 {
	struct fib6_table___9 *fib6_table;
	struct fib6_info___9 *fib6_next;
	struct fib6_node___9 *fib6_node;
	struct list_head fib6_siblings;
	unsigned int fib6_nsiblings;
	atomic_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	struct rt6_info___9 **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
	long unsigned int last_probe;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 exception_bucket_flushed: 1;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 dst_host: 1;
	u8 fib6_destroying: 1;
	u8 unused: 2;
	struct fib6_nh___9 fib6_nh;
	struct callback_head rcu;
};

struct rt6_info___9 {
	struct dst_entry___48 dst;
	struct fib6_info___9 *from;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___28 *rt6i_idev;
	u32 rt6i_flags;
	struct rt6key rt6i_prefsrc;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct fib6_node___9 {
	struct fib6_node___9 *parent;
	struct fib6_node___9 *left;
	struct fib6_node___9 *right;
	struct fib6_info___9 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info___9 *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table___9 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node___9 tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

struct ucounts___285 {
	struct hlist_node node;
	struct user_namespace___285 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_prog_aux___61;

struct bpf_prog___58 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___61 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

typedef int (*key_restrict_link_func_t___389)(struct key___388 *, const struct key_type *, const union key_payload *, struct key___388 *);

struct key_restriction___388;

struct key___388 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___422 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___388 *restrict_link;
};

struct key_restriction___388 {
	key_restrict_link_func_t___389 check;
	struct key___388 *key;
	struct key_type *keytype;
};

struct seq_operations___359 {
	void * (*start)(struct seq_file___359 *, loff_t *);
	void (*stop)(struct seq_file___359 *, void *);
	void * (*next)(struct seq_file___359 *, void *, loff_t *);
	int (*show)(struct seq_file___359 *, void *);
};

struct pernet_operations___66 {
	struct list_head list;
	int (*init)(struct net___77 *);
	void (*exit)(struct net___77 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___65 {
	int (*ieee_getets)(struct net_device___66 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___66 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___66 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___66 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___66 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___66 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___66 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___66 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___66 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___66 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___66 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___66 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___66 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___66 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___66 *);
	u8 (*setstate)(struct net_device___66 *, u8);
	void (*getpermhwaddr)(struct net_device___66 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___66 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___66 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___66 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___66 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___66 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___66 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___66 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___66 *, int, u8 *);
	void (*setpfccfg)(struct net_device___66 *, int, u8);
	void (*getpfccfg)(struct net_device___66 *, int, u8 *);
	u8 (*setall)(struct net_device___66 *);
	u8 (*getcap)(struct net_device___66 *, int, u8 *);
	int (*getnumtcs)(struct net_device___66 *, int, u8 *);
	int (*setnumtcs)(struct net_device___66 *, int, u8);
	u8 (*getpfcstate)(struct net_device___66 *);
	void (*setpfcstate)(struct net_device___66 *, u8);
	void (*getbcncfg)(struct net_device___66 *, int, u32 *);
	void (*setbcncfg)(struct net_device___66 *, int, u32);
	void (*getbcnrp)(struct net_device___66 *, int, u8 *);
	void (*setbcnrp)(struct net_device___66 *, int, u8);
	int (*setapp)(struct net_device___66 *, u8, u16, u8);
	int (*getapp)(struct net_device___66 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___66 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___66 *, int, u8);
	u8 (*getdcbx)(struct net_device___66 *);
	u8 (*setdcbx)(struct net_device___66 *, u8);
	int (*peer_getappinfo)(struct net_device___66 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___66 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___66 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___66 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___66 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___66 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___269 {
	refcount_t count;
	struct ns_common___29 ns;
	struct user_namespace___285 *user_ns;
	struct ucounts___285 *ucounts;
	struct css_set___269 *root_cset;
};

struct bpf_map___270;

struct bpf_map_ops___269 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___270 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___270 *, struct file___420 *);
	void (*map_free)(struct bpf_map___270 *);
	int (*map_get_next_key)(struct bpf_map___270 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___270 *);
	void * (*map_lookup_elem)(struct bpf_map___270 *, void *);
	int (*map_update_elem)(struct bpf_map___270 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___270 *, void *);
	int (*map_push_elem)(struct bpf_map___270 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___270 *, void *);
	int (*map_peek_elem)(struct bpf_map___270 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___270 *, struct file___420 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___270 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___270 *, void *, struct seq_file___359 *);
	int (*map_check_btf)(const struct bpf_map___270 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___270 {
	const struct bpf_map_ops___269 *ops;
	struct bpf_map___270 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___388 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___65;

struct bpf_map_dev_ops___65 {
	int (*map_get_next_key)(struct bpf_offloaded_map___65 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___65 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___65 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___65 *, void *);
};

struct bpf_offloaded_map___65 {
	struct bpf_map___270 map;
	struct net_device___66 *netdev;
	const struct bpf_map_dev_ops___65 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___58 {
	int (*test_run)(struct bpf_prog___58 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___58 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___58 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___58 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___58 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___58 *, u32 *);
};

struct bpf_prog_offload_ops___58 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___58 *);
	int (*translate)(struct bpf_prog___58 *);
	void (*destroy)(struct bpf_prog___58 *);
};

struct bpf_prog_offload___58 {
	struct bpf_prog___58 *prog;
	struct net_device___66 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___58 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___61 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___58 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___58 *ops;
	struct bpf_map___270 **used_maps;
	struct bpf_prog___58 *prog;
	struct user_struct___388 *user;
	u64 load_time;
	struct bpf_map___270 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___58 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___58 {
	struct bpf_prog___58 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___58 {
	struct callback_head rcu;
	struct bpf_prog_array_item___58 items[0];
};

struct cgroup_bpf___58 {
	struct bpf_prog_array___58 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___58 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___270;

typedef void (*kthread_work_func_t___270)(struct kthread_work___270 *);

struct kthread_worker___270;

struct kthread_work___270 {
	struct list_head node;
	kthread_work_func_t___270 func;
	struct kthread_worker___270 *worker;
	int canceling;
};

struct kthread_worker___270 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___422 *task;
	struct kthread_work___270 *current_work;
};

struct kthread_delayed_work___269 {
	struct kthread_work___270 work;
	struct timer_list timer;
};

struct psi_group___269 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___270 *poll_kworker;
	struct kthread_delayed_work___269 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___269;

struct cgroup_rstat_cpu___269;

struct cgroup___269 {
	struct cgroup_subsys_state___269 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___415 *kn;
	struct cgroup_file___269 procs_file;
	struct cgroup_file___269 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___269 *subsys[13];
	struct cgroup_root___269 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___269 *dom_cgrp;
	struct cgroup_rstat_cpu___269 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___58 bpf;
	atomic_t congestion_count;
	struct cgroup___269 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___269 psi;
	int ancestor_ids[0];
};

struct cftype___269;

struct cgroup_subsys___269 {
	struct cgroup_subsys_state___269 * (*css_alloc)(struct cgroup_subsys_state___269 *);
	int (*css_online)(struct cgroup_subsys_state___269 *);
	void (*css_offline)(struct cgroup_subsys_state___269 *);
	void (*css_released)(struct cgroup_subsys_state___269 *);
	void (*css_free)(struct cgroup_subsys_state___269 *);
	void (*css_reset)(struct cgroup_subsys_state___269 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___269 *, int);
	int (*css_extra_stat_show)(struct seq_file___359 *, struct cgroup_subsys_state___269 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___422 *);
	void (*cancel_fork)(struct task_struct___422 *);
	void (*fork)(struct task_struct___422 *);
	void (*exit)(struct task_struct___422 *);
	void (*free)(struct task_struct___422 *);
	void (*bind)(struct cgroup_subsys_state___269 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___269 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___269 *dfl_cftypes;
	struct cftype___269 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___269 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___269 *updated_children;
	struct cgroup___269 *updated_next;
};

struct cgroup_root___269 {
	struct kernfs_root___414 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___269 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___269 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___269 *ss;
	struct list_head node;
	struct kernfs_ops___414 *kf_ops;
	int (*open)(struct kernfs_open_file___414 *);
	void (*release)(struct kernfs_open_file___414 *);
	u64 (*read_u64)(struct cgroup_subsys_state___269 *, struct cftype___269 *);
	s64 (*read_s64)(struct cgroup_subsys_state___269 *, struct cftype___269 *);
	int (*seq_show)(struct seq_file___359 *, void *);
	void * (*seq_start)(struct seq_file___359 *, loff_t *);
	void * (*seq_next)(struct seq_file___359 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___359 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___269 *, struct cftype___269 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___269 *, struct cftype___269 *, s64);
	ssize_t (*write)(struct kernfs_open_file___414 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___414 *, struct poll_table_struct___262 *);
};

struct xdp_rxq_info___65 {
	struct net_device___66 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___65 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___66 *dev_rx;
};

struct netlink_callback___67 {
	struct sk_buff___67 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___67 *);
	int (*dump)(struct sk_buff___67 *, struct netlink_callback___67 *);
	int (*done)(struct netlink_callback___67 *);
	void *data;
	struct module___350 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___65 {
	int (*create)(struct sk_buff___67 *, struct net_device___66 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___67 *, unsigned char *);
	int (*cache)(const struct neighbour___48 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___66 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___65 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___65 *, int);
	int poll_owner;
	struct net_device___66 *dev;
	struct sk_buff___67 *gro_list;
	struct sk_buff___67 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___65 {
	struct net_device___66 *dev;
	struct Qdisc___58 *qdisc;
	struct Qdisc___58 *qdisc_sleeping;
	struct kobject___408 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___66 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___58 {
	struct sk_buff___67 *head;
	struct sk_buff___67 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___58;

struct Qdisc___58 {
	int (*enqueue)(struct sk_buff___67 *, struct Qdisc___58 *, struct sk_buff___67 **);
	struct sk_buff___67 * (*dequeue)(struct Qdisc___58 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___58 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___65 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___65 gso_skb;
	struct qdisc_skb_head___58 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___58 *next_sched;
	struct sk_buff_head___65 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___65 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___408 kobj;
	struct net_device___66 *dev;
	long: 64;
	struct xdp_rxq_info___65 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___65)(struct net_device___66 *, struct sk_buff___67 *, struct net_device___66 *);

struct netdev_bpf___65 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___58 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___58 *prog;
			const struct bpf_prog_offload_ops___58 *ops;
		} verifier;
		struct {
			struct bpf_prog___58 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___65 *offmap;
		};
		struct {
			struct xdp_umem___3 *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___65 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___67 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___65 {
	int (*tls_dev_add)(struct net_device___66 *, struct sock___49 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___66 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___66 *, struct sock___49 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___65 {
	int (*ndo_init)(struct net_device___66 *);
	void (*ndo_uninit)(struct net_device___66 *);
	int (*ndo_open)(struct net_device___66 *);
	int (*ndo_stop)(struct net_device___66 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___67 *, struct net_device___66 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___67 *, struct net_device___66 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___66 *, struct sk_buff___67 *, struct net_device___66 *, select_queue_fallback_t___65);
	void (*ndo_change_rx_flags)(struct net_device___66 *, int);
	void (*ndo_set_rx_mode)(struct net_device___66 *);
	int (*ndo_set_mac_address)(struct net_device___66 *, void *);
	int (*ndo_validate_addr)(struct net_device___66 *);
	int (*ndo_do_ioctl)(struct net_device___66 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___66 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___66 *, int);
	int (*ndo_neigh_setup)(struct net_device___66 *, struct neigh_parms___48 *);
	void (*ndo_tx_timeout)(struct net_device___66 *);
	void (*ndo_get_stats64)(struct net_device___66 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___66 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___66 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___66 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___66 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___66 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___66 *);
	int (*ndo_netpoll_setup)(struct net_device___66 *, struct netpoll_info___4 *);
	void (*ndo_netpoll_cleanup)(struct net_device___66 *);
	int (*ndo_set_vf_mac)(struct net_device___66 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___66 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___66 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___66 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___66 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___66 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___66 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___66 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___66 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___66 *, int, struct sk_buff___67 *);
	int (*ndo_set_vf_guid)(struct net_device___66 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___66 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___66 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___66 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___66 *, const struct sk_buff___67 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___66 *, struct net_device___66 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___66 *, struct net_device___66 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___66 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___66 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___66 *, struct neighbour___48 *);
	void (*ndo_neigh_destroy)(struct net_device___66 *, struct neighbour___48 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___66 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___66 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___66 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___67 *, struct netlink_callback___67 *, struct net_device___66 *, struct net_device___66 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___66 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___66 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___67 *, u32, u32, struct net_device___66 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___66 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___66 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___66 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___66 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___66 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___66 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___66 *, struct net_device___66 *);
	void (*ndo_dfwd_del_station)(struct net_device___66 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___66 *);
	int (*ndo_set_tx_maxrate)(struct net_device___66 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___66 *);
	int (*ndo_change_proto_down)(struct net_device___66 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___66 *, struct sk_buff___67 *);
	void (*ndo_set_rx_headroom)(struct net_device___66 *, int);
	int (*ndo_bpf)(struct net_device___66 *, struct netdev_bpf___65 *);
	int (*ndo_xdp_xmit)(struct net_device___66 *, int, struct xdp_frame___65 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___66 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___66 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___48 {
	possible_net_t___67 net;
	struct net_device___66 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___48 *);
	void (*neigh_cleanup)(struct neighbour___48 *);
	struct neigh_table___48 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct netpoll___3;

struct netpoll_info___4 {
	refcount_t refcnt;
	struct semaphore dev_lock;
	struct sk_buff_head___65 txq;
	struct delayed_work tx_work;
	struct netpoll___3 *netpoll;
	struct callback_head rcu;
};

struct l3mdev_ops___48 {
	u32 (*l3mdev_fib_table)(const struct net_device___66 *);
	struct sk_buff___67 * (*l3mdev_l3_rcv)(struct net_device___66 *, struct sk_buff___67 *, u16);
	struct sk_buff___67 * (*l3mdev_l3_out)(struct net_device___66 *, struct sock___49 *, struct sk_buff___67 *, u16);
	struct dst_entry___48 * (*l3mdev_link_scope_lookup)(const struct net_device___66 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct ndisc_ops___28 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___66 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___66 *, struct neighbour___48 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___66 *, u8, struct neighbour___48 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___66 *, struct sk_buff___67 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___77 *, struct net_device___66 *, const struct prefix_info *, struct inet6_dev___28 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct in_ifaddr___5;

struct in_device___5 {
	struct net_device___66 *dev;
	refcount_t refcnt;
	int dead;
	struct in_ifaddr___5 *ifa_list;
	struct ip_mc_list *mc_list;
	struct ip_mc_list **mc_hash;
	int mc_count;
	spinlock_t mc_tomb_lock;
	struct ip_mc_list *mc_tomb;
	long unsigned int mr_v1_seen;
	long unsigned int mr_v2_seen;
	long unsigned int mr_maxdelay;
	long unsigned int mr_qi;
	long unsigned int mr_qri;
	unsigned char mr_qrv;
	unsigned char mr_gq_running;
	unsigned char mr_ifc_count;
	struct timer_list mr_gq_timer;
	struct timer_list mr_ifc_timer;
	struct neigh_parms___48 *arp_parms;
	struct ipv4_devconf cnf;
	struct callback_head callback_head;
};

struct ifmcaddr6___28;

struct ifacaddr6___9;

struct inet6_dev___28 {
	struct net_device___66 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___28 *mc_list;
	struct ifmcaddr6___28 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___9 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	u8 rndid[8];
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___48 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
};

struct tcf_proto___58;

struct mini_Qdisc___58 {
	struct tcf_proto___58 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___58 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___66 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___77 *, struct net_device___66 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___66 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___66 *, struct list_head *);
	size_t (*get_size)(const struct net_device___66 *);
	int (*fill_info)(struct sk_buff___67 *, const struct net_device___66 *);
	size_t (*get_xstats_size)(const struct net_device___66 *);
	int (*fill_xstats)(struct sk_buff___67 *, const struct net_device___66 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___66 *, struct net_device___66 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___66 *, const struct net_device___66 *);
	int (*fill_slave_info)(struct sk_buff___67 *, const struct net_device___66 *, const struct net_device___66 *);
	struct net___77 * (*get_link_net)(const struct net_device___66 *);
	size_t (*get_linkxstats_size)(const struct net_device___66 *, int);
	int (*fill_linkxstats)(struct sk_buff___67 *, const struct net_device___66 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___65 {
	struct list_head poll_list;
	struct sk_buff_head___65 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___65 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___58 *output_queue;
	struct Qdisc___58 **output_queue_tailp;
	struct sk_buff___67 *completion_queue;
	struct sk_buff_head___65 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___65 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___65 input_pkt_queue;
	struct napi_struct___65 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct in_ifaddr___5 {
	struct hlist_node hash;
	struct in_ifaddr___5 *ifa_next;
	struct in_device___5 *ifa_dev;
	struct callback_head callback_head;
	__be32 ifa_local;
	__be32 ifa_address;
	__be32 ifa_mask;
	__u32 ifa_rt_priority;
	__be32 ifa_broadcast;
	unsigned char ifa_scope;
	unsigned char ifa_prefixlen;
	__u32 ifa_flags;
	char ifa_label[16];
	__u32 ifa_valid_lft;
	__u32 ifa_preferred_lft;
	long unsigned int ifa_cstamp;
	long unsigned int ifa_tstamp;
};

struct netpoll___3 {
	struct net_device___66 *dev;
	char dev_name[16];
	const char *name;
	union inet_addr local_ip;
	union inet_addr remote_ip;
	bool ipv6;
	u16 local_port;
	u16 remote_port;
	u8 remote_mac[6];
	struct work_struct cleanup_work;
};

struct kernel_param_ops___348 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___348 *);
	int (*get)(char *, const struct kernel_param___348 *);
	void (*free)(void *);
};

struct kparam_array___348;

struct kernel_param___348 {
	const char *name;
	struct module___350 *mod;
	const struct kernel_param_ops___348 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___348 *arr;
	};
};

struct kparam_array___348 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___348 *ops;
	void *elem;
};

struct module_attribute___348 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___348 *, struct module_kobject___348 *, char *);
	ssize_t (*store)(struct module_attribute___348 *, struct module_kobject___348 *, const char *, size_t);
	void (*setup)(struct module___350 *, const char *);
	int (*test)(struct module___350 *);
	void (*free)(struct module___350 *);
};

struct trace_event_class___146;

struct trace_event_call___146 {
	struct list_head list;
	struct trace_event_class___146 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___13 event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___58 *prog_array;
	int (*perf_perm)(struct trace_event_call___146 *, struct perf_event___155 *);
};

struct node___225 {
	struct device___388 dev;
};

struct perf_cpu_context___155;

struct pmu___155 {
	struct list_head entry;
	struct module___350 *module;
	struct device___388 *dev;
	const struct attribute_group___385 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___155 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___155 *);
	void (*pmu_disable)(struct pmu___155 *);
	int (*event_init)(struct perf_event___155 *);
	void (*event_mapped)(struct perf_event___155 *, struct mm_struct___421 *);
	void (*event_unmapped)(struct perf_event___155 *, struct mm_struct___421 *);
	int (*add)(struct perf_event___155 *, int);
	void (*del)(struct perf_event___155 *, int);
	void (*start)(struct perf_event___155 *, int);
	void (*stop)(struct perf_event___155 *, int);
	void (*read)(struct perf_event___155 *);
	void (*start_txn)(struct pmu___155 *, unsigned int);
	int (*commit_txn)(struct pmu___155 *);
	void (*cancel_txn)(struct pmu___155 *);
	int (*event_idx)(struct perf_event___155 *);
	void (*sched_task)(struct perf_event_context___155 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___155 *);
	int (*filter_match)(struct perf_event___155 *);
	int (*check_period)(struct perf_event___155 *, u64);
};

struct perf_cpu_context___155 {
	struct perf_event_context___155 ctx;
	struct perf_event_context___155 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___155 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___155 {
	struct cgroup_subsys_state___269 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___146 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___146 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___146 *);
	struct list_head * (*get_fields)(struct trace_event_call___146 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___146 *);
};

struct trace_event_file___62;

struct trace_event_buffer___54 {
	struct ring_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___62 *trace_file;
	void *entry;
	long unsigned int flags;
	int pc;
};

struct trace_event_file___62 {
	struct list_head list;
	struct trace_event_call___146 *event_call;
	struct event_filter *filter;
	struct dentry___420 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_kfree_skb {
	struct trace_entry ent;
	void *skbaddr;
	void *location;
	short unsigned int protocol;
	char __data[0];
};

struct trace_event_raw_consume_skb {
	struct trace_entry ent;
	void *skbaddr;
	char __data[0];
};

struct trace_event_raw_skb_copy_datagram_iovec {
	struct trace_entry ent;
	const void *skbaddr;
	int len;
	char __data[0];
};

struct trace_event_data_offsets_kfree_skb {};

struct trace_event_data_offsets_consume_skb {};

struct trace_event_data_offsets_skb_copy_datagram_iovec {};

struct trace_event_raw_net_dev_start_xmit {
	struct trace_entry ent;
	u32 __data_loc_name;
	u16 queue_mapping;
	const void *skbaddr;
	bool vlan_tagged;
	u16 vlan_proto;
	u16 vlan_tci;
	u16 protocol;
	u8 ip_summed;
	unsigned int len;
	unsigned int data_len;
	int network_offset;
	bool transport_offset_valid;
	int transport_offset;
	u8 tx_flags;
	u16 gso_size;
	u16 gso_segs;
	u16 gso_type;
	char __data[0];
};

struct trace_event_raw_net_dev_xmit {
	struct trace_entry ent;
	void *skbaddr;
	unsigned int len;
	int rc;
	u32 __data_loc_name;
	char __data[0];
};

struct trace_event_raw_net_dev_xmit_timeout {
	struct trace_entry ent;
	u32 __data_loc_name;
	u32 __data_loc_driver;
	int queue_index;
	char __data[0];
};

struct trace_event_raw_net_dev_template {
	struct trace_entry ent;
	void *skbaddr;
	unsigned int len;
	u32 __data_loc_name;
	char __data[0];
};

struct trace_event_raw_net_dev_rx_verbose_template {
	struct trace_entry ent;
	u32 __data_loc_name;
	unsigned int napi_id;
	u16 queue_mapping;
	const void *skbaddr;
	bool vlan_tagged;
	u16 vlan_proto;
	u16 vlan_tci;
	u16 protocol;
	u8 ip_summed;
	u32 hash;
	bool l4_hash;
	unsigned int len;
	unsigned int data_len;
	unsigned int truesize;
	bool mac_header_valid;
	int mac_header;
	unsigned char nr_frags;
	u16 gso_size;
	u16 gso_type;
	char __data[0];
};

struct trace_event_data_offsets_net_dev_start_xmit {
	u32 name;
};

struct trace_event_data_offsets_net_dev_xmit {
	u32 name;
};

struct trace_event_data_offsets_net_dev_xmit_timeout {
	u32 name;
	u32 driver;
};

struct trace_event_data_offsets_net_dev_template {
	u32 name;
};

struct trace_event_data_offsets_net_dev_rx_verbose_template {
	u32 name;
};

struct trace_event_raw_napi_poll {
	struct trace_entry ent;
	struct napi_struct___65 *napi;
	u32 __data_loc_dev_name;
	int work;
	int budget;
	char __data[0];
};

struct trace_event_data_offsets_napi_poll {
	u32 dev_name;
};

struct bdi_writeback_congested___213 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___213 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___213 {
	struct bio___213 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___215 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___215 bip_inline_vecs[0];
};

struct bio_set___213 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___213 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___156 {
	struct mem_cgroup___156 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___156 {
	struct lruvec___421 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___156 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___156 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct gnet_dump___58 {
	spinlock_t *lock;
	struct sk_buff___67 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___58;

struct Qdisc_ops___58 {
	struct Qdisc_ops___58 *next;
	const struct Qdisc_class_ops___58 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___67 *, struct Qdisc___58 *, struct sk_buff___67 **);
	struct sk_buff___67 * (*dequeue)(struct Qdisc___58 *);
	struct sk_buff___67 * (*peek)(struct Qdisc___58 *);
	int (*init)(struct Qdisc___58 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___58 *);
	void (*destroy)(struct Qdisc___58 *);
	int (*change)(struct Qdisc___58 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___58 *);
	int (*change_tx_queue_len)(struct Qdisc___58 *, unsigned int);
	int (*dump)(struct Qdisc___58 *, struct sk_buff___67 *);
	int (*dump_stats)(struct Qdisc___58 *, struct gnet_dump___58 *);
	void (*ingress_block_set)(struct Qdisc___58 *, u32);
	void (*egress_block_set)(struct Qdisc___58 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___58 *);
	u32 (*egress_block_get)(struct Qdisc___58 *);
	struct module___350 *owner;
};

struct tcf_block___58;

struct Qdisc_class_ops___58 {
	unsigned int flags;
	struct netdev_queue___65 * (*select_queue)(struct Qdisc___58 *, struct tcmsg *);
	int (*graft)(struct Qdisc___58 *, long unsigned int, struct Qdisc___58 *, struct Qdisc___58 **, struct netlink_ext_ack *);
	struct Qdisc___58 * (*leaf)(struct Qdisc___58 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___58 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___58 *, u32);
	int (*change)(struct Qdisc___58 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___58 *, long unsigned int);
	void (*walk)(struct Qdisc___58 *, struct qdisc_walker *);
	struct tcf_block___58 * (*tcf_block)(struct Qdisc___58 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___58 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___58 *, long unsigned int);
	int (*dump)(struct Qdisc___58 *, long unsigned int, struct sk_buff___67 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___58 *, long unsigned int, struct gnet_dump___58 *);
};

struct tcf_chain___58;

struct tcf_block___58 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___77 *net;
	struct Qdisc___58 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___58 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___58;

struct tcf_proto_ops___58;

struct tcf_proto___58 {
	struct tcf_proto___58 *next;
	void *root;
	int (*classify)(struct sk_buff___67 *, const struct tcf_proto___58 *, struct tcf_result___58 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___58 *ops;
	struct tcf_chain___58 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___58 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___58 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___58 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___67 *, const struct tcf_proto___58 *, struct tcf_result___58 *);
	int (*init)(struct tcf_proto___58 *);
	void (*destroy)(struct tcf_proto___58 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___58 *, u32);
	void (*put)(struct tcf_proto___58 *, void *);
	int (*change)(struct net___77 *, struct sk_buff___67 *, struct tcf_proto___58 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___58 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___58 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___58 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___77 *, struct tcf_chain___58 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___77 *, struct tcf_proto___58 *, void *, struct sk_buff___67 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___67 *, struct net___77 *, void *);
	struct module___350 *owner;
	int flags;
};

struct tcf_chain___58 {
	struct mutex filter_chain_lock;
	struct tcf_proto___58 *filter_chain;
	struct list_head list;
	struct tcf_block___58 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___58 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___48 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___58 *prog;
};

struct bpf_redirect_info___58 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___270 *map;
	struct bpf_map___270 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___48;

struct neigh_hash_table___48;

struct neigh_table___48 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___66 *, __u32 *);
	bool (*key_eq)(const struct neighbour___48 *, const void *);
	int (*constructor)(struct neighbour___48 *);
	int (*pconstructor)(struct pneigh_entry___48 *);
	void (*pdestructor)(struct pneigh_entry___48 *);
	void (*proxy_redo)(struct sk_buff___67 *);
	char *id;
	struct neigh_parms___48 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___65 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___48 *nht;
	struct pneigh_entry___48 **phash_buckets;
};

struct neigh_ops___48 {
	int family;
	void (*solicit)(struct neighbour___48 *, struct sk_buff___67 *);
	void (*error_report)(struct neighbour___48 *, struct sk_buff___67 *);
	int (*output)(struct neighbour___48 *, struct sk_buff___67 *);
	int (*connected_output)(struct neighbour___48 *, struct sk_buff___67 *);
};

struct pneigh_entry___48 {
	struct pneigh_entry___48 *next;
	possible_net_t___67 net;
	struct net_device___66 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___48 {
	struct neighbour___48 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___48 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___48 *ctarget;
	struct net___77 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___48 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___48 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___33;

struct timewait_sock_ops___31;

struct proto___48 {
	void (*close)(struct sock___49 *, long int);
	int (*pre_connect)(struct sock___49 *, struct sockaddr *, int);
	int (*connect)(struct sock___49 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___49 *, int);
	struct sock___49 * (*accept)(struct sock___49 *, int, int *, bool);
	int (*ioctl)(struct sock___49 *, int, long unsigned int);
	int (*init)(struct sock___49 *);
	void (*destroy)(struct sock___49 *);
	void (*shutdown)(struct sock___49 *, int);
	int (*setsockopt)(struct sock___49 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___49 *, int, int, char *, int *);
	void (*keepalive)(struct sock___49 *, int);
	int (*sendmsg)(struct sock___49 *, struct msghdr___51 *, size_t);
	int (*recvmsg)(struct sock___49 *, struct msghdr___51 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___49 *, struct page___421 *, int, size_t, int);
	int (*bind)(struct sock___49 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___49 *, struct sk_buff___67 *);
	void (*release_cb)(struct sock___49 *);
	int (*hash)(struct sock___49 *);
	void (*unhash)(struct sock___49 *);
	void (*rehash)(struct sock___49 *);
	int (*get_port)(struct sock___49 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___49 *);
	bool (*stream_memory_read)(const struct sock___49 *);
	void (*enter_memory_pressure)(struct sock___49 *);
	void (*leave_memory_pressure)(struct sock___49 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___33 *rsk_prot;
	struct timewait_sock_ops___31 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___350 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___49 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct request_sock___34;

struct request_sock_ops___33 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___49 *, struct request_sock___34 *);
	void (*send_ack)(const struct sock___49 *, struct sk_buff___67 *, struct request_sock___34 *);
	void (*send_reset)(const struct sock___49 *, struct sk_buff___67 *);
	void (*destructor)(struct request_sock___34 *);
	void (*syn_ack_timeout)(const struct request_sock___34 *);
};

struct timewait_sock_ops___31 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___49 *, struct sock___49 *, void *);
	void (*twsk_destructor)(struct sock___49 *);
};

struct request_sock___34 {
	struct sock_common___48 __req_common;
	struct request_sock___34 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___33 *rsk_ops;
	struct sock___49 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct fastopen_queue___4 {
	struct request_sock___34 *rskq_rst_head;
	struct request_sock___34 *rskq_rst_tail;
	spinlock_t lock;
	int qlen;
	int max_qlen;
	struct tcp_fastopen_context___8 *ctx;
};

struct request_sock_queue___4 {
	spinlock_t rskq_lock;
	u8 rskq_defer_accept;
	u32 synflood_warned;
	atomic_t qlen;
	atomic_t young;
	struct request_sock___34 *rskq_accept_head;
	struct request_sock___34 *rskq_accept_tail;
	struct fastopen_queue___4 fastopenq;
};

struct inet_request_sock___2 {
	struct request_sock___34 req;
	u16 snd_wscale: 4;
	u16 rcv_wscale: 4;
	u16 tstamp_ok: 1;
	u16 sack_ok: 1;
	u16 wscale_ok: 1;
	u16 ecn_ok: 1;
	u16 acked: 1;
	u16 no_srccheck: 1;
	u16 smc_ok: 1;
	u32 ir_mark;
	union {
		struct ip_options_rcu *ireq_opt;
		struct {
			struct ipv6_txoptions *ipv6_opt;
			struct sk_buff___67 *pktopts;
		};
	};
};

struct inet_cork___7 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___48 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
	__u16 gso_size;
	u64 transmit_time;
};

struct inet_cork_full___7 {
	struct inet_cork___7 base;
	struct flowi fl;
};

struct ipv6_pinfo___7;

struct inet_sock___7 {
	struct sock___49 sk;
	struct ipv6_pinfo___7 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	__be16 inet_sport;
	__u16 inet_id;
	struct ip_options_rcu *inet_opt;
	int rx_dst_ifindex;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 bind_address_no_port: 1;
	__u8 defer_connect: 1;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___7 cork;
};

struct ipv6_fl_socklist___6;

struct ipv6_pinfo___7 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
			__u16 recvfragsize: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 repflow: 1;
	__u16 pmtudisc: 3;
	__u16 padding: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u16 autoflowlabel: 1;
	__u16 autoflowlabel_set: 1;
	__u8 min_hopcount;
	__u8 tclass;
	__be32 rcv_flowinfo;
	__u32 dst_cookie;
	__u32 rx_dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___6 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___67 *pktoptions;
	struct sk_buff___67 *rxpmtu;
	struct inet6_cork cork;
};

struct inet_connection_sock_af_ops___4 {
	int (*queue_xmit)(struct sock___49 *, struct sk_buff___67 *, struct flowi *);
	void (*send_check)(struct sock___49 *, struct sk_buff___67 *);
	int (*rebuild_header)(struct sock___49 *);
	void (*sk_rx_dst_set)(struct sock___49 *, const struct sk_buff___67 *);
	int (*conn_request)(struct sock___49 *, struct sk_buff___67 *);
	struct sock___49 * (*syn_recv_sock)(const struct sock___49 *, struct sk_buff___67 *, struct request_sock___34 *, struct dst_entry___48 *, struct request_sock___34 *, bool *);
	u16 net_header_len;
	u16 net_frag_header_len;
	u16 sockaddr_len;
	int (*setsockopt)(struct sock___49 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___49 *, int, int, char *, int *);
	void (*addr2sockaddr)(struct sock___49 *, struct sockaddr *);
	void (*mtu_reduced)(struct sock___49 *);
};

struct inet_bind_bucket___4;

struct tcp_ulp_ops___4;

struct inet_connection_sock___4 {
	struct inet_sock___7 icsk_inet;
	struct request_sock_queue___4 icsk_accept_queue;
	struct inet_bind_bucket___4 *icsk_bind_hash;
	long unsigned int icsk_timeout;
	struct timer_list icsk_retransmit_timer;
	struct timer_list icsk_delack_timer;
	__u32 icsk_rto;
	__u32 icsk_pmtu_cookie;
	const struct tcp_congestion_ops___8 *icsk_ca_ops;
	const struct inet_connection_sock_af_ops___4 *icsk_af_ops;
	const struct tcp_ulp_ops___4 *icsk_ulp_ops;
	void *icsk_ulp_data;
	void (*icsk_clean_acked)(struct sock___49 *, u32);
	struct hlist_node icsk_listen_portaddr_node;
	unsigned int (*icsk_sync_mss)(struct sock___49 *, u32);
	__u8 icsk_ca_state: 6;
	__u8 icsk_ca_setsockopt: 1;
	__u8 icsk_ca_dst_locked: 1;
	__u8 icsk_retransmits;
	__u8 icsk_pending;
	__u8 icsk_backoff;
	__u8 icsk_syn_retries;
	__u8 icsk_probes_out;
	__u16 icsk_ext_hdr_len;
	struct {
		__u8 pending;
		__u8 quick;
		__u8 pingpong;
		__u8 blocked;
		__u32 ato;
		long unsigned int timeout;
		__u32 lrcvtime;
		__u16 last_seg_size;
		__u16 rcv_mss;
	} icsk_ack;
	struct {
		int enabled;
		int search_high;
		int search_low;
		int probe_size;
		u32 probe_timestamp;
	} icsk_mtup;
	u32 icsk_user_timeout;
	u64 icsk_ca_priv[11];
};

struct inet_bind_bucket___4 {
	possible_net_t___67 ib_net;
	short unsigned int port;
	signed char fastreuse;
	signed char fastreuseport;
	kuid_t fastuid;
	struct in6_addr fast_v6_rcv_saddr;
	__be32 fast_rcv_saddr;
	short unsigned int fast_sk_family;
	bool fast_ipv6_only;
	struct hlist_node node;
	struct hlist_head owners;
};

struct tcp_ulp_ops___4 {
	struct list_head list;
	int (*init)(struct sock___49 *);
	void (*release)(struct sock___49 *);
	char name[16];
	struct module___350 *owner;
};

enum tcp_ca_state {
	TCP_CA_Open = 0,
	TCP_CA_Disorder = 1,
	TCP_CA_CWR = 2,
	TCP_CA_Recovery = 3,
	TCP_CA_Loss = 4,
};

struct tcp_sock_af_ops___4;

struct tcp_fastopen_request___4;

struct tcp_sock___4 {
	struct inet_connection_sock___4 inet_conn;
	u16 tcp_header_len;
	u16 gso_segs;
	__be32 pred_flags;
	u64 bytes_received;
	u32 segs_in;
	u32 data_segs_in;
	u32 rcv_nxt;
	u32 copied_seq;
	u32 rcv_wup;
	u32 snd_nxt;
	u32 segs_out;
	u32 data_segs_out;
	u64 bytes_acked;
	u32 snd_una;
	u32 snd_sml;
	u32 rcv_tstamp;
	u32 lsndtime;
	u32 last_oow_ack_time;
	u32 compressed_ack_rcv_nxt;
	u32 tsoffset;
	struct list_head tsq_node;
	struct list_head tsorted_sent_queue;
	u32 snd_wl1;
	u32 snd_wnd;
	u32 max_window;
	u32 mss_cache;
	u32 window_clamp;
	u32 rcv_ssthresh;
	struct tcp_rack rack;
	u16 advmss;
	u8 compressed_ack;
	u32 chrono_start;
	u32 chrono_stat[3];
	u8 chrono_type: 2;
	u8 rate_app_limited: 1;
	u8 fastopen_connect: 1;
	u8 fastopen_no_cookie: 1;
	u8 is_sack_reneg: 1;
	u8 unused: 2;
	u8 nonagle: 4;
	u8 thin_lto: 1;
	u8 recvmsg_inq: 1;
	u8 repair: 1;
	u8 frto: 1;
	u8 repair_queue;
	u8 syn_data: 1;
	u8 syn_fastopen: 1;
	u8 syn_fastopen_exp: 1;
	u8 syn_fastopen_ch: 1;
	u8 syn_data_acked: 1;
	u8 save_syn: 1;
	u8 is_cwnd_limited: 1;
	u8 syn_smc: 1;
	u32 tlp_high_seq;
	u64 tcp_mstamp;
	u32 srtt_us;
	u32 mdev_us;
	u32 mdev_max_us;
	u32 rttvar_us;
	u32 rtt_seq;
	struct minmax rtt_min;
	u32 packets_out;
	u32 retrans_out;
	u32 max_packets_out;
	u32 max_packets_seq;
	u16 urg_data;
	u8 ecn_flags;
	u8 keepalive_probes;
	u32 reordering;
	u32 snd_up;
	struct tcp_options_received rx_opt;
	u32 snd_ssthresh;
	u32 snd_cwnd;
	u32 snd_cwnd_cnt;
	u32 snd_cwnd_clamp;
	u32 snd_cwnd_used;
	u32 snd_cwnd_stamp;
	u32 prior_cwnd;
	u32 prr_delivered;
	u32 prr_out;
	u32 delivered;
	u32 delivered_ce;
	u32 lost;
	u32 app_limited;
	u64 first_tx_mstamp;
	u64 delivered_mstamp;
	u32 rate_delivered;
	u32 rate_interval_us;
	u32 rcv_wnd;
	u32 write_seq;
	u32 notsent_lowat;
	u32 pushed_seq;
	u32 lost_out;
	u32 sacked_out;
	struct hrtimer pacing_timer;
	struct hrtimer compressed_ack_timer;
	struct sk_buff___67 *lost_skb_hint;
	struct sk_buff___67 *retransmit_skb_hint;
	struct rb_root out_of_order_queue;
	struct sk_buff___67 *ooo_last_skb;
	struct tcp_sack_block duplicate_sack[1];
	struct tcp_sack_block selective_acks[4];
	struct tcp_sack_block recv_sack_cache[4];
	struct sk_buff___67 *highest_sack;
	int lost_cnt_hint;
	u32 prior_ssthresh;
	u32 high_seq;
	u32 retrans_stamp;
	u32 undo_marker;
	int undo_retrans;
	u32 total_retrans;
	u32 urg_seq;
	unsigned int keepalive_time;
	unsigned int keepalive_intvl;
	int linger2;
	u8 bpf_sock_ops_cb_flags;
	struct {
		u32 rtt_us;
		u32 seq;
		u64 time;
	} rcv_rtt_est;
	struct {
		u32 space;
		u32 seq;
		u64 time;
	} rcvq_space;
	struct {
		u32 probe_seq_start;
		u32 probe_seq_end;
	} mtu_probe;
	u32 mtu_info;
	const struct tcp_sock_af_ops___4 *af_specific;
	struct tcp_md5sig_info *md5sig_info;
	struct tcp_fastopen_request___4 *fastopen_req;
	struct request_sock___34 *fastopen_rsk;
	u32 *saved_syn;
};

struct tcp_sock_af_ops___4 {
	struct tcp_md5sig_key * (*md5_lookup)(const struct sock___49 *, const struct sock___49 *);
	int (*calc_md5_hash)(char *, const struct tcp_md5sig_key *, const struct sock___49 *, const struct sk_buff___67 *);
	int (*md5_parse)(struct sock___49 *, int, char *, int);
};

struct tcp_fastopen_request___4 {
	struct tcp_fastopen_cookie cookie;
	struct msghdr___51 *data;
	size_t size;
	int copied;
};

struct ip6_flowlabel___6;

struct ipv6_fl_socklist___6 {
	struct ipv6_fl_socklist___6 *next;
	struct ip6_flowlabel___6 *fl;
	struct callback_head rcu;
};

struct ifmcaddr6___28 {
	struct in6_addr mca_addr;
	struct inet6_dev___28 *idev;
	struct ifmcaddr6___28 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___9 {
	struct in6_addr aca_addr;
	struct fib6_info___9 *aca_rt;
	struct ifacaddr6___9 *aca_next;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct ip6_ra_chain___28 {
	struct ip6_ra_chain___28 *next;
	struct sock___49 *sk;
	int sel;
	void (*destructor)(struct sock___49 *);
};

struct ip6_flowlabel___6 {
	struct ip6_flowlabel___6 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___238 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___77 *fl_net;
};

struct trace_event_raw_sock_rcvqueue_full {
	struct trace_entry ent;
	int rmem_alloc;
	unsigned int truesize;
	int sk_rcvbuf;
	char __data[0];
};

struct trace_event_raw_sock_exceed_buf_limit {
	struct trace_entry ent;
	char name[32];
	long int *sysctl_mem;
	long int allocated;
	int sysctl_rmem;
	int rmem_alloc;
	char __data[0];
};

struct trace_event_raw_inet_sock_set_state {
	struct trace_entry ent;
	const void *skaddr;
	int oldstate;
	int newstate;
	__u16 sport;
	__u16 dport;
	__u16 family;
	__u8 protocol;
	__u8 saddr[4];
	__u8 daddr[4];
	__u8 saddr_v6[16];
	__u8 daddr_v6[16];
	char __data[0];
};

struct trace_event_data_offsets_sock_rcvqueue_full {};

struct trace_event_data_offsets_sock_exceed_buf_limit {};

struct trace_event_data_offsets_inet_sock_set_state {};

struct trace_event_raw_udp_fail_queue_rcv_skb {
	struct trace_entry ent;
	int rc;
	__u16 lport;
	char __data[0];
};

struct trace_event_data_offsets_udp_fail_queue_rcv_skb {};

struct rtable___5;

struct fib_nh_exception___2 {
	struct fib_nh_exception___2 *fnhe_next;
	int fnhe_genid;
	__be32 fnhe_daddr;
	u32 fnhe_pmtu;
	bool fnhe_mtu_locked;
	__be32 fnhe_gw;
	long unsigned int fnhe_expires;
	struct rtable___5 *fnhe_rth_input;
	struct rtable___5 *fnhe_rth_output;
	long unsigned int fnhe_stamp;
	struct callback_head rcu;
};

struct rtable___5 {
	struct dst_entry___48 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	__be32 rt_gateway;
	u32 rt_mtu_locked: 1;
	u32 rt_pmtu: 31;
	struct list_head rt_uncached;
	struct uncached_list *rt_uncached_list;
};

struct fnhe_hash_bucket___2 {
	struct fib_nh_exception___2 *chain;
};

struct fib_info___2;

struct fib_nh___2 {
	struct net_device___66 *nh_dev;
	struct hlist_node nh_hash;
	struct fib_info___2 *nh_parent;
	unsigned int nh_flags;
	unsigned char nh_scope;
	int nh_weight;
	atomic_t nh_upper_bound;
	__u32 nh_tclassid;
	int nh_oif;
	__be32 nh_gw;
	__be32 nh_saddr;
	int nh_saddr_genid;
	struct rtable___5 **nh_pcpu_rth_output;
	struct rtable___5 *nh_rth_input;
	struct fnhe_hash_bucket___2 *nh_exceptions;
	struct lwtunnel_state *nh_lwtstate;
};

struct fib_info___2 {
	struct hlist_node fib_hash;
	struct hlist_node fib_lhash;
	struct net___77 *fib_net;
	int fib_treeref;
	refcount_t fib_clntref;
	unsigned int fib_flags;
	unsigned char fib_dead;
	unsigned char fib_protocol;
	unsigned char fib_scope;
	unsigned char fib_type;
	__be32 fib_prefsrc;
	u32 fib_tb_id;
	u32 fib_priority;
	struct dst_metrics *fib_metrics;
	int fib_nhs;
	struct callback_head rcu;
	struct fib_nh___2 fib_nh[0];
};

struct trace_event_raw_tcp_event_sk_skb {
	struct trace_entry ent;
	const void *skbaddr;
	const void *skaddr;
	__u16 sport;
	__u16 dport;
	__u8 saddr[4];
	__u8 daddr[4];
	__u8 saddr_v6[16];
	__u8 daddr_v6[16];
	char __data[0];
};

struct trace_event_raw_tcp_event_sk {
	struct trace_entry ent;
	const void *skaddr;
	__u16 sport;
	__u16 dport;
	__u8 saddr[4];
	__u8 daddr[4];
	__u8 saddr_v6[16];
	__u8 daddr_v6[16];
	__u64 sock_cookie;
	char __data[0];
};

struct trace_event_raw_tcp_retransmit_synack {
	struct trace_entry ent;
	const void *skaddr;
	const void *req;
	__u16 sport;
	__u16 dport;
	__u8 saddr[4];
	__u8 daddr[4];
	__u8 saddr_v6[16];
	__u8 daddr_v6[16];
	char __data[0];
};

struct trace_event_raw_tcp_probe {
	struct trace_entry ent;
	__u8 saddr[28];
	__u8 daddr[28];
	__u16 sport;
	__u16 dport;
	__u32 mark;
	__u16 data_len;
	__u32 snd_nxt;
	__u32 snd_una;
	__u32 snd_cwnd;
	__u32 ssthresh;
	__u32 snd_wnd;
	__u32 srtt;
	__u32 rcv_wnd;
	__u64 sock_cookie;
	char __data[0];
};

struct trace_event_data_offsets_tcp_event_sk_skb {};

struct trace_event_data_offsets_tcp_event_sk {};

struct trace_event_data_offsets_tcp_retransmit_synack {};

struct trace_event_data_offsets_tcp_probe {};

struct trace_event_raw_fib_table_lookup {
	struct trace_entry ent;
	u32 tb_id;
	int err;
	int oif;
	int iif;
	__u8 tos;
	__u8 scope;
	__u8 flags;
	__u8 src[4];
	__u8 dst[4];
	__u8 gw[4];
	__u8 saddr[4];
	u16 sport;
	u16 dport;
	u8 proto;
	u32 __data_loc_name;
	char __data[0];
};

struct trace_event_data_offsets_fib_table_lookup {
	u32 name;
};

struct trace_event_raw_qdisc_dequeue {
	struct trace_entry ent;
	struct Qdisc___58 *qdisc;
	const struct netdev_queue___65 *txq;
	int packets;
	void *skbaddr;
	int ifindex;
	u32 handle;
	u32 parent;
	long unsigned int txq_state;
	char __data[0];
};

struct trace_event_data_offsets_qdisc_dequeue {};

struct br_mcast_stats {
	__u64 igmp_v1queries[2];
	__u64 igmp_v2queries[2];
	__u64 igmp_v3queries[2];
	__u64 igmp_leaves[2];
	__u64 igmp_v1reports[2];
	__u64 igmp_v2reports[2];
	__u64 igmp_v3reports[2];
	__u64 igmp_parse_errors;
	__u64 mld_v1queries[2];
	__u64 mld_v2queries[2];
	__u64 mld_leaves[2];
	__u64 mld_v1reports[2];
	__u64 mld_v2reports[2];
	__u64 mld_parse_errors;
	__u64 mcast_bytes[2];
	__u64 mcast_packets[2];
};

struct br_ip {
	union {
		__be32 ip4;
		struct in6_addr ip6;
	} u;
	__be16 proto;
	__u16 vid;
};

typedef int br_should_route_hook_t___3(struct sk_buff___67 *);

struct bridge_id {
	unsigned char prio[2];
	unsigned char addr[6];
};

typedef struct bridge_id bridge_id;

struct mac_addr {
	unsigned char addr[6];
};

typedef struct mac_addr mac_addr;

typedef __u16 port_id;

struct bridge_mcast_own_query {
	struct timer_list timer;
	u32 startup_sent;
};

struct bridge_mcast_other_query {
	struct timer_list timer;
	long unsigned int delay_time;
};

struct net_bridge_port;

struct bridge_mcast_querier {
	struct br_ip addr;
	struct net_bridge_port *port;
};

struct net_bridge;

struct net_bridge_vlan_group;

struct bridge_mcast_stats;

struct net_bridge_port {
	struct net_bridge *br;
	struct net_device___66 *dev;
	struct list_head list;
	long unsigned int flags;
	struct net_bridge_vlan_group *vlgrp;
	u8 priority;
	u8 state;
	u16 port_no;
	unsigned char topology_change_ack;
	unsigned char config_pending;
	port_id port_id;
	port_id designated_port;
	bridge_id designated_root;
	bridge_id designated_bridge;
	u32 path_cost;
	u32 designated_cost;
	long unsigned int designated_age;
	struct timer_list forward_delay_timer;
	struct timer_list hold_timer;
	struct timer_list message_age_timer;
	struct kobject___408 kobj;
	struct callback_head rcu;
	struct bridge_mcast_own_query ip4_own_query;
	struct bridge_mcast_own_query ip6_own_query;
	unsigned char multicast_router;
	struct bridge_mcast_stats *mcast_stats;
	struct timer_list multicast_router_timer;
	struct hlist_head mglist;
	struct hlist_node rlist;
	char sysfs_name[16];
	struct netpoll___3 *np;
	int offload_fwd_mark;
	u16 group_fwd_mask;
};

struct bridge_mcast_stats {
	struct br_mcast_stats mstats;
	struct u64_stats_sync syncp;
};

struct net_bridge_mdb_htable;

struct net_bridge {
	spinlock_t lock;
	spinlock_t hash_lock;
	struct list_head port_list;
	struct net_device___66 *dev;
	struct pcpu_sw_netstats *stats;
	long unsigned int options;
	__be16 vlan_proto;
	u16 default_pvid;
	struct net_bridge_vlan_group *vlgrp;
	struct rhashtable fdb_hash_tbl;
	union {
		struct rtable___5 fake_rtable;
		struct rt6_info___9 fake_rt6_info;
	};
	u16 group_fwd_mask;
	u16 group_fwd_mask_required;
	bridge_id designated_root;
	bridge_id bridge_id;
	unsigned char topology_change;
	unsigned char topology_change_detected;
	u16 root_port;
	long unsigned int max_age;
	long unsigned int hello_time;
	long unsigned int forward_delay;
	long unsigned int ageing_time;
	long unsigned int bridge_max_age;
	long unsigned int bridge_hello_time;
	long unsigned int bridge_forward_delay;
	long unsigned int bridge_ageing_time;
	u32 root_path_cost;
	u8 group_addr[6];
	enum {
		BR_NO_STP = 0,
		BR_KERNEL_STP = 1,
		BR_USER_STP = 2,
	} stp_enabled;
	u32 hash_elasticity;
	u32 hash_max;
	u32 multicast_last_member_count;
	u32 multicast_startup_query_count;
	u8 multicast_igmp_version;
	u8 multicast_router;
	u8 multicast_mld_version;
	spinlock_t multicast_lock;
	long unsigned int multicast_last_member_interval;
	long unsigned int multicast_membership_interval;
	long unsigned int multicast_querier_interval;
	long unsigned int multicast_query_interval;
	long unsigned int multicast_query_response_interval;
	long unsigned int multicast_startup_query_interval;
	struct net_bridge_mdb_htable *mdb;
	struct hlist_head router_list;
	struct timer_list multicast_router_timer;
	struct bridge_mcast_other_query ip4_other_query;
	struct bridge_mcast_own_query ip4_own_query;
	struct bridge_mcast_querier ip4_querier;
	struct bridge_mcast_stats *mcast_stats;
	struct bridge_mcast_other_query ip6_other_query;
	struct bridge_mcast_own_query ip6_own_query;
	struct bridge_mcast_querier ip6_querier;
	struct timer_list hello_timer;
	struct timer_list tcn_timer;
	struct timer_list topology_change_timer;
	struct delayed_work gc_work;
	struct kobject___408 *ifobj;
	u32 auto_cnt;
	int offload_fwd_mark;
	struct hlist_head fdb_list;
};

struct net_bridge_vlan_group {
	struct rhashtable vlan_hash;
	struct rhashtable tunnel_hash;
	struct list_head vlan_list;
	u16 num_vlans;
	u16 pvid;
};

struct net_bridge_fdb_key {
	mac_addr addr;
	u16 vlan_id;
};

struct net_bridge_fdb_entry {
	struct rhash_head rhnode;
	struct net_bridge_port *dst;
	struct net_bridge_fdb_key key;
	struct hlist_node fdb_node;
	unsigned char is_local: 1;
	unsigned char is_static: 1;
	unsigned char added_by_user: 1;
	unsigned char added_by_external_learn: 1;
	unsigned char offloaded: 1;
	long: 59;
	long: 64;
	long: 64;
	long unsigned int updated;
	long unsigned int used;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_bridge_mdb_htable {
	struct hlist_head *mhash;
	struct callback_head rcu;
	struct net_bridge_mdb_htable *old;
	u32 size;
	u32 max;
	u32 secret;
	u32 ver;
};

struct nf_br_ops {
	int (*br_dev_xmit_hook)(struct sk_buff___67 *);
};

struct trace_event_raw_br_fdb_add {
	struct trace_entry ent;
	u8 ndm_flags;
	u32 __data_loc_dev;
	unsigned char addr[6];
	u16 vid;
	u16 nlh_flags;
	char __data[0];
};

struct trace_event_raw_br_fdb_external_learn_add {
	struct trace_entry ent;
	u32 __data_loc_br_dev;
	u32 __data_loc_dev;
	unsigned char addr[6];
	u16 vid;
	char __data[0];
};

struct trace_event_raw_fdb_delete {
	struct trace_entry ent;
	u32 __data_loc_br_dev;
	u32 __data_loc_dev;
	unsigned char addr[6];
	u16 vid;
	char __data[0];
};

struct trace_event_raw_br_fdb_update {
	struct trace_entry ent;
	u32 __data_loc_br_dev;
	u32 __data_loc_dev;
	unsigned char addr[6];
	u16 vid;
	bool added_by_user;
	char __data[0];
};

struct trace_event_data_offsets_br_fdb_add {
	u32 dev;
};

struct trace_event_data_offsets_br_fdb_external_learn_add {
	u32 br_dev;
	u32 dev;
};

struct trace_event_data_offsets_fdb_delete {
	u32 br_dev;
	u32 dev;
};

struct trace_event_data_offsets_br_fdb_update {
	u32 br_dev;
	u32 dev;
};

struct module___351;

struct file___421;

struct kiocb___421;

struct iov_iter___188;

struct vm_area_struct___422;

struct inode___421;

struct file_lock___421;

struct page___422;

struct pipe_inode_info___102;

struct seq_file___360;

struct file_operations___421 {
	struct module___351 *owner;
	loff_t (*llseek)(struct file___421 *, loff_t, int);
	ssize_t (*read)(struct file___421 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___421 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___421 *, struct iov_iter___188 *);
	ssize_t (*write_iter)(struct kiocb___421 *, struct iov_iter___188 *);
	int (*iopoll)(struct kiocb___421 *, bool);
	int (*iterate)(struct file___421 *, struct dir_context *);
	int (*iterate_shared)(struct file___421 *, struct dir_context *);
	__poll_t (*poll)(struct file___421 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___421 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___421 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___421 *, struct vm_area_struct___422 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___421 *, struct file___421 *);
	int (*flush)(struct file___421 *, fl_owner_t);
	int (*release)(struct inode___421 *, struct file___421 *);
	int (*fsync)(struct file___421 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___421 *, int);
	int (*lock)(struct file___421 *, int, struct file_lock___421 *);
	ssize_t (*sendpage)(struct file___421 *, struct page___422 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___421 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___421 *, int, struct file_lock___421 *);
	ssize_t (*splice_write)(struct pipe_inode_info___102 *, struct file___421 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___421 *, loff_t *, struct pipe_inode_info___102 *, size_t, unsigned int);
	int (*setlease)(struct file___421 *, long int, struct file_lock___421 **, void **);
	long int (*fallocate)(struct file___421 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___360 *, struct file___421 *);
	ssize_t (*copy_file_range)(struct file___421 *, loff_t, struct file___421 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___421 *, loff_t, struct file___421 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___421 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___422 {
	u64 seqnum;
	struct vm_area_struct___422 *vmas[4];
};

struct page_frag___422 {
	struct page___422 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___422;

struct pid___239;

struct cred___389;

struct nsproxy___316;

struct signal_struct___296;

struct css_set___270;

struct vm_struct___325;

struct task_struct___423 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___423 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___422 *mm;
	struct mm_struct___422 *active_mm;
	struct vmacache___422 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___423 *real_parent;
	struct task_struct___423 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___423 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___239 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___239 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___239 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___389 *ptracer_cred;
	const struct cred___389 *real_cred;
	const struct cred___389 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___316 *nsproxy;
	struct signal_struct___296 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___423 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___270 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___102 *splice_pipe;
	struct page_frag___422 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___423 *oom_reaper_list;
	struct vm_struct___325 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___155 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct secondary_data___423 {
	void *stack;
	struct task_struct___423 *task;
	long int status;
};

struct rw_semaphore___423 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___423 *owner;
};

struct key___389;

struct ucounts___286;

struct user_namespace___286 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___286 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___29 ns;
	long unsigned int flags;
	struct key___389 *persistent_keyring_register;
	struct rw_semaphore___423 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___286 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___422 *pgtable_t___422;

struct address_space___421;

struct dev_pagemap___409;

struct page___422 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___421 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___422 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___422 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___422 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___409 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___422;

struct lruvec___422 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___422 *pgdat;
};

struct zone___422 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___422 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___422 {
	struct zone___422 *zone;
	int zone_idx;
};

struct zonelist___422 {
	struct zoneref___422 _zonerefs[25];
};

struct pglist_data___422 {
	struct zone___422 node_zones[3];
	struct zonelist___422 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___423 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___423 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___422 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___422 {
	struct rw_semaphore___423 rwsem;
	struct notifier_block *head;
};

struct pid_namespace___239;

struct upid___239 {
	int nr;
	struct pid_namespace___239 *ns;
};

struct dentry___421;

struct pid_namespace___239 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___423 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___239 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___421 *proc_self;
	struct dentry___421 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___286 *user_ns;
	struct ucounts___286 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___29 ns;
};

struct pid___239 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___239 numbers[1];
};

struct user_struct___389 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___389 *uid_keyring;
	struct key___389 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___409;

struct vm_area_struct___422 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___422 *vm_next;
	struct vm_area_struct___422 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___422 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___409 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___421 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___422;

struct mm_struct___422 {
	struct {
		struct vm_area_struct___422 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___421 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___423 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___422 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___423 *owner;
		struct user_namespace___286 *user_ns;
		struct file___421 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___422 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___389 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___389 *session_keyring;
	struct key___389 *process_keyring;
	struct key___389 *thread_keyring;
	struct key___389 *request_key_auth;
	void *security;
	struct user_struct___389 *user;
	struct user_namespace___286 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___78;

struct cgroup_namespace___270;

struct nsproxy___316 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___239 *pid_ns_for_children;
	struct net___78 *net_ns;
	struct cgroup_namespace___270 *cgroup_ns;
};

struct signal_struct___296 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___423 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___423 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___239 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___239 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___422 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___239 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___270;

struct cgroup___270;

struct css_set___270 {
	struct cgroup_subsys_state___270 *subsys[13];
	refcount_t refcount;
	struct css_set___270 *dom_cset;
	struct cgroup___270 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___270 *mg_src_cgrp;
	struct cgroup___270 *mg_dst_cgrp;
	struct css_set___270 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___421;

struct pipe_buffer___102;

struct pipe_inode_info___102 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___422 *tmp_page;
	struct fasync_struct___421 *fasync_readers;
	struct fasync_struct___421 *fasync_writers;
	struct pipe_buffer___102 *bufs;
	struct user_struct___389 *user;
};

struct vm_struct___325 {
	struct vm_struct___325 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___422 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___308 {
	struct task_struct___423 task;
	long unsigned int stack[8192];
};

struct address_space_operations___421;

struct address_space___421 {
	struct inode___421 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___423 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___421 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___409)(struct vm_area_struct___422 *, long unsigned int, const struct page___422 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___409)(struct page___422 *, void *);

struct device___389;

struct dev_pagemap___409 {
	dev_page_fault_t___409 page_fault;
	dev_page_free_t___409 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___389 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___422 {
	struct vfsmount *mnt;
	struct dentry___421 *dentry;
};

struct fown_struct___239 {
	rwlock_t lock;
	struct pid___239 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___421 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___422 f_path;
	struct inode___421 *f_inode;
	const struct file_operations___421 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___239 f_owner;
	const struct cred___389 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___421 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___409;

struct vm_operations_struct___409 {
	void (*open)(struct vm_area_struct___422 *);
	void (*close)(struct vm_area_struct___422 *);
	int (*split)(struct vm_area_struct___422 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___422 *);
	vm_fault_t (*fault)(struct vm_fault___409 *);
	vm_fault_t (*huge_fault)(struct vm_fault___409 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___409 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___422 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___409 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___409 *);
	int (*access)(struct vm_area_struct___422 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___422 *);
	int (*set_policy)(struct vm_area_struct___422 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___422 *, long unsigned int);
	struct page___422 * (*find_special_page)(struct vm_area_struct___422 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___422 {
	struct task_struct___423 *task;
	struct core_thread___422 *next;
};

struct core_state___422 {
	atomic_t nr_threads;
	struct core_thread___422 dumper;
	struct completion startup;
};

struct vm_fault___409 {
	struct vm_area_struct___422 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___422 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___422 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___422 prealloc_pte;
};

struct kset___408;

struct kobj_type___408;

struct kernfs_node___416;

struct kobject___409 {
	const char *name;
	struct list_head entry;
	struct kobject___409 *parent;
	struct kset___408 *kset;
	struct kobj_type___408 *ktype;
	struct kernfs_node___416 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___349 {
	struct kobject___409 kobj;
	struct module___351 *mod;
	struct kobject___409 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___349 {
	struct module___351 *mod;
	struct latch_tree_node node;
};

struct module_layout___349 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___349 mtn;
};

struct module_attribute___349;

struct kernel_param___349;

struct module___351 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___349 mkobj;
	struct module_attribute___349 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___409 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___349 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___349 core_layout;
	struct module_layout___349 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide38;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide39;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct iov_iter___188 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___3 *bvec;
		struct pipe_inode_info___102 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct kiocb___421 {
	struct file___421 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___421 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dentry_operations___421;

struct super_block___421;

struct dentry___421 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___421 *d_parent;
	struct qstr d_name;
	struct inode___421 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___421 *d_op;
	struct super_block___421 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___421;

struct block_device___421;

struct inode___421 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___421 *i_op;
	struct super_block___421 *i_sb;
	struct address_space___421 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___423 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___421 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___421 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___102 *i_pipe;
		struct block_device___421 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___421 {
	int (*d_revalidate)(struct dentry___421 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___421 *, unsigned int);
	int (*d_hash)(const struct dentry___421 *, struct qstr *);
	int (*d_compare)(const struct dentry___421 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___421 *);
	int (*d_init)(struct dentry___421 *);
	void (*d_release)(struct dentry___421 *);
	void (*d_prune)(struct dentry___421 *);
	void (*d_iput)(struct dentry___421 *, struct inode___421 *);
	char * (*d_dname)(struct dentry___421 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___422 *);
	int (*d_manage)(const struct path___422 *, bool);
	struct dentry___421 * (*d_real)(struct dentry___421 *, const struct inode___421 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___421;

struct mem_dqinfo___421 {
	struct quota_format_type___421 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___421;

struct quota_info___421 {
	unsigned int flags;
	struct rw_semaphore___423 dqio_sem;
	struct inode___421 *files[3];
	struct mem_dqinfo___421 info[3];
	const struct quota_format_ops___421 *ops[3];
};

struct rcuwait___421 {
	struct task_struct___423 *task;
};

struct percpu_rw_semaphore___421 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___423 rw_sem;
	struct rcuwait___421 writer;
	int readers_block;
};

struct sb_writers___421 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___421 rw_sem[3];
};

struct file_system_type___421;

struct super_operations___421;

struct dquot_operations___421;

struct quotactl_ops___421;

struct super_block___421 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___421 *s_type;
	const struct super_operations___421 *s_op;
	const struct dquot_operations___421 *dq_op;
	const struct quotactl_ops___421 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___421 *s_root;
	struct rw_semaphore___423 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___421 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___421 s_dquot;
	struct sb_writers___421 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___421 *s_d_op;
	int cleancache_poolid;
	struct shrinker___156 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___286 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct iattr___421 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___421 *ia_file;
};

struct dquot___421 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___421 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___421 {
	int qf_fmt_id;
	const struct quota_format_ops___421 *qf_ops;
	struct module___351 *qf_owner;
	struct quota_format_type___421 *qf_next;
};

struct quota_format_ops___421 {
	int (*check_quota_file)(struct super_block___421 *, int);
	int (*read_file_info)(struct super_block___421 *, int);
	int (*write_file_info)(struct super_block___421 *, int);
	int (*free_file_info)(struct super_block___421 *, int);
	int (*read_dqblk)(struct dquot___421 *);
	int (*commit_dqblk)(struct dquot___421 *);
	int (*release_dqblk)(struct dquot___421 *);
	int (*get_next_id)(struct super_block___421 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___421 {
	int (*write_dquot)(struct dquot___421 *);
	struct dquot___421 * (*alloc_dquot)(struct super_block___421 *, int);
	void (*destroy_dquot)(struct dquot___421 *);
	int (*acquire_dquot)(struct dquot___421 *);
	int (*release_dquot)(struct dquot___421 *);
	int (*mark_dirty)(struct dquot___421 *);
	int (*write_info)(struct super_block___421 *, int);
	qsize_t * (*get_reserved_space)(struct inode___421 *);
	int (*get_projid)(struct inode___421 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___421 *, qsize_t *);
	int (*get_next_id)(struct super_block___421 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___421 {
	int (*quota_on)(struct super_block___421 *, int, int, const struct path___422 *);
	int (*quota_off)(struct super_block___421 *, int);
	int (*quota_enable)(struct super_block___421 *, unsigned int);
	int (*quota_disable)(struct super_block___421 *, unsigned int);
	int (*quota_sync)(struct super_block___421 *, int);
	int (*set_info)(struct super_block___421 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___421 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___421 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___421 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___421 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___421 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___421 {
	int (*writepage)(struct page___422 *, struct writeback_control___3 *);
	int (*readpage)(struct file___421 *, struct page___422 *);
	int (*writepages)(struct address_space___421 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___422 *);
	int (*readpages)(struct file___421 *, struct address_space___421 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___421 *, struct address_space___421 *, loff_t, unsigned int, unsigned int, struct page___422 **, void **);
	int (*write_end)(struct file___421 *, struct address_space___421 *, loff_t, unsigned int, unsigned int, struct page___422 *, void *);
	sector_t (*bmap)(struct address_space___421 *, sector_t);
	void (*invalidatepage)(struct page___422 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___422 *, gfp_t);
	void (*freepage)(struct page___422 *);
	ssize_t (*direct_IO)(struct kiocb___421 *, struct iov_iter___188 *);
	int (*migratepage)(struct address_space___421 *, struct page___422 *, struct page___422 *, enum migrate_mode);
	bool (*isolate_page)(struct page___422 *, isolate_mode_t);
	void (*putback_page)(struct page___422 *);
	int (*launder_page)(struct page___422 *);
	int (*is_partially_uptodate)(struct page___422 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___422 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___421 *, struct page___422 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___421 *, sector_t *);
	void (*swap_deactivate)(struct file___421 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___421 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___421 *bd_inode;
	struct super_block___421 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___421 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___421 {
	struct dentry___421 * (*lookup)(struct inode___421 *, struct dentry___421 *, unsigned int);
	const char * (*get_link)(struct dentry___421 *, struct inode___421 *, struct delayed_call *);
	int (*permission)(struct inode___421 *, int);
	struct posix_acl * (*get_acl)(struct inode___421 *, int);
	int (*readlink)(struct dentry___421 *, char *, int);
	int (*create)(struct inode___421 *, struct dentry___421 *, umode_t, bool);
	int (*link)(struct dentry___421 *, struct inode___421 *, struct dentry___421 *);
	int (*unlink)(struct inode___421 *, struct dentry___421 *);
	int (*symlink)(struct inode___421 *, struct dentry___421 *, const char *);
	int (*mkdir)(struct inode___421 *, struct dentry___421 *, umode_t);
	int (*rmdir)(struct inode___421 *, struct dentry___421 *);
	int (*mknod)(struct inode___421 *, struct dentry___421 *, umode_t, dev_t);
	int (*rename)(struct inode___421 *, struct dentry___421 *, struct inode___421 *, struct dentry___421 *, unsigned int);
	int (*setattr)(struct dentry___421 *, struct iattr___421 *);
	int (*getattr)(const struct path___422 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___421 *, char *, size_t);
	int (*fiemap)(struct inode___421 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___421 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___421 *, struct dentry___421 *, struct file___421 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___421 *, struct dentry___421 *, umode_t);
	int (*set_acl)(struct inode___421 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___421 {
	void (*fl_copy_lock)(struct file_lock___421 *, struct file_lock___421 *);
	void (*fl_release_private)(struct file_lock___421 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___421;

struct file_lock___421 {
	struct file_lock___421 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___421 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___421 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___421 *fl_ops;
	const struct lock_manager_operations___421 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___421 {
	int (*lm_compare_owner)(struct file_lock___421 *, struct file_lock___421 *);
	long unsigned int (*lm_owner_key)(struct file_lock___421 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___421 *);
	int (*lm_grant)(struct file_lock___421 *, int);
	bool (*lm_break)(struct file_lock___421 *);
	int (*lm_change)(struct file_lock___421 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___421 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___421 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___421 *fa_next;
	struct file___421 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___421 {
	const char *name;
	int fs_flags;
	struct dentry___421 * (*mount)(struct file_system_type___421 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___421 *);
	struct module___351 *owner;
	struct file_system_type___421 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___421 {
	struct inode___421 * (*alloc_inode)(struct super_block___421 *);
	void (*destroy_inode)(struct inode___421 *);
	void (*dirty_inode)(struct inode___421 *, int);
	int (*write_inode)(struct inode___421 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___421 *);
	void (*evict_inode)(struct inode___421 *);
	void (*put_super)(struct super_block___421 *);
	int (*sync_fs)(struct super_block___421 *, int);
	int (*freeze_super)(struct super_block___421 *);
	int (*freeze_fs)(struct super_block___421 *);
	int (*thaw_super)(struct super_block___421 *);
	int (*unfreeze_fs)(struct super_block___421 *);
	int (*statfs)(struct dentry___421 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___421 *, int *, char *);
	void (*umount_begin)(struct super_block___421 *);
	int (*show_options)(struct seq_file___360 *, struct dentry___421 *);
	int (*show_devname)(struct seq_file___360 *, struct dentry___421 *);
	int (*show_path)(struct seq_file___360 *, struct dentry___421 *);
	int (*show_stats)(struct seq_file___360 *, struct dentry___421 *);
	ssize_t (*quota_read)(struct super_block___421 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___421 *, int, const char *, size_t, loff_t);
	struct dquot___421 ** (*get_dquots)(struct inode___421 *);
	int (*bdev_try_to_free_page)(struct super_block___421 *, struct page___422 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___421 *, struct shrink_control___156 *);
	long int (*free_cached_objects)(struct super_block___421 *, struct shrink_control___156 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___360;

struct seq_file___360 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___360 *op;
	int poll_event;
	const struct file___421 *file;
	void *private;
};

struct net_device___67;

struct nf_bridge_info___66;

struct sk_buff___68 {
	union {
		struct {
			struct sk_buff___68 *next;
			struct sk_buff___68 *prev;
			union {
				struct net_device___67 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___49 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___68 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___66 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___66;

struct netns_frags___66 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___66 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv4___66 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct sock *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock **tcp_sk;
	struct netns_frags___66 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct dst_ops___77 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___77 *);
	struct dst_entry___2 * (*check)(struct dst_entry___2 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___2 *);
	unsigned int (*mtu)(const struct dst_entry___2 *);
	u32 * (*cow_metrics)(struct dst_entry___2 *, long unsigned int);
	void (*destroy)(struct dst_entry___2 *);
	void (*ifdown)(struct dst_entry___2 *, struct net_device___67 *, int);
	struct dst_entry___2 * (*negative_advice)(struct dst_entry___2 *);
	void (*link_failure)(struct sk_buff___68 *);
	void (*update_pmtu)(struct dst_entry___2 *, struct sock *, struct sk_buff___68 *, u32);
	void (*redirect)(struct dst_entry___2 *, struct sock *, struct sk_buff___68 *);
	int (*local_out)(struct net___78 *, struct sock *, struct sk_buff___68 *);
	struct neighbour___2 * (*neigh_lookup)(const struct dst_entry___2 *, struct sk_buff___68 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___2 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___77 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___66 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___77 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct sock *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops *notifier_ops;
	struct fib_notifier_ops *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_nf_frag___66 {
	struct netns_frags___66 frags;
};

struct netns_xfrm___77 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___77 xfrm4_dst_ops;
	struct dst_ops___77 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct net___78 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___286 *user_ns;
	struct ucounts___286 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___29 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___67 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___66 ipv4;
	struct netns_ipv6___77 ipv6;
	struct netns_sctp___49 sctp;
	struct netns_nf___4 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___66 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock *nfnl;
	struct sock *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___77 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kernfs_root___415;

struct kernfs_elem_dir___415 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___415 *root;
};

struct kernfs_syscall_ops___415;

struct kernfs_root___415 {
	struct kernfs_node___416 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___415 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___415 {
	struct kernfs_node___416 *target_kn;
};

struct kernfs_ops___415;

struct kernfs_elem_attr___415 {
	const struct kernfs_ops___415 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___416 *notify_next;
};

struct kernfs_node___416 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___416 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___415 dir;
		struct kernfs_elem_symlink___415 symlink;
		struct kernfs_elem_attr___415 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___415;

struct kernfs_ops___415 {
	int (*open)(struct kernfs_open_file___415 *);
	void (*release)(struct kernfs_open_file___415 *);
	int (*seq_show)(struct seq_file___360 *, void *);
	void * (*seq_start)(struct seq_file___360 *, loff_t *);
	void * (*seq_next)(struct seq_file___360 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___360 *, void *);
	ssize_t (*read)(struct kernfs_open_file___415 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___415 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___415 *, struct vm_area_struct___422 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___415 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___415 {
	int (*remount_fs)(struct kernfs_root___415 *, int *, char *);
	int (*show_options)(struct seq_file___360 *, struct kernfs_root___415 *);
	int (*mkdir)(struct kernfs_node___416 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___416 *);
	int (*rename)(struct kernfs_node___416 *, struct kernfs_node___416 *, const char *);
	int (*show_path)(struct seq_file___360 *, struct kernfs_node___416 *, struct kernfs_root___415 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___415 {
	struct kernfs_node___416 *kn;
	struct file___421 *file;
	struct seq_file___360 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___409 *vm_ops;
};

struct bin_attribute___385;

struct attribute_group___386 {
	const char *name;
	umode_t (*is_visible)(struct kobject___409 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___409 *, struct bin_attribute___385 *, int);
	struct attribute **attrs;
	struct bin_attribute___385 **bin_attrs;
};

struct bin_attribute___385 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___421 *, struct kobject___409 *, struct bin_attribute___385 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___421 *, struct kobject___409 *, struct bin_attribute___385 *, char *, loff_t, size_t);
	int (*mmap)(struct file___421 *, struct kobject___409 *, struct bin_attribute___385 *, struct vm_area_struct___422 *);
};

struct sysfs_ops___408 {
	ssize_t (*show)(struct kobject___409 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___409 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___408;

struct kset___408 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___409 kobj;
	const struct kset_uevent_ops___408 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___408 {
	void (*release)(struct kobject___409 *);
	const struct sysfs_ops___408 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___48 * (*child_ns_type)(struct kobject___409 *);
	const void * (*namespace)(struct kobject___409 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___408 {
	int (* const filter)(struct kset___408 *, struct kobject___409 *);
	const char * (* const name)(struct kset___408 *, struct kobject___409 *);
	int (* const uevent)(struct kset___408 *, struct kobject___409 *, struct kobj_uevent_env *);
};

struct kobj_attribute___399 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___409 *, struct kobj_attribute___399 *, char *);
	ssize_t (*store)(struct kobject___409 *, struct kobj_attribute___399 *, const char *, size_t);
};

struct dev_pm_ops___389 {
	int (*prepare)(struct device___389 *);
	void (*complete)(struct device___389 *);
	int (*suspend)(struct device___389 *);
	int (*resume)(struct device___389 *);
	int (*freeze)(struct device___389 *);
	int (*thaw)(struct device___389 *);
	int (*poweroff)(struct device___389 *);
	int (*restore)(struct device___389 *);
	int (*suspend_late)(struct device___389 *);
	int (*resume_early)(struct device___389 *);
	int (*freeze_late)(struct device___389 *);
	int (*thaw_early)(struct device___389 *);
	int (*poweroff_late)(struct device___389 *);
	int (*restore_early)(struct device___389 *);
	int (*suspend_noirq)(struct device___389 *);
	int (*resume_noirq)(struct device___389 *);
	int (*freeze_noirq)(struct device___389 *);
	int (*thaw_noirq)(struct device___389 *);
	int (*poweroff_noirq)(struct device___389 *);
	int (*restore_noirq)(struct device___389 *);
	int (*runtime_suspend)(struct device___389 *);
	int (*runtime_resume)(struct device___389 *);
	int (*runtime_idle)(struct device___389 *);
};

struct dev_pm_info___389 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___389 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___389;

struct bus_type___389;

struct device_driver___389;

struct dev_pm_domain___389;

struct dma_map_ops___161;

struct fwnode_handle___309;

struct class___389;

struct device___389 {
	struct device___389 *parent;
	struct device_private *p;
	struct kobject___409 kobj;
	const char *init_name;
	const struct device_type___389 *type;
	struct mutex mutex;
	struct bus_type___389 *bus;
	struct device_driver___389 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___389 power;
	struct dev_pm_domain___389 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___161 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___309 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___389 *class;
	const struct attribute_group___386 **groups;
	void (*release)(struct device___389 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___389 {
	struct dev_pm_ops___389 ops;
	void (*detach)(struct device___389 *, bool);
	int (*activate)(struct device___389 *);
	void (*sync)(struct device___389 *);
	void (*dismiss)(struct device___389 *);
};

struct bus_type___389 {
	const char *name;
	const char *dev_name;
	struct device___389 *dev_root;
	const struct attribute_group___386 **bus_groups;
	const struct attribute_group___386 **dev_groups;
	const struct attribute_group___386 **drv_groups;
	int (*match)(struct device___389 *, struct device_driver___389 *);
	int (*uevent)(struct device___389 *, struct kobj_uevent_env *);
	int (*probe)(struct device___389 *);
	int (*remove)(struct device___389 *);
	void (*shutdown)(struct device___389 *);
	int (*online)(struct device___389 *);
	int (*offline)(struct device___389 *);
	int (*suspend)(struct device___389 *, pm_message_t);
	int (*resume)(struct device___389 *);
	int (*num_vf)(struct device___389 *);
	int (*dma_configure)(struct device___389 *);
	const struct dev_pm_ops___389 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___389 {
	const char *name;
	struct bus_type___389 *bus;
	struct module___351 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___389 *);
	int (*remove)(struct device___389 *);
	void (*shutdown)(struct device___389 *);
	int (*suspend)(struct device___389 *, pm_message_t);
	int (*resume)(struct device___389 *);
	const struct attribute_group___386 **groups;
	const struct dev_pm_ops___389 *pm;
	void (*coredump)(struct device___389 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___389 {
	const char *name;
	const struct attribute_group___386 **groups;
	int (*uevent)(struct device___389 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___389 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___389 *);
	const struct dev_pm_ops___389 *pm;
};

struct class___389 {
	const char *name;
	struct module___351 *owner;
	const struct attribute_group___386 **class_groups;
	const struct attribute_group___386 **dev_groups;
	struct kobject___409 *dev_kobj;
	int (*dev_uevent)(struct device___389 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___389 *, umode_t *);
	void (*class_release)(struct class___389 *);
	void (*dev_release)(struct device___389 *);
	int (*shutdown_pre)(struct device___389 *);
	const struct kobj_ns_type_operations___48 *ns_type;
	const void * (*namespace)(struct device___389 *);
	const struct dev_pm_ops___389 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___161 {
	void * (*alloc)(struct device___389 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___389 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___389 *, struct vm_area_struct___422 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___389 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___389 *, struct page___422 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___389 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___389 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___389 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___389 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___389 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___389 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___389 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___389 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___389 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___389 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___389 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___389 *, u64);
	u64 (*get_required_mask)(struct device___389 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___309;

struct fwnode_handle___309 {
	struct fwnode_handle___309 *secondary;
	const struct fwnode_operations___309 *ops;
};

typedef void compound_page_dtor___409(struct page___422 *);

struct fwnode_reference_args___309;

struct fwnode_endpoint___309;

struct fwnode_operations___309 {
	struct fwnode_handle___309 * (*get)(struct fwnode_handle___309 *);
	void (*put)(struct fwnode_handle___309 *);
	bool (*device_is_available)(const struct fwnode_handle___309 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___309 *, const struct device___389 *);
	bool (*property_present)(const struct fwnode_handle___309 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___309 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___309 *, const char *, const char **, size_t);
	struct fwnode_handle___309 * (*get_parent)(const struct fwnode_handle___309 *);
	struct fwnode_handle___309 * (*get_next_child_node)(const struct fwnode_handle___309 *, struct fwnode_handle___309 *);
	struct fwnode_handle___309 * (*get_named_child_node)(const struct fwnode_handle___309 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___309 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___309 *);
	struct fwnode_handle___309 * (*graph_get_next_endpoint)(const struct fwnode_handle___309 *, struct fwnode_handle___309 *);
	struct fwnode_handle___309 * (*graph_get_remote_endpoint)(const struct fwnode_handle___309 *);
	struct fwnode_handle___309 * (*graph_get_port_parent)(struct fwnode_handle___309 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___309 *, struct fwnode_endpoint___309 *);
};

struct fwnode_endpoint___309 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___309 *local_fwnode;
};

struct fwnode_reference_args___309 {
	struct fwnode_handle___309 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___102;

struct pipe_buffer___102 {
	struct page___422 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___102 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___102 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___102 *, struct pipe_buffer___102 *);
	void (*release)(struct pipe_inode_info___102 *, struct pipe_buffer___102 *);
	int (*steal)(struct pipe_inode_info___102 *, struct pipe_buffer___102 *);
	union {
		bool (*get)(struct pipe_inode_info___102 *, struct pipe_buffer___102 *);
		struct {
			void (*get)(struct pipe_inode_info___102 *, struct pipe_buffer___102 *);
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
};

struct nf_bridge_info___66 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___66 = 0,
		BRNF_PROTO_8021Q___66 = 1,
		BRNF_PROTO_PPPOE___66 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___67 *physindev;
	struct net_device___67 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___66(struct sk_buff___68 **);

typedef struct {
	struct net___78 *net;
} possible_net_t___68;

struct net_device_ops___66;

struct ethtool_ops___66;

struct xfrmdev_ops___66;

struct tlsdev_ops___66;

struct header_ops___66;

struct in_device___6;

struct netdev_rx_queue___66;

struct netdev_queue___66;

struct dcbnl_rtnl_ops___66;

struct net_device___67 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___66 *netdev_ops;
	const struct ethtool_ops___66 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___2 *l3mdev_ops;
	const struct ndisc_ops___2 *ndisc_ops;
	const struct xfrmdev_ops___66 *xfrmdev_ops;
	const struct tlsdev_ops___66 *tlsdev_ops;
	const struct header_ops___66 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___408 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device___6 *ip_ptr;
	struct inet6_dev___2 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___66 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___66 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___2 *miniq_ingress;
	struct netdev_queue___66 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___66 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___2 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___2 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___66 = 0,
		NETREG_REGISTERED___66 = 1,
		NETREG_UNREGISTERING___66 = 2,
		NETREG_UNREGISTERED___66 = 3,
		NETREG_RELEASED___66 = 4,
		NETREG_DUMMY___66 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___66 = 0,
		RTNL_LINK_INITIALIZING___66 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___67 *);
	struct netpoll_info *npinfo;
	possible_net_t___68 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___389 dev;
	const struct attribute_group___386 *sysfs_groups[4];
	const struct attribute_group___386 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___2 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___66 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct sk_buff_head___66 {
	struct sk_buff___68 *next;
	struct sk_buff___68 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct ethtool_ops___66 {
	int (*get_settings)(struct net_device___67 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___67 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___67 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___67 *);
	void (*get_regs)(struct net_device___67 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___67 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___67 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___67 *);
	void (*set_msglevel)(struct net_device___67 *, u32);
	int (*nway_reset)(struct net_device___67 *);
	u32 (*get_link)(struct net_device___67 *);
	int (*get_eeprom_len)(struct net_device___67 *);
	int (*get_eeprom)(struct net_device___67 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___67 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___67 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___67 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___67 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___67 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___67 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___67 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___67 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___67 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___67 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___67 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___67 *);
	void (*complete)(struct net_device___67 *);
	u32 (*get_priv_flags)(struct net_device___67 *);
	int (*set_priv_flags)(struct net_device___67 *, u32);
	int (*get_sset_count)(struct net_device___67 *, int);
	int (*get_rxnfc)(struct net_device___67 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___67 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___67 *, struct ethtool_flash *);
	int (*reset)(struct net_device___67 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___67 *);
	u32 (*get_rxfh_indir_size)(struct net_device___67 *);
	int (*get_rxfh)(struct net_device___67 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___67 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___67 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___67 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___67 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___67 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___67 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___67 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___67 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___67 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___67 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___67 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___67 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___67 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___67 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___67 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___67 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___67 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___67 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___67 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___67 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___67 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	int (*get_fecparam)(struct net_device___67 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___67 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___67 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___67 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___67 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___66;

struct inet_frags___66 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___66 *, const void *);
	void (*destructor)(struct inet_frag_queue___66 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___66 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___68 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___68 *fragments_tail;
	struct sk_buff___68 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___66 *net;
	struct callback_head rcu;
};

struct ucounts___286 {
	struct hlist_node node;
	struct user_namespace___286 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

typedef int (*key_restrict_link_func_t___390)(struct key___389 *, const struct key_type *, const union key_payload *, struct key___389 *);

struct key_restriction___389;

struct key___389 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___423 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___389 *restrict_link;
};

struct key_restriction___389 {
	key_restrict_link_func_t___390 check;
	struct key___389 *key;
	struct key_type *keytype;
};

struct seq_operations___360 {
	void * (*start)(struct seq_file___360 *, loff_t *);
	void (*stop)(struct seq_file___360 *, void *);
	void * (*next)(struct seq_file___360 *, void *, loff_t *);
	int (*show)(struct seq_file___360 *, void *);
};

struct pernet_operations___67 {
	struct list_head list;
	int (*init)(struct net___78 *);
	void (*exit)(struct net___78 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___66 {
	int (*ieee_getets)(struct net_device___67 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___67 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___67 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___67 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___67 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___67 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___67 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___67 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___67 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___67 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___67 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___67 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___67 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___67 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___67 *);
	u8 (*setstate)(struct net_device___67 *, u8);
	void (*getpermhwaddr)(struct net_device___67 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___67 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___67 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___67 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___67 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___67 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___67 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___67 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___67 *, int, u8 *);
	void (*setpfccfg)(struct net_device___67 *, int, u8);
	void (*getpfccfg)(struct net_device___67 *, int, u8 *);
	u8 (*setall)(struct net_device___67 *);
	u8 (*getcap)(struct net_device___67 *, int, u8 *);
	int (*getnumtcs)(struct net_device___67 *, int, u8 *);
	int (*setnumtcs)(struct net_device___67 *, int, u8);
	u8 (*getpfcstate)(struct net_device___67 *);
	void (*setpfcstate)(struct net_device___67 *, u8);
	void (*getbcncfg)(struct net_device___67 *, int, u32 *);
	void (*setbcncfg)(struct net_device___67 *, int, u32);
	void (*getbcnrp)(struct net_device___67 *, int, u8 *);
	void (*setbcnrp)(struct net_device___67 *, int, u8);
	int (*setapp)(struct net_device___67 *, u8, u16, u8);
	int (*getapp)(struct net_device___67 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___67 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___67 *, int, u8);
	u8 (*getdcbx)(struct net_device___67 *);
	u8 (*setdcbx)(struct net_device___67 *, u8);
	int (*peer_getappinfo)(struct net_device___67 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___67 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___67 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___67 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___67 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___67 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___270 {
	refcount_t count;
	struct ns_common___29 ns;
	struct user_namespace___286 *user_ns;
	struct ucounts___286 *ucounts;
	struct css_set___270 *root_cset;
};

struct bpf_map___271;

struct bpf_map_ops___270 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___271 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___271 *, struct file___421 *);
	void (*map_free)(struct bpf_map___271 *);
	int (*map_get_next_key)(struct bpf_map___271 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___271 *);
	void * (*map_lookup_elem)(struct bpf_map___271 *, void *);
	int (*map_update_elem)(struct bpf_map___271 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___271 *, void *);
	int (*map_push_elem)(struct bpf_map___271 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___271 *, void *);
	int (*map_peek_elem)(struct bpf_map___271 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___271 *, struct file___421 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___271 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___271 *, void *, struct seq_file___360 *);
	int (*map_check_btf)(const struct bpf_map___271 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___271 {
	const struct bpf_map_ops___270 *ops;
	struct bpf_map___271 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___389 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___66;

struct bpf_map_dev_ops___66 {
	int (*map_get_next_key)(struct bpf_offloaded_map___66 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___66 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___66 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___66 *, void *);
};

struct bpf_offloaded_map___66 {
	struct bpf_map___271 map;
	struct net_device___67 *netdev;
	const struct bpf_map_dev_ops___66 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___271;

typedef void (*kthread_work_func_t___271)(struct kthread_work___271 *);

struct kthread_worker___271;

struct kthread_work___271 {
	struct list_head node;
	kthread_work_func_t___271 func;
	struct kthread_worker___271 *worker;
	int canceling;
};

struct kthread_worker___271 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___423 *task;
	struct kthread_work___271 *current_work;
};

struct kthread_delayed_work___270 {
	struct kthread_work___271 work;
	struct timer_list timer;
};

struct psi_group___270 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___271 *poll_kworker;
	struct kthread_delayed_work___270 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___270 {
	struct kernfs_node___416 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___270;

struct cgroup_subsys_state___270 {
	struct cgroup___270 *cgroup;
	struct cgroup_subsys___270 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___270 *parent;
};

struct cgroup_root___270;

struct cgroup_rstat_cpu___270;

struct cgroup___270 {
	struct cgroup_subsys_state___270 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___416 *kn;
	struct cgroup_file___270 procs_file;
	struct cgroup_file___270 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___270 *subsys[13];
	struct cgroup_root___270 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___270 *dom_cgrp;
	struct cgroup_rstat_cpu___270 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___58 bpf;
	atomic_t congestion_count;
	struct cgroup___270 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___270 psi;
	int ancestor_ids[0];
};

struct cftype___270;

struct cgroup_subsys___270 {
	struct cgroup_subsys_state___270 * (*css_alloc)(struct cgroup_subsys_state___270 *);
	int (*css_online)(struct cgroup_subsys_state___270 *);
	void (*css_offline)(struct cgroup_subsys_state___270 *);
	void (*css_released)(struct cgroup_subsys_state___270 *);
	void (*css_free)(struct cgroup_subsys_state___270 *);
	void (*css_reset)(struct cgroup_subsys_state___270 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___270 *, int);
	int (*css_extra_stat_show)(struct seq_file___360 *, struct cgroup_subsys_state___270 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___423 *);
	void (*cancel_fork)(struct task_struct___423 *);
	void (*fork)(struct task_struct___423 *);
	void (*exit)(struct task_struct___423 *);
	void (*free)(struct task_struct___423 *);
	void (*bind)(struct cgroup_subsys_state___270 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___270 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___270 *dfl_cftypes;
	struct cftype___270 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___270 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___270 *updated_children;
	struct cgroup___270 *updated_next;
};

struct cgroup_root___270 {
	struct kernfs_root___415 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___270 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___270 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___270 *ss;
	struct list_head node;
	struct kernfs_ops___415 *kf_ops;
	int (*open)(struct kernfs_open_file___415 *);
	void (*release)(struct kernfs_open_file___415 *);
	u64 (*read_u64)(struct cgroup_subsys_state___270 *, struct cftype___270 *);
	s64 (*read_s64)(struct cgroup_subsys_state___270 *, struct cftype___270 *);
	int (*seq_show)(struct seq_file___360 *, void *);
	void * (*seq_start)(struct seq_file___360 *, loff_t *);
	void * (*seq_next)(struct seq_file___360 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___360 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___270 *, struct cftype___270 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___270 *, struct cftype___270 *, s64);
	ssize_t (*write)(struct kernfs_open_file___415 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___415 *, struct poll_table_struct___6 *);
};

struct xdp_rxq_info___66 {
	struct net_device___67 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___66 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___67 *dev_rx;
};

struct netlink_callback___68 {
	struct sk_buff___68 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___68 *);
	int (*dump)(struct sk_buff___68 *, struct netlink_callback___68 *);
	int (*done)(struct netlink_callback___68 *);
	void *data;
	struct module___351 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___66 {
	int (*create)(struct sk_buff___68 *, struct net_device___67 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___68 *, unsigned char *);
	int (*cache)(const struct neighbour___2 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___67 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___66 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___66 *, int);
	int poll_owner;
	struct net_device___67 *dev;
	struct sk_buff___68 *gro_list;
	struct sk_buff___68 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___66 {
	struct net_device___67 *dev;
	struct Qdisc___2 *qdisc;
	struct Qdisc___2 *qdisc_sleeping;
	struct kobject___409 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___67 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct netdev_rx_queue___66 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___409 kobj;
	struct net_device___67 *dev;
	long: 64;
	struct xdp_rxq_info___66 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___66)(struct net_device___67 *, struct sk_buff___68 *, struct net_device___67 *);

struct netdev_bpf___66 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___58 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___58 *prog;
			const struct bpf_prog_offload_ops___58 *ops;
		} verifier;
		struct {
			struct bpf_prog___58 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___66 *offmap;
		};
		struct {
			struct xdp_umem___3 *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___66 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___68 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___66 {
	int (*tls_dev_add)(struct net_device___67 *, struct sock *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___67 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___67 *, struct sock *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___66 {
	int (*ndo_init)(struct net_device___67 *);
	void (*ndo_uninit)(struct net_device___67 *);
	int (*ndo_open)(struct net_device___67 *);
	int (*ndo_stop)(struct net_device___67 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___68 *, struct net_device___67 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___68 *, struct net_device___67 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___67 *, struct sk_buff___68 *, struct net_device___67 *, select_queue_fallback_t___66);
	void (*ndo_change_rx_flags)(struct net_device___67 *, int);
	void (*ndo_set_rx_mode)(struct net_device___67 *);
	int (*ndo_set_mac_address)(struct net_device___67 *, void *);
	int (*ndo_validate_addr)(struct net_device___67 *);
	int (*ndo_do_ioctl)(struct net_device___67 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___67 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___67 *, int);
	int (*ndo_neigh_setup)(struct net_device___67 *, struct neigh_parms___3 *);
	void (*ndo_tx_timeout)(struct net_device___67 *);
	void (*ndo_get_stats64)(struct net_device___67 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___67 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___67 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___67 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___67 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___67 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___67 *);
	int (*ndo_netpoll_setup)(struct net_device___67 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___67 *);
	int (*ndo_set_vf_mac)(struct net_device___67 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___67 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___67 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___67 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___67 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___67 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___67 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___67 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___67 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___67 *, int, struct sk_buff___68 *);
	int (*ndo_set_vf_guid)(struct net_device___67 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___67 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___67 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___67 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___67 *, const struct sk_buff___68 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___67 *, struct net_device___67 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___67 *, struct net_device___67 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___67 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___67 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___67 *, struct neighbour___2 *);
	void (*ndo_neigh_destroy)(struct net_device___67 *, struct neighbour___2 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___67 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___67 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___67 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___68 *, struct netlink_callback___68 *, struct net_device___67 *, struct net_device___67 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___67 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___67 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___68 *, u32, u32, struct net_device___67 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___67 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___67 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___67 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___67 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___67 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___67 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___67 *, struct net_device___67 *);
	void (*ndo_dfwd_del_station)(struct net_device___67 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___67 *);
	int (*ndo_set_tx_maxrate)(struct net_device___67 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___67 *);
	int (*ndo_change_proto_down)(struct net_device___67 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___67 *, struct sk_buff___68 *);
	void (*ndo_set_rx_headroom)(struct net_device___67 *, int);
	int (*ndo_bpf)(struct net_device___67 *, struct netdev_bpf___66 *);
	int (*ndo_xdp_xmit)(struct net_device___67 *, int, struct xdp_frame___66 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___67 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___67 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct netpoll___4;

struct netpoll_info {
	refcount_t refcnt;
	struct semaphore dev_lock;
	struct sk_buff_head___66 txq;
	struct delayed_work tx_work;
	struct netpoll___4 *netpoll;
	struct callback_head rcu;
};

struct in_ifaddr___6;

struct in_device___6 {
	struct net_device___67 *dev;
	refcount_t refcnt;
	int dead;
	struct in_ifaddr___6 *ifa_list;
	struct ip_mc_list *mc_list;
	struct ip_mc_list **mc_hash;
	int mc_count;
	spinlock_t mc_tomb_lock;
	struct ip_mc_list *mc_tomb;
	long unsigned int mr_v1_seen;
	long unsigned int mr_v2_seen;
	long unsigned int mr_maxdelay;
	long unsigned int mr_qi;
	long unsigned int mr_qri;
	unsigned char mr_qrv;
	unsigned char mr_gq_running;
	unsigned char mr_ifc_count;
	struct timer_list mr_gq_timer;
	struct timer_list mr_ifc_timer;
	struct neigh_parms___3 *arp_parms;
	struct ipv4_devconf cnf;
	struct callback_head callback_head;
};

struct netdev_notifier_info___6 {
	struct net_device___67 *dev;
	struct netlink_ext_ack *extack;
};

struct softnet_data___66 {
	struct list_head poll_list;
	struct sk_buff_head___66 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___66 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___2 *output_queue;
	struct Qdisc___2 **output_queue_tailp;
	struct sk_buff___68 *completion_queue;
	struct sk_buff_head___66 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___66 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___66 input_pkt_queue;
	struct napi_struct___66 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct in_ifaddr___6 {
	struct hlist_node hash;
	struct in_ifaddr___6 *ifa_next;
	struct in_device___6 *ifa_dev;
	struct callback_head callback_head;
	__be32 ifa_local;
	__be32 ifa_address;
	__be32 ifa_mask;
	__u32 ifa_rt_priority;
	__be32 ifa_broadcast;
	unsigned char ifa_scope;
	unsigned char ifa_prefixlen;
	__u32 ifa_flags;
	char ifa_label[16];
	__u32 ifa_valid_lft;
	__u32 ifa_preferred_lft;
	long unsigned int ifa_cstamp;
	long unsigned int ifa_tstamp;
};

struct netpoll___4 {
	struct net_device___67 *dev;
	char dev_name[16];
	const char *name;
	union inet_addr local_ip;
	union inet_addr remote_ip;
	bool ipv6;
	u16 local_port;
	u16 remote_port;
	u8 remote_mac[6];
	struct work_struct cleanup_work;
};

struct net_dm_drop_point {
	__u8 pc[8];
	__u32 count;
};

struct net_dm_alert_msg {
	__u32 entries;
	struct net_dm_drop_point points[0];
};

enum {
	NET_DM_CMD_UNSPEC = 0,
	NET_DM_CMD_ALERT = 1,
	NET_DM_CMD_CONFIG = 2,
	NET_DM_CMD_START = 3,
	NET_DM_CMD_STOP = 4,
	_NET_DM_CMD_MAX = 5,
};

struct kernel_param_ops___349 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___349 *);
	int (*get)(char *, const struct kernel_param___349 *);
	void (*free)(void *);
};

struct kparam_array___349;

struct kernel_param___349 {
	const char *name;
	struct module___351 *mod;
	const struct kernel_param_ops___349 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___349 *arr;
	};
};

struct kparam_array___349 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___349 *ops;
	void *elem;
};

struct module_attribute___349 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___349 *, struct module_kobject___349 *, char *);
	ssize_t (*store)(struct module_attribute___349 *, struct module_kobject___349 *, const char *, size_t);
	void (*setup)(struct module___351 *, const char *);
	int (*test)(struct module___351 *);
	void (*free)(struct module___351 *);
};

struct genl_ops___4;

struct genl_info___3;

struct genl_family___4 {
	int id;
	unsigned int hdrsize;
	char name[16];
	unsigned int version;
	unsigned int maxattr;
	bool netnsok;
	bool parallel_ops;
	int (*pre_doit)(const struct genl_ops___4 *, struct sk_buff___68 *, struct genl_info___3 *);
	void (*post_doit)(const struct genl_ops___4 *, struct sk_buff___68 *, struct genl_info___3 *);
	int (*mcast_bind)(struct net___78 *, int);
	void (*mcast_unbind)(struct net___78 *, int);
	struct nlattr **attrbuf;
	const struct genl_ops___4 *ops;
	const struct genl_multicast_group *mcgrps;
	unsigned int n_ops;
	unsigned int n_mcgrps;
	unsigned int mcgrp_offset;
	struct module___351 *module;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct genl_ops___4 {
	const struct nla_policy *policy;
	int (*doit)(struct sk_buff___68 *, struct genl_info___3 *);
	int (*start)(struct netlink_callback___68 *);
	int (*dumpit)(struct sk_buff___68 *, struct netlink_callback___68 *);
	int (*done)(struct netlink_callback___68 *);
	u8 cmd;
	u8 internal_flags;
	u8 flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t genl_ops_extended_size_rh;
	struct genl_ops_extended_rh genl_ops_extended_rh;
};

struct genl_info___3 {
	u32 snd_seq;
	u32 snd_portid;
	struct nlmsghdr *nlhdr;
	struct genlmsghdr *genlhdr;
	void *userhdr;
	struct nlattr **attrs;
	possible_net_t___68 _net;
	void *user_ptr[2];
	struct netlink_ext_ack *extack;
};

struct per_cpu_dm_data {
	spinlock_t lock;
	struct sk_buff___68 *skb;
	struct work_struct dm_alert_work;
	struct timer_list send_timer;
};

struct dm_hw_stat_delta {
	struct net_device___67 *dev;
	long unsigned int last_rx;
	struct list_head list;
	struct callback_head rcu;
	long unsigned int last_drop_val;
};

struct module___352;

struct file___422;

struct kiocb___422;

struct iov_iter___189;

struct poll_table_struct___263;

struct vm_area_struct___423;

struct inode___422;

struct file_lock___422;

struct page___423;

struct pipe_inode_info___103;

struct seq_file___361;

struct file_operations___422 {
	struct module___352 *owner;
	loff_t (*llseek)(struct file___422 *, loff_t, int);
	ssize_t (*read)(struct file___422 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___422 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___422 *, struct iov_iter___189 *);
	ssize_t (*write_iter)(struct kiocb___422 *, struct iov_iter___189 *);
	int (*iopoll)(struct kiocb___422 *, bool);
	int (*iterate)(struct file___422 *, struct dir_context *);
	int (*iterate_shared)(struct file___422 *, struct dir_context *);
	__poll_t (*poll)(struct file___422 *, struct poll_table_struct___263 *);
	long int (*unlocked_ioctl)(struct file___422 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___422 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___422 *, struct vm_area_struct___423 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___422 *, struct file___422 *);
	int (*flush)(struct file___422 *, fl_owner_t);
	int (*release)(struct inode___422 *, struct file___422 *);
	int (*fsync)(struct file___422 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___422 *, int);
	int (*lock)(struct file___422 *, int, struct file_lock___422 *);
	ssize_t (*sendpage)(struct file___422 *, struct page___423 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___422 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___422 *, int, struct file_lock___422 *);
	ssize_t (*splice_write)(struct pipe_inode_info___103 *, struct file___422 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___422 *, loff_t *, struct pipe_inode_info___103 *, size_t, unsigned int);
	int (*setlease)(struct file___422 *, long int, struct file_lock___422 **, void **);
	long int (*fallocate)(struct file___422 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___361 *, struct file___422 *);
	ssize_t (*copy_file_range)(struct file___422 *, loff_t, struct file___422 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___422 *, loff_t, struct file___422 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___422 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___423 {
	u64 seqnum;
	struct vm_area_struct___423 *vmas[4];
};

struct page_frag___423 {
	struct page___423 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___423;

struct mem_cgroup___157;

struct cred___390;

struct files_struct___18;

struct nsproxy___317;

struct signal_struct___297;

struct bio_list___214;

struct backing_dev_info___214;

struct css_set___271;

struct vm_struct___326;

struct task_struct___424 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___424 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___423 *mm;
	struct mm_struct___423 *active_mm;
	struct vmacache___423 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___424 *real_parent;
	struct task_struct___424 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___424 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___157 *active_memcg;
	long int rh_reserved2;
	struct pid___239 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___239 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___239 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___390 *ptracer_cred;
	const struct cred___390 *real_cred;
	const struct cred___390 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct___18 *files;
	struct nsproxy___317 *nsproxy;
	struct signal_struct___297 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___424 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___214 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___214 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___271 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___103 *splice_pipe;
	struct page_frag___423 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___157 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___424 *oom_reaper_list;
	struct vm_struct___326 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___155 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rw_semaphore___424 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___424 *owner;
};

struct key___390;

struct ucounts___287;

struct user_namespace___287 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___287 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___29 ns;
	long unsigned int flags;
	struct key___390 *persistent_keyring_register;
	struct rw_semaphore___424 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___287 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___423 *pgtable_t___423;

struct address_space___422;

struct dev_pagemap___410;

struct page___423 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___422 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___423 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___423 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___423 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___410 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___157 *mem_cgroup;
};

struct pglist_data___423;

struct lruvec___423 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___423 *pgdat;
};

struct zone___423 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___423 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___423 {
	struct zone___423 *zone;
	int zone_idx;
};

struct zonelist___423 {
	struct zoneref___423 _zonerefs[25];
};

struct pglist_data___423 {
	struct zone___423 node_zones[3];
	struct zonelist___423 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___424 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___424 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___423 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___424 {
	void *stack;
	struct task_struct___424 *task;
	long int status;
};

struct blocking_notifier_head___423 {
	struct rw_semaphore___424 rwsem;
	struct notifier_block *head;
};

struct dentry___422;

struct path___423 {
	struct vfsmount *mnt;
	struct dentry___422 *dentry;
};

struct file___422 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___423 f_path;
	struct inode___422 *f_inode;
	const struct file_operations___422 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___239 f_owner;
	const struct cred___390 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___422 *f_mapping;
	errseq_t f_wb_err;
};

struct user_struct___390;

struct cred___390 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___390 *session_keyring;
	struct key___390 *process_keyring;
	struct key___390 *thread_keyring;
	struct key___390 *request_key_auth;
	void *security;
	struct user_struct___390 *user;
	struct user_namespace___287 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___416;

struct kernfs_elem_dir___416 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___416 *root;
};

struct kernfs_node___417;

struct kernfs_syscall_ops___416;

struct kernfs_root___416 {
	struct kernfs_node___417 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___416 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___416 {
	struct kernfs_node___417 *target_kn;
};

struct kernfs_ops___416;

struct kernfs_elem_attr___416 {
	const struct kernfs_ops___416 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___417 *notify_next;
};

struct kernfs_node___417 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___417 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___416 dir;
		struct kernfs_elem_symlink___416 symlink;
		struct kernfs_elem_attr___416 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___416;

struct kernfs_ops___416 {
	int (*open)(struct kernfs_open_file___416 *);
	void (*release)(struct kernfs_open_file___416 *);
	int (*seq_show)(struct seq_file___361 *, void *);
	void * (*seq_start)(struct seq_file___361 *, loff_t *);
	void * (*seq_next)(struct seq_file___361 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___361 *, void *);
	ssize_t (*read)(struct kernfs_open_file___416 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___416 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___416 *, struct vm_area_struct___423 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___416 *, struct poll_table_struct___263 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___416 {
	int (*remount_fs)(struct kernfs_root___416 *, int *, char *);
	int (*show_options)(struct seq_file___361 *, struct kernfs_root___416 *);
	int (*mkdir)(struct kernfs_node___417 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___417 *);
	int (*rename)(struct kernfs_node___417 *, struct kernfs_node___417 *, const char *);
	int (*show_path)(struct seq_file___361 *, struct kernfs_node___417 *, struct kernfs_root___416 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___361;

struct seq_file___361 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___361 *op;
	int poll_event;
	const struct file___422 *file;
	void *private;
};

struct vm_operations_struct___410;

struct kernfs_open_file___416 {
	struct kernfs_node___417 *kn;
	struct file___422 *file;
	struct seq_file___361 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___410 *vm_ops;
};

struct vm_fault___410;

struct vm_operations_struct___410 {
	void (*open)(struct vm_area_struct___423 *);
	void (*close)(struct vm_area_struct___423 *);
	int (*split)(struct vm_area_struct___423 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___423 *);
	vm_fault_t (*fault)(struct vm_fault___410 *);
	vm_fault_t (*huge_fault)(struct vm_fault___410 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___410 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___423 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___410 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___410 *);
	int (*access)(struct vm_area_struct___423 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___423 *);
	int (*set_policy)(struct vm_area_struct___423 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___423 *, long unsigned int);
	struct page___423 * (*find_special_page)(struct vm_area_struct___423 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___273)(struct file___422 *, wait_queue_head_t *, struct poll_table_struct___263 *);

struct poll_table_struct___263 {
	poll_queue_proc___273 _qproc;
	__poll_t _key;
};

struct vm_area_struct___423 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___423 *vm_next;
	struct vm_area_struct___423 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___423 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___410 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___422 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sock___50;

struct kobj_ns_type_operations___49 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___50 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct net___79;

typedef struct {
	struct net___79 *net;
} possible_net_t___69;

struct proto___49;

struct sock_common___49 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___49 *skc_prot;
	possible_net_t___69 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___50 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___69;

struct sk_buff_head___67 {
	struct sk_buff___69 *next;
	struct sk_buff___69 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___49;

struct socket_wq___50;

struct dst_entry___49;

struct socket___51;

struct net_device___68;

struct sock___50 {
	struct sock_common___49 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___67 sk_error_queue;
	struct sk_buff_head___67 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___69 *head;
		struct sk_buff___69 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___49 *sk_filter;
	union {
		struct socket_wq___50 *sk_wq;
		struct socket_wq___50 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___49 *sk_rx_dst;
	struct dst_entry___49 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___69 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___67 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___423 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___49 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___239 *sk_peer_pid;
	const struct cred___390 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___51 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___157 *sk_memcg;
	void (*sk_state_change)(struct sock___50 *);
	void (*sk_data_ready)(struct sock___50 *);
	void (*sk_write_space)(struct sock___50 *);
	void (*sk_error_report)(struct sock___50 *);
	int (*sk_backlog_rcv)(struct sock___50 *, struct sk_buff___69 *);
	struct sk_buff___69 * (*sk_validate_xmit_skb)(struct sock___50 *, struct net_device___68 *, struct sk_buff___69 *);
	void (*sk_destruct)(struct sock___50 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kobject___410;

struct bin_attribute___386;

struct attribute_group___387 {
	const char *name;
	umode_t (*is_visible)(struct kobject___410 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___410 *, struct bin_attribute___386 *, int);
	struct attribute **attrs;
	struct bin_attribute___386 **bin_attrs;
};

struct kset___409;

struct kobj_type___409;

struct kobject___410 {
	const char *name;
	struct list_head entry;
	struct kobject___410 *parent;
	struct kset___409 *kset;
	struct kobj_type___409 *ktype;
	struct kernfs_node___417 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___386 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___422 *, struct kobject___410 *, struct bin_attribute___386 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___422 *, struct kobject___410 *, struct bin_attribute___386 *, char *, loff_t, size_t);
	int (*mmap)(struct file___422 *, struct kobject___410 *, struct bin_attribute___386 *, struct vm_area_struct___423 *);
};

struct sysfs_ops___409 {
	ssize_t (*show)(struct kobject___410 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___410 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___409;

struct kset___409 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___410 kobj;
	const struct kset_uevent_ops___409 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___409 {
	void (*release)(struct kobject___410 *);
	const struct sysfs_ops___409 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___49 * (*child_ns_type)(struct kobject___410 *);
	const void * (*namespace)(struct kobject___410 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___409 {
	int (* const filter)(struct kset___409 *, struct kobject___410 *);
	const char * (* const name)(struct kset___409 *, struct kobject___410 *);
	int (* const uevent)(struct kset___409 *, struct kobject___410 *, struct kobj_uevent_env *);
};

struct kobj_attribute___400 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___410 *, struct kobj_attribute___400 *, char *);
	ssize_t (*store)(struct kobject___410 *, struct kobj_attribute___400 *, const char *, size_t);
};

struct kernel_param___350;

struct kernel_param_ops___350 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___350 *);
	int (*get)(char *, const struct kernel_param___350 *);
	void (*free)(void *);
};

struct kparam_array___350;

struct kernel_param___350 {
	const char *name;
	struct module___352 *mod;
	const struct kernel_param_ops___350 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___350 *arr;
	};
};

struct kparam_array___350 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___350 *ops;
	void *elem;
};

struct module_kobject___350 {
	struct kobject___410 kobj;
	struct module___352 *mod;
	struct kobject___410 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___350 {
	struct module___352 *mod;
	struct latch_tree_node node;
};

struct module_layout___350 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___350 mtn;
};

struct module_attribute___350;

struct module___352 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___350 mkobj;
	struct module_attribute___350 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___410 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___350 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___350 core_layout;
	struct module_layout___350 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___350 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___350 *, struct module_kobject___350 *, char *);
	ssize_t (*store)(struct module_attribute___350 *, struct module_kobject___350 *, const char *, size_t);
	void (*setup)(struct module___352 *, const char *);
	int (*test)(struct module___352 *);
	void (*free)(struct module___352 *);
};

struct cgroup___271;

struct cgroup_subsys___271;

struct cgroup_subsys_state___271 {
	struct cgroup___271 *cgroup;
	struct cgroup_subsys___271 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___271 *parent;
};

struct cgroup_file___271 {
	struct kernfs_node___417 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___157;

struct mem_cgroup___157 {
	struct cgroup_subsys_state___271 css;
	struct mem_cgroup_id___15 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___271 events_file;
	struct cgroup_file___271 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___424 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___157 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct user_struct___390 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___390 *uid_keyring;
	struct key___390 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___423;

struct mm_struct___423 {
	struct {
		struct vm_area_struct___423 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___422 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___424 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___423 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___424 *owner;
		struct user_namespace___287 *user_ns;
		struct file___422 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___423 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct fdtable___18 {
	unsigned int max_fds;
	struct file___422 **fd;
	long unsigned int *close_on_exec;
	long unsigned int *open_fds;
	long unsigned int *full_fds_bits;
	struct callback_head rcu;
};

struct files_struct___18 {
	atomic_t count;
	bool resize_in_progress;
	wait_queue_head_t resize_wait;
	struct fdtable___18 *fdt;
	struct fdtable___18 fdtab;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t file_lock;
	unsigned int next_fd;
	long unsigned int close_on_exec_init[1];
	long unsigned int open_fds_init[1];
	long unsigned int full_fds_bits_init[1];
	struct file___422 *fd_array[64];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cgroup_namespace___271;

struct nsproxy___317 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net___79 *net_ns;
	struct cgroup_namespace___271 *cgroup_ns;
};

struct signal_struct___297 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___424 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___424 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___239 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___239 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___423 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___239 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___214;

struct bio_list___214 {
	struct bio___214 *head;
	struct bio___214 *tail;
};

struct bdi_writeback_congested___214;

struct bdi_writeback___214 {
	struct backing_dev_info___214 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___214 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___271 *memcg_css;
	struct cgroup_subsys_state___271 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___390;

struct backing_dev_info___214 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___214 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___390 *dev;
	struct device___390 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___422 *debug_dir;
	struct dentry___422 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___271 {
	struct cgroup_subsys_state___271 *subsys[13];
	refcount_t refcount;
	struct css_set___271 *dom_cset;
	struct cgroup___271 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___271 *mg_src_cgrp;
	struct cgroup___271 *mg_dst_cgrp;
	struct css_set___271 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___422;

struct pipe_buffer___103;

struct pipe_inode_info___103 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___423 *tmp_page;
	struct fasync_struct___422 *fasync_readers;
	struct fasync_struct___422 *fasync_writers;
	struct pipe_buffer___103 *bufs;
	struct user_struct___390 *user;
};

struct vm_struct___326 {
	struct vm_struct___326 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___423 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___309 {
	struct task_struct___424 task;
	long unsigned int stack[8192];
};

struct address_space_operations___422;

struct address_space___422 {
	struct inode___422 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___424 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___422 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___410)(struct vm_area_struct___423 *, long unsigned int, const struct page___423 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___410)(struct page___423 *, void *);

struct dev_pagemap___410 {
	dev_page_fault_t___410 page_fault;
	dev_page_free_t___410 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___390 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___423 {
	struct task_struct___424 *task;
	struct core_thread___423 *next;
};

struct core_state___423 {
	atomic_t nr_threads;
	struct core_thread___423 dumper;
	struct completion startup;
};

struct vm_fault___410 {
	struct vm_area_struct___423 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___423 *cow_page;
	struct mem_cgroup___157 *memcg;
	struct page___423 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___423 prealloc_pte;
};

struct bio_vec___216 {
	struct page___423 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___189 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___216 *bvec;
		struct pipe_inode_info___103 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct msghdr___52 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___189 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___422 *msg_iocb;
};

struct kiocb___422 {
	struct file___422 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___422 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dentry_operations___422;

struct super_block___422;

struct dentry___422 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___422 *d_parent;
	struct qstr d_name;
	struct inode___422 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___422 *d_op;
	struct super_block___422 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___422;

struct block_device___422;

struct inode___422 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___422 *i_op;
	struct super_block___422 *i_sb;
	struct address_space___422 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___424 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___214 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___422 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___422 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___103 *i_pipe;
		struct block_device___422 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___422 {
	int (*d_revalidate)(struct dentry___422 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___422 *, unsigned int);
	int (*d_hash)(const struct dentry___422 *, struct qstr *);
	int (*d_compare)(const struct dentry___422 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___422 *);
	int (*d_init)(struct dentry___422 *);
	void (*d_release)(struct dentry___422 *);
	void (*d_prune)(struct dentry___422 *);
	void (*d_iput)(struct dentry___422 *, struct inode___422 *);
	char * (*d_dname)(struct dentry___422 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___423 *);
	int (*d_manage)(const struct path___423 *, bool);
	struct dentry___422 * (*d_real)(struct dentry___422 *, const struct inode___422 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___422;

struct mem_dqinfo___422 {
	struct quota_format_type___422 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___422;

struct quota_info___422 {
	unsigned int flags;
	struct rw_semaphore___424 dqio_sem;
	struct inode___422 *files[3];
	struct mem_dqinfo___422 info[3];
	const struct quota_format_ops___422 *ops[3];
};

struct rcuwait___422 {
	struct task_struct___424 *task;
};

struct percpu_rw_semaphore___422 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___424 rw_sem;
	struct rcuwait___422 writer;
	int readers_block;
};

struct sb_writers___422 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___422 rw_sem[3];
};

struct shrink_control___157;

struct shrinker___157 {
	long unsigned int (*count_objects)(struct shrinker___157 *, struct shrink_control___157 *);
	long unsigned int (*scan_objects)(struct shrinker___157 *, struct shrink_control___157 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___422;

struct super_operations___422;

struct dquot_operations___422;

struct quotactl_ops___422;

struct super_block___422 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___422 *s_type;
	const struct super_operations___422 *s_op;
	const struct dquot_operations___422 *dq_op;
	const struct quotactl_ops___422 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___422 *s_root;
	struct rw_semaphore___424 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___422 *s_bdev;
	struct backing_dev_info___214 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___422 s_dquot;
	struct sb_writers___422 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___422 *s_d_op;
	int cleancache_poolid;
	struct shrinker___157 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___287 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___157 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___157 *memcg;
};

struct iattr___422 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___422 *ia_file;
};

struct dquot___422 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___422 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___422 {
	int qf_fmt_id;
	const struct quota_format_ops___422 *qf_ops;
	struct module___352 *qf_owner;
	struct quota_format_type___422 *qf_next;
};

struct quota_format_ops___422 {
	int (*check_quota_file)(struct super_block___422 *, int);
	int (*read_file_info)(struct super_block___422 *, int);
	int (*write_file_info)(struct super_block___422 *, int);
	int (*free_file_info)(struct super_block___422 *, int);
	int (*read_dqblk)(struct dquot___422 *);
	int (*commit_dqblk)(struct dquot___422 *);
	int (*release_dqblk)(struct dquot___422 *);
	int (*get_next_id)(struct super_block___422 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___422 {
	int (*write_dquot)(struct dquot___422 *);
	struct dquot___422 * (*alloc_dquot)(struct super_block___422 *, int);
	void (*destroy_dquot)(struct dquot___422 *);
	int (*acquire_dquot)(struct dquot___422 *);
	int (*release_dquot)(struct dquot___422 *);
	int (*mark_dirty)(struct dquot___422 *);
	int (*write_info)(struct super_block___422 *, int);
	qsize_t * (*get_reserved_space)(struct inode___422 *);
	int (*get_projid)(struct inode___422 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___422 *, qsize_t *);
	int (*get_next_id)(struct super_block___422 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___422 {
	int (*quota_on)(struct super_block___422 *, int, int, const struct path___423 *);
	int (*quota_off)(struct super_block___422 *, int);
	int (*quota_enable)(struct super_block___422 *, unsigned int);
	int (*quota_disable)(struct super_block___422 *, unsigned int);
	int (*quota_sync)(struct super_block___422 *, int);
	int (*set_info)(struct super_block___422 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___422 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___422 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___422 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___422 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___422 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___177;

struct address_space_operations___422 {
	int (*writepage)(struct page___423 *, struct writeback_control___177 *);
	int (*readpage)(struct file___422 *, struct page___423 *);
	int (*writepages)(struct address_space___422 *, struct writeback_control___177 *);
	int (*set_page_dirty)(struct page___423 *);
	int (*readpages)(struct file___422 *, struct address_space___422 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___422 *, struct address_space___422 *, loff_t, unsigned int, unsigned int, struct page___423 **, void **);
	int (*write_end)(struct file___422 *, struct address_space___422 *, loff_t, unsigned int, unsigned int, struct page___423 *, void *);
	sector_t (*bmap)(struct address_space___422 *, sector_t);
	void (*invalidatepage)(struct page___423 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___423 *, gfp_t);
	void (*freepage)(struct page___423 *);
	ssize_t (*direct_IO)(struct kiocb___422 *, struct iov_iter___189 *);
	int (*migratepage)(struct address_space___422 *, struct page___423 *, struct page___423 *, enum migrate_mode);
	bool (*isolate_page)(struct page___423 *, isolate_mode_t);
	void (*putback_page)(struct page___423 *);
	int (*launder_page)(struct page___423 *);
	int (*is_partially_uptodate)(struct page___423 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___423 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___422 *, struct page___423 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___422 *, sector_t *);
	void (*swap_deactivate)(struct file___422 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___177 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___214 *wb;
	struct inode___422 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___422 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___422 *bd_inode;
	struct super_block___422 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___422 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___214 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___422 {
	struct dentry___422 * (*lookup)(struct inode___422 *, struct dentry___422 *, unsigned int);
	const char * (*get_link)(struct dentry___422 *, struct inode___422 *, struct delayed_call *);
	int (*permission)(struct inode___422 *, int);
	struct posix_acl * (*get_acl)(struct inode___422 *, int);
	int (*readlink)(struct dentry___422 *, char *, int);
	int (*create)(struct inode___422 *, struct dentry___422 *, umode_t, bool);
	int (*link)(struct dentry___422 *, struct inode___422 *, struct dentry___422 *);
	int (*unlink)(struct inode___422 *, struct dentry___422 *);
	int (*symlink)(struct inode___422 *, struct dentry___422 *, const char *);
	int (*mkdir)(struct inode___422 *, struct dentry___422 *, umode_t);
	int (*rmdir)(struct inode___422 *, struct dentry___422 *);
	int (*mknod)(struct inode___422 *, struct dentry___422 *, umode_t, dev_t);
	int (*rename)(struct inode___422 *, struct dentry___422 *, struct inode___422 *, struct dentry___422 *, unsigned int);
	int (*setattr)(struct dentry___422 *, struct iattr___422 *);
	int (*getattr)(const struct path___423 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___422 *, char *, size_t);
	int (*fiemap)(struct inode___422 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___422 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___422 *, struct dentry___422 *, struct file___422 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___422 *, struct dentry___422 *, umode_t);
	int (*set_acl)(struct inode___422 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___422 {
	void (*fl_copy_lock)(struct file_lock___422 *, struct file_lock___422 *);
	void (*fl_release_private)(struct file_lock___422 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___422;

struct file_lock___422 {
	struct file_lock___422 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___422 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___422 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___422 *fl_ops;
	const struct lock_manager_operations___422 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___422 {
	int (*lm_compare_owner)(struct file_lock___422 *, struct file_lock___422 *);
	long unsigned int (*lm_owner_key)(struct file_lock___422 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___422 *);
	int (*lm_grant)(struct file_lock___422 *, int);
	bool (*lm_break)(struct file_lock___422 *);
	int (*lm_change)(struct file_lock___422 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___422 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___422 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___422 *fa_next;
	struct file___422 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___422 {
	const char *name;
	int fs_flags;
	struct dentry___422 * (*mount)(struct file_system_type___422 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___422 *);
	struct module___352 *owner;
	struct file_system_type___422 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___422 {
	struct inode___422 * (*alloc_inode)(struct super_block___422 *);
	void (*destroy_inode)(struct inode___422 *);
	void (*dirty_inode)(struct inode___422 *, int);
	int (*write_inode)(struct inode___422 *, struct writeback_control___177 *);
	int (*drop_inode)(struct inode___422 *);
	void (*evict_inode)(struct inode___422 *);
	void (*put_super)(struct super_block___422 *);
	int (*sync_fs)(struct super_block___422 *, int);
	int (*freeze_super)(struct super_block___422 *);
	int (*freeze_fs)(struct super_block___422 *);
	int (*thaw_super)(struct super_block___422 *);
	int (*unfreeze_fs)(struct super_block___422 *);
	int (*statfs)(struct dentry___422 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___422 *, int *, char *);
	void (*umount_begin)(struct super_block___422 *);
	int (*show_options)(struct seq_file___361 *, struct dentry___422 *);
	int (*show_devname)(struct seq_file___361 *, struct dentry___422 *);
	int (*show_path)(struct seq_file___361 *, struct dentry___422 *);
	int (*show_stats)(struct seq_file___361 *, struct dentry___422 *);
	ssize_t (*quota_read)(struct super_block___422 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___422 *, int, const char *, size_t, loff_t);
	struct dquot___422 ** (*get_dquots)(struct inode___422 *);
	int (*bdev_try_to_free_page)(struct super_block___422 *, struct page___423 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___422 *, struct shrink_control___157 *);
	long int (*free_cached_objects)(struct super_block___422 *, struct shrink_control___157 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___214(struct bio___214 *);

struct bio_integrity_payload___214;

struct bio_set___214;

struct bio___214 {
	struct bio___214 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___214 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___214 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___216 *bi_io_vec;
	struct bio_set___214 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___216 bi_inline_vecs[0];
};

struct socket_wq___50 {
	wait_queue_head_t wait;
	struct fasync_struct___422 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___50;

struct socket___51 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___50 *wq;
	struct file___422 *file;
	struct sock___50 *sk;
	const struct proto_ops___50 *ops;
};

typedef int (*sk_read_actor_t___49)(read_descriptor_t *, struct sk_buff___69 *, unsigned int, size_t);

struct proto_ops___50 {
	int family;
	struct module___352 *owner;
	int (*release)(struct socket___51 *);
	int (*bind)(struct socket___51 *, struct sockaddr *, int);
	int (*connect)(struct socket___51 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___51 *, struct socket___51 *);
	int (*accept)(struct socket___51 *, struct socket___51 *, int, bool);
	int (*getname)(struct socket___51 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___422 *, struct socket___51 *, struct poll_table_struct___263 *);
	int (*ioctl)(struct socket___51 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___51 *, int);
	int (*shutdown)(struct socket___51 *, int);
	int (*setsockopt)(struct socket___51 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___51 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___51 *, struct msghdr___52 *, size_t);
	int (*recvmsg)(struct socket___51 *, struct msghdr___52 *, size_t, int);
	int (*mmap)(struct file___422 *, struct socket___51 *, struct vm_area_struct___423 *);
	ssize_t (*sendpage)(struct socket___51 *, struct page___423 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___51 *, loff_t *, struct pipe_inode_info___103 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___50 *, int);
	int (*peek_len)(struct socket___51 *);
	int (*read_sock)(struct sock___50 *, read_descriptor_t *, sk_read_actor_t___49);
	int (*sendpage_locked)(struct sock___50 *, struct page___423 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___50 *, struct msghdr___52 *, size_t);
	int (*set_rcvlowat)(struct sock___50 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct nf_bridge_info___67;

struct sk_buff___69 {
	union {
		struct {
			struct sk_buff___69 *next;
			struct sk_buff___69 *prev;
			union {
				struct net_device___68 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___50 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___69 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___67 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___67;

struct netns_frags___67 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___67 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_rules_ops___49;

struct fib_notifier_ops___50;

struct netns_ipv4___67 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___49 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___50 *fibnl;
	struct sock___50 **icmp_sk;
	struct sock___50 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___50 **tcp_sk;
	struct netns_frags___67 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___49 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___50 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___50 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___49;

struct dst_ops___78 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___78 *);
	struct dst_entry___49 * (*check)(struct dst_entry___49 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___49 *);
	unsigned int (*mtu)(const struct dst_entry___49 *);
	u32 * (*cow_metrics)(struct dst_entry___49 *, long unsigned int);
	void (*destroy)(struct dst_entry___49 *);
	void (*ifdown)(struct dst_entry___49 *, struct net_device___68 *, int);
	struct dst_entry___49 * (*negative_advice)(struct dst_entry___49 *);
	void (*link_failure)(struct sk_buff___69 *);
	void (*update_pmtu)(struct dst_entry___49 *, struct sock___50 *, struct sk_buff___69 *, u32);
	void (*redirect)(struct dst_entry___49 *, struct sock___50 *, struct sk_buff___69 *);
	int (*local_out)(struct net___79 *, struct sock___50 *, struct sk_buff___69 *);
	struct neighbour___49 * (*neigh_lookup)(const struct dst_entry___49 *, struct sk_buff___69 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___49 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___78 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___67 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___78 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___49 *fib6_rules_ops;
	struct sock___50 **icmp_sk;
	struct sock___50 *ndisc_sk;
	struct sock___50 *tcp_sk;
	struct sock___50 *igmp_sk;
	struct sock___50 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___49 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___50 *notifier_ops;
	struct fib_notifier_ops___50 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___50 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___50 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___67 {
	struct netns_frags___67 frags;
};

struct netns_xfrm___78 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___50 *nlsk;
	struct sock___50 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___78 xfrm4_dst_ops;
	struct dst_ops___78 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___59;

struct net___79 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___287 *user_ns;
	struct ucounts___287 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___29 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___50 *rtnl;
	struct sock___50 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___68 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___67 ipv4;
	struct netns_ipv6___78 ipv6;
	struct netns_sctp___50 sctp;
	struct netns_nf___4 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___67 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___50 *nfnl;
	struct sock___50 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___78 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___50 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___59 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___390 {
	int (*prepare)(struct device___390 *);
	void (*complete)(struct device___390 *);
	int (*suspend)(struct device___390 *);
	int (*resume)(struct device___390 *);
	int (*freeze)(struct device___390 *);
	int (*thaw)(struct device___390 *);
	int (*poweroff)(struct device___390 *);
	int (*restore)(struct device___390 *);
	int (*suspend_late)(struct device___390 *);
	int (*resume_early)(struct device___390 *);
	int (*freeze_late)(struct device___390 *);
	int (*thaw_early)(struct device___390 *);
	int (*poweroff_late)(struct device___390 *);
	int (*restore_early)(struct device___390 *);
	int (*suspend_noirq)(struct device___390 *);
	int (*resume_noirq)(struct device___390 *);
	int (*freeze_noirq)(struct device___390 *);
	int (*thaw_noirq)(struct device___390 *);
	int (*poweroff_noirq)(struct device___390 *);
	int (*restore_noirq)(struct device___390 *);
	int (*runtime_suspend)(struct device___390 *);
	int (*runtime_resume)(struct device___390 *);
	int (*runtime_idle)(struct device___390 *);
};

struct dev_pm_info___390 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___390 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___390;

struct bus_type___390;

struct device_driver___390;

struct dev_pm_domain___390;

struct dma_map_ops___162;

struct fwnode_handle___310;

struct class___390;

struct device___390 {
	struct device___390 *parent;
	struct device_private *p;
	struct kobject___410 kobj;
	const char *init_name;
	const struct device_type___390 *type;
	struct mutex mutex;
	struct bus_type___390 *bus;
	struct device_driver___390 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___390 power;
	struct dev_pm_domain___390 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___162 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___310 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___390 *class;
	const struct attribute_group___387 **groups;
	void (*release)(struct device___390 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___390 {
	struct dev_pm_ops___390 ops;
	void (*detach)(struct device___390 *, bool);
	int (*activate)(struct device___390 *);
	void (*sync)(struct device___390 *);
	void (*dismiss)(struct device___390 *);
};

struct bus_type___390 {
	const char *name;
	const char *dev_name;
	struct device___390 *dev_root;
	const struct attribute_group___387 **bus_groups;
	const struct attribute_group___387 **dev_groups;
	const struct attribute_group___387 **drv_groups;
	int (*match)(struct device___390 *, struct device_driver___390 *);
	int (*uevent)(struct device___390 *, struct kobj_uevent_env *);
	int (*probe)(struct device___390 *);
	int (*remove)(struct device___390 *);
	void (*shutdown)(struct device___390 *);
	int (*online)(struct device___390 *);
	int (*offline)(struct device___390 *);
	int (*suspend)(struct device___390 *, pm_message_t);
	int (*resume)(struct device___390 *);
	int (*num_vf)(struct device___390 *);
	int (*dma_configure)(struct device___390 *);
	const struct dev_pm_ops___390 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___390 {
	const char *name;
	struct bus_type___390 *bus;
	struct module___352 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___390 *);
	int (*remove)(struct device___390 *);
	void (*shutdown)(struct device___390 *);
	int (*suspend)(struct device___390 *, pm_message_t);
	int (*resume)(struct device___390 *);
	const struct attribute_group___387 **groups;
	const struct dev_pm_ops___390 *pm;
	void (*coredump)(struct device___390 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___390 {
	const char *name;
	const struct attribute_group___387 **groups;
	int (*uevent)(struct device___390 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___390 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___390 *);
	const struct dev_pm_ops___390 *pm;
};

struct class___390 {
	const char *name;
	struct module___352 *owner;
	const struct attribute_group___387 **class_groups;
	const struct attribute_group___387 **dev_groups;
	struct kobject___410 *dev_kobj;
	int (*dev_uevent)(struct device___390 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___390 *, umode_t *);
	void (*class_release)(struct class___390 *);
	void (*dev_release)(struct device___390 *);
	int (*shutdown_pre)(struct device___390 *);
	const struct kobj_ns_type_operations___49 *ns_type;
	const void * (*namespace)(struct device___390 *);
	const struct dev_pm_ops___390 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___162 {
	void * (*alloc)(struct device___390 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___390 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___390 *, struct vm_area_struct___423 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___390 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___390 *, struct page___423 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___390 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___390 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___390 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___390 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___390 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___390 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___390 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___390 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___390 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___390 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___390 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___390 *, u64);
	u64 (*get_required_mask)(struct device___390 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___310;

struct fwnode_handle___310 {
	struct fwnode_handle___310 *secondary;
	const struct fwnode_operations___310 *ops;
};

typedef void compound_page_dtor___410(struct page___423 *);

struct fwnode_reference_args___310;

struct fwnode_endpoint___310;

struct fwnode_operations___310 {
	struct fwnode_handle___310 * (*get)(struct fwnode_handle___310 *);
	void (*put)(struct fwnode_handle___310 *);
	bool (*device_is_available)(const struct fwnode_handle___310 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___310 *, const struct device___390 *);
	bool (*property_present)(const struct fwnode_handle___310 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___310 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___310 *, const char *, const char **, size_t);
	struct fwnode_handle___310 * (*get_parent)(const struct fwnode_handle___310 *);
	struct fwnode_handle___310 * (*get_next_child_node)(const struct fwnode_handle___310 *, struct fwnode_handle___310 *);
	struct fwnode_handle___310 * (*get_named_child_node)(const struct fwnode_handle___310 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___310 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___310 *);
	struct fwnode_handle___310 * (*graph_get_next_endpoint)(const struct fwnode_handle___310 *, struct fwnode_handle___310 *);
	struct fwnode_handle___310 * (*graph_get_remote_endpoint)(const struct fwnode_handle___310 *);
	struct fwnode_handle___310 * (*graph_get_port_parent)(struct fwnode_handle___310 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___310 *, struct fwnode_endpoint___310 *);
};

struct fwnode_endpoint___310 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___310 *local_fwnode;
};

struct fwnode_reference_args___310 {
	struct fwnode_handle___310 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___103;

struct pipe_buffer___103 {
	struct page___423 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___103 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___103 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___103 *, struct pipe_buffer___103 *);
	void (*release)(struct pipe_inode_info___103 *, struct pipe_buffer___103 *);
	int (*steal)(struct pipe_inode_info___103 *, struct pipe_buffer___103 *);
	union {
		bool (*get)(struct pipe_inode_info___103 *, struct pipe_buffer___103 *);
		struct {
			void (*get)(struct pipe_inode_info___103 *, struct pipe_buffer___103 *);
		} __UNIQUE_ID_rh_kabi_hide21;
		union {		};
	};
};

struct nf_bridge_info___67 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___67 = 0,
		BRNF_PROTO_8021Q___67 = 1,
		BRNF_PROTO_PPPOE___67 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___68 *physindev;
	struct net_device___68 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___67(struct sk_buff___69 **);

struct net_device_ops___67;

struct ethtool_ops___67;

struct l3mdev_ops___49;

struct xfrmdev_ops___67;

struct tlsdev_ops___67;

struct header_ops___67;

struct netdev_rx_queue___67;

struct mini_Qdisc___59;

struct netdev_queue___67;

struct Qdisc___59;

struct rtnl_link_ops___59;

struct dcbnl_rtnl_ops___67;

struct net_device___68 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___67 *netdev_ops;
	const struct ethtool_ops___67 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___49 *l3mdev_ops;
	const struct ndisc_ops___2 *ndisc_ops;
	const struct xfrmdev_ops___67 *xfrmdev_ops;
	const struct tlsdev_ops___67 *tlsdev_ops;
	const struct header_ops___67 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___409 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___2 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___67 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___59 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___67 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___59 *miniq_ingress;
	struct netdev_queue___67 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___67 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___59 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___59 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___67 = 0,
		NETREG_REGISTERED___67 = 1,
		NETREG_UNREGISTERING___67 = 2,
		NETREG_UNREGISTERED___67 = 3,
		NETREG_RELEASED___67 = 4,
		NETREG_DUMMY___67 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___67 = 0,
		RTNL_LINK_INITIALIZING___67 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___68 *);
	struct netpoll_info *npinfo;
	possible_net_t___69 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___390 dev;
	const struct attribute_group___387 *sysfs_groups[4];
	const struct attribute_group___387 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___59 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___67 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide35;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

typedef int (*key_restrict_link_func_t___391)(struct key___390 *, const struct key_type *, const union key_payload *, struct key___390 *);

struct key_restriction___390;

struct key___390 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___424 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___390 *restrict_link;
};

struct key_restriction___390 {
	key_restrict_link_func_t___391 check;
	struct key___390 *key;
	struct key_type *keytype;
};

struct seq_operations___361 {
	void * (*start)(struct seq_file___361 *, loff_t *);
	void (*stop)(struct seq_file___361 *, void *);
	void * (*next)(struct seq_file___361 *, void *, loff_t *);
	int (*show)(struct seq_file___361 *, void *);
};

struct cgroup_namespace___271 {
	refcount_t count;
	struct ns_common___29 ns;
	struct user_namespace___287 *user_ns;
	struct ucounts___287 *ucounts;
	struct css_set___271 *root_cset;
};

struct ucounts___287 {
	struct hlist_node node;
	struct user_namespace___287 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___272;

struct bpf_map_ops___271 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___272 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___272 *, struct file___422 *);
	void (*map_free)(struct bpf_map___272 *);
	int (*map_get_next_key)(struct bpf_map___272 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___272 *);
	void * (*map_lookup_elem)(struct bpf_map___272 *, void *);
	int (*map_update_elem)(struct bpf_map___272 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___272 *, void *);
	int (*map_push_elem)(struct bpf_map___272 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___272 *, void *);
	int (*map_peek_elem)(struct bpf_map___272 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___272 *, struct file___422 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___272 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___272 *, void *, struct seq_file___361 *);
	int (*map_check_btf)(const struct bpf_map___272 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___272 {
	const struct bpf_map_ops___271 *ops;
	struct bpf_map___272 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___390 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___67;

struct bpf_map_dev_ops___67 {
	int (*map_get_next_key)(struct bpf_offloaded_map___67 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___67 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___67 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___67 *, void *);
};

struct bpf_offloaded_map___67 {
	struct bpf_map___272 map;
	struct net_device___68 *netdev;
	const struct bpf_map_dev_ops___67 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___59 {
	int (*test_run)(struct bpf_prog___59 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_aux___62;

struct bpf_prog___59 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___62 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

struct bpf_verifier_ops___59 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___59 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___59 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___59 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___59 *, u32 *);
};

struct bpf_prog_offload_ops___59 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___59 *);
	int (*translate)(struct bpf_prog___59 *);
	void (*destroy)(struct bpf_prog___59 *);
};

struct bpf_prog_offload___59 {
	struct bpf_prog___59 *prog;
	struct net_device___68 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___59 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___62 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___59 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___59 *ops;
	struct bpf_map___272 **used_maps;
	struct bpf_prog___59 *prog;
	struct user_struct___390 *user;
	u64 load_time;
	struct bpf_map___272 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___59 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___59 {
	struct bpf_prog___59 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___59 {
	struct callback_head rcu;
	struct bpf_prog_array_item___59 items[0];
};

struct cgroup_bpf___59 {
	struct bpf_prog_array___59 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___59 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___272;

typedef void (*kthread_work_func_t___272)(struct kthread_work___272 *);

struct kthread_worker___272;

struct kthread_work___272 {
	struct list_head node;
	kthread_work_func_t___272 func;
	struct kthread_worker___272 *worker;
	int canceling;
};

struct kthread_worker___272 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___424 *task;
	struct kthread_work___272 *current_work;
};

struct kthread_delayed_work___271 {
	struct kthread_work___272 work;
	struct timer_list timer;
};

struct psi_group___271 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___272 *poll_kworker;
	struct kthread_delayed_work___271 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___271;

struct cgroup_rstat_cpu___271;

struct cgroup___271 {
	struct cgroup_subsys_state___271 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___417 *kn;
	struct cgroup_file___271 procs_file;
	struct cgroup_file___271 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___271 *subsys[13];
	struct cgroup_root___271 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___271 *dom_cgrp;
	struct cgroup_rstat_cpu___271 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___59 bpf;
	atomic_t congestion_count;
	struct cgroup___271 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___271 psi;
	int ancestor_ids[0];
};

struct cftype___271;

struct cgroup_subsys___271 {
	struct cgroup_subsys_state___271 * (*css_alloc)(struct cgroup_subsys_state___271 *);
	int (*css_online)(struct cgroup_subsys_state___271 *);
	void (*css_offline)(struct cgroup_subsys_state___271 *);
	void (*css_released)(struct cgroup_subsys_state___271 *);
	void (*css_free)(struct cgroup_subsys_state___271 *);
	void (*css_reset)(struct cgroup_subsys_state___271 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___271 *, int);
	int (*css_extra_stat_show)(struct seq_file___361 *, struct cgroup_subsys_state___271 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___424 *);
	void (*cancel_fork)(struct task_struct___424 *);
	void (*fork)(struct task_struct___424 *);
	void (*exit)(struct task_struct___424 *);
	void (*free)(struct task_struct___424 *);
	void (*bind)(struct cgroup_subsys_state___271 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___271 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___271 *dfl_cftypes;
	struct cftype___271 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___271 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___271 *updated_children;
	struct cgroup___271 *updated_next;
};

struct cgroup_root___271 {
	struct kernfs_root___416 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___271 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___271 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___271 *ss;
	struct list_head node;
	struct kernfs_ops___416 *kf_ops;
	int (*open)(struct kernfs_open_file___416 *);
	void (*release)(struct kernfs_open_file___416 *);
	u64 (*read_u64)(struct cgroup_subsys_state___271 *, struct cftype___271 *);
	s64 (*read_s64)(struct cgroup_subsys_state___271 *, struct cftype___271 *);
	int (*seq_show)(struct seq_file___361 *, void *);
	void * (*seq_start)(struct seq_file___361 *, loff_t *);
	void * (*seq_next)(struct seq_file___361 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___361 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___271 *, struct cftype___271 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___271 *, struct cftype___271 *, s64);
	ssize_t (*write)(struct kernfs_open_file___416 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___416 *, struct poll_table_struct___263 *);
};

struct ethtool_ops___67 {
	int (*get_settings)(struct net_device___68 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___68 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___68 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___68 *);
	void (*get_regs)(struct net_device___68 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___68 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___68 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___68 *);
	void (*set_msglevel)(struct net_device___68 *, u32);
	int (*nway_reset)(struct net_device___68 *);
	u32 (*get_link)(struct net_device___68 *);
	int (*get_eeprom_len)(struct net_device___68 *);
	int (*get_eeprom)(struct net_device___68 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___68 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___68 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___68 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___68 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___68 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___68 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___68 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___68 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___68 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___68 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___68 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___68 *);
	void (*complete)(struct net_device___68 *);
	u32 (*get_priv_flags)(struct net_device___68 *);
	int (*set_priv_flags)(struct net_device___68 *, u32);
	int (*get_sset_count)(struct net_device___68 *, int);
	int (*get_rxnfc)(struct net_device___68 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___68 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___68 *, struct ethtool_flash *);
	int (*reset)(struct net_device___68 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___68 *);
	u32 (*get_rxfh_indir_size)(struct net_device___68 *);
	int (*get_rxfh)(struct net_device___68 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___68 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___68 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___68 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___68 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___68 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___68 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___68 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___68 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___68 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___68 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___68 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___68 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___68 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___68 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___68 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___68 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___68 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___68 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___68 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___68 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___68 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	int (*get_fecparam)(struct net_device___68 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___68 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___68 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___68 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___68 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___67;

struct inet_frags___67 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___67 *, const void *);
	void (*destructor)(struct inet_frag_queue___67 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___67 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___69 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___69 *fragments_tail;
	struct sk_buff___69 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___67 *net;
	struct callback_head rcu;
};

struct fib_rule___49;

struct fib_lookup_arg___49;

struct fib_rules_ops___49 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___49 *, struct flowi *, int, struct fib_lookup_arg___49 *);
	bool (*suppress)(struct fib_rule___49 *, struct fib_lookup_arg___49 *);
	int (*match)(struct fib_rule___49 *, struct flowi *, int);
	int (*configure)(struct fib_rule___49 *, struct sk_buff___69 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___49 *);
	int (*compare)(struct fib_rule___49 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___49 *, struct sk_buff___69 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___49 *);
	void (*flush_cache)(struct fib_rules_ops___49 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___352 *owner;
	struct net___79 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___50 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___79 *);
	int (*fib_dump)(struct net___79 *, struct notifier_block *);
	struct module___352 *owner;
	struct callback_head rcu;
};

struct dst_entry___49 {
	struct net_device___68 *dev;
	struct dst_ops___78 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___69 *);
	int (*output)(struct net___79 *, struct sock___50 *, struct sk_buff___69 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___49;

struct neigh_parms___49;

struct neigh_ops___49;

struct neighbour___49 {
	struct neighbour___49 *next;
	struct neigh_table___49 *tbl;
	struct neigh_parms___49 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___67 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___49 *, struct sk_buff___69 *);
	const struct neigh_ops___49 *ops;
	struct callback_head rcu;
	struct net_device___68 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct pernet_operations___68 {
	struct list_head list;
	int (*init)(struct net___79 *);
	void (*exit)(struct net___79 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___67 {
	int (*ieee_getets)(struct net_device___68 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___68 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___68 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___68 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___68 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___68 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___68 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___68 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___68 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___68 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___68 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___68 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___68 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___68 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___68 *);
	u8 (*setstate)(struct net_device___68 *, u8);
	void (*getpermhwaddr)(struct net_device___68 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___68 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___68 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___68 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___68 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___68 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___68 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___68 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___68 *, int, u8 *);
	void (*setpfccfg)(struct net_device___68 *, int, u8);
	void (*getpfccfg)(struct net_device___68 *, int, u8 *);
	u8 (*setall)(struct net_device___68 *);
	u8 (*getcap)(struct net_device___68 *, int, u8 *);
	int (*getnumtcs)(struct net_device___68 *, int, u8 *);
	int (*setnumtcs)(struct net_device___68 *, int, u8);
	u8 (*getpfcstate)(struct net_device___68 *);
	void (*setpfcstate)(struct net_device___68 *, u8);
	void (*getbcncfg)(struct net_device___68 *, int, u32 *);
	void (*setbcncfg)(struct net_device___68 *, int, u32);
	void (*getbcnrp)(struct net_device___68 *, int, u8 *);
	void (*setbcnrp)(struct net_device___68 *, int, u8);
	int (*setapp)(struct net_device___68 *, u8, u16, u8);
	int (*getapp)(struct net_device___68 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___68 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___68 *, int, u8);
	u8 (*getdcbx)(struct net_device___68 *);
	u8 (*setdcbx)(struct net_device___68 *, u8);
	int (*peer_getappinfo)(struct net_device___68 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___68 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___68 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___68 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___68 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___68 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct xdp_rxq_info___67 {
	struct net_device___68 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___67 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___68 *dev_rx;
};

struct netlink_callback___69 {
	struct sk_buff___69 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___69 *);
	int (*dump)(struct sk_buff___69 *, struct netlink_callback___69 *);
	int (*done)(struct netlink_callback___69 *);
	void *data;
	struct module___352 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___67 {
	int (*create)(struct sk_buff___69 *, struct net_device___68 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___69 *, unsigned char *);
	int (*cache)(const struct neighbour___49 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___68 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___67 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___67 *, int);
	int poll_owner;
	struct net_device___68 *dev;
	struct sk_buff___69 *gro_list;
	struct sk_buff___69 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___67 {
	struct net_device___68 *dev;
	struct Qdisc___59 *qdisc;
	struct Qdisc___59 *qdisc_sleeping;
	struct kobject___410 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___68 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem___3 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___59 {
	struct sk_buff___69 *head;
	struct sk_buff___69 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___59;

struct Qdisc___59 {
	int (*enqueue)(struct sk_buff___69 *, struct Qdisc___59 *, struct sk_buff___69 **);
	struct sk_buff___69 * (*dequeue)(struct Qdisc___59 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___59 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___67 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___67 gso_skb;
	struct qdisc_skb_head___59 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___59 *next_sched;
	struct sk_buff_head___67 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___67 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___410 kobj;
	struct net_device___68 *dev;
	long: 64;
	struct xdp_rxq_info___67 xdp_rxq;
	union {
		struct xdp_umem___3 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___67)(struct net_device___68 *, struct sk_buff___69 *, struct net_device___68 *);

struct netdev_bpf___67 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___59 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___59 *prog;
			const struct bpf_prog_offload_ops___59 *ops;
		} verifier;
		struct {
			struct bpf_prog___59 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___67 *offmap;
		};
		struct {
			struct xdp_umem___3 *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___67 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___69 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___67 {
	int (*tls_dev_add)(struct net_device___68 *, struct sock___50 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___68 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___68 *, struct sock___50 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___67 {
	int (*ndo_init)(struct net_device___68 *);
	void (*ndo_uninit)(struct net_device___68 *);
	int (*ndo_open)(struct net_device___68 *);
	int (*ndo_stop)(struct net_device___68 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___69 *, struct net_device___68 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___69 *, struct net_device___68 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___68 *, struct sk_buff___69 *, struct net_device___68 *, select_queue_fallback_t___67);
	void (*ndo_change_rx_flags)(struct net_device___68 *, int);
	void (*ndo_set_rx_mode)(struct net_device___68 *);
	int (*ndo_set_mac_address)(struct net_device___68 *, void *);
	int (*ndo_validate_addr)(struct net_device___68 *);
	int (*ndo_do_ioctl)(struct net_device___68 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___68 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___68 *, int);
	int (*ndo_neigh_setup)(struct net_device___68 *, struct neigh_parms___49 *);
	void (*ndo_tx_timeout)(struct net_device___68 *);
	void (*ndo_get_stats64)(struct net_device___68 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___68 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___68 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___68 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___68 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___68 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___68 *);
	int (*ndo_netpoll_setup)(struct net_device___68 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___68 *);
	int (*ndo_set_vf_mac)(struct net_device___68 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___68 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___68 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___68 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___68 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___68 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___68 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___68 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___68 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___68 *, int, struct sk_buff___69 *);
	int (*ndo_set_vf_guid)(struct net_device___68 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___68 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___68 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___68 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___68 *, const struct sk_buff___69 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___68 *, struct net_device___68 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___68 *, struct net_device___68 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___68 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___68 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___68 *, struct neighbour___49 *);
	void (*ndo_neigh_destroy)(struct net_device___68 *, struct neighbour___49 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___68 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___68 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___68 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___69 *, struct netlink_callback___69 *, struct net_device___68 *, struct net_device___68 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___68 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___68 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___69 *, u32, u32, struct net_device___68 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___68 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___68 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___68 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___68 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___68 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___68 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___68 *, struct net_device___68 *);
	void (*ndo_dfwd_del_station)(struct net_device___68 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___68 *);
	int (*ndo_set_tx_maxrate)(struct net_device___68 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___68 *);
	int (*ndo_change_proto_down)(struct net_device___68 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___68 *, struct sk_buff___69 *);
	void (*ndo_set_rx_headroom)(struct net_device___68 *, int);
	int (*ndo_bpf)(struct net_device___68 *, struct netdev_bpf___67 *);
	int (*ndo_xdp_xmit)(struct net_device___68 *, int, struct xdp_frame___67 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___68 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___68 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___49 {
	possible_net_t___69 net;
	struct net_device___68 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___49 *);
	void (*neigh_cleanup)(struct neighbour___49 *);
	struct neigh_table___49 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___49 {
	u32 (*l3mdev_fib_table)(const struct net_device___68 *);
	struct sk_buff___69 * (*l3mdev_l3_rcv)(struct net_device___68 *, struct sk_buff___69 *, u16);
	struct sk_buff___69 * (*l3mdev_l3_out)(struct net_device___68 *, struct sock___50 *, struct sk_buff___69 *, u16);
	struct dst_entry___49 * (*l3mdev_link_scope_lookup)(const struct net_device___68 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct tcf_proto___59;

struct mini_Qdisc___59 {
	struct tcf_proto___59 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___59 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___68 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___79 *, struct net_device___68 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___68 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___68 *, struct list_head *);
	size_t (*get_size)(const struct net_device___68 *);
	int (*fill_info)(struct sk_buff___69 *, const struct net_device___68 *);
	size_t (*get_xstats_size)(const struct net_device___68 *);
	int (*fill_xstats)(struct sk_buff___69 *, const struct net_device___68 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___68 *, struct net_device___68 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___68 *, const struct net_device___68 *);
	int (*fill_slave_info)(struct sk_buff___69 *, const struct net_device___68 *, const struct net_device___68 *);
	struct net___79 * (*get_link_net)(const struct net_device___68 *);
	size_t (*get_linkxstats_size)(const struct net_device___68 *, int);
	int (*fill_linkxstats)(struct sk_buff___69 *, const struct net_device___68 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct netdev_notifier_info___7 {
	struct net_device___68 *dev;
	struct netlink_ext_ack *extack;
};

struct softnet_data___67 {
	struct list_head poll_list;
	struct sk_buff_head___67 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___67 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___59 *output_queue;
	struct Qdisc___59 **output_queue_tailp;
	struct sk_buff___69 *completion_queue;
	struct sk_buff_head___67 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___67 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___67 input_pkt_queue;
	struct napi_struct___67 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct gnet_dump___59 {
	spinlock_t *lock;
	struct sk_buff___69 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___59;

struct Qdisc_ops___59 {
	struct Qdisc_ops___59 *next;
	const struct Qdisc_class_ops___59 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___69 *, struct Qdisc___59 *, struct sk_buff___69 **);
	struct sk_buff___69 * (*dequeue)(struct Qdisc___59 *);
	struct sk_buff___69 * (*peek)(struct Qdisc___59 *);
	int (*init)(struct Qdisc___59 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___59 *);
	void (*destroy)(struct Qdisc___59 *);
	int (*change)(struct Qdisc___59 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___59 *);
	int (*change_tx_queue_len)(struct Qdisc___59 *, unsigned int);
	int (*dump)(struct Qdisc___59 *, struct sk_buff___69 *);
	int (*dump_stats)(struct Qdisc___59 *, struct gnet_dump___59 *);
	void (*ingress_block_set)(struct Qdisc___59 *, u32);
	void (*egress_block_set)(struct Qdisc___59 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___59 *);
	u32 (*egress_block_get)(struct Qdisc___59 *);
	struct module___352 *owner;
};

struct qdisc_walker___5;

struct tcf_block___59;

struct Qdisc_class_ops___59 {
	unsigned int flags;
	struct netdev_queue___67 * (*select_queue)(struct Qdisc___59 *, struct tcmsg *);
	int (*graft)(struct Qdisc___59 *, long unsigned int, struct Qdisc___59 *, struct Qdisc___59 **, struct netlink_ext_ack *);
	struct Qdisc___59 * (*leaf)(struct Qdisc___59 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___59 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___59 *, u32);
	int (*change)(struct Qdisc___59 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___59 *, long unsigned int);
	void (*walk)(struct Qdisc___59 *, struct qdisc_walker___5 *);
	struct tcf_block___59 * (*tcf_block)(struct Qdisc___59 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___59 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___59 *, long unsigned int);
	int (*dump)(struct Qdisc___59 *, long unsigned int, struct sk_buff___69 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___59 *, long unsigned int, struct gnet_dump___59 *);
};

struct qdisc_walker___5 {
	int stop;
	int skip;
	int count;
	int (*fn)(struct Qdisc___59 *, long unsigned int, struct qdisc_walker___5 *);
};

struct tcf_chain___59;

struct tcf_block___59 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___79 *net;
	struct Qdisc___59 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___59 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___59;

struct tcf_proto_ops___59;

struct tcf_proto___59 {
	struct tcf_proto___59 *next;
	void *root;
	int (*classify)(struct sk_buff___69 *, const struct tcf_proto___59 *, struct tcf_result___59 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___59 *ops;
	struct tcf_chain___59 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___59 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___59 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_walker___3;

struct tcf_proto_ops___59 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___69 *, const struct tcf_proto___59 *, struct tcf_result___59 *);
	int (*init)(struct tcf_proto___59 *);
	void (*destroy)(struct tcf_proto___59 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___59 *, u32);
	void (*put)(struct tcf_proto___59 *, void *);
	int (*change)(struct net___79 *, struct sk_buff___69 *, struct tcf_proto___59 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___59 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___59 *, struct tcf_walker___3 *, bool);
	int (*reoffload)(struct tcf_proto___59 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___79 *, struct tcf_chain___59 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___79 *, struct tcf_proto___59 *, void *, struct sk_buff___69 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___69 *, struct net___79 *, void *);
	struct module___352 *owner;
	int flags;
};

struct tcf_walker___3 {
	int stop;
	int skip;
	int count;
	bool nonempty;
	long unsigned int cookie;
	int (*fn)(struct tcf_proto___59 *, void *, struct tcf_walker___3 *);
};

struct tcf_chain___59 {
	struct mutex filter_chain_lock;
	struct tcf_proto___59 *filter_chain;
	struct list_head list;
	struct tcf_block___59 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___59 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct bdi_writeback_congested___214 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___214 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___214 {
	struct bio___214 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___216 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___216 bip_inline_vecs[0];
};

struct bio_set___214 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___214 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___157 {
	struct mem_cgroup___157 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___157 {
	struct lruvec___423 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___157 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___157 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct sk_filter___49 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___59 *prog;
};

struct bpf_redirect_info___59 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___272 *map;
	struct bpf_map___272 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___49;

struct neigh_hash_table___49;

struct neigh_table___49 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___68 *, __u32 *);
	bool (*key_eq)(const struct neighbour___49 *, const void *);
	int (*constructor)(struct neighbour___49 *);
	int (*pconstructor)(struct pneigh_entry___49 *);
	void (*pdestructor)(struct pneigh_entry___49 *);
	void (*proxy_redo)(struct sk_buff___69 *);
	char *id;
	struct neigh_parms___49 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___67 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___49 *nht;
	struct pneigh_entry___49 **phash_buckets;
};

struct neigh_ops___49 {
	int family;
	void (*solicit)(struct neighbour___49 *, struct sk_buff___69 *);
	void (*error_report)(struct neighbour___49 *, struct sk_buff___69 *);
	int (*output)(struct neighbour___49 *, struct sk_buff___69 *);
	int (*connected_output)(struct neighbour___49 *, struct sk_buff___69 *);
};

struct pneigh_entry___49 {
	struct pneigh_entry___49 *next;
	possible_net_t___69 net;
	struct net_device___68 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___49 {
	struct neighbour___49 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___49 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___49 *ctarget;
	struct net___79 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___49 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___49 *rule;
	u32 table;
	int flags;
};

struct proto___49 {
	void (*close)(struct sock___50 *, long int);
	int (*pre_connect)(struct sock___50 *, struct sockaddr *, int);
	int (*connect)(struct sock___50 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___50 *, int);
	struct sock___50 * (*accept)(struct sock___50 *, int, int *, bool);
	int (*ioctl)(struct sock___50 *, int, long unsigned int);
	int (*init)(struct sock___50 *);
	void (*destroy)(struct sock___50 *);
	void (*shutdown)(struct sock___50 *, int);
	int (*setsockopt)(struct sock___50 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___50 *, int, int, char *, int *);
	void (*keepalive)(struct sock___50 *, int);
	int (*sendmsg)(struct sock___50 *, struct msghdr___52 *, size_t);
	int (*recvmsg)(struct sock___50 *, struct msghdr___52 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___50 *, struct page___423 *, int, size_t, int);
	int (*bind)(struct sock___50 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___50 *, struct sk_buff___69 *);
	void (*release_cb)(struct sock___50 *);
	int (*hash)(struct sock___50 *);
	void (*unhash)(struct sock___50 *);
	void (*rehash)(struct sock___50 *);
	int (*get_port)(struct sock___50 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___50 *);
	bool (*stream_memory_read)(const struct sock___50 *);
	void (*enter_memory_pressure)(struct sock___50 *);
	void (*leave_memory_pressure)(struct sock___50 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___3 *rsk_prot;
	struct timewait_sock_ops___3 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___352 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___50 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct module___353;

struct file___423;

struct kiocb___423;

struct iov_iter___190;

struct poll_table_struct___264;

struct vm_area_struct___424;

struct inode___423;

struct file_lock___423;

struct page___424;

struct pipe_inode_info___104;

struct seq_file___362;

struct file_operations___423 {
	struct module___353 *owner;
	loff_t (*llseek)(struct file___423 *, loff_t, int);
	ssize_t (*read)(struct file___423 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___423 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___423 *, struct iov_iter___190 *);
	ssize_t (*write_iter)(struct kiocb___423 *, struct iov_iter___190 *);
	int (*iopoll)(struct kiocb___423 *, bool);
	int (*iterate)(struct file___423 *, struct dir_context *);
	int (*iterate_shared)(struct file___423 *, struct dir_context *);
	__poll_t (*poll)(struct file___423 *, struct poll_table_struct___264 *);
	long int (*unlocked_ioctl)(struct file___423 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___423 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___423 *, struct vm_area_struct___424 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___423 *, struct file___423 *);
	int (*flush)(struct file___423 *, fl_owner_t);
	int (*release)(struct inode___423 *, struct file___423 *);
	int (*fsync)(struct file___423 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___423 *, int);
	int (*lock)(struct file___423 *, int, struct file_lock___423 *);
	ssize_t (*sendpage)(struct file___423 *, struct page___424 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___423 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___423 *, int, struct file_lock___423 *);
	ssize_t (*splice_write)(struct pipe_inode_info___104 *, struct file___423 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___423 *, loff_t *, struct pipe_inode_info___104 *, size_t, unsigned int);
	int (*setlease)(struct file___423 *, long int, struct file_lock___423 **, void **);
	long int (*fallocate)(struct file___423 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___362 *, struct file___423 *);
	ssize_t (*copy_file_range)(struct file___423 *, loff_t, struct file___423 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___423 *, loff_t, struct file___423 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___423 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___424 {
	u64 seqnum;
	struct vm_area_struct___424 *vmas[4];
};

struct page_frag___424 {
	struct page___424 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___424;

struct mem_cgroup___158;

struct cred___391;

struct files_struct___19;

struct nsproxy___318;

struct signal_struct___298;

struct bio_list___215;

struct backing_dev_info___215;

struct css_set___272;

struct vm_struct___327;

struct task_struct___425 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___425 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___424 *mm;
	struct mm_struct___424 *active_mm;
	struct vmacache___424 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___425 *real_parent;
	struct task_struct___425 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___425 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___158 *active_memcg;
	long int rh_reserved2;
	struct pid___239 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___239 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___239 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___391 *ptracer_cred;
	const struct cred___391 *real_cred;
	const struct cred___391 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct___19 *files;
	struct nsproxy___318 *nsproxy;
	struct signal_struct___298 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___425 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___215 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___215 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___272 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___104 *splice_pipe;
	struct page_frag___424 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___158 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___425 *oom_reaper_list;
	struct vm_struct___327 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___155 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___424 *pgtable_t___424;

struct address_space___423;

struct dev_pagemap___411;

struct page___424 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___423 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___424 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___424 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___424 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___411 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___158 *mem_cgroup;
};

struct pglist_data___424;

struct lruvec___424 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___424 *pgdat;
};

struct zone___424 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___424 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___424 {
	struct zone___424 *zone;
	int zone_idx;
};

struct zonelist___424 {
	struct zoneref___424 _zonerefs[25];
};

struct pglist_data___424 {
	struct zone___424 node_zones[3];
	struct zonelist___424 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___425 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___425 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___424 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___425 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___425 *owner;
};

struct secondary_data___425 {
	void *stack;
	struct task_struct___425 *task;
	long int status;
};

struct blocking_notifier_head___424 {
	struct rw_semaphore___425 rwsem;
	struct notifier_block *head;
};

struct cgroup___272;

struct cgroup_subsys___272;

struct cgroup_subsys_state___272 {
	struct cgroup___272 *cgroup;
	struct cgroup_subsys___272 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___272 *parent;
};

struct kernfs_node___418;

struct cgroup_file___272 {
	struct kernfs_node___418 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___158;

struct mem_cgroup___158 {
	struct cgroup_subsys_state___272 css;
	struct mem_cgroup_id___16 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___272 events_file;
	struct cgroup_file___272 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___425 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___158 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct key___391;

struct ucounts___288;

struct user_namespace___288 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___288 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___29 ns;
	long unsigned int flags;
	struct key___391 *persistent_keyring_register;
	struct rw_semaphore___425 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___288 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct user_struct___391 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___391 *uid_keyring;
	struct key___391 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___411;

struct vm_area_struct___424 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___424 *vm_next;
	struct vm_area_struct___424 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___424 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___411 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___423 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___424;

struct mm_struct___424 {
	struct {
		struct vm_area_struct___424 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___423 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___425 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___424 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___425 *owner;
		struct user_namespace___288 *user_ns;
		struct file___423 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___424 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___391 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___391 *session_keyring;
	struct key___391 *process_keyring;
	struct key___391 *thread_keyring;
	struct key___391 *request_key_auth;
	void *security;
	struct user_struct___391 *user;
	struct user_namespace___288 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct fdtable___19 {
	unsigned int max_fds;
	struct file___423 **fd;
	long unsigned int *close_on_exec;
	long unsigned int *open_fds;
	long unsigned int *full_fds_bits;
	struct callback_head rcu;
};

struct files_struct___19 {
	atomic_t count;
	bool resize_in_progress;
	wait_queue_head_t resize_wait;
	struct fdtable___19 *fdt;
	struct fdtable___19 fdtab;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t file_lock;
	unsigned int next_fd;
	long unsigned int close_on_exec_init[1];
	long unsigned int open_fds_init[1];
	long unsigned int full_fds_bits_init[1];
	struct file___423 *fd_array[64];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net___80;

struct cgroup_namespace___272;

struct nsproxy___318 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net___80 *net_ns;
	struct cgroup_namespace___272 *cgroup_ns;
};

struct signal_struct___298 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___425 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___425 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___239 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___239 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___424 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___239 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___215;

struct bio_list___215 {
	struct bio___215 *head;
	struct bio___215 *tail;
};

struct bdi_writeback_congested___215;

struct bdi_writeback___215 {
	struct backing_dev_info___215 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___215 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___272 *memcg_css;
	struct cgroup_subsys_state___272 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___391;

struct dentry___423;

struct backing_dev_info___215 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___215 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___391 *dev;
	struct device___391 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___423 *debug_dir;
	struct dentry___423 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___272 {
	struct cgroup_subsys_state___272 *subsys[13];
	refcount_t refcount;
	struct css_set___272 *dom_cset;
	struct cgroup___272 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___272 *mg_src_cgrp;
	struct cgroup___272 *mg_dst_cgrp;
	struct css_set___272 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___423;

struct pipe_buffer___104;

struct pipe_inode_info___104 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___424 *tmp_page;
	struct fasync_struct___423 *fasync_readers;
	struct fasync_struct___423 *fasync_writers;
	struct pipe_buffer___104 *bufs;
	struct user_struct___391 *user;
};

struct vm_struct___327 {
	struct vm_struct___327 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___424 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___310 {
	struct task_struct___425 task;
	long unsigned int stack[8192];
};

struct dentry_operations___423;

struct super_block___423;

struct dentry___423 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___423 *d_parent;
	struct qstr d_name;
	struct inode___423 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___423 *d_op;
	struct super_block___423 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___423;

struct address_space___423 {
	struct inode___423 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___425 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___423 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___423;

struct block_device___423;

struct inode___423 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___423 *i_op;
	struct super_block___423 *i_sb;
	struct address_space___423 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___425 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___215 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___423 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___423 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___104 *i_pipe;
		struct block_device___423 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct path___424;

struct dentry_operations___423 {
	int (*d_revalidate)(struct dentry___423 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___423 *, unsigned int);
	int (*d_hash)(const struct dentry___423 *, struct qstr *);
	int (*d_compare)(const struct dentry___423 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___423 *);
	int (*d_init)(struct dentry___423 *);
	void (*d_release)(struct dentry___423 *);
	void (*d_prune)(struct dentry___423 *);
	void (*d_iput)(struct dentry___423 *, struct inode___423 *);
	char * (*d_dname)(struct dentry___423 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___424 *);
	int (*d_manage)(const struct path___424 *, bool);
	struct dentry___423 * (*d_real)(struct dentry___423 *, const struct inode___423 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___423;

struct mem_dqinfo___423 {
	struct quota_format_type___423 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___423;

struct quota_info___423 {
	unsigned int flags;
	struct rw_semaphore___425 dqio_sem;
	struct inode___423 *files[3];
	struct mem_dqinfo___423 info[3];
	const struct quota_format_ops___423 *ops[3];
};

struct rcuwait___423 {
	struct task_struct___425 *task;
};

struct percpu_rw_semaphore___423 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___425 rw_sem;
	struct rcuwait___423 writer;
	int readers_block;
};

struct sb_writers___423 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___423 rw_sem[3];
};

struct shrink_control___158;

struct shrinker___158 {
	long unsigned int (*count_objects)(struct shrinker___158 *, struct shrink_control___158 *);
	long unsigned int (*scan_objects)(struct shrinker___158 *, struct shrink_control___158 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___423;

struct super_operations___423;

struct dquot_operations___423;

struct quotactl_ops___423;

struct super_block___423 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___423 *s_type;
	const struct super_operations___423 *s_op;
	const struct dquot_operations___423 *dq_op;
	const struct quotactl_ops___423 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___423 *s_root;
	struct rw_semaphore___425 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___423 *s_bdev;
	struct backing_dev_info___215 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___423 s_dquot;
	struct sb_writers___423 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___423 *s_d_op;
	int cleancache_poolid;
	struct shrinker___158 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___288 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct path___424 {
	struct vfsmount *mnt;
	struct dentry___423 *dentry;
};

struct shrink_control___158 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___158 *memcg;
};

typedef int (*dev_page_fault_t___411)(struct vm_area_struct___424 *, long unsigned int, const struct page___424 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___411)(struct page___424 *, void *);

struct dev_pagemap___411 {
	dev_page_fault_t___411 page_fault;
	dev_page_free_t___411 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___391 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct file___423 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___424 f_path;
	struct inode___423 *f_inode;
	const struct file_operations___423 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___239 f_owner;
	const struct cred___391 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___423 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___411;

struct vm_operations_struct___411 {
	void (*open)(struct vm_area_struct___424 *);
	void (*close)(struct vm_area_struct___424 *);
	int (*split)(struct vm_area_struct___424 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___424 *);
	vm_fault_t (*fault)(struct vm_fault___411 *);
	vm_fault_t (*huge_fault)(struct vm_fault___411 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___411 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___424 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___411 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___411 *);
	int (*access)(struct vm_area_struct___424 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___424 *);
	int (*set_policy)(struct vm_area_struct___424 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___424 *, long unsigned int);
	struct page___424 * (*find_special_page)(struct vm_area_struct___424 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___424 {
	struct task_struct___425 *task;
	struct core_thread___424 *next;
};

struct core_state___424 {
	atomic_t nr_threads;
	struct core_thread___424 dumper;
	struct completion startup;
};

struct vm_fault___411 {
	struct vm_area_struct___424 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___424 *cow_page;
	struct mem_cgroup___158 *memcg;
	struct page___424 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___424 prealloc_pte;
};

struct kiocb___423 {
	struct file___423 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___423 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___423 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___423 *ia_file;
};

struct dquot___423 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___423 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___423 {
	int qf_fmt_id;
	const struct quota_format_ops___423 *qf_ops;
	struct module___353 *qf_owner;
	struct quota_format_type___423 *qf_next;
};

struct quota_format_ops___423 {
	int (*check_quota_file)(struct super_block___423 *, int);
	int (*read_file_info)(struct super_block___423 *, int);
	int (*write_file_info)(struct super_block___423 *, int);
	int (*free_file_info)(struct super_block___423 *, int);
	int (*read_dqblk)(struct dquot___423 *);
	int (*commit_dqblk)(struct dquot___423 *);
	int (*release_dqblk)(struct dquot___423 *);
	int (*get_next_id)(struct super_block___423 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___423 {
	int (*write_dquot)(struct dquot___423 *);
	struct dquot___423 * (*alloc_dquot)(struct super_block___423 *, int);
	void (*destroy_dquot)(struct dquot___423 *);
	int (*acquire_dquot)(struct dquot___423 *);
	int (*release_dquot)(struct dquot___423 *);
	int (*mark_dirty)(struct dquot___423 *);
	int (*write_info)(struct super_block___423 *, int);
	qsize_t * (*get_reserved_space)(struct inode___423 *);
	int (*get_projid)(struct inode___423 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___423 *, qsize_t *);
	int (*get_next_id)(struct super_block___423 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___423 {
	int (*quota_on)(struct super_block___423 *, int, int, const struct path___424 *);
	int (*quota_off)(struct super_block___423 *, int);
	int (*quota_enable)(struct super_block___423 *, unsigned int);
	int (*quota_disable)(struct super_block___423 *, unsigned int);
	int (*quota_sync)(struct super_block___423 *, int);
	int (*set_info)(struct super_block___423 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___423 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___423 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___423 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___423 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___423 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___410;

struct kobj_type___410;

struct kobject___411 {
	const char *name;
	struct list_head entry;
	struct kobject___411 *parent;
	struct kset___410 *kset;
	struct kobj_type___410 *ktype;
	struct kernfs_node___418 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___351 {
	struct kobject___411 kobj;
	struct module___353 *mod;
	struct kobject___411 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___351 {
	struct module___353 *mod;
	struct latch_tree_node node;
};

struct module_layout___351 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___351 mtn;
};

struct module_attribute___351;

struct kernel_param___351;

struct module___353 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___351 mkobj;
	struct module_attribute___351 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___411 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___351 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___351 core_layout;
	struct module_layout___351 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide53;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide54;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___178;

struct address_space_operations___423 {
	int (*writepage)(struct page___424 *, struct writeback_control___178 *);
	int (*readpage)(struct file___423 *, struct page___424 *);
	int (*writepages)(struct address_space___423 *, struct writeback_control___178 *);
	int (*set_page_dirty)(struct page___424 *);
	int (*readpages)(struct file___423 *, struct address_space___423 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___423 *, struct address_space___423 *, loff_t, unsigned int, unsigned int, struct page___424 **, void **);
	int (*write_end)(struct file___423 *, struct address_space___423 *, loff_t, unsigned int, unsigned int, struct page___424 *, void *);
	sector_t (*bmap)(struct address_space___423 *, sector_t);
	void (*invalidatepage)(struct page___424 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___424 *, gfp_t);
	void (*freepage)(struct page___424 *);
	ssize_t (*direct_IO)(struct kiocb___423 *, struct iov_iter___190 *);
	int (*migratepage)(struct address_space___423 *, struct page___424 *, struct page___424 *, enum migrate_mode);
	bool (*isolate_page)(struct page___424 *, isolate_mode_t);
	void (*putback_page)(struct page___424 *);
	int (*launder_page)(struct page___424 *);
	int (*is_partially_uptodate)(struct page___424 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___424 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___423 *, struct page___424 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___423 *, sector_t *);
	void (*swap_deactivate)(struct file___423 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___178 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___215 *wb;
	struct inode___423 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___217;

struct iov_iter___190 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___217 *bvec;
		struct pipe_inode_info___104 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___423 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___423 *bd_inode;
	struct super_block___423 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___423 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___215 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___423 {
	struct dentry___423 * (*lookup)(struct inode___423 *, struct dentry___423 *, unsigned int);
	const char * (*get_link)(struct dentry___423 *, struct inode___423 *, struct delayed_call *);
	int (*permission)(struct inode___423 *, int);
	struct posix_acl * (*get_acl)(struct inode___423 *, int);
	int (*readlink)(struct dentry___423 *, char *, int);
	int (*create)(struct inode___423 *, struct dentry___423 *, umode_t, bool);
	int (*link)(struct dentry___423 *, struct inode___423 *, struct dentry___423 *);
	int (*unlink)(struct inode___423 *, struct dentry___423 *);
	int (*symlink)(struct inode___423 *, struct dentry___423 *, const char *);
	int (*mkdir)(struct inode___423 *, struct dentry___423 *, umode_t);
	int (*rmdir)(struct inode___423 *, struct dentry___423 *);
	int (*mknod)(struct inode___423 *, struct dentry___423 *, umode_t, dev_t);
	int (*rename)(struct inode___423 *, struct dentry___423 *, struct inode___423 *, struct dentry___423 *, unsigned int);
	int (*setattr)(struct dentry___423 *, struct iattr___423 *);
	int (*getattr)(const struct path___424 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___423 *, char *, size_t);
	int (*fiemap)(struct inode___423 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___423 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___423 *, struct dentry___423 *, struct file___423 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___423 *, struct dentry___423 *, umode_t);
	int (*set_acl)(struct inode___423 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___423 {
	void (*fl_copy_lock)(struct file_lock___423 *, struct file_lock___423 *);
	void (*fl_release_private)(struct file_lock___423 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___423;

struct file_lock___423 {
	struct file_lock___423 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___423 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___423 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___423 *fl_ops;
	const struct lock_manager_operations___423 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___423 {
	int (*lm_compare_owner)(struct file_lock___423 *, struct file_lock___423 *);
	long unsigned int (*lm_owner_key)(struct file_lock___423 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___423 *);
	int (*lm_grant)(struct file_lock___423 *, int);
	bool (*lm_break)(struct file_lock___423 *);
	int (*lm_change)(struct file_lock___423 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___423 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___423 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___423 *fa_next;
	struct file___423 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___423 {
	const char *name;
	int fs_flags;
	struct dentry___423 * (*mount)(struct file_system_type___423 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___423 *);
	struct module___353 *owner;
	struct file_system_type___423 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___423 {
	struct inode___423 * (*alloc_inode)(struct super_block___423 *);
	void (*destroy_inode)(struct inode___423 *);
	void (*dirty_inode)(struct inode___423 *, int);
	int (*write_inode)(struct inode___423 *, struct writeback_control___178 *);
	int (*drop_inode)(struct inode___423 *);
	void (*evict_inode)(struct inode___423 *);
	void (*put_super)(struct super_block___423 *);
	int (*sync_fs)(struct super_block___423 *, int);
	int (*freeze_super)(struct super_block___423 *);
	int (*freeze_fs)(struct super_block___423 *);
	int (*thaw_super)(struct super_block___423 *);
	int (*unfreeze_fs)(struct super_block___423 *);
	int (*statfs)(struct dentry___423 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___423 *, int *, char *);
	void (*umount_begin)(struct super_block___423 *);
	int (*show_options)(struct seq_file___362 *, struct dentry___423 *);
	int (*show_devname)(struct seq_file___362 *, struct dentry___423 *);
	int (*show_path)(struct seq_file___362 *, struct dentry___423 *);
	int (*show_stats)(struct seq_file___362 *, struct dentry___423 *);
	ssize_t (*quota_read)(struct super_block___423 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___423 *, int, const char *, size_t, loff_t);
	struct dquot___423 ** (*get_dquots)(struct inode___423 *);
	int (*bdev_try_to_free_page)(struct super_block___423 *, struct page___424 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___423 *, struct shrink_control___158 *);
	long int (*free_cached_objects)(struct super_block___423 *, struct shrink_control___158 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___274)(struct file___423 *, wait_queue_head_t *, struct poll_table_struct___264 *);

struct poll_table_struct___264 {
	poll_queue_proc___274 _qproc;
	__poll_t _key;
};

struct seq_operations___362;

struct seq_file___362 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___362 *op;
	int poll_event;
	const struct file___423 *file;
	void *private;
};

typedef void bio_end_io_t___215(struct bio___215 *);

struct bio_vec___217 {
	struct page___424 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___215;

struct bio_set___215;

struct bio___215 {
	struct bio___215 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___215 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___215 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___217 *bi_io_vec;
	struct bio_set___215 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___217 bi_inline_vecs[0];
};

typedef int (*key_restrict_link_func_t___392)(struct key___391 *, const struct key_type *, const union key_payload *, struct key___391 *);

struct key_restriction___391;

struct key___391 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___425 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___391 *restrict_link;
};

struct key_restriction___391 {
	key_restrict_link_func_t___392 check;
	struct key___391 *key;
	struct key_type *keytype;
};

struct seq_operations___362 {
	void * (*start)(struct seq_file___362 *, loff_t *);
	void (*stop)(struct seq_file___362 *, void *);
	void * (*next)(struct seq_file___362 *, void *, loff_t *);
	int (*show)(struct seq_file___362 *, void *);
};

struct kernfs_root___417;

struct kernfs_elem_dir___417 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___417 *root;
};

struct kernfs_syscall_ops___417;

struct kernfs_root___417 {
	struct kernfs_node___418 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___417 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___417 {
	struct kernfs_node___418 *target_kn;
};

struct kernfs_ops___417;

struct kernfs_elem_attr___417 {
	const struct kernfs_ops___417 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___418 *notify_next;
};

struct kernfs_node___418 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___418 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___417 dir;
		struct kernfs_elem_symlink___417 symlink;
		struct kernfs_elem_attr___417 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___417;

struct kernfs_ops___417 {
	int (*open)(struct kernfs_open_file___417 *);
	void (*release)(struct kernfs_open_file___417 *);
	int (*seq_show)(struct seq_file___362 *, void *);
	void * (*seq_start)(struct seq_file___362 *, loff_t *);
	void * (*seq_next)(struct seq_file___362 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___362 *, void *);
	ssize_t (*read)(struct kernfs_open_file___417 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___417 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___417 *, struct vm_area_struct___424 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___417 *, struct poll_table_struct___264 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___417 {
	int (*remount_fs)(struct kernfs_root___417 *, int *, char *);
	int (*show_options)(struct seq_file___362 *, struct kernfs_root___417 *);
	int (*mkdir)(struct kernfs_node___418 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___418 *);
	int (*rename)(struct kernfs_node___418 *, struct kernfs_node___418 *, const char *);
	int (*show_path)(struct seq_file___362 *, struct kernfs_node___418 *, struct kernfs_root___417 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___417 {
	struct kernfs_node___418 *kn;
	struct file___423 *file;
	struct seq_file___362 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___411 *vm_ops;
};

struct inet_frags___68;

struct netns_frags___68 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___68 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_rules_ops___50;

struct sock___51;

struct fib_notifier_ops___51;

struct netns_ipv4___68 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___50 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___51 *fibnl;
	struct sock___51 **icmp_sk;
	struct sock___51 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___51 **tcp_sk;
	struct netns_frags___68 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___50 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___51 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___51 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct dst_entry___50;

struct net_device___69;

struct sk_buff___70;

struct neighbour___50;

struct dst_ops___79 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___79 *);
	struct dst_entry___50 * (*check)(struct dst_entry___50 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___50 *);
	unsigned int (*mtu)(const struct dst_entry___50 *);
	u32 * (*cow_metrics)(struct dst_entry___50 *, long unsigned int);
	void (*destroy)(struct dst_entry___50 *);
	void (*ifdown)(struct dst_entry___50 *, struct net_device___69 *, int);
	struct dst_entry___50 * (*negative_advice)(struct dst_entry___50 *);
	void (*link_failure)(struct sk_buff___70 *);
	void (*update_pmtu)(struct dst_entry___50 *, struct sock___51 *, struct sk_buff___70 *, u32);
	void (*redirect)(struct dst_entry___50 *, struct sock___51 *, struct sk_buff___70 *);
	int (*local_out)(struct net___80 *, struct sock___51 *, struct sk_buff___70 *);
	struct neighbour___50 * (*neigh_lookup)(const struct dst_entry___50 *, struct sk_buff___70 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___50 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___79 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___68 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___79 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___50 *fib6_rules_ops;
	struct sock___51 **icmp_sk;
	struct sock___51 *ndisc_sk;
	struct sock___51 *tcp_sk;
	struct sock___51 *igmp_sk;
	struct sock___51 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___50 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___51 *notifier_ops;
	struct fib_notifier_ops___51 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___51 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___51 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___68 {
	struct netns_frags___68 frags;
};

struct netns_xfrm___79 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___51 *nlsk;
	struct sock___51 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___79 xfrm4_dst_ops;
	struct dst_ops___79 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___60;

struct net___80 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___288 *user_ns;
	struct ucounts___288 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___29 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___51 *rtnl;
	struct sock___51 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___69 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___68 ipv4;
	struct netns_ipv6___79 ipv6;
	struct netns_sctp___51 sctp;
	struct netns_nf___4 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___68 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___51 *nfnl;
	struct sock___51 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___79 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___51 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___60 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cgroup_namespace___272 {
	refcount_t count;
	struct ns_common___29 ns;
	struct user_namespace___288 *user_ns;
	struct ucounts___288 *ucounts;
	struct css_set___272 *root_cset;
};

struct ucounts___288 {
	struct hlist_node node;
	struct user_namespace___288 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___273;

struct bpf_map_ops___272 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___273 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___273 *, struct file___423 *);
	void (*map_free)(struct bpf_map___273 *);
	int (*map_get_next_key)(struct bpf_map___273 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___273 *);
	void * (*map_lookup_elem)(struct bpf_map___273 *, void *);
	int (*map_update_elem)(struct bpf_map___273 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___273 *, void *);
	int (*map_push_elem)(struct bpf_map___273 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___273 *, void *);
	int (*map_peek_elem)(struct bpf_map___273 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___273 *, struct file___423 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___273 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___273 *, void *, struct seq_file___362 *);
	int (*map_check_btf)(const struct bpf_map___273 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___273 {
	const struct bpf_map_ops___272 *ops;
	struct bpf_map___273 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___391 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___68;

struct bpf_map_dev_ops___68 {
	int (*map_get_next_key)(struct bpf_offloaded_map___68 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___68 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___68 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___68 *, void *);
};

struct bpf_offloaded_map___68 {
	struct bpf_map___273 map;
	struct net_device___69 *netdev;
	const struct bpf_map_dev_ops___68 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

typedef rx_handler_result_t rx_handler_func_t___68(struct sk_buff___70 **);

typedef struct {
	struct net___80 *net;
} possible_net_t___70;

struct dev_pm_info___391 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___391 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___391;

struct bus_type___391;

struct device_driver___391;

struct dev_pm_domain___391;

struct dma_map_ops___163;

struct fwnode_handle___311;

struct class___391;

struct attribute_group___388;

struct device___391 {
	struct device___391 *parent;
	struct device_private *p;
	struct kobject___411 kobj;
	const char *init_name;
	const struct device_type___391 *type;
	struct mutex mutex;
	struct bus_type___391 *bus;
	struct device_driver___391 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___391 power;
	struct dev_pm_domain___391 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___163 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___311 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___391 *class;
	const struct attribute_group___388 **groups;
	void (*release)(struct device___391 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct net_device_ops___68;

struct ethtool_ops___68;

struct l3mdev_ops___50;

struct xfrmdev_ops___68;

struct tlsdev_ops___68;

struct header_ops___68;

struct netdev_rx_queue___68;

struct mini_Qdisc___60;

struct netdev_queue___68;

struct Qdisc___60;

struct rtnl_link_ops___60;

struct dcbnl_rtnl_ops___68;

struct net_device___69 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___68 *netdev_ops;
	const struct ethtool_ops___68 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___50 *l3mdev_ops;
	const struct ndisc_ops___2 *ndisc_ops;
	const struct xfrmdev_ops___68 *xfrmdev_ops;
	const struct tlsdev_ops___68 *tlsdev_ops;
	const struct header_ops___68 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___410 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___2 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___68 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___60 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___68 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___60 *miniq_ingress;
	struct netdev_queue___68 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___68 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___60 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___60 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___68 = 0,
		NETREG_REGISTERED___68 = 1,
		NETREG_UNREGISTERING___68 = 2,
		NETREG_UNREGISTERED___68 = 3,
		NETREG_RELEASED___68 = 4,
		NETREG_DUMMY___68 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___68 = 0,
		RTNL_LINK_INITIALIZING___68 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___69 *);
	struct netpoll_info *npinfo;
	possible_net_t___70 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___391 dev;
	const struct attribute_group___388 *sysfs_groups[4];
	const struct attribute_group___388 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___60 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___68 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct bpf_prog_ops___60 {
	int (*test_run)(struct bpf_prog___60 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_aux___63;

struct bpf_prog___60 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___63 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

struct bpf_verifier_ops___60 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___60 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___60 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___60 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___60 *, u32 *);
};

struct bpf_prog_offload_ops___60 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___60 *);
	int (*translate)(struct bpf_prog___60 *);
	void (*destroy)(struct bpf_prog___60 *);
};

struct bpf_prog_offload___60 {
	struct bpf_prog___60 *prog;
	struct net_device___69 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___60 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___63 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___60 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___60 *ops;
	struct bpf_map___273 **used_maps;
	struct bpf_prog___60 *prog;
	struct user_struct___391 *user;
	u64 load_time;
	struct bpf_map___273 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___60 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___60 {
	struct bpf_prog___60 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___60 {
	struct callback_head rcu;
	struct bpf_prog_array_item___60 items[0];
};

struct cgroup_bpf___60 {
	struct bpf_prog_array___60 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___60 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___273;

typedef void (*kthread_work_func_t___273)(struct kthread_work___273 *);

struct kthread_worker___273;

struct kthread_work___273 {
	struct list_head node;
	kthread_work_func_t___273 func;
	struct kthread_worker___273 *worker;
	int canceling;
};

struct kthread_worker___273 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___425 *task;
	struct kthread_work___273 *current_work;
};

struct kthread_delayed_work___272 {
	struct kthread_work___273 work;
	struct timer_list timer;
};

struct psi_group___272 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___273 *poll_kworker;
	struct kthread_delayed_work___272 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___272;

struct cgroup_rstat_cpu___272;

struct cgroup___272 {
	struct cgroup_subsys_state___272 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___418 *kn;
	struct cgroup_file___272 procs_file;
	struct cgroup_file___272 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___272 *subsys[13];
	struct cgroup_root___272 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___272 *dom_cgrp;
	struct cgroup_rstat_cpu___272 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___60 bpf;
	atomic_t congestion_count;
	struct cgroup___272 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___272 psi;
	int ancestor_ids[0];
};

struct cftype___272;

struct cgroup_subsys___272 {
	struct cgroup_subsys_state___272 * (*css_alloc)(struct cgroup_subsys_state___272 *);
	int (*css_online)(struct cgroup_subsys_state___272 *);
	void (*css_offline)(struct cgroup_subsys_state___272 *);
	void (*css_released)(struct cgroup_subsys_state___272 *);
	void (*css_free)(struct cgroup_subsys_state___272 *);
	void (*css_reset)(struct cgroup_subsys_state___272 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___272 *, int);
	int (*css_extra_stat_show)(struct seq_file___362 *, struct cgroup_subsys_state___272 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___425 *);
	void (*cancel_fork)(struct task_struct___425 *);
	void (*fork)(struct task_struct___425 *);
	void (*exit)(struct task_struct___425 *);
	void (*free)(struct task_struct___425 *);
	void (*bind)(struct cgroup_subsys_state___272 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___272 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___272 *dfl_cftypes;
	struct cftype___272 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___272 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___272 *updated_children;
	struct cgroup___272 *updated_next;
};

struct cgroup_root___272 {
	struct kernfs_root___417 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___272 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___272 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___272 *ss;
	struct list_head node;
	struct kernfs_ops___417 *kf_ops;
	int (*open)(struct kernfs_open_file___417 *);
	void (*release)(struct kernfs_open_file___417 *);
	u64 (*read_u64)(struct cgroup_subsys_state___272 *, struct cftype___272 *);
	s64 (*read_s64)(struct cgroup_subsys_state___272 *, struct cftype___272 *);
	int (*seq_show)(struct seq_file___362 *, void *);
	void * (*seq_start)(struct seq_file___362 *, loff_t *);
	void * (*seq_next)(struct seq_file___362 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___362 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___272 *, struct cftype___272 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___272 *, struct cftype___272 *, s64);
	ssize_t (*write)(struct kernfs_open_file___417 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___417 *, struct poll_table_struct___264 *);
};

struct css_task_iter___6 {
	struct cgroup_subsys___272 *ss;
	unsigned int flags;
	struct list_head *cset_pos;
	struct list_head *cset_head;
	struct list_head *tcset_pos;
	struct list_head *tcset_head;
	struct list_head *task_pos;
	struct list_head *tasks_head;
	struct list_head *mg_tasks_head;
	struct css_set___272 *cur_cset;
	struct css_set___272 *cur_dcset;
	struct task_struct___425 *cur_task;
	struct list_head iters_node;
};

struct msghdr___53 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___190 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___423 *msg_iocb;
};

struct socket_wq___51 {
	wait_queue_head_t wait;
	struct fasync_struct___423 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___51;

struct socket___52 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___51 *wq;
	struct file___423 *file;
	struct sock___51 *sk;
	const struct proto_ops___51 *ops;
};

struct proto___50;

struct sock_common___50 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___50 *skc_prot;
	possible_net_t___70 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___51 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff_head___68 {
	struct sk_buff___70 *next;
	struct sk_buff___70 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___50;

struct sock___51 {
	struct sock_common___50 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___68 sk_error_queue;
	struct sk_buff_head___68 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___70 *head;
		struct sk_buff___70 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___50 *sk_filter;
	union {
		struct socket_wq___51 *sk_wq;
		struct socket_wq___51 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___50 *sk_rx_dst;
	struct dst_entry___50 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___70 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___68 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___424 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___50 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___239 *sk_peer_pid;
	const struct cred___391 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___52 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___158 *sk_memcg;
	void (*sk_state_change)(struct sock___51 *);
	void (*sk_data_ready)(struct sock___51 *);
	void (*sk_write_space)(struct sock___51 *);
	void (*sk_error_report)(struct sock___51 *);
	int (*sk_backlog_rcv)(struct sock___51 *, struct sk_buff___70 *);
	struct sk_buff___70 * (*sk_validate_xmit_skb)(struct sock___51 *, struct net_device___69 *, struct sk_buff___70 *);
	void (*sk_destruct)(struct sock___51 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

typedef int (*sk_read_actor_t___50)(read_descriptor_t *, struct sk_buff___70 *, unsigned int, size_t);

struct proto_ops___51 {
	int family;
	struct module___353 *owner;
	int (*release)(struct socket___52 *);
	int (*bind)(struct socket___52 *, struct sockaddr *, int);
	int (*connect)(struct socket___52 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___52 *, struct socket___52 *);
	int (*accept)(struct socket___52 *, struct socket___52 *, int, bool);
	int (*getname)(struct socket___52 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___423 *, struct socket___52 *, struct poll_table_struct___264 *);
	int (*ioctl)(struct socket___52 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___52 *, int);
	int (*shutdown)(struct socket___52 *, int);
	int (*setsockopt)(struct socket___52 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___52 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___52 *, struct msghdr___53 *, size_t);
	int (*recvmsg)(struct socket___52 *, struct msghdr___53 *, size_t, int);
	int (*mmap)(struct file___423 *, struct socket___52 *, struct vm_area_struct___424 *);
	ssize_t (*sendpage)(struct socket___52 *, struct page___424 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___52 *, loff_t *, struct pipe_inode_info___104 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___51 *, int);
	int (*peek_len)(struct socket___52 *);
	int (*read_sock)(struct sock___51 *, read_descriptor_t *, sk_read_actor_t___50);
	int (*sendpage_locked)(struct sock___51 *, struct page___424 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___51 *, struct msghdr___53 *, size_t);
	int (*set_rcvlowat)(struct sock___51 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct nf_bridge_info___68;

struct sk_buff___70 {
	union {
		struct {
			struct sk_buff___70 *next;
			struct sk_buff___70 *prev;
			union {
				struct net_device___69 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___51 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___70 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___68 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct kobj_ns_type_operations___50 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___51 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___387;

struct attribute_group___388 {
	const char *name;
	umode_t (*is_visible)(struct kobject___411 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___411 *, struct bin_attribute___387 *, int);
	struct attribute **attrs;
	struct bin_attribute___387 **bin_attrs;
};

struct bin_attribute___387 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___423 *, struct kobject___411 *, struct bin_attribute___387 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___423 *, struct kobject___411 *, struct bin_attribute___387 *, char *, loff_t, size_t);
	int (*mmap)(struct file___423 *, struct kobject___411 *, struct bin_attribute___387 *, struct vm_area_struct___424 *);
};

struct sysfs_ops___410 {
	ssize_t (*show)(struct kobject___411 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___411 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___410;

struct kset___410 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___411 kobj;
	const struct kset_uevent_ops___410 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___410 {
	void (*release)(struct kobject___411 *);
	const struct sysfs_ops___410 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___50 * (*child_ns_type)(struct kobject___411 *);
	const void * (*namespace)(struct kobject___411 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___410 {
	int (* const filter)(struct kset___410 *, struct kobject___411 *);
	const char * (* const name)(struct kset___410 *, struct kobject___411 *);
	int (* const uevent)(struct kset___410 *, struct kobject___411 *, struct kobj_uevent_env *);
};

struct kobj_attribute___401 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___411 *, struct kobj_attribute___401 *, char *);
	ssize_t (*store)(struct kobject___411 *, struct kobj_attribute___401 *, const char *, size_t);
};

struct dev_pm_ops___391 {
	int (*prepare)(struct device___391 *);
	void (*complete)(struct device___391 *);
	int (*suspend)(struct device___391 *);
	int (*resume)(struct device___391 *);
	int (*freeze)(struct device___391 *);
	int (*thaw)(struct device___391 *);
	int (*poweroff)(struct device___391 *);
	int (*restore)(struct device___391 *);
	int (*suspend_late)(struct device___391 *);
	int (*resume_early)(struct device___391 *);
	int (*freeze_late)(struct device___391 *);
	int (*thaw_early)(struct device___391 *);
	int (*poweroff_late)(struct device___391 *);
	int (*restore_early)(struct device___391 *);
	int (*suspend_noirq)(struct device___391 *);
	int (*resume_noirq)(struct device___391 *);
	int (*freeze_noirq)(struct device___391 *);
	int (*thaw_noirq)(struct device___391 *);
	int (*poweroff_noirq)(struct device___391 *);
	int (*restore_noirq)(struct device___391 *);
	int (*runtime_suspend)(struct device___391 *);
	int (*runtime_resume)(struct device___391 *);
	int (*runtime_idle)(struct device___391 *);
};

struct dev_pm_domain___391 {
	struct dev_pm_ops___391 ops;
	void (*detach)(struct device___391 *, bool);
	int (*activate)(struct device___391 *);
	void (*sync)(struct device___391 *);
	void (*dismiss)(struct device___391 *);
};

struct bus_type___391 {
	const char *name;
	const char *dev_name;
	struct device___391 *dev_root;
	const struct attribute_group___388 **bus_groups;
	const struct attribute_group___388 **dev_groups;
	const struct attribute_group___388 **drv_groups;
	int (*match)(struct device___391 *, struct device_driver___391 *);
	int (*uevent)(struct device___391 *, struct kobj_uevent_env *);
	int (*probe)(struct device___391 *);
	int (*remove)(struct device___391 *);
	void (*shutdown)(struct device___391 *);
	int (*online)(struct device___391 *);
	int (*offline)(struct device___391 *);
	int (*suspend)(struct device___391 *, pm_message_t);
	int (*resume)(struct device___391 *);
	int (*num_vf)(struct device___391 *);
	int (*dma_configure)(struct device___391 *);
	const struct dev_pm_ops___391 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___391 {
	const char *name;
	struct bus_type___391 *bus;
	struct module___353 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___391 *);
	int (*remove)(struct device___391 *);
	void (*shutdown)(struct device___391 *);
	int (*suspend)(struct device___391 *, pm_message_t);
	int (*resume)(struct device___391 *);
	const struct attribute_group___388 **groups;
	const struct dev_pm_ops___391 *pm;
	void (*coredump)(struct device___391 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___391 {
	const char *name;
	const struct attribute_group___388 **groups;
	int (*uevent)(struct device___391 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___391 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___391 *);
	const struct dev_pm_ops___391 *pm;
};

struct class___391 {
	const char *name;
	struct module___353 *owner;
	const struct attribute_group___388 **class_groups;
	const struct attribute_group___388 **dev_groups;
	struct kobject___411 *dev_kobj;
	int (*dev_uevent)(struct device___391 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___391 *, umode_t *);
	void (*class_release)(struct class___391 *);
	void (*dev_release)(struct device___391 *);
	int (*shutdown_pre)(struct device___391 *);
	const struct kobj_ns_type_operations___50 *ns_type;
	const void * (*namespace)(struct device___391 *);
	const struct dev_pm_ops___391 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___163 {
	void * (*alloc)(struct device___391 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___391 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___391 *, struct vm_area_struct___424 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___391 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___391 *, struct page___424 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___391 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___391 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___391 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___391 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___391 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___391 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___391 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___391 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___391 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___391 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___391 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___391 *, u64);
	u64 (*get_required_mask)(struct device___391 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___311;

struct fwnode_handle___311 {
	struct fwnode_handle___311 *secondary;
	const struct fwnode_operations___311 *ops;
};

typedef void compound_page_dtor___411(struct page___424 *);

struct fwnode_reference_args___311;

struct fwnode_endpoint___311;

struct fwnode_operations___311 {
	struct fwnode_handle___311 * (*get)(struct fwnode_handle___311 *);
	void (*put)(struct fwnode_handle___311 *);
	bool (*device_is_available)(const struct fwnode_handle___311 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___311 *, const struct device___391 *);
	bool (*property_present)(const struct fwnode_handle___311 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___311 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___311 *, const char *, const char **, size_t);
	struct fwnode_handle___311 * (*get_parent)(const struct fwnode_handle___311 *);
	struct fwnode_handle___311 * (*get_next_child_node)(const struct fwnode_handle___311 *, struct fwnode_handle___311 *);
	struct fwnode_handle___311 * (*get_named_child_node)(const struct fwnode_handle___311 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___311 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___311 *);
	struct fwnode_handle___311 * (*graph_get_next_endpoint)(const struct fwnode_handle___311 *, struct fwnode_handle___311 *);
	struct fwnode_handle___311 * (*graph_get_remote_endpoint)(const struct fwnode_handle___311 *);
	struct fwnode_handle___311 * (*graph_get_port_parent)(struct fwnode_handle___311 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___311 *, struct fwnode_endpoint___311 *);
};

struct fwnode_endpoint___311 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___311 *local_fwnode;
};

struct fwnode_reference_args___311 {
	struct fwnode_handle___311 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___104;

struct pipe_buffer___104 {
	struct page___424 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___104 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___104 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___104 *, struct pipe_buffer___104 *);
	void (*release)(struct pipe_inode_info___104 *, struct pipe_buffer___104 *);
	int (*steal)(struct pipe_inode_info___104 *, struct pipe_buffer___104 *);
	union {
		bool (*get)(struct pipe_inode_info___104 *, struct pipe_buffer___104 *);
		struct {
			void (*get)(struct pipe_inode_info___104 *, struct pipe_buffer___104 *);
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
};

struct nf_bridge_info___68 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___68 = 0,
		BRNF_PROTO_8021Q___68 = 1,
		BRNF_PROTO_PPPOE___68 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___69 *physindev;
	struct net_device___69 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

struct ethtool_ops___68 {
	int (*get_settings)(struct net_device___69 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___69 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___69 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___69 *);
	void (*get_regs)(struct net_device___69 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___69 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___69 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___69 *);
	void (*set_msglevel)(struct net_device___69 *, u32);
	int (*nway_reset)(struct net_device___69 *);
	u32 (*get_link)(struct net_device___69 *);
	int (*get_eeprom_len)(struct net_device___69 *);
	int (*get_eeprom)(struct net_device___69 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___69 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___69 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___69 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___69 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___69 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___69 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___69 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___69 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___69 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___69 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___69 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___69 *);
	void (*complete)(struct net_device___69 *);
	u32 (*get_priv_flags)(struct net_device___69 *);
	int (*set_priv_flags)(struct net_device___69 *, u32);
	int (*get_sset_count)(struct net_device___69 *, int);
	int (*get_rxnfc)(struct net_device___69 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___69 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___69 *, struct ethtool_flash *);
	int (*reset)(struct net_device___69 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___69 *);
	u32 (*get_rxfh_indir_size)(struct net_device___69 *);
	int (*get_rxfh)(struct net_device___69 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___69 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___69 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___69 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___69 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___69 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___69 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___69 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___69 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___69 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___69 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___69 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___69 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___69 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___69 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___69 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___69 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___69 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___69 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___69 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___69 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___69 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	int (*get_fecparam)(struct net_device___69 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___69 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___69 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___69 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___69 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___68;

struct inet_frags___68 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___68 *, const void *);
	void (*destructor)(struct inet_frag_queue___68 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___68 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___70 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___70 *fragments_tail;
	struct sk_buff___70 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___68 *net;
	struct callback_head rcu;
};

struct fib_rule___50;

struct fib_lookup_arg___50;

struct fib_rules_ops___50 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___50 *, struct flowi *, int, struct fib_lookup_arg___50 *);
	bool (*suppress)(struct fib_rule___50 *, struct fib_lookup_arg___50 *);
	int (*match)(struct fib_rule___50 *, struct flowi *, int);
	int (*configure)(struct fib_rule___50 *, struct sk_buff___70 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___50 *);
	int (*compare)(struct fib_rule___50 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___50 *, struct sk_buff___70 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___50 *);
	void (*flush_cache)(struct fib_rules_ops___50 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___353 *owner;
	struct net___80 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___51 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___80 *);
	int (*fib_dump)(struct net___80 *, struct notifier_block *);
	struct module___353 *owner;
	struct callback_head rcu;
};

struct dst_entry___50 {
	struct net_device___69 *dev;
	struct dst_ops___79 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___70 *);
	int (*output)(struct net___80 *, struct sock___51 *, struct sk_buff___70 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___50;

struct neigh_parms___50;

struct neigh_ops___50;

struct neighbour___50 {
	struct neighbour___50 *next;
	struct neigh_table___50 *tbl;
	struct neigh_parms___50 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___68 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___50 *, struct sk_buff___70 *);
	const struct neigh_ops___50 *ops;
	struct callback_head rcu;
	struct net_device___69 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct pernet_operations___69 {
	struct list_head list;
	int (*init)(struct net___80 *);
	void (*exit)(struct net___80 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___68 {
	int (*ieee_getets)(struct net_device___69 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___69 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___69 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___69 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___69 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___69 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___69 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___69 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___69 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___69 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___69 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___69 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___69 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___69 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___69 *);
	u8 (*setstate)(struct net_device___69 *, u8);
	void (*getpermhwaddr)(struct net_device___69 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___69 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___69 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___69 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___69 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___69 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___69 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___69 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___69 *, int, u8 *);
	void (*setpfccfg)(struct net_device___69 *, int, u8);
	void (*getpfccfg)(struct net_device___69 *, int, u8 *);
	u8 (*setall)(struct net_device___69 *);
	u8 (*getcap)(struct net_device___69 *, int, u8 *);
	int (*getnumtcs)(struct net_device___69 *, int, u8 *);
	int (*setnumtcs)(struct net_device___69 *, int, u8);
	u8 (*getpfcstate)(struct net_device___69 *);
	void (*setpfcstate)(struct net_device___69 *, u8);
	void (*getbcncfg)(struct net_device___69 *, int, u32 *);
	void (*setbcncfg)(struct net_device___69 *, int, u32);
	void (*getbcnrp)(struct net_device___69 *, int, u8 *);
	void (*setbcnrp)(struct net_device___69 *, int, u8);
	int (*setapp)(struct net_device___69 *, u8, u16, u8);
	int (*getapp)(struct net_device___69 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___69 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___69 *, int, u8);
	u8 (*getdcbx)(struct net_device___69 *);
	u8 (*setdcbx)(struct net_device___69 *, u8);
	int (*peer_getappinfo)(struct net_device___69 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___69 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___69 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___69 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___69 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___69 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct xdp_rxq_info___68 {
	struct net_device___69 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___68 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___69 *dev_rx;
};

struct netlink_callback___70 {
	struct sk_buff___70 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___70 *);
	int (*dump)(struct sk_buff___70 *, struct netlink_callback___70 *);
	int (*done)(struct netlink_callback___70 *);
	void *data;
	struct module___353 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___68 {
	int (*create)(struct sk_buff___70 *, struct net_device___69 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___70 *, unsigned char *);
	int (*cache)(const struct neighbour___50 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___69 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___68 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___68 *, int);
	int poll_owner;
	struct net_device___69 *dev;
	struct sk_buff___70 *gro_list;
	struct sk_buff___70 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___68 {
	struct net_device___69 *dev;
	struct Qdisc___60 *qdisc;
	struct Qdisc___60 *qdisc_sleeping;
	struct kobject___411 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___69 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___60 {
	struct sk_buff___70 *head;
	struct sk_buff___70 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___60;

struct Qdisc___60 {
	int (*enqueue)(struct sk_buff___70 *, struct Qdisc___60 *, struct sk_buff___70 **);
	struct sk_buff___70 * (*dequeue)(struct Qdisc___60 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___60 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___68 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___68 gso_skb;
	struct qdisc_skb_head___60 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___60 *next_sched;
	struct sk_buff_head___68 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___68 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___411 kobj;
	struct net_device___69 *dev;
	long: 64;
	struct xdp_rxq_info___68 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___68)(struct net_device___69 *, struct sk_buff___70 *, struct net_device___69 *);

struct netdev_bpf___68 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___60 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___60 *prog;
			const struct bpf_prog_offload_ops___60 *ops;
		} verifier;
		struct {
			struct bpf_prog___60 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___68 *offmap;
		};
		struct {
			struct xdp_umem___3 *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___68 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___70 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___68 {
	int (*tls_dev_add)(struct net_device___69 *, struct sock___51 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___69 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___69 *, struct sock___51 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___68 {
	int (*ndo_init)(struct net_device___69 *);
	void (*ndo_uninit)(struct net_device___69 *);
	int (*ndo_open)(struct net_device___69 *);
	int (*ndo_stop)(struct net_device___69 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___70 *, struct net_device___69 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___70 *, struct net_device___69 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___69 *, struct sk_buff___70 *, struct net_device___69 *, select_queue_fallback_t___68);
	void (*ndo_change_rx_flags)(struct net_device___69 *, int);
	void (*ndo_set_rx_mode)(struct net_device___69 *);
	int (*ndo_set_mac_address)(struct net_device___69 *, void *);
	int (*ndo_validate_addr)(struct net_device___69 *);
	int (*ndo_do_ioctl)(struct net_device___69 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___69 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___69 *, int);
	int (*ndo_neigh_setup)(struct net_device___69 *, struct neigh_parms___50 *);
	void (*ndo_tx_timeout)(struct net_device___69 *);
	void (*ndo_get_stats64)(struct net_device___69 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___69 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___69 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___69 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___69 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___69 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___69 *);
	int (*ndo_netpoll_setup)(struct net_device___69 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___69 *);
	int (*ndo_set_vf_mac)(struct net_device___69 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___69 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___69 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___69 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___69 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___69 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___69 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___69 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___69 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___69 *, int, struct sk_buff___70 *);
	int (*ndo_set_vf_guid)(struct net_device___69 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___69 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___69 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___69 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___69 *, const struct sk_buff___70 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___69 *, struct net_device___69 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___69 *, struct net_device___69 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___69 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___69 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___69 *, struct neighbour___50 *);
	void (*ndo_neigh_destroy)(struct net_device___69 *, struct neighbour___50 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___69 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___69 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___69 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___70 *, struct netlink_callback___70 *, struct net_device___69 *, struct net_device___69 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___69 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___69 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___70 *, u32, u32, struct net_device___69 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___69 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___69 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___69 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___69 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___69 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___69 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___69 *, struct net_device___69 *);
	void (*ndo_dfwd_del_station)(struct net_device___69 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___69 *);
	int (*ndo_set_tx_maxrate)(struct net_device___69 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___69 *);
	int (*ndo_change_proto_down)(struct net_device___69 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___69 *, struct sk_buff___70 *);
	void (*ndo_set_rx_headroom)(struct net_device___69 *, int);
	int (*ndo_bpf)(struct net_device___69 *, struct netdev_bpf___68 *);
	int (*ndo_xdp_xmit)(struct net_device___69 *, int, struct xdp_frame___68 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___69 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___69 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___50 {
	possible_net_t___70 net;
	struct net_device___69 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___50 *);
	void (*neigh_cleanup)(struct neighbour___50 *);
	struct neigh_table___50 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___50 {
	u32 (*l3mdev_fib_table)(const struct net_device___69 *);
	struct sk_buff___70 * (*l3mdev_l3_rcv)(struct net_device___69 *, struct sk_buff___70 *, u16);
	struct sk_buff___70 * (*l3mdev_l3_out)(struct net_device___69 *, struct sock___51 *, struct sk_buff___70 *, u16);
	struct dst_entry___50 * (*l3mdev_link_scope_lookup)(const struct net_device___69 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct tcf_proto___60;

struct mini_Qdisc___60 {
	struct tcf_proto___60 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___60 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___69 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___80 *, struct net_device___69 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___69 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___69 *, struct list_head *);
	size_t (*get_size)(const struct net_device___69 *);
	int (*fill_info)(struct sk_buff___70 *, const struct net_device___69 *);
	size_t (*get_xstats_size)(const struct net_device___69 *);
	int (*fill_xstats)(struct sk_buff___70 *, const struct net_device___69 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___69 *, struct net_device___69 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___69 *, const struct net_device___69 *);
	int (*fill_slave_info)(struct sk_buff___70 *, const struct net_device___69 *, const struct net_device___69 *);
	struct net___80 * (*get_link_net)(const struct net_device___69 *);
	size_t (*get_linkxstats_size)(const struct net_device___69 *, int);
	int (*fill_linkxstats)(struct sk_buff___70 *, const struct net_device___69 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___68 {
	struct list_head poll_list;
	struct sk_buff_head___68 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___68 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___60 *output_queue;
	struct Qdisc___60 **output_queue_tailp;
	struct sk_buff___70 *completion_queue;
	struct sk_buff_head___68 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___68 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___68 input_pkt_queue;
	struct napi_struct___68 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bdi_writeback_congested___215 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___215 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___215 {
	struct bio___215 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___217 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___217 bip_inline_vecs[0];
};

struct bio_set___215 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___215 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___158 {
	struct mem_cgroup___158 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___158 {
	struct lruvec___424 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___158 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___158 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct kernel_param_ops___351 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___351 *);
	int (*get)(char *, const struct kernel_param___351 *);
	void (*free)(void *);
};

struct kparam_array___351;

struct kernel_param___351 {
	const char *name;
	struct module___353 *mod;
	const struct kernel_param_ops___351 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___351 *arr;
	};
};

struct kparam_array___351 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___351 *ops;
	void *elem;
};

struct module_attribute___351 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___351 *, struct module_kobject___351 *, char *);
	ssize_t (*store)(struct module_attribute___351 *, struct module_kobject___351 *, const char *, size_t);
	void (*setup)(struct module___353 *, const char *);
	int (*test)(struct module___353 *);
	void (*free)(struct module___353 *);
};

struct gnet_dump___60 {
	spinlock_t *lock;
	struct sk_buff___70 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___60;

struct Qdisc_ops___60 {
	struct Qdisc_ops___60 *next;
	const struct Qdisc_class_ops___60 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___70 *, struct Qdisc___60 *, struct sk_buff___70 **);
	struct sk_buff___70 * (*dequeue)(struct Qdisc___60 *);
	struct sk_buff___70 * (*peek)(struct Qdisc___60 *);
	int (*init)(struct Qdisc___60 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___60 *);
	void (*destroy)(struct Qdisc___60 *);
	int (*change)(struct Qdisc___60 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___60 *);
	int (*change_tx_queue_len)(struct Qdisc___60 *, unsigned int);
	int (*dump)(struct Qdisc___60 *, struct sk_buff___70 *);
	int (*dump_stats)(struct Qdisc___60 *, struct gnet_dump___60 *);
	void (*ingress_block_set)(struct Qdisc___60 *, u32);
	void (*egress_block_set)(struct Qdisc___60 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___60 *);
	u32 (*egress_block_get)(struct Qdisc___60 *);
	struct module___353 *owner;
};

struct tcf_block___60;

struct Qdisc_class_ops___60 {
	unsigned int flags;
	struct netdev_queue___68 * (*select_queue)(struct Qdisc___60 *, struct tcmsg *);
	int (*graft)(struct Qdisc___60 *, long unsigned int, struct Qdisc___60 *, struct Qdisc___60 **, struct netlink_ext_ack *);
	struct Qdisc___60 * (*leaf)(struct Qdisc___60 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___60 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___60 *, u32);
	int (*change)(struct Qdisc___60 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___60 *, long unsigned int);
	void (*walk)(struct Qdisc___60 *, struct qdisc_walker *);
	struct tcf_block___60 * (*tcf_block)(struct Qdisc___60 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___60 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___60 *, long unsigned int);
	int (*dump)(struct Qdisc___60 *, long unsigned int, struct sk_buff___70 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___60 *, long unsigned int, struct gnet_dump___60 *);
};

struct tcf_chain___60;

struct tcf_block___60 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___80 *net;
	struct Qdisc___60 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___60 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___60;

struct tcf_proto_ops___60;

struct tcf_proto___60 {
	struct tcf_proto___60 *next;
	void *root;
	int (*classify)(struct sk_buff___70 *, const struct tcf_proto___60 *, struct tcf_result___60 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___60 *ops;
	struct tcf_chain___60 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___60 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___60 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___60 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___70 *, const struct tcf_proto___60 *, struct tcf_result___60 *);
	int (*init)(struct tcf_proto___60 *);
	void (*destroy)(struct tcf_proto___60 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___60 *, u32);
	void (*put)(struct tcf_proto___60 *, void *);
	int (*change)(struct net___80 *, struct sk_buff___70 *, struct tcf_proto___60 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___60 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___60 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___60 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___80 *, struct tcf_chain___60 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___80 *, struct tcf_proto___60 *, void *, struct sk_buff___70 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___70 *, struct net___80 *, void *);
	struct module___353 *owner;
	int flags;
};

struct tcf_chain___60 {
	struct mutex filter_chain_lock;
	struct tcf_proto___60 *filter_chain;
	struct list_head list;
	struct tcf_block___60 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___60 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___50 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___60 *prog;
};

struct bpf_redirect_info___60 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___273 *map;
	struct bpf_map___273 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___50;

struct neigh_hash_table___50;

struct neigh_table___50 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___69 *, __u32 *);
	bool (*key_eq)(const struct neighbour___50 *, const void *);
	int (*constructor)(struct neighbour___50 *);
	int (*pconstructor)(struct pneigh_entry___50 *);
	void (*pdestructor)(struct pneigh_entry___50 *);
	void (*proxy_redo)(struct sk_buff___70 *);
	char *id;
	struct neigh_parms___50 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___68 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___50 *nht;
	struct pneigh_entry___50 **phash_buckets;
};

struct neigh_ops___50 {
	int family;
	void (*solicit)(struct neighbour___50 *, struct sk_buff___70 *);
	void (*error_report)(struct neighbour___50 *, struct sk_buff___70 *);
	int (*output)(struct neighbour___50 *, struct sk_buff___70 *);
	int (*connected_output)(struct neighbour___50 *, struct sk_buff___70 *);
};

struct pneigh_entry___50 {
	struct pneigh_entry___50 *next;
	possible_net_t___70 net;
	struct net_device___69 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___50 {
	struct neighbour___50 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___50 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___50 *ctarget;
	struct net___80 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___50 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___50 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___34;

struct proto___50 {
	void (*close)(struct sock___51 *, long int);
	int (*pre_connect)(struct sock___51 *, struct sockaddr *, int);
	int (*connect)(struct sock___51 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___51 *, int);
	struct sock___51 * (*accept)(struct sock___51 *, int, int *, bool);
	int (*ioctl)(struct sock___51 *, int, long unsigned int);
	int (*init)(struct sock___51 *);
	void (*destroy)(struct sock___51 *);
	void (*shutdown)(struct sock___51 *, int);
	int (*setsockopt)(struct sock___51 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___51 *, int, int, char *, int *);
	void (*keepalive)(struct sock___51 *, int);
	int (*sendmsg)(struct sock___51 *, struct msghdr___53 *, size_t);
	int (*recvmsg)(struct sock___51 *, struct msghdr___53 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___51 *, struct page___424 *, int, size_t, int);
	int (*bind)(struct sock___51 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___51 *, struct sk_buff___70 *);
	void (*release_cb)(struct sock___51 *);
	int (*hash)(struct sock___51 *);
	void (*unhash)(struct sock___51 *);
	void (*rehash)(struct sock___51 *);
	int (*get_port)(struct sock___51 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___51 *);
	bool (*stream_memory_read)(const struct sock___51 *);
	void (*enter_memory_pressure)(struct sock___51 *);
	void (*leave_memory_pressure)(struct sock___51 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___34 *rsk_prot;
	struct timewait_sock_ops___3 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___353 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___51 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct request_sock___35;

struct request_sock_ops___34 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___51 *, struct request_sock___35 *);
	void (*send_ack)(const struct sock___51 *, struct sk_buff___70 *, struct request_sock___35 *);
	void (*send_reset)(const struct sock___51 *, struct sk_buff___70 *);
	void (*destructor)(struct request_sock___35 *);
	void (*syn_ack_timeout)(const struct request_sock___35 *);
};

struct request_sock___35 {
	struct sock_common___50 __req_common;
	struct request_sock___35 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___34 *rsk_ops;
	struct sock___51 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct cgroup_cls_state___3 {
	struct cgroup_subsys_state___272 css;
	u32 classid;
};

enum lwtunnel_encap_types {
	LWTUNNEL_ENCAP_NONE = 0,
	LWTUNNEL_ENCAP_MPLS = 1,
	LWTUNNEL_ENCAP_IP = 2,
	LWTUNNEL_ENCAP_ILA = 3,
	LWTUNNEL_ENCAP_IP6 = 4,
	LWTUNNEL_ENCAP_SEG6 = 5,
	LWTUNNEL_ENCAP_BPF = 6,
	LWTUNNEL_ENCAP_SEG6_LOCAL = 7,
	__LWTUNNEL_ENCAP_MAX = 8,
};

struct rtnexthop {
	short unsigned int rtnh_len;
	unsigned char rtnh_flags;
	unsigned char rtnh_hops;
	int rtnh_ifindex;
};

struct lwtunnel_encap_ops {
	int (*build_state)(struct nlattr *, unsigned int, const void *, struct lwtunnel_state___5 **, struct netlink_ext_ack *);
	void (*destroy_state)(struct lwtunnel_state___5 *);
	int (*output)(struct net___76 *, struct sock___48 *, struct sk_buff___66 *);
	int (*input)(struct sk_buff___66 *);
	int (*fill_encap)(struct sk_buff___66 *, struct lwtunnel_state___5 *);
	int (*get_encap_size)(struct lwtunnel_state___5 *);
	int (*cmp_encap)(struct lwtunnel_state___5 *, struct lwtunnel_state___5 *);
	int (*xmit)(struct sk_buff___66 *);
	struct module___349 *owner;
};

struct skb_frag_struct___11 {
	struct {
		struct page___420 *p;
	} page;
	__u32 page_offset;
	__u32 size;
};

typedef struct skb_frag_struct___11 skb_frag_t___11;

struct skb_shared_info___11 {
	__u8 __unused;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___66 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___11 frags[16];
};

enum {
	LWT_BPF_PROG_UNSPEC = 0,
	LWT_BPF_PROG_FD = 1,
	LWT_BPF_PROG_NAME = 2,
	__LWT_BPF_PROG_MAX = 3,
};

enum {
	LWT_BPF_UNSPEC = 0,
	LWT_BPF_IN = 1,
	LWT_BPF_OUT = 2,
	LWT_BPF_XMIT = 3,
	LWT_BPF_XMIT_HEADROOM = 4,
	__LWT_BPF_MAX = 5,
};

enum {
	LWTUNNEL_XMIT_DONE = 0,
	LWTUNNEL_XMIT_CONTINUE = 1,
};

struct bpf_lwt_prog {
	struct bpf_prog___57 *prog;
	char *name;
};

struct bpf_lwt {
	struct bpf_lwt_prog in;
	struct bpf_lwt_prog out;
	struct bpf_lwt_prog xmit;
	int family;
};

struct fd___30 {
	struct file___417 *file;
	unsigned int flags;
};

struct bpf_sock_ops_kern___3 {
	struct sock___46 *sk;
	u32 op;
	union {
		u32 args[4];
		u32 reply;
		u32 replylong[4];
	};
	u32 is_fullsock;
	u64 temp;
};

struct bpf_stab {
	struct bpf_map___267 map;
	struct sock___46 **sks;
	struct sk_psock_progs progs;
	raw_spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_htab_elem {
	struct callback_head rcu;
	u32 hash;
	struct sock___46 *sk;
	struct hlist_node node;
	u8 key[0];
};

struct bpf_htab_bucket {
	struct hlist_head head;
	raw_spinlock_t lock;
};

struct bpf_htab___2 {
	struct bpf_map___267 map;
	struct bpf_htab_bucket *buckets;
	u32 buckets_num;
	u32 elem_size;
	struct sk_psock_progs progs;
	atomic_t count;
	long: 32;
	long: 64;
	long: 64;
};

struct dst_cache_pcpu {
	long unsigned int refresh_ts;
	struct dst_entry___36 *dst;
	u32 cookie;
	union {
		struct in_addr in_saddr;
		struct in6_addr in6_saddr;
	};
};

struct module___354;

struct file___424;

struct kiocb___424;

struct iov_iter___191;

struct poll_table_struct___265;

struct vm_area_struct___425;

struct inode___424;

struct file_lock___424;

struct page___425;

struct pipe_inode_info___105;

struct seq_file___363;

struct file_operations___424 {
	struct module___354 *owner;
	loff_t (*llseek)(struct file___424 *, loff_t, int);
	ssize_t (*read)(struct file___424 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___424 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___424 *, struct iov_iter___191 *);
	ssize_t (*write_iter)(struct kiocb___424 *, struct iov_iter___191 *);
	int (*iopoll)(struct kiocb___424 *, bool);
	int (*iterate)(struct file___424 *, struct dir_context *);
	int (*iterate_shared)(struct file___424 *, struct dir_context *);
	__poll_t (*poll)(struct file___424 *, struct poll_table_struct___265 *);
	long int (*unlocked_ioctl)(struct file___424 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___424 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___424 *, struct vm_area_struct___425 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___424 *, struct file___424 *);
	int (*flush)(struct file___424 *, fl_owner_t);
	int (*release)(struct inode___424 *, struct file___424 *);
	int (*fsync)(struct file___424 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___424 *, int);
	int (*lock)(struct file___424 *, int, struct file_lock___424 *);
	ssize_t (*sendpage)(struct file___424 *, struct page___425 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___424 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___424 *, int, struct file_lock___424 *);
	ssize_t (*splice_write)(struct pipe_inode_info___105 *, struct file___424 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___424 *, loff_t *, struct pipe_inode_info___105 *, size_t, unsigned int);
	int (*setlease)(struct file___424 *, long int, struct file_lock___424 **, void **);
	long int (*fallocate)(struct file___424 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___363 *, struct file___424 *);
	ssize_t (*copy_file_range)(struct file___424 *, loff_t, struct file___424 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___424 *, loff_t, struct file___424 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___424 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___425 {
	u64 seqnum;
	struct vm_area_struct___425 *vmas[4];
};

struct page_frag___425 {
	struct page___425 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___156;

struct debug_info___156 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___156 *hbp_break[16];
	struct perf_event___156 *hbp_watch[16];
};

struct thread_struct___156 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___156 debug;
	long: 64;
};

struct mm_struct___425;

struct mem_cgroup___159;

struct pid___240;

struct cred___392;

struct nsproxy___319;

struct signal_struct___299;

struct bio_list___216;

struct backing_dev_info___216;

struct css_set___273;

struct perf_event_context___156;

struct vm_struct___328;

struct task_struct___426 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___426 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___425 *mm;
	struct mm_struct___425 *active_mm;
	struct vmacache___425 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___426 *real_parent;
	struct task_struct___426 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___426 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___159 *active_memcg;
	long int rh_reserved2;
	struct pid___240 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___240 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___240 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___392 *ptracer_cred;
	const struct cred___392 *real_cred;
	const struct cred___392 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___319 *nsproxy;
	struct signal_struct___299 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___426 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___216 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___216 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___273 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___156 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___105 *splice_pipe;
	struct page_frag___425 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___159 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___426 *oom_reaper_list;
	struct vm_struct___328 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___156 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___156 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___426 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___156)(struct perf_event___156 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___156;

struct fasync_struct___424;

struct pid_namespace___240;

struct bpf_prog___61;

struct trace_event_call___147;

struct perf_cgroup___156;

struct perf_event___156 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___156 *group_leader;
	struct pmu___156 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___156 hw;
	struct perf_event_context___156 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___156 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___426 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___424 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___156 *);
	struct callback_head callback_head;
	struct pid_namespace___240 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___156 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___156 orig_overflow_handler;
	struct bpf_prog___61 *prog;
	struct trace_event_call___147 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___156 *cgrp;
	struct list_head sb_list;
};

struct rw_semaphore___426 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___426 *owner;
};

struct key___392;

struct ucounts___289;

struct user_namespace___289 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___289 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___29 ns;
	long unsigned int flags;
	struct key___392 *persistent_keyring_register;
	struct rw_semaphore___426 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___289 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___425 *pgtable_t___425;

struct address_space___424;

struct dev_pagemap___412;

struct page___425 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___424 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___425 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___425 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___425 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___412 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___159 *mem_cgroup;
};

struct pglist_data___425;

struct lruvec___425 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___425 *pgdat;
};

struct zone___425 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___425 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___425 {
	struct zone___425 *zone;
	int zone_idx;
};

struct zonelist___425 {
	struct zoneref___425 _zonerefs[25];
};

struct pglist_data___425 {
	struct zone___425 node_zones[3];
	struct zonelist___425 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___426 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___426 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___425 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___426 {
	void *stack;
	struct task_struct___426 *task;
	long int status;
};

struct blocking_notifier_head___425 {
	struct rw_semaphore___426 rwsem;
	struct notifier_block *head;
};

struct dentry___424;

struct path___425 {
	struct vfsmount *mnt;
	struct dentry___424 *dentry;
};

struct fown_struct___240 {
	rwlock_t lock;
	struct pid___240 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___424 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___425 f_path;
	struct inode___424 *f_inode;
	const struct file_operations___424 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___240 f_owner;
	const struct cred___392 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___424 *f_mapping;
	errseq_t f_wb_err;
};

struct user_struct___392;

struct cred___392 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___392 *session_keyring;
	struct key___392 *process_keyring;
	struct key___392 *thread_keyring;
	struct key___392 *request_key_auth;
	void *security;
	struct user_struct___392 *user;
	struct user_namespace___289 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___418;

struct kernfs_elem_dir___418 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___418 *root;
};

struct kernfs_node___419;

struct kernfs_syscall_ops___418;

struct kernfs_root___418 {
	struct kernfs_node___419 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___418 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___418 {
	struct kernfs_node___419 *target_kn;
};

struct kernfs_ops___418;

struct kernfs_elem_attr___418 {
	const struct kernfs_ops___418 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___419 *notify_next;
};

struct kernfs_node___419 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___419 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___418 dir;
		struct kernfs_elem_symlink___418 symlink;
		struct kernfs_elem_attr___418 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___418;

struct kernfs_ops___418 {
	int (*open)(struct kernfs_open_file___418 *);
	void (*release)(struct kernfs_open_file___418 *);
	int (*seq_show)(struct seq_file___363 *, void *);
	void * (*seq_start)(struct seq_file___363 *, loff_t *);
	void * (*seq_next)(struct seq_file___363 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___363 *, void *);
	ssize_t (*read)(struct kernfs_open_file___418 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___418 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___418 *, struct vm_area_struct___425 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___418 *, struct poll_table_struct___265 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___418 {
	int (*remount_fs)(struct kernfs_root___418 *, int *, char *);
	int (*show_options)(struct seq_file___363 *, struct kernfs_root___418 *);
	int (*mkdir)(struct kernfs_node___419 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___419 *);
	int (*rename)(struct kernfs_node___419 *, struct kernfs_node___419 *, const char *);
	int (*show_path)(struct seq_file___363 *, struct kernfs_node___419 *, struct kernfs_root___418 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___363;

struct seq_file___363 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___363 *op;
	int poll_event;
	const struct file___424 *file;
	void *private;
};

struct vm_operations_struct___412;

struct kernfs_open_file___418 {
	struct kernfs_node___419 *kn;
	struct file___424 *file;
	struct seq_file___363 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___412 *vm_ops;
};

struct vm_fault___412;

struct vm_operations_struct___412 {
	void (*open)(struct vm_area_struct___425 *);
	void (*close)(struct vm_area_struct___425 *);
	int (*split)(struct vm_area_struct___425 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___425 *);
	vm_fault_t (*fault)(struct vm_fault___412 *);
	vm_fault_t (*huge_fault)(struct vm_fault___412 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___412 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___425 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___412 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___412 *);
	int (*access)(struct vm_area_struct___425 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___425 *);
	int (*set_policy)(struct vm_area_struct___425 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___425 *, long unsigned int);
	struct page___425 * (*find_special_page)(struct vm_area_struct___425 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___275)(struct file___424 *, wait_queue_head_t *, struct poll_table_struct___265 *);

struct poll_table_struct___265 {
	poll_queue_proc___275 _qproc;
	__poll_t _key;
};

struct vm_area_struct___425 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___425 *vm_next;
	struct vm_area_struct___425 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___425 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___412 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___424 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sock___52;

struct kobj_ns_type_operations___51 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___52 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct net___81;

typedef struct {
	struct net___81 *net;
} possible_net_t___71;

struct proto___51;

struct sock_common___51 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___51 *skc_prot;
	possible_net_t___71 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___52 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___71;

struct sk_buff_head___69 {
	struct sk_buff___71 *next;
	struct sk_buff___71 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___51;

struct socket_wq___52;

struct dst_entry___51;

struct socket___53;

struct net_device___70;

struct sock___52 {
	struct sock_common___51 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___69 sk_error_queue;
	struct sk_buff_head___69 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___71 *head;
		struct sk_buff___71 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___51 *sk_filter;
	union {
		struct socket_wq___52 *sk_wq;
		struct socket_wq___52 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___51 *sk_rx_dst;
	struct dst_entry___51 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___71 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___69 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___425 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___51 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___240 *sk_peer_pid;
	const struct cred___392 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___53 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___159 *sk_memcg;
	void (*sk_state_change)(struct sock___52 *);
	void (*sk_data_ready)(struct sock___52 *);
	void (*sk_write_space)(struct sock___52 *);
	void (*sk_error_report)(struct sock___52 *);
	int (*sk_backlog_rcv)(struct sock___52 *, struct sk_buff___71 *);
	struct sk_buff___71 * (*sk_validate_xmit_skb)(struct sock___52 *, struct net_device___70 *, struct sk_buff___71 *);
	void (*sk_destruct)(struct sock___52 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kobject___412;

struct bin_attribute___388;

struct attribute_group___389 {
	const char *name;
	umode_t (*is_visible)(struct kobject___412 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___412 *, struct bin_attribute___388 *, int);
	struct attribute **attrs;
	struct bin_attribute___388 **bin_attrs;
};

struct kset___411;

struct kobj_type___411;

struct kobject___412 {
	const char *name;
	struct list_head entry;
	struct kobject___412 *parent;
	struct kset___411 *kset;
	struct kobj_type___411 *ktype;
	struct kernfs_node___419 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___388 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___424 *, struct kobject___412 *, struct bin_attribute___388 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___424 *, struct kobject___412 *, struct bin_attribute___388 *, char *, loff_t, size_t);
	int (*mmap)(struct file___424 *, struct kobject___412 *, struct bin_attribute___388 *, struct vm_area_struct___425 *);
};

struct sysfs_ops___411 {
	ssize_t (*show)(struct kobject___412 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___412 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___411;

struct kset___411 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___412 kobj;
	const struct kset_uevent_ops___411 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___411 {
	void (*release)(struct kobject___412 *);
	const struct sysfs_ops___411 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___51 * (*child_ns_type)(struct kobject___412 *);
	const void * (*namespace)(struct kobject___412 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___411 {
	int (* const filter)(struct kset___411 *, struct kobject___412 *);
	const char * (* const name)(struct kset___411 *, struct kobject___412 *);
	int (* const uevent)(struct kset___411 *, struct kobject___412 *, struct kobj_uevent_env *);
};

struct kobj_attribute___402 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___412 *, struct kobj_attribute___402 *, char *);
	ssize_t (*store)(struct kobject___412 *, struct kobj_attribute___402 *, const char *, size_t);
};

struct kernel_param___352;

struct kernel_param_ops___352 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___352 *);
	int (*get)(char *, const struct kernel_param___352 *);
	void (*free)(void *);
};

struct kparam_array___352;

struct kernel_param___352 {
	const char *name;
	struct module___354 *mod;
	const struct kernel_param_ops___352 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___352 *arr;
	};
};

struct kparam_array___352 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___352 *ops;
	void *elem;
};

struct module_kobject___352 {
	struct kobject___412 kobj;
	struct module___354 *mod;
	struct kobject___412 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___352 {
	struct module___354 *mod;
	struct latch_tree_node node;
};

struct module_layout___352 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___352 mtn;
};

struct module_attribute___352;

struct module___354 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___352 mkobj;
	struct module_attribute___352 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___412 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___352 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___352 core_layout;
	struct module_layout___352 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___147 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___352 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___352 *, struct module_kobject___352 *, char *);
	ssize_t (*store)(struct module_attribute___352 *, struct module_kobject___352 *, const char *, size_t);
	void (*setup)(struct module___354 *, const char *);
	int (*test)(struct module___354 *);
	void (*free)(struct module___354 *);
};

struct trace_event_class___147;

struct bpf_prog_array___61;

struct trace_event_call___147 {
	struct list_head list;
	struct trace_event_class___147 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___13 event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___61 *prog_array;
	int (*perf_perm)(struct trace_event_call___147 *, struct perf_event___156 *);
};

struct cgroup___273;

struct cgroup_subsys___273;

struct cgroup_subsys_state___273 {
	struct cgroup___273 *cgroup;
	struct cgroup_subsys___273 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___273 *parent;
};

struct cgroup_file___273 {
	struct kernfs_node___419 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___159;

struct mem_cgroup___159 {
	struct cgroup_subsys_state___273 css;
	struct mem_cgroup_id___13 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___273 events_file;
	struct cgroup_file___273 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___426 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___159 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct device___392;

struct dev_pm_ops___392 {
	int (*prepare)(struct device___392 *);
	void (*complete)(struct device___392 *);
	int (*suspend)(struct device___392 *);
	int (*resume)(struct device___392 *);
	int (*freeze)(struct device___392 *);
	int (*thaw)(struct device___392 *);
	int (*poweroff)(struct device___392 *);
	int (*restore)(struct device___392 *);
	int (*suspend_late)(struct device___392 *);
	int (*resume_early)(struct device___392 *);
	int (*freeze_late)(struct device___392 *);
	int (*thaw_early)(struct device___392 *);
	int (*poweroff_late)(struct device___392 *);
	int (*restore_early)(struct device___392 *);
	int (*suspend_noirq)(struct device___392 *);
	int (*resume_noirq)(struct device___392 *);
	int (*freeze_noirq)(struct device___392 *);
	int (*thaw_noirq)(struct device___392 *);
	int (*poweroff_noirq)(struct device___392 *);
	int (*restore_noirq)(struct device___392 *);
	int (*runtime_suspend)(struct device___392 *);
	int (*runtime_resume)(struct device___392 *);
	int (*runtime_idle)(struct device___392 *);
};

struct dev_pm_info___392 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___392 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___392;

struct bus_type___392;

struct device_driver___392;

struct dev_pm_domain___392;

struct dma_map_ops___164;

struct fwnode_handle___312;

struct class___392;

struct device___392 {
	struct device___392 *parent;
	struct device_private *p;
	struct kobject___412 kobj;
	const char *init_name;
	const struct device_type___392 *type;
	struct mutex mutex;
	struct bus_type___392 *bus;
	struct device_driver___392 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___392 power;
	struct dev_pm_domain___392 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___164 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___312 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___392 *class;
	const struct attribute_group___389 **groups;
	void (*release)(struct device___392 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___392 {
	struct dev_pm_ops___392 ops;
	void (*detach)(struct device___392 *, bool);
	int (*activate)(struct device___392 *);
	void (*sync)(struct device___392 *);
	void (*dismiss)(struct device___392 *);
};

struct upid___240 {
	int nr;
	struct pid_namespace___240 *ns;
};

struct pid_namespace___240 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___426 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___240 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___424 *proc_self;
	struct dentry___424 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___289 *user_ns;
	struct ucounts___289 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___29 ns;
};

struct pid___240 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___240 numbers[1];
};

struct user_struct___392 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___392 *uid_keyring;
	struct key___392 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___425;

struct mm_struct___425 {
	struct {
		struct vm_area_struct___425 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___424 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___426 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___425 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___426 *owner;
		struct user_namespace___289 *user_ns;
		struct file___424 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___425 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___273;

struct nsproxy___319 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___240 *pid_ns_for_children;
	struct net___81 *net_ns;
	struct cgroup_namespace___273 *cgroup_ns;
};

struct signal_struct___299 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___426 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___426 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___240 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___240 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___425 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___240 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___216;

struct bio_list___216 {
	struct bio___216 *head;
	struct bio___216 *tail;
};

struct bdi_writeback_congested___216;

struct bdi_writeback___216 {
	struct backing_dev_info___216 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___216 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___273 *memcg_css;
	struct cgroup_subsys_state___273 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___216 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___216 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___392 *dev;
	struct device___392 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___424 *debug_dir;
	struct dentry___424 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___273 {
	struct cgroup_subsys_state___273 *subsys[13];
	refcount_t refcount;
	struct css_set___273 *dom_cset;
	struct cgroup___273 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___273 *mg_src_cgrp;
	struct cgroup___273 *mg_dst_cgrp;
	struct css_set___273 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___156 {
	struct pmu___156 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___426 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___156 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___105;

struct pipe_inode_info___105 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___425 *tmp_page;
	struct fasync_struct___424 *fasync_readers;
	struct fasync_struct___424 *fasync_writers;
	struct pipe_buffer___105 *bufs;
	struct user_struct___392 *user;
};

struct vm_struct___328 {
	struct vm_struct___328 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___425 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___311 {
	struct task_struct___426 task;
	long unsigned int stack[8192];
};

struct bus_type___392 {
	const char *name;
	const char *dev_name;
	struct device___392 *dev_root;
	const struct attribute_group___389 **bus_groups;
	const struct attribute_group___389 **dev_groups;
	const struct attribute_group___389 **drv_groups;
	int (*match)(struct device___392 *, struct device_driver___392 *);
	int (*uevent)(struct device___392 *, struct kobj_uevent_env *);
	int (*probe)(struct device___392 *);
	int (*remove)(struct device___392 *);
	void (*shutdown)(struct device___392 *);
	int (*online)(struct device___392 *);
	int (*offline)(struct device___392 *);
	int (*suspend)(struct device___392 *, pm_message_t);
	int (*resume)(struct device___392 *);
	int (*num_vf)(struct device___392 *);
	int (*dma_configure)(struct device___392 *);
	const struct dev_pm_ops___392 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___392 {
	const char *name;
	struct bus_type___392 *bus;
	struct module___354 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___392 *);
	int (*remove)(struct device___392 *);
	void (*shutdown)(struct device___392 *);
	int (*suspend)(struct device___392 *, pm_message_t);
	int (*resume)(struct device___392 *);
	const struct attribute_group___389 **groups;
	const struct dev_pm_ops___392 *pm;
	void (*coredump)(struct device___392 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___392 {
	const char *name;
	const struct attribute_group___389 **groups;
	int (*uevent)(struct device___392 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___392 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___392 *);
	const struct dev_pm_ops___392 *pm;
};

struct class___392 {
	const char *name;
	struct module___354 *owner;
	const struct attribute_group___389 **class_groups;
	const struct attribute_group___389 **dev_groups;
	struct kobject___412 *dev_kobj;
	int (*dev_uevent)(struct device___392 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___392 *, umode_t *);
	void (*class_release)(struct class___392 *);
	void (*dev_release)(struct device___392 *);
	int (*shutdown_pre)(struct device___392 *);
	const struct kobj_ns_type_operations___51 *ns_type;
	const void * (*namespace)(struct device___392 *);
	const struct dev_pm_ops___392 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___164 {
	void * (*alloc)(struct device___392 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___392 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___392 *, struct vm_area_struct___425 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___392 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___392 *, struct page___425 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___392 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___392 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___392 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___392 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___392 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___392 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___392 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___392 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___392 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___392 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___392 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___392 *, u64);
	u64 (*get_required_mask)(struct device___392 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___312;

struct fwnode_handle___312 {
	struct fwnode_handle___312 *secondary;
	const struct fwnode_operations___312 *ops;
};

struct address_space_operations___424;

struct address_space___424 {
	struct inode___424 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___426 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___424 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___412)(struct vm_area_struct___425 *, long unsigned int, const struct page___425 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___412)(struct page___425 *, void *);

struct dev_pagemap___412 {
	dev_page_fault_t___412 page_fault;
	dev_page_free_t___412 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___392 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___425 {
	struct task_struct___426 *task;
	struct core_thread___425 *next;
};

struct core_state___425 {
	atomic_t nr_threads;
	struct core_thread___425 dumper;
	struct completion startup;
};

struct vm_fault___412 {
	struct vm_area_struct___425 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___425 *cow_page;
	struct mem_cgroup___159 *memcg;
	struct page___425 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___425 prealloc_pte;
};

struct bio_vec___218 {
	struct page___425 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___191 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___218 *bvec;
		struct pipe_inode_info___105 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct msghdr___54 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___191 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___424 *msg_iocb;
};

struct kiocb___424 {
	struct file___424 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___424 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dentry_operations___424;

struct super_block___424;

struct dentry___424 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___424 *d_parent;
	struct qstr d_name;
	struct inode___424 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___424 *d_op;
	struct super_block___424 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___424;

struct block_device___424;

struct inode___424 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___424 *i_op;
	struct super_block___424 *i_sb;
	struct address_space___424 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___426 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___216 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___424 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___424 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___105 *i_pipe;
		struct block_device___424 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___424 {
	int (*d_revalidate)(struct dentry___424 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___424 *, unsigned int);
	int (*d_hash)(const struct dentry___424 *, struct qstr *);
	int (*d_compare)(const struct dentry___424 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___424 *);
	int (*d_init)(struct dentry___424 *);
	void (*d_release)(struct dentry___424 *);
	void (*d_prune)(struct dentry___424 *);
	void (*d_iput)(struct dentry___424 *, struct inode___424 *);
	char * (*d_dname)(struct dentry___424 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___425 *);
	int (*d_manage)(const struct path___425 *, bool);
	struct dentry___424 * (*d_real)(struct dentry___424 *, const struct inode___424 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___424;

struct mem_dqinfo___424 {
	struct quota_format_type___424 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___424;

struct quota_info___424 {
	unsigned int flags;
	struct rw_semaphore___426 dqio_sem;
	struct inode___424 *files[3];
	struct mem_dqinfo___424 info[3];
	const struct quota_format_ops___424 *ops[3];
};

struct rcuwait___424 {
	struct task_struct___426 *task;
};

struct percpu_rw_semaphore___424 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___426 rw_sem;
	struct rcuwait___424 writer;
	int readers_block;
};

struct sb_writers___424 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___424 rw_sem[3];
};

struct shrink_control___159;

struct shrinker___159 {
	long unsigned int (*count_objects)(struct shrinker___159 *, struct shrink_control___159 *);
	long unsigned int (*scan_objects)(struct shrinker___159 *, struct shrink_control___159 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___424;

struct super_operations___424;

struct dquot_operations___424;

struct quotactl_ops___424;

struct super_block___424 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___424 *s_type;
	const struct super_operations___424 *s_op;
	const struct dquot_operations___424 *dq_op;
	const struct quotactl_ops___424 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___424 *s_root;
	struct rw_semaphore___426 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___424 *s_bdev;
	struct backing_dev_info___216 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___424 s_dquot;
	struct sb_writers___424 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___424 *s_d_op;
	int cleancache_poolid;
	struct shrinker___159 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___289 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___159 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___159 *memcg;
};

struct iattr___424 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___424 *ia_file;
};

struct dquot___424 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___424 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___424 {
	int qf_fmt_id;
	const struct quota_format_ops___424 *qf_ops;
	struct module___354 *qf_owner;
	struct quota_format_type___424 *qf_next;
};

struct quota_format_ops___424 {
	int (*check_quota_file)(struct super_block___424 *, int);
	int (*read_file_info)(struct super_block___424 *, int);
	int (*write_file_info)(struct super_block___424 *, int);
	int (*free_file_info)(struct super_block___424 *, int);
	int (*read_dqblk)(struct dquot___424 *);
	int (*commit_dqblk)(struct dquot___424 *);
	int (*release_dqblk)(struct dquot___424 *);
	int (*get_next_id)(struct super_block___424 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___424 {
	int (*write_dquot)(struct dquot___424 *);
	struct dquot___424 * (*alloc_dquot)(struct super_block___424 *, int);
	void (*destroy_dquot)(struct dquot___424 *);
	int (*acquire_dquot)(struct dquot___424 *);
	int (*release_dquot)(struct dquot___424 *);
	int (*mark_dirty)(struct dquot___424 *);
	int (*write_info)(struct super_block___424 *, int);
	qsize_t * (*get_reserved_space)(struct inode___424 *);
	int (*get_projid)(struct inode___424 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___424 *, qsize_t *);
	int (*get_next_id)(struct super_block___424 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___424 {
	int (*quota_on)(struct super_block___424 *, int, int, const struct path___425 *);
	int (*quota_off)(struct super_block___424 *, int);
	int (*quota_enable)(struct super_block___424 *, unsigned int);
	int (*quota_disable)(struct super_block___424 *, unsigned int);
	int (*quota_sync)(struct super_block___424 *, int);
	int (*set_info)(struct super_block___424 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___424 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___424 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___424 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___424 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___424 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___179;

struct address_space_operations___424 {
	int (*writepage)(struct page___425 *, struct writeback_control___179 *);
	int (*readpage)(struct file___424 *, struct page___425 *);
	int (*writepages)(struct address_space___424 *, struct writeback_control___179 *);
	int (*set_page_dirty)(struct page___425 *);
	int (*readpages)(struct file___424 *, struct address_space___424 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___424 *, struct address_space___424 *, loff_t, unsigned int, unsigned int, struct page___425 **, void **);
	int (*write_end)(struct file___424 *, struct address_space___424 *, loff_t, unsigned int, unsigned int, struct page___425 *, void *);
	sector_t (*bmap)(struct address_space___424 *, sector_t);
	void (*invalidatepage)(struct page___425 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___425 *, gfp_t);
	void (*freepage)(struct page___425 *);
	ssize_t (*direct_IO)(struct kiocb___424 *, struct iov_iter___191 *);
	int (*migratepage)(struct address_space___424 *, struct page___425 *, struct page___425 *, enum migrate_mode);
	bool (*isolate_page)(struct page___425 *, isolate_mode_t);
	void (*putback_page)(struct page___425 *);
	int (*launder_page)(struct page___425 *);
	int (*is_partially_uptodate)(struct page___425 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___425 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___424 *, struct page___425 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___424 *, sector_t *);
	void (*swap_deactivate)(struct file___424 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___179 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___216 *wb;
	struct inode___424 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___424 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___424 *bd_inode;
	struct super_block___424 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___424 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___216 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___424 {
	struct dentry___424 * (*lookup)(struct inode___424 *, struct dentry___424 *, unsigned int);
	const char * (*get_link)(struct dentry___424 *, struct inode___424 *, struct delayed_call *);
	int (*permission)(struct inode___424 *, int);
	struct posix_acl * (*get_acl)(struct inode___424 *, int);
	int (*readlink)(struct dentry___424 *, char *, int);
	int (*create)(struct inode___424 *, struct dentry___424 *, umode_t, bool);
	int (*link)(struct dentry___424 *, struct inode___424 *, struct dentry___424 *);
	int (*unlink)(struct inode___424 *, struct dentry___424 *);
	int (*symlink)(struct inode___424 *, struct dentry___424 *, const char *);
	int (*mkdir)(struct inode___424 *, struct dentry___424 *, umode_t);
	int (*rmdir)(struct inode___424 *, struct dentry___424 *);
	int (*mknod)(struct inode___424 *, struct dentry___424 *, umode_t, dev_t);
	int (*rename)(struct inode___424 *, struct dentry___424 *, struct inode___424 *, struct dentry___424 *, unsigned int);
	int (*setattr)(struct dentry___424 *, struct iattr___424 *);
	int (*getattr)(const struct path___425 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___424 *, char *, size_t);
	int (*fiemap)(struct inode___424 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___424 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___424 *, struct dentry___424 *, struct file___424 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___424 *, struct dentry___424 *, umode_t);
	int (*set_acl)(struct inode___424 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___424 {
	void (*fl_copy_lock)(struct file_lock___424 *, struct file_lock___424 *);
	void (*fl_release_private)(struct file_lock___424 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___424;

struct file_lock___424 {
	struct file_lock___424 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___424 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___424 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___424 *fl_ops;
	const struct lock_manager_operations___424 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___424 {
	int (*lm_compare_owner)(struct file_lock___424 *, struct file_lock___424 *);
	long unsigned int (*lm_owner_key)(struct file_lock___424 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___424 *);
	int (*lm_grant)(struct file_lock___424 *, int);
	bool (*lm_break)(struct file_lock___424 *);
	int (*lm_change)(struct file_lock___424 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___424 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___424 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___424 *fa_next;
	struct file___424 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___424 {
	const char *name;
	int fs_flags;
	struct dentry___424 * (*mount)(struct file_system_type___424 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___424 *);
	struct module___354 *owner;
	struct file_system_type___424 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___424 {
	struct inode___424 * (*alloc_inode)(struct super_block___424 *);
	void (*destroy_inode)(struct inode___424 *);
	void (*dirty_inode)(struct inode___424 *, int);
	int (*write_inode)(struct inode___424 *, struct writeback_control___179 *);
	int (*drop_inode)(struct inode___424 *);
	void (*evict_inode)(struct inode___424 *);
	void (*put_super)(struct super_block___424 *);
	int (*sync_fs)(struct super_block___424 *, int);
	int (*freeze_super)(struct super_block___424 *);
	int (*freeze_fs)(struct super_block___424 *);
	int (*thaw_super)(struct super_block___424 *);
	int (*unfreeze_fs)(struct super_block___424 *);
	int (*statfs)(struct dentry___424 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___424 *, int *, char *);
	void (*umount_begin)(struct super_block___424 *);
	int (*show_options)(struct seq_file___363 *, struct dentry___424 *);
	int (*show_devname)(struct seq_file___363 *, struct dentry___424 *);
	int (*show_path)(struct seq_file___363 *, struct dentry___424 *);
	int (*show_stats)(struct seq_file___363 *, struct dentry___424 *);
	ssize_t (*quota_read)(struct super_block___424 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___424 *, int, const char *, size_t, loff_t);
	struct dquot___424 ** (*get_dquots)(struct inode___424 *);
	int (*bdev_try_to_free_page)(struct super_block___424 *, struct page___425 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___424 *, struct shrink_control___159 *);
	long int (*free_cached_objects)(struct super_block___424 *, struct shrink_control___159 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___216(struct bio___216 *);

struct bio_integrity_payload___216;

struct bio_set___216;

struct bio___216 {
	struct bio___216 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___216 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___216 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___218 *bi_io_vec;
	struct bio_set___216 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___218 bi_inline_vecs[0];
};

struct socket_wq___52 {
	wait_queue_head_t wait;
	struct fasync_struct___424 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___52;

struct socket___53 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___52 *wq;
	struct file___424 *file;
	struct sock___52 *sk;
	const struct proto_ops___52 *ops;
};

typedef int (*sk_read_actor_t___51)(read_descriptor_t *, struct sk_buff___71 *, unsigned int, size_t);

struct proto_ops___52 {
	int family;
	struct module___354 *owner;
	int (*release)(struct socket___53 *);
	int (*bind)(struct socket___53 *, struct sockaddr *, int);
	int (*connect)(struct socket___53 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___53 *, struct socket___53 *);
	int (*accept)(struct socket___53 *, struct socket___53 *, int, bool);
	int (*getname)(struct socket___53 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___424 *, struct socket___53 *, struct poll_table_struct___265 *);
	int (*ioctl)(struct socket___53 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___53 *, int);
	int (*shutdown)(struct socket___53 *, int);
	int (*setsockopt)(struct socket___53 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___53 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___53 *, struct msghdr___54 *, size_t);
	int (*recvmsg)(struct socket___53 *, struct msghdr___54 *, size_t, int);
	int (*mmap)(struct file___424 *, struct socket___53 *, struct vm_area_struct___425 *);
	ssize_t (*sendpage)(struct socket___53 *, struct page___425 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___53 *, loff_t *, struct pipe_inode_info___105 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___52 *, int);
	int (*peek_len)(struct socket___53 *);
	int (*read_sock)(struct sock___52 *, read_descriptor_t *, sk_read_actor_t___51);
	int (*sendpage_locked)(struct sock___52 *, struct page___425 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___52 *, struct msghdr___54 *, size_t);
	int (*set_rcvlowat)(struct sock___52 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct nf_bridge_info___69;

struct sk_buff___71 {
	union {
		struct {
			struct sk_buff___71 *next;
			struct sk_buff___71 *prev;
			union {
				struct net_device___70 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___52 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___71 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___69 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___69;

struct netns_frags___69 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___69 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ip_ra_chain___25;

struct fib_rules_ops___51;

struct fib_notifier_ops___52;

struct netns_ipv4___69 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___25 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___51 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___52 *fibnl;
	struct sock___52 **icmp_sk;
	struct sock___52 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___52 **tcp_sk;
	struct netns_frags___69 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___51 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___52 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___52 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___51;

struct dst_ops___80 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___80 *);
	struct dst_entry___51 * (*check)(struct dst_entry___51 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___51 *);
	unsigned int (*mtu)(const struct dst_entry___51 *);
	u32 * (*cow_metrics)(struct dst_entry___51 *, long unsigned int);
	void (*destroy)(struct dst_entry___51 *);
	void (*ifdown)(struct dst_entry___51 *, struct net_device___70 *, int);
	struct dst_entry___51 * (*negative_advice)(struct dst_entry___51 *);
	void (*link_failure)(struct sk_buff___71 *);
	void (*update_pmtu)(struct dst_entry___51 *, struct sock___52 *, struct sk_buff___71 *, u32);
	void (*redirect)(struct dst_entry___51 *, struct sock___52 *, struct sk_buff___71 *);
	int (*local_out)(struct net___81 *, struct sock___52 *, struct sk_buff___71 *);
	struct neighbour___51 * (*neigh_lookup)(const struct dst_entry___51 *, struct sk_buff___71 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___51 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___80 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___69 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___80 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___51 *fib6_rules_ops;
	struct sock___52 **icmp_sk;
	struct sock___52 *ndisc_sk;
	struct sock___52 *tcp_sk;
	struct sock___52 *igmp_sk;
	struct sock___52 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___51 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___52 *notifier_ops;
	struct fib_notifier_ops___52 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___52 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___52 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___69 {
	struct netns_frags___69 frags;
};

struct netns_xfrm___80 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___52 *nlsk;
	struct sock___52 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___80 xfrm4_dst_ops;
	struct dst_ops___80 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct net___81 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___289 *user_ns;
	struct ucounts___289 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___29 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___52 *rtnl;
	struct sock___52 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___70 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___69 ipv4;
	struct netns_ipv6___80 ipv6;
	struct netns_sctp___52 sctp;
	struct netns_nf___4 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___69 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___52 *nfnl;
	struct sock___52 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___80 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___52 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___61 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef void compound_page_dtor___412(struct page___425 *);

struct fwnode_reference_args___312;

struct fwnode_endpoint___312;

struct fwnode_operations___312 {
	struct fwnode_handle___312 * (*get)(struct fwnode_handle___312 *);
	void (*put)(struct fwnode_handle___312 *);
	bool (*device_is_available)(const struct fwnode_handle___312 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___312 *, const struct device___392 *);
	bool (*property_present)(const struct fwnode_handle___312 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___312 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___312 *, const char *, const char **, size_t);
	struct fwnode_handle___312 * (*get_parent)(const struct fwnode_handle___312 *);
	struct fwnode_handle___312 * (*get_next_child_node)(const struct fwnode_handle___312 *, struct fwnode_handle___312 *);
	struct fwnode_handle___312 * (*get_named_child_node)(const struct fwnode_handle___312 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___312 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___312 *);
	struct fwnode_handle___312 * (*graph_get_next_endpoint)(const struct fwnode_handle___312 *, struct fwnode_handle___312 *);
	struct fwnode_handle___312 * (*graph_get_remote_endpoint)(const struct fwnode_handle___312 *);
	struct fwnode_handle___312 * (*graph_get_port_parent)(struct fwnode_handle___312 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___312 *, struct fwnode_endpoint___312 *);
};

struct fwnode_endpoint___312 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___312 *local_fwnode;
};

struct fwnode_reference_args___312 {
	struct fwnode_handle___312 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___105;

struct pipe_buffer___105 {
	struct page___425 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___105 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___105 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___105 *, struct pipe_buffer___105 *);
	void (*release)(struct pipe_inode_info___105 *, struct pipe_buffer___105 *);
	int (*steal)(struct pipe_inode_info___105 *, struct pipe_buffer___105 *);
	union {
		bool (*get)(struct pipe_inode_info___105 *, struct pipe_buffer___105 *);
		struct {
			void (*get)(struct pipe_inode_info___105 *, struct pipe_buffer___105 *);
		} __UNIQUE_ID_rh_kabi_hide21;
		union {		};
	};
};

struct nf_bridge_info___69 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___69 = 0,
		BRNF_PROTO_8021Q___69 = 1,
		BRNF_PROTO_PPPOE___69 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___70 *physindev;
	struct net_device___70 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___69(struct sk_buff___71 **);

struct net_device_ops___69;

struct ethtool_ops___69;

struct l3mdev_ops___51;

struct ndisc_ops___29;

struct xfrmdev_ops___69;

struct tlsdev_ops___69;

struct header_ops___69;

struct inet6_dev___29;

struct netdev_rx_queue___69;

struct mini_Qdisc___61;

struct netdev_queue___69;

struct Qdisc___61;

struct rtnl_link_ops___61;

struct dcbnl_rtnl_ops___69;

struct net_device___70 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___69 *netdev_ops;
	const struct ethtool_ops___69 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___51 *l3mdev_ops;
	const struct ndisc_ops___29 *ndisc_ops;
	const struct xfrmdev_ops___69 *xfrmdev_ops;
	const struct tlsdev_ops___69 *tlsdev_ops;
	const struct header_ops___69 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___411 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___29 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___69 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___61 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___69 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___61 *miniq_ingress;
	struct netdev_queue___69 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___69 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___61 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___61 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___69 = 0,
		NETREG_REGISTERED___69 = 1,
		NETREG_UNREGISTERING___69 = 2,
		NETREG_UNREGISTERED___69 = 3,
		NETREG_RELEASED___69 = 4,
		NETREG_DUMMY___69 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___69 = 0,
		RTNL_LINK_INITIALIZING___69 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___70 *);
	struct netpoll_info *npinfo;
	possible_net_t___71 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___392 dev;
	const struct attribute_group___389 *sysfs_groups[4];
	const struct attribute_group___389 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___61 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___69 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide35;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct ethtool_ops___69 {
	int (*get_settings)(struct net_device___70 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___70 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___70 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___70 *);
	void (*get_regs)(struct net_device___70 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___70 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___70 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___70 *);
	void (*set_msglevel)(struct net_device___70 *, u32);
	int (*nway_reset)(struct net_device___70 *);
	u32 (*get_link)(struct net_device___70 *);
	int (*get_eeprom_len)(struct net_device___70 *);
	int (*get_eeprom)(struct net_device___70 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___70 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___70 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___70 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___70 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___70 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___70 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___70 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___70 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___70 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___70 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___70 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___70 *);
	void (*complete)(struct net_device___70 *);
	u32 (*get_priv_flags)(struct net_device___70 *);
	int (*set_priv_flags)(struct net_device___70 *, u32);
	int (*get_sset_count)(struct net_device___70 *, int);
	int (*get_rxnfc)(struct net_device___70 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___70 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___70 *, struct ethtool_flash *);
	int (*reset)(struct net_device___70 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___70 *);
	u32 (*get_rxfh_indir_size)(struct net_device___70 *);
	int (*get_rxfh)(struct net_device___70 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___70 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___70 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___70 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___70 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___70 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___70 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___70 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___70 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___70 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___70 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___70 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___70 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___70 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___70 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___70 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___70 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___70 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___70 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___70 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___70 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___70 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	int (*get_fecparam)(struct net_device___70 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___70 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___70 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___70 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___70 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___69;

struct inet_frags___69 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___69 *, const void *);
	void (*destructor)(struct inet_frag_queue___69 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___69 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___71 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___71 *fragments_tail;
	struct sk_buff___71 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___69 *net;
	struct callback_head rcu;
};

struct ip_ra_chain___25 {
	struct ip_ra_chain___25 *next;
	struct sock___52 *sk;
	union {
		void (*destructor)(struct sock___52 *);
		struct sock___52 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___51;

struct fib_lookup_arg___51;

struct fib_rules_ops___51 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___51 *, struct flowi *, int, struct fib_lookup_arg___51 *);
	bool (*suppress)(struct fib_rule___51 *, struct fib_lookup_arg___51 *);
	int (*match)(struct fib_rule___51 *, struct flowi *, int);
	int (*configure)(struct fib_rule___51 *, struct sk_buff___71 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___51 *);
	int (*compare)(struct fib_rule___51 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___51 *, struct sk_buff___71 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___51 *);
	void (*flush_cache)(struct fib_rules_ops___51 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___354 *owner;
	struct net___81 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___52 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___81 *);
	int (*fib_dump)(struct net___81 *, struct notifier_block *);
	struct module___354 *owner;
	struct callback_head rcu;
};

struct dst_entry___51 {
	struct net_device___70 *dev;
	struct dst_ops___80 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___71 *);
	int (*output)(struct net___81 *, struct sock___52 *, struct sk_buff___71 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___51;

struct neigh_parms___51;

struct neigh_ops___51;

struct neighbour___51 {
	struct neighbour___51 *next;
	struct neigh_table___51 *tbl;
	struct neigh_parms___51 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___69 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___51 *, struct sk_buff___71 *);
	const struct neigh_ops___51 *ops;
	struct callback_head rcu;
	struct net_device___70 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct ucounts___289 {
	struct hlist_node node;
	struct user_namespace___289 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_prog_aux___64;

struct bpf_prog___61 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___64 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

typedef int (*key_restrict_link_func_t___393)(struct key___392 *, const struct key_type *, const union key_payload *, struct key___392 *);

struct key_restriction___392;

struct key___392 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___426 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___392 *restrict_link;
};

struct key_restriction___392 {
	key_restrict_link_func_t___393 check;
	struct key___392 *key;
	struct key_type *keytype;
};

struct seq_operations___363 {
	void * (*start)(struct seq_file___363 *, loff_t *);
	void (*stop)(struct seq_file___363 *, void *);
	void * (*next)(struct seq_file___363 *, void *, loff_t *);
	int (*show)(struct seq_file___363 *, void *);
};

struct pernet_operations___70 {
	struct list_head list;
	int (*init)(struct net___81 *);
	void (*exit)(struct net___81 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___69 {
	int (*ieee_getets)(struct net_device___70 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___70 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___70 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___70 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___70 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___70 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___70 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___70 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___70 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___70 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___70 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___70 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___70 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___70 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___70 *);
	u8 (*setstate)(struct net_device___70 *, u8);
	void (*getpermhwaddr)(struct net_device___70 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___70 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___70 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___70 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___70 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___70 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___70 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___70 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___70 *, int, u8 *);
	void (*setpfccfg)(struct net_device___70 *, int, u8);
	void (*getpfccfg)(struct net_device___70 *, int, u8 *);
	u8 (*setall)(struct net_device___70 *);
	u8 (*getcap)(struct net_device___70 *, int, u8 *);
	int (*getnumtcs)(struct net_device___70 *, int, u8 *);
	int (*setnumtcs)(struct net_device___70 *, int, u8);
	u8 (*getpfcstate)(struct net_device___70 *);
	void (*setpfcstate)(struct net_device___70 *, u8);
	void (*getbcncfg)(struct net_device___70 *, int, u32 *);
	void (*setbcncfg)(struct net_device___70 *, int, u32);
	void (*getbcnrp)(struct net_device___70 *, int, u8 *);
	void (*setbcnrp)(struct net_device___70 *, int, u8);
	int (*setapp)(struct net_device___70 *, u8, u16, u8);
	int (*getapp)(struct net_device___70 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___70 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___70 *, int, u8);
	u8 (*getdcbx)(struct net_device___70 *);
	u8 (*setdcbx)(struct net_device___70 *, u8);
	int (*peer_getappinfo)(struct net_device___70 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___70 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___70 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___70 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___70 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___70 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___273 {
	refcount_t count;
	struct ns_common___29 ns;
	struct user_namespace___289 *user_ns;
	struct ucounts___289 *ucounts;
	struct css_set___273 *root_cset;
};

struct bpf_map___274;

struct bpf_map_ops___273 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___274 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___274 *, struct file___424 *);
	void (*map_free)(struct bpf_map___274 *);
	int (*map_get_next_key)(struct bpf_map___274 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___274 *);
	void * (*map_lookup_elem)(struct bpf_map___274 *, void *);
	int (*map_update_elem)(struct bpf_map___274 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___274 *, void *);
	int (*map_push_elem)(struct bpf_map___274 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___274 *, void *);
	int (*map_peek_elem)(struct bpf_map___274 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___274 *, struct file___424 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___274 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___274 *, void *, struct seq_file___363 *);
	int (*map_check_btf)(const struct bpf_map___274 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___274 {
	const struct bpf_map_ops___273 *ops;
	struct bpf_map___274 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___392 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___69;

struct bpf_map_dev_ops___69 {
	int (*map_get_next_key)(struct bpf_offloaded_map___69 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___69 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___69 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___69 *, void *);
};

struct bpf_offloaded_map___69 {
	struct bpf_map___274 map;
	struct net_device___70 *netdev;
	const struct bpf_map_dev_ops___69 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___61 {
	int (*test_run)(struct bpf_prog___61 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___61 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___61 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___61 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___61 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___61 *, u32 *);
};

struct bpf_prog_offload_ops___61 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___61 *);
	int (*translate)(struct bpf_prog___61 *);
	void (*destroy)(struct bpf_prog___61 *);
};

struct bpf_prog_offload___61 {
	struct bpf_prog___61 *prog;
	struct net_device___70 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___61 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___64 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___61 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___61 *ops;
	struct bpf_map___274 **used_maps;
	struct bpf_prog___61 *prog;
	struct user_struct___392 *user;
	u64 load_time;
	struct bpf_map___274 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___61 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___61 {
	struct bpf_prog___61 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___61 {
	struct callback_head rcu;
	struct bpf_prog_array_item___61 items[0];
};

struct cgroup_bpf___61 {
	struct bpf_prog_array___61 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___61 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___274;

typedef void (*kthread_work_func_t___274)(struct kthread_work___274 *);

struct kthread_worker___274;

struct kthread_work___274 {
	struct list_head node;
	kthread_work_func_t___274 func;
	struct kthread_worker___274 *worker;
	int canceling;
};

struct kthread_worker___274 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___426 *task;
	struct kthread_work___274 *current_work;
};

struct kthread_delayed_work___273 {
	struct kthread_work___274 work;
	struct timer_list timer;
};

struct psi_group___273 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___274 *poll_kworker;
	struct kthread_delayed_work___273 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___273;

struct cgroup_rstat_cpu___273;

struct cgroup___273 {
	struct cgroup_subsys_state___273 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___419 *kn;
	struct cgroup_file___273 procs_file;
	struct cgroup_file___273 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___273 *subsys[13];
	struct cgroup_root___273 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___273 *dom_cgrp;
	struct cgroup_rstat_cpu___273 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___61 bpf;
	atomic_t congestion_count;
	struct cgroup___273 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___273 psi;
	int ancestor_ids[0];
};

struct cftype___273;

struct cgroup_subsys___273 {
	struct cgroup_subsys_state___273 * (*css_alloc)(struct cgroup_subsys_state___273 *);
	int (*css_online)(struct cgroup_subsys_state___273 *);
	void (*css_offline)(struct cgroup_subsys_state___273 *);
	void (*css_released)(struct cgroup_subsys_state___273 *);
	void (*css_free)(struct cgroup_subsys_state___273 *);
	void (*css_reset)(struct cgroup_subsys_state___273 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___273 *, int);
	int (*css_extra_stat_show)(struct seq_file___363 *, struct cgroup_subsys_state___273 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___426 *);
	void (*cancel_fork)(struct task_struct___426 *);
	void (*fork)(struct task_struct___426 *);
	void (*exit)(struct task_struct___426 *);
	void (*free)(struct task_struct___426 *);
	void (*bind)(struct cgroup_subsys_state___273 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___273 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___273 *dfl_cftypes;
	struct cftype___273 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___273 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___273 *updated_children;
	struct cgroup___273 *updated_next;
};

struct cgroup_root___273 {
	struct kernfs_root___418 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___273 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___273 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___273 *ss;
	struct list_head node;
	struct kernfs_ops___418 *kf_ops;
	int (*open)(struct kernfs_open_file___418 *);
	void (*release)(struct kernfs_open_file___418 *);
	u64 (*read_u64)(struct cgroup_subsys_state___273 *, struct cftype___273 *);
	s64 (*read_s64)(struct cgroup_subsys_state___273 *, struct cftype___273 *);
	int (*seq_show)(struct seq_file___363 *, void *);
	void * (*seq_start)(struct seq_file___363 *, loff_t *);
	void * (*seq_next)(struct seq_file___363 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___363 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___273 *, struct cftype___273 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___273 *, struct cftype___273 *, s64);
	ssize_t (*write)(struct kernfs_open_file___418 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___418 *, struct poll_table_struct___265 *);
};

struct xdp_rxq_info___69 {
	struct net_device___70 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___69 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___70 *dev_rx;
};

struct netlink_skb_parms___11 {
	struct scm_creds creds;
	__u32 portid;
	__u32 dst_group;
	__u32 flags;
	struct sock___52 *sk;
	bool nsid_is_set;
	int nsid;
};

struct netlink_callback___71 {
	struct sk_buff___71 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___71 *);
	int (*dump)(struct sk_buff___71 *, struct netlink_callback___71 *);
	int (*done)(struct netlink_callback___71 *);
	void *data;
	struct module___354 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___69 {
	int (*create)(struct sk_buff___71 *, struct net_device___70 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___71 *, unsigned char *);
	int (*cache)(const struct neighbour___51 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___70 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___69 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___69 *, int);
	int poll_owner;
	struct net_device___70 *dev;
	struct sk_buff___71 *gro_list;
	struct sk_buff___71 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___69 {
	struct net_device___70 *dev;
	struct Qdisc___61 *qdisc;
	struct Qdisc___61 *qdisc_sleeping;
	struct kobject___412 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___70 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem___3 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___61 {
	struct sk_buff___71 *head;
	struct sk_buff___71 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___61;

struct Qdisc___61 {
	int (*enqueue)(struct sk_buff___71 *, struct Qdisc___61 *, struct sk_buff___71 **);
	struct sk_buff___71 * (*dequeue)(struct Qdisc___61 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___61 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___69 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___69 gso_skb;
	struct qdisc_skb_head___61 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___61 *next_sched;
	struct sk_buff_head___69 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___69 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___412 kobj;
	struct net_device___70 *dev;
	long: 64;
	struct xdp_rxq_info___69 xdp_rxq;
	union {
		struct xdp_umem___3 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___69)(struct net_device___70 *, struct sk_buff___71 *, struct net_device___70 *);

struct netdev_bpf___69 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___61 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___61 *prog;
			const struct bpf_prog_offload_ops___61 *ops;
		} verifier;
		struct {
			struct bpf_prog___61 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___69 *offmap;
		};
		struct {
			struct xdp_umem___3 *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___69 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___71 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___69 {
	int (*tls_dev_add)(struct net_device___70 *, struct sock___52 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___70 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___70 *, struct sock___52 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___69 {
	int (*ndo_init)(struct net_device___70 *);
	void (*ndo_uninit)(struct net_device___70 *);
	int (*ndo_open)(struct net_device___70 *);
	int (*ndo_stop)(struct net_device___70 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___71 *, struct net_device___70 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___71 *, struct net_device___70 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___70 *, struct sk_buff___71 *, struct net_device___70 *, select_queue_fallback_t___69);
	void (*ndo_change_rx_flags)(struct net_device___70 *, int);
	void (*ndo_set_rx_mode)(struct net_device___70 *);
	int (*ndo_set_mac_address)(struct net_device___70 *, void *);
	int (*ndo_validate_addr)(struct net_device___70 *);
	int (*ndo_do_ioctl)(struct net_device___70 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___70 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___70 *, int);
	int (*ndo_neigh_setup)(struct net_device___70 *, struct neigh_parms___51 *);
	void (*ndo_tx_timeout)(struct net_device___70 *);
	void (*ndo_get_stats64)(struct net_device___70 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___70 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___70 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___70 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___70 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___70 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___70 *);
	int (*ndo_netpoll_setup)(struct net_device___70 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___70 *);
	int (*ndo_set_vf_mac)(struct net_device___70 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___70 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___70 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___70 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___70 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___70 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___70 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___70 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___70 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___70 *, int, struct sk_buff___71 *);
	int (*ndo_set_vf_guid)(struct net_device___70 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___70 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___70 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___70 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___70 *, const struct sk_buff___71 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___70 *, struct net_device___70 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___70 *, struct net_device___70 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___70 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___70 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___70 *, struct neighbour___51 *);
	void (*ndo_neigh_destroy)(struct net_device___70 *, struct neighbour___51 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___70 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___70 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___70 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___71 *, struct netlink_callback___71 *, struct net_device___70 *, struct net_device___70 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___70 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___70 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___71 *, u32, u32, struct net_device___70 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___70 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___70 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___70 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___70 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___70 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___70 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___70 *, struct net_device___70 *);
	void (*ndo_dfwd_del_station)(struct net_device___70 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___70 *);
	int (*ndo_set_tx_maxrate)(struct net_device___70 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___70 *);
	int (*ndo_change_proto_down)(struct net_device___70 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___70 *, struct sk_buff___71 *);
	void (*ndo_set_rx_headroom)(struct net_device___70 *, int);
	int (*ndo_bpf)(struct net_device___70 *, struct netdev_bpf___69 *);
	int (*ndo_xdp_xmit)(struct net_device___70 *, int, struct xdp_frame___69 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___70 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___70 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___51 {
	possible_net_t___71 net;
	struct net_device___70 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___51 *);
	void (*neigh_cleanup)(struct neighbour___51 *);
	struct neigh_table___51 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___51 {
	u32 (*l3mdev_fib_table)(const struct net_device___70 *);
	struct sk_buff___71 * (*l3mdev_l3_rcv)(struct net_device___70 *, struct sk_buff___71 *, u16);
	struct sk_buff___71 * (*l3mdev_l3_out)(struct net_device___70 *, struct sock___52 *, struct sk_buff___71 *, u16);
	struct dst_entry___51 * (*l3mdev_link_scope_lookup)(const struct net_device___70 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct ndisc_ops___29 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___70 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___70 *, struct neighbour___51 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___70 *, u8, struct neighbour___51 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___70 *, struct sk_buff___71 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___81 *, struct net_device___70 *, const struct prefix_info *, struct inet6_dev___29 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___29;

struct inet6_dev___29 {
	struct net_device___70 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___29 *mc_list;
	struct ifmcaddr6___29 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___9 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	u8 rndid[8];
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___51 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
};

struct tcf_proto___61;

struct mini_Qdisc___61 {
	struct tcf_proto___61 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___61 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___70 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___81 *, struct net_device___70 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___70 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___70 *, struct list_head *);
	size_t (*get_size)(const struct net_device___70 *);
	int (*fill_info)(struct sk_buff___71 *, const struct net_device___70 *);
	size_t (*get_xstats_size)(const struct net_device___70 *);
	int (*fill_xstats)(struct sk_buff___71 *, const struct net_device___70 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___70 *, struct net_device___70 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___70 *, const struct net_device___70 *);
	int (*fill_slave_info)(struct sk_buff___71 *, const struct net_device___70 *, const struct net_device___70 *);
	struct net___81 * (*get_link_net)(const struct net_device___70 *);
	size_t (*get_linkxstats_size)(const struct net_device___70 *, int);
	int (*fill_linkxstats)(struct sk_buff___71 *, const struct net_device___70 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___69 {
	struct list_head poll_list;
	struct sk_buff_head___69 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___69 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___61 *output_queue;
	struct Qdisc___61 **output_queue_tailp;
	struct sk_buff___71 *completion_queue;
	struct sk_buff_head___69 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___69 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___69 input_pkt_queue;
	struct napi_struct___69 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bdi_writeback_congested___216 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___216 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___216 {
	struct bio___216 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___218 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___218 bip_inline_vecs[0];
};

struct bio_set___216 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___216 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___159 {
	struct mem_cgroup___159 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___159 {
	struct lruvec___425 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___159 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___159 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct gnet_dump___61 {
	spinlock_t *lock;
	struct sk_buff___71 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___61;

struct Qdisc_ops___61 {
	struct Qdisc_ops___61 *next;
	const struct Qdisc_class_ops___61 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___71 *, struct Qdisc___61 *, struct sk_buff___71 **);
	struct sk_buff___71 * (*dequeue)(struct Qdisc___61 *);
	struct sk_buff___71 * (*peek)(struct Qdisc___61 *);
	int (*init)(struct Qdisc___61 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___61 *);
	void (*destroy)(struct Qdisc___61 *);
	int (*change)(struct Qdisc___61 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___61 *);
	int (*change_tx_queue_len)(struct Qdisc___61 *, unsigned int);
	int (*dump)(struct Qdisc___61 *, struct sk_buff___71 *);
	int (*dump_stats)(struct Qdisc___61 *, struct gnet_dump___61 *);
	void (*ingress_block_set)(struct Qdisc___61 *, u32);
	void (*egress_block_set)(struct Qdisc___61 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___61 *);
	u32 (*egress_block_get)(struct Qdisc___61 *);
	struct module___354 *owner;
};

struct tcf_block___61;

struct Qdisc_class_ops___61 {
	unsigned int flags;
	struct netdev_queue___69 * (*select_queue)(struct Qdisc___61 *, struct tcmsg *);
	int (*graft)(struct Qdisc___61 *, long unsigned int, struct Qdisc___61 *, struct Qdisc___61 **, struct netlink_ext_ack *);
	struct Qdisc___61 * (*leaf)(struct Qdisc___61 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___61 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___61 *, u32);
	int (*change)(struct Qdisc___61 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___61 *, long unsigned int);
	void (*walk)(struct Qdisc___61 *, struct qdisc_walker *);
	struct tcf_block___61 * (*tcf_block)(struct Qdisc___61 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___61 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___61 *, long unsigned int);
	int (*dump)(struct Qdisc___61 *, long unsigned int, struct sk_buff___71 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___61 *, long unsigned int, struct gnet_dump___61 *);
};

struct tcf_chain___61;

struct tcf_block___61 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___81 *net;
	struct Qdisc___61 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___61 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___61;

struct tcf_proto_ops___61;

struct tcf_proto___61 {
	struct tcf_proto___61 *next;
	void *root;
	int (*classify)(struct sk_buff___71 *, const struct tcf_proto___61 *, struct tcf_result___61 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___61 *ops;
	struct tcf_chain___61 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___61 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___61 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___61 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___71 *, const struct tcf_proto___61 *, struct tcf_result___61 *);
	int (*init)(struct tcf_proto___61 *);
	void (*destroy)(struct tcf_proto___61 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___61 *, u32);
	void (*put)(struct tcf_proto___61 *, void *);
	int (*change)(struct net___81 *, struct sk_buff___71 *, struct tcf_proto___61 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___61 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___61 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___61 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___81 *, struct tcf_chain___61 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___81 *, struct tcf_proto___61 *, void *, struct sk_buff___71 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___71 *, struct net___81 *, void *);
	struct module___354 *owner;
	int flags;
};

struct tcf_chain___61 {
	struct mutex filter_chain_lock;
	struct tcf_proto___61 *filter_chain;
	struct list_head list;
	struct tcf_block___61 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___61 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___51 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___61 *prog;
};

struct bpf_redirect_info___61 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___274 *map;
	struct bpf_map___274 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___51;

struct neigh_hash_table___51;

struct neigh_table___51 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___70 *, __u32 *);
	bool (*key_eq)(const struct neighbour___51 *, const void *);
	int (*constructor)(struct neighbour___51 *);
	int (*pconstructor)(struct pneigh_entry___51 *);
	void (*pdestructor)(struct pneigh_entry___51 *);
	void (*proxy_redo)(struct sk_buff___71 *);
	char *id;
	struct neigh_parms___51 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___69 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___51 *nht;
	struct pneigh_entry___51 **phash_buckets;
};

struct neigh_ops___51 {
	int family;
	void (*solicit)(struct neighbour___51 *, struct sk_buff___71 *);
	void (*error_report)(struct neighbour___51 *, struct sk_buff___71 *);
	int (*output)(struct neighbour___51 *, struct sk_buff___71 *);
	int (*connected_output)(struct neighbour___51 *, struct sk_buff___71 *);
};

struct pneigh_entry___51 {
	struct pneigh_entry___51 *next;
	possible_net_t___71 net;
	struct net_device___70 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___51 {
	struct neighbour___51 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___51 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___51 *ctarget;
	struct net___81 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___51 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___51 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___35;

struct timewait_sock_ops___32;

struct proto___51 {
	void (*close)(struct sock___52 *, long int);
	int (*pre_connect)(struct sock___52 *, struct sockaddr *, int);
	int (*connect)(struct sock___52 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___52 *, int);
	struct sock___52 * (*accept)(struct sock___52 *, int, int *, bool);
	int (*ioctl)(struct sock___52 *, int, long unsigned int);
	int (*init)(struct sock___52 *);
	void (*destroy)(struct sock___52 *);
	void (*shutdown)(struct sock___52 *, int);
	int (*setsockopt)(struct sock___52 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___52 *, int, int, char *, int *);
	void (*keepalive)(struct sock___52 *, int);
	int (*sendmsg)(struct sock___52 *, struct msghdr___54 *, size_t);
	int (*recvmsg)(struct sock___52 *, struct msghdr___54 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___52 *, struct page___425 *, int, size_t, int);
	int (*bind)(struct sock___52 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___52 *, struct sk_buff___71 *);
	void (*release_cb)(struct sock___52 *);
	int (*hash)(struct sock___52 *);
	void (*unhash)(struct sock___52 *);
	void (*rehash)(struct sock___52 *);
	int (*get_port)(struct sock___52 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___52 *);
	bool (*stream_memory_read)(const struct sock___52 *);
	void (*enter_memory_pressure)(struct sock___52 *);
	void (*leave_memory_pressure)(struct sock___52 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___35 *rsk_prot;
	struct timewait_sock_ops___32 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___354 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___52 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct request_sock___36;

struct request_sock_ops___35 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___52 *, struct request_sock___36 *);
	void (*send_ack)(const struct sock___52 *, struct sk_buff___71 *, struct request_sock___36 *);
	void (*send_reset)(const struct sock___52 *, struct sk_buff___71 *);
	void (*destructor)(struct request_sock___36 *);
	void (*syn_ack_timeout)(const struct request_sock___36 *);
};

struct timewait_sock_ops___32 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___52 *, struct sock___52 *, void *);
	void (*twsk_destructor)(struct sock___52 *);
};

struct request_sock___36 {
	struct sock_common___51 __req_common;
	struct request_sock___36 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___35 *rsk_ops;
	struct sock___52 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___29 {
	struct in6_addr mca_addr;
	struct inet6_dev___29 *idev;
	struct ifmcaddr6___29 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ip6_ra_chain___29 {
	struct ip6_ra_chain___29 *next;
	struct sock___52 *sk;
	int sel;
	void (*destructor)(struct sock___52 *);
};

struct rdma_cgroup___3 {
	struct cgroup_subsys_state___273 css;
	struct list_head rpools;
};

struct rdma_restrack_entry___2;

struct rdma_restrack_root___2 {
	struct rw_semaphore___426 rwsem;
	struct hlist_head hash[256];
	int (*fill_res_entry)(struct sk_buff___71 *, struct rdma_restrack_entry___2 *);
};

struct rdma_restrack_entry___2 {
	bool valid;
	struct kref kref;
	struct completion comp;
	struct task_struct___426 *task;
	const char *kern_name;
	struct hlist_node node;
	enum rdma_restrack_type type;
	bool user;
};

struct ib_device___2;

struct ib_gid_attr___2 {
	struct net_device___70 *ndev;
	struct ib_device___2 *device;
	union ib_gid gid;
	enum ib_gid_type gid_type;
	u16 index;
	u8 port_num;
};

struct ib_qp___2;

struct ib_send_wr___2;

struct ib_recv_wr___2;

struct ib_cq___2;

struct ib_wc___2;

struct ib_srq___2;

struct rdma_netdev_alloc_params___2;

struct ib_ucontext___2;

struct ib_pd___2;

struct ib_ah___2;

struct rdma_ah_attr___2;

struct ib_srq_init_attr___2;

struct ib_qp_init_attr___2;

struct ib_qp_attr___2;

struct ib_mr___2;

struct ib_mw___2;

struct ib_fmr___2;

struct ib_xrcd___2;

struct ib_flow___2;

struct ib_flow_attr___2;

struct ib_flow_action___2;

struct ib_flow_action_attrs_esp___2;

struct ib_wq___2;

struct ib_wq_init_attr___2;

struct ib_rwq_ind_table___2;

struct ib_rwq_ind_table_init_attr___2;

struct ib_dm___2;

struct ib_counters___2;

struct ib_device_ops___2 {
	int (*post_send)(struct ib_qp___2 *, const struct ib_send_wr___2 *, const struct ib_send_wr___2 **);
	int (*post_recv)(struct ib_qp___2 *, const struct ib_recv_wr___2 *, const struct ib_recv_wr___2 **);
	void (*drain_rq)(struct ib_qp___2 *);
	void (*drain_sq)(struct ib_qp___2 *);
	int (*poll_cq)(struct ib_cq___2 *, int, struct ib_wc___2 *);
	int (*peek_cq)(struct ib_cq___2 *, int);
	int (*req_notify_cq)(struct ib_cq___2 *, enum ib_cq_notify_flags);
	int (*req_ncomp_notif)(struct ib_cq___2 *, int);
	int (*post_srq_recv)(struct ib_srq___2 *, const struct ib_recv_wr___2 *, const struct ib_recv_wr___2 **);
	int (*process_mad)(struct ib_device___2 *, int, u8, const struct ib_wc___2 *, const struct ib_grh *, const struct ib_mad_hdr *, size_t, struct ib_mad_hdr *, size_t *, u16 *);
	int (*query_device)(struct ib_device___2 *, struct ib_device_attr *, struct ib_udata *);
	int (*modify_device)(struct ib_device___2 *, int, struct ib_device_modify *);
	void (*get_dev_fw_str)(struct ib_device___2 *, char *);
	const struct cpumask * (*get_vector_affinity)(struct ib_device___2 *, int);
	int (*query_port)(struct ib_device___2 *, u8, struct ib_port_attr *);
	int (*modify_port)(struct ib_device___2 *, u8, int, struct ib_port_modify *);
	int (*get_port_immutable)(struct ib_device___2 *, u8, struct ib_port_immutable *);
	enum rdma_link_layer (*get_link_layer)(struct ib_device___2 *, u8);
	struct net_device___70 * (*get_netdev)(struct ib_device___2 *, u8);
	struct net_device___70 * (*alloc_rdma_netdev)(struct ib_device___2 *, u8, enum rdma_netdev_t, const char *, unsigned char, void (*)(struct net_device___70 *));
	int (*rdma_netdev_get_params)(struct ib_device___2 *, u8, enum rdma_netdev_t, struct rdma_netdev_alloc_params___2 *);
	int (*query_gid)(struct ib_device___2 *, u8, int, union ib_gid *);
	int (*add_gid)(const struct ib_gid_attr___2 *, void **);
	int (*del_gid)(const struct ib_gid_attr___2 *, void **);
	int (*query_pkey)(struct ib_device___2 *, u8, u16, u16 *);
	struct ib_ucontext___2 * (*alloc_ucontext)(struct ib_device___2 *, struct ib_udata *);
	int (*dealloc_ucontext)(struct ib_ucontext___2 *);
	int (*mmap)(struct ib_ucontext___2 *, struct vm_area_struct___425 *);
	void (*disassociate_ucontext)(struct ib_ucontext___2 *);
	struct ib_pd___2 * (*alloc_pd)(struct ib_device___2 *, struct ib_ucontext___2 *, struct ib_udata *);
	int (*dealloc_pd)(struct ib_pd___2 *);
	struct ib_ah___2 * (*create_ah)(struct ib_pd___2 *, struct rdma_ah_attr___2 *, u32, struct ib_udata *);
	int (*modify_ah)(struct ib_ah___2 *, struct rdma_ah_attr___2 *);
	int (*query_ah)(struct ib_ah___2 *, struct rdma_ah_attr___2 *);
	int (*destroy_ah)(struct ib_ah___2 *, u32);
	struct ib_srq___2 * (*create_srq)(struct ib_pd___2 *, struct ib_srq_init_attr___2 *, struct ib_udata *);
	int (*modify_srq)(struct ib_srq___2 *, struct ib_srq_attr *, enum ib_srq_attr_mask, struct ib_udata *);
	int (*query_srq)(struct ib_srq___2 *, struct ib_srq_attr *);
	int (*destroy_srq)(struct ib_srq___2 *);
	struct ib_qp___2 * (*create_qp)(struct ib_pd___2 *, struct ib_qp_init_attr___2 *, struct ib_udata *);
	int (*modify_qp)(struct ib_qp___2 *, struct ib_qp_attr___2 *, int, struct ib_udata *);
	int (*query_qp)(struct ib_qp___2 *, struct ib_qp_attr___2 *, int, struct ib_qp_init_attr___2 *);
	int (*destroy_qp)(struct ib_qp___2 *);
	struct ib_cq___2 * (*create_cq)(struct ib_device___2 *, const struct ib_cq_init_attr *, struct ib_ucontext___2 *, struct ib_udata *);
	int (*modify_cq)(struct ib_cq___2 *, u16, u16);
	int (*destroy_cq)(struct ib_cq___2 *);
	int (*resize_cq)(struct ib_cq___2 *, int, struct ib_udata *);
	struct ib_mr___2 * (*get_dma_mr)(struct ib_pd___2 *, int);
	struct ib_mr___2 * (*reg_user_mr)(struct ib_pd___2 *, u64, u64, u64, int, struct ib_udata *);
	int (*rereg_user_mr)(struct ib_mr___2 *, int, u64, u64, u64, int, struct ib_pd___2 *, struct ib_udata *);
	int (*dereg_mr)(struct ib_mr___2 *);
	struct ib_mr___2 * (*alloc_mr)(struct ib_pd___2 *, enum ib_mr_type, u32);
	int (*advise_mr)(struct ib_pd___2 *, enum ib_uverbs_advise_mr_advice, u32, struct ib_sge *, u32, struct uverbs_attr_bundle *);
	int (*map_mr_sg)(struct ib_mr___2 *, struct scatterlist *, int, unsigned int *);
	int (*check_mr_status)(struct ib_mr___2 *, u32, struct ib_mr_status *);
	struct ib_mw___2 * (*alloc_mw)(struct ib_pd___2 *, enum ib_mw_type, struct ib_udata *);
	int (*dealloc_mw)(struct ib_mw___2 *);
	struct ib_fmr___2 * (*alloc_fmr)(struct ib_pd___2 *, int, struct ib_fmr_attr *);
	int (*map_phys_fmr)(struct ib_fmr___2 *, u64 *, int, u64);
	int (*unmap_fmr)(struct list_head *);
	int (*dealloc_fmr)(struct ib_fmr___2 *);
	int (*attach_mcast)(struct ib_qp___2 *, union ib_gid *, u16);
	int (*detach_mcast)(struct ib_qp___2 *, union ib_gid *, u16);
	struct ib_xrcd___2 * (*alloc_xrcd)(struct ib_device___2 *, struct ib_ucontext___2 *, struct ib_udata *);
	int (*dealloc_xrcd)(struct ib_xrcd___2 *);
	struct ib_flow___2 * (*create_flow)(struct ib_qp___2 *, struct ib_flow_attr___2 *, int, struct ib_udata *);
	int (*destroy_flow)(struct ib_flow___2 *);
	struct ib_flow_action___2 * (*create_flow_action_esp)(struct ib_device___2 *, const struct ib_flow_action_attrs_esp___2 *, struct uverbs_attr_bundle *);
	int (*destroy_flow_action)(struct ib_flow_action___2 *);
	int (*modify_flow_action_esp)(struct ib_flow_action___2 *, const struct ib_flow_action_attrs_esp___2 *, struct uverbs_attr_bundle *);
	int (*set_vf_link_state)(struct ib_device___2 *, int, u8, int);
	int (*get_vf_config)(struct ib_device___2 *, int, u8, struct ifla_vf_info *);
	int (*get_vf_stats)(struct ib_device___2 *, int, u8, struct ifla_vf_stats *);
	int (*set_vf_guid)(struct ib_device___2 *, int, u8, u64, int);
	struct ib_wq___2 * (*create_wq)(struct ib_pd___2 *, struct ib_wq_init_attr___2 *, struct ib_udata *);
	int (*destroy_wq)(struct ib_wq___2 *);
	int (*modify_wq)(struct ib_wq___2 *, struct ib_wq_attr *, u32, struct ib_udata *);
	struct ib_rwq_ind_table___2 * (*create_rwq_ind_table)(struct ib_device___2 *, struct ib_rwq_ind_table_init_attr___2 *, struct ib_udata *);
	int (*destroy_rwq_ind_table)(struct ib_rwq_ind_table___2 *);
	struct ib_dm___2 * (*alloc_dm)(struct ib_device___2 *, struct ib_ucontext___2 *, struct ib_dm_alloc_attr *, struct uverbs_attr_bundle *);
	int (*dealloc_dm)(struct ib_dm___2 *);
	struct ib_mr___2 * (*reg_dm_mr)(struct ib_pd___2 *, struct ib_dm___2 *, struct ib_dm_mr_attr *, struct uverbs_attr_bundle *);
	struct ib_counters___2 * (*create_counters)(struct ib_device___2 *, struct uverbs_attr_bundle *);
	int (*destroy_counters)(struct ib_counters___2 *);
	int (*read_counters)(struct ib_counters___2 *, struct ib_counters_read_attr *, struct uverbs_attr_bundle *);
	struct rdma_hw_stats * (*alloc_hw_stats)(struct ib_device___2 *, u8);
	int (*get_hw_stats)(struct ib_device___2 *, struct rdma_hw_stats *, u8, int);
};

struct ib_event___2;

struct ib_event_handler___2 {
	struct ib_device___2 *device;
	void (*handler)(struct ib_event_handler___2 *, struct ib_event___2 *);
	struct list_head list;
};

struct ib_cache___2 {
	rwlock_t lock;
	struct ib_event_handler___2 event_handler;
	struct ib_port_cache *ports;
};

struct ib_device___2 {
	struct device___392 *dma_device;
	struct ib_device_ops___2 ops;
	char name[64];
	struct list_head event_handler_list;
	spinlock_t event_handler_lock;
	rwlock_t client_data_lock;
	struct list_head core_list;
	struct list_head client_data_list;
	struct ib_cache___2 cache;
	struct ib_port_immutable *port_immutable;
	int num_comp_vectors;
	struct ib_port_pkey_list *port_pkey_list;
	struct iw_cm_verbs *iwcm;
	struct module___354 *owner;
	struct device___392 dev;
	const struct attribute_group___389 *groups[3];
	struct kobject___412 *ports_kobj;
	struct list_head port_list;
	enum {
		IB_DEV_UNINITIALIZED___2 = 0,
		IB_DEV_REGISTERED___2 = 1,
		IB_DEV_UNREGISTERED___2 = 2,
	} reg_state;
	int uverbs_abi_ver;
	u64 uverbs_cmd_mask;
	u64 uverbs_ex_cmd_mask;
	char node_desc[64];
	__be64 node_guid;
	u32 local_dma_lkey;
	u16 is_switch: 1;
	u8 node_type;
	u8 phys_port_cnt;
	struct ib_device_attr attrs;
	struct attribute_group___389 *hw_stats_ag;
	struct rdma_hw_stats *hw_stats;
	struct rdmacg_device cg_device;
	u32 index;
	struct rdma_restrack_root___2 res;
	const struct uapi_definition *driver_def;
	enum rdma_driver_id driver_id;
	refcount_t refcount;
	struct completion unreg_completion;
};

typedef void (*ib_comp_handler___2)(struct ib_cq___2 *, void *);

struct ib_uobject___2;

struct ib_cq___2 {
	struct ib_device___2 *device;
	struct ib_uobject___2 *uobject;
	ib_comp_handler___2 comp_handler;
	void (*event_handler)(struct ib_event___2 *, void *);
	void *cq_context;
	int cqe;
	atomic_t usecnt;
	enum ib_poll_context poll_ctx;
	struct ib_wc___2 *wc;
	union {
		struct irq_poll iop;
		struct work_struct work;
	};
	struct workqueue_struct *comp_wq;
	struct rdma_restrack_entry___2 res;
};

struct ib_qp_security___2;

struct ib_qp___2 {
	struct ib_device___2 *device;
	struct ib_pd___2 *pd;
	struct ib_cq___2 *send_cq;
	struct ib_cq___2 *recv_cq;
	spinlock_t mr_lock;
	int mrs_used;
	struct list_head rdma_mrs;
	struct list_head sig_mrs;
	struct ib_srq___2 *srq;
	struct ib_xrcd___2 *xrcd;
	struct list_head xrcd_list;
	atomic_t usecnt;
	struct list_head open_list;
	struct ib_qp___2 *real_qp;
	struct ib_uobject___2 *uobject;
	void (*event_handler)(struct ib_event___2 *, void *);
	void *qp_context;
	const struct ib_gid_attr___2 *av_sgid_attr;
	const struct ib_gid_attr___2 *alt_path_sgid_attr;
	u32 qp_num;
	u32 max_write_sge;
	u32 max_read_sge;
	enum ib_qp_type qp_type;
	struct ib_rwq_ind_table___2 *rwq_ind_tbl;
	struct ib_qp_security___2 *qp_sec;
	u8 port;
	struct rdma_restrack_entry___2 res;
};

struct ib_srq___2 {
	struct ib_device___2 *device;
	struct ib_pd___2 *pd;
	struct ib_uobject___2 *uobject;
	void (*event_handler)(struct ib_event___2 *, void *);
	void *srq_context;
	enum ib_srq_type srq_type;
	atomic_t usecnt;
	struct {
		struct ib_cq___2 *cq;
		union {
			struct {
				struct ib_xrcd___2 *xrcd;
				u32 srq_num;
			} xrc;
		};
	} ext;
};

struct ib_wq___2 {
	struct ib_device___2 *device;
	struct ib_uobject___2 *uobject;
	void *wq_context;
	void (*event_handler)(struct ib_event___2 *, void *);
	struct ib_pd___2 *pd;
	struct ib_cq___2 *cq;
	u32 wq_num;
	enum ib_wq_state state;
	enum ib_wq_type wq_type;
	atomic_t usecnt;
};

struct ib_event___2 {
	struct ib_device___2 *device;
	union {
		struct ib_cq___2 *cq;
		struct ib_qp___2 *qp;
		struct ib_srq___2 *srq;
		struct ib_wq___2 *wq;
		u8 port_num;
	} element;
	enum ib_event_type event;
};

struct ib_global_route___2 {
	const struct ib_gid_attr___2 *sgid_attr;
	union ib_gid dgid;
	u32 flow_label;
	u8 sgid_index;
	u8 hop_limit;
	u8 traffic_class;
};

struct rdma_ah_attr___2 {
	struct ib_global_route___2 grh;
	u8 sl;
	u8 static_rate;
	u8 port_num;
	u8 ah_flags;
	enum rdma_ah_attr_type type;
	union {
		struct ib_ah_attr ib;
		struct roce_ah_attr roce;
		struct opa_ah_attr opa;
	};
};

struct ib_cqe___2 {
	void (*done)(struct ib_cq___2 *, struct ib_wc___2 *);
};

struct ib_wc___2 {
	union {
		u64 wr_id;
		struct ib_cqe___2 *wr_cqe;
	};
	enum ib_wc_status status;
	enum ib_wc_opcode opcode;
	u32 vendor_err;
	u32 byte_len;
	struct ib_qp___2 *qp;
	union {
		__be32 imm_data;
		u32 invalidate_rkey;
	} ex;
	u32 src_qp;
	u32 slid;
	int wc_flags;
	u16 pkey_index;
	u8 sl;
	u8 dlid_path_bits;
	u8 port_num;
	u8 smac[6];
	u16 vlan_id;
	u8 network_hdr_type;
};

struct ib_xrcd___2 {
	struct ib_device___2 *device;
	atomic_t usecnt;
	struct inode___424 *inode;
	struct mutex tgt_qp_mutex;
	struct list_head tgt_qp_list;
};

struct ib_srq_init_attr___2 {
	void (*event_handler)(struct ib_event___2 *, void *);
	void *srq_context;
	struct ib_srq_attr attr;
	enum ib_srq_type srq_type;
	struct {
		struct ib_cq___2 *cq;
		union {
			struct {
				struct ib_xrcd___2 *xrcd;
			} xrc;
			struct {
				u32 max_num_tags;
			} tag_matching;
		};
	} ext;
};

struct ib_qp_init_attr___2 {
	void (*event_handler)(struct ib_event___2 *, void *);
	void *qp_context;
	struct ib_cq___2 *send_cq;
	struct ib_cq___2 *recv_cq;
	struct ib_srq___2 *srq;
	struct ib_xrcd___2 *xrcd;
	struct ib_qp_cap cap;
	enum ib_sig_type sq_sig_type;
	enum ib_qp_type qp_type;
	u32 create_flags;
	u8 port_num;
	struct ib_rwq_ind_table___2 *rwq_ind_tbl;
	u32 source_qpn;
};

struct ib_rwq_ind_table___2 {
	struct ib_device___2 *device;
	struct ib_uobject___2 *uobject;
	atomic_t usecnt;
	u32 ind_tbl_num;
	u32 log_ind_tbl_size;
	struct ib_wq___2 **ind_tbl;
};

struct ib_qp_attr___2 {
	enum ib_qp_state qp_state;
	enum ib_qp_state cur_qp_state;
	enum ib_mtu path_mtu;
	enum ib_mig_state path_mig_state;
	u32 qkey;
	u32 rq_psn;
	u32 sq_psn;
	u32 dest_qp_num;
	int qp_access_flags;
	struct ib_qp_cap cap;
	struct rdma_ah_attr___2 ah_attr;
	struct rdma_ah_attr___2 alt_ah_attr;
	u16 pkey_index;
	u16 alt_pkey_index;
	u8 en_sqd_async_notify;
	u8 sq_draining;
	u8 max_rd_atomic;
	u8 max_dest_rd_atomic;
	u8 min_rnr_timer;
	u8 port_num;
	u8 timeout;
	u8 retry_cnt;
	u8 rnr_retry;
	u8 alt_port_num;
	u8 alt_timeout;
	u32 rate_limit;
};

struct ib_send_wr___2 {
	struct ib_send_wr___2 *next;
	union {
		u64 wr_id;
		struct ib_cqe___2 *wr_cqe;
	};
	struct ib_sge *sg_list;
	int num_sge;
	enum ib_wr_opcode opcode;
	int send_flags;
	union {
		__be32 imm_data;
		u32 invalidate_rkey;
	} ex;
};

struct ib_ah___2 {
	struct ib_device___2 *device;
	struct ib_pd___2 *pd;
	struct ib_uobject___2 *uobject;
	const struct ib_gid_attr___2 *sgid_attr;
	enum rdma_ah_attr_type type;
};

struct ib_mr___2 {
	struct ib_device___2 *device;
	struct ib_pd___2 *pd;
	u32 lkey;
	u32 rkey;
	u64 iova;
	u64 length;
	unsigned int page_size;
	bool need_inval;
	union {
		struct ib_uobject___2 *uobject;
		struct list_head qp_entry;
	};
	struct ib_dm___2 *dm;
	struct rdma_restrack_entry___2 res;
};

struct ib_recv_wr___2 {
	struct ib_recv_wr___2 *next;
	union {
		u64 wr_id;
		struct ib_cqe___2 *wr_cqe;
	};
	struct ib_sge *sg_list;
	int num_sge;
};

struct ib_rdmacg_object___2 {
	struct rdma_cgroup___3 *cg;
};

struct ib_ucontext___2 {
	struct ib_device___2 *device;
	struct ib_uverbs_file *ufile;
	bool closing;
	bool cleanup_retryable;
	void (*invalidate_range)(struct ib_umem_odp *, long unsigned int, long unsigned int);
	struct mutex per_mm_list_lock;
	struct list_head per_mm_list;
	struct ib_rdmacg_object___2 cg_obj;
	struct rdma_restrack_entry___2 res;
};

struct ib_uobject___2 {
	u64 user_handle;
	struct ib_uverbs_file *ufile;
	struct ib_ucontext___2 *context;
	void *object;
	struct list_head list;
	struct ib_rdmacg_object___2 cg_obj;
	int id;
	struct kref ref;
	atomic_t usecnt;
	struct callback_head rcu;
	const struct uverbs_api_object *uapi_object;
};

struct ib_pd___2 {
	u32 local_dma_lkey;
	u32 flags;
	struct ib_device___2 *device;
	struct ib_uobject___2 *uobject;
	atomic_t usecnt;
	u32 unsafe_global_rkey;
	struct ib_mr___2 *__internal_mr;
	struct rdma_restrack_entry___2 res;
};

struct ib_wq_init_attr___2 {
	void *wq_context;
	enum ib_wq_type wq_type;
	u32 max_wr;
	u32 max_sge;
	struct ib_cq___2 *cq;
	void (*event_handler)(struct ib_event___2 *, void *);
	u32 create_flags;
};

struct ib_rwq_ind_table_init_attr___2 {
	u32 log_ind_tbl_size;
	struct ib_wq___2 **ind_tbl;
};

struct ib_port_pkey___2 {
	enum port_pkey_state state;
	u16 pkey_index;
	u8 port_num;
	struct list_head qp_list;
	struct list_head to_error_list;
	struct ib_qp_security___2 *sec;
};

struct ib_ports_pkeys___2;

struct ib_qp_security___2 {
	struct ib_qp___2 *qp;
	struct ib_device___2 *dev;
	struct mutex mutex;
	struct ib_ports_pkeys___2 *ports_pkeys;
	struct list_head shared_qp_list;
	void *security;
	bool destroying;
	atomic_t error_list_count;
	struct completion error_complete;
	int error_comps_pending;
};

struct ib_ports_pkeys___2 {
	struct ib_port_pkey___2 main;
	struct ib_port_pkey___2 alt;
};

struct ib_dm___2 {
	struct ib_device___2 *device;
	u32 length;
	u32 flags;
	struct ib_uobject___2 *uobject;
	atomic_t usecnt;
};

struct ib_mw___2 {
	struct ib_device___2 *device;
	struct ib_pd___2 *pd;
	struct ib_uobject___2 *uobject;
	u32 rkey;
	enum ib_mw_type type;
};

struct ib_fmr___2 {
	struct ib_device___2 *device;
	struct ib_pd___2 *pd;
	struct list_head list;
	u32 lkey;
	u32 rkey;
};

struct ib_flow_spec_action_handle___2 {
	enum ib_flow_spec_type type;
	u16 size;
	struct ib_flow_action___2 *act;
};

struct ib_flow_action___2 {
	struct ib_device___2 *device;
	struct ib_uobject___2 *uobject;
	enum ib_flow_action_type type;
	atomic_t usecnt;
};

struct ib_flow_spec_action_count___2 {
	enum ib_flow_spec_type type;
	u16 size;
	struct ib_counters___2 *counters;
};

struct ib_counters___2 {
	struct ib_device___2 *device;
	struct ib_uobject___2 *uobject;
	atomic_t usecnt;
};

union ib_flow_spec___2 {
	struct {
		u32 type;
		u16 size;
	};
	struct ib_flow_spec_eth eth;
	struct ib_flow_spec_ib ib;
	struct ib_flow_spec_ipv4 ipv4;
	struct ib_flow_spec_tcp_udp tcp_udp;
	struct ib_flow_spec_ipv6 ipv6;
	struct ib_flow_spec_tunnel tunnel;
	struct ib_flow_spec_esp esp;
	struct ib_flow_spec_gre gre;
	struct ib_flow_spec_mpls mpls;
	struct ib_flow_spec_action_tag flow_tag;
	struct ib_flow_spec_action_drop drop;
	struct ib_flow_spec_action_handle___2 action;
	struct ib_flow_spec_action_count___2 flow_count;
};

struct ib_flow_attr___2 {
	enum ib_flow_attr_type type;
	u16 size;
	u16 priority;
	u32 flags;
	u8 num_of_specs;
	u8 port;
	union ib_flow_spec___2 flows[0];
};

struct ib_flow___2 {
	struct ib_qp___2 *qp;
	struct ib_device___2 *device;
	struct ib_uobject___2 *uobject;
};

struct ib_flow_spec_list___2 {
	struct ib_flow_spec_list___2 *next;
	union ib_flow_spec___2 spec;
};

struct ib_flow_action_attrs_esp___2 {
	struct ib_flow_action_attrs_esp_keymats *keymat;
	struct ib_flow_action_attrs_esp_replays *replay;
	struct ib_flow_spec_list___2 *encap;
	u32 esn;
	u32 spi;
	u32 seq;
	u32 tfc_pad;
	u64 flags;
	u64 hard_limit_pkts;
};

struct rdma_netdev_alloc_params___2 {
	size_t sizeof_priv;
	unsigned int txqs;
	unsigned int rxqs;
	void *param;
	int (*initialize_rdma_netdev)(struct ib_device___2 *, u8, struct net_device___70 *, void *);
};

struct genl_ops___5;

struct genl_info___4;

struct genl_family___5 {
	int id;
	unsigned int hdrsize;
	char name[16];
	unsigned int version;
	unsigned int maxattr;
	bool netnsok;
	bool parallel_ops;
	int (*pre_doit)(const struct genl_ops___5 *, struct sk_buff___71 *, struct genl_info___4 *);
	void (*post_doit)(const struct genl_ops___5 *, struct sk_buff___71 *, struct genl_info___4 *);
	int (*mcast_bind)(struct net___81 *, int);
	void (*mcast_unbind)(struct net___81 *, int);
	struct nlattr **attrbuf;
	const struct genl_ops___5 *ops;
	const struct genl_multicast_group *mcgrps;
	unsigned int n_ops;
	unsigned int n_mcgrps;
	unsigned int mcgrp_offset;
	struct module___354 *module;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct genl_ops___5 {
	const struct nla_policy *policy;
	int (*doit)(struct sk_buff___71 *, struct genl_info___4 *);
	int (*start)(struct netlink_callback___71 *);
	int (*dumpit)(struct sk_buff___71 *, struct netlink_callback___71 *);
	int (*done)(struct netlink_callback___71 *);
	u8 cmd;
	u8 internal_flags;
	u8 flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t genl_ops_extended_size_rh;
	struct genl_ops_extended_rh genl_ops_extended_rh;
};

struct genl_info___4 {
	u32 snd_seq;
	u32 snd_portid;
	struct nlmsghdr *nlhdr;
	struct genlmsghdr *genlhdr;
	void *userhdr;
	struct nlattr **attrs;
	possible_net_t___71 _net;
	void *user_ptr[2];
	struct netlink_ext_ack *extack;
};

enum devlink_command {
	DEVLINK_CMD_UNSPEC = 0,
	DEVLINK_CMD_GET = 1,
	DEVLINK_CMD_SET = 2,
	DEVLINK_CMD_NEW = 3,
	DEVLINK_CMD_DEL = 4,
	DEVLINK_CMD_PORT_GET = 5,
	DEVLINK_CMD_PORT_SET = 6,
	DEVLINK_CMD_PORT_NEW = 7,
	DEVLINK_CMD_PORT_DEL = 8,
	DEVLINK_CMD_PORT_SPLIT = 9,
	DEVLINK_CMD_PORT_UNSPLIT = 10,
	DEVLINK_CMD_SB_GET = 11,
	DEVLINK_CMD_SB_SET = 12,
	DEVLINK_CMD_SB_NEW = 13,
	DEVLINK_CMD_SB_DEL = 14,
	DEVLINK_CMD_SB_POOL_GET = 15,
	DEVLINK_CMD_SB_POOL_SET = 16,
	DEVLINK_CMD_SB_POOL_NEW = 17,
	DEVLINK_CMD_SB_POOL_DEL = 18,
	DEVLINK_CMD_SB_PORT_POOL_GET = 19,
	DEVLINK_CMD_SB_PORT_POOL_SET = 20,
	DEVLINK_CMD_SB_PORT_POOL_NEW = 21,
	DEVLINK_CMD_SB_PORT_POOL_DEL = 22,
	DEVLINK_CMD_SB_TC_POOL_BIND_GET = 23,
	DEVLINK_CMD_SB_TC_POOL_BIND_SET = 24,
	DEVLINK_CMD_SB_TC_POOL_BIND_NEW = 25,
	DEVLINK_CMD_SB_TC_POOL_BIND_DEL = 26,
	DEVLINK_CMD_SB_OCC_SNAPSHOT = 27,
	DEVLINK_CMD_SB_OCC_MAX_CLEAR = 28,
	DEVLINK_CMD_ESWITCH_GET = 29,
	DEVLINK_CMD_ESWITCH_SET = 30,
	DEVLINK_CMD_DPIPE_TABLE_GET = 31,
	DEVLINK_CMD_DPIPE_ENTRIES_GET = 32,
	DEVLINK_CMD_DPIPE_HEADERS_GET = 33,
	DEVLINK_CMD_DPIPE_TABLE_COUNTERS_SET = 34,
	DEVLINK_CMD_RESOURCE_SET = 35,
	DEVLINK_CMD_RESOURCE_DUMP = 36,
	DEVLINK_CMD_RELOAD = 37,
	DEVLINK_CMD_PARAM_GET = 38,
	DEVLINK_CMD_PARAM_SET = 39,
	DEVLINK_CMD_PARAM_NEW = 40,
	DEVLINK_CMD_PARAM_DEL = 41,
	DEVLINK_CMD_REGION_GET = 42,
	DEVLINK_CMD_REGION_SET = 43,
	DEVLINK_CMD_REGION_NEW = 44,
	DEVLINK_CMD_REGION_DEL = 45,
	DEVLINK_CMD_REGION_READ = 46,
	DEVLINK_CMD_PORT_PARAM_GET = 47,
	DEVLINK_CMD_PORT_PARAM_SET = 48,
	DEVLINK_CMD_PORT_PARAM_NEW = 49,
	DEVLINK_CMD_PORT_PARAM_DEL = 50,
	DEVLINK_CMD_INFO_GET = 51,
	DEVLINK_CMD_HEALTH_REPORTER_GET = 52,
	DEVLINK_CMD_HEALTH_REPORTER_SET = 53,
	DEVLINK_CMD_HEALTH_REPORTER_RECOVER = 54,
	DEVLINK_CMD_HEALTH_REPORTER_DIAGNOSE = 55,
	DEVLINK_CMD_HEALTH_REPORTER_DUMP_GET = 56,
	DEVLINK_CMD_HEALTH_REPORTER_DUMP_CLEAR = 57,
	DEVLINK_CMD_FLASH_UPDATE = 58,
	__DEVLINK_CMD_MAX = 59,
	DEVLINK_CMD_MAX = 58,
};

enum devlink_port_type {
	DEVLINK_PORT_TYPE_NOTSET = 0,
	DEVLINK_PORT_TYPE_AUTO = 1,
	DEVLINK_PORT_TYPE_ETH = 2,
	DEVLINK_PORT_TYPE_IB = 3,
};

enum devlink_sb_pool_type {
	DEVLINK_SB_POOL_TYPE_INGRESS = 0,
	DEVLINK_SB_POOL_TYPE_EGRESS = 1,
};

enum devlink_sb_threshold_type {
	DEVLINK_SB_THRESHOLD_TYPE_STATIC = 0,
	DEVLINK_SB_THRESHOLD_TYPE_DYNAMIC = 1,
};

enum devlink_port_flavour {
	DEVLINK_PORT_FLAVOUR_PHYSICAL = 0,
	DEVLINK_PORT_FLAVOUR_CPU = 1,
	DEVLINK_PORT_FLAVOUR_DSA = 2,
};

enum devlink_param_cmode {
	DEVLINK_PARAM_CMODE_RUNTIME = 0,
	DEVLINK_PARAM_CMODE_DRIVERINIT = 1,
	DEVLINK_PARAM_CMODE_PERMANENT = 2,
	__DEVLINK_PARAM_CMODE_MAX = 3,
	DEVLINK_PARAM_CMODE_MAX = 2,
};

enum devlink_attr {
	DEVLINK_ATTR_UNSPEC = 0,
	DEVLINK_ATTR_BUS_NAME = 1,
	DEVLINK_ATTR_DEV_NAME = 2,
	DEVLINK_ATTR_PORT_INDEX = 3,
	DEVLINK_ATTR_PORT_TYPE = 4,
	DEVLINK_ATTR_PORT_DESIRED_TYPE = 5,
	DEVLINK_ATTR_PORT_NETDEV_IFINDEX = 6,
	DEVLINK_ATTR_PORT_NETDEV_NAME = 7,
	DEVLINK_ATTR_PORT_IBDEV_NAME = 8,
	DEVLINK_ATTR_PORT_SPLIT_COUNT = 9,
	DEVLINK_ATTR_PORT_SPLIT_GROUP = 10,
	DEVLINK_ATTR_SB_INDEX = 11,
	DEVLINK_ATTR_SB_SIZE = 12,
	DEVLINK_ATTR_SB_INGRESS_POOL_COUNT = 13,
	DEVLINK_ATTR_SB_EGRESS_POOL_COUNT = 14,
	DEVLINK_ATTR_SB_INGRESS_TC_COUNT = 15,
	DEVLINK_ATTR_SB_EGRESS_TC_COUNT = 16,
	DEVLINK_ATTR_SB_POOL_INDEX = 17,
	DEVLINK_ATTR_SB_POOL_TYPE = 18,
	DEVLINK_ATTR_SB_POOL_SIZE = 19,
	DEVLINK_ATTR_SB_POOL_THRESHOLD_TYPE = 20,
	DEVLINK_ATTR_SB_THRESHOLD = 21,
	DEVLINK_ATTR_SB_TC_INDEX = 22,
	DEVLINK_ATTR_SB_OCC_CUR = 23,
	DEVLINK_ATTR_SB_OCC_MAX = 24,
	DEVLINK_ATTR_ESWITCH_MODE = 25,
	DEVLINK_ATTR_ESWITCH_INLINE_MODE = 26,
	DEVLINK_ATTR_DPIPE_TABLES = 27,
	DEVLINK_ATTR_DPIPE_TABLE = 28,
	DEVLINK_ATTR_DPIPE_TABLE_NAME = 29,
	DEVLINK_ATTR_DPIPE_TABLE_SIZE = 30,
	DEVLINK_ATTR_DPIPE_TABLE_MATCHES = 31,
	DEVLINK_ATTR_DPIPE_TABLE_ACTIONS = 32,
	DEVLINK_ATTR_DPIPE_TABLE_COUNTERS_ENABLED = 33,
	DEVLINK_ATTR_DPIPE_ENTRIES = 34,
	DEVLINK_ATTR_DPIPE_ENTRY = 35,
	DEVLINK_ATTR_DPIPE_ENTRY_INDEX = 36,
	DEVLINK_ATTR_DPIPE_ENTRY_MATCH_VALUES = 37,
	DEVLINK_ATTR_DPIPE_ENTRY_ACTION_VALUES = 38,
	DEVLINK_ATTR_DPIPE_ENTRY_COUNTER = 39,
	DEVLINK_ATTR_DPIPE_MATCH = 40,
	DEVLINK_ATTR_DPIPE_MATCH_VALUE = 41,
	DEVLINK_ATTR_DPIPE_MATCH_TYPE = 42,
	DEVLINK_ATTR_DPIPE_ACTION = 43,
	DEVLINK_ATTR_DPIPE_ACTION_VALUE = 44,
	DEVLINK_ATTR_DPIPE_ACTION_TYPE = 45,
	DEVLINK_ATTR_DPIPE_VALUE = 46,
	DEVLINK_ATTR_DPIPE_VALUE_MASK = 47,
	DEVLINK_ATTR_DPIPE_VALUE_MAPPING = 48,
	DEVLINK_ATTR_DPIPE_HEADERS = 49,
	DEVLINK_ATTR_DPIPE_HEADER = 50,
	DEVLINK_ATTR_DPIPE_HEADER_NAME = 51,
	DEVLINK_ATTR_DPIPE_HEADER_ID = 52,
	DEVLINK_ATTR_DPIPE_HEADER_FIELDS = 53,
	DEVLINK_ATTR_DPIPE_HEADER_GLOBAL = 54,
	DEVLINK_ATTR_DPIPE_HEADER_INDEX = 55,
	DEVLINK_ATTR_DPIPE_FIELD = 56,
	DEVLINK_ATTR_DPIPE_FIELD_NAME = 57,
	DEVLINK_ATTR_DPIPE_FIELD_ID = 58,
	DEVLINK_ATTR_DPIPE_FIELD_BITWIDTH = 59,
	DEVLINK_ATTR_DPIPE_FIELD_MAPPING_TYPE = 60,
	DEVLINK_ATTR_PAD = 61,
	DEVLINK_ATTR_ESWITCH_ENCAP_MODE = 62,
	DEVLINK_ATTR_RESOURCE_LIST = 63,
	DEVLINK_ATTR_RESOURCE = 64,
	DEVLINK_ATTR_RESOURCE_NAME = 65,
	DEVLINK_ATTR_RESOURCE_ID = 66,
	DEVLINK_ATTR_RESOURCE_SIZE = 67,
	DEVLINK_ATTR_RESOURCE_SIZE_NEW = 68,
	DEVLINK_ATTR_RESOURCE_SIZE_VALID = 69,
	DEVLINK_ATTR_RESOURCE_SIZE_MIN = 70,
	DEVLINK_ATTR_RESOURCE_SIZE_MAX = 71,
	DEVLINK_ATTR_RESOURCE_SIZE_GRAN = 72,
	DEVLINK_ATTR_RESOURCE_UNIT = 73,
	DEVLINK_ATTR_RESOURCE_OCC = 74,
	DEVLINK_ATTR_DPIPE_TABLE_RESOURCE_ID = 75,
	DEVLINK_ATTR_DPIPE_TABLE_RESOURCE_UNITS = 76,
	DEVLINK_ATTR_PORT_FLAVOUR = 77,
	DEVLINK_ATTR_PORT_NUMBER = 78,
	DEVLINK_ATTR_PORT_SPLIT_SUBPORT_NUMBER = 79,
	DEVLINK_ATTR_PARAM = 80,
	DEVLINK_ATTR_PARAM_NAME = 81,
	DEVLINK_ATTR_PARAM_GENERIC = 82,
	DEVLINK_ATTR_PARAM_TYPE = 83,
	DEVLINK_ATTR_PARAM_VALUES_LIST = 84,
	DEVLINK_ATTR_PARAM_VALUE = 85,
	DEVLINK_ATTR_PARAM_VALUE_DATA = 86,
	DEVLINK_ATTR_PARAM_VALUE_CMODE = 87,
	DEVLINK_ATTR_REGION_NAME = 88,
	DEVLINK_ATTR_REGION_SIZE = 89,
	DEVLINK_ATTR_REGION_SNAPSHOTS = 90,
	DEVLINK_ATTR_REGION_SNAPSHOT = 91,
	DEVLINK_ATTR_REGION_SNAPSHOT_ID = 92,
	DEVLINK_ATTR_REGION_CHUNKS = 93,
	DEVLINK_ATTR_REGION_CHUNK = 94,
	DEVLINK_ATTR_REGION_CHUNK_DATA = 95,
	DEVLINK_ATTR_REGION_CHUNK_ADDR = 96,
	DEVLINK_ATTR_REGION_CHUNK_LEN = 97,
	DEVLINK_ATTR_INFO_DRIVER_NAME = 98,
	DEVLINK_ATTR_INFO_SERIAL_NUMBER = 99,
	DEVLINK_ATTR_INFO_VERSION_FIXED = 100,
	DEVLINK_ATTR_INFO_VERSION_RUNNING = 101,
	DEVLINK_ATTR_INFO_VERSION_STORED = 102,
	DEVLINK_ATTR_INFO_VERSION_NAME = 103,
	DEVLINK_ATTR_INFO_VERSION_VALUE = 104,
	DEVLINK_ATTR_SB_POOL_CELL_SIZE = 105,
	DEVLINK_ATTR_FMSG = 106,
	DEVLINK_ATTR_FMSG_OBJ_NEST_START = 107,
	DEVLINK_ATTR_FMSG_PAIR_NEST_START = 108,
	DEVLINK_ATTR_FMSG_ARR_NEST_START = 109,
	DEVLINK_ATTR_FMSG_NEST_END = 110,
	DEVLINK_ATTR_FMSG_OBJ_NAME = 111,
	DEVLINK_ATTR_FMSG_OBJ_VALUE_TYPE = 112,
	DEVLINK_ATTR_FMSG_OBJ_VALUE_DATA = 113,
	DEVLINK_ATTR_HEALTH_REPORTER = 114,
	DEVLINK_ATTR_HEALTH_REPORTER_NAME = 115,
	DEVLINK_ATTR_HEALTH_REPORTER_STATE = 116,
	DEVLINK_ATTR_HEALTH_REPORTER_ERR_COUNT = 117,
	DEVLINK_ATTR_HEALTH_REPORTER_RECOVER_COUNT = 118,
	DEVLINK_ATTR_HEALTH_REPORTER_DUMP_TS = 119,
	DEVLINK_ATTR_HEALTH_REPORTER_GRACEFUL_PERIOD = 120,
	DEVLINK_ATTR_HEALTH_REPORTER_AUTO_RECOVER = 121,
	DEVLINK_ATTR_FLASH_UPDATE_FILE_NAME = 122,
	DEVLINK_ATTR_FLASH_UPDATE_COMPONENT = 123,
	__DEVLINK_ATTR_MAX = 124,
	DEVLINK_ATTR_MAX = 123,
};

enum devlink_dpipe_match_type {
	DEVLINK_DPIPE_MATCH_TYPE_FIELD_EXACT = 0,
};

enum devlink_dpipe_action_type {
	DEVLINK_DPIPE_ACTION_TYPE_FIELD_MODIFY = 0,
};

enum devlink_dpipe_field_ethernet_id {
	DEVLINK_DPIPE_FIELD_ETHERNET_DST_MAC = 0,
};

enum devlink_dpipe_field_ipv4_id {
	DEVLINK_DPIPE_FIELD_IPV4_DST_IP = 0,
};

enum devlink_dpipe_field_ipv6_id {
	DEVLINK_DPIPE_FIELD_IPV6_DST_IP = 0,
};

enum devlink_dpipe_header_id {
	DEVLINK_DPIPE_HEADER_ETHERNET = 0,
	DEVLINK_DPIPE_HEADER_IPV4 = 1,
	DEVLINK_DPIPE_HEADER_IPV6 = 2,
};

enum devlink_resource_unit {
	DEVLINK_RESOURCE_UNIT_ENTRY = 0,
};

struct devlink_dpipe_headers;

struct devlink_ops;

struct devlink {
	struct list_head list;
	struct list_head port_list;
	struct list_head sb_list;
	struct list_head dpipe_table_list;
	struct list_head resource_list;
	struct list_head param_list;
	struct list_head region_list;
	u32 snapshot_id;
	struct list_head reporter_list;
	struct devlink_dpipe_headers *dpipe_headers;
	const struct devlink_ops *ops;
	struct device___392 *dev;
	possible_net_t___71 _net;
	struct mutex lock;
	long: 64;
	long: 64;
	long: 64;
	char priv[0];
};

struct devlink_dpipe_headers {
	struct devlink_dpipe_header **headers;
	unsigned int headers_count;
};

struct devlink_port;

struct devlink_sb_pool_info;

struct devlink_info_req;

struct devlink_ops {
	int (*reload)(struct devlink *, struct netlink_ext_ack *);
	int (*port_type_set)(struct devlink_port *, enum devlink_port_type);
	int (*port_split)(struct devlink *, unsigned int, unsigned int, struct netlink_ext_ack *);
	int (*port_unsplit)(struct devlink *, unsigned int, struct netlink_ext_ack *);
	int (*sb_pool_get)(struct devlink *, unsigned int, u16, struct devlink_sb_pool_info *);
	int (*sb_pool_set)(struct devlink *, unsigned int, u16, u32, enum devlink_sb_threshold_type);
	int (*sb_port_pool_get)(struct devlink_port *, unsigned int, u16, u32 *);
	int (*sb_port_pool_set)(struct devlink_port *, unsigned int, u16, u32);
	int (*sb_tc_pool_bind_get)(struct devlink_port *, unsigned int, u16, enum devlink_sb_pool_type, u16 *, u32 *);
	int (*sb_tc_pool_bind_set)(struct devlink_port *, unsigned int, u16, enum devlink_sb_pool_type, u16, u32);
	int (*sb_occ_snapshot)(struct devlink *, unsigned int);
	int (*sb_occ_max_clear)(struct devlink *, unsigned int);
	int (*sb_occ_port_pool_get)(struct devlink_port *, unsigned int, u16, u32 *, u32 *);
	int (*sb_occ_tc_port_bind_get)(struct devlink_port *, unsigned int, u16, enum devlink_sb_pool_type, u32 *, u32 *);
	int (*eswitch_mode_get)(struct devlink *, u16 *);
	int (*eswitch_mode_set)(struct devlink *, u16, struct netlink_ext_ack *);
	int (*eswitch_inline_mode_get)(struct devlink *, u8 *);
	int (*eswitch_inline_mode_set)(struct devlink *, u8, struct netlink_ext_ack *);
	int (*eswitch_encap_mode_get)(struct devlink *, u8 *);
	int (*eswitch_encap_mode_set)(struct devlink *, u8, struct netlink_ext_ack *);
	int (*info_get)(struct devlink *, struct devlink_info_req *, struct netlink_ext_ack *);
	int (*flash_update)(struct devlink *, const char *, const char *, struct netlink_ext_ack *);
};

struct devlink_port_attrs {
	bool set;
	enum devlink_port_flavour flavour;
	u32 port_number;
	bool split;
	u32 split_subport_number;
};

struct devlink_port {
	struct list_head list;
	struct list_head param_list;
	struct devlink *devlink;
	unsigned int index;
	bool registered;
	enum devlink_port_type type;
	enum devlink_port_type desired_type;
	void *type_dev;
	struct devlink_port_attrs attrs;
};

struct devlink_sb_pool_info {
	enum devlink_sb_pool_type pool_type;
	u32 size;
	enum devlink_sb_threshold_type threshold_type;
	u32 cell_size;
};

struct devlink_dpipe_match {
	enum devlink_dpipe_match_type type;
	unsigned int header_index;
	struct devlink_dpipe_header *header;
	unsigned int field_id;
};

struct devlink_dpipe_action {
	enum devlink_dpipe_action_type type;
	unsigned int header_index;
	struct devlink_dpipe_header *header;
	unsigned int field_id;
};

struct devlink_dpipe_value {
	union {
		struct devlink_dpipe_action *action;
		struct devlink_dpipe_match *match;
	};
	unsigned int mapping_value;
	bool mapping_valid;
	unsigned int value_size;
	void *value;
	void *mask;
};

struct devlink_dpipe_entry {
	u64 index;
	struct devlink_dpipe_value *match_values;
	unsigned int match_values_count;
	struct devlink_dpipe_value *action_values;
	unsigned int action_values_count;
	u64 counter;
	bool counter_valid;
};

struct devlink_dpipe_dump_ctx {
	struct genl_info___4 *info;
	enum devlink_command cmd;
	struct sk_buff___71 *skb;
	struct nlattr *nest;
	void *hdr;
};

struct devlink_dpipe_table_ops;

struct devlink_dpipe_table {
	void *priv;
	struct list_head list;
	const char *name;
	bool counters_enabled;
	bool counter_control_extern;
	bool resource_valid;
	u64 resource_id;
	u64 resource_units;
	struct devlink_dpipe_table_ops *table_ops;
	struct callback_head rcu;
};

struct devlink_dpipe_table_ops {
	int (*actions_dump)(void *, struct sk_buff___71 *);
	int (*matches_dump)(void *, struct sk_buff___71 *);
	int (*entries_dump)(void *, bool, struct devlink_dpipe_dump_ctx *);
	int (*counters_set_update)(void *, bool);
	u64 (*size_get)(void *);
};

struct devlink_resource_size_params {
	u64 size_min;
	u64 size_max;
	u64 size_granularity;
	enum devlink_resource_unit unit;
};

typedef u64 devlink_resource_occ_get_t(void *);

struct devlink_resource {
	const char *name;
	u64 id;
	u64 size;
	u64 size_new;
	bool size_valid;
	struct devlink_resource *parent;
	struct devlink_resource_size_params size_params;
	struct list_head list;
	struct list_head resource_list;
	devlink_resource_occ_get_t *occ_get;
	void *occ_get_priv;
};

enum devlink_param_type {
	DEVLINK_PARAM_TYPE_U8 = 0,
	DEVLINK_PARAM_TYPE_U16 = 1,
	DEVLINK_PARAM_TYPE_U32 = 2,
	DEVLINK_PARAM_TYPE_STRING = 3,
	DEVLINK_PARAM_TYPE_BOOL = 4,
};

union devlink_param_value {
	u8 vu8;
	u16 vu16;
	u32 vu32;
	char vstr[32];
	bool vbool;
};

struct devlink_param_gset_ctx {
	union devlink_param_value val;
	enum devlink_param_cmode cmode;
};

struct devlink_param {
	u32 id;
	const char *name;
	bool generic;
	enum devlink_param_type type;
	long unsigned int supported_cmodes;
	int (*get)(struct devlink *, u32, struct devlink_param_gset_ctx *);
	int (*set)(struct devlink *, u32, struct devlink_param_gset_ctx *);
	int (*validate)(struct devlink *, u32, union devlink_param_value, struct netlink_ext_ack *);
};

struct devlink_param_item {
	struct list_head list;
	const struct devlink_param *param;
	union devlink_param_value driverinit_value;
	bool driverinit_value_valid;
	bool published;
};

enum devlink_param_generic_id {
	DEVLINK_PARAM_GENERIC_ID_INT_ERR_RESET = 0,
	DEVLINK_PARAM_GENERIC_ID_MAX_MACS = 1,
	DEVLINK_PARAM_GENERIC_ID_ENABLE_SRIOV = 2,
	DEVLINK_PARAM_GENERIC_ID_REGION_SNAPSHOT = 3,
	DEVLINK_PARAM_GENERIC_ID_IGNORE_ARI = 4,
	DEVLINK_PARAM_GENERIC_ID_MSIX_VEC_PER_PF_MAX = 5,
	DEVLINK_PARAM_GENERIC_ID_MSIX_VEC_PER_PF_MIN = 6,
	DEVLINK_PARAM_GENERIC_ID_FW_LOAD_POLICY = 7,
	__DEVLINK_PARAM_GENERIC_ID_MAX = 8,
	DEVLINK_PARAM_GENERIC_ID_MAX = 7,
};

typedef void devlink_snapshot_data_dest_t(const void *);

struct devlink_health_reporter;

struct devlink_fmsg;

struct devlink_health_reporter_ops {
	char *name;
	int (*recover)(struct devlink_health_reporter *, void *);
	int (*dump)(struct devlink_health_reporter *, struct devlink_fmsg *, void *);
	int (*diagnose)(struct devlink_health_reporter *, struct devlink_fmsg *);
};

struct devlink_health_reporter {
	struct list_head list;
	void *priv;
	const struct devlink_health_reporter_ops *ops;
	struct devlink *devlink;
	struct devlink_fmsg *dump_fmsg;
	struct mutex dump_lock;
	u64 graceful_period;
	bool auto_recover;
	u8 health_state;
	u64 dump_ts;
	u64 error_count;
	u64 recovery_count;
	u64 last_recovery_ts;
};

struct devlink_fmsg {
	struct list_head item_list;
};

struct devlink_info_req {
	struct sk_buff___71 *msg;
};

struct node___226 {
	struct device___392 dev;
};

struct perf_cpu_context___156;

struct pmu___156 {
	struct list_head entry;
	struct module___354 *module;
	struct device___392 *dev;
	const struct attribute_group___389 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___156 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___156 *);
	void (*pmu_disable)(struct pmu___156 *);
	int (*event_init)(struct perf_event___156 *);
	void (*event_mapped)(struct perf_event___156 *, struct mm_struct___425 *);
	void (*event_unmapped)(struct perf_event___156 *, struct mm_struct___425 *);
	int (*add)(struct perf_event___156 *, int);
	void (*del)(struct perf_event___156 *, int);
	void (*start)(struct perf_event___156 *, int);
	void (*stop)(struct perf_event___156 *, int);
	void (*read)(struct perf_event___156 *);
	void (*start_txn)(struct pmu___156 *, unsigned int);
	int (*commit_txn)(struct pmu___156 *);
	void (*cancel_txn)(struct pmu___156 *);
	int (*event_idx)(struct perf_event___156 *);
	void (*sched_task)(struct perf_event_context___156 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___156 *);
	int (*filter_match)(struct perf_event___156 *);
	int (*check_period)(struct perf_event___156 *, u64);
};

struct perf_cpu_context___156 {
	struct perf_event_context___156 ctx;
	struct perf_event_context___156 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___156 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___156 {
	struct cgroup_subsys_state___273 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___147 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___147 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___147 *);
	struct list_head * (*get_fields)(struct trace_event_call___147 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___147 *);
};

struct trace_event_file___63;

struct trace_event_buffer___55 {
	struct ring_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___63 *trace_file;
	void *entry;
	long unsigned int flags;
	int pc;
};

struct trace_event_file___63 {
	struct list_head list;
	struct trace_event_call___147 *event_call;
	struct event_filter *filter;
	struct dentry___424 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_devlink_hwmsg {
	struct trace_entry ent;
	u32 __data_loc_bus_name;
	u32 __data_loc_dev_name;
	u32 __data_loc_driver_name;
	bool incoming;
	long unsigned int type;
	u32 __data_loc_buf;
	size_t len;
	char __data[0];
};

struct trace_event_raw_devlink_hwerr {
	struct trace_entry ent;
	u32 __data_loc_bus_name;
	u32 __data_loc_dev_name;
	u32 __data_loc_driver_name;
	int err;
	u32 __data_loc_msg;
	char __data[0];
};

struct trace_event_raw_devlink_health_report {
	struct trace_entry ent;
	u32 __data_loc_bus_name;
	u32 __data_loc_dev_name;
	u32 __data_loc_driver_name;
	u32 __data_loc_reporter_name;
	u32 __data_loc_msg;
	char __data[0];
};

struct trace_event_raw_devlink_health_recover_aborted {
	struct trace_entry ent;
	u32 __data_loc_bus_name;
	u32 __data_loc_dev_name;
	u32 __data_loc_driver_name;
	u32 __data_loc_reporter_name;
	bool health_state;
	u64 time_since_last_recover;
	char __data[0];
};

struct trace_event_data_offsets_devlink_hwmsg {
	u32 bus_name;
	u32 dev_name;
	u32 driver_name;
	u32 buf;
};

struct trace_event_data_offsets_devlink_hwerr {
	u32 bus_name;
	u32 dev_name;
	u32 driver_name;
	u32 msg;
};

struct trace_event_data_offsets_devlink_health_report {
	u32 bus_name;
	u32 dev_name;
	u32 driver_name;
	u32 reporter_name;
	u32 msg;
};

struct trace_event_data_offsets_devlink_health_recover_aborted {
	u32 bus_name;
	u32 dev_name;
	u32 driver_name;
	u32 reporter_name;
};

struct devlink_sb {
	struct list_head list;
	unsigned int index;
	u32 size;
	u16 ingress_pools_count;
	u16 egress_pools_count;
	u16 ingress_tc_count;
	u16 egress_tc_count;
};

struct devlink_region {
	struct devlink *devlink;
	struct list_head list;
	const char *name;
	struct list_head snapshot_list;
	u32 max_snapshots;
	u32 cur_snapshots;
	u64 size;
};

struct devlink_snapshot {
	struct list_head list;
	struct devlink_region *region;
	devlink_snapshot_data_dest_t *data_destructor;
	u64 data_len;
	u8 *data;
	u32 id;
};

enum devlink_multicast_groups {
	DEVLINK_MCGRP_CONFIG = 0,
};

struct devlink_fmsg_item {
	struct list_head list;
	int attrtype;
	u8 nla_type;
	u16 len;
	int value[0];
};

enum devlink_health_reporter_state {
	DEVLINK_HEALTH_REPORTER_STATE_HEALTHY = 0,
	DEVLINK_HEALTH_REPORTER_STATE_ERROR = 1,
};

struct gro_cell;

struct gro_cells {
	struct gro_cell *cells;
};

struct gro_cell {
	struct sk_buff_head___66 napi_skbs;
	struct napi_struct___66 napi;
};

struct module___355;

struct file___425;

struct kiocb___425;

struct iov_iter___192;

struct poll_table_struct___266;

struct vm_area_struct___426;

struct inode___425;

struct file_lock___425;

struct page___426;

struct pipe_inode_info___106;

struct seq_file___364;

struct file_operations___425 {
	struct module___355 *owner;
	loff_t (*llseek)(struct file___425 *, loff_t, int);
	ssize_t (*read)(struct file___425 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___425 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___425 *, struct iov_iter___192 *);
	ssize_t (*write_iter)(struct kiocb___425 *, struct iov_iter___192 *);
	int (*iopoll)(struct kiocb___425 *, bool);
	int (*iterate)(struct file___425 *, struct dir_context *);
	int (*iterate_shared)(struct file___425 *, struct dir_context *);
	__poll_t (*poll)(struct file___425 *, struct poll_table_struct___266 *);
	long int (*unlocked_ioctl)(struct file___425 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___425 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___425 *, struct vm_area_struct___426 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___425 *, struct file___425 *);
	int (*flush)(struct file___425 *, fl_owner_t);
	int (*release)(struct inode___425 *, struct file___425 *);
	int (*fsync)(struct file___425 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___425 *, int);
	int (*lock)(struct file___425 *, int, struct file_lock___425 *);
	ssize_t (*sendpage)(struct file___425 *, struct page___426 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___425 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___425 *, int, struct file_lock___425 *);
	ssize_t (*splice_write)(struct pipe_inode_info___106 *, struct file___425 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___425 *, loff_t *, struct pipe_inode_info___106 *, size_t, unsigned int);
	int (*setlease)(struct file___425 *, long int, struct file_lock___425 **, void **);
	long int (*fallocate)(struct file___425 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___364 *, struct file___425 *);
	ssize_t (*copy_file_range)(struct file___425 *, loff_t, struct file___425 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___425 *, loff_t, struct file___425 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___425 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___426 {
	u64 seqnum;
	struct vm_area_struct___426 *vmas[4];
};

struct page_frag___426 {
	struct page___426 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___426;

struct mem_cgroup___160;

struct cred___393;

struct nsproxy___320;

struct signal_struct___300;

struct bio_list___217;

struct backing_dev_info___217;

struct css_set___274;

struct vm_struct___329;

struct task_struct___427 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___427 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___426 *mm;
	struct mm_struct___426 *active_mm;
	struct vmacache___426 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___427 *real_parent;
	struct task_struct___427 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___427 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___160 *active_memcg;
	long int rh_reserved2;
	struct pid___240 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___240 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___240 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___393 *ptracer_cred;
	const struct cred___393 *real_cred;
	const struct cred___393 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___320 *nsproxy;
	struct signal_struct___300 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___427 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___217 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___217 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___274 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___106 *splice_pipe;
	struct page_frag___426 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___160 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___427 *oom_reaper_list;
	struct vm_struct___329 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___156 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rw_semaphore___427 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___427 *owner;
};

struct key___393;

struct ucounts___290;

struct user_namespace___290 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___290 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___29 ns;
	long unsigned int flags;
	struct key___393 *persistent_keyring_register;
	struct rw_semaphore___427 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___290 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___426 *pgtable_t___426;

struct address_space___425;

struct dev_pagemap___413;

struct page___426 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___425 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___426 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___426 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___426 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___413 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___160 *mem_cgroup;
};

struct pglist_data___426;

struct lruvec___426 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___426 *pgdat;
};

struct zone___426 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___426 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___426 {
	struct zone___426 *zone;
	int zone_idx;
};

struct zonelist___426 {
	struct zoneref___426 _zonerefs[25];
};

struct pglist_data___426 {
	struct zone___426 node_zones[3];
	struct zonelist___426 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___427 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___427 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___426 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___427 {
	void *stack;
	struct task_struct___427 *task;
	long int status;
};

struct blocking_notifier_head___426 {
	struct rw_semaphore___427 rwsem;
	struct notifier_block *head;
};

struct dentry___425;

struct path___426 {
	struct vfsmount *mnt;
	struct dentry___425 *dentry;
};

struct file___425 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___426 f_path;
	struct inode___425 *f_inode;
	const struct file_operations___425 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___240 f_owner;
	const struct cred___393 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___425 *f_mapping;
	errseq_t f_wb_err;
};

struct user_struct___393;

struct cred___393 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___393 *session_keyring;
	struct key___393 *process_keyring;
	struct key___393 *thread_keyring;
	struct key___393 *request_key_auth;
	void *security;
	struct user_struct___393 *user;
	struct user_namespace___290 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___419;

struct kernfs_elem_dir___419 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___419 *root;
};

struct kernfs_node___420;

struct kernfs_syscall_ops___419;

struct kernfs_root___419 {
	struct kernfs_node___420 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___419 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___419 {
	struct kernfs_node___420 *target_kn;
};

struct kernfs_ops___419;

struct kernfs_elem_attr___419 {
	const struct kernfs_ops___419 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___420 *notify_next;
};

struct kernfs_node___420 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___420 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___419 dir;
		struct kernfs_elem_symlink___419 symlink;
		struct kernfs_elem_attr___419 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___419;

struct kernfs_ops___419 {
	int (*open)(struct kernfs_open_file___419 *);
	void (*release)(struct kernfs_open_file___419 *);
	int (*seq_show)(struct seq_file___364 *, void *);
	void * (*seq_start)(struct seq_file___364 *, loff_t *);
	void * (*seq_next)(struct seq_file___364 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___364 *, void *);
	ssize_t (*read)(struct kernfs_open_file___419 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___419 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___419 *, struct vm_area_struct___426 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___419 *, struct poll_table_struct___266 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___419 {
	int (*remount_fs)(struct kernfs_root___419 *, int *, char *);
	int (*show_options)(struct seq_file___364 *, struct kernfs_root___419 *);
	int (*mkdir)(struct kernfs_node___420 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___420 *);
	int (*rename)(struct kernfs_node___420 *, struct kernfs_node___420 *, const char *);
	int (*show_path)(struct seq_file___364 *, struct kernfs_node___420 *, struct kernfs_root___419 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___364;

struct seq_file___364 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___364 *op;
	int poll_event;
	const struct file___425 *file;
	void *private;
};

struct vm_operations_struct___413;

struct kernfs_open_file___419 {
	struct kernfs_node___420 *kn;
	struct file___425 *file;
	struct seq_file___364 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___413 *vm_ops;
};

struct vm_fault___413;

struct vm_operations_struct___413 {
	void (*open)(struct vm_area_struct___426 *);
	void (*close)(struct vm_area_struct___426 *);
	int (*split)(struct vm_area_struct___426 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___426 *);
	vm_fault_t (*fault)(struct vm_fault___413 *);
	vm_fault_t (*huge_fault)(struct vm_fault___413 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___413 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___426 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___413 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___413 *);
	int (*access)(struct vm_area_struct___426 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___426 *);
	int (*set_policy)(struct vm_area_struct___426 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___426 *, long unsigned int);
	struct page___426 * (*find_special_page)(struct vm_area_struct___426 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___276)(struct file___425 *, wait_queue_head_t *, struct poll_table_struct___266 *);

struct poll_table_struct___266 {
	poll_queue_proc___276 _qproc;
	__poll_t _key;
};

struct vm_area_struct___426 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___426 *vm_next;
	struct vm_area_struct___426 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___426 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___413 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___425 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sock___53;

struct kobj_ns_type_operations___52 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___53 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct net___82;

typedef struct {
	struct net___82 *net;
} possible_net_t___72;

struct proto___52;

struct sock_common___52 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___52 *skc_prot;
	possible_net_t___72 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___53 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___72;

struct sk_buff_head___70 {
	struct sk_buff___72 *next;
	struct sk_buff___72 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___52;

struct socket_wq___53;

struct dst_entry___52;

struct socket___54;

struct net_device___71;

struct sock___53 {
	struct sock_common___52 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___70 sk_error_queue;
	struct sk_buff_head___70 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___72 *head;
		struct sk_buff___72 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___52 *sk_filter;
	union {
		struct socket_wq___53 *sk_wq;
		struct socket_wq___53 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___52 *sk_rx_dst;
	struct dst_entry___52 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___72 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___70 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___426 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___52 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___240 *sk_peer_pid;
	const struct cred___393 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___54 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___160 *sk_memcg;
	void (*sk_state_change)(struct sock___53 *);
	void (*sk_data_ready)(struct sock___53 *);
	void (*sk_write_space)(struct sock___53 *);
	void (*sk_error_report)(struct sock___53 *);
	int (*sk_backlog_rcv)(struct sock___53 *, struct sk_buff___72 *);
	struct sk_buff___72 * (*sk_validate_xmit_skb)(struct sock___53 *, struct net_device___71 *, struct sk_buff___72 *);
	void (*sk_destruct)(struct sock___53 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kobject___413;

struct bin_attribute___389;

struct attribute_group___390 {
	const char *name;
	umode_t (*is_visible)(struct kobject___413 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___413 *, struct bin_attribute___389 *, int);
	struct attribute **attrs;
	struct bin_attribute___389 **bin_attrs;
};

struct kset___412;

struct kobj_type___412;

struct kobject___413 {
	const char *name;
	struct list_head entry;
	struct kobject___413 *parent;
	struct kset___412 *kset;
	struct kobj_type___412 *ktype;
	struct kernfs_node___420 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___389 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___425 *, struct kobject___413 *, struct bin_attribute___389 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___425 *, struct kobject___413 *, struct bin_attribute___389 *, char *, loff_t, size_t);
	int (*mmap)(struct file___425 *, struct kobject___413 *, struct bin_attribute___389 *, struct vm_area_struct___426 *);
};

struct sysfs_ops___412 {
	ssize_t (*show)(struct kobject___413 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___413 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___412;

struct kset___412 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___413 kobj;
	const struct kset_uevent_ops___412 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___412 {
	void (*release)(struct kobject___413 *);
	const struct sysfs_ops___412 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___52 * (*child_ns_type)(struct kobject___413 *);
	const void * (*namespace)(struct kobject___413 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___412 {
	int (* const filter)(struct kset___412 *, struct kobject___413 *);
	const char * (* const name)(struct kset___412 *, struct kobject___413 *);
	int (* const uevent)(struct kset___412 *, struct kobject___413 *, struct kobj_uevent_env *);
};

struct kobj_attribute___403 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___413 *, struct kobj_attribute___403 *, char *);
	ssize_t (*store)(struct kobject___413 *, struct kobj_attribute___403 *, const char *, size_t);
};

struct kernel_param___353;

struct kernel_param_ops___353 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___353 *);
	int (*get)(char *, const struct kernel_param___353 *);
	void (*free)(void *);
};

struct kparam_array___353;

struct kernel_param___353 {
	const char *name;
	struct module___355 *mod;
	const struct kernel_param_ops___353 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___353 *arr;
	};
};

struct kparam_array___353 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___353 *ops;
	void *elem;
};

struct module_kobject___353 {
	struct kobject___413 kobj;
	struct module___355 *mod;
	struct kobject___413 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___353 {
	struct module___355 *mod;
	struct latch_tree_node node;
};

struct module_layout___353 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___353 mtn;
};

struct module_attribute___353;

struct module___355 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___353 mkobj;
	struct module_attribute___353 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___413 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___353 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___353 core_layout;
	struct module_layout___353 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___353 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___353 *, struct module_kobject___353 *, char *);
	ssize_t (*store)(struct module_attribute___353 *, struct module_kobject___353 *, const char *, size_t);
	void (*setup)(struct module___355 *, const char *);
	int (*test)(struct module___355 *);
	void (*free)(struct module___355 *);
};

struct core_state___426;

struct mm_struct___426 {
	struct {
		struct vm_area_struct___426 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___425 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___427 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___426 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___427 *owner;
		struct user_namespace___290 *user_ns;
		struct file___425 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___426 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___425;

struct address_space___425 {
	struct inode___425 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___427 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___425 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___413)(struct vm_area_struct___426 *, long unsigned int, const struct page___426 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___413)(struct page___426 *, void *);

struct device___393;

struct dev_pagemap___413 {
	dev_page_fault_t___413 page_fault;
	dev_page_free_t___413 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___393 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct cgroup___274;

struct cgroup_subsys___274;

struct cgroup_subsys_state___274 {
	struct cgroup___274 *cgroup;
	struct cgroup_subsys___274 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___274 *parent;
};

struct cgroup_file___274 {
	struct kernfs_node___420 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___160;

struct mem_cgroup___160 {
	struct cgroup_subsys_state___274 css;
	struct mem_cgroup_id___13 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___274 events_file;
	struct cgroup_file___274 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___427 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___160 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct core_thread___426 {
	struct task_struct___427 *task;
	struct core_thread___426 *next;
};

struct core_state___426 {
	atomic_t nr_threads;
	struct core_thread___426 dumper;
	struct completion startup;
};

struct vm_fault___413 {
	struct vm_area_struct___426 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___426 *cow_page;
	struct mem_cgroup___160 *memcg;
	struct page___426 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___426 prealloc_pte;
};

struct shrink_control___160 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___160 *memcg;
};

struct shrinker___160 {
	long unsigned int (*count_objects)(struct shrinker___160 *, struct shrink_control___160 *);
	long unsigned int (*scan_objects)(struct shrinker___160 *, struct shrink_control___160 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct user_struct___393 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___393 *uid_keyring;
	struct key___393 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cgroup_namespace___274;

struct nsproxy___320 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net___82 *net_ns;
	struct cgroup_namespace___274 *cgroup_ns;
};

struct signal_struct___300 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___427 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___427 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___240 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___240 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___426 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___240 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___217;

struct bio_list___217 {
	struct bio___217 *head;
	struct bio___217 *tail;
};

struct bdi_writeback_congested___217;

struct bdi_writeback___217 {
	struct backing_dev_info___217 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___217 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___274 *memcg_css;
	struct cgroup_subsys_state___274 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___217 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___217 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___393 *dev;
	struct device___393 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___425 *debug_dir;
	struct dentry___425 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___274 {
	struct cgroup_subsys_state___274 *subsys[13];
	refcount_t refcount;
	struct css_set___274 *dom_cset;
	struct cgroup___274 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___274 *mg_src_cgrp;
	struct cgroup___274 *mg_dst_cgrp;
	struct css_set___274 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___425;

struct pipe_buffer___106;

struct pipe_inode_info___106 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___426 *tmp_page;
	struct fasync_struct___425 *fasync_readers;
	struct fasync_struct___425 *fasync_writers;
	struct pipe_buffer___106 *bufs;
	struct user_struct___393 *user;
};

struct vm_struct___329 {
	struct vm_struct___329 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___426 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___312 {
	struct task_struct___427 task;
	long unsigned int stack[8192];
};

struct dev_pm_info___393 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___393 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___393;

struct bus_type___393;

struct device_driver___393;

struct dev_pm_domain___393;

struct dma_map_ops___165;

struct device_node___100;

struct fwnode_handle___313;

struct class___393;

struct device___393 {
	struct device___393 *parent;
	struct device_private *p;
	struct kobject___413 kobj;
	const char *init_name;
	const struct device_type___393 *type;
	struct mutex mutex;
	struct bus_type___393 *bus;
	struct device_driver___393 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___393 power;
	struct dev_pm_domain___393 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___165 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___100 *of_node;
	struct fwnode_handle___313 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___393 *class;
	const struct attribute_group___390 **groups;
	void (*release)(struct device___393 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___425;

struct super_block___425;

struct dentry___425 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___425 *d_parent;
	struct qstr d_name;
	struct inode___425 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___425 *d_op;
	struct super_block___425 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___425;

struct block_device___425;

struct inode___425 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___425 *i_op;
	struct super_block___425 *i_sb;
	struct address_space___425 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___427 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___217 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___425 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___425 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___106 *i_pipe;
		struct block_device___425 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___425 {
	int (*d_revalidate)(struct dentry___425 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___425 *, unsigned int);
	int (*d_hash)(const struct dentry___425 *, struct qstr *);
	int (*d_compare)(const struct dentry___425 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___425 *);
	int (*d_init)(struct dentry___425 *);
	void (*d_release)(struct dentry___425 *);
	void (*d_prune)(struct dentry___425 *);
	void (*d_iput)(struct dentry___425 *, struct inode___425 *);
	char * (*d_dname)(struct dentry___425 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___426 *);
	int (*d_manage)(const struct path___426 *, bool);
	struct dentry___425 * (*d_real)(struct dentry___425 *, const struct inode___425 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___425;

struct mem_dqinfo___425 {
	struct quota_format_type___425 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___425;

struct quota_info___425 {
	unsigned int flags;
	struct rw_semaphore___427 dqio_sem;
	struct inode___425 *files[3];
	struct mem_dqinfo___425 info[3];
	const struct quota_format_ops___425 *ops[3];
};

struct rcuwait___425 {
	struct task_struct___427 *task;
};

struct percpu_rw_semaphore___425 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___427 rw_sem;
	struct rcuwait___425 writer;
	int readers_block;
};

struct sb_writers___425 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___425 rw_sem[3];
};

struct file_system_type___425;

struct super_operations___425;

struct dquot_operations___425;

struct quotactl_ops___425;

struct super_block___425 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___425 *s_type;
	const struct super_operations___425 *s_op;
	const struct dquot_operations___425 *dq_op;
	const struct quotactl_ops___425 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___425 *s_root;
	struct rw_semaphore___427 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___425 *s_bdev;
	struct backing_dev_info___217 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___425 s_dquot;
	struct sb_writers___425 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___425 *s_d_op;
	int cleancache_poolid;
	struct shrinker___160 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___290 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___425 {
	struct file___425 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___425 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___425 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___425 *ia_file;
};

struct dquot___425 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___425 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___425 {
	int qf_fmt_id;
	const struct quota_format_ops___425 *qf_ops;
	struct module___355 *qf_owner;
	struct quota_format_type___425 *qf_next;
};

struct quota_format_ops___425 {
	int (*check_quota_file)(struct super_block___425 *, int);
	int (*read_file_info)(struct super_block___425 *, int);
	int (*write_file_info)(struct super_block___425 *, int);
	int (*free_file_info)(struct super_block___425 *, int);
	int (*read_dqblk)(struct dquot___425 *);
	int (*commit_dqblk)(struct dquot___425 *);
	int (*release_dqblk)(struct dquot___425 *);
	int (*get_next_id)(struct super_block___425 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___425 {
	int (*write_dquot)(struct dquot___425 *);
	struct dquot___425 * (*alloc_dquot)(struct super_block___425 *, int);
	void (*destroy_dquot)(struct dquot___425 *);
	int (*acquire_dquot)(struct dquot___425 *);
	int (*release_dquot)(struct dquot___425 *);
	int (*mark_dirty)(struct dquot___425 *);
	int (*write_info)(struct super_block___425 *, int);
	qsize_t * (*get_reserved_space)(struct inode___425 *);
	int (*get_projid)(struct inode___425 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___425 *, qsize_t *);
	int (*get_next_id)(struct super_block___425 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___425 {
	int (*quota_on)(struct super_block___425 *, int, int, const struct path___426 *);
	int (*quota_off)(struct super_block___425 *, int);
	int (*quota_enable)(struct super_block___425 *, unsigned int);
	int (*quota_disable)(struct super_block___425 *, unsigned int);
	int (*quota_sync)(struct super_block___425 *, int);
	int (*set_info)(struct super_block___425 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___425 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___425 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___425 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___425 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___425 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___180;

struct address_space_operations___425 {
	int (*writepage)(struct page___426 *, struct writeback_control___180 *);
	int (*readpage)(struct file___425 *, struct page___426 *);
	int (*writepages)(struct address_space___425 *, struct writeback_control___180 *);
	int (*set_page_dirty)(struct page___426 *);
	int (*readpages)(struct file___425 *, struct address_space___425 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___425 *, struct address_space___425 *, loff_t, unsigned int, unsigned int, struct page___426 **, void **);
	int (*write_end)(struct file___425 *, struct address_space___425 *, loff_t, unsigned int, unsigned int, struct page___426 *, void *);
	sector_t (*bmap)(struct address_space___425 *, sector_t);
	void (*invalidatepage)(struct page___426 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___426 *, gfp_t);
	void (*freepage)(struct page___426 *);
	ssize_t (*direct_IO)(struct kiocb___425 *, struct iov_iter___192 *);
	int (*migratepage)(struct address_space___425 *, struct page___426 *, struct page___426 *, enum migrate_mode);
	bool (*isolate_page)(struct page___426 *, isolate_mode_t);
	void (*putback_page)(struct page___426 *);
	int (*launder_page)(struct page___426 *);
	int (*is_partially_uptodate)(struct page___426 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___426 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___425 *, struct page___426 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___425 *, sector_t *);
	void (*swap_deactivate)(struct file___425 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___180 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___217 *wb;
	struct inode___425 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___219;

struct iov_iter___192 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___219 *bvec;
		struct pipe_inode_info___106 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___425 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___425 *bd_inode;
	struct super_block___425 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___425 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___217 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___425 {
	struct dentry___425 * (*lookup)(struct inode___425 *, struct dentry___425 *, unsigned int);
	const char * (*get_link)(struct dentry___425 *, struct inode___425 *, struct delayed_call *);
	int (*permission)(struct inode___425 *, int);
	struct posix_acl * (*get_acl)(struct inode___425 *, int);
	int (*readlink)(struct dentry___425 *, char *, int);
	int (*create)(struct inode___425 *, struct dentry___425 *, umode_t, bool);
	int (*link)(struct dentry___425 *, struct inode___425 *, struct dentry___425 *);
	int (*unlink)(struct inode___425 *, struct dentry___425 *);
	int (*symlink)(struct inode___425 *, struct dentry___425 *, const char *);
	int (*mkdir)(struct inode___425 *, struct dentry___425 *, umode_t);
	int (*rmdir)(struct inode___425 *, struct dentry___425 *);
	int (*mknod)(struct inode___425 *, struct dentry___425 *, umode_t, dev_t);
	int (*rename)(struct inode___425 *, struct dentry___425 *, struct inode___425 *, struct dentry___425 *, unsigned int);
	int (*setattr)(struct dentry___425 *, struct iattr___425 *);
	int (*getattr)(const struct path___426 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___425 *, char *, size_t);
	int (*fiemap)(struct inode___425 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___425 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___425 *, struct dentry___425 *, struct file___425 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___425 *, struct dentry___425 *, umode_t);
	int (*set_acl)(struct inode___425 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___425 {
	void (*fl_copy_lock)(struct file_lock___425 *, struct file_lock___425 *);
	void (*fl_release_private)(struct file_lock___425 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___425;

struct file_lock___425 {
	struct file_lock___425 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___425 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___425 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___425 *fl_ops;
	const struct lock_manager_operations___425 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___425 {
	int (*lm_compare_owner)(struct file_lock___425 *, struct file_lock___425 *);
	long unsigned int (*lm_owner_key)(struct file_lock___425 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___425 *);
	int (*lm_grant)(struct file_lock___425 *, int);
	bool (*lm_break)(struct file_lock___425 *);
	int (*lm_change)(struct file_lock___425 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___425 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___425 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___425 *fa_next;
	struct file___425 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___425 {
	const char *name;
	int fs_flags;
	struct dentry___425 * (*mount)(struct file_system_type___425 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___425 *);
	struct module___355 *owner;
	struct file_system_type___425 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___425 {
	struct inode___425 * (*alloc_inode)(struct super_block___425 *);
	void (*destroy_inode)(struct inode___425 *);
	void (*dirty_inode)(struct inode___425 *, int);
	int (*write_inode)(struct inode___425 *, struct writeback_control___180 *);
	int (*drop_inode)(struct inode___425 *);
	void (*evict_inode)(struct inode___425 *);
	void (*put_super)(struct super_block___425 *);
	int (*sync_fs)(struct super_block___425 *, int);
	int (*freeze_super)(struct super_block___425 *);
	int (*freeze_fs)(struct super_block___425 *);
	int (*thaw_super)(struct super_block___425 *);
	int (*unfreeze_fs)(struct super_block___425 *);
	int (*statfs)(struct dentry___425 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___425 *, int *, char *);
	void (*umount_begin)(struct super_block___425 *);
	int (*show_options)(struct seq_file___364 *, struct dentry___425 *);
	int (*show_devname)(struct seq_file___364 *, struct dentry___425 *);
	int (*show_path)(struct seq_file___364 *, struct dentry___425 *);
	int (*show_stats)(struct seq_file___364 *, struct dentry___425 *);
	ssize_t (*quota_read)(struct super_block___425 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___425 *, int, const char *, size_t, loff_t);
	struct dquot___425 ** (*get_dquots)(struct inode___425 *);
	int (*bdev_try_to_free_page)(struct super_block___425 *, struct page___426 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___425 *, struct shrink_control___160 *);
	long int (*free_cached_objects)(struct super_block___425 *, struct shrink_control___160 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___217(struct bio___217 *);

struct bio_vec___219 {
	struct page___426 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___217;

struct bio_set___217;

struct bio___217 {
	struct bio___217 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___217 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___217 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___219 *bi_io_vec;
	struct bio_set___217 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___219 bi_inline_vecs[0];
};

typedef void compound_page_dtor___413(struct page___426 *);

struct msghdr___55 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___192 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___425 *msg_iocb;
};

struct inet_frags___70;

struct netns_frags___70 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___70 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct inet_frag_queue___70;

struct inet_frags___70 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___70 *, const void *);
	void (*destructor)(struct inet_frag_queue___70 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___70 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___72 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___72 *fragments_tail;
	struct sk_buff___72 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___70 *net;
	struct callback_head rcu;
};

struct nf_bridge_info___70;

struct sk_buff___72 {
	union {
		struct {
			struct sk_buff___72 *next;
			struct sk_buff___72 *prev;
			union {
				struct net_device___71 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___53 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___72 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___70 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct ip_ra_chain___26;

struct fib_rules_ops___52;

struct fib_notifier_ops___53;

struct netns_ipv4___70 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___26 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___52 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___53 *fibnl;
	struct sock___53 **icmp_sk;
	struct sock___53 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___53 **tcp_sk;
	struct netns_frags___70 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___52 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___53 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___53 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct ip_ra_chain___26 {
	struct ip_ra_chain___26 *next;
	struct sock___53 *sk;
	union {
		void (*destructor)(struct sock___53 *);
		struct sock___53 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___52;

struct fib_lookup_arg___52;

struct fib_rules_ops___52 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___52 *, struct flowi *, int, struct fib_lookup_arg___52 *);
	bool (*suppress)(struct fib_rule___52 *, struct fib_lookup_arg___52 *);
	int (*match)(struct fib_rule___52 *, struct flowi *, int);
	int (*configure)(struct fib_rule___52 *, struct sk_buff___72 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___52 *);
	int (*compare)(struct fib_rule___52 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___52 *, struct sk_buff___72 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___52 *);
	void (*flush_cache)(struct fib_rules_ops___52 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___355 *owner;
	struct net___82 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___53 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___82 *);
	int (*fib_dump)(struct net___82 *, struct notifier_block *);
	struct module___355 *owner;
	struct callback_head rcu;
};

struct neighbour___52;

struct dst_ops___81 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___81 *);
	struct dst_entry___52 * (*check)(struct dst_entry___52 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___52 *);
	unsigned int (*mtu)(const struct dst_entry___52 *);
	u32 * (*cow_metrics)(struct dst_entry___52 *, long unsigned int);
	void (*destroy)(struct dst_entry___52 *);
	void (*ifdown)(struct dst_entry___52 *, struct net_device___71 *, int);
	struct dst_entry___52 * (*negative_advice)(struct dst_entry___52 *);
	void (*link_failure)(struct sk_buff___72 *);
	void (*update_pmtu)(struct dst_entry___52 *, struct sock___53 *, struct sk_buff___72 *, u32);
	void (*redirect)(struct dst_entry___52 *, struct sock___53 *, struct sk_buff___72 *);
	int (*local_out)(struct net___82 *, struct sock___53 *, struct sk_buff___72 *);
	struct neighbour___52 * (*neigh_lookup)(const struct dst_entry___52 *, struct sk_buff___72 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___52 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct dst_entry___52 {
	struct net_device___71 *dev;
	struct dst_ops___81 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___72 *);
	int (*output)(struct net___82 *, struct sock___53 *, struct sk_buff___72 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

typedef rx_handler_result_t rx_handler_func_t___70(struct sk_buff___72 **);

struct net_device_ops___70;

struct ethtool_ops___70;

struct switchdev_ops___3;

struct l3mdev_ops___52;

struct ndisc_ops___30;

struct xfrmdev_ops___70;

struct tlsdev_ops___70;

struct header_ops___70;

struct inet6_dev___30;

struct netdev_rx_queue___70;

struct bpf_prog___62;

struct mini_Qdisc___62;

struct netdev_queue___70;

struct Qdisc___62;

struct rtnl_link_ops___62;

struct dcbnl_rtnl_ops___70;

struct phy_device___10;

struct net_device___71 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___70 *netdev_ops;
	const struct ethtool_ops___70 *ethtool_ops;
	const struct switchdev_ops___3 *switchdev_ops;
	const struct l3mdev_ops___52 *l3mdev_ops;
	const struct ndisc_ops___30 *ndisc_ops;
	const struct xfrmdev_ops___70 *xfrmdev_ops;
	const struct tlsdev_ops___70 *tlsdev_ops;
	const struct header_ops___70 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___412 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___30 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___70 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___62 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___70 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___62 *miniq_ingress;
	struct netdev_queue___70 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___70 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___62 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___62 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___70 = 0,
		NETREG_REGISTERED___70 = 1,
		NETREG_UNREGISTERING___70 = 2,
		NETREG_UNREGISTERED___70 = 3,
		NETREG_RELEASED___70 = 4,
		NETREG_DUMMY___70 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___70 = 0,
		RTNL_LINK_INITIALIZING___70 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___71 *);
	struct netpoll_info *npinfo;
	possible_net_t___72 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___393 dev;
	const struct attribute_group___390 *sysfs_groups[4];
	const struct attribute_group___390 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___62 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___70 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device___10 *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide35;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct netns_ipv6___81 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___70 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___81 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___52 *fib6_rules_ops;
	struct sock___53 **icmp_sk;
	struct sock___53 *ndisc_sk;
	struct sock___53 *tcp_sk;
	struct sock___53 *igmp_sk;
	struct sock___53 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___52 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___53 *notifier_ops;
	struct fib_notifier_ops___53 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___53 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___53 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___70 {
	struct netns_frags___70 frags;
};

struct netns_xfrm___81 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___53 *nlsk;
	struct sock___53 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___81 xfrm4_dst_ops;
	struct dst_ops___81 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct net___82 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___290 *user_ns;
	struct ucounts___290 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___29 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___53 *rtnl;
	struct sock___53 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___71 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___70 ipv4;
	struct netns_ipv6___81 ipv6;
	struct netns_sctp___53 sctp;
	struct netns_nf___4 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___70 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___53 *nfnl;
	struct sock___53 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___81 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___53 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___62 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neigh_table___52;

struct neigh_parms___52;

struct neigh_ops___52;

struct neighbour___52 {
	struct neighbour___52 *next;
	struct neigh_table___52 *tbl;
	struct neigh_parms___52 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___70 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___52 *, struct sk_buff___72 *);
	const struct neigh_ops___52 *ops;
	struct callback_head rcu;
	struct net_device___71 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct socket_wq___53 {
	wait_queue_head_t wait;
	struct fasync_struct___425 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___53;

struct socket___54 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___53 *wq;
	struct file___425 *file;
	struct sock___53 *sk;
	const struct proto_ops___53 *ops;
};

typedef int (*sk_read_actor_t___52)(read_descriptor_t *, struct sk_buff___72 *, unsigned int, size_t);

struct proto_ops___53 {
	int family;
	struct module___355 *owner;
	int (*release)(struct socket___54 *);
	int (*bind)(struct socket___54 *, struct sockaddr *, int);
	int (*connect)(struct socket___54 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___54 *, struct socket___54 *);
	int (*accept)(struct socket___54 *, struct socket___54 *, int, bool);
	int (*getname)(struct socket___54 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___425 *, struct socket___54 *, struct poll_table_struct___266 *);
	int (*ioctl)(struct socket___54 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___54 *, int);
	int (*shutdown)(struct socket___54 *, int);
	int (*setsockopt)(struct socket___54 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___54 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___54 *, struct msghdr___55 *, size_t);
	int (*recvmsg)(struct socket___54 *, struct msghdr___55 *, size_t, int);
	int (*mmap)(struct file___425 *, struct socket___54 *, struct vm_area_struct___426 *);
	ssize_t (*sendpage)(struct socket___54 *, struct page___426 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___54 *, loff_t *, struct pipe_inode_info___106 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___53 *, int);
	int (*peek_len)(struct socket___54 *);
	int (*read_sock)(struct sock___53 *, read_descriptor_t *, sk_read_actor_t___52);
	int (*sendpage_locked)(struct sock___53 *, struct page___426 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___53 *, struct msghdr___55 *, size_t);
	int (*set_rcvlowat)(struct sock___53 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct dev_pm_ops___393 {
	int (*prepare)(struct device___393 *);
	void (*complete)(struct device___393 *);
	int (*suspend)(struct device___393 *);
	int (*resume)(struct device___393 *);
	int (*freeze)(struct device___393 *);
	int (*thaw)(struct device___393 *);
	int (*poweroff)(struct device___393 *);
	int (*restore)(struct device___393 *);
	int (*suspend_late)(struct device___393 *);
	int (*resume_early)(struct device___393 *);
	int (*freeze_late)(struct device___393 *);
	int (*thaw_early)(struct device___393 *);
	int (*poweroff_late)(struct device___393 *);
	int (*restore_early)(struct device___393 *);
	int (*suspend_noirq)(struct device___393 *);
	int (*resume_noirq)(struct device___393 *);
	int (*freeze_noirq)(struct device___393 *);
	int (*thaw_noirq)(struct device___393 *);
	int (*poweroff_noirq)(struct device___393 *);
	int (*restore_noirq)(struct device___393 *);
	int (*runtime_suspend)(struct device___393 *);
	int (*runtime_resume)(struct device___393 *);
	int (*runtime_idle)(struct device___393 *);
};

struct dev_pm_domain___393 {
	struct dev_pm_ops___393 ops;
	void (*detach)(struct device___393 *, bool);
	int (*activate)(struct device___393 *);
	void (*sync)(struct device___393 *);
	void (*dismiss)(struct device___393 *);
};

struct bus_type___393 {
	const char *name;
	const char *dev_name;
	struct device___393 *dev_root;
	const struct attribute_group___390 **bus_groups;
	const struct attribute_group___390 **dev_groups;
	const struct attribute_group___390 **drv_groups;
	int (*match)(struct device___393 *, struct device_driver___393 *);
	int (*uevent)(struct device___393 *, struct kobj_uevent_env *);
	int (*probe)(struct device___393 *);
	int (*remove)(struct device___393 *);
	void (*shutdown)(struct device___393 *);
	int (*online)(struct device___393 *);
	int (*offline)(struct device___393 *);
	int (*suspend)(struct device___393 *, pm_message_t);
	int (*resume)(struct device___393 *);
	int (*num_vf)(struct device___393 *);
	int (*dma_configure)(struct device___393 *);
	const struct dev_pm_ops___393 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___393 {
	const char *name;
	struct bus_type___393 *bus;
	struct module___355 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___393 *);
	int (*remove)(struct device___393 *);
	void (*shutdown)(struct device___393 *);
	int (*suspend)(struct device___393 *, pm_message_t);
	int (*resume)(struct device___393 *);
	const struct attribute_group___390 **groups;
	const struct dev_pm_ops___393 *pm;
	void (*coredump)(struct device___393 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___393 {
	const char *name;
	const struct attribute_group___390 **groups;
	int (*uevent)(struct device___393 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___393 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___393 *);
	const struct dev_pm_ops___393 *pm;
};

struct class___393 {
	const char *name;
	struct module___355 *owner;
	const struct attribute_group___390 **class_groups;
	const struct attribute_group___390 **dev_groups;
	struct kobject___413 *dev_kobj;
	int (*dev_uevent)(struct device___393 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___393 *, umode_t *);
	void (*class_release)(struct class___393 *);
	void (*dev_release)(struct device___393 *);
	int (*shutdown_pre)(struct device___393 *);
	const struct kobj_ns_type_operations___52 *ns_type;
	const void * (*namespace)(struct device___393 *);
	const struct dev_pm_ops___393 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

typedef void (*dr_release_t___32)(struct device___393 *, void *);

struct dma_map_ops___165 {
	void * (*alloc)(struct device___393 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___393 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___393 *, struct vm_area_struct___426 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___393 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___393 *, struct page___426 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___393 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___393 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___393 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___393 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___393 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___393 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___393 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___393 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___393 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___393 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___393 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___393 *, u64);
	u64 (*get_required_mask)(struct device___393 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___313;

struct fwnode_handle___313 {
	struct fwnode_handle___313 *secondary;
	const struct fwnode_operations___313 *ops;
};

struct property___96;

struct device_node___100 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___313 fwnode;
	struct property___96 *properties;
	struct property___96 *deadprops;
	struct device_node___100 *parent;
	struct device_node___100 *child;
	struct device_node___100 *sibling;
	struct kobject___413 kobj;
	long unsigned int _flags;
	void *data;
};

struct fwnode_reference_args___313;

struct fwnode_endpoint___313;

struct fwnode_operations___313 {
	struct fwnode_handle___313 * (*get)(struct fwnode_handle___313 *);
	void (*put)(struct fwnode_handle___313 *);
	bool (*device_is_available)(const struct fwnode_handle___313 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___313 *, const struct device___393 *);
	bool (*property_present)(const struct fwnode_handle___313 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___313 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___313 *, const char *, const char **, size_t);
	struct fwnode_handle___313 * (*get_parent)(const struct fwnode_handle___313 *);
	struct fwnode_handle___313 * (*get_next_child_node)(const struct fwnode_handle___313 *, struct fwnode_handle___313 *);
	struct fwnode_handle___313 * (*get_named_child_node)(const struct fwnode_handle___313 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___313 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___313 *);
	struct fwnode_handle___313 * (*graph_get_next_endpoint)(const struct fwnode_handle___313 *, struct fwnode_handle___313 *);
	struct fwnode_handle___313 * (*graph_get_remote_endpoint)(const struct fwnode_handle___313 *);
	struct fwnode_handle___313 * (*graph_get_port_parent)(struct fwnode_handle___313 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___313 *, struct fwnode_endpoint___313 *);
};

struct fwnode_endpoint___313 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___313 *local_fwnode;
};

struct fwnode_reference_args___313 {
	struct fwnode_handle___313 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___106;

struct pipe_buffer___106 {
	struct page___426 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___106 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___106 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___106 *, struct pipe_buffer___106 *);
	void (*release)(struct pipe_inode_info___106 *, struct pipe_buffer___106 *);
	int (*steal)(struct pipe_inode_info___106 *, struct pipe_buffer___106 *);
	union {
		bool (*get)(struct pipe_inode_info___106 *, struct pipe_buffer___106 *);
		struct {
			void (*get)(struct pipe_inode_info___106 *, struct pipe_buffer___106 *);
		} __UNIQUE_ID_rh_kabi_hide21;
		union {		};
	};
};

struct nf_bridge_info___70 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___70 = 0,
		BRNF_PROTO_8021Q___70 = 1,
		BRNF_PROTO_PPPOE___70 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___71 *physindev;
	struct net_device___71 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

struct ucounts___290 {
	struct hlist_node node;
	struct user_namespace___290 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_prog_aux___65;

struct bpf_prog___62 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___65 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

typedef int (*key_restrict_link_func_t___394)(struct key___393 *, const struct key_type *, const union key_payload *, struct key___393 *);

struct key_restriction___393;

struct key___393 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___427 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___393 *restrict_link;
};

struct key_restriction___393 {
	key_restrict_link_func_t___394 check;
	struct key___393 *key;
	struct key_type *keytype;
};

struct seq_operations___364 {
	void * (*start)(struct seq_file___364 *, loff_t *);
	void (*stop)(struct seq_file___364 *, void *);
	void * (*next)(struct seq_file___364 *, void *, loff_t *);
	int (*show)(struct seq_file___364 *, void *);
};

struct pernet_operations___71 {
	struct list_head list;
	int (*init)(struct net___82 *);
	void (*exit)(struct net___82 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct ethtool_ops___70 {
	int (*get_settings)(struct net_device___71 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___71 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___71 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___71 *);
	void (*get_regs)(struct net_device___71 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___71 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___71 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___71 *);
	void (*set_msglevel)(struct net_device___71 *, u32);
	int (*nway_reset)(struct net_device___71 *);
	u32 (*get_link)(struct net_device___71 *);
	int (*get_eeprom_len)(struct net_device___71 *);
	int (*get_eeprom)(struct net_device___71 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___71 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___71 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___71 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___71 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___71 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___71 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___71 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___71 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___71 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___71 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___71 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___71 *);
	void (*complete)(struct net_device___71 *);
	u32 (*get_priv_flags)(struct net_device___71 *);
	int (*set_priv_flags)(struct net_device___71 *, u32);
	int (*get_sset_count)(struct net_device___71 *, int);
	int (*get_rxnfc)(struct net_device___71 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___71 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___71 *, struct ethtool_flash *);
	int (*reset)(struct net_device___71 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___71 *);
	u32 (*get_rxfh_indir_size)(struct net_device___71 *);
	int (*get_rxfh)(struct net_device___71 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___71 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___71 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___71 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___71 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___71 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___71 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___71 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___71 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___71 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___71 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___71 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___71 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___71 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___71 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___71 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___71 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___71 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___71 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___71 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___71 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___71 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	int (*get_fecparam)(struct net_device___71 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___71 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___71 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___71 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___71 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct dcbnl_rtnl_ops___70 {
	int (*ieee_getets)(struct net_device___71 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___71 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___71 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___71 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___71 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___71 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___71 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___71 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___71 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___71 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___71 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___71 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___71 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___71 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___71 *);
	u8 (*setstate)(struct net_device___71 *, u8);
	void (*getpermhwaddr)(struct net_device___71 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___71 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___71 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___71 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___71 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___71 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___71 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___71 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___71 *, int, u8 *);
	void (*setpfccfg)(struct net_device___71 *, int, u8);
	void (*getpfccfg)(struct net_device___71 *, int, u8 *);
	u8 (*setall)(struct net_device___71 *);
	u8 (*getcap)(struct net_device___71 *, int, u8 *);
	int (*getnumtcs)(struct net_device___71 *, int, u8 *);
	int (*setnumtcs)(struct net_device___71 *, int, u8);
	u8 (*getpfcstate)(struct net_device___71 *);
	void (*setpfcstate)(struct net_device___71 *, u8);
	void (*getbcncfg)(struct net_device___71 *, int, u32 *);
	void (*setbcncfg)(struct net_device___71 *, int, u32);
	void (*getbcnrp)(struct net_device___71 *, int, u8 *);
	void (*setbcnrp)(struct net_device___71 *, int, u8);
	int (*setapp)(struct net_device___71 *, u8, u16, u8);
	int (*getapp)(struct net_device___71 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___71 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___71 *, int, u8);
	u8 (*getdcbx)(struct net_device___71 *);
	u8 (*setdcbx)(struct net_device___71 *, u8);
	int (*peer_getappinfo)(struct net_device___71 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___71 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___71 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___71 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___71 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___71 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___274 {
	refcount_t count;
	struct ns_common___29 ns;
	struct user_namespace___290 *user_ns;
	struct ucounts___290 *ucounts;
	struct css_set___274 *root_cset;
};

struct bpf_map___275;

struct bpf_map_ops___274 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___275 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___275 *, struct file___425 *);
	void (*map_free)(struct bpf_map___275 *);
	int (*map_get_next_key)(struct bpf_map___275 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___275 *);
	void * (*map_lookup_elem)(struct bpf_map___275 *, void *);
	int (*map_update_elem)(struct bpf_map___275 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___275 *, void *);
	int (*map_push_elem)(struct bpf_map___275 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___275 *, void *);
	int (*map_peek_elem)(struct bpf_map___275 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___275 *, struct file___425 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___275 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___275 *, void *, struct seq_file___364 *);
	int (*map_check_btf)(const struct bpf_map___275 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___275 {
	const struct bpf_map_ops___274 *ops;
	struct bpf_map___275 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___393 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___70;

struct bpf_map_dev_ops___70 {
	int (*map_get_next_key)(struct bpf_offloaded_map___70 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___70 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___70 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___70 *, void *);
};

struct bpf_offloaded_map___70 {
	struct bpf_map___275 map;
	struct net_device___71 *netdev;
	const struct bpf_map_dev_ops___70 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___62 {
	int (*test_run)(struct bpf_prog___62 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___62 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___62 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___62 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___62 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___62 *, u32 *);
};

struct bpf_prog_offload_ops___62 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___62 *);
	int (*translate)(struct bpf_prog___62 *);
	void (*destroy)(struct bpf_prog___62 *);
};

struct bpf_prog_offload___62 {
	struct bpf_prog___62 *prog;
	struct net_device___71 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___62 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___65 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___62 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___62 *ops;
	struct bpf_map___275 **used_maps;
	struct bpf_prog___62 *prog;
	struct user_struct___393 *user;
	u64 load_time;
	struct bpf_map___275 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___62 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___62 {
	struct bpf_prog___62 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___62 {
	struct callback_head rcu;
	struct bpf_prog_array_item___62 items[0];
};

struct cgroup_bpf___62 {
	struct bpf_prog_array___62 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___62 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___275;

typedef void (*kthread_work_func_t___275)(struct kthread_work___275 *);

struct kthread_worker___275;

struct kthread_work___275 {
	struct list_head node;
	kthread_work_func_t___275 func;
	struct kthread_worker___275 *worker;
	int canceling;
};

struct kthread_worker___275 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___427 *task;
	struct kthread_work___275 *current_work;
};

struct kthread_delayed_work___274 {
	struct kthread_work___275 work;
	struct timer_list timer;
};

struct psi_group___274 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___275 *poll_kworker;
	struct kthread_delayed_work___274 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___274;

struct cgroup_rstat_cpu___274;

struct cgroup___274 {
	struct cgroup_subsys_state___274 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___420 *kn;
	struct cgroup_file___274 procs_file;
	struct cgroup_file___274 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___274 *subsys[13];
	struct cgroup_root___274 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___274 *dom_cgrp;
	struct cgroup_rstat_cpu___274 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___62 bpf;
	atomic_t congestion_count;
	struct cgroup___274 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___274 psi;
	int ancestor_ids[0];
};

struct cftype___274;

struct cgroup_subsys___274 {
	struct cgroup_subsys_state___274 * (*css_alloc)(struct cgroup_subsys_state___274 *);
	int (*css_online)(struct cgroup_subsys_state___274 *);
	void (*css_offline)(struct cgroup_subsys_state___274 *);
	void (*css_released)(struct cgroup_subsys_state___274 *);
	void (*css_free)(struct cgroup_subsys_state___274 *);
	void (*css_reset)(struct cgroup_subsys_state___274 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___274 *, int);
	int (*css_extra_stat_show)(struct seq_file___364 *, struct cgroup_subsys_state___274 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___427 *);
	void (*cancel_fork)(struct task_struct___427 *);
	void (*fork)(struct task_struct___427 *);
	void (*exit)(struct task_struct___427 *);
	void (*free)(struct task_struct___427 *);
	void (*bind)(struct cgroup_subsys_state___274 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___274 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___274 *dfl_cftypes;
	struct cftype___274 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___274 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___274 *updated_children;
	struct cgroup___274 *updated_next;
};

struct cgroup_root___274 {
	struct kernfs_root___419 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___274 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___274 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___274 *ss;
	struct list_head node;
	struct kernfs_ops___419 *kf_ops;
	int (*open)(struct kernfs_open_file___419 *);
	void (*release)(struct kernfs_open_file___419 *);
	u64 (*read_u64)(struct cgroup_subsys_state___274 *, struct cftype___274 *);
	s64 (*read_s64)(struct cgroup_subsys_state___274 *, struct cftype___274 *);
	int (*seq_show)(struct seq_file___364 *, void *);
	void * (*seq_start)(struct seq_file___364 *, loff_t *);
	void * (*seq_next)(struct seq_file___364 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___364 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___274 *, struct cftype___274 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___274 *, struct cftype___274 *, s64);
	ssize_t (*write)(struct kernfs_open_file___419 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___419 *, struct poll_table_struct___266 *);
};

struct xdp_rxq_info___70 {
	struct net_device___71 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___70 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___71 *dev_rx;
};

struct netlink_callback___72 {
	struct sk_buff___72 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___72 *);
	int (*dump)(struct sk_buff___72 *, struct netlink_callback___72 *);
	int (*done)(struct netlink_callback___72 *);
	void *data;
	struct module___355 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___70 {
	int (*create)(struct sk_buff___72 *, struct net_device___71 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___72 *, unsigned char *);
	int (*cache)(const struct neighbour___52 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___71 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___70 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___70 *, int);
	int poll_owner;
	struct net_device___71 *dev;
	struct sk_buff___72 *gro_list;
	struct sk_buff___72 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___70 {
	struct net_device___71 *dev;
	struct Qdisc___62 *qdisc;
	struct Qdisc___62 *qdisc_sleeping;
	struct kobject___413 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___71 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem___3 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___62 {
	struct sk_buff___72 *head;
	struct sk_buff___72 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___62;

struct Qdisc___62 {
	int (*enqueue)(struct sk_buff___72 *, struct Qdisc___62 *, struct sk_buff___72 **);
	struct sk_buff___72 * (*dequeue)(struct Qdisc___62 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___62 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___70 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___70 gso_skb;
	struct qdisc_skb_head___62 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___62 *next_sched;
	struct sk_buff_head___70 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___70 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___413 kobj;
	struct net_device___71 *dev;
	long: 64;
	struct xdp_rxq_info___70 xdp_rxq;
	union {
		struct xdp_umem___3 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___70)(struct net_device___71 *, struct sk_buff___72 *, struct net_device___71 *);

struct netdev_bpf___70 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___62 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___62 *prog;
			const struct bpf_prog_offload_ops___62 *ops;
		} verifier;
		struct {
			struct bpf_prog___62 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___70 *offmap;
		};
		struct {
			struct xdp_umem___3 *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___70 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___72 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___70 {
	int (*tls_dev_add)(struct net_device___71 *, struct sock___53 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___71 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___71 *, struct sock___53 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___70 {
	int (*ndo_init)(struct net_device___71 *);
	void (*ndo_uninit)(struct net_device___71 *);
	int (*ndo_open)(struct net_device___71 *);
	int (*ndo_stop)(struct net_device___71 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___72 *, struct net_device___71 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___72 *, struct net_device___71 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___71 *, struct sk_buff___72 *, struct net_device___71 *, select_queue_fallback_t___70);
	void (*ndo_change_rx_flags)(struct net_device___71 *, int);
	void (*ndo_set_rx_mode)(struct net_device___71 *);
	int (*ndo_set_mac_address)(struct net_device___71 *, void *);
	int (*ndo_validate_addr)(struct net_device___71 *);
	int (*ndo_do_ioctl)(struct net_device___71 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___71 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___71 *, int);
	int (*ndo_neigh_setup)(struct net_device___71 *, struct neigh_parms___52 *);
	void (*ndo_tx_timeout)(struct net_device___71 *);
	void (*ndo_get_stats64)(struct net_device___71 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___71 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___71 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___71 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___71 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___71 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___71 *);
	int (*ndo_netpoll_setup)(struct net_device___71 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___71 *);
	int (*ndo_set_vf_mac)(struct net_device___71 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___71 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___71 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___71 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___71 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___71 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___71 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___71 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___71 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___71 *, int, struct sk_buff___72 *);
	int (*ndo_set_vf_guid)(struct net_device___71 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___71 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___71 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___71 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___71 *, const struct sk_buff___72 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___71 *, struct net_device___71 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___71 *, struct net_device___71 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___71 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___71 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___71 *, struct neighbour___52 *);
	void (*ndo_neigh_destroy)(struct net_device___71 *, struct neighbour___52 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___71 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___71 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___71 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___72 *, struct netlink_callback___72 *, struct net_device___71 *, struct net_device___71 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___71 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___71 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___72 *, u32, u32, struct net_device___71 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___71 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___71 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___71 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___71 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___71 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___71 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___71 *, struct net_device___71 *);
	void (*ndo_dfwd_del_station)(struct net_device___71 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___71 *);
	int (*ndo_set_tx_maxrate)(struct net_device___71 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___71 *);
	int (*ndo_change_proto_down)(struct net_device___71 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___71 *, struct sk_buff___72 *);
	void (*ndo_set_rx_headroom)(struct net_device___71 *, int);
	int (*ndo_bpf)(struct net_device___71 *, struct netdev_bpf___70 *);
	int (*ndo_xdp_xmit)(struct net_device___71 *, int, struct xdp_frame___70 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___71 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___71 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___52 {
	possible_net_t___72 net;
	struct net_device___71 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___52 *);
	void (*neigh_cleanup)(struct neighbour___52 *);
	struct neigh_table___52 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct switchdev_attr___3;

struct switchdev_obj___3;

struct switchdev_ops___3 {
	int (*switchdev_port_attr_get)(struct net_device___71 *, struct switchdev_attr___3 *);
	int (*switchdev_port_attr_set)(struct net_device___71 *, const struct switchdev_attr___3 *, struct switchdev_trans *);
	int (*rh_reserved_switchdev_port_obj_add)(struct net_device___71 *, const struct switchdev_obj___3 *, struct switchdev_trans *);
	int (*rh_reserved_switchdev_port_obj_del)(struct net_device___71 *, const struct switchdev_obj___3 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t switchdev_ops_extended_size_rh;
	struct switchdev_ops_extended_rh switchdev_ops_extended_rh;
};

struct l3mdev_ops___52 {
	u32 (*l3mdev_fib_table)(const struct net_device___71 *);
	struct sk_buff___72 * (*l3mdev_l3_rcv)(struct net_device___71 *, struct sk_buff___72 *, u16);
	struct sk_buff___72 * (*l3mdev_l3_out)(struct net_device___71 *, struct sock___53 *, struct sk_buff___72 *, u16);
	struct dst_entry___52 * (*l3mdev_link_scope_lookup)(const struct net_device___71 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct ndisc_ops___30 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___71 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___71 *, struct neighbour___52 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___71 *, u8, struct neighbour___52 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___71 *, struct sk_buff___72 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___82 *, struct net_device___71 *, const struct prefix_info *, struct inet6_dev___30 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___30;

struct inet6_dev___30 {
	struct net_device___71 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___30 *mc_list;
	struct ifmcaddr6___30 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___9 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	u8 rndid[8];
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___52 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
};

struct tcf_proto___62;

struct mini_Qdisc___62 {
	struct tcf_proto___62 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___62 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___71 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___82 *, struct net_device___71 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___71 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___71 *, struct list_head *);
	size_t (*get_size)(const struct net_device___71 *);
	int (*fill_info)(struct sk_buff___72 *, const struct net_device___71 *);
	size_t (*get_xstats_size)(const struct net_device___71 *);
	int (*fill_xstats)(struct sk_buff___72 *, const struct net_device___71 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___71 *, struct net_device___71 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___71 *, const struct net_device___71 *);
	int (*fill_slave_info)(struct sk_buff___72 *, const struct net_device___71 *, const struct net_device___71 *);
	struct net___82 * (*get_link_net)(const struct net_device___71 *);
	size_t (*get_linkxstats_size)(const struct net_device___71 *, int);
	int (*fill_linkxstats)(struct sk_buff___72 *, const struct net_device___71 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct mii_bus___10;

struct mdio_device___10 {
	struct device___393 dev;
	struct mii_bus___10 *bus;
	char modalias[32];
	int (*bus_match)(struct device___393 *, struct device_driver___393 *);
	void (*device_free)(struct mdio_device___10 *);
	void (*device_remove)(struct mdio_device___10 *);
	int addr;
	int flags;
	struct gpio_desc *reset;
	unsigned int reset_assert_delay;
	unsigned int reset_deassert_delay;
};

struct phy_driver___10;

struct phy_device___10 {
	struct mdio_device___10 mdio;
	struct phy_driver___10 *drv;
	u32 phy_id;
	struct phy_c45_device_ids c45_ids;
	unsigned int is_c45: 1;
	unsigned int is_internal: 1;
	unsigned int is_pseudo_fixed_link: 1;
	unsigned int has_fixups: 1;
	unsigned int suspended: 1;
	unsigned int sysfs_links: 1;
	unsigned int loopback_enabled: 1;
	unsigned int autoneg: 1;
	unsigned int link: 1;
	enum phy_state state;
	u32 dev_flags;
	phy_interface_t interface;
	int speed;
	int duplex;
	int pause;
	int asym_pause;
	u32 interrupts;
	u32 rh_reserved_supported;
	u32 rh_reserved_advertising;
	u32 rh_reserved_lp_advertising;
	u32 eee_broken_modes;
	int link_timeout;
	struct phy_led_trigger *phy_led_triggers;
	unsigned int phy_num_led_triggers;
	struct phy_led_trigger *last_triggered;
	struct phy_led_trigger *led_link_trigger;
	int irq;
	void *priv;
	struct work_struct phy_queue;
	struct delayed_work state_queue;
	struct mutex lock;
	struct phylink *phylink;
	struct net_device___71 *attached_dev;
	u8 mdix;
	u8 mdix_ctrl;
	long unsigned int supported[2];
	long unsigned int advertising[2];
	long unsigned int lp_advertising[2];
	void (*phy_link_change)(struct phy_device___10 *, bool, bool);
	void (*adjust_link)(struct net_device___71 *);
};

struct napi_gro_cb___3 {
	void *frag0;
	unsigned int frag0_len;
	int data_offset;
	u16 flush;
	u16 flush_id;
	u16 count;
	u16 gro_remcsum_start;
	long unsigned int age;
	u16 proto;
	u8 same_flow: 1;
	u8 encap_mark: 1;
	u8 csum_valid: 1;
	u8 csum_cnt: 3;
	u8 free: 2;
	u8 is_ipv6: 1;
	u8 is_fou: 1;
	u8 is_atomic: 1;
	u8 recursion_counter: 4;
	__wsum csum;
	struct sk_buff___72 *last;
};

typedef struct sk_buff___72 ** (*gro_receive_t)(struct sk_buff___72 **, struct sk_buff___72 *);

struct offload_callbacks___6 {
	struct sk_buff___72 * (*gso_segment)(struct sk_buff___72 *, netdev_features_t);
	struct sk_buff___72 ** (*gro_receive)(struct sk_buff___72 **, struct sk_buff___72 *);
	int (*gro_complete)(struct sk_buff___72 *, int);
};

struct packet_offload___2 {
	__be16 type;
	u16 priority;
	struct offload_callbacks___6 callbacks;
	struct list_head list;
};

struct softnet_data___70 {
	struct list_head poll_list;
	struct sk_buff_head___70 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___70 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___62 *output_queue;
	struct Qdisc___62 **output_queue_tailp;
	struct sk_buff___72 *completion_queue;
	struct sk_buff_head___70 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___70 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___70 input_pkt_queue;
	struct napi_struct___70 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct property___96 {
	char *name;
	int length;
	void *value;
	struct property___96 *next;
	long unsigned int _flags;
	struct bin_attribute___389 attr;
};

struct pci_bus___37;

struct pci_slot___37 {
	struct pci_bus___37 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject___413 kobj;
};

struct pci_dev___38;

struct pci_ops___37;

struct pci_bus___37 {
	struct list_head node;
	struct pci_bus___37 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___38 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___37 *ops;
	struct msi_controller___2 *msi;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	int domain_nr;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___393 *bridge;
	struct device___393 dev;
	struct bin_attribute___389 *legacy_io;
	struct bin_attribute___389 *legacy_mem;
	unsigned int is_added: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
};

struct pci_driver___37;

struct pci_dev___38 {
	struct list_head bus_list;
	struct pci_bus___37 *bus;
	struct pci_bus___37 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___37 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u16 aer_cap;
	struct aer_stats *aer_stats;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	long unsigned int *dma_alias_mask;
	struct pci_driver___37 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	unsigned int imm_ready: 1;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int bridge_d3: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int hotplug_user_indicators: 1;
	unsigned int clear_retrain_link: 1;
	unsigned int d3_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	unsigned int ltr_path: 1;
	unsigned int eetlp_prefix_path: 1;
	pci_channel_state_t error_state;
	struct device___393 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int multifunction: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int ats_enabled: 1;
	unsigned int pasid_enabled: 1;
	unsigned int pri_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int reset_fn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int shpc_managed: 1;
	unsigned int is_thunderbolt: 1;
	unsigned int __aer_firmware_first_valid: 1;
	unsigned int __aer_firmware_first: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int irq_managed: 1;
	unsigned int has_secondary_link: 1;
	unsigned int non_compliant_bars: 1;
	unsigned int is_probed: 1;
	unsigned int link_active_reporting: 1;
	unsigned int untrusted: 1;
	unsigned int no_vf_scan: 1;
	unsigned int io_window: 1;
	unsigned int pref_window: 1;
	unsigned int pref_64_window: 1;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	struct bin_attribute___389 *rom_attr;
	int rom_attr_enabled;
	struct bin_attribute___389 *res_attr[17];
	struct bin_attribute___389 *res_attr_wc[17];
	unsigned int broken_cmd_compl: 1;
	const struct attribute_group___390 **msi_irq_groups;
	struct pci_vpd *vpd;
	union {
		struct pci_sriov *sriov;
		struct pci_dev___38 *physfn;
	};
	u16 ats_cap;
	u8 ats_stu;
	atomic_t ats_ref_cnt;
	u32 pri_reqs_alloc;
	u16 pasid_features;
	struct pci_p2pdma *p2pdma;
	phys_addr_t rom;
	size_t romlen;
	char *driver_override;
	long unsigned int priv_flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t pci_dev_extended_size_rh;
	struct pci_dev_extended_rh pci_dev_extended_rh;
};

struct pci_error_handlers___37;

struct pci_driver___37 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___38 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___38 *);
	int (*suspend)(struct pci_dev___38 *, pm_message_t);
	int (*suspend_late)(struct pci_dev___38 *, pm_message_t);
	int (*resume_early)(struct pci_dev___38 *);
	int (*resume)(struct pci_dev___38 *);
	void (*shutdown)(struct pci_dev___38 *);
	int (*sriov_configure)(struct pci_dev___38 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	const struct pci_error_handlers___37 *err_handler;
	const struct attribute_group___390 **groups;
	struct device_driver___393 driver;
	struct pci_dynids dynids;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct pci_ops___37 {
	int (*add_bus)(struct pci_bus___37 *);
	void (*remove_bus)(struct pci_bus___37 *);
	void * (*map_bus)(struct pci_bus___37 *, unsigned int, int);
	int (*read)(struct pci_bus___37 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___37 *, unsigned int, int, int, u32);
};

struct pci_error_handlers___37 {
	pci_ers_result_t (*error_detected)(struct pci_dev___38 *, enum pci_channel_state);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___38 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___38 *);
	void (*reset_prepare)(struct pci_dev___38 *);
	void (*reset_done)(struct pci_dev___38 *);
	void (*resume)(struct pci_dev___38 *);
};

struct pneigh_entry___52;

struct neigh_hash_table___52;

struct neigh_table___52 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___71 *, __u32 *);
	bool (*key_eq)(const struct neighbour___52 *, const void *);
	int (*constructor)(struct neighbour___52 *);
	int (*pconstructor)(struct pneigh_entry___52 *);
	void (*pdestructor)(struct pneigh_entry___52 *);
	void (*proxy_redo)(struct sk_buff___72 *);
	char *id;
	struct neigh_parms___52 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___70 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___52 *nht;
	struct pneigh_entry___52 **phash_buckets;
};

struct neigh_ops___52 {
	int family;
	void (*solicit)(struct neighbour___52 *, struct sk_buff___72 *);
	void (*error_report)(struct neighbour___52 *, struct sk_buff___72 *);
	int (*output)(struct neighbour___52 *, struct sk_buff___72 *);
	int (*connected_output)(struct neighbour___52 *, struct sk_buff___72 *);
};

struct pneigh_entry___52 {
	struct pneigh_entry___52 *next;
	possible_net_t___72 net;
	struct net_device___71 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___52 {
	struct neighbour___52 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct bdi_writeback_congested___217 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___217 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___217 {
	struct bio___217 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___219 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___219 bip_inline_vecs[0];
};

struct bio_set___217 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___217 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___160 {
	struct mem_cgroup___160 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___160 {
	struct lruvec___426 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___160 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___160 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct gnet_dump___62 {
	spinlock_t *lock;
	struct sk_buff___72 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___62;

struct Qdisc_ops___62 {
	struct Qdisc_ops___62 *next;
	const struct Qdisc_class_ops___62 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___72 *, struct Qdisc___62 *, struct sk_buff___72 **);
	struct sk_buff___72 * (*dequeue)(struct Qdisc___62 *);
	struct sk_buff___72 * (*peek)(struct Qdisc___62 *);
	int (*init)(struct Qdisc___62 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___62 *);
	void (*destroy)(struct Qdisc___62 *);
	int (*change)(struct Qdisc___62 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___62 *);
	int (*change_tx_queue_len)(struct Qdisc___62 *, unsigned int);
	int (*dump)(struct Qdisc___62 *, struct sk_buff___72 *);
	int (*dump_stats)(struct Qdisc___62 *, struct gnet_dump___62 *);
	void (*ingress_block_set)(struct Qdisc___62 *, u32);
	void (*egress_block_set)(struct Qdisc___62 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___62 *);
	u32 (*egress_block_get)(struct Qdisc___62 *);
	struct module___355 *owner;
};

struct qdisc_walker___6;

struct tcf_block___62;

struct Qdisc_class_ops___62 {
	unsigned int flags;
	struct netdev_queue___70 * (*select_queue)(struct Qdisc___62 *, struct tcmsg *);
	int (*graft)(struct Qdisc___62 *, long unsigned int, struct Qdisc___62 *, struct Qdisc___62 **, struct netlink_ext_ack *);
	struct Qdisc___62 * (*leaf)(struct Qdisc___62 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___62 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___62 *, u32);
	int (*change)(struct Qdisc___62 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___62 *, long unsigned int);
	void (*walk)(struct Qdisc___62 *, struct qdisc_walker___6 *);
	struct tcf_block___62 * (*tcf_block)(struct Qdisc___62 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___62 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___62 *, long unsigned int);
	int (*dump)(struct Qdisc___62 *, long unsigned int, struct sk_buff___72 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___62 *, long unsigned int, struct gnet_dump___62 *);
};

struct qdisc_walker___6 {
	int stop;
	int skip;
	int count;
	int (*fn)(struct Qdisc___62 *, long unsigned int, struct qdisc_walker___6 *);
};

struct tcf_chain___62;

struct tcf_block___62 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___82 *net;
	struct Qdisc___62 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___62 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___62;

struct tcf_proto_ops___62;

struct tcf_proto___62 {
	struct tcf_proto___62 *next;
	void *root;
	int (*classify)(struct sk_buff___72 *, const struct tcf_proto___62 *, struct tcf_result___62 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___62 *ops;
	struct tcf_chain___62 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___62 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___62 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___62 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___72 *, const struct tcf_proto___62 *, struct tcf_result___62 *);
	int (*init)(struct tcf_proto___62 *);
	void (*destroy)(struct tcf_proto___62 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___62 *, u32);
	void (*put)(struct tcf_proto___62 *, void *);
	int (*change)(struct net___82 *, struct sk_buff___72 *, struct tcf_proto___62 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___62 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___62 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___62 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___82 *, struct tcf_chain___62 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___82 *, struct tcf_proto___62 *, void *, struct sk_buff___72 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___72 *, struct net___82 *, void *);
	struct module___355 *owner;
	int flags;
};

struct tcf_chain___62 {
	struct mutex filter_chain_lock;
	struct tcf_proto___62 *filter_chain;
	struct list_head list;
	struct tcf_block___62 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___62 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___52 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___62 *prog;
};

struct bpf_redirect_info___62 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___275 *map;
	struct bpf_map___275 *map_to_flush;
	u32 kern_flags;
};

struct fib_rule___52 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___52 *ctarget;
	struct net___82 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___52 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___52 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___36;

struct timewait_sock_ops___33;

struct proto___52 {
	void (*close)(struct sock___53 *, long int);
	int (*pre_connect)(struct sock___53 *, struct sockaddr *, int);
	int (*connect)(struct sock___53 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___53 *, int);
	struct sock___53 * (*accept)(struct sock___53 *, int, int *, bool);
	int (*ioctl)(struct sock___53 *, int, long unsigned int);
	int (*init)(struct sock___53 *);
	void (*destroy)(struct sock___53 *);
	void (*shutdown)(struct sock___53 *, int);
	int (*setsockopt)(struct sock___53 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___53 *, int, int, char *, int *);
	void (*keepalive)(struct sock___53 *, int);
	int (*sendmsg)(struct sock___53 *, struct msghdr___55 *, size_t);
	int (*recvmsg)(struct sock___53 *, struct msghdr___55 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___53 *, struct page___426 *, int, size_t, int);
	int (*bind)(struct sock___53 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___53 *, struct sk_buff___72 *);
	void (*release_cb)(struct sock___53 *);
	int (*hash)(struct sock___53 *);
	void (*unhash)(struct sock___53 *);
	void (*rehash)(struct sock___53 *);
	int (*get_port)(struct sock___53 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___53 *);
	bool (*stream_memory_read)(const struct sock___53 *);
	void (*enter_memory_pressure)(struct sock___53 *);
	void (*leave_memory_pressure)(struct sock___53 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___36 *rsk_prot;
	struct timewait_sock_ops___33 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___355 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___53 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct request_sock___37;

struct request_sock_ops___36 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___53 *, struct request_sock___37 *);
	void (*send_ack)(const struct sock___53 *, struct sk_buff___72 *, struct request_sock___37 *);
	void (*send_reset)(const struct sock___53 *, struct sk_buff___72 *);
	void (*destructor)(struct request_sock___37 *);
	void (*syn_ack_timeout)(const struct request_sock___37 *);
};

struct timewait_sock_ops___33 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___53 *, struct sock___53 *, void *);
	void (*twsk_destructor)(struct sock___53 *);
};

struct request_sock___37 {
	struct sock_common___52 __req_common;
	struct request_sock___37 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___36 *rsk_ops;
	struct sock___53 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___30 {
	struct in6_addr mca_addr;
	struct inet6_dev___30 *idev;
	struct ifmcaddr6___30 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ip6_ra_chain___30 {
	struct ip6_ra_chain___30 *next;
	struct sock___53 *sk;
	int sel;
	void (*destructor)(struct sock___53 *);
};

struct mii_bus___10 {
	struct module___355 *owner;
	const char *name;
	char id[61];
	void *priv;
	int (*read)(struct mii_bus___10 *, int, int);
	int (*write)(struct mii_bus___10 *, int, int, u16);
	int (*reset)(struct mii_bus___10 *);
	struct mutex mdio_lock;
	struct device___393 *parent;
	enum {
		MDIOBUS_ALLOCATED___10 = 1,
		MDIOBUS_REGISTERED___10 = 2,
		MDIOBUS_UNREGISTERED___10 = 3,
		MDIOBUS_RELEASED___10 = 4,
	} state;
	struct device___393 dev;
	struct mdio_device___10 *mdio_map[32];
	u32 phy_mask;
	u32 phy_ignore_ta_mask;
	int irq[32];
	int reset_delay_us;
	struct gpio_desc *reset_gpiod;
};

struct mdio_driver_common___10 {
	struct device_driver___393 driver;
	int flags;
};

struct phy_driver___10 {
	struct mdio_driver_common___10 mdiodrv;
	u32 phy_id;
	char *name;
	u32 phy_id_mask;
	u32 rh_reserved_features;
	u32 flags;
	const void *driver_data;
	const long unsigned int * const features;
	int (*soft_reset)(struct phy_device___10 *);
	int (*config_init)(struct phy_device___10 *);
	int (*probe)(struct phy_device___10 *);
	int (*suspend)(struct phy_device___10 *);
	int (*resume)(struct phy_device___10 *);
	int (*config_aneg)(struct phy_device___10 *);
	int (*aneg_done)(struct phy_device___10 *);
	int (*read_status)(struct phy_device___10 *);
	int (*ack_interrupt)(struct phy_device___10 *);
	int (*config_intr)(struct phy_device___10 *);
	int (*did_interrupt)(struct phy_device___10 *);
	void (*remove)(struct phy_device___10 *);
	int (*match_phy_device)(struct phy_device___10 *);
	int (*ts_info)(struct phy_device___10 *, struct ethtool_ts_info *);
	int (*hwtstamp)(struct phy_device___10 *, struct ifreq *);
	bool (*rxtstamp)(struct phy_device___10 *, struct sk_buff___72 *, int);
	void (*txtstamp)(struct phy_device___10 *, struct sk_buff___72 *, int);
	int (*set_wol)(struct phy_device___10 *, struct ethtool_wolinfo *);
	void (*get_wol)(struct phy_device___10 *, struct ethtool_wolinfo *);
	void (*link_change_notify)(struct phy_device___10 *);
	int (*read_mmd)(struct phy_device___10 *, int, u16);
	int (*write_mmd)(struct phy_device___10 *, int, u16, u16);
	int (*read_page)(struct phy_device___10 *);
	int (*write_page)(struct phy_device___10 *, int);
	int (*module_info)(struct phy_device___10 *, struct ethtool_modinfo *);
	int (*module_eeprom)(struct phy_device___10 *, struct ethtool_eeprom *, u8 *);
	int (*get_sset_count)(struct phy_device___10 *);
	void (*get_strings)(struct phy_device___10 *, u8 *);
	void (*get_stats)(struct phy_device___10 *, struct ethtool_stats *, u64 *);
	int (*get_tunable)(struct phy_device___10 *, struct ethtool_tunable *, void *);
	int (*set_tunable)(struct phy_device___10 *, struct ethtool_tunable *, const void *);
	int (*set_loopback)(struct phy_device___10 *, bool);
};

struct switchdev_attr___3 {
	struct net_device___71 *orig_dev;
	enum switchdev_attr_id id;
	u32 flags;
	void *complete_priv;
	void (*complete)(struct net_device___71 *, int, void *);
	union {
		struct netdev_phys_item_id ppid;
		u8 stp_state;
		long unsigned int brport_flags;
		long unsigned int brport_flags_support;
		bool mrouter;
		clock_t ageing_time;
		bool vlan_filtering;
		bool mc_disabled;
	} u;
};

struct switchdev_obj___3 {
	struct net_device___71 *orig_dev;
	enum switchdev_obj_id id;
	u32 flags;
	void *complete_priv;
	void (*complete)(struct net_device___71 *, int, void *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct fch_hdr {
	__u8 daddr[6];
	__u8 saddr[6];
};

struct fcllc {
	__u8 dsap;
	__u8 ssap;
	__u8 llc;
	__u8 protid[3];
	__be16 ethertype;
};

struct module___356;

struct file___426;

struct kiocb___426;

struct iov_iter___193;

struct poll_table_struct___267;

struct vm_area_struct___427;

struct inode___426;

struct file_lock___426;

struct page___427;

struct pipe_inode_info___107;

struct seq_file___365;

struct file_operations___426 {
	struct module___356 *owner;
	loff_t (*llseek)(struct file___426 *, loff_t, int);
	ssize_t (*read)(struct file___426 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___426 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___426 *, struct iov_iter___193 *);
	ssize_t (*write_iter)(struct kiocb___426 *, struct iov_iter___193 *);
	int (*iopoll)(struct kiocb___426 *, bool);
	int (*iterate)(struct file___426 *, struct dir_context *);
	int (*iterate_shared)(struct file___426 *, struct dir_context *);
	__poll_t (*poll)(struct file___426 *, struct poll_table_struct___267 *);
	long int (*unlocked_ioctl)(struct file___426 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___426 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___426 *, struct vm_area_struct___427 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___426 *, struct file___426 *);
	int (*flush)(struct file___426 *, fl_owner_t);
	int (*release)(struct inode___426 *, struct file___426 *);
	int (*fsync)(struct file___426 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___426 *, int);
	int (*lock)(struct file___426 *, int, struct file_lock___426 *);
	ssize_t (*sendpage)(struct file___426 *, struct page___427 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___426 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___426 *, int, struct file_lock___426 *);
	ssize_t (*splice_write)(struct pipe_inode_info___107 *, struct file___426 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___426 *, loff_t *, struct pipe_inode_info___107 *, size_t, unsigned int);
	int (*setlease)(struct file___426 *, long int, struct file_lock___426 **, void **);
	long int (*fallocate)(struct file___426 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___365 *, struct file___426 *);
	ssize_t (*copy_file_range)(struct file___426 *, loff_t, struct file___426 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___426 *, loff_t, struct file___426 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___426 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___427 {
	u64 seqnum;
	struct vm_area_struct___427 *vmas[4];
};

struct page_frag___427 {
	struct page___427 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___427;

struct mem_cgroup___161;

struct pid___241;

struct cred___394;

struct nsproxy___321;

struct signal_struct___301;

struct bio_list___218;

struct backing_dev_info___218;

struct css_set___275;

struct vm_struct___330;

struct task_struct___428 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___428 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___427 *mm;
	struct mm_struct___427 *active_mm;
	struct vmacache___427 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___428 *real_parent;
	struct task_struct___428 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___428 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___161 *active_memcg;
	long int rh_reserved2;
	struct pid___241 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___241 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___241 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___394 *ptracer_cred;
	const struct cred___394 *real_cred;
	const struct cred___394 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___321 *nsproxy;
	struct signal_struct___301 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___428 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___218 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___218 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___275 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___107 *splice_pipe;
	struct page_frag___427 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___161 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___428 *oom_reaper_list;
	struct vm_struct___330 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___156 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rw_semaphore___428 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___428 *owner;
};

struct key___394;

struct ucounts___291;

struct user_namespace___291 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___291 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___29 ns;
	long unsigned int flags;
	struct key___394 *persistent_keyring_register;
	struct rw_semaphore___428 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___291 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___427 *pgtable_t___427;

struct address_space___426;

struct dev_pagemap___414;

struct page___427 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___426 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___427 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___427 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___427 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___414 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___161 *mem_cgroup;
};

struct pglist_data___427;

struct lruvec___427 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___427 *pgdat;
};

struct zone___427 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___427 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___427 {
	struct zone___427 *zone;
	int zone_idx;
};

struct zonelist___427 {
	struct zoneref___427 _zonerefs[25];
};

struct pglist_data___427 {
	struct zone___427 node_zones[3];
	struct zonelist___427 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___428 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___428 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___427 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___428 {
	void *stack;
	struct task_struct___428 *task;
	long int status;
};

struct blocking_notifier_head___427 {
	struct rw_semaphore___428 rwsem;
	struct notifier_block *head;
};

struct dentry___426;

struct path___427 {
	struct vfsmount *mnt;
	struct dentry___426 *dentry;
};

struct fown_struct___241 {
	rwlock_t lock;
	struct pid___241 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___426 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___427 f_path;
	struct inode___426 *f_inode;
	const struct file_operations___426 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___241 f_owner;
	const struct cred___394 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___426 *f_mapping;
	errseq_t f_wb_err;
};

struct user_struct___394;

struct cred___394 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___394 *session_keyring;
	struct key___394 *process_keyring;
	struct key___394 *thread_keyring;
	struct key___394 *request_key_auth;
	void *security;
	struct user_struct___394 *user;
	struct user_namespace___291 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___420;

struct kernfs_elem_dir___420 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___420 *root;
};

struct kernfs_node___421;

struct kernfs_syscall_ops___420;

struct kernfs_root___420 {
	struct kernfs_node___421 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___420 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___420 {
	struct kernfs_node___421 *target_kn;
};

struct kernfs_ops___420;

struct kernfs_elem_attr___420 {
	const struct kernfs_ops___420 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___421 *notify_next;
};

struct kernfs_node___421 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___421 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___420 dir;
		struct kernfs_elem_symlink___420 symlink;
		struct kernfs_elem_attr___420 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___420;

struct kernfs_ops___420 {
	int (*open)(struct kernfs_open_file___420 *);
	void (*release)(struct kernfs_open_file___420 *);
	int (*seq_show)(struct seq_file___365 *, void *);
	void * (*seq_start)(struct seq_file___365 *, loff_t *);
	void * (*seq_next)(struct seq_file___365 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___365 *, void *);
	ssize_t (*read)(struct kernfs_open_file___420 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___420 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___420 *, struct vm_area_struct___427 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___420 *, struct poll_table_struct___267 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___420 {
	int (*remount_fs)(struct kernfs_root___420 *, int *, char *);
	int (*show_options)(struct seq_file___365 *, struct kernfs_root___420 *);
	int (*mkdir)(struct kernfs_node___421 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___421 *);
	int (*rename)(struct kernfs_node___421 *, struct kernfs_node___421 *, const char *);
	int (*show_path)(struct seq_file___365 *, struct kernfs_node___421 *, struct kernfs_root___420 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___365;

struct seq_file___365 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___365 *op;
	int poll_event;
	const struct file___426 *file;
	void *private;
};

struct vm_operations_struct___414;

struct kernfs_open_file___420 {
	struct kernfs_node___421 *kn;
	struct file___426 *file;
	struct seq_file___365 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___414 *vm_ops;
};

struct vm_fault___414;

struct vm_operations_struct___414 {
	void (*open)(struct vm_area_struct___427 *);
	void (*close)(struct vm_area_struct___427 *);
	int (*split)(struct vm_area_struct___427 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___427 *);
	vm_fault_t (*fault)(struct vm_fault___414 *);
	vm_fault_t (*huge_fault)(struct vm_fault___414 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___414 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___427 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___414 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___414 *);
	int (*access)(struct vm_area_struct___427 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___427 *);
	int (*set_policy)(struct vm_area_struct___427 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___427 *, long unsigned int);
	struct page___427 * (*find_special_page)(struct vm_area_struct___427 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___277)(struct file___426 *, wait_queue_head_t *, struct poll_table_struct___267 *);

struct poll_table_struct___267 {
	poll_queue_proc___277 _qproc;
	__poll_t _key;
};

struct vm_area_struct___427 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___427 *vm_next;
	struct vm_area_struct___427 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___427 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___414 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___426 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sock___54;

struct kobj_ns_type_operations___53 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___54 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct net___83;

typedef struct {
	struct net___83 *net;
} possible_net_t___73;

struct proto___53;

struct sock_common___53 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___53 *skc_prot;
	possible_net_t___73 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___54 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___73;

struct sk_buff_head___71 {
	struct sk_buff___73 *next;
	struct sk_buff___73 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___53;

struct socket_wq___54;

struct xfrm_policy___7;

struct dst_entry___53;

struct socket___55;

struct net_device___72;

struct sock___54 {
	struct sock_common___53 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___71 sk_error_queue;
	struct sk_buff_head___71 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___73 *head;
		struct sk_buff___73 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___53 *sk_filter;
	union {
		struct socket_wq___54 *sk_wq;
		struct socket_wq___54 *sk_wq_raw;
	};
	struct xfrm_policy___7 *sk_policy[2];
	struct dst_entry___53 *sk_rx_dst;
	struct dst_entry___53 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___73 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___71 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___427 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___53 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___241 *sk_peer_pid;
	const struct cred___394 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___55 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___161 *sk_memcg;
	void (*sk_state_change)(struct sock___54 *);
	void (*sk_data_ready)(struct sock___54 *);
	void (*sk_write_space)(struct sock___54 *);
	void (*sk_error_report)(struct sock___54 *);
	int (*sk_backlog_rcv)(struct sock___54 *, struct sk_buff___73 *);
	struct sk_buff___73 * (*sk_validate_xmit_skb)(struct sock___54 *, struct net_device___72 *, struct sk_buff___73 *);
	void (*sk_destruct)(struct sock___54 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kobject___414;

struct bin_attribute___390;

struct attribute_group___391 {
	const char *name;
	umode_t (*is_visible)(struct kobject___414 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___414 *, struct bin_attribute___390 *, int);
	struct attribute **attrs;
	struct bin_attribute___390 **bin_attrs;
};

struct kset___413;

struct kobj_type___413;

struct kobject___414 {
	const char *name;
	struct list_head entry;
	struct kobject___414 *parent;
	struct kset___413 *kset;
	struct kobj_type___413 *ktype;
	struct kernfs_node___421 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___390 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___426 *, struct kobject___414 *, struct bin_attribute___390 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___426 *, struct kobject___414 *, struct bin_attribute___390 *, char *, loff_t, size_t);
	int (*mmap)(struct file___426 *, struct kobject___414 *, struct bin_attribute___390 *, struct vm_area_struct___427 *);
};

struct sysfs_ops___413 {
	ssize_t (*show)(struct kobject___414 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___414 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___413;

struct kset___413 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___414 kobj;
	const struct kset_uevent_ops___413 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___413 {
	void (*release)(struct kobject___414 *);
	const struct sysfs_ops___413 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___53 * (*child_ns_type)(struct kobject___414 *);
	const void * (*namespace)(struct kobject___414 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___413 {
	int (* const filter)(struct kset___413 *, struct kobject___414 *);
	const char * (* const name)(struct kset___413 *, struct kobject___414 *);
	int (* const uevent)(struct kset___413 *, struct kobject___414 *, struct kobj_uevent_env *);
};

struct kobj_attribute___404 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___414 *, struct kobj_attribute___404 *, char *);
	ssize_t (*store)(struct kobject___414 *, struct kobj_attribute___404 *, const char *, size_t);
};

struct kernel_param___354;

struct kernel_param_ops___354 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___354 *);
	int (*get)(char *, const struct kernel_param___354 *);
	void (*free)(void *);
};

struct kparam_array___354;

struct kernel_param___354 {
	const char *name;
	struct module___356 *mod;
	const struct kernel_param_ops___354 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___354 *arr;
	};
};

struct kparam_array___354 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___354 *ops;
	void *elem;
};

struct module_kobject___354 {
	struct kobject___414 kobj;
	struct module___356 *mod;
	struct kobject___414 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___354 {
	struct module___356 *mod;
	struct latch_tree_node node;
};

struct module_layout___354 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___354 mtn;
};

struct module_attribute___354;

struct module___356 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___354 mkobj;
	struct module_attribute___354 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___414 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___354 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___354 core_layout;
	struct module_layout___354 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___354 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___354 *, struct module_kobject___354 *, char *);
	ssize_t (*store)(struct module_attribute___354 *, struct module_kobject___354 *, const char *, size_t);
	void (*setup)(struct module___356 *, const char *);
	int (*test)(struct module___356 *);
	void (*free)(struct module___356 *);
};

struct pid_namespace___241;

struct upid___241 {
	int nr;
	struct pid_namespace___241 *ns;
};

struct pid_namespace___241 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___428 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___241 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___426 *proc_self;
	struct dentry___426 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___291 *user_ns;
	struct ucounts___291 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___29 ns;
};

struct pid___241 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___241 numbers[1];
};

struct user_struct___394 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___394 *uid_keyring;
	struct key___394 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___427;

struct mm_struct___427 {
	struct {
		struct vm_area_struct___427 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___426 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___428 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___427 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___428 *owner;
		struct user_namespace___291 *user_ns;
		struct file___426 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___427 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup___275;

struct cgroup_subsys___275;

struct cgroup_subsys_state___275 {
	struct cgroup___275 *cgroup;
	struct cgroup_subsys___275 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___275 *parent;
};

struct cgroup_file___275 {
	struct kernfs_node___421 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___161;

struct mem_cgroup___161 {
	struct cgroup_subsys_state___275 css;
	struct mem_cgroup_id___21 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___275 events_file;
	struct cgroup_file___275 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___428 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___161 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cgroup_namespace___275;

struct nsproxy___321 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___241 *pid_ns_for_children;
	struct net___83 *net_ns;
	struct cgroup_namespace___275 *cgroup_ns;
};

struct signal_struct___301 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___428 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___428 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___241 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___241 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___427 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___241 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___218;

struct bio_list___218 {
	struct bio___218 *head;
	struct bio___218 *tail;
};

struct bdi_writeback_congested___218;

struct bdi_writeback___218 {
	struct backing_dev_info___218 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___218 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___275 *memcg_css;
	struct cgroup_subsys_state___275 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___394;

struct backing_dev_info___218 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___218 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___394 *dev;
	struct device___394 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___426 *debug_dir;
	struct dentry___426 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___275 {
	struct cgroup_subsys_state___275 *subsys[13];
	refcount_t refcount;
	struct css_set___275 *dom_cset;
	struct cgroup___275 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___275 *mg_src_cgrp;
	struct cgroup___275 *mg_dst_cgrp;
	struct css_set___275 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___426;

struct pipe_buffer___107;

struct pipe_inode_info___107 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___427 *tmp_page;
	struct fasync_struct___426 *fasync_readers;
	struct fasync_struct___426 *fasync_writers;
	struct pipe_buffer___107 *bufs;
	struct user_struct___394 *user;
};

struct vm_struct___330 {
	struct vm_struct___330 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___427 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___313 {
	struct task_struct___428 task;
	long unsigned int stack[8192];
};

struct address_space_operations___426;

struct address_space___426 {
	struct inode___426 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___428 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___426 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___414)(struct vm_area_struct___427 *, long unsigned int, const struct page___427 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___414)(struct page___427 *, void *);

struct dev_pagemap___414 {
	dev_page_fault_t___414 page_fault;
	dev_page_free_t___414 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___394 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___427 {
	struct task_struct___428 *task;
	struct core_thread___427 *next;
};

struct core_state___427 {
	atomic_t nr_threads;
	struct core_thread___427 dumper;
	struct completion startup;
};

struct vm_fault___414 {
	struct vm_area_struct___427 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___427 *cow_page;
	struct mem_cgroup___161 *memcg;
	struct page___427 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___427 prealloc_pte;
};

struct bio_vec___220 {
	struct page___427 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___193 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___220 *bvec;
		struct pipe_inode_info___107 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct msghdr___56 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___193 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___426 *msg_iocb;
};

struct kiocb___426 {
	struct file___426 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___426 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dentry_operations___426;

struct super_block___426;

struct dentry___426 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___426 *d_parent;
	struct qstr d_name;
	struct inode___426 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___426 *d_op;
	struct super_block___426 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___426;

struct block_device___426;

struct inode___426 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___426 *i_op;
	struct super_block___426 *i_sb;
	struct address_space___426 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___428 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___218 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___426 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___426 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___107 *i_pipe;
		struct block_device___426 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___426 {
	int (*d_revalidate)(struct dentry___426 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___426 *, unsigned int);
	int (*d_hash)(const struct dentry___426 *, struct qstr *);
	int (*d_compare)(const struct dentry___426 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___426 *);
	int (*d_init)(struct dentry___426 *);
	void (*d_release)(struct dentry___426 *);
	void (*d_prune)(struct dentry___426 *);
	void (*d_iput)(struct dentry___426 *, struct inode___426 *);
	char * (*d_dname)(struct dentry___426 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___427 *);
	int (*d_manage)(const struct path___427 *, bool);
	struct dentry___426 * (*d_real)(struct dentry___426 *, const struct inode___426 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___426;

struct mem_dqinfo___426 {
	struct quota_format_type___426 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___426;

struct quota_info___426 {
	unsigned int flags;
	struct rw_semaphore___428 dqio_sem;
	struct inode___426 *files[3];
	struct mem_dqinfo___426 info[3];
	const struct quota_format_ops___426 *ops[3];
};

struct rcuwait___426 {
	struct task_struct___428 *task;
};

struct percpu_rw_semaphore___426 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___428 rw_sem;
	struct rcuwait___426 writer;
	int readers_block;
};

struct sb_writers___426 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___426 rw_sem[3];
};

struct shrink_control___161;

struct shrinker___161 {
	long unsigned int (*count_objects)(struct shrinker___161 *, struct shrink_control___161 *);
	long unsigned int (*scan_objects)(struct shrinker___161 *, struct shrink_control___161 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___426;

struct super_operations___426;

struct dquot_operations___426;

struct quotactl_ops___426;

struct super_block___426 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___426 *s_type;
	const struct super_operations___426 *s_op;
	const struct dquot_operations___426 *dq_op;
	const struct quotactl_ops___426 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___426 *s_root;
	struct rw_semaphore___428 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___426 *s_bdev;
	struct backing_dev_info___218 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___426 s_dquot;
	struct sb_writers___426 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___426 *s_d_op;
	int cleancache_poolid;
	struct shrinker___161 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___291 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___161 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___161 *memcg;
};

struct iattr___426 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___426 *ia_file;
};

struct dquot___426 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___426 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___426 {
	int qf_fmt_id;
	const struct quota_format_ops___426 *qf_ops;
	struct module___356 *qf_owner;
	struct quota_format_type___426 *qf_next;
};

struct quota_format_ops___426 {
	int (*check_quota_file)(struct super_block___426 *, int);
	int (*read_file_info)(struct super_block___426 *, int);
	int (*write_file_info)(struct super_block___426 *, int);
	int (*free_file_info)(struct super_block___426 *, int);
	int (*read_dqblk)(struct dquot___426 *);
	int (*commit_dqblk)(struct dquot___426 *);
	int (*release_dqblk)(struct dquot___426 *);
	int (*get_next_id)(struct super_block___426 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___426 {
	int (*write_dquot)(struct dquot___426 *);
	struct dquot___426 * (*alloc_dquot)(struct super_block___426 *, int);
	void (*destroy_dquot)(struct dquot___426 *);
	int (*acquire_dquot)(struct dquot___426 *);
	int (*release_dquot)(struct dquot___426 *);
	int (*mark_dirty)(struct dquot___426 *);
	int (*write_info)(struct super_block___426 *, int);
	qsize_t * (*get_reserved_space)(struct inode___426 *);
	int (*get_projid)(struct inode___426 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___426 *, qsize_t *);
	int (*get_next_id)(struct super_block___426 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___426 {
	int (*quota_on)(struct super_block___426 *, int, int, const struct path___427 *);
	int (*quota_off)(struct super_block___426 *, int);
	int (*quota_enable)(struct super_block___426 *, unsigned int);
	int (*quota_disable)(struct super_block___426 *, unsigned int);
	int (*quota_sync)(struct super_block___426 *, int);
	int (*set_info)(struct super_block___426 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___426 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___426 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___426 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___426 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___426 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___181;

struct address_space_operations___426 {
	int (*writepage)(struct page___427 *, struct writeback_control___181 *);
	int (*readpage)(struct file___426 *, struct page___427 *);
	int (*writepages)(struct address_space___426 *, struct writeback_control___181 *);
	int (*set_page_dirty)(struct page___427 *);
	int (*readpages)(struct file___426 *, struct address_space___426 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___426 *, struct address_space___426 *, loff_t, unsigned int, unsigned int, struct page___427 **, void **);
	int (*write_end)(struct file___426 *, struct address_space___426 *, loff_t, unsigned int, unsigned int, struct page___427 *, void *);
	sector_t (*bmap)(struct address_space___426 *, sector_t);
	void (*invalidatepage)(struct page___427 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___427 *, gfp_t);
	void (*freepage)(struct page___427 *);
	ssize_t (*direct_IO)(struct kiocb___426 *, struct iov_iter___193 *);
	int (*migratepage)(struct address_space___426 *, struct page___427 *, struct page___427 *, enum migrate_mode);
	bool (*isolate_page)(struct page___427 *, isolate_mode_t);
	void (*putback_page)(struct page___427 *);
	int (*launder_page)(struct page___427 *);
	int (*is_partially_uptodate)(struct page___427 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___427 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___426 *, struct page___427 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___426 *, sector_t *);
	void (*swap_deactivate)(struct file___426 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___181 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___218 *wb;
	struct inode___426 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___426 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___426 *bd_inode;
	struct super_block___426 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___426 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___218 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___426 {
	struct dentry___426 * (*lookup)(struct inode___426 *, struct dentry___426 *, unsigned int);
	const char * (*get_link)(struct dentry___426 *, struct inode___426 *, struct delayed_call *);
	int (*permission)(struct inode___426 *, int);
	struct posix_acl * (*get_acl)(struct inode___426 *, int);
	int (*readlink)(struct dentry___426 *, char *, int);
	int (*create)(struct inode___426 *, struct dentry___426 *, umode_t, bool);
	int (*link)(struct dentry___426 *, struct inode___426 *, struct dentry___426 *);
	int (*unlink)(struct inode___426 *, struct dentry___426 *);
	int (*symlink)(struct inode___426 *, struct dentry___426 *, const char *);
	int (*mkdir)(struct inode___426 *, struct dentry___426 *, umode_t);
	int (*rmdir)(struct inode___426 *, struct dentry___426 *);
	int (*mknod)(struct inode___426 *, struct dentry___426 *, umode_t, dev_t);
	int (*rename)(struct inode___426 *, struct dentry___426 *, struct inode___426 *, struct dentry___426 *, unsigned int);
	int (*setattr)(struct dentry___426 *, struct iattr___426 *);
	int (*getattr)(const struct path___427 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___426 *, char *, size_t);
	int (*fiemap)(struct inode___426 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___426 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___426 *, struct dentry___426 *, struct file___426 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___426 *, struct dentry___426 *, umode_t);
	int (*set_acl)(struct inode___426 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___426 {
	void (*fl_copy_lock)(struct file_lock___426 *, struct file_lock___426 *);
	void (*fl_release_private)(struct file_lock___426 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___426;

struct file_lock___426 {
	struct file_lock___426 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___426 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___426 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___426 *fl_ops;
	const struct lock_manager_operations___426 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___426 {
	int (*lm_compare_owner)(struct file_lock___426 *, struct file_lock___426 *);
	long unsigned int (*lm_owner_key)(struct file_lock___426 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___426 *);
	int (*lm_grant)(struct file_lock___426 *, int);
	bool (*lm_break)(struct file_lock___426 *);
	int (*lm_change)(struct file_lock___426 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___426 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___426 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___426 *fa_next;
	struct file___426 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___426 {
	const char *name;
	int fs_flags;
	struct dentry___426 * (*mount)(struct file_system_type___426 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___426 *);
	struct module___356 *owner;
	struct file_system_type___426 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___426 {
	struct inode___426 * (*alloc_inode)(struct super_block___426 *);
	void (*destroy_inode)(struct inode___426 *);
	void (*dirty_inode)(struct inode___426 *, int);
	int (*write_inode)(struct inode___426 *, struct writeback_control___181 *);
	int (*drop_inode)(struct inode___426 *);
	void (*evict_inode)(struct inode___426 *);
	void (*put_super)(struct super_block___426 *);
	int (*sync_fs)(struct super_block___426 *, int);
	int (*freeze_super)(struct super_block___426 *);
	int (*freeze_fs)(struct super_block___426 *);
	int (*thaw_super)(struct super_block___426 *);
	int (*unfreeze_fs)(struct super_block___426 *);
	int (*statfs)(struct dentry___426 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___426 *, int *, char *);
	void (*umount_begin)(struct super_block___426 *);
	int (*show_options)(struct seq_file___365 *, struct dentry___426 *);
	int (*show_devname)(struct seq_file___365 *, struct dentry___426 *);
	int (*show_path)(struct seq_file___365 *, struct dentry___426 *);
	int (*show_stats)(struct seq_file___365 *, struct dentry___426 *);
	ssize_t (*quota_read)(struct super_block___426 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___426 *, int, const char *, size_t, loff_t);
	struct dquot___426 ** (*get_dquots)(struct inode___426 *);
	int (*bdev_try_to_free_page)(struct super_block___426 *, struct page___427 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___426 *, struct shrink_control___161 *);
	long int (*free_cached_objects)(struct super_block___426 *, struct shrink_control___161 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___218(struct bio___218 *);

struct bio_integrity_payload___218;

struct bio_set___218;

struct bio___218 {
	struct bio___218 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___218 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___218 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___220 *bi_io_vec;
	struct bio_set___218 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___220 bi_inline_vecs[0];
};

struct socket_wq___54 {
	wait_queue_head_t wait;
	struct fasync_struct___426 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___54;

struct socket___55 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___54 *wq;
	struct file___426 *file;
	struct sock___54 *sk;
	const struct proto_ops___54 *ops;
};

typedef int (*sk_read_actor_t___53)(read_descriptor_t *, struct sk_buff___73 *, unsigned int, size_t);

struct proto_ops___54 {
	int family;
	struct module___356 *owner;
	int (*release)(struct socket___55 *);
	int (*bind)(struct socket___55 *, struct sockaddr *, int);
	int (*connect)(struct socket___55 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___55 *, struct socket___55 *);
	int (*accept)(struct socket___55 *, struct socket___55 *, int, bool);
	int (*getname)(struct socket___55 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___426 *, struct socket___55 *, struct poll_table_struct___267 *);
	int (*ioctl)(struct socket___55 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___55 *, int);
	int (*shutdown)(struct socket___55 *, int);
	int (*setsockopt)(struct socket___55 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___55 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___55 *, struct msghdr___56 *, size_t);
	int (*recvmsg)(struct socket___55 *, struct msghdr___56 *, size_t, int);
	int (*mmap)(struct file___426 *, struct socket___55 *, struct vm_area_struct___427 *);
	ssize_t (*sendpage)(struct socket___55 *, struct page___427 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___55 *, loff_t *, struct pipe_inode_info___107 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___54 *, int);
	int (*peek_len)(struct socket___55 *);
	int (*read_sock)(struct sock___54 *, read_descriptor_t *, sk_read_actor_t___53);
	int (*sendpage_locked)(struct sock___54 *, struct page___427 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___54 *, struct msghdr___56 *, size_t);
	int (*set_rcvlowat)(struct sock___54 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct sec_path___7;

struct nf_bridge_info___71;

struct sk_buff___73 {
	union {
		struct {
			struct sk_buff___73 *next;
			struct sk_buff___73 *prev;
			union {
				struct net_device___72 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___54 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___73 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path___7 *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___71 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___71;

struct netns_frags___71 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___71 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ip_ra_chain___27;

struct fib_rules_ops___53;

struct fib_notifier_ops___54;

struct netns_ipv4___71 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___27 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___53 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___54 *fibnl;
	struct sock___54 **icmp_sk;
	struct sock___54 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___54 **tcp_sk;
	struct netns_frags___71 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___53 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___54 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___54 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___53;

struct dst_ops___82 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___82 *);
	struct dst_entry___53 * (*check)(struct dst_entry___53 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___53 *);
	unsigned int (*mtu)(const struct dst_entry___53 *);
	u32 * (*cow_metrics)(struct dst_entry___53 *, long unsigned int);
	void (*destroy)(struct dst_entry___53 *);
	void (*ifdown)(struct dst_entry___53 *, struct net_device___72 *, int);
	struct dst_entry___53 * (*negative_advice)(struct dst_entry___53 *);
	void (*link_failure)(struct sk_buff___73 *);
	void (*update_pmtu)(struct dst_entry___53 *, struct sock___54 *, struct sk_buff___73 *, u32);
	void (*redirect)(struct dst_entry___53 *, struct sock___54 *, struct sk_buff___73 *);
	int (*local_out)(struct net___83 *, struct sock___54 *, struct sk_buff___73 *);
	struct neighbour___53 * (*neigh_lookup)(const struct dst_entry___53 *, struct sk_buff___73 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___53 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_info___10;

struct rt6_info___10;

struct fib6_table___10;

struct netns_ipv6___82 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___71 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info___10 *fib6_null_entry;
	struct rt6_info___10 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___10 *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___82 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info___10 *ip6_prohibit_entry;
	struct rt6_info___10 *ip6_blk_hole_entry;
	struct fib6_table___10 *fib6_local_tbl;
	struct fib_rules_ops___53 *fib6_rules_ops;
	struct sock___54 **icmp_sk;
	struct sock___54 *ndisc_sk;
	struct sock___54 *tcp_sk;
	struct sock___54 *igmp_sk;
	struct sock___54 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___53 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___54 *notifier_ops;
	struct fib_notifier_ops___54 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___54 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___54 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___71 {
	struct netns_frags___71 frags;
};

struct netns_xfrm___82 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___54 *nlsk;
	struct sock___54 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___82 xfrm4_dst_ops;
	struct dst_ops___82 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___63;

struct net___83 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___291 *user_ns;
	struct ucounts___291 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___29 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___54 *rtnl;
	struct sock___54 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___72 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___71 ipv4;
	struct netns_ipv6___82 ipv6;
	struct netns_sctp___54 sctp;
	struct netns_nf___4 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___71 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___54 *nfnl;
	struct sock___54 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___82 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___54 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___63 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___394 {
	int (*prepare)(struct device___394 *);
	void (*complete)(struct device___394 *);
	int (*suspend)(struct device___394 *);
	int (*resume)(struct device___394 *);
	int (*freeze)(struct device___394 *);
	int (*thaw)(struct device___394 *);
	int (*poweroff)(struct device___394 *);
	int (*restore)(struct device___394 *);
	int (*suspend_late)(struct device___394 *);
	int (*resume_early)(struct device___394 *);
	int (*freeze_late)(struct device___394 *);
	int (*thaw_early)(struct device___394 *);
	int (*poweroff_late)(struct device___394 *);
	int (*restore_early)(struct device___394 *);
	int (*suspend_noirq)(struct device___394 *);
	int (*resume_noirq)(struct device___394 *);
	int (*freeze_noirq)(struct device___394 *);
	int (*thaw_noirq)(struct device___394 *);
	int (*poweroff_noirq)(struct device___394 *);
	int (*restore_noirq)(struct device___394 *);
	int (*runtime_suspend)(struct device___394 *);
	int (*runtime_resume)(struct device___394 *);
	int (*runtime_idle)(struct device___394 *);
};

struct dev_pm_info___394 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___394 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___394;

struct bus_type___394;

struct device_driver___394;

struct dev_pm_domain___394;

struct dma_map_ops___166;

struct fwnode_handle___314;

struct class___394;

struct device___394 {
	struct device___394 *parent;
	struct device_private *p;
	struct kobject___414 kobj;
	const char *init_name;
	const struct device_type___394 *type;
	struct mutex mutex;
	struct bus_type___394 *bus;
	struct device_driver___394 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___394 power;
	struct dev_pm_domain___394 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___166 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___314 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___394 *class;
	const struct attribute_group___391 **groups;
	void (*release)(struct device___394 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___394 {
	struct dev_pm_ops___394 ops;
	void (*detach)(struct device___394 *, bool);
	int (*activate)(struct device___394 *);
	void (*sync)(struct device___394 *);
	void (*dismiss)(struct device___394 *);
};

struct bus_type___394 {
	const char *name;
	const char *dev_name;
	struct device___394 *dev_root;
	const struct attribute_group___391 **bus_groups;
	const struct attribute_group___391 **dev_groups;
	const struct attribute_group___391 **drv_groups;
	int (*match)(struct device___394 *, struct device_driver___394 *);
	int (*uevent)(struct device___394 *, struct kobj_uevent_env *);
	int (*probe)(struct device___394 *);
	int (*remove)(struct device___394 *);
	void (*shutdown)(struct device___394 *);
	int (*online)(struct device___394 *);
	int (*offline)(struct device___394 *);
	int (*suspend)(struct device___394 *, pm_message_t);
	int (*resume)(struct device___394 *);
	int (*num_vf)(struct device___394 *);
	int (*dma_configure)(struct device___394 *);
	const struct dev_pm_ops___394 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___394 {
	const char *name;
	struct bus_type___394 *bus;
	struct module___356 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___394 *);
	int (*remove)(struct device___394 *);
	void (*shutdown)(struct device___394 *);
	int (*suspend)(struct device___394 *, pm_message_t);
	int (*resume)(struct device___394 *);
	const struct attribute_group___391 **groups;
	const struct dev_pm_ops___394 *pm;
	void (*coredump)(struct device___394 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___394 {
	const char *name;
	const struct attribute_group___391 **groups;
	int (*uevent)(struct device___394 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___394 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___394 *);
	const struct dev_pm_ops___394 *pm;
};

struct class___394 {
	const char *name;
	struct module___356 *owner;
	const struct attribute_group___391 **class_groups;
	const struct attribute_group___391 **dev_groups;
	struct kobject___414 *dev_kobj;
	int (*dev_uevent)(struct device___394 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___394 *, umode_t *);
	void (*class_release)(struct class___394 *);
	void (*dev_release)(struct device___394 *);
	int (*shutdown_pre)(struct device___394 *);
	const struct kobj_ns_type_operations___53 *ns_type;
	const void * (*namespace)(struct device___394 *);
	const struct dev_pm_ops___394 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___166 {
	void * (*alloc)(struct device___394 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___394 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___394 *, struct vm_area_struct___427 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___394 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___394 *, struct page___427 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___394 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___394 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___394 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___394 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___394 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___394 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___394 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___394 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___394 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___394 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___394 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___394 *, u64);
	u64 (*get_required_mask)(struct device___394 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___314;

struct fwnode_handle___314 {
	struct fwnode_handle___314 *secondary;
	const struct fwnode_operations___314 *ops;
};

typedef void compound_page_dtor___414(struct page___427 *);

struct fwnode_reference_args___314;

struct fwnode_endpoint___314;

struct fwnode_operations___314 {
	struct fwnode_handle___314 * (*get)(struct fwnode_handle___314 *);
	void (*put)(struct fwnode_handle___314 *);
	bool (*device_is_available)(const struct fwnode_handle___314 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___314 *, const struct device___394 *);
	bool (*property_present)(const struct fwnode_handle___314 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___314 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___314 *, const char *, const char **, size_t);
	struct fwnode_handle___314 * (*get_parent)(const struct fwnode_handle___314 *);
	struct fwnode_handle___314 * (*get_next_child_node)(const struct fwnode_handle___314 *, struct fwnode_handle___314 *);
	struct fwnode_handle___314 * (*get_named_child_node)(const struct fwnode_handle___314 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___314 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___314 *);
	struct fwnode_handle___314 * (*graph_get_next_endpoint)(const struct fwnode_handle___314 *, struct fwnode_handle___314 *);
	struct fwnode_handle___314 * (*graph_get_remote_endpoint)(const struct fwnode_handle___314 *);
	struct fwnode_handle___314 * (*graph_get_port_parent)(struct fwnode_handle___314 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___314 *, struct fwnode_endpoint___314 *);
};

struct fwnode_endpoint___314 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___314 *local_fwnode;
};

struct fwnode_reference_args___314 {
	struct fwnode_handle___314 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___107;

struct pipe_buffer___107 {
	struct page___427 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___107 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___107 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___107 *, struct pipe_buffer___107 *);
	void (*release)(struct pipe_inode_info___107 *, struct pipe_buffer___107 *);
	int (*steal)(struct pipe_inode_info___107 *, struct pipe_buffer___107 *);
	union {
		bool (*get)(struct pipe_inode_info___107 *, struct pipe_buffer___107 *);
		struct {
			void (*get)(struct pipe_inode_info___107 *, struct pipe_buffer___107 *);
		} __UNIQUE_ID_rh_kabi_hide21;
		union {		};
	};
};

struct nf_bridge_info___71 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___71 = 0,
		BRNF_PROTO_8021Q___71 = 1,
		BRNF_PROTO_PPPOE___71 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___72 *physindev;
	struct net_device___72 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___71(struct sk_buff___73 **);

struct net_device_ops___71;

struct ethtool_ops___71;

struct l3mdev_ops___53;

struct ndisc_ops___31;

struct xfrmdev_ops___71;

struct tlsdev_ops___71;

struct header_ops___71;

struct inet6_dev___31;

struct netdev_rx_queue___71;

struct mini_Qdisc___63;

struct netdev_queue___71;

struct Qdisc___63;

struct rtnl_link_ops___63;

struct dcbnl_rtnl_ops___71;

struct net_device___72 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___71 *netdev_ops;
	const struct ethtool_ops___71 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___53 *l3mdev_ops;
	const struct ndisc_ops___31 *ndisc_ops;
	const struct xfrmdev_ops___71 *xfrmdev_ops;
	const struct tlsdev_ops___71 *tlsdev_ops;
	const struct header_ops___71 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___413 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___31 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___71 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___63 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___71 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___63 *miniq_ingress;
	struct netdev_queue___71 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___71 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___63 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___63 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___71 = 0,
		NETREG_REGISTERED___71 = 1,
		NETREG_UNREGISTERING___71 = 2,
		NETREG_UNREGISTERED___71 = 3,
		NETREG_RELEASED___71 = 4,
		NETREG_DUMMY___71 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___71 = 0,
		RTNL_LINK_INITIALIZING___71 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___72 *);
	struct netpoll_info *npinfo;
	possible_net_t___73 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___394 dev;
	const struct attribute_group___391 *sysfs_groups[4];
	const struct attribute_group___391 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___63 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___71 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide35;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct skb_frag_struct___12 {
	struct {
		struct page___427 *p;
	} page;
	__u32 page_offset;
	__u32 size;
};

typedef struct skb_frag_struct___12 skb_frag_t___12;

struct skb_shared_info___12 {
	__u8 __unused;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___73 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___12 frags[16];
};

struct xfrm_state___7;

struct sec_path___7 {
	refcount_t refcnt;
	int len;
	int olen;
	struct xfrm_state___7 *xvec[6];
	struct xfrm_offload ovec[1];
};

struct ethtool_ops___71 {
	int (*get_settings)(struct net_device___72 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___72 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___72 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___72 *);
	void (*get_regs)(struct net_device___72 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___72 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___72 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___72 *);
	void (*set_msglevel)(struct net_device___72 *, u32);
	int (*nway_reset)(struct net_device___72 *);
	u32 (*get_link)(struct net_device___72 *);
	int (*get_eeprom_len)(struct net_device___72 *);
	int (*get_eeprom)(struct net_device___72 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___72 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___72 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___72 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___72 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___72 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___72 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___72 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___72 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___72 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___72 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___72 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___72 *);
	void (*complete)(struct net_device___72 *);
	u32 (*get_priv_flags)(struct net_device___72 *);
	int (*set_priv_flags)(struct net_device___72 *, u32);
	int (*get_sset_count)(struct net_device___72 *, int);
	int (*get_rxnfc)(struct net_device___72 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___72 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___72 *, struct ethtool_flash *);
	int (*reset)(struct net_device___72 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___72 *);
	u32 (*get_rxfh_indir_size)(struct net_device___72 *);
	int (*get_rxfh)(struct net_device___72 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___72 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___72 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___72 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___72 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___72 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___72 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___72 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___72 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___72 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___72 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___72 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___72 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___72 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___72 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___72 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___72 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___72 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___72 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___72 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___72 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___72 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	int (*get_fecparam)(struct net_device___72 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___72 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___72 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___72 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___72 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___71;

struct inet_frags___71 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___71 *, const void *);
	void (*destructor)(struct inet_frag_queue___71 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___71 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___73 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___73 *fragments_tail;
	struct sk_buff___73 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___71 *net;
	struct callback_head rcu;
};

struct ip_ra_chain___27 {
	struct ip_ra_chain___27 *next;
	struct sock___54 *sk;
	union {
		void (*destructor)(struct sock___54 *);
		struct sock___54 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___53;

struct fib_lookup_arg___53;

struct fib_rules_ops___53 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___53 *, struct flowi *, int, struct fib_lookup_arg___53 *);
	bool (*suppress)(struct fib_rule___53 *, struct fib_lookup_arg___53 *);
	int (*match)(struct fib_rule___53 *, struct flowi *, int);
	int (*configure)(struct fib_rule___53 *, struct sk_buff___73 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___53 *);
	int (*compare)(struct fib_rule___53 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___53 *, struct sk_buff___73 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___53 *);
	void (*flush_cache)(struct fib_rules_ops___53 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___356 *owner;
	struct net___83 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___54 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___83 *);
	int (*fib_dump)(struct net___83 *, struct notifier_block *);
	struct module___356 *owner;
	struct callback_head rcu;
};

struct dst_entry___53 {
	struct net_device___72 *dev;
	struct dst_ops___82 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state___7 *xfrm;
	int (*input)(struct sk_buff___73 *);
	int (*output)(struct net___83 *, struct sock___54 *, struct sk_buff___73 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___53;

struct neigh_parms___53;

struct neigh_ops___53;

struct neighbour___53 {
	struct neighbour___53 *next;
	struct neigh_table___53 *tbl;
	struct neigh_parms___53 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___71 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___53 *, struct sk_buff___73 *);
	const struct neigh_ops___53 *ops;
	struct callback_head rcu;
	struct net_device___72 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct fib6_nh___10 {
	struct in6_addr nh_gw;
	struct net_device___72 *nh_dev;
	struct lwtunnel_state *nh_lwtstate;
	unsigned int nh_flags;
	atomic_t nh_upper_bound;
	int nh_weight;
};

struct fib6_node___10;

struct fib6_info___10 {
	struct fib6_table___10 *fib6_table;
	struct fib6_info___10 *fib6_next;
	struct fib6_node___10 *fib6_node;
	struct list_head fib6_siblings;
	unsigned int fib6_nsiblings;
	atomic_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	struct rt6_info___10 **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
	long unsigned int last_probe;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 exception_bucket_flushed: 1;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 dst_host: 1;
	u8 fib6_destroying: 1;
	u8 unused: 2;
	struct fib6_nh___10 fib6_nh;
	struct callback_head rcu;
};

struct rt6_info___10 {
	struct dst_entry___53 dst;
	struct fib6_info___10 *from;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___31 *rt6i_idev;
	u32 rt6i_flags;
	struct rt6key rt6i_prefsrc;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct fib6_node___10 {
	struct fib6_node___10 *parent;
	struct fib6_node___10 *left;
	struct fib6_node___10 *right;
	struct fib6_info___10 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info___10 *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table___10 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node___10 tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

struct ucounts___291 {
	struct hlist_node node;
	struct user_namespace___291 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_prog_aux___66;

struct bpf_prog___63 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___66 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

typedef int (*key_restrict_link_func_t___395)(struct key___394 *, const struct key_type *, const union key_payload *, struct key___394 *);

struct key_restriction___394;

struct key___394 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___428 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___394 *restrict_link;
};

struct key_restriction___394 {
	key_restrict_link_func_t___395 check;
	struct key___394 *key;
	struct key_type *keytype;
};

struct seq_operations___365 {
	void * (*start)(struct seq_file___365 *, loff_t *);
	void (*stop)(struct seq_file___365 *, void *);
	void * (*next)(struct seq_file___365 *, void *, loff_t *);
	int (*show)(struct seq_file___365 *, void *);
};

struct pernet_operations___72 {
	struct list_head list;
	int (*init)(struct net___83 *);
	void (*exit)(struct net___83 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___71 {
	int (*ieee_getets)(struct net_device___72 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___72 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___72 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___72 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___72 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___72 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___72 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___72 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___72 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___72 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___72 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___72 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___72 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___72 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___72 *);
	u8 (*setstate)(struct net_device___72 *, u8);
	void (*getpermhwaddr)(struct net_device___72 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___72 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___72 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___72 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___72 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___72 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___72 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___72 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___72 *, int, u8 *);
	void (*setpfccfg)(struct net_device___72 *, int, u8);
	void (*getpfccfg)(struct net_device___72 *, int, u8 *);
	u8 (*setall)(struct net_device___72 *);
	u8 (*getcap)(struct net_device___72 *, int, u8 *);
	int (*getnumtcs)(struct net_device___72 *, int, u8 *);
	int (*setnumtcs)(struct net_device___72 *, int, u8);
	u8 (*getpfcstate)(struct net_device___72 *);
	void (*setpfcstate)(struct net_device___72 *, u8);
	void (*getbcncfg)(struct net_device___72 *, int, u32 *);
	void (*setbcncfg)(struct net_device___72 *, int, u32);
	void (*getbcnrp)(struct net_device___72 *, int, u8 *);
	void (*setbcnrp)(struct net_device___72 *, int, u8);
	int (*setapp)(struct net_device___72 *, u8, u16, u8);
	int (*getapp)(struct net_device___72 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___72 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___72 *, int, u8);
	u8 (*getdcbx)(struct net_device___72 *);
	u8 (*setdcbx)(struct net_device___72 *, u8);
	int (*peer_getappinfo)(struct net_device___72 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___72 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___72 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___72 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___72 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___72 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___275 {
	refcount_t count;
	struct ns_common___29 ns;
	struct user_namespace___291 *user_ns;
	struct ucounts___291 *ucounts;
	struct css_set___275 *root_cset;
};

struct bpf_map___276;

struct bpf_map_ops___275 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___276 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___276 *, struct file___426 *);
	void (*map_free)(struct bpf_map___276 *);
	int (*map_get_next_key)(struct bpf_map___276 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___276 *);
	void * (*map_lookup_elem)(struct bpf_map___276 *, void *);
	int (*map_update_elem)(struct bpf_map___276 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___276 *, void *);
	int (*map_push_elem)(struct bpf_map___276 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___276 *, void *);
	int (*map_peek_elem)(struct bpf_map___276 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___276 *, struct file___426 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___276 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___276 *, void *, struct seq_file___365 *);
	int (*map_check_btf)(const struct bpf_map___276 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___276 {
	const struct bpf_map_ops___275 *ops;
	struct bpf_map___276 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___394 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___71;

struct bpf_map_dev_ops___71 {
	int (*map_get_next_key)(struct bpf_offloaded_map___71 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___71 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___71 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___71 *, void *);
};

struct bpf_offloaded_map___71 {
	struct bpf_map___276 map;
	struct net_device___72 *netdev;
	const struct bpf_map_dev_ops___71 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___63 {
	int (*test_run)(struct bpf_prog___63 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___63 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___63 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___63 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___63 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___63 *, u32 *);
};

struct bpf_prog_offload_ops___63 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___63 *);
	int (*translate)(struct bpf_prog___63 *);
	void (*destroy)(struct bpf_prog___63 *);
};

struct bpf_prog_offload___63 {
	struct bpf_prog___63 *prog;
	struct net_device___72 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___63 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___66 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___63 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___63 *ops;
	struct bpf_map___276 **used_maps;
	struct bpf_prog___63 *prog;
	struct user_struct___394 *user;
	u64 load_time;
	struct bpf_map___276 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___63 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___63 {
	struct bpf_prog___63 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___63 {
	struct callback_head rcu;
	struct bpf_prog_array_item___63 items[0];
};

struct cgroup_bpf___63 {
	struct bpf_prog_array___63 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___63 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___276;

typedef void (*kthread_work_func_t___276)(struct kthread_work___276 *);

struct kthread_worker___276;

struct kthread_work___276 {
	struct list_head node;
	kthread_work_func_t___276 func;
	struct kthread_worker___276 *worker;
	int canceling;
};

struct kthread_worker___276 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___428 *task;
	struct kthread_work___276 *current_work;
};

struct kthread_delayed_work___275 {
	struct kthread_work___276 work;
	struct timer_list timer;
};

struct psi_group___275 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___276 *poll_kworker;
	struct kthread_delayed_work___275 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___275;

struct cgroup_rstat_cpu___275;

struct cgroup___275 {
	struct cgroup_subsys_state___275 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___421 *kn;
	struct cgroup_file___275 procs_file;
	struct cgroup_file___275 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___275 *subsys[13];
	struct cgroup_root___275 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___275 *dom_cgrp;
	struct cgroup_rstat_cpu___275 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___63 bpf;
	atomic_t congestion_count;
	struct cgroup___275 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___275 psi;
	int ancestor_ids[0];
};

struct cftype___275;

struct cgroup_subsys___275 {
	struct cgroup_subsys_state___275 * (*css_alloc)(struct cgroup_subsys_state___275 *);
	int (*css_online)(struct cgroup_subsys_state___275 *);
	void (*css_offline)(struct cgroup_subsys_state___275 *);
	void (*css_released)(struct cgroup_subsys_state___275 *);
	void (*css_free)(struct cgroup_subsys_state___275 *);
	void (*css_reset)(struct cgroup_subsys_state___275 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___275 *, int);
	int (*css_extra_stat_show)(struct seq_file___365 *, struct cgroup_subsys_state___275 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___428 *);
	void (*cancel_fork)(struct task_struct___428 *);
	void (*fork)(struct task_struct___428 *);
	void (*exit)(struct task_struct___428 *);
	void (*free)(struct task_struct___428 *);
	void (*bind)(struct cgroup_subsys_state___275 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___275 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___275 *dfl_cftypes;
	struct cftype___275 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___275 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___275 *updated_children;
	struct cgroup___275 *updated_next;
};

struct cgroup_root___275 {
	struct kernfs_root___420 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___275 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___275 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___275 *ss;
	struct list_head node;
	struct kernfs_ops___420 *kf_ops;
	int (*open)(struct kernfs_open_file___420 *);
	void (*release)(struct kernfs_open_file___420 *);
	u64 (*read_u64)(struct cgroup_subsys_state___275 *, struct cftype___275 *);
	s64 (*read_s64)(struct cgroup_subsys_state___275 *, struct cftype___275 *);
	int (*seq_show)(struct seq_file___365 *, void *);
	void * (*seq_start)(struct seq_file___365 *, loff_t *);
	void * (*seq_next)(struct seq_file___365 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___365 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___275 *, struct cftype___275 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___275 *, struct cftype___275 *, s64);
	ssize_t (*write)(struct kernfs_open_file___420 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___420 *, struct poll_table_struct___267 *);
};

struct xdp_rxq_info___71 {
	struct net_device___72 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___71 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___72 *dev_rx;
};

struct netlink_callback___73 {
	struct sk_buff___73 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___73 *);
	int (*dump)(struct sk_buff___73 *, struct netlink_callback___73 *);
	int (*done)(struct netlink_callback___73 *);
	void *data;
	struct module___356 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

enum macvlan_mode {
	MACVLAN_MODE_PRIVATE = 1,
	MACVLAN_MODE_VEPA = 2,
	MACVLAN_MODE_BRIDGE = 4,
	MACVLAN_MODE_PASSTHRU = 8,
	MACVLAN_MODE_SOURCE = 16,
};

struct tc_ratespec {
	unsigned char cell_log;
	__u8 linklayer;
	short unsigned int overhead;
	short int cell_align;
	short unsigned int mpu;
	__u32 rate;
};

struct tc_prio_qopt {
	int bands;
	__u8 priomap[16];
};

struct header_ops___71 {
	int (*create)(struct sk_buff___73 *, struct net_device___72 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___73 *, unsigned char *);
	int (*cache)(const struct neighbour___53 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___72 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___71 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___71 *, int);
	int poll_owner;
	struct net_device___72 *dev;
	struct sk_buff___73 *gro_list;
	struct sk_buff___73 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___71 {
	struct net_device___72 *dev;
	struct Qdisc___63 *qdisc;
	struct Qdisc___63 *qdisc_sleeping;
	struct kobject___414 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___72 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem___3 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___63 {
	struct sk_buff___73 *head;
	struct sk_buff___73 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___63;

struct Qdisc___63 {
	int (*enqueue)(struct sk_buff___73 *, struct Qdisc___63 *, struct sk_buff___73 **);
	struct sk_buff___73 * (*dequeue)(struct Qdisc___63 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___63 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___71 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___71 gso_skb;
	struct qdisc_skb_head___63 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___63 *next_sched;
	struct sk_buff_head___71 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___71 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___414 kobj;
	struct net_device___72 *dev;
	long: 64;
	struct xdp_rxq_info___71 xdp_rxq;
	union {
		struct xdp_umem___3 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___71)(struct net_device___72 *, struct sk_buff___73 *, struct net_device___72 *);

struct netdev_bpf___71 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___63 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___63 *prog;
			const struct bpf_prog_offload_ops___63 *ops;
		} verifier;
		struct {
			struct bpf_prog___63 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___71 *offmap;
		};
		struct {
			struct xdp_umem___3 *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___71 {
	int (*xdo_dev_state_add)(struct xfrm_state___7 *);
	void (*xdo_dev_state_delete)(struct xfrm_state___7 *);
	void (*xdo_dev_state_free)(struct xfrm_state___7 *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___73 *, struct xfrm_state___7 *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state___7 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct xfrm_state_offload___7 {
	struct net_device___72 *dev;
	long unsigned int offload_handle;
	unsigned int num_exthdrs;
	u8 flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct xfrm_replay___7;

struct xfrm_type___7;

struct xfrm_mode___7;

struct xfrm_type_offload___7;

struct xfrm_state___7 {
	possible_net_t___73 xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	refcount_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
		u32 output_mark;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	const char *geniv;
	struct xfrm_encap_tmpl *encap;
	xfrm_address_t *coaddr;
	struct xfrm_state___7 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	const struct xfrm_replay___7 *repl;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct tasklet_hrtimer mtimer;
	struct xfrm_state_offload___7 xso;
	long int saved_tmo;
	long unsigned int lastused;
	struct page_frag___427 xfrag;
	const struct xfrm_type___7 *type;
	struct xfrm_mode___7 *inner_mode;
	struct xfrm_mode___7 *inner_mode_iaf;
	struct xfrm_mode___7 *outer_mode;
	const struct xfrm_type_offload___7 *type_offload;
	struct xfrm_sec_ctx___2 *security;
	void *data;
	u32 output_mark_mask;
	u32 if_id;
};

struct tlsdev_ops___71 {
	int (*tls_dev_add)(struct net_device___72 *, struct sock___54 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___72 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___72 *, struct sock___54 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___71 {
	int (*ndo_init)(struct net_device___72 *);
	void (*ndo_uninit)(struct net_device___72 *);
	int (*ndo_open)(struct net_device___72 *);
	int (*ndo_stop)(struct net_device___72 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___73 *, struct net_device___72 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___73 *, struct net_device___72 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___72 *, struct sk_buff___73 *, struct net_device___72 *, select_queue_fallback_t___71);
	void (*ndo_change_rx_flags)(struct net_device___72 *, int);
	void (*ndo_set_rx_mode)(struct net_device___72 *);
	int (*ndo_set_mac_address)(struct net_device___72 *, void *);
	int (*ndo_validate_addr)(struct net_device___72 *);
	int (*ndo_do_ioctl)(struct net_device___72 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___72 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___72 *, int);
	int (*ndo_neigh_setup)(struct net_device___72 *, struct neigh_parms___53 *);
	void (*ndo_tx_timeout)(struct net_device___72 *);
	void (*ndo_get_stats64)(struct net_device___72 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___72 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___72 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___72 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___72 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___72 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___72 *);
	int (*ndo_netpoll_setup)(struct net_device___72 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___72 *);
	int (*ndo_set_vf_mac)(struct net_device___72 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___72 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___72 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___72 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___72 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___72 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___72 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___72 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___72 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___72 *, int, struct sk_buff___73 *);
	int (*ndo_set_vf_guid)(struct net_device___72 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___72 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___72 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___72 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___72 *, const struct sk_buff___73 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___72 *, struct net_device___72 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___72 *, struct net_device___72 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___72 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___72 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___72 *, struct neighbour___53 *);
	void (*ndo_neigh_destroy)(struct net_device___72 *, struct neighbour___53 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___72 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___72 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___72 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___73 *, struct netlink_callback___73 *, struct net_device___72 *, struct net_device___72 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___72 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___72 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___73 *, u32, u32, struct net_device___72 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___72 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___72 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___72 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___72 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___72 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___72 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___72 *, struct net_device___72 *);
	void (*ndo_dfwd_del_station)(struct net_device___72 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___72 *);
	int (*ndo_set_tx_maxrate)(struct net_device___72 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___72 *);
	int (*ndo_change_proto_down)(struct net_device___72 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___72 *, struct sk_buff___73 *);
	void (*ndo_set_rx_headroom)(struct net_device___72 *, int);
	int (*ndo_bpf)(struct net_device___72 *, struct netdev_bpf___71 *);
	int (*ndo_xdp_xmit)(struct net_device___72 *, int, struct xdp_frame___71 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___72 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___72 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___53 {
	possible_net_t___73 net;
	struct net_device___72 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___53 *);
	void (*neigh_cleanup)(struct neighbour___53 *);
	struct neigh_table___53 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___53 {
	u32 (*l3mdev_fib_table)(const struct net_device___72 *);
	struct sk_buff___73 * (*l3mdev_l3_rcv)(struct net_device___72 *, struct sk_buff___73 *, u16);
	struct sk_buff___73 * (*l3mdev_l3_out)(struct net_device___72 *, struct sock___54 *, struct sk_buff___73 *, u16);
	struct dst_entry___53 * (*l3mdev_link_scope_lookup)(const struct net_device___72 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct ndisc_ops___31 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___72 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___72 *, struct neighbour___53 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___72 *, u8, struct neighbour___53 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___72 *, struct sk_buff___73 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___83 *, struct net_device___72 *, const struct prefix_info *, struct inet6_dev___31 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___31;

struct ifacaddr6___10;

struct inet6_dev___31 {
	struct net_device___72 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___31 *mc_list;
	struct ifmcaddr6___31 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___10 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	u8 rndid[8];
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___53 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
};

struct tcf_proto___63;

struct mini_Qdisc___63 {
	struct tcf_proto___63 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___63 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___72 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___83 *, struct net_device___72 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___72 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___72 *, struct list_head *);
	size_t (*get_size)(const struct net_device___72 *);
	int (*fill_info)(struct sk_buff___73 *, const struct net_device___72 *);
	size_t (*get_xstats_size)(const struct net_device___72 *);
	int (*fill_xstats)(struct sk_buff___73 *, const struct net_device___72 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___72 *, struct net_device___72 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___72 *, const struct net_device___72 *);
	int (*fill_slave_info)(struct sk_buff___73 *, const struct net_device___72 *, const struct net_device___72 *);
	struct net___83 * (*get_link_net)(const struct net_device___72 *);
	size_t (*get_linkxstats_size)(const struct net_device___72 *, int);
	int (*fill_linkxstats)(struct sk_buff___73 *, const struct net_device___72 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___71 {
	struct list_head poll_list;
	struct sk_buff_head___71 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___71 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___63 *output_queue;
	struct Qdisc___63 **output_queue_tailp;
	struct sk_buff___73 *completion_queue;
	struct sk_buff_head___71 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___71 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___71 input_pkt_queue;
	struct napi_struct___71 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

enum {
	TCA_UNSPEC = 0,
	TCA_KIND = 1,
	TCA_OPTIONS = 2,
	TCA_STATS = 3,
	TCA_XSTATS = 4,
	TCA_RATE = 5,
	TCA_FCNT = 6,
	TCA_STATS2 = 7,
	TCA_STAB = 8,
	TCA_PAD = 9,
	TCA_DUMP_INVISIBLE = 10,
	TCA_CHAIN = 11,
	TCA_HW_OFFLOAD = 12,
	TCA_INGRESS_BLOCK = 13,
	TCA_EGRESS_BLOCK = 14,
	__TCA_MAX = 15,
};

struct vlan_pcpu_stats {
	u64 rx_packets;
	u64 rx_bytes;
	u64 rx_multicast;
	u64 tx_packets;
	u64 tx_bytes;
	struct u64_stats_sync syncp;
	u32 rx_errors;
	u32 tx_dropped;
};

struct netpoll___5;

struct skb_array {
	struct ptr_ring ring;
};

struct macvlan_port;

struct macvlan_dev {
	struct net_device___72 *dev;
	struct list_head list;
	struct hlist_node hlist;
	struct macvlan_port *port;
	struct net_device___72 *lowerdev;
	void *accel_priv;
	struct vlan_pcpu_stats *pcpu_stats;
	long unsigned int mc_filter[4];
	netdev_features_t set_features;
	enum macvlan_mode mode;
	u16 flags;
	int nest_level;
	unsigned int macaddr_count;
	struct netpoll___5 *netpoll;
};

struct gnet_dump___63 {
	spinlock_t *lock;
	struct sk_buff___73 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___63;

struct Qdisc_ops___63 {
	struct Qdisc_ops___63 *next;
	const struct Qdisc_class_ops___63 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___73 *, struct Qdisc___63 *, struct sk_buff___73 **);
	struct sk_buff___73 * (*dequeue)(struct Qdisc___63 *);
	struct sk_buff___73 * (*peek)(struct Qdisc___63 *);
	int (*init)(struct Qdisc___63 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___63 *);
	void (*destroy)(struct Qdisc___63 *);
	int (*change)(struct Qdisc___63 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___63 *);
	int (*change_tx_queue_len)(struct Qdisc___63 *, unsigned int);
	int (*dump)(struct Qdisc___63 *, struct sk_buff___73 *);
	int (*dump_stats)(struct Qdisc___63 *, struct gnet_dump___63 *);
	void (*ingress_block_set)(struct Qdisc___63 *, u32);
	void (*egress_block_set)(struct Qdisc___63 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___63 *);
	u32 (*egress_block_get)(struct Qdisc___63 *);
	struct module___356 *owner;
};

struct qdisc_walker___7;

struct tcf_block___63;

struct Qdisc_class_ops___63 {
	unsigned int flags;
	struct netdev_queue___71 * (*select_queue)(struct Qdisc___63 *, struct tcmsg *);
	int (*graft)(struct Qdisc___63 *, long unsigned int, struct Qdisc___63 *, struct Qdisc___63 **, struct netlink_ext_ack *);
	struct Qdisc___63 * (*leaf)(struct Qdisc___63 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___63 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___63 *, u32);
	int (*change)(struct Qdisc___63 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___63 *, long unsigned int);
	void (*walk)(struct Qdisc___63 *, struct qdisc_walker___7 *);
	struct tcf_block___63 * (*tcf_block)(struct Qdisc___63 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___63 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___63 *, long unsigned int);
	int (*dump)(struct Qdisc___63 *, long unsigned int, struct sk_buff___73 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___63 *, long unsigned int, struct gnet_dump___63 *);
};

struct qdisc_walker___7 {
	int stop;
	int skip;
	int count;
	int (*fn)(struct Qdisc___63 *, long unsigned int, struct qdisc_walker___7 *);
};

struct tcf_chain___63;

struct tcf_block___63 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___83 *net;
	struct Qdisc___63 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___63 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___63;

struct tcf_proto_ops___63;

struct tcf_proto___63 {
	struct tcf_proto___63 *next;
	void *root;
	int (*classify)(struct sk_buff___73 *, const struct tcf_proto___63 *, struct tcf_result___63 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___63 *ops;
	struct tcf_chain___63 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___63 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___63 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___63 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___73 *, const struct tcf_proto___63 *, struct tcf_result___63 *);
	int (*init)(struct tcf_proto___63 *);
	void (*destroy)(struct tcf_proto___63 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___63 *, u32);
	void (*put)(struct tcf_proto___63 *, void *);
	int (*change)(struct net___83 *, struct sk_buff___73 *, struct tcf_proto___63 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___63 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___63 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___63 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___83 *, struct tcf_chain___63 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___83 *, struct tcf_proto___63 *, void *, struct sk_buff___73 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___73 *, struct net___83 *, void *);
	struct module___356 *owner;
	int flags;
};

struct tcf_chain___63 {
	struct mutex filter_chain_lock;
	struct tcf_proto___63 *filter_chain;
	struct list_head list;
	struct tcf_block___63 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___63 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct psched_ratecfg {
	u64 rate_bytes_ps;
	u32 mult;
	u16 overhead;
	u8 linklayer;
	u8 shift;
};

struct mini_Qdisc_pair {
	struct mini_Qdisc___63 miniq1;
	struct mini_Qdisc___63 miniq2;
	struct mini_Qdisc___63 **p_miniq;
};

struct pneigh_entry___53;

struct neigh_hash_table___53;

struct neigh_table___53 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___72 *, __u32 *);
	bool (*key_eq)(const struct neighbour___53 *, const void *);
	int (*constructor)(struct neighbour___53 *);
	int (*pconstructor)(struct pneigh_entry___53 *);
	void (*pdestructor)(struct pneigh_entry___53 *);
	void (*proxy_redo)(struct sk_buff___73 *);
	char *id;
	struct neigh_parms___53 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___71 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___53 *nht;
	struct pneigh_entry___53 **phash_buckets;
};

struct neigh_ops___53 {
	int family;
	void (*solicit)(struct neighbour___53 *, struct sk_buff___73 *);
	void (*error_report)(struct neighbour___53 *, struct sk_buff___73 *);
	int (*output)(struct neighbour___53 *, struct sk_buff___73 *);
	int (*connected_output)(struct neighbour___53 *, struct sk_buff___73 *);
};

struct pneigh_entry___53 {
	struct pneigh_entry___53 *next;
	possible_net_t___73 net;
	struct net_device___72 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___53 {
	struct neighbour___53 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct bdi_writeback_congested___218 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___218 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___218 {
	struct bio___218 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___220 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___220 bip_inline_vecs[0];
};

struct bio_set___218 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___218 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___161 {
	struct mem_cgroup___161 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___161 {
	struct lruvec___427 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___161 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___161 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct sk_filter___53 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___63 *prog;
};

struct bpf_redirect_info___63 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___276 *map;
	struct bpf_map___276 *map_to_flush;
	u32 kern_flags;
};

struct fib_rule___53 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___53 *ctarget;
	struct net___83 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___53 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___53 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___37;

struct timewait_sock_ops___34;

struct proto___53 {
	void (*close)(struct sock___54 *, long int);
	int (*pre_connect)(struct sock___54 *, struct sockaddr *, int);
	int (*connect)(struct sock___54 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___54 *, int);
	struct sock___54 * (*accept)(struct sock___54 *, int, int *, bool);
	int (*ioctl)(struct sock___54 *, int, long unsigned int);
	int (*init)(struct sock___54 *);
	void (*destroy)(struct sock___54 *);
	void (*shutdown)(struct sock___54 *, int);
	int (*setsockopt)(struct sock___54 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___54 *, int, int, char *, int *);
	void (*keepalive)(struct sock___54 *, int);
	int (*sendmsg)(struct sock___54 *, struct msghdr___56 *, size_t);
	int (*recvmsg)(struct sock___54 *, struct msghdr___56 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___54 *, struct page___427 *, int, size_t, int);
	int (*bind)(struct sock___54 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___54 *, struct sk_buff___73 *);
	void (*release_cb)(struct sock___54 *);
	int (*hash)(struct sock___54 *);
	void (*unhash)(struct sock___54 *);
	void (*rehash)(struct sock___54 *);
	int (*get_port)(struct sock___54 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___54 *);
	bool (*stream_memory_read)(const struct sock___54 *);
	void (*enter_memory_pressure)(struct sock___54 *);
	void (*leave_memory_pressure)(struct sock___54 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___37 *rsk_prot;
	struct timewait_sock_ops___34 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___356 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___54 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct xfrm_policy_queue___7 {
	struct sk_buff_head___71 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___7 {
	possible_net_t___73 xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	refcount_t refcnt;
	struct timer_list timer;
	atomic_t genid;
	u32 priority;
	u32 index;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___7 polq;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx___2 *security;
	struct xfrm_tmpl xfrm_vec[6];
	struct callback_head rcu;
	u32 if_id;
};

struct request_sock___38;

struct request_sock_ops___37 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___54 *, struct request_sock___38 *);
	void (*send_ack)(const struct sock___54 *, struct sk_buff___73 *, struct request_sock___38 *);
	void (*send_reset)(const struct sock___54 *, struct sk_buff___73 *);
	void (*destructor)(struct request_sock___38 *);
	void (*syn_ack_timeout)(const struct request_sock___38 *);
};

struct timewait_sock_ops___34 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___54 *, struct sock___54 *, void *);
	void (*twsk_destructor)(struct sock___54 *);
};

struct request_sock___38 {
	struct sock_common___53 __req_common;
	struct request_sock___38 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___37 *rsk_ops;
	struct sock___54 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___31 {
	struct in6_addr mca_addr;
	struct inet6_dev___31 *idev;
	struct ifmcaddr6___31 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___10 {
	struct in6_addr aca_addr;
	struct fib6_info___10 *aca_rt;
	struct ifacaddr6___10 *aca_next;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct ip6_ra_chain___31 {
	struct ip6_ra_chain___31 *next;
	struct sock___54 *sk;
	int sel;
	void (*destructor)(struct sock___54 *);
};

struct xfrm_replay___7 {
	void (*advance)(struct xfrm_state___7 *, __be32);
	int (*check)(struct xfrm_state___7 *, struct sk_buff___73 *, __be32);
	int (*recheck)(struct xfrm_state___7 *, struct sk_buff___73 *, __be32);
	void (*notify)(struct xfrm_state___7 *, int);
	int (*overflow)(struct xfrm_state___7 *, struct sk_buff___73 *);
};

struct xfrm_type___7 {
	char *description;
	struct module___356 *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___7 *);
	void (*destructor)(struct xfrm_state___7 *);
	int (*input)(struct xfrm_state___7 *, struct sk_buff___73 *);
	int (*output)(struct xfrm_state___7 *, struct sk_buff___73 *);
	int (*reject)(struct xfrm_state___7 *, struct sk_buff___73 *, const struct flowi *);
	int (*hdr_offset)(struct xfrm_state___7 *, struct sk_buff___73 *, u8 **);
	u32 (*get_mtu)(struct xfrm_state___7 *, int);
};

struct xfrm_state_afinfo___7;

struct xfrm_mode___7 {
	int (*input2)(struct xfrm_state___7 *, struct sk_buff___73 *);
	int (*input)(struct xfrm_state___7 *, struct sk_buff___73 *);
	int (*output2)(struct xfrm_state___7 *, struct sk_buff___73 *);
	int (*output)(struct xfrm_state___7 *, struct sk_buff___73 *);
	struct sk_buff___73 * (*gso_segment)(struct xfrm_state___7 *, struct sk_buff___73 *, netdev_features_t);
	void (*xmit)(struct xfrm_state___7 *, struct sk_buff___73 *);
	struct xfrm_state_afinfo___7 *afinfo;
	struct module___356 *owner;
	unsigned int encap;
	int flags;
};

struct xfrm_type_offload___7 {
	char *description;
	struct module___356 *owner;
	u8 proto;
	void (*encap)(struct xfrm_state___7 *, struct sk_buff___73 *);
	int (*input_tail)(struct xfrm_state___7 *, struct sk_buff___73 *);
	int (*xmit)(struct xfrm_state___7 *, struct sk_buff___73 *, netdev_features_t);
};

struct xfrm_state_afinfo___7 {
	unsigned int family;
	unsigned int proto;
	__be16 eth_proto;
	struct module___356 *owner;
	const struct xfrm_type___7 *type_map[256];
	const struct xfrm_type_offload___7 *type_offload_map[256];
	struct xfrm_mode___7 *mode_map[5];
	int (*init_flags)(struct xfrm_state___7 *);
	void (*init_tempsel)(struct xfrm_selector *, const struct flowi *);
	void (*init_temprop)(struct xfrm_state___7 *, const struct xfrm_tmpl *, const xfrm_address_t *, const xfrm_address_t *);
	int (*tmpl_sort)(struct xfrm_tmpl **, struct xfrm_tmpl **, int);
	int (*state_sort)(struct xfrm_state___7 **, struct xfrm_state___7 **, int);
	int (*output)(struct net___83 *, struct sock___54 *, struct sk_buff___73 *);
	int (*output_finish)(struct sock___54 *, struct sk_buff___73 *);
	int (*extract_input)(struct xfrm_state___7 *, struct sk_buff___73 *);
	int (*extract_output)(struct xfrm_state___7 *, struct sk_buff___73 *);
	int (*transport_finish)(struct sk_buff___73 *, int);
	void (*local_error)(struct sk_buff___73 *, u32);
};

struct pfifo_fast_priv {
	struct skb_array q[3];
};

struct file___427;

struct kiocb___427;

struct iov_iter___194;

struct vm_area_struct___428;

struct inode___427;

struct file_lock___427;

struct page___428;

struct pipe_inode_info___108;

struct seq_file___366;

struct file_operations___427 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___427 *, loff_t, int);
	ssize_t (*read)(struct file___427 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___427 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___427 *, struct iov_iter___194 *);
	ssize_t (*write_iter)(struct kiocb___427 *, struct iov_iter___194 *);
	int (*iopoll)(struct kiocb___427 *, bool);
	int (*iterate)(struct file___427 *, struct dir_context *);
	int (*iterate_shared)(struct file___427 *, struct dir_context *);
	__poll_t (*poll)(struct file___427 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___427 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___427 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___427 *, struct vm_area_struct___428 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___427 *, struct file___427 *);
	int (*flush)(struct file___427 *, fl_owner_t);
	int (*release)(struct inode___427 *, struct file___427 *);
	int (*fsync)(struct file___427 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___427 *, int);
	int (*lock)(struct file___427 *, int, struct file_lock___427 *);
	ssize_t (*sendpage)(struct file___427 *, struct page___428 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___427 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___427 *, int, struct file_lock___427 *);
	ssize_t (*splice_write)(struct pipe_inode_info___108 *, struct file___427 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___427 *, loff_t *, struct pipe_inode_info___108 *, size_t, unsigned int);
	int (*setlease)(struct file___427 *, long int, struct file_lock___427 **, void **);
	long int (*fallocate)(struct file___427 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___366 *, struct file___427 *);
	ssize_t (*copy_file_range)(struct file___427 *, loff_t, struct file___427 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___427 *, loff_t, struct file___427 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___427 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___428 {
	u64 seqnum;
	struct vm_area_struct___428 *vmas[4];
};

struct page_frag___428 {
	struct page___428 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___428;

struct cred___395;

struct nsproxy___322;

struct signal_struct___302;

struct css_set___276;

struct vm_struct___331;

struct task_struct___429 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___429 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___428 *mm;
	struct mm_struct___428 *active_mm;
	struct vmacache___428 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___429 *real_parent;
	struct task_struct___429 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___429 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___241 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___241 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___241 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___395 *ptracer_cred;
	const struct cred___395 *real_cred;
	const struct cred___395 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___322 *nsproxy;
	struct signal_struct___302 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___429 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___276 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___108 *splice_pipe;
	struct page_frag___428 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___429 *oom_reaper_list;
	struct vm_struct___331 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___156 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___428 *pgtable_t___428;

struct address_space___427;

struct dev_pagemap___415;

struct page___428 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___427 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___428 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___428 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___428 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___415 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___428;

struct lruvec___428 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___428 *pgdat;
};

struct zone___428 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___428 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___428 {
	struct zone___428 *zone;
	int zone_idx;
};

struct zonelist___428 {
	struct zoneref___428 _zonerefs[25];
};

struct pglist_data___428 {
	struct zone___428 node_zones[3];
	struct zonelist___428 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___429 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___429 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___428 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___429 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___429 *owner;
};

struct secondary_data___429 {
	void *stack;
	struct task_struct___429 *task;
	long int status;
};

struct blocking_notifier_head___428 {
	struct rw_semaphore___429 rwsem;
	struct notifier_block *head;
};

struct key___395;

struct ucounts___292;

struct user_namespace___292 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___292 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___29 ns;
	long unsigned int flags;
	struct key___395 *persistent_keyring_register;
	struct rw_semaphore___429 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___292 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct user_struct___395 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___395 *uid_keyring;
	struct key___395 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___415;

struct vm_area_struct___428 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___428 *vm_next;
	struct vm_area_struct___428 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___428 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___415 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___427 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___428;

struct mm_struct___428 {
	struct {
		struct vm_area_struct___428 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___427 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___429 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___428 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___429 *owner;
		struct user_namespace___292 *user_ns;
		struct file___427 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___428 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___395 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___395 *session_keyring;
	struct key___395 *process_keyring;
	struct key___395 *thread_keyring;
	struct key___395 *request_key_auth;
	void *security;
	struct user_struct___395 *user;
	struct user_namespace___292 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___84;

struct cgroup_namespace___276;

struct nsproxy___322 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net___84 *net_ns;
	struct cgroup_namespace___276 *cgroup_ns;
};

struct signal_struct___302 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___429 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___429 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___241 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___241 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___428 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___241 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___276;

struct cgroup___276;

struct css_set___276 {
	struct cgroup_subsys_state___276 *subsys[13];
	refcount_t refcount;
	struct css_set___276 *dom_cset;
	struct cgroup___276 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___276 *mg_src_cgrp;
	struct cgroup___276 *mg_dst_cgrp;
	struct css_set___276 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___427;

struct pipe_buffer___108;

struct pipe_inode_info___108 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___428 *tmp_page;
	struct fasync_struct___427 *fasync_readers;
	struct fasync_struct___427 *fasync_writers;
	struct pipe_buffer___108 *bufs;
	struct user_struct___395 *user;
};

struct vm_struct___331 {
	struct vm_struct___331 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___428 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___314 {
	struct task_struct___429 task;
	long unsigned int stack[8192];
};

struct address_space_operations___427;

struct address_space___427 {
	struct inode___427 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___429 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___427 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___415)(struct vm_area_struct___428 *, long unsigned int, const struct page___428 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___415)(struct page___428 *, void *);

struct device___395;

struct dev_pagemap___415 {
	dev_page_fault_t___415 page_fault;
	dev_page_free_t___415 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___395 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct dentry___427;

struct path___428 {
	struct vfsmount *mnt;
	struct dentry___427 *dentry;
};

struct file___427 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___428 f_path;
	struct inode___427 *f_inode;
	const struct file_operations___427 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___241 f_owner;
	const struct cred___395 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___427 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___415;

struct vm_operations_struct___415 {
	void (*open)(struct vm_area_struct___428 *);
	void (*close)(struct vm_area_struct___428 *);
	int (*split)(struct vm_area_struct___428 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___428 *);
	vm_fault_t (*fault)(struct vm_fault___415 *);
	vm_fault_t (*huge_fault)(struct vm_fault___415 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___415 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___428 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___415 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___415 *);
	int (*access)(struct vm_area_struct___428 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___428 *);
	int (*set_policy)(struct vm_area_struct___428 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___428 *, long unsigned int);
	struct page___428 * (*find_special_page)(struct vm_area_struct___428 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___428 {
	struct task_struct___429 *task;
	struct core_thread___428 *next;
};

struct core_state___428 {
	atomic_t nr_threads;
	struct core_thread___428 dumper;
	struct completion startup;
};

struct vm_fault___415 {
	struct vm_area_struct___428 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___428 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___428 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___428 prealloc_pte;
};

struct iov_iter___194 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___3 *bvec;
		struct pipe_inode_info___108 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct kiocb___427 {
	struct file___427 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___427 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dentry_operations___427;

struct super_block___427;

struct dentry___427 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___427 *d_parent;
	struct qstr d_name;
	struct inode___427 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___427 *d_op;
	struct super_block___427 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___427;

struct block_device___427;

struct inode___427 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___427 *i_op;
	struct super_block___427 *i_sb;
	struct address_space___427 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___429 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___427 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___427 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___108 *i_pipe;
		struct block_device___427 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___427 {
	int (*d_revalidate)(struct dentry___427 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___427 *, unsigned int);
	int (*d_hash)(const struct dentry___427 *, struct qstr *);
	int (*d_compare)(const struct dentry___427 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___427 *);
	int (*d_init)(struct dentry___427 *);
	void (*d_release)(struct dentry___427 *);
	void (*d_prune)(struct dentry___427 *);
	void (*d_iput)(struct dentry___427 *, struct inode___427 *);
	char * (*d_dname)(struct dentry___427 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___428 *);
	int (*d_manage)(const struct path___428 *, bool);
	struct dentry___427 * (*d_real)(struct dentry___427 *, const struct inode___427 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___427;

struct mem_dqinfo___427 {
	struct quota_format_type___427 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___427;

struct quota_info___427 {
	unsigned int flags;
	struct rw_semaphore___429 dqio_sem;
	struct inode___427 *files[3];
	struct mem_dqinfo___427 info[3];
	const struct quota_format_ops___427 *ops[3];
};

struct rcuwait___427 {
	struct task_struct___429 *task;
};

struct percpu_rw_semaphore___427 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___429 rw_sem;
	struct rcuwait___427 writer;
	int readers_block;
};

struct sb_writers___427 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___427 rw_sem[3];
};

struct file_system_type___427;

struct super_operations___427;

struct dquot_operations___427;

struct quotactl_ops___427;

struct super_block___427 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___427 *s_type;
	const struct super_operations___427 *s_op;
	const struct dquot_operations___427 *dq_op;
	const struct quotactl_ops___427 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___427 *s_root;
	struct rw_semaphore___429 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___427 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___427 s_dquot;
	struct sb_writers___427 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___427 *s_d_op;
	int cleancache_poolid;
	struct shrinker___161 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___292 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct iattr___427 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___427 *ia_file;
};

struct dquot___427 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___427 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___427 {
	int qf_fmt_id;
	const struct quota_format_ops___427 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___427 *qf_next;
};

struct quota_format_ops___427 {
	int (*check_quota_file)(struct super_block___427 *, int);
	int (*read_file_info)(struct super_block___427 *, int);
	int (*write_file_info)(struct super_block___427 *, int);
	int (*free_file_info)(struct super_block___427 *, int);
	int (*read_dqblk)(struct dquot___427 *);
	int (*commit_dqblk)(struct dquot___427 *);
	int (*release_dqblk)(struct dquot___427 *);
	int (*get_next_id)(struct super_block___427 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___427 {
	int (*write_dquot)(struct dquot___427 *);
	struct dquot___427 * (*alloc_dquot)(struct super_block___427 *, int);
	void (*destroy_dquot)(struct dquot___427 *);
	int (*acquire_dquot)(struct dquot___427 *);
	int (*release_dquot)(struct dquot___427 *);
	int (*mark_dirty)(struct dquot___427 *);
	int (*write_info)(struct super_block___427 *, int);
	qsize_t * (*get_reserved_space)(struct inode___427 *);
	int (*get_projid)(struct inode___427 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___427 *, qsize_t *);
	int (*get_next_id)(struct super_block___427 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___427 {
	int (*quota_on)(struct super_block___427 *, int, int, const struct path___428 *);
	int (*quota_off)(struct super_block___427 *, int);
	int (*quota_enable)(struct super_block___427 *, unsigned int);
	int (*quota_disable)(struct super_block___427 *, unsigned int);
	int (*quota_sync)(struct super_block___427 *, int);
	int (*set_info)(struct super_block___427 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___427 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___427 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___427 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___427 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___427 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___427 {
	int (*writepage)(struct page___428 *, struct writeback_control___3 *);
	int (*readpage)(struct file___427 *, struct page___428 *);
	int (*writepages)(struct address_space___427 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___428 *);
	int (*readpages)(struct file___427 *, struct address_space___427 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___427 *, struct address_space___427 *, loff_t, unsigned int, unsigned int, struct page___428 **, void **);
	int (*write_end)(struct file___427 *, struct address_space___427 *, loff_t, unsigned int, unsigned int, struct page___428 *, void *);
	sector_t (*bmap)(struct address_space___427 *, sector_t);
	void (*invalidatepage)(struct page___428 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___428 *, gfp_t);
	void (*freepage)(struct page___428 *);
	ssize_t (*direct_IO)(struct kiocb___427 *, struct iov_iter___194 *);
	int (*migratepage)(struct address_space___427 *, struct page___428 *, struct page___428 *, enum migrate_mode);
	bool (*isolate_page)(struct page___428 *, isolate_mode_t);
	void (*putback_page)(struct page___428 *);
	int (*launder_page)(struct page___428 *);
	int (*is_partially_uptodate)(struct page___428 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___428 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___427 *, struct page___428 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___427 *, sector_t *);
	void (*swap_deactivate)(struct file___427 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___427 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___427 *bd_inode;
	struct super_block___427 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___427 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___427 {
	struct dentry___427 * (*lookup)(struct inode___427 *, struct dentry___427 *, unsigned int);
	const char * (*get_link)(struct dentry___427 *, struct inode___427 *, struct delayed_call *);
	int (*permission)(struct inode___427 *, int);
	struct posix_acl * (*get_acl)(struct inode___427 *, int);
	int (*readlink)(struct dentry___427 *, char *, int);
	int (*create)(struct inode___427 *, struct dentry___427 *, umode_t, bool);
	int (*link)(struct dentry___427 *, struct inode___427 *, struct dentry___427 *);
	int (*unlink)(struct inode___427 *, struct dentry___427 *);
	int (*symlink)(struct inode___427 *, struct dentry___427 *, const char *);
	int (*mkdir)(struct inode___427 *, struct dentry___427 *, umode_t);
	int (*rmdir)(struct inode___427 *, struct dentry___427 *);
	int (*mknod)(struct inode___427 *, struct dentry___427 *, umode_t, dev_t);
	int (*rename)(struct inode___427 *, struct dentry___427 *, struct inode___427 *, struct dentry___427 *, unsigned int);
	int (*setattr)(struct dentry___427 *, struct iattr___427 *);
	int (*getattr)(const struct path___428 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___427 *, char *, size_t);
	int (*fiemap)(struct inode___427 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___427 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___427 *, struct dentry___427 *, struct file___427 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___427 *, struct dentry___427 *, umode_t);
	int (*set_acl)(struct inode___427 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___427 {
	void (*fl_copy_lock)(struct file_lock___427 *, struct file_lock___427 *);
	void (*fl_release_private)(struct file_lock___427 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___427;

struct file_lock___427 {
	struct file_lock___427 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___427 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___427 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___427 *fl_ops;
	const struct lock_manager_operations___427 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___427 {
	int (*lm_compare_owner)(struct file_lock___427 *, struct file_lock___427 *);
	long unsigned int (*lm_owner_key)(struct file_lock___427 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___427 *);
	int (*lm_grant)(struct file_lock___427 *, int);
	bool (*lm_break)(struct file_lock___427 *);
	int (*lm_change)(struct file_lock___427 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___427 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___427 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___427 *fa_next;
	struct file___427 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___427 {
	const char *name;
	int fs_flags;
	struct dentry___427 * (*mount)(struct file_system_type___427 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___427 *);
	struct module___11 *owner;
	struct file_system_type___427 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___427 {
	struct inode___427 * (*alloc_inode)(struct super_block___427 *);
	void (*destroy_inode)(struct inode___427 *);
	void (*dirty_inode)(struct inode___427 *, int);
	int (*write_inode)(struct inode___427 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___427 *);
	void (*evict_inode)(struct inode___427 *);
	void (*put_super)(struct super_block___427 *);
	int (*sync_fs)(struct super_block___427 *, int);
	int (*freeze_super)(struct super_block___427 *);
	int (*freeze_fs)(struct super_block___427 *);
	int (*thaw_super)(struct super_block___427 *);
	int (*unfreeze_fs)(struct super_block___427 *);
	int (*statfs)(struct dentry___427 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___427 *, int *, char *);
	void (*umount_begin)(struct super_block___427 *);
	int (*show_options)(struct seq_file___366 *, struct dentry___427 *);
	int (*show_devname)(struct seq_file___366 *, struct dentry___427 *);
	int (*show_path)(struct seq_file___366 *, struct dentry___427 *);
	int (*show_stats)(struct seq_file___366 *, struct dentry___427 *);
	ssize_t (*quota_read)(struct super_block___427 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___427 *, int, const char *, size_t, loff_t);
	struct dquot___427 ** (*get_dquots)(struct inode___427 *);
	int (*bdev_try_to_free_page)(struct super_block___427 *, struct page___428 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___427 *, struct shrink_control___161 *);
	long int (*free_cached_objects)(struct super_block___427 *, struct shrink_control___161 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___366;

struct seq_file___366 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___366 *op;
	int poll_event;
	const struct file___427 *file;
	void *private;
};

struct kset___414;

struct kobj_type___414;

struct kernfs_node___422;

struct kobject___415 {
	const char *name;
	struct list_head entry;
	struct kobject___415 *parent;
	struct kset___414 *kset;
	struct kobj_type___414 *ktype;
	struct kernfs_node___422 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct net_device___73;

struct nf_bridge_info___72;

struct sk_buff___74 {
	union {
		struct {
			struct sk_buff___74 *next;
			struct sk_buff___74 *prev;
			union {
				struct net_device___73 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___54 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___74 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___72 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___72;

struct netns_frags___72 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___72 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv4___72 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct sock *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock **tcp_sk;
	struct netns_frags___72 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct dst_ops___83 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___83 *);
	struct dst_entry___2 * (*check)(struct dst_entry___2 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___2 *);
	unsigned int (*mtu)(const struct dst_entry___2 *);
	u32 * (*cow_metrics)(struct dst_entry___2 *, long unsigned int);
	void (*destroy)(struct dst_entry___2 *);
	void (*ifdown)(struct dst_entry___2 *, struct net_device___73 *, int);
	struct dst_entry___2 * (*negative_advice)(struct dst_entry___2 *);
	void (*link_failure)(struct sk_buff___74 *);
	void (*update_pmtu)(struct dst_entry___2 *, struct sock *, struct sk_buff___74 *, u32);
	void (*redirect)(struct dst_entry___2 *, struct sock *, struct sk_buff___74 *);
	int (*local_out)(struct net___84 *, struct sock *, struct sk_buff___74 *);
	struct neighbour___2 * (*neigh_lookup)(const struct dst_entry___2 *, struct sk_buff___74 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___2 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___83 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___72 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___83 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct sock *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops *notifier_ops;
	struct fib_notifier_ops *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_nf_frag___72 {
	struct netns_frags___72 frags;
};

struct netns_xfrm___83 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___83 xfrm4_dst_ops;
	struct dst_ops___83 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct net___84 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___292 *user_ns;
	struct ucounts___292 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___29 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___73 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___72 ipv4;
	struct netns_ipv6___83 ipv6;
	struct netns_sctp___54 sctp;
	struct netns_nf___4 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___72 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock *nfnl;
	struct sock *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___83 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kernfs_root___421;

struct kernfs_elem_dir___421 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___421 *root;
};

struct kernfs_syscall_ops___421;

struct kernfs_root___421 {
	struct kernfs_node___422 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___421 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___421 {
	struct kernfs_node___422 *target_kn;
};

struct kernfs_ops___421;

struct kernfs_elem_attr___421 {
	const struct kernfs_ops___421 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___422 *notify_next;
};

struct kernfs_node___422 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___422 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___421 dir;
		struct kernfs_elem_symlink___421 symlink;
		struct kernfs_elem_attr___421 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___421;

struct kernfs_ops___421 {
	int (*open)(struct kernfs_open_file___421 *);
	void (*release)(struct kernfs_open_file___421 *);
	int (*seq_show)(struct seq_file___366 *, void *);
	void * (*seq_start)(struct seq_file___366 *, loff_t *);
	void * (*seq_next)(struct seq_file___366 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___366 *, void *);
	ssize_t (*read)(struct kernfs_open_file___421 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___421 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___421 *, struct vm_area_struct___428 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___421 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___421 {
	int (*remount_fs)(struct kernfs_root___421 *, int *, char *);
	int (*show_options)(struct seq_file___366 *, struct kernfs_root___421 *);
	int (*mkdir)(struct kernfs_node___422 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___422 *);
	int (*rename)(struct kernfs_node___422 *, struct kernfs_node___422 *, const char *);
	int (*show_path)(struct seq_file___366 *, struct kernfs_node___422 *, struct kernfs_root___421 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___421 {
	struct kernfs_node___422 *kn;
	struct file___427 *file;
	struct seq_file___366 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___415 *vm_ops;
};

struct bin_attribute___391;

struct attribute_group___392 {
	const char *name;
	umode_t (*is_visible)(struct kobject___415 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___415 *, struct bin_attribute___391 *, int);
	struct attribute **attrs;
	struct bin_attribute___391 **bin_attrs;
};

struct bin_attribute___391 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___427 *, struct kobject___415 *, struct bin_attribute___391 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___427 *, struct kobject___415 *, struct bin_attribute___391 *, char *, loff_t, size_t);
	int (*mmap)(struct file___427 *, struct kobject___415 *, struct bin_attribute___391 *, struct vm_area_struct___428 *);
};

struct sysfs_ops___414 {
	ssize_t (*show)(struct kobject___415 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___415 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___414;

struct kset___414 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___415 kobj;
	const struct kset_uevent_ops___414 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___414 {
	void (*release)(struct kobject___415 *);
	const struct sysfs_ops___414 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___53 * (*child_ns_type)(struct kobject___415 *);
	const void * (*namespace)(struct kobject___415 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___414 {
	int (* const filter)(struct kset___414 *, struct kobject___415 *);
	const char * (* const name)(struct kset___414 *, struct kobject___415 *);
	int (* const uevent)(struct kset___414 *, struct kobject___415 *, struct kobj_uevent_env *);
};

struct kobj_attribute___405 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___415 *, struct kobj_attribute___405 *, char *);
	ssize_t (*store)(struct kobject___415 *, struct kobj_attribute___405 *, const char *, size_t);
};

struct dev_pm_ops___395 {
	int (*prepare)(struct device___395 *);
	void (*complete)(struct device___395 *);
	int (*suspend)(struct device___395 *);
	int (*resume)(struct device___395 *);
	int (*freeze)(struct device___395 *);
	int (*thaw)(struct device___395 *);
	int (*poweroff)(struct device___395 *);
	int (*restore)(struct device___395 *);
	int (*suspend_late)(struct device___395 *);
	int (*resume_early)(struct device___395 *);
	int (*freeze_late)(struct device___395 *);
	int (*thaw_early)(struct device___395 *);
	int (*poweroff_late)(struct device___395 *);
	int (*restore_early)(struct device___395 *);
	int (*suspend_noirq)(struct device___395 *);
	int (*resume_noirq)(struct device___395 *);
	int (*freeze_noirq)(struct device___395 *);
	int (*thaw_noirq)(struct device___395 *);
	int (*poweroff_noirq)(struct device___395 *);
	int (*restore_noirq)(struct device___395 *);
	int (*runtime_suspend)(struct device___395 *);
	int (*runtime_resume)(struct device___395 *);
	int (*runtime_idle)(struct device___395 *);
};

struct dev_pm_info___395 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___395 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___395;

struct bus_type___395;

struct device_driver___395;

struct dev_pm_domain___395;

struct dma_map_ops___167;

struct fwnode_handle___315;

struct class___395;

struct device___395 {
	struct device___395 *parent;
	struct device_private *p;
	struct kobject___415 kobj;
	const char *init_name;
	const struct device_type___395 *type;
	struct mutex mutex;
	struct bus_type___395 *bus;
	struct device_driver___395 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___395 power;
	struct dev_pm_domain___395 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___167 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___315 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___395 *class;
	const struct attribute_group___392 **groups;
	void (*release)(struct device___395 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___395 {
	struct dev_pm_ops___395 ops;
	void (*detach)(struct device___395 *, bool);
	int (*activate)(struct device___395 *);
	void (*sync)(struct device___395 *);
	void (*dismiss)(struct device___395 *);
};

struct bus_type___395 {
	const char *name;
	const char *dev_name;
	struct device___395 *dev_root;
	const struct attribute_group___392 **bus_groups;
	const struct attribute_group___392 **dev_groups;
	const struct attribute_group___392 **drv_groups;
	int (*match)(struct device___395 *, struct device_driver___395 *);
	int (*uevent)(struct device___395 *, struct kobj_uevent_env *);
	int (*probe)(struct device___395 *);
	int (*remove)(struct device___395 *);
	void (*shutdown)(struct device___395 *);
	int (*online)(struct device___395 *);
	int (*offline)(struct device___395 *);
	int (*suspend)(struct device___395 *, pm_message_t);
	int (*resume)(struct device___395 *);
	int (*num_vf)(struct device___395 *);
	int (*dma_configure)(struct device___395 *);
	const struct dev_pm_ops___395 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___395 {
	const char *name;
	struct bus_type___395 *bus;
	struct module___11 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___395 *);
	int (*remove)(struct device___395 *);
	void (*shutdown)(struct device___395 *);
	int (*suspend)(struct device___395 *, pm_message_t);
	int (*resume)(struct device___395 *);
	const struct attribute_group___392 **groups;
	const struct dev_pm_ops___395 *pm;
	void (*coredump)(struct device___395 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___395 {
	const char *name;
	const struct attribute_group___392 **groups;
	int (*uevent)(struct device___395 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___395 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___395 *);
	const struct dev_pm_ops___395 *pm;
};

struct class___395 {
	const char *name;
	struct module___11 *owner;
	const struct attribute_group___392 **class_groups;
	const struct attribute_group___392 **dev_groups;
	struct kobject___415 *dev_kobj;
	int (*dev_uevent)(struct device___395 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___395 *, umode_t *);
	void (*class_release)(struct class___395 *);
	void (*dev_release)(struct device___395 *);
	int (*shutdown_pre)(struct device___395 *);
	const struct kobj_ns_type_operations___53 *ns_type;
	const void * (*namespace)(struct device___395 *);
	const struct dev_pm_ops___395 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___167 {
	void * (*alloc)(struct device___395 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___395 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___395 *, struct vm_area_struct___428 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___395 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___395 *, struct page___428 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___395 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___395 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___395 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___395 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___395 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___395 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___395 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___395 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___395 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___395 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___395 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___395 *, u64);
	u64 (*get_required_mask)(struct device___395 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___315;

struct fwnode_handle___315 {
	struct fwnode_handle___315 *secondary;
	const struct fwnode_operations___315 *ops;
};

typedef void compound_page_dtor___415(struct page___428 *);

struct fwnode_reference_args___315;

struct fwnode_endpoint___315;

struct fwnode_operations___315 {
	struct fwnode_handle___315 * (*get)(struct fwnode_handle___315 *);
	void (*put)(struct fwnode_handle___315 *);
	bool (*device_is_available)(const struct fwnode_handle___315 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___315 *, const struct device___395 *);
	bool (*property_present)(const struct fwnode_handle___315 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___315 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___315 *, const char *, const char **, size_t);
	struct fwnode_handle___315 * (*get_parent)(const struct fwnode_handle___315 *);
	struct fwnode_handle___315 * (*get_next_child_node)(const struct fwnode_handle___315 *, struct fwnode_handle___315 *);
	struct fwnode_handle___315 * (*get_named_child_node)(const struct fwnode_handle___315 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___315 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___315 *);
	struct fwnode_handle___315 * (*graph_get_next_endpoint)(const struct fwnode_handle___315 *, struct fwnode_handle___315 *);
	struct fwnode_handle___315 * (*graph_get_remote_endpoint)(const struct fwnode_handle___315 *);
	struct fwnode_handle___315 * (*graph_get_port_parent)(struct fwnode_handle___315 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___315 *, struct fwnode_endpoint___315 *);
};

struct fwnode_endpoint___315 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___315 *local_fwnode;
};

struct fwnode_reference_args___315 {
	struct fwnode_handle___315 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___108;

struct pipe_buffer___108 {
	struct page___428 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___108 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___108 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___108 *, struct pipe_buffer___108 *);
	void (*release)(struct pipe_inode_info___108 *, struct pipe_buffer___108 *);
	int (*steal)(struct pipe_inode_info___108 *, struct pipe_buffer___108 *);
	union {
		bool (*get)(struct pipe_inode_info___108 *, struct pipe_buffer___108 *);
		struct {
			void (*get)(struct pipe_inode_info___108 *, struct pipe_buffer___108 *);
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
};

struct nf_bridge_info___72 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___72 = 0,
		BRNF_PROTO_8021Q___72 = 1,
		BRNF_PROTO_PPPOE___72 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___73 *physindev;
	struct net_device___73 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___72(struct sk_buff___74 **);

typedef struct {
	struct net___84 *net;
} possible_net_t___74;

struct net_device_ops___72;

struct ethtool_ops___72;

struct xfrmdev_ops___72;

struct tlsdev_ops___72;

struct header_ops___72;

struct netdev_rx_queue___72;

struct mini_Qdisc___64;

struct netdev_queue___72;

struct Qdisc___64;

struct rtnl_link_ops___64;

struct dcbnl_rtnl_ops___72;

struct net_device___73 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___72 *netdev_ops;
	const struct ethtool_ops___72 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___2 *l3mdev_ops;
	const struct ndisc_ops___2 *ndisc_ops;
	const struct xfrmdev_ops___72 *xfrmdev_ops;
	const struct tlsdev_ops___72 *tlsdev_ops;
	const struct header_ops___72 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___414 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___2 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___72 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___72 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___64 *miniq_ingress;
	struct netdev_queue___72 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___72 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___64 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___64 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___72 = 0,
		NETREG_REGISTERED___72 = 1,
		NETREG_UNREGISTERING___72 = 2,
		NETREG_UNREGISTERED___72 = 3,
		NETREG_RELEASED___72 = 4,
		NETREG_DUMMY___72 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___72 = 0,
		RTNL_LINK_INITIALIZING___72 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___73 *);
	struct netpoll_info *npinfo;
	possible_net_t___74 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___395 dev;
	const struct attribute_group___392 *sysfs_groups[4];
	const struct attribute_group___392 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___64 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___72 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct sk_buff_head___72 {
	struct sk_buff___74 *next;
	struct sk_buff___74 *prev;
	__u32 qlen;
	spinlock_t lock;
};

typedef int (*key_restrict_link_func_t___396)(struct key___395 *, const struct key_type *, const union key_payload *, struct key___395 *);

struct key_restriction___395;

struct key___395 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___429 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___395 *restrict_link;
};

struct key_restriction___395 {
	key_restrict_link_func_t___396 check;
	struct key___395 *key;
	struct key_type *keytype;
};

struct cgroup_namespace___276 {
	refcount_t count;
	struct ns_common___29 ns;
	struct user_namespace___292 *user_ns;
	struct ucounts___292 *ucounts;
	struct css_set___276 *root_cset;
};

struct netlink_callback___74 {
	struct sk_buff___74 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___74 *);
	int (*dump)(struct sk_buff___74 *, struct netlink_callback___74 *);
	int (*done)(struct netlink_callback___74 *);
	void *data;
	struct module___11 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct ethtool_ops___72 {
	int (*get_settings)(struct net_device___73 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___73 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___73 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___73 *);
	void (*get_regs)(struct net_device___73 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___73 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___73 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___73 *);
	void (*set_msglevel)(struct net_device___73 *, u32);
	int (*nway_reset)(struct net_device___73 *);
	u32 (*get_link)(struct net_device___73 *);
	int (*get_eeprom_len)(struct net_device___73 *);
	int (*get_eeprom)(struct net_device___73 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___73 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___73 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___73 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___73 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___73 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___73 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___73 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___73 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___73 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___73 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___73 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___73 *);
	void (*complete)(struct net_device___73 *);
	u32 (*get_priv_flags)(struct net_device___73 *);
	int (*set_priv_flags)(struct net_device___73 *, u32);
	int (*get_sset_count)(struct net_device___73 *, int);
	int (*get_rxnfc)(struct net_device___73 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___73 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___73 *, struct ethtool_flash *);
	int (*reset)(struct net_device___73 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___73 *);
	u32 (*get_rxfh_indir_size)(struct net_device___73 *);
	int (*get_rxfh)(struct net_device___73 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___73 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___73 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___73 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___73 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___73 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___73 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___73 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___73 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___73 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___73 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___73 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___73 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___73 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___73 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___73 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___73 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___73 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___73 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___73 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___73 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___73 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	int (*get_fecparam)(struct net_device___73 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___73 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___73 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___73 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___73 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___72;

struct inet_frags___72 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___72 *, const void *);
	void (*destructor)(struct inet_frag_queue___72 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___72 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___74 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___74 *fragments_tail;
	struct sk_buff___74 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___72 *net;
	struct callback_head rcu;
};

struct ucounts___292 {
	struct hlist_node node;
	struct user_namespace___292 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct seq_operations___366 {
	void * (*start)(struct seq_file___366 *, loff_t *);
	void (*stop)(struct seq_file___366 *, void *);
	void * (*next)(struct seq_file___366 *, void *, loff_t *);
	int (*show)(struct seq_file___366 *, void *);
};

struct pernet_operations___73 {
	struct list_head list;
	int (*init)(struct net___84 *);
	void (*exit)(struct net___84 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___72 {
	int (*ieee_getets)(struct net_device___73 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___73 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___73 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___73 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___73 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___73 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___73 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___73 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___73 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___73 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___73 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___73 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___73 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___73 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___73 *);
	u8 (*setstate)(struct net_device___73 *, u8);
	void (*getpermhwaddr)(struct net_device___73 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___73 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___73 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___73 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___73 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___73 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___73 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___73 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___73 *, int, u8 *);
	void (*setpfccfg)(struct net_device___73 *, int, u8);
	void (*getpfccfg)(struct net_device___73 *, int, u8 *);
	u8 (*setall)(struct net_device___73 *);
	u8 (*getcap)(struct net_device___73 *, int, u8 *);
	int (*getnumtcs)(struct net_device___73 *, int, u8 *);
	int (*setnumtcs)(struct net_device___73 *, int, u8);
	u8 (*getpfcstate)(struct net_device___73 *);
	void (*setpfcstate)(struct net_device___73 *, u8);
	void (*getbcncfg)(struct net_device___73 *, int, u32 *);
	void (*setbcncfg)(struct net_device___73 *, int, u32);
	void (*getbcnrp)(struct net_device___73 *, int, u8 *);
	void (*setbcnrp)(struct net_device___73 *, int, u8);
	int (*setapp)(struct net_device___73 *, u8, u16, u8);
	int (*getapp)(struct net_device___73 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___73 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___73 *, int, u8);
	u8 (*getdcbx)(struct net_device___73 *);
	u8 (*setdcbx)(struct net_device___73 *, u8);
	int (*peer_getappinfo)(struct net_device___73 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___73 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___73 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___73 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___73 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___73 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct bpf_map___277;

struct bpf_map_ops___276 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___277 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___277 *, struct file___427 *);
	void (*map_free)(struct bpf_map___277 *);
	int (*map_get_next_key)(struct bpf_map___277 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___277 *);
	void * (*map_lookup_elem)(struct bpf_map___277 *, void *);
	int (*map_update_elem)(struct bpf_map___277 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___277 *, void *);
	int (*map_push_elem)(struct bpf_map___277 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___277 *, void *);
	int (*map_peek_elem)(struct bpf_map___277 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___277 *, struct file___427 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___277 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___277 *, void *, struct seq_file___366 *);
	int (*map_check_btf)(const struct bpf_map___277 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___277 {
	const struct bpf_map_ops___276 *ops;
	struct bpf_map___277 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___395 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___72;

struct bpf_map_dev_ops___72 {
	int (*map_get_next_key)(struct bpf_offloaded_map___72 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___72 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___72 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___72 *, void *);
};

struct bpf_offloaded_map___72 {
	struct bpf_map___277 map;
	struct net_device___73 *netdev;
	const struct bpf_map_dev_ops___72 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___277;

typedef void (*kthread_work_func_t___277)(struct kthread_work___277 *);

struct kthread_worker___277;

struct kthread_work___277 {
	struct list_head node;
	kthread_work_func_t___277 func;
	struct kthread_worker___277 *worker;
	int canceling;
};

struct kthread_worker___277 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___429 *task;
	struct kthread_work___277 *current_work;
};

struct kthread_delayed_work___276 {
	struct kthread_work___277 work;
	struct timer_list timer;
};

struct psi_group___276 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___277 *poll_kworker;
	struct kthread_delayed_work___276 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___276 {
	struct kernfs_node___422 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___276;

struct cgroup_subsys_state___276 {
	struct cgroup___276 *cgroup;
	struct cgroup_subsys___276 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___276 *parent;
};

struct cgroup_root___276;

struct cgroup_rstat_cpu___276;

struct cgroup___276 {
	struct cgroup_subsys_state___276 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___422 *kn;
	struct cgroup_file___276 procs_file;
	struct cgroup_file___276 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___276 *subsys[13];
	struct cgroup_root___276 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___276 *dom_cgrp;
	struct cgroup_rstat_cpu___276 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___63 bpf;
	atomic_t congestion_count;
	struct cgroup___276 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___276 psi;
	int ancestor_ids[0];
};

struct cftype___276;

struct cgroup_subsys___276 {
	struct cgroup_subsys_state___276 * (*css_alloc)(struct cgroup_subsys_state___276 *);
	int (*css_online)(struct cgroup_subsys_state___276 *);
	void (*css_offline)(struct cgroup_subsys_state___276 *);
	void (*css_released)(struct cgroup_subsys_state___276 *);
	void (*css_free)(struct cgroup_subsys_state___276 *);
	void (*css_reset)(struct cgroup_subsys_state___276 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___276 *, int);
	int (*css_extra_stat_show)(struct seq_file___366 *, struct cgroup_subsys_state___276 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___429 *);
	void (*cancel_fork)(struct task_struct___429 *);
	void (*fork)(struct task_struct___429 *);
	void (*exit)(struct task_struct___429 *);
	void (*free)(struct task_struct___429 *);
	void (*bind)(struct cgroup_subsys_state___276 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___276 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___276 *dfl_cftypes;
	struct cftype___276 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___276 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___276 *updated_children;
	struct cgroup___276 *updated_next;
};

struct cgroup_root___276 {
	struct kernfs_root___421 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___276 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___276 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___276 *ss;
	struct list_head node;
	struct kernfs_ops___421 *kf_ops;
	int (*open)(struct kernfs_open_file___421 *);
	void (*release)(struct kernfs_open_file___421 *);
	u64 (*read_u64)(struct cgroup_subsys_state___276 *, struct cftype___276 *);
	s64 (*read_s64)(struct cgroup_subsys_state___276 *, struct cftype___276 *);
	int (*seq_show)(struct seq_file___366 *, void *);
	void * (*seq_start)(struct seq_file___366 *, loff_t *);
	void * (*seq_next)(struct seq_file___366 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___366 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___276 *, struct cftype___276 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___276 *, struct cftype___276 *, s64);
	ssize_t (*write)(struct kernfs_open_file___421 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___421 *, struct poll_table_struct___6 *);
};

struct xdp_rxq_info___72 {
	struct net_device___73 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___72 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___73 *dev_rx;
};

struct header_ops___72 {
	int (*create)(struct sk_buff___74 *, struct net_device___73 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___74 *, unsigned char *);
	int (*cache)(const struct neighbour___2 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___73 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___72 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___72 *, int);
	int poll_owner;
	struct net_device___73 *dev;
	struct sk_buff___74 *gro_list;
	struct sk_buff___74 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___72 {
	struct net_device___73 *dev;
	struct Qdisc___64 *qdisc;
	struct Qdisc___64 *qdisc_sleeping;
	struct kobject___415 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___73 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___64 {
	struct sk_buff___74 *head;
	struct sk_buff___74 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___64;

struct Qdisc___64 {
	int (*enqueue)(struct sk_buff___74 *, struct Qdisc___64 *, struct sk_buff___74 **);
	struct sk_buff___74 * (*dequeue)(struct Qdisc___64 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___64 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___72 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___72 gso_skb;
	struct qdisc_skb_head___64 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___64 *next_sched;
	struct sk_buff_head___72 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___72 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___415 kobj;
	struct net_device___73 *dev;
	long: 64;
	struct xdp_rxq_info___72 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___72)(struct net_device___73 *, struct sk_buff___74 *, struct net_device___73 *);

struct netdev_bpf___72 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___63 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___63 *prog;
			const struct bpf_prog_offload_ops___63 *ops;
		} verifier;
		struct {
			struct bpf_prog___63 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___72 *offmap;
		};
		struct {
			struct xdp_umem___3 *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___72 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___74 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___72 {
	int (*tls_dev_add)(struct net_device___73 *, struct sock *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___73 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___73 *, struct sock *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___72 {
	int (*ndo_init)(struct net_device___73 *);
	void (*ndo_uninit)(struct net_device___73 *);
	int (*ndo_open)(struct net_device___73 *);
	int (*ndo_stop)(struct net_device___73 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___74 *, struct net_device___73 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___74 *, struct net_device___73 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___73 *, struct sk_buff___74 *, struct net_device___73 *, select_queue_fallback_t___72);
	void (*ndo_change_rx_flags)(struct net_device___73 *, int);
	void (*ndo_set_rx_mode)(struct net_device___73 *);
	int (*ndo_set_mac_address)(struct net_device___73 *, void *);
	int (*ndo_validate_addr)(struct net_device___73 *);
	int (*ndo_do_ioctl)(struct net_device___73 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___73 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___73 *, int);
	int (*ndo_neigh_setup)(struct net_device___73 *, struct neigh_parms___3 *);
	void (*ndo_tx_timeout)(struct net_device___73 *);
	void (*ndo_get_stats64)(struct net_device___73 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___73 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___73 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___73 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___73 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___73 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___73 *);
	int (*ndo_netpoll_setup)(struct net_device___73 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___73 *);
	int (*ndo_set_vf_mac)(struct net_device___73 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___73 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___73 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___73 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___73 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___73 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___73 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___73 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___73 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___73 *, int, struct sk_buff___74 *);
	int (*ndo_set_vf_guid)(struct net_device___73 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___73 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___73 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___73 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___73 *, const struct sk_buff___74 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___73 *, struct net_device___73 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___73 *, struct net_device___73 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___73 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___73 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___73 *, struct neighbour___2 *);
	void (*ndo_neigh_destroy)(struct net_device___73 *, struct neighbour___2 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___73 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___73 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___73 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___74 *, struct netlink_callback___74 *, struct net_device___73 *, struct net_device___73 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___73 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___73 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___74 *, u32, u32, struct net_device___73 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___73 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___73 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___73 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___73 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___73 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___73 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___73 *, struct net_device___73 *);
	void (*ndo_dfwd_del_station)(struct net_device___73 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___73 *);
	int (*ndo_set_tx_maxrate)(struct net_device___73 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___73 *);
	int (*ndo_change_proto_down)(struct net_device___73 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___73 *, struct sk_buff___74 *);
	void (*ndo_set_rx_headroom)(struct net_device___73 *, int);
	int (*ndo_bpf)(struct net_device___73 *, struct netdev_bpf___72 *);
	int (*ndo_xdp_xmit)(struct net_device___73 *, int, struct xdp_frame___72 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___73 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___73 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct tcf_proto___64;

struct mini_Qdisc___64 {
	struct tcf_proto___64 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___64 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___73 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___84 *, struct net_device___73 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___73 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___73 *, struct list_head *);
	size_t (*get_size)(const struct net_device___73 *);
	int (*fill_info)(struct sk_buff___74 *, const struct net_device___73 *);
	size_t (*get_xstats_size)(const struct net_device___73 *);
	int (*fill_xstats)(struct sk_buff___74 *, const struct net_device___73 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___73 *, struct net_device___73 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___73 *, const struct net_device___73 *);
	int (*fill_slave_info)(struct sk_buff___74 *, const struct net_device___73 *, const struct net_device___73 *);
	struct net___84 * (*get_link_net)(const struct net_device___73 *);
	size_t (*get_linkxstats_size)(const struct net_device___73 *, int);
	int (*fill_linkxstats)(struct sk_buff___74 *, const struct net_device___73 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___72 {
	struct list_head poll_list;
	struct sk_buff_head___72 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___72 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___64 *output_queue;
	struct Qdisc___64 **output_queue_tailp;
	struct sk_buff___74 *completion_queue;
	struct sk_buff_head___72 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___72 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___72 input_pkt_queue;
	struct napi_struct___72 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct gnet_dump___64 {
	spinlock_t *lock;
	struct sk_buff___74 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___64;

struct Qdisc_ops___64 {
	struct Qdisc_ops___64 *next;
	const struct Qdisc_class_ops___64 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___74 *, struct Qdisc___64 *, struct sk_buff___74 **);
	struct sk_buff___74 * (*dequeue)(struct Qdisc___64 *);
	struct sk_buff___74 * (*peek)(struct Qdisc___64 *);
	int (*init)(struct Qdisc___64 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___64 *);
	void (*destroy)(struct Qdisc___64 *);
	int (*change)(struct Qdisc___64 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___64 *);
	int (*change_tx_queue_len)(struct Qdisc___64 *, unsigned int);
	int (*dump)(struct Qdisc___64 *, struct sk_buff___74 *);
	int (*dump_stats)(struct Qdisc___64 *, struct gnet_dump___64 *);
	void (*ingress_block_set)(struct Qdisc___64 *, u32);
	void (*egress_block_set)(struct Qdisc___64 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___64 *);
	u32 (*egress_block_get)(struct Qdisc___64 *);
	struct module___11 *owner;
};

struct qdisc_walker___8;

struct tcf_block___64;

struct Qdisc_class_ops___64 {
	unsigned int flags;
	struct netdev_queue___72 * (*select_queue)(struct Qdisc___64 *, struct tcmsg *);
	int (*graft)(struct Qdisc___64 *, long unsigned int, struct Qdisc___64 *, struct Qdisc___64 **, struct netlink_ext_ack *);
	struct Qdisc___64 * (*leaf)(struct Qdisc___64 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___64 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___64 *, u32);
	int (*change)(struct Qdisc___64 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___64 *, long unsigned int);
	void (*walk)(struct Qdisc___64 *, struct qdisc_walker___8 *);
	struct tcf_block___64 * (*tcf_block)(struct Qdisc___64 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___64 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___64 *, long unsigned int);
	int (*dump)(struct Qdisc___64 *, long unsigned int, struct sk_buff___74 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___64 *, long unsigned int, struct gnet_dump___64 *);
};

struct qdisc_walker___8 {
	int stop;
	int skip;
	int count;
	int (*fn)(struct Qdisc___64 *, long unsigned int, struct qdisc_walker___8 *);
};

struct tcf_chain___64;

struct tcf_block___64 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___84 *net;
	struct Qdisc___64 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___64 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___64;

struct tcf_proto_ops___64;

struct tcf_proto___64 {
	struct tcf_proto___64 *next;
	void *root;
	int (*classify)(struct sk_buff___74 *, const struct tcf_proto___64 *, struct tcf_result___64 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___64 *ops;
	struct tcf_chain___64 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___64 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___64 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_walker___4;

struct tcf_proto_ops___64 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___74 *, const struct tcf_proto___64 *, struct tcf_result___64 *);
	int (*init)(struct tcf_proto___64 *);
	void (*destroy)(struct tcf_proto___64 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___64 *, u32);
	void (*put)(struct tcf_proto___64 *, void *);
	int (*change)(struct net___84 *, struct sk_buff___74 *, struct tcf_proto___64 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___64 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___64 *, struct tcf_walker___4 *, bool);
	int (*reoffload)(struct tcf_proto___64 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___84 *, struct tcf_chain___64 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___84 *, struct tcf_proto___64 *, void *, struct sk_buff___74 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___74 *, struct net___84 *, void *);
	struct module___11 *owner;
	int flags;
};

struct tcf_walker___4 {
	int stop;
	int skip;
	int count;
	bool nonempty;
	long unsigned int cookie;
	int (*fn)(struct tcf_proto___64 *, void *, struct tcf_walker___4 *);
};

struct tcf_chain___64 {
	struct mutex filter_chain_lock;
	struct tcf_proto___64 *filter_chain;
	struct list_head list;
	struct tcf_block___64 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___64 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct tc_qopt_offload_stats {
	struct gnet_stats_basic_packed *bstats;
	struct gnet_stats_queue *qstats;
};

enum tc_mq_command {
	TC_MQ_CREATE = 0,
	TC_MQ_DESTROY = 1,
	TC_MQ_STATS = 2,
	TC_MQ_GRAFT = 3,
};

struct tc_mq_opt_offload_graft_params {
	long unsigned int queue;
	u32 child_handle;
};

struct tc_mq_qopt_offload {
	enum tc_mq_command command;
	u32 handle;
	union {
		struct tc_qopt_offload_stats stats;
		struct tc_mq_opt_offload_graft_params graft_params;
	};
};

struct mq_sched {
	struct Qdisc___64 **qdiscs;
};

enum tc_link_layer {
	TC_LINKLAYER_UNAWARE = 0,
	TC_LINKLAYER_ETHERNET = 1,
	TC_LINKLAYER_ATM = 2,
};

enum {
	TCA_STAB_UNSPEC = 0,
	TCA_STAB_BASE = 1,
	TCA_STAB_DATA = 2,
	__TCA_STAB_MAX = 3,
};

struct qdisc_rate_table {
	struct tc_ratespec rate;
	u32 data[256];
	struct qdisc_rate_table *next;
	int refcnt;
};

struct tcf_walker {
	int stop;
	int skip;
	int count;
	bool nonempty;
	long unsigned int cookie;
	int (*fn)(struct tcf_proto___62 *, void *, struct tcf_walker *);
};

struct Qdisc_class_common {
	u32 classid;
	struct hlist_node hnode;
};

struct Qdisc_class_hash {
	struct hlist_head *hash;
	unsigned int hashsize;
	unsigned int hashmask;
	unsigned int hashelems;
};

struct qdisc_watchdog {
	u64 last_expires;
	struct hrtimer timer;
	struct Qdisc___62 *qdisc;
};

enum tc_root_command {
	TC_ROOT_GRAFT = 0,
};

struct tc_root_qopt_offload {
	enum tc_root_command command;
	u32 handle;
	bool ingress;
};

struct check_loop_arg {
	struct qdisc_walker___6 w;
	struct Qdisc___62 *p;
	int depth;
};

struct tcf_bind_args {
	struct tcf_walker w;
	u32 classid;
	long unsigned int cl;
};

struct qdisc_dump_args {
	struct qdisc_walker___6 w;
	struct sk_buff___72 *skb;
	struct netlink_callback___72 *cb;
};

struct file___428;

struct kiocb___428;

struct iov_iter___195;

struct vm_area_struct___429;

struct inode___428;

struct file_lock___428;

struct page___429;

struct pipe_inode_info___109;

struct seq_file___367;

struct file_operations___428 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___428 *, loff_t, int);
	ssize_t (*read)(struct file___428 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___428 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___428 *, struct iov_iter___195 *);
	ssize_t (*write_iter)(struct kiocb___428 *, struct iov_iter___195 *);
	int (*iopoll)(struct kiocb___428 *, bool);
	int (*iterate)(struct file___428 *, struct dir_context *);
	int (*iterate_shared)(struct file___428 *, struct dir_context *);
	__poll_t (*poll)(struct file___428 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___428 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___428 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___428 *, struct vm_area_struct___429 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___428 *, struct file___428 *);
	int (*flush)(struct file___428 *, fl_owner_t);
	int (*release)(struct inode___428 *, struct file___428 *);
	int (*fsync)(struct file___428 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___428 *, int);
	int (*lock)(struct file___428 *, int, struct file_lock___428 *);
	ssize_t (*sendpage)(struct file___428 *, struct page___429 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___428 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___428 *, int, struct file_lock___428 *);
	ssize_t (*splice_write)(struct pipe_inode_info___109 *, struct file___428 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___428 *, loff_t *, struct pipe_inode_info___109 *, size_t, unsigned int);
	int (*setlease)(struct file___428 *, long int, struct file_lock___428 **, void **);
	long int (*fallocate)(struct file___428 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___367 *, struct file___428 *);
	ssize_t (*copy_file_range)(struct file___428 *, loff_t, struct file___428 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___428 *, loff_t, struct file___428 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___428 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___429 {
	u64 seqnum;
	struct vm_area_struct___429 *vmas[4];
};

struct page_frag___429 {
	struct page___429 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___429;

struct cred___396;

struct nsproxy___323;

struct signal_struct___303;

struct css_set___277;

struct vm_struct___332;

struct task_struct___430 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___430 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___429 *mm;
	struct mm_struct___429 *active_mm;
	struct vmacache___429 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___430 *real_parent;
	struct task_struct___430 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___430 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___2 *active_memcg;
	long int rh_reserved2;
	struct pid___241 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___241 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___241 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___396 *ptracer_cred;
	const struct cred___396 *real_cred;
	const struct cred___396 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___323 *nsproxy;
	struct signal_struct___303 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___430 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___277 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___109 *splice_pipe;
	struct page_frag___429 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___430 *oom_reaper_list;
	struct vm_struct___332 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___156 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___429 *pgtable_t___429;

struct address_space___428;

struct dev_pagemap___416;

struct page___429 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___428 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___429 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___429 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___429 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___416 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___2 *mem_cgroup;
};

struct pglist_data___429;

struct lruvec___429 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___429 *pgdat;
};

struct zone___429 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___429 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___429 {
	struct zone___429 *zone;
	int zone_idx;
};

struct zonelist___429 {
	struct zoneref___429 _zonerefs[25];
};

struct pglist_data___429 {
	struct zone___429 node_zones[3];
	struct zonelist___429 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___430 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___430 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___429 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___430 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___430 *owner;
};

struct secondary_data___430 {
	void *stack;
	struct task_struct___430 *task;
	long int status;
};

struct blocking_notifier_head___429 {
	struct rw_semaphore___430 rwsem;
	struct notifier_block *head;
};

struct key___396;

struct ucounts___293;

struct user_namespace___293 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___293 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___29 ns;
	long unsigned int flags;
	struct key___396 *persistent_keyring_register;
	struct rw_semaphore___430 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___293 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct user_struct___396 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___396 *uid_keyring;
	struct key___396 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___416;

struct vm_area_struct___429 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___429 *vm_next;
	struct vm_area_struct___429 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___429 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___416 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___428 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___429;

struct mm_struct___429 {
	struct {
		struct vm_area_struct___429 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___428 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___430 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___429 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___430 *owner;
		struct user_namespace___293 *user_ns;
		struct file___428 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___429 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___396 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___396 *session_keyring;
	struct key___396 *process_keyring;
	struct key___396 *thread_keyring;
	struct key___396 *request_key_auth;
	void *security;
	struct user_struct___396 *user;
	struct user_namespace___293 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___85;

struct cgroup_namespace___277;

struct nsproxy___323 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net___85 *net_ns;
	struct cgroup_namespace___277 *cgroup_ns;
};

struct signal_struct___303 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___430 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___430 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___241 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___241 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___429 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___241 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cgroup_subsys_state___277;

struct cgroup___277;

struct css_set___277 {
	struct cgroup_subsys_state___277 *subsys[13];
	refcount_t refcount;
	struct css_set___277 *dom_cset;
	struct cgroup___277 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___277 *mg_src_cgrp;
	struct cgroup___277 *mg_dst_cgrp;
	struct css_set___277 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___428;

struct pipe_buffer___109;

struct pipe_inode_info___109 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___429 *tmp_page;
	struct fasync_struct___428 *fasync_readers;
	struct fasync_struct___428 *fasync_writers;
	struct pipe_buffer___109 *bufs;
	struct user_struct___396 *user;
};

struct vm_struct___332 {
	struct vm_struct___332 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___429 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___315 {
	struct task_struct___430 task;
	long unsigned int stack[8192];
};

struct address_space_operations___428;

struct address_space___428 {
	struct inode___428 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___430 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___428 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___416)(struct vm_area_struct___429 *, long unsigned int, const struct page___429 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___416)(struct page___429 *, void *);

struct device___396;

struct dev_pagemap___416 {
	dev_page_fault_t___416 page_fault;
	dev_page_free_t___416 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___396 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct dentry___428;

struct path___429 {
	struct vfsmount *mnt;
	struct dentry___428 *dentry;
};

struct file___428 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___429 f_path;
	struct inode___428 *f_inode;
	const struct file_operations___428 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___241 f_owner;
	const struct cred___396 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___428 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___416;

struct vm_operations_struct___416 {
	void (*open)(struct vm_area_struct___429 *);
	void (*close)(struct vm_area_struct___429 *);
	int (*split)(struct vm_area_struct___429 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___429 *);
	vm_fault_t (*fault)(struct vm_fault___416 *);
	vm_fault_t (*huge_fault)(struct vm_fault___416 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___416 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___429 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___416 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___416 *);
	int (*access)(struct vm_area_struct___429 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___429 *);
	int (*set_policy)(struct vm_area_struct___429 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___429 *, long unsigned int);
	struct page___429 * (*find_special_page)(struct vm_area_struct___429 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___429 {
	struct task_struct___430 *task;
	struct core_thread___429 *next;
};

struct core_state___429 {
	atomic_t nr_threads;
	struct core_thread___429 dumper;
	struct completion startup;
};

struct vm_fault___416 {
	struct vm_area_struct___429 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___429 *cow_page;
	struct mem_cgroup___2 *memcg;
	struct page___429 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___429 prealloc_pte;
};

struct iov_iter___195 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___3 *bvec;
		struct pipe_inode_info___109 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct kiocb___428 {
	struct file___428 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___428 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dentry_operations___428;

struct super_block___428;

struct dentry___428 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___428 *d_parent;
	struct qstr d_name;
	struct inode___428 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___428 *d_op;
	struct super_block___428 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___428;

struct block_device___428;

struct inode___428 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___428 *i_op;
	struct super_block___428 *i_sb;
	struct address_space___428 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___430 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___428 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___428 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___109 *i_pipe;
		struct block_device___428 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___428 {
	int (*d_revalidate)(struct dentry___428 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___428 *, unsigned int);
	int (*d_hash)(const struct dentry___428 *, struct qstr *);
	int (*d_compare)(const struct dentry___428 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___428 *);
	int (*d_init)(struct dentry___428 *);
	void (*d_release)(struct dentry___428 *);
	void (*d_prune)(struct dentry___428 *);
	void (*d_iput)(struct dentry___428 *, struct inode___428 *);
	char * (*d_dname)(struct dentry___428 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___429 *);
	int (*d_manage)(const struct path___429 *, bool);
	struct dentry___428 * (*d_real)(struct dentry___428 *, const struct inode___428 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___428;

struct mem_dqinfo___428 {
	struct quota_format_type___428 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___428;

struct quota_info___428 {
	unsigned int flags;
	struct rw_semaphore___430 dqio_sem;
	struct inode___428 *files[3];
	struct mem_dqinfo___428 info[3];
	const struct quota_format_ops___428 *ops[3];
};

struct rcuwait___428 {
	struct task_struct___430 *task;
};

struct percpu_rw_semaphore___428 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___430 rw_sem;
	struct rcuwait___428 writer;
	int readers_block;
};

struct sb_writers___428 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___428 rw_sem[3];
};

struct file_system_type___428;

struct super_operations___428;

struct dquot_operations___428;

struct quotactl_ops___428;

struct super_block___428 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___428 *s_type;
	const struct super_operations___428 *s_op;
	const struct dquot_operations___428 *dq_op;
	const struct quotactl_ops___428 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___428 *s_root;
	struct rw_semaphore___430 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___428 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___428 s_dquot;
	struct sb_writers___428 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___428 *s_d_op;
	int cleancache_poolid;
	struct shrinker___161 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___293 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct iattr___428 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___428 *ia_file;
};

struct dquot___428 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___428 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___428 {
	int qf_fmt_id;
	const struct quota_format_ops___428 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___428 *qf_next;
};

struct quota_format_ops___428 {
	int (*check_quota_file)(struct super_block___428 *, int);
	int (*read_file_info)(struct super_block___428 *, int);
	int (*write_file_info)(struct super_block___428 *, int);
	int (*free_file_info)(struct super_block___428 *, int);
	int (*read_dqblk)(struct dquot___428 *);
	int (*commit_dqblk)(struct dquot___428 *);
	int (*release_dqblk)(struct dquot___428 *);
	int (*get_next_id)(struct super_block___428 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___428 {
	int (*write_dquot)(struct dquot___428 *);
	struct dquot___428 * (*alloc_dquot)(struct super_block___428 *, int);
	void (*destroy_dquot)(struct dquot___428 *);
	int (*acquire_dquot)(struct dquot___428 *);
	int (*release_dquot)(struct dquot___428 *);
	int (*mark_dirty)(struct dquot___428 *);
	int (*write_info)(struct super_block___428 *, int);
	qsize_t * (*get_reserved_space)(struct inode___428 *);
	int (*get_projid)(struct inode___428 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___428 *, qsize_t *);
	int (*get_next_id)(struct super_block___428 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___428 {
	int (*quota_on)(struct super_block___428 *, int, int, const struct path___429 *);
	int (*quota_off)(struct super_block___428 *, int);
	int (*quota_enable)(struct super_block___428 *, unsigned int);
	int (*quota_disable)(struct super_block___428 *, unsigned int);
	int (*quota_sync)(struct super_block___428 *, int);
	int (*set_info)(struct super_block___428 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___428 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___428 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___428 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___428 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___428 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct address_space_operations___428 {
	int (*writepage)(struct page___429 *, struct writeback_control___3 *);
	int (*readpage)(struct file___428 *, struct page___429 *);
	int (*writepages)(struct address_space___428 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___429 *);
	int (*readpages)(struct file___428 *, struct address_space___428 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___428 *, struct address_space___428 *, loff_t, unsigned int, unsigned int, struct page___429 **, void **);
	int (*write_end)(struct file___428 *, struct address_space___428 *, loff_t, unsigned int, unsigned int, struct page___429 *, void *);
	sector_t (*bmap)(struct address_space___428 *, sector_t);
	void (*invalidatepage)(struct page___429 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___429 *, gfp_t);
	void (*freepage)(struct page___429 *);
	ssize_t (*direct_IO)(struct kiocb___428 *, struct iov_iter___195 *);
	int (*migratepage)(struct address_space___428 *, struct page___429 *, struct page___429 *, enum migrate_mode);
	bool (*isolate_page)(struct page___429 *, isolate_mode_t);
	void (*putback_page)(struct page___429 *);
	int (*launder_page)(struct page___429 *);
	int (*is_partially_uptodate)(struct page___429 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___429 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___428 *, struct page___429 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___428 *, sector_t *);
	void (*swap_deactivate)(struct file___428 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct block_device___428 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___428 *bd_inode;
	struct super_block___428 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___428 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___2 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___428 {
	struct dentry___428 * (*lookup)(struct inode___428 *, struct dentry___428 *, unsigned int);
	const char * (*get_link)(struct dentry___428 *, struct inode___428 *, struct delayed_call *);
	int (*permission)(struct inode___428 *, int);
	struct posix_acl * (*get_acl)(struct inode___428 *, int);
	int (*readlink)(struct dentry___428 *, char *, int);
	int (*create)(struct inode___428 *, struct dentry___428 *, umode_t, bool);
	int (*link)(struct dentry___428 *, struct inode___428 *, struct dentry___428 *);
	int (*unlink)(struct inode___428 *, struct dentry___428 *);
	int (*symlink)(struct inode___428 *, struct dentry___428 *, const char *);
	int (*mkdir)(struct inode___428 *, struct dentry___428 *, umode_t);
	int (*rmdir)(struct inode___428 *, struct dentry___428 *);
	int (*mknod)(struct inode___428 *, struct dentry___428 *, umode_t, dev_t);
	int (*rename)(struct inode___428 *, struct dentry___428 *, struct inode___428 *, struct dentry___428 *, unsigned int);
	int (*setattr)(struct dentry___428 *, struct iattr___428 *);
	int (*getattr)(const struct path___429 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___428 *, char *, size_t);
	int (*fiemap)(struct inode___428 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___428 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___428 *, struct dentry___428 *, struct file___428 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___428 *, struct dentry___428 *, umode_t);
	int (*set_acl)(struct inode___428 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___428 {
	void (*fl_copy_lock)(struct file_lock___428 *, struct file_lock___428 *);
	void (*fl_release_private)(struct file_lock___428 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___428;

struct file_lock___428 {
	struct file_lock___428 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___428 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___428 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___428 *fl_ops;
	const struct lock_manager_operations___428 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___428 {
	int (*lm_compare_owner)(struct file_lock___428 *, struct file_lock___428 *);
	long unsigned int (*lm_owner_key)(struct file_lock___428 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___428 *);
	int (*lm_grant)(struct file_lock___428 *, int);
	bool (*lm_break)(struct file_lock___428 *);
	int (*lm_change)(struct file_lock___428 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___428 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___428 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___428 *fa_next;
	struct file___428 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___428 {
	const char *name;
	int fs_flags;
	struct dentry___428 * (*mount)(struct file_system_type___428 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___428 *);
	struct module___11 *owner;
	struct file_system_type___428 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___428 {
	struct inode___428 * (*alloc_inode)(struct super_block___428 *);
	void (*destroy_inode)(struct inode___428 *);
	void (*dirty_inode)(struct inode___428 *, int);
	int (*write_inode)(struct inode___428 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___428 *);
	void (*evict_inode)(struct inode___428 *);
	void (*put_super)(struct super_block___428 *);
	int (*sync_fs)(struct super_block___428 *, int);
	int (*freeze_super)(struct super_block___428 *);
	int (*freeze_fs)(struct super_block___428 *);
	int (*thaw_super)(struct super_block___428 *);
	int (*unfreeze_fs)(struct super_block___428 *);
	int (*statfs)(struct dentry___428 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___428 *, int *, char *);
	void (*umount_begin)(struct super_block___428 *);
	int (*show_options)(struct seq_file___367 *, struct dentry___428 *);
	int (*show_devname)(struct seq_file___367 *, struct dentry___428 *);
	int (*show_path)(struct seq_file___367 *, struct dentry___428 *);
	int (*show_stats)(struct seq_file___367 *, struct dentry___428 *);
	ssize_t (*quota_read)(struct super_block___428 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___428 *, int, const char *, size_t, loff_t);
	struct dquot___428 ** (*get_dquots)(struct inode___428 *);
	int (*bdev_try_to_free_page)(struct super_block___428 *, struct page___429 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___428 *, struct shrink_control___161 *);
	long int (*free_cached_objects)(struct super_block___428 *, struct shrink_control___161 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___367;

struct seq_file___367 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___367 *op;
	int poll_event;
	const struct file___428 *file;
	void *private;
};

struct kset___415;

struct kobj_type___415;

struct kernfs_node___423;

struct kobject___416 {
	const char *name;
	struct list_head entry;
	struct kobject___416 *parent;
	struct kset___415 *kset;
	struct kobj_type___415 *ktype;
	struct kernfs_node___423 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct net_device___74;

struct nf_bridge_info___73;

struct sk_buff___75 {
	union {
		struct {
			struct sk_buff___75 *next;
			struct sk_buff___75 *prev;
			union {
				struct net_device___74 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___54 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___75 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___73 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___73;

struct netns_frags___73 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___73 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv4___73 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct sock *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock **tcp_sk;
	struct netns_frags___73 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct dst_ops___84 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___84 *);
	struct dst_entry___2 * (*check)(struct dst_entry___2 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___2 *);
	unsigned int (*mtu)(const struct dst_entry___2 *);
	u32 * (*cow_metrics)(struct dst_entry___2 *, long unsigned int);
	void (*destroy)(struct dst_entry___2 *);
	void (*ifdown)(struct dst_entry___2 *, struct net_device___74 *, int);
	struct dst_entry___2 * (*negative_advice)(struct dst_entry___2 *);
	void (*link_failure)(struct sk_buff___75 *);
	void (*update_pmtu)(struct dst_entry___2 *, struct sock *, struct sk_buff___75 *, u32);
	void (*redirect)(struct dst_entry___2 *, struct sock *, struct sk_buff___75 *);
	int (*local_out)(struct net___85 *, struct sock *, struct sk_buff___75 *);
	struct neighbour___2 * (*neigh_lookup)(const struct dst_entry___2 *, struct sk_buff___75 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___2 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___84 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___73 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___84 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct sock *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops *notifier_ops;
	struct fib_notifier_ops *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_nf_frag___73 {
	struct netns_frags___73 frags;
};

struct netns_xfrm___84 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___84 xfrm4_dst_ops;
	struct dst_ops___84 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct net___85 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___293 *user_ns;
	struct ucounts___293 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___29 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___74 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___73 ipv4;
	struct netns_ipv6___84 ipv6;
	struct netns_sctp___54 sctp;
	struct netns_nf___4 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___73 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock *nfnl;
	struct sock *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___84 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kernfs_root___422;

struct kernfs_elem_dir___422 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___422 *root;
};

struct kernfs_syscall_ops___422;

struct kernfs_root___422 {
	struct kernfs_node___423 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___422 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___422 {
	struct kernfs_node___423 *target_kn;
};

struct kernfs_ops___422;

struct kernfs_elem_attr___422 {
	const struct kernfs_ops___422 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___423 *notify_next;
};

struct kernfs_node___423 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___423 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___422 dir;
		struct kernfs_elem_symlink___422 symlink;
		struct kernfs_elem_attr___422 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___422;

struct kernfs_ops___422 {
	int (*open)(struct kernfs_open_file___422 *);
	void (*release)(struct kernfs_open_file___422 *);
	int (*seq_show)(struct seq_file___367 *, void *);
	void * (*seq_start)(struct seq_file___367 *, loff_t *);
	void * (*seq_next)(struct seq_file___367 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___367 *, void *);
	ssize_t (*read)(struct kernfs_open_file___422 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___422 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___422 *, struct vm_area_struct___429 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___422 *, struct poll_table_struct___6 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___422 {
	int (*remount_fs)(struct kernfs_root___422 *, int *, char *);
	int (*show_options)(struct seq_file___367 *, struct kernfs_root___422 *);
	int (*mkdir)(struct kernfs_node___423 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___423 *);
	int (*rename)(struct kernfs_node___423 *, struct kernfs_node___423 *, const char *);
	int (*show_path)(struct seq_file___367 *, struct kernfs_node___423 *, struct kernfs_root___422 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___422 {
	struct kernfs_node___423 *kn;
	struct file___428 *file;
	struct seq_file___367 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___416 *vm_ops;
};

struct bin_attribute___392;

struct attribute_group___393 {
	const char *name;
	umode_t (*is_visible)(struct kobject___416 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___416 *, struct bin_attribute___392 *, int);
	struct attribute **attrs;
	struct bin_attribute___392 **bin_attrs;
};

struct bin_attribute___392 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___428 *, struct kobject___416 *, struct bin_attribute___392 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___428 *, struct kobject___416 *, struct bin_attribute___392 *, char *, loff_t, size_t);
	int (*mmap)(struct file___428 *, struct kobject___416 *, struct bin_attribute___392 *, struct vm_area_struct___429 *);
};

struct sysfs_ops___415 {
	ssize_t (*show)(struct kobject___416 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___416 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___415;

struct kset___415 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___416 kobj;
	const struct kset_uevent_ops___415 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___415 {
	void (*release)(struct kobject___416 *);
	const struct sysfs_ops___415 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___53 * (*child_ns_type)(struct kobject___416 *);
	const void * (*namespace)(struct kobject___416 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___415 {
	int (* const filter)(struct kset___415 *, struct kobject___416 *);
	const char * (* const name)(struct kset___415 *, struct kobject___416 *);
	int (* const uevent)(struct kset___415 *, struct kobject___416 *, struct kobj_uevent_env *);
};

struct kobj_attribute___406 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___416 *, struct kobj_attribute___406 *, char *);
	ssize_t (*store)(struct kobject___416 *, struct kobj_attribute___406 *, const char *, size_t);
};

struct dev_pm_ops___396 {
	int (*prepare)(struct device___396 *);
	void (*complete)(struct device___396 *);
	int (*suspend)(struct device___396 *);
	int (*resume)(struct device___396 *);
	int (*freeze)(struct device___396 *);
	int (*thaw)(struct device___396 *);
	int (*poweroff)(struct device___396 *);
	int (*restore)(struct device___396 *);
	int (*suspend_late)(struct device___396 *);
	int (*resume_early)(struct device___396 *);
	int (*freeze_late)(struct device___396 *);
	int (*thaw_early)(struct device___396 *);
	int (*poweroff_late)(struct device___396 *);
	int (*restore_early)(struct device___396 *);
	int (*suspend_noirq)(struct device___396 *);
	int (*resume_noirq)(struct device___396 *);
	int (*freeze_noirq)(struct device___396 *);
	int (*thaw_noirq)(struct device___396 *);
	int (*poweroff_noirq)(struct device___396 *);
	int (*restore_noirq)(struct device___396 *);
	int (*runtime_suspend)(struct device___396 *);
	int (*runtime_resume)(struct device___396 *);
	int (*runtime_idle)(struct device___396 *);
};

struct dev_pm_info___396 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___396 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___396;

struct bus_type___396;

struct device_driver___396;

struct dev_pm_domain___396;

struct dma_map_ops___168;

struct fwnode_handle___316;

struct class___396;

struct device___396 {
	struct device___396 *parent;
	struct device_private *p;
	struct kobject___416 kobj;
	const char *init_name;
	const struct device_type___396 *type;
	struct mutex mutex;
	struct bus_type___396 *bus;
	struct device_driver___396 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___396 power;
	struct dev_pm_domain___396 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___168 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___316 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___396 *class;
	const struct attribute_group___393 **groups;
	void (*release)(struct device___396 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___396 {
	struct dev_pm_ops___396 ops;
	void (*detach)(struct device___396 *, bool);
	int (*activate)(struct device___396 *);
	void (*sync)(struct device___396 *);
	void (*dismiss)(struct device___396 *);
};

struct bus_type___396 {
	const char *name;
	const char *dev_name;
	struct device___396 *dev_root;
	const struct attribute_group___393 **bus_groups;
	const struct attribute_group___393 **dev_groups;
	const struct attribute_group___393 **drv_groups;
	int (*match)(struct device___396 *, struct device_driver___396 *);
	int (*uevent)(struct device___396 *, struct kobj_uevent_env *);
	int (*probe)(struct device___396 *);
	int (*remove)(struct device___396 *);
	void (*shutdown)(struct device___396 *);
	int (*online)(struct device___396 *);
	int (*offline)(struct device___396 *);
	int (*suspend)(struct device___396 *, pm_message_t);
	int (*resume)(struct device___396 *);
	int (*num_vf)(struct device___396 *);
	int (*dma_configure)(struct device___396 *);
	const struct dev_pm_ops___396 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___396 {
	const char *name;
	struct bus_type___396 *bus;
	struct module___11 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___396 *);
	int (*remove)(struct device___396 *);
	void (*shutdown)(struct device___396 *);
	int (*suspend)(struct device___396 *, pm_message_t);
	int (*resume)(struct device___396 *);
	const struct attribute_group___393 **groups;
	const struct dev_pm_ops___396 *pm;
	void (*coredump)(struct device___396 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___396 {
	const char *name;
	const struct attribute_group___393 **groups;
	int (*uevent)(struct device___396 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___396 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___396 *);
	const struct dev_pm_ops___396 *pm;
};

struct class___396 {
	const char *name;
	struct module___11 *owner;
	const struct attribute_group___393 **class_groups;
	const struct attribute_group___393 **dev_groups;
	struct kobject___416 *dev_kobj;
	int (*dev_uevent)(struct device___396 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___396 *, umode_t *);
	void (*class_release)(struct class___396 *);
	void (*dev_release)(struct device___396 *);
	int (*shutdown_pre)(struct device___396 *);
	const struct kobj_ns_type_operations___53 *ns_type;
	const void * (*namespace)(struct device___396 *);
	const struct dev_pm_ops___396 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___168 {
	void * (*alloc)(struct device___396 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___396 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___396 *, struct vm_area_struct___429 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___396 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___396 *, struct page___429 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___396 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___396 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___396 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___396 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___396 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___396 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___396 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___396 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___396 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___396 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___396 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___396 *, u64);
	u64 (*get_required_mask)(struct device___396 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___316;

struct fwnode_handle___316 {
	struct fwnode_handle___316 *secondary;
	const struct fwnode_operations___316 *ops;
};

typedef void compound_page_dtor___416(struct page___429 *);

struct fwnode_reference_args___316;

struct fwnode_endpoint___316;

struct fwnode_operations___316 {
	struct fwnode_handle___316 * (*get)(struct fwnode_handle___316 *);
	void (*put)(struct fwnode_handle___316 *);
	bool (*device_is_available)(const struct fwnode_handle___316 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___316 *, const struct device___396 *);
	bool (*property_present)(const struct fwnode_handle___316 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___316 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___316 *, const char *, const char **, size_t);
	struct fwnode_handle___316 * (*get_parent)(const struct fwnode_handle___316 *);
	struct fwnode_handle___316 * (*get_next_child_node)(const struct fwnode_handle___316 *, struct fwnode_handle___316 *);
	struct fwnode_handle___316 * (*get_named_child_node)(const struct fwnode_handle___316 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___316 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___316 *);
	struct fwnode_handle___316 * (*graph_get_next_endpoint)(const struct fwnode_handle___316 *, struct fwnode_handle___316 *);
	struct fwnode_handle___316 * (*graph_get_remote_endpoint)(const struct fwnode_handle___316 *);
	struct fwnode_handle___316 * (*graph_get_port_parent)(struct fwnode_handle___316 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___316 *, struct fwnode_endpoint___316 *);
};

struct fwnode_endpoint___316 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___316 *local_fwnode;
};

struct fwnode_reference_args___316 {
	struct fwnode_handle___316 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___109;

struct pipe_buffer___109 {
	struct page___429 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___109 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___109 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___109 *, struct pipe_buffer___109 *);
	void (*release)(struct pipe_inode_info___109 *, struct pipe_buffer___109 *);
	int (*steal)(struct pipe_inode_info___109 *, struct pipe_buffer___109 *);
	union {
		bool (*get)(struct pipe_inode_info___109 *, struct pipe_buffer___109 *);
		struct {
			void (*get)(struct pipe_inode_info___109 *, struct pipe_buffer___109 *);
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
};

struct nf_bridge_info___73 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___73 = 0,
		BRNF_PROTO_8021Q___73 = 1,
		BRNF_PROTO_PPPOE___73 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___74 *physindev;
	struct net_device___74 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___73(struct sk_buff___75 **);

typedef struct {
	struct net___85 *net;
} possible_net_t___75;

struct net_device_ops___73;

struct ethtool_ops___73;

struct xfrmdev_ops___73;

struct tlsdev_ops___73;

struct header_ops___73;

struct netdev_rx_queue___73;

struct mini_Qdisc___65;

struct netdev_queue___73;

struct Qdisc___65;

struct rtnl_link_ops___65;

struct dcbnl_rtnl_ops___73;

struct net_device___74 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___73 *netdev_ops;
	const struct ethtool_ops___73 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___2 *l3mdev_ops;
	const struct ndisc_ops___2 *ndisc_ops;
	const struct xfrmdev_ops___73 *xfrmdev_ops;
	const struct tlsdev_ops___73 *tlsdev_ops;
	const struct header_ops___73 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___415 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___2 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___73 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___73 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___65 *miniq_ingress;
	struct netdev_queue___73 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___73 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___65 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___65 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___73 = 0,
		NETREG_REGISTERED___73 = 1,
		NETREG_UNREGISTERING___73 = 2,
		NETREG_UNREGISTERED___73 = 3,
		NETREG_RELEASED___73 = 4,
		NETREG_DUMMY___73 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___73 = 0,
		RTNL_LINK_INITIALIZING___73 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___74 *);
	struct netpoll_info *npinfo;
	possible_net_t___75 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___396 dev;
	const struct attribute_group___393 *sysfs_groups[4];
	const struct attribute_group___393 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___65 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___73 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct sk_buff_head___73 {
	struct sk_buff___75 *next;
	struct sk_buff___75 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct ethtool_ops___73 {
	int (*get_settings)(struct net_device___74 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___74 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___74 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___74 *);
	void (*get_regs)(struct net_device___74 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___74 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___74 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___74 *);
	void (*set_msglevel)(struct net_device___74 *, u32);
	int (*nway_reset)(struct net_device___74 *);
	u32 (*get_link)(struct net_device___74 *);
	int (*get_eeprom_len)(struct net_device___74 *);
	int (*get_eeprom)(struct net_device___74 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___74 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___74 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___74 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___74 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___74 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___74 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___74 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___74 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___74 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___74 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___74 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___74 *);
	void (*complete)(struct net_device___74 *);
	u32 (*get_priv_flags)(struct net_device___74 *);
	int (*set_priv_flags)(struct net_device___74 *, u32);
	int (*get_sset_count)(struct net_device___74 *, int);
	int (*get_rxnfc)(struct net_device___74 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___74 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___74 *, struct ethtool_flash *);
	int (*reset)(struct net_device___74 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___74 *);
	u32 (*get_rxfh_indir_size)(struct net_device___74 *);
	int (*get_rxfh)(struct net_device___74 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___74 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___74 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___74 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___74 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___74 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___74 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___74 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___74 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___74 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___74 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___74 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___74 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___74 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___74 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___74 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___74 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___74 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___74 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___74 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___74 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___74 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	int (*get_fecparam)(struct net_device___74 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___74 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___74 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___74 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___74 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___73;

struct inet_frags___73 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___73 *, const void *);
	void (*destructor)(struct inet_frag_queue___73 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___73 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___75 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___75 *fragments_tail;
	struct sk_buff___75 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___73 *net;
	struct callback_head rcu;
};

struct ucounts___293 {
	struct hlist_node node;
	struct user_namespace___293 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

typedef int (*key_restrict_link_func_t___397)(struct key___396 *, const struct key_type *, const union key_payload *, struct key___396 *);

struct key_restriction___396;

struct key___396 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___430 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___396 *restrict_link;
};

struct key_restriction___396 {
	key_restrict_link_func_t___397 check;
	struct key___396 *key;
	struct key_type *keytype;
};

struct seq_operations___367 {
	void * (*start)(struct seq_file___367 *, loff_t *);
	void (*stop)(struct seq_file___367 *, void *);
	void * (*next)(struct seq_file___367 *, void *, loff_t *);
	int (*show)(struct seq_file___367 *, void *);
};

struct pernet_operations___74 {
	struct list_head list;
	int (*init)(struct net___85 *);
	void (*exit)(struct net___85 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___73 {
	int (*ieee_getets)(struct net_device___74 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___74 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___74 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___74 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___74 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___74 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___74 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___74 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___74 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___74 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___74 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___74 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___74 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___74 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___74 *);
	u8 (*setstate)(struct net_device___74 *, u8);
	void (*getpermhwaddr)(struct net_device___74 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___74 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___74 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___74 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___74 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___74 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___74 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___74 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___74 *, int, u8 *);
	void (*setpfccfg)(struct net_device___74 *, int, u8);
	void (*getpfccfg)(struct net_device___74 *, int, u8 *);
	u8 (*setall)(struct net_device___74 *);
	u8 (*getcap)(struct net_device___74 *, int, u8 *);
	int (*getnumtcs)(struct net_device___74 *, int, u8 *);
	int (*setnumtcs)(struct net_device___74 *, int, u8);
	u8 (*getpfcstate)(struct net_device___74 *);
	void (*setpfcstate)(struct net_device___74 *, u8);
	void (*getbcncfg)(struct net_device___74 *, int, u32 *);
	void (*setbcncfg)(struct net_device___74 *, int, u32);
	void (*getbcnrp)(struct net_device___74 *, int, u8 *);
	void (*setbcnrp)(struct net_device___74 *, int, u8);
	int (*setapp)(struct net_device___74 *, u8, u16, u8);
	int (*getapp)(struct net_device___74 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___74 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___74 *, int, u8);
	u8 (*getdcbx)(struct net_device___74 *);
	u8 (*setdcbx)(struct net_device___74 *, u8);
	int (*peer_getappinfo)(struct net_device___74 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___74 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___74 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___74 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___74 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___74 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___277 {
	refcount_t count;
	struct ns_common___29 ns;
	struct user_namespace___293 *user_ns;
	struct ucounts___293 *ucounts;
	struct css_set___277 *root_cset;
};

struct bpf_map___278;

struct bpf_map_ops___277 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___278 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___278 *, struct file___428 *);
	void (*map_free)(struct bpf_map___278 *);
	int (*map_get_next_key)(struct bpf_map___278 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___278 *);
	void * (*map_lookup_elem)(struct bpf_map___278 *, void *);
	int (*map_update_elem)(struct bpf_map___278 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___278 *, void *);
	int (*map_push_elem)(struct bpf_map___278 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___278 *, void *);
	int (*map_peek_elem)(struct bpf_map___278 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___278 *, struct file___428 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___278 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___278 *, void *, struct seq_file___367 *);
	int (*map_check_btf)(const struct bpf_map___278 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___278 {
	const struct bpf_map_ops___277 *ops;
	struct bpf_map___278 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___396 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___73;

struct bpf_map_dev_ops___73 {
	int (*map_get_next_key)(struct bpf_offloaded_map___73 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___73 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___73 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___73 *, void *);
};

struct bpf_offloaded_map___73 {
	struct bpf_map___278 map;
	struct net_device___74 *netdev;
	const struct bpf_map_dev_ops___73 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct kthread_work___278;

typedef void (*kthread_work_func_t___278)(struct kthread_work___278 *);

struct kthread_worker___278;

struct kthread_work___278 {
	struct list_head node;
	kthread_work_func_t___278 func;
	struct kthread_worker___278 *worker;
	int canceling;
};

struct kthread_worker___278 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___430 *task;
	struct kthread_work___278 *current_work;
};

struct kthread_delayed_work___277 {
	struct kthread_work___278 work;
	struct timer_list timer;
};

struct psi_group___277 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___278 *poll_kworker;
	struct kthread_delayed_work___277 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_file___277 {
	struct kernfs_node___423 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct cgroup_subsys___277;

struct cgroup_subsys_state___277 {
	struct cgroup___277 *cgroup;
	struct cgroup_subsys___277 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___277 *parent;
};

struct cgroup_root___277;

struct cgroup_rstat_cpu___277;

struct cgroup___277 {
	struct cgroup_subsys_state___277 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___423 *kn;
	struct cgroup_file___277 procs_file;
	struct cgroup_file___277 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___277 *subsys[13];
	struct cgroup_root___277 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___277 *dom_cgrp;
	struct cgroup_rstat_cpu___277 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___63 bpf;
	atomic_t congestion_count;
	struct cgroup___277 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___277 psi;
	int ancestor_ids[0];
};

struct cftype___277;

struct cgroup_subsys___277 {
	struct cgroup_subsys_state___277 * (*css_alloc)(struct cgroup_subsys_state___277 *);
	int (*css_online)(struct cgroup_subsys_state___277 *);
	void (*css_offline)(struct cgroup_subsys_state___277 *);
	void (*css_released)(struct cgroup_subsys_state___277 *);
	void (*css_free)(struct cgroup_subsys_state___277 *);
	void (*css_reset)(struct cgroup_subsys_state___277 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___277 *, int);
	int (*css_extra_stat_show)(struct seq_file___367 *, struct cgroup_subsys_state___277 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___430 *);
	void (*cancel_fork)(struct task_struct___430 *);
	void (*fork)(struct task_struct___430 *);
	void (*exit)(struct task_struct___430 *);
	void (*free)(struct task_struct___430 *);
	void (*bind)(struct cgroup_subsys_state___277 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___277 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___277 *dfl_cftypes;
	struct cftype___277 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___277 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___277 *updated_children;
	struct cgroup___277 *updated_next;
};

struct cgroup_root___277 {
	struct kernfs_root___422 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___277 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___277 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___277 *ss;
	struct list_head node;
	struct kernfs_ops___422 *kf_ops;
	int (*open)(struct kernfs_open_file___422 *);
	void (*release)(struct kernfs_open_file___422 *);
	u64 (*read_u64)(struct cgroup_subsys_state___277 *, struct cftype___277 *);
	s64 (*read_s64)(struct cgroup_subsys_state___277 *, struct cftype___277 *);
	int (*seq_show)(struct seq_file___367 *, void *);
	void * (*seq_start)(struct seq_file___367 *, loff_t *);
	void * (*seq_next)(struct seq_file___367 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___367 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___277 *, struct cftype___277 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___277 *, struct cftype___277 *, s64);
	ssize_t (*write)(struct kernfs_open_file___422 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___422 *, struct poll_table_struct___6 *);
};

struct xdp_rxq_info___73 {
	struct net_device___74 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___73 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___74 *dev_rx;
};

struct netlink_callback___75 {
	struct sk_buff___75 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___75 *);
	int (*dump)(struct sk_buff___75 *, struct netlink_callback___75 *);
	int (*done)(struct netlink_callback___75 *);
	void *data;
	struct module___11 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___73 {
	int (*create)(struct sk_buff___75 *, struct net_device___74 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___75 *, unsigned char *);
	int (*cache)(const struct neighbour___2 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___74 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___73 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___73 *, int);
	int poll_owner;
	struct net_device___74 *dev;
	struct sk_buff___75 *gro_list;
	struct sk_buff___75 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___73 {
	struct net_device___74 *dev;
	struct Qdisc___65 *qdisc;
	struct Qdisc___65 *qdisc_sleeping;
	struct kobject___416 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___74 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___65 {
	struct sk_buff___75 *head;
	struct sk_buff___75 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___65;

struct Qdisc___65 {
	int (*enqueue)(struct sk_buff___75 *, struct Qdisc___65 *, struct sk_buff___75 **);
	struct sk_buff___75 * (*dequeue)(struct Qdisc___65 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___65 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___73 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___73 gso_skb;
	struct qdisc_skb_head___65 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___65 *next_sched;
	struct sk_buff_head___73 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___73 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___416 kobj;
	struct net_device___74 *dev;
	long: 64;
	struct xdp_rxq_info___73 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___73)(struct net_device___74 *, struct sk_buff___75 *, struct net_device___74 *);

struct netdev_bpf___73 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___63 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___63 *prog;
			const struct bpf_prog_offload_ops___63 *ops;
		} verifier;
		struct {
			struct bpf_prog___63 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___73 *offmap;
		};
		struct {
			struct xdp_umem___3 *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___73 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___75 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___73 {
	int (*tls_dev_add)(struct net_device___74 *, struct sock *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___74 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___74 *, struct sock *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___73 {
	int (*ndo_init)(struct net_device___74 *);
	void (*ndo_uninit)(struct net_device___74 *);
	int (*ndo_open)(struct net_device___74 *);
	int (*ndo_stop)(struct net_device___74 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___75 *, struct net_device___74 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___75 *, struct net_device___74 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___74 *, struct sk_buff___75 *, struct net_device___74 *, select_queue_fallback_t___73);
	void (*ndo_change_rx_flags)(struct net_device___74 *, int);
	void (*ndo_set_rx_mode)(struct net_device___74 *);
	int (*ndo_set_mac_address)(struct net_device___74 *, void *);
	int (*ndo_validate_addr)(struct net_device___74 *);
	int (*ndo_do_ioctl)(struct net_device___74 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___74 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___74 *, int);
	int (*ndo_neigh_setup)(struct net_device___74 *, struct neigh_parms___3 *);
	void (*ndo_tx_timeout)(struct net_device___74 *);
	void (*ndo_get_stats64)(struct net_device___74 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___74 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___74 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___74 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___74 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___74 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___74 *);
	int (*ndo_netpoll_setup)(struct net_device___74 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___74 *);
	int (*ndo_set_vf_mac)(struct net_device___74 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___74 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___74 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___74 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___74 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___74 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___74 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___74 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___74 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___74 *, int, struct sk_buff___75 *);
	int (*ndo_set_vf_guid)(struct net_device___74 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___74 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___74 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___74 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___74 *, const struct sk_buff___75 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___74 *, struct net_device___74 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___74 *, struct net_device___74 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___74 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___74 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___74 *, struct neighbour___2 *);
	void (*ndo_neigh_destroy)(struct net_device___74 *, struct neighbour___2 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___74 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___74 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___74 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___75 *, struct netlink_callback___75 *, struct net_device___74 *, struct net_device___74 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___74 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___74 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___75 *, u32, u32, struct net_device___74 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___74 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___74 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___74 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___74 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___74 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___74 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___74 *, struct net_device___74 *);
	void (*ndo_dfwd_del_station)(struct net_device___74 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___74 *);
	int (*ndo_set_tx_maxrate)(struct net_device___74 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___74 *);
	int (*ndo_change_proto_down)(struct net_device___74 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___74 *, struct sk_buff___75 *);
	void (*ndo_set_rx_headroom)(struct net_device___74 *, int);
	int (*ndo_bpf)(struct net_device___74 *, struct netdev_bpf___73 *);
	int (*ndo_xdp_xmit)(struct net_device___74 *, int, struct xdp_frame___73 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___74 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___74 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct tcf_proto___65;

struct mini_Qdisc___65 {
	struct tcf_proto___65 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___65 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___74 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___85 *, struct net_device___74 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___74 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___74 *, struct list_head *);
	size_t (*get_size)(const struct net_device___74 *);
	int (*fill_info)(struct sk_buff___75 *, const struct net_device___74 *);
	size_t (*get_xstats_size)(const struct net_device___74 *);
	int (*fill_xstats)(struct sk_buff___75 *, const struct net_device___74 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___74 *, struct net_device___74 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___74 *, const struct net_device___74 *);
	int (*fill_slave_info)(struct sk_buff___75 *, const struct net_device___74 *, const struct net_device___74 *);
	struct net___85 * (*get_link_net)(const struct net_device___74 *);
	size_t (*get_linkxstats_size)(const struct net_device___74 *, int);
	int (*fill_linkxstats)(struct sk_buff___75 *, const struct net_device___74 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___73 {
	struct list_head poll_list;
	struct sk_buff_head___73 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___73 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___65 *output_queue;
	struct Qdisc___65 **output_queue_tailp;
	struct sk_buff___75 *completion_queue;
	struct sk_buff_head___73 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___73 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___73 input_pkt_queue;
	struct napi_struct___73 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct gnet_dump___65 {
	spinlock_t *lock;
	struct sk_buff___75 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___65;

struct Qdisc_ops___65 {
	struct Qdisc_ops___65 *next;
	const struct Qdisc_class_ops___65 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___75 *, struct Qdisc___65 *, struct sk_buff___75 **);
	struct sk_buff___75 * (*dequeue)(struct Qdisc___65 *);
	struct sk_buff___75 * (*peek)(struct Qdisc___65 *);
	int (*init)(struct Qdisc___65 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___65 *);
	void (*destroy)(struct Qdisc___65 *);
	int (*change)(struct Qdisc___65 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___65 *);
	int (*change_tx_queue_len)(struct Qdisc___65 *, unsigned int);
	int (*dump)(struct Qdisc___65 *, struct sk_buff___75 *);
	int (*dump_stats)(struct Qdisc___65 *, struct gnet_dump___65 *);
	void (*ingress_block_set)(struct Qdisc___65 *, u32);
	void (*egress_block_set)(struct Qdisc___65 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___65 *);
	u32 (*egress_block_get)(struct Qdisc___65 *);
	struct module___11 *owner;
};

struct qdisc_walker___9;

struct tcf_block___65;

struct Qdisc_class_ops___65 {
	unsigned int flags;
	struct netdev_queue___73 * (*select_queue)(struct Qdisc___65 *, struct tcmsg *);
	int (*graft)(struct Qdisc___65 *, long unsigned int, struct Qdisc___65 *, struct Qdisc___65 **, struct netlink_ext_ack *);
	struct Qdisc___65 * (*leaf)(struct Qdisc___65 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___65 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___65 *, u32);
	int (*change)(struct Qdisc___65 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___65 *, long unsigned int);
	void (*walk)(struct Qdisc___65 *, struct qdisc_walker___9 *);
	struct tcf_block___65 * (*tcf_block)(struct Qdisc___65 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___65 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___65 *, long unsigned int);
	int (*dump)(struct Qdisc___65 *, long unsigned int, struct sk_buff___75 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___65 *, long unsigned int, struct gnet_dump___65 *);
};

struct qdisc_walker___9 {
	int stop;
	int skip;
	int count;
	int (*fn)(struct Qdisc___65 *, long unsigned int, struct qdisc_walker___9 *);
};

struct tcf_chain___65;

struct tcf_block___65 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___85 *net;
	struct Qdisc___65 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___65 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___65;

struct tcf_proto_ops___65;

struct tcf_proto___65 {
	struct tcf_proto___65 *next;
	void *root;
	int (*classify)(struct sk_buff___75 *, const struct tcf_proto___65 *, struct tcf_result___65 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___65 *ops;
	struct tcf_chain___65 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___65 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___65 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___65 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___75 *, const struct tcf_proto___65 *, struct tcf_result___65 *);
	int (*init)(struct tcf_proto___65 *);
	void (*destroy)(struct tcf_proto___65 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___65 *, u32);
	void (*put)(struct tcf_proto___65 *, void *);
	int (*change)(struct net___85 *, struct sk_buff___75 *, struct tcf_proto___65 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___65 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___65 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___65 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___85 *, struct tcf_chain___65 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___85 *, struct tcf_proto___65 *, void *, struct sk_buff___75 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___75 *, struct net___85 *, void *);
	struct module___11 *owner;
	int flags;
};

struct tcf_chain___65 {
	struct mutex filter_chain_lock;
	struct tcf_proto___65 *filter_chain;
	struct list_head list;
	struct tcf_block___65 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___65 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

enum net_xmit_qdisc_t {
	__NET_XMIT_STOLEN = 65536,
	__NET_XMIT_BYPASS = 131072,
};

struct module___357;

struct file___429;

struct kiocb___429;

struct iov_iter___196;

struct poll_table_struct___268;

struct vm_area_struct___430;

struct inode___429;

struct file_lock___429;

struct page___430;

struct pipe_inode_info___110;

struct seq_file___368;

struct file_operations___429 {
	struct module___357 *owner;
	loff_t (*llseek)(struct file___429 *, loff_t, int);
	ssize_t (*read)(struct file___429 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___429 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___429 *, struct iov_iter___196 *);
	ssize_t (*write_iter)(struct kiocb___429 *, struct iov_iter___196 *);
	int (*iopoll)(struct kiocb___429 *, bool);
	int (*iterate)(struct file___429 *, struct dir_context *);
	int (*iterate_shared)(struct file___429 *, struct dir_context *);
	__poll_t (*poll)(struct file___429 *, struct poll_table_struct___268 *);
	long int (*unlocked_ioctl)(struct file___429 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___429 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___429 *, struct vm_area_struct___430 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___429 *, struct file___429 *);
	int (*flush)(struct file___429 *, fl_owner_t);
	int (*release)(struct inode___429 *, struct file___429 *);
	int (*fsync)(struct file___429 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___429 *, int);
	int (*lock)(struct file___429 *, int, struct file_lock___429 *);
	ssize_t (*sendpage)(struct file___429 *, struct page___430 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___429 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___429 *, int, struct file_lock___429 *);
	ssize_t (*splice_write)(struct pipe_inode_info___110 *, struct file___429 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___429 *, loff_t *, struct pipe_inode_info___110 *, size_t, unsigned int);
	int (*setlease)(struct file___429 *, long int, struct file_lock___429 **, void **);
	long int (*fallocate)(struct file___429 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___368 *, struct file___429 *);
	ssize_t (*copy_file_range)(struct file___429 *, loff_t, struct file___429 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___429 *, loff_t, struct file___429 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___429 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___430 {
	u64 seqnum;
	struct vm_area_struct___430 *vmas[4];
};

struct page_frag___430 {
	struct page___430 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___430;

struct mem_cgroup___162;

struct cred___397;

struct nsproxy___324;

struct signal_struct___304;

struct bio_list___219;

struct backing_dev_info___219;

struct css_set___278;

struct vm_struct___333;

struct task_struct___431 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___431 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___430 *mm;
	struct mm_struct___430 *active_mm;
	struct vmacache___430 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___431 *real_parent;
	struct task_struct___431 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___431 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___162 *active_memcg;
	long int rh_reserved2;
	struct pid___241 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___241 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___241 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___397 *ptracer_cred;
	const struct cred___397 *real_cred;
	const struct cred___397 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___324 *nsproxy;
	struct signal_struct___304 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___431 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___219 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___219 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___278 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___110 *splice_pipe;
	struct page_frag___430 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___162 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___431 *oom_reaper_list;
	struct vm_struct___333 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___156 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rw_semaphore___431 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___431 *owner;
};

struct key___397;

struct ucounts___294;

struct user_namespace___294 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___294 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___29 ns;
	long unsigned int flags;
	struct key___397 *persistent_keyring_register;
	struct rw_semaphore___431 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___294 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___430 *pgtable_t___430;

struct address_space___429;

struct dev_pagemap___417;

struct page___430 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___429 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___430 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___430 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___430 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___417 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___162 *mem_cgroup;
};

struct pglist_data___430;

struct lruvec___430 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___430 *pgdat;
};

struct zone___430 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___430 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___430 {
	struct zone___430 *zone;
	int zone_idx;
};

struct zonelist___430 {
	struct zoneref___430 _zonerefs[25];
};

struct pglist_data___430 {
	struct zone___430 node_zones[3];
	struct zonelist___430 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___431 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___431 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___430 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___431 {
	void *stack;
	struct task_struct___431 *task;
	long int status;
};

struct blocking_notifier_head___430 {
	struct rw_semaphore___431 rwsem;
	struct notifier_block *head;
};

struct dentry___429;

struct path___430 {
	struct vfsmount *mnt;
	struct dentry___429 *dentry;
};

struct file___429 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___430 f_path;
	struct inode___429 *f_inode;
	const struct file_operations___429 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___241 f_owner;
	const struct cred___397 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___429 *f_mapping;
	errseq_t f_wb_err;
};

struct user_struct___397;

struct cred___397 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___397 *session_keyring;
	struct key___397 *process_keyring;
	struct key___397 *thread_keyring;
	struct key___397 *request_key_auth;
	void *security;
	struct user_struct___397 *user;
	struct user_namespace___294 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___423;

struct kernfs_elem_dir___423 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___423 *root;
};

struct kernfs_node___424;

struct kernfs_syscall_ops___423;

struct kernfs_root___423 {
	struct kernfs_node___424 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___423 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___423 {
	struct kernfs_node___424 *target_kn;
};

struct kernfs_ops___423;

struct kernfs_elem_attr___423 {
	const struct kernfs_ops___423 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___424 *notify_next;
};

struct kernfs_node___424 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___424 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___423 dir;
		struct kernfs_elem_symlink___423 symlink;
		struct kernfs_elem_attr___423 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___423;

struct kernfs_ops___423 {
	int (*open)(struct kernfs_open_file___423 *);
	void (*release)(struct kernfs_open_file___423 *);
	int (*seq_show)(struct seq_file___368 *, void *);
	void * (*seq_start)(struct seq_file___368 *, loff_t *);
	void * (*seq_next)(struct seq_file___368 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___368 *, void *);
	ssize_t (*read)(struct kernfs_open_file___423 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___423 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___423 *, struct vm_area_struct___430 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___423 *, struct poll_table_struct___268 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___423 {
	int (*remount_fs)(struct kernfs_root___423 *, int *, char *);
	int (*show_options)(struct seq_file___368 *, struct kernfs_root___423 *);
	int (*mkdir)(struct kernfs_node___424 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___424 *);
	int (*rename)(struct kernfs_node___424 *, struct kernfs_node___424 *, const char *);
	int (*show_path)(struct seq_file___368 *, struct kernfs_node___424 *, struct kernfs_root___423 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___368;

struct seq_file___368 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___368 *op;
	int poll_event;
	const struct file___429 *file;
	void *private;
};

struct vm_operations_struct___417;

struct kernfs_open_file___423 {
	struct kernfs_node___424 *kn;
	struct file___429 *file;
	struct seq_file___368 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___417 *vm_ops;
};

struct vm_fault___417;

struct vm_operations_struct___417 {
	void (*open)(struct vm_area_struct___430 *);
	void (*close)(struct vm_area_struct___430 *);
	int (*split)(struct vm_area_struct___430 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___430 *);
	vm_fault_t (*fault)(struct vm_fault___417 *);
	vm_fault_t (*huge_fault)(struct vm_fault___417 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___417 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___430 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___417 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___417 *);
	int (*access)(struct vm_area_struct___430 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___430 *);
	int (*set_policy)(struct vm_area_struct___430 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___430 *, long unsigned int);
	struct page___430 * (*find_special_page)(struct vm_area_struct___430 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___278)(struct file___429 *, wait_queue_head_t *, struct poll_table_struct___268 *);

struct poll_table_struct___268 {
	poll_queue_proc___278 _qproc;
	__poll_t _key;
};

struct vm_area_struct___430 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___430 *vm_next;
	struct vm_area_struct___430 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___430 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___417 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___429 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sock___55;

struct kobj_ns_type_operations___54 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___55 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct net___86;

typedef struct {
	struct net___86 *net;
} possible_net_t___76;

struct proto___54;

struct sock_common___54 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___54 *skc_prot;
	possible_net_t___76 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___55 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___76;

struct sk_buff_head___74 {
	struct sk_buff___76 *next;
	struct sk_buff___76 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___54;

struct socket_wq___55;

struct dst_entry___54;

struct socket___56;

struct net_device___75;

struct sock___55 {
	struct sock_common___54 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___74 sk_error_queue;
	struct sk_buff_head___74 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___76 *head;
		struct sk_buff___76 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___54 *sk_filter;
	union {
		struct socket_wq___55 *sk_wq;
		struct socket_wq___55 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___54 *sk_rx_dst;
	struct dst_entry___54 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___76 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___74 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___430 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___54 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___241 *sk_peer_pid;
	const struct cred___397 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___56 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___162 *sk_memcg;
	void (*sk_state_change)(struct sock___55 *);
	void (*sk_data_ready)(struct sock___55 *);
	void (*sk_write_space)(struct sock___55 *);
	void (*sk_error_report)(struct sock___55 *);
	int (*sk_backlog_rcv)(struct sock___55 *, struct sk_buff___76 *);
	struct sk_buff___76 * (*sk_validate_xmit_skb)(struct sock___55 *, struct net_device___75 *, struct sk_buff___76 *);
	void (*sk_destruct)(struct sock___55 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kobject___417;

struct bin_attribute___393;

struct attribute_group___394 {
	const char *name;
	umode_t (*is_visible)(struct kobject___417 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___417 *, struct bin_attribute___393 *, int);
	struct attribute **attrs;
	struct bin_attribute___393 **bin_attrs;
};

struct kset___416;

struct kobj_type___416;

struct kobject___417 {
	const char *name;
	struct list_head entry;
	struct kobject___417 *parent;
	struct kset___416 *kset;
	struct kobj_type___416 *ktype;
	struct kernfs_node___424 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___393 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___429 *, struct kobject___417 *, struct bin_attribute___393 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___429 *, struct kobject___417 *, struct bin_attribute___393 *, char *, loff_t, size_t);
	int (*mmap)(struct file___429 *, struct kobject___417 *, struct bin_attribute___393 *, struct vm_area_struct___430 *);
};

struct sysfs_ops___416 {
	ssize_t (*show)(struct kobject___417 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___417 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___416;

struct kset___416 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___417 kobj;
	const struct kset_uevent_ops___416 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___416 {
	void (*release)(struct kobject___417 *);
	const struct sysfs_ops___416 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___54 * (*child_ns_type)(struct kobject___417 *);
	const void * (*namespace)(struct kobject___417 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___416 {
	int (* const filter)(struct kset___416 *, struct kobject___417 *);
	const char * (* const name)(struct kset___416 *, struct kobject___417 *);
	int (* const uevent)(struct kset___416 *, struct kobject___417 *, struct kobj_uevent_env *);
};

struct kobj_attribute___407 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___417 *, struct kobj_attribute___407 *, char *);
	ssize_t (*store)(struct kobject___417 *, struct kobj_attribute___407 *, const char *, size_t);
};

struct kernel_param___355;

struct kernel_param_ops___355 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___355 *);
	int (*get)(char *, const struct kernel_param___355 *);
	void (*free)(void *);
};

struct kparam_array___355;

struct kernel_param___355 {
	const char *name;
	struct module___357 *mod;
	const struct kernel_param_ops___355 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___355 *arr;
	};
};

struct kparam_array___355 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___355 *ops;
	void *elem;
};

struct module_kobject___355 {
	struct kobject___417 kobj;
	struct module___357 *mod;
	struct kobject___417 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___355 {
	struct module___357 *mod;
	struct latch_tree_node node;
};

struct module_layout___355 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___355 mtn;
};

struct module_attribute___355;

struct module___357 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___355 mkobj;
	struct module_attribute___355 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___417 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___355 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___355 core_layout;
	struct module_layout___355 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___355 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___355 *, struct module_kobject___355 *, char *);
	ssize_t (*store)(struct module_attribute___355 *, struct module_kobject___355 *, const char *, size_t);
	void (*setup)(struct module___357 *, const char *);
	int (*test)(struct module___357 *);
	void (*free)(struct module___357 *);
};

struct cgroup___278;

struct cgroup_subsys___278;

struct cgroup_subsys_state___278 {
	struct cgroup___278 *cgroup;
	struct cgroup_subsys___278 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___278 *parent;
};

struct cgroup_file___278 {
	struct kernfs_node___424 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___162;

struct mem_cgroup___162 {
	struct cgroup_subsys_state___278 css;
	struct mem_cgroup_id___13 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___278 events_file;
	struct cgroup_file___278 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___431 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___162 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct user_struct___397 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___397 *uid_keyring;
	struct key___397 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___430;

struct mm_struct___430 {
	struct {
		struct vm_area_struct___430 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___429 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___431 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___430 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___431 *owner;
		struct user_namespace___294 *user_ns;
		struct file___429 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___430 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___278;

struct nsproxy___324 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net___86 *net_ns;
	struct cgroup_namespace___278 *cgroup_ns;
};

struct signal_struct___304 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___431 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___431 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___241 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___241 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___430 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___241 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___219;

struct bio_list___219 {
	struct bio___219 *head;
	struct bio___219 *tail;
};

struct bdi_writeback_congested___219;

struct bdi_writeback___219 {
	struct backing_dev_info___219 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___219 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___278 *memcg_css;
	struct cgroup_subsys_state___278 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___397;

struct backing_dev_info___219 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___219 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___397 *dev;
	struct device___397 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___429 *debug_dir;
	struct dentry___429 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___278 {
	struct cgroup_subsys_state___278 *subsys[13];
	refcount_t refcount;
	struct css_set___278 *dom_cset;
	struct cgroup___278 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___278 *mg_src_cgrp;
	struct cgroup___278 *mg_dst_cgrp;
	struct css_set___278 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___429;

struct pipe_buffer___110;

struct pipe_inode_info___110 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___430 *tmp_page;
	struct fasync_struct___429 *fasync_readers;
	struct fasync_struct___429 *fasync_writers;
	struct pipe_buffer___110 *bufs;
	struct user_struct___397 *user;
};

struct vm_struct___333 {
	struct vm_struct___333 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___430 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___316 {
	struct task_struct___431 task;
	long unsigned int stack[8192];
};

struct address_space_operations___429;

struct address_space___429 {
	struct inode___429 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___431 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___429 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___417)(struct vm_area_struct___430 *, long unsigned int, const struct page___430 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___417)(struct page___430 *, void *);

struct dev_pagemap___417 {
	dev_page_fault_t___417 page_fault;
	dev_page_free_t___417 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___397 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___430 {
	struct task_struct___431 *task;
	struct core_thread___430 *next;
};

struct core_state___430 {
	atomic_t nr_threads;
	struct core_thread___430 dumper;
	struct completion startup;
};

struct vm_fault___417 {
	struct vm_area_struct___430 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___430 *cow_page;
	struct mem_cgroup___162 *memcg;
	struct page___430 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___430 prealloc_pte;
};

struct bio_vec___221 {
	struct page___430 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___196 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___221 *bvec;
		struct pipe_inode_info___110 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct msghdr___57 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___196 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___429 *msg_iocb;
};

struct kiocb___429 {
	struct file___429 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___429 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dentry_operations___429;

struct super_block___429;

struct dentry___429 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___429 *d_parent;
	struct qstr d_name;
	struct inode___429 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___429 *d_op;
	struct super_block___429 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___429;

struct block_device___429;

struct inode___429 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___429 *i_op;
	struct super_block___429 *i_sb;
	struct address_space___429 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___431 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___219 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___429 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___429 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___110 *i_pipe;
		struct block_device___429 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___429 {
	int (*d_revalidate)(struct dentry___429 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___429 *, unsigned int);
	int (*d_hash)(const struct dentry___429 *, struct qstr *);
	int (*d_compare)(const struct dentry___429 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___429 *);
	int (*d_init)(struct dentry___429 *);
	void (*d_release)(struct dentry___429 *);
	void (*d_prune)(struct dentry___429 *);
	void (*d_iput)(struct dentry___429 *, struct inode___429 *);
	char * (*d_dname)(struct dentry___429 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___430 *);
	int (*d_manage)(const struct path___430 *, bool);
	struct dentry___429 * (*d_real)(struct dentry___429 *, const struct inode___429 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___429;

struct mem_dqinfo___429 {
	struct quota_format_type___429 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___429;

struct quota_info___429 {
	unsigned int flags;
	struct rw_semaphore___431 dqio_sem;
	struct inode___429 *files[3];
	struct mem_dqinfo___429 info[3];
	const struct quota_format_ops___429 *ops[3];
};

struct rcuwait___429 {
	struct task_struct___431 *task;
};

struct percpu_rw_semaphore___429 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___431 rw_sem;
	struct rcuwait___429 writer;
	int readers_block;
};

struct sb_writers___429 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___429 rw_sem[3];
};

struct shrink_control___162;

struct shrinker___162 {
	long unsigned int (*count_objects)(struct shrinker___162 *, struct shrink_control___162 *);
	long unsigned int (*scan_objects)(struct shrinker___162 *, struct shrink_control___162 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___429;

struct super_operations___429;

struct dquot_operations___429;

struct quotactl_ops___429;

struct super_block___429 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___429 *s_type;
	const struct super_operations___429 *s_op;
	const struct dquot_operations___429 *dq_op;
	const struct quotactl_ops___429 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___429 *s_root;
	struct rw_semaphore___431 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___429 *s_bdev;
	struct backing_dev_info___219 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___429 s_dquot;
	struct sb_writers___429 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___429 *s_d_op;
	int cleancache_poolid;
	struct shrinker___162 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___294 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___162 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___162 *memcg;
};

struct iattr___429 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___429 *ia_file;
};

struct dquot___429 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___429 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___429 {
	int qf_fmt_id;
	const struct quota_format_ops___429 *qf_ops;
	struct module___357 *qf_owner;
	struct quota_format_type___429 *qf_next;
};

struct quota_format_ops___429 {
	int (*check_quota_file)(struct super_block___429 *, int);
	int (*read_file_info)(struct super_block___429 *, int);
	int (*write_file_info)(struct super_block___429 *, int);
	int (*free_file_info)(struct super_block___429 *, int);
	int (*read_dqblk)(struct dquot___429 *);
	int (*commit_dqblk)(struct dquot___429 *);
	int (*release_dqblk)(struct dquot___429 *);
	int (*get_next_id)(struct super_block___429 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___429 {
	int (*write_dquot)(struct dquot___429 *);
	struct dquot___429 * (*alloc_dquot)(struct super_block___429 *, int);
	void (*destroy_dquot)(struct dquot___429 *);
	int (*acquire_dquot)(struct dquot___429 *);
	int (*release_dquot)(struct dquot___429 *);
	int (*mark_dirty)(struct dquot___429 *);
	int (*write_info)(struct super_block___429 *, int);
	qsize_t * (*get_reserved_space)(struct inode___429 *);
	int (*get_projid)(struct inode___429 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___429 *, qsize_t *);
	int (*get_next_id)(struct super_block___429 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___429 {
	int (*quota_on)(struct super_block___429 *, int, int, const struct path___430 *);
	int (*quota_off)(struct super_block___429 *, int);
	int (*quota_enable)(struct super_block___429 *, unsigned int);
	int (*quota_disable)(struct super_block___429 *, unsigned int);
	int (*quota_sync)(struct super_block___429 *, int);
	int (*set_info)(struct super_block___429 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___429 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___429 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___429 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___429 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___429 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___182;

struct address_space_operations___429 {
	int (*writepage)(struct page___430 *, struct writeback_control___182 *);
	int (*readpage)(struct file___429 *, struct page___430 *);
	int (*writepages)(struct address_space___429 *, struct writeback_control___182 *);
	int (*set_page_dirty)(struct page___430 *);
	int (*readpages)(struct file___429 *, struct address_space___429 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___429 *, struct address_space___429 *, loff_t, unsigned int, unsigned int, struct page___430 **, void **);
	int (*write_end)(struct file___429 *, struct address_space___429 *, loff_t, unsigned int, unsigned int, struct page___430 *, void *);
	sector_t (*bmap)(struct address_space___429 *, sector_t);
	void (*invalidatepage)(struct page___430 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___430 *, gfp_t);
	void (*freepage)(struct page___430 *);
	ssize_t (*direct_IO)(struct kiocb___429 *, struct iov_iter___196 *);
	int (*migratepage)(struct address_space___429 *, struct page___430 *, struct page___430 *, enum migrate_mode);
	bool (*isolate_page)(struct page___430 *, isolate_mode_t);
	void (*putback_page)(struct page___430 *);
	int (*launder_page)(struct page___430 *);
	int (*is_partially_uptodate)(struct page___430 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___430 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___429 *, struct page___430 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___429 *, sector_t *);
	void (*swap_deactivate)(struct file___429 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___182 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___219 *wb;
	struct inode___429 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___429 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___429 *bd_inode;
	struct super_block___429 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___429 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___219 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___429 {
	struct dentry___429 * (*lookup)(struct inode___429 *, struct dentry___429 *, unsigned int);
	const char * (*get_link)(struct dentry___429 *, struct inode___429 *, struct delayed_call *);
	int (*permission)(struct inode___429 *, int);
	struct posix_acl * (*get_acl)(struct inode___429 *, int);
	int (*readlink)(struct dentry___429 *, char *, int);
	int (*create)(struct inode___429 *, struct dentry___429 *, umode_t, bool);
	int (*link)(struct dentry___429 *, struct inode___429 *, struct dentry___429 *);
	int (*unlink)(struct inode___429 *, struct dentry___429 *);
	int (*symlink)(struct inode___429 *, struct dentry___429 *, const char *);
	int (*mkdir)(struct inode___429 *, struct dentry___429 *, umode_t);
	int (*rmdir)(struct inode___429 *, struct dentry___429 *);
	int (*mknod)(struct inode___429 *, struct dentry___429 *, umode_t, dev_t);
	int (*rename)(struct inode___429 *, struct dentry___429 *, struct inode___429 *, struct dentry___429 *, unsigned int);
	int (*setattr)(struct dentry___429 *, struct iattr___429 *);
	int (*getattr)(const struct path___430 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___429 *, char *, size_t);
	int (*fiemap)(struct inode___429 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___429 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___429 *, struct dentry___429 *, struct file___429 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___429 *, struct dentry___429 *, umode_t);
	int (*set_acl)(struct inode___429 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___429 {
	void (*fl_copy_lock)(struct file_lock___429 *, struct file_lock___429 *);
	void (*fl_release_private)(struct file_lock___429 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___429;

struct file_lock___429 {
	struct file_lock___429 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___429 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___429 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___429 *fl_ops;
	const struct lock_manager_operations___429 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___429 {
	int (*lm_compare_owner)(struct file_lock___429 *, struct file_lock___429 *);
	long unsigned int (*lm_owner_key)(struct file_lock___429 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___429 *);
	int (*lm_grant)(struct file_lock___429 *, int);
	bool (*lm_break)(struct file_lock___429 *);
	int (*lm_change)(struct file_lock___429 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___429 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___429 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___429 *fa_next;
	struct file___429 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___429 {
	const char *name;
	int fs_flags;
	struct dentry___429 * (*mount)(struct file_system_type___429 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___429 *);
	struct module___357 *owner;
	struct file_system_type___429 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___429 {
	struct inode___429 * (*alloc_inode)(struct super_block___429 *);
	void (*destroy_inode)(struct inode___429 *);
	void (*dirty_inode)(struct inode___429 *, int);
	int (*write_inode)(struct inode___429 *, struct writeback_control___182 *);
	int (*drop_inode)(struct inode___429 *);
	void (*evict_inode)(struct inode___429 *);
	void (*put_super)(struct super_block___429 *);
	int (*sync_fs)(struct super_block___429 *, int);
	int (*freeze_super)(struct super_block___429 *);
	int (*freeze_fs)(struct super_block___429 *);
	int (*thaw_super)(struct super_block___429 *);
	int (*unfreeze_fs)(struct super_block___429 *);
	int (*statfs)(struct dentry___429 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___429 *, int *, char *);
	void (*umount_begin)(struct super_block___429 *);
	int (*show_options)(struct seq_file___368 *, struct dentry___429 *);
	int (*show_devname)(struct seq_file___368 *, struct dentry___429 *);
	int (*show_path)(struct seq_file___368 *, struct dentry___429 *);
	int (*show_stats)(struct seq_file___368 *, struct dentry___429 *);
	ssize_t (*quota_read)(struct super_block___429 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___429 *, int, const char *, size_t, loff_t);
	struct dquot___429 ** (*get_dquots)(struct inode___429 *);
	int (*bdev_try_to_free_page)(struct super_block___429 *, struct page___430 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___429 *, struct shrink_control___162 *);
	long int (*free_cached_objects)(struct super_block___429 *, struct shrink_control___162 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___219(struct bio___219 *);

struct bio_integrity_payload___219;

struct bio_set___219;

struct bio___219 {
	struct bio___219 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___219 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___219 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___221 *bi_io_vec;
	struct bio_set___219 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___221 bi_inline_vecs[0];
};

struct socket_wq___55 {
	wait_queue_head_t wait;
	struct fasync_struct___429 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___55;

struct socket___56 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___55 *wq;
	struct file___429 *file;
	struct sock___55 *sk;
	const struct proto_ops___55 *ops;
};

typedef int (*sk_read_actor_t___54)(read_descriptor_t *, struct sk_buff___76 *, unsigned int, size_t);

struct proto_ops___55 {
	int family;
	struct module___357 *owner;
	int (*release)(struct socket___56 *);
	int (*bind)(struct socket___56 *, struct sockaddr *, int);
	int (*connect)(struct socket___56 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___56 *, struct socket___56 *);
	int (*accept)(struct socket___56 *, struct socket___56 *, int, bool);
	int (*getname)(struct socket___56 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___429 *, struct socket___56 *, struct poll_table_struct___268 *);
	int (*ioctl)(struct socket___56 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___56 *, int);
	int (*shutdown)(struct socket___56 *, int);
	int (*setsockopt)(struct socket___56 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___56 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___56 *, struct msghdr___57 *, size_t);
	int (*recvmsg)(struct socket___56 *, struct msghdr___57 *, size_t, int);
	int (*mmap)(struct file___429 *, struct socket___56 *, struct vm_area_struct___430 *);
	ssize_t (*sendpage)(struct socket___56 *, struct page___430 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___56 *, loff_t *, struct pipe_inode_info___110 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___55 *, int);
	int (*peek_len)(struct socket___56 *);
	int (*read_sock)(struct sock___55 *, read_descriptor_t *, sk_read_actor_t___54);
	int (*sendpage_locked)(struct sock___55 *, struct page___430 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___55 *, struct msghdr___57 *, size_t);
	int (*set_rcvlowat)(struct sock___55 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct nf_bridge_info___74;

struct sk_buff___76 {
	union {
		struct {
			struct sk_buff___76 *next;
			struct sk_buff___76 *prev;
			union {
				struct net_device___75 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___55 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___76 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___74 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___74;

struct netns_frags___74 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___74 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_rules_ops___54;

struct fib_notifier_ops___55;

struct netns_ipv4___74 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___54 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___55 *fibnl;
	struct sock___55 **icmp_sk;
	struct sock___55 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___55 **tcp_sk;
	struct netns_frags___74 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___54 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___55 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___55 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___54;

struct dst_ops___85 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___85 *);
	struct dst_entry___54 * (*check)(struct dst_entry___54 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___54 *);
	unsigned int (*mtu)(const struct dst_entry___54 *);
	u32 * (*cow_metrics)(struct dst_entry___54 *, long unsigned int);
	void (*destroy)(struct dst_entry___54 *);
	void (*ifdown)(struct dst_entry___54 *, struct net_device___75 *, int);
	struct dst_entry___54 * (*negative_advice)(struct dst_entry___54 *);
	void (*link_failure)(struct sk_buff___76 *);
	void (*update_pmtu)(struct dst_entry___54 *, struct sock___55 *, struct sk_buff___76 *, u32);
	void (*redirect)(struct dst_entry___54 *, struct sock___55 *, struct sk_buff___76 *);
	int (*local_out)(struct net___86 *, struct sock___55 *, struct sk_buff___76 *);
	struct neighbour___54 * (*neigh_lookup)(const struct dst_entry___54 *, struct sk_buff___76 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___54 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_info___11;

struct rt6_info___11;

struct fib6_table___11;

struct netns_ipv6___85 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___74 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info___11 *fib6_null_entry;
	struct rt6_info___11 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___11 *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___85 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info___11 *ip6_prohibit_entry;
	struct rt6_info___11 *ip6_blk_hole_entry;
	struct fib6_table___11 *fib6_local_tbl;
	struct fib_rules_ops___54 *fib6_rules_ops;
	struct sock___55 **icmp_sk;
	struct sock___55 *ndisc_sk;
	struct sock___55 *tcp_sk;
	struct sock___55 *igmp_sk;
	struct sock___55 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___54 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___55 *notifier_ops;
	struct fib_notifier_ops___55 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___55 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___55 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___74 {
	struct netns_frags___74 frags;
};

struct netns_xfrm___85 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___55 *nlsk;
	struct sock___55 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___85 xfrm4_dst_ops;
	struct dst_ops___85 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___64;

struct net___86 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___294 *user_ns;
	struct ucounts___294 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___29 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___55 *rtnl;
	struct sock___55 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___75 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___74 ipv4;
	struct netns_ipv6___85 ipv6;
	struct netns_sctp___55 sctp;
	struct netns_nf___4 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___74 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___55 *nfnl;
	struct sock___55 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___85 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___55 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___64 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___397 {
	int (*prepare)(struct device___397 *);
	void (*complete)(struct device___397 *);
	int (*suspend)(struct device___397 *);
	int (*resume)(struct device___397 *);
	int (*freeze)(struct device___397 *);
	int (*thaw)(struct device___397 *);
	int (*poweroff)(struct device___397 *);
	int (*restore)(struct device___397 *);
	int (*suspend_late)(struct device___397 *);
	int (*resume_early)(struct device___397 *);
	int (*freeze_late)(struct device___397 *);
	int (*thaw_early)(struct device___397 *);
	int (*poweroff_late)(struct device___397 *);
	int (*restore_early)(struct device___397 *);
	int (*suspend_noirq)(struct device___397 *);
	int (*resume_noirq)(struct device___397 *);
	int (*freeze_noirq)(struct device___397 *);
	int (*thaw_noirq)(struct device___397 *);
	int (*poweroff_noirq)(struct device___397 *);
	int (*restore_noirq)(struct device___397 *);
	int (*runtime_suspend)(struct device___397 *);
	int (*runtime_resume)(struct device___397 *);
	int (*runtime_idle)(struct device___397 *);
};

struct dev_pm_info___397 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___397 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___397;

struct bus_type___397;

struct device_driver___397;

struct dev_pm_domain___397;

struct dma_map_ops___169;

struct fwnode_handle___317;

struct class___397;

struct device___397 {
	struct device___397 *parent;
	struct device_private *p;
	struct kobject___417 kobj;
	const char *init_name;
	const struct device_type___397 *type;
	struct mutex mutex;
	struct bus_type___397 *bus;
	struct device_driver___397 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___397 power;
	struct dev_pm_domain___397 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___169 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___317 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___397 *class;
	const struct attribute_group___394 **groups;
	void (*release)(struct device___397 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___397 {
	struct dev_pm_ops___397 ops;
	void (*detach)(struct device___397 *, bool);
	int (*activate)(struct device___397 *);
	void (*sync)(struct device___397 *);
	void (*dismiss)(struct device___397 *);
};

struct bus_type___397 {
	const char *name;
	const char *dev_name;
	struct device___397 *dev_root;
	const struct attribute_group___394 **bus_groups;
	const struct attribute_group___394 **dev_groups;
	const struct attribute_group___394 **drv_groups;
	int (*match)(struct device___397 *, struct device_driver___397 *);
	int (*uevent)(struct device___397 *, struct kobj_uevent_env *);
	int (*probe)(struct device___397 *);
	int (*remove)(struct device___397 *);
	void (*shutdown)(struct device___397 *);
	int (*online)(struct device___397 *);
	int (*offline)(struct device___397 *);
	int (*suspend)(struct device___397 *, pm_message_t);
	int (*resume)(struct device___397 *);
	int (*num_vf)(struct device___397 *);
	int (*dma_configure)(struct device___397 *);
	const struct dev_pm_ops___397 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___397 {
	const char *name;
	struct bus_type___397 *bus;
	struct module___357 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___397 *);
	int (*remove)(struct device___397 *);
	void (*shutdown)(struct device___397 *);
	int (*suspend)(struct device___397 *, pm_message_t);
	int (*resume)(struct device___397 *);
	const struct attribute_group___394 **groups;
	const struct dev_pm_ops___397 *pm;
	void (*coredump)(struct device___397 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___397 {
	const char *name;
	const struct attribute_group___394 **groups;
	int (*uevent)(struct device___397 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___397 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___397 *);
	const struct dev_pm_ops___397 *pm;
};

struct class___397 {
	const char *name;
	struct module___357 *owner;
	const struct attribute_group___394 **class_groups;
	const struct attribute_group___394 **dev_groups;
	struct kobject___417 *dev_kobj;
	int (*dev_uevent)(struct device___397 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___397 *, umode_t *);
	void (*class_release)(struct class___397 *);
	void (*dev_release)(struct device___397 *);
	int (*shutdown_pre)(struct device___397 *);
	const struct kobj_ns_type_operations___54 *ns_type;
	const void * (*namespace)(struct device___397 *);
	const struct dev_pm_ops___397 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___169 {
	void * (*alloc)(struct device___397 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___397 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___397 *, struct vm_area_struct___430 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___397 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___397 *, struct page___430 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___397 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___397 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___397 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___397 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___397 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___397 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___397 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___397 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___397 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___397 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___397 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___397 *, u64);
	u64 (*get_required_mask)(struct device___397 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___317;

struct fwnode_handle___317 {
	struct fwnode_handle___317 *secondary;
	const struct fwnode_operations___317 *ops;
};

typedef void compound_page_dtor___417(struct page___430 *);

struct fwnode_reference_args___317;

struct fwnode_endpoint___317;

struct fwnode_operations___317 {
	struct fwnode_handle___317 * (*get)(struct fwnode_handle___317 *);
	void (*put)(struct fwnode_handle___317 *);
	bool (*device_is_available)(const struct fwnode_handle___317 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___317 *, const struct device___397 *);
	bool (*property_present)(const struct fwnode_handle___317 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___317 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___317 *, const char *, const char **, size_t);
	struct fwnode_handle___317 * (*get_parent)(const struct fwnode_handle___317 *);
	struct fwnode_handle___317 * (*get_next_child_node)(const struct fwnode_handle___317 *, struct fwnode_handle___317 *);
	struct fwnode_handle___317 * (*get_named_child_node)(const struct fwnode_handle___317 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___317 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___317 *);
	struct fwnode_handle___317 * (*graph_get_next_endpoint)(const struct fwnode_handle___317 *, struct fwnode_handle___317 *);
	struct fwnode_handle___317 * (*graph_get_remote_endpoint)(const struct fwnode_handle___317 *);
	struct fwnode_handle___317 * (*graph_get_port_parent)(struct fwnode_handle___317 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___317 *, struct fwnode_endpoint___317 *);
};

struct fwnode_endpoint___317 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___317 *local_fwnode;
};

struct fwnode_reference_args___317 {
	struct fwnode_handle___317 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___110;

struct pipe_buffer___110 {
	struct page___430 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___110 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___110 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___110 *, struct pipe_buffer___110 *);
	void (*release)(struct pipe_inode_info___110 *, struct pipe_buffer___110 *);
	int (*steal)(struct pipe_inode_info___110 *, struct pipe_buffer___110 *);
	union {
		bool (*get)(struct pipe_inode_info___110 *, struct pipe_buffer___110 *);
		struct {
			void (*get)(struct pipe_inode_info___110 *, struct pipe_buffer___110 *);
		} __UNIQUE_ID_rh_kabi_hide21;
		union {		};
	};
};

struct nf_bridge_info___74 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___74 = 0,
		BRNF_PROTO_8021Q___74 = 1,
		BRNF_PROTO_PPPOE___74 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___75 *physindev;
	struct net_device___75 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___74(struct sk_buff___76 **);

struct net_device_ops___74;

struct ethtool_ops___74;

struct l3mdev_ops___54;

struct ndisc_ops___32;

struct xfrmdev_ops___74;

struct tlsdev_ops___74;

struct header_ops___74;

struct inet6_dev___32;

struct netdev_rx_queue___74;

struct mini_Qdisc___66;

struct netdev_queue___74;

struct Qdisc___66;

struct rtnl_link_ops___66;

struct dcbnl_rtnl_ops___74;

struct net_device___75 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___74 *netdev_ops;
	const struct ethtool_ops___74 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___54 *l3mdev_ops;
	const struct ndisc_ops___32 *ndisc_ops;
	const struct xfrmdev_ops___74 *xfrmdev_ops;
	const struct tlsdev_ops___74 *tlsdev_ops;
	const struct header_ops___74 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___416 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___32 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___74 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___64 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___74 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___66 *miniq_ingress;
	struct netdev_queue___74 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___74 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___66 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___66 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___74 = 0,
		NETREG_REGISTERED___74 = 1,
		NETREG_UNREGISTERING___74 = 2,
		NETREG_UNREGISTERED___74 = 3,
		NETREG_RELEASED___74 = 4,
		NETREG_DUMMY___74 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___74 = 0,
		RTNL_LINK_INITIALIZING___74 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___75 *);
	struct netpoll_info *npinfo;
	possible_net_t___76 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___397 dev;
	const struct attribute_group___394 *sysfs_groups[4];
	const struct attribute_group___394 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___66 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___74 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide35;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct inet_frag_queue___74;

struct inet_frags___74 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___74 *, const void *);
	void (*destructor)(struct inet_frag_queue___74 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___74 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___76 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___76 *fragments_tail;
	struct sk_buff___76 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___74 *net;
	struct callback_head rcu;
};

struct fib_rule___54;

struct fib_lookup_arg___54;

struct fib_rules_ops___54 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___54 *, struct flowi *, int, struct fib_lookup_arg___54 *);
	bool (*suppress)(struct fib_rule___54 *, struct fib_lookup_arg___54 *);
	int (*match)(struct fib_rule___54 *, struct flowi *, int);
	int (*configure)(struct fib_rule___54 *, struct sk_buff___76 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___54 *);
	int (*compare)(struct fib_rule___54 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___54 *, struct sk_buff___76 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___54 *);
	void (*flush_cache)(struct fib_rules_ops___54 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___357 *owner;
	struct net___86 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___55 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___86 *);
	int (*fib_dump)(struct net___86 *, struct notifier_block *);
	struct module___357 *owner;
	struct callback_head rcu;
};

struct lwtunnel_state___6;

struct dst_entry___54 {
	struct net_device___75 *dev;
	struct dst_ops___85 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___76 *);
	int (*output)(struct net___86 *, struct sock___55 *, struct sk_buff___76 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___6 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___54;

struct neigh_parms___54;

struct neigh_ops___54;

struct neighbour___54 {
	struct neighbour___54 *next;
	struct neigh_table___54 *tbl;
	struct neigh_parms___54 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___74 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___54 *, struct sk_buff___76 *);
	const struct neigh_ops___54 *ops;
	struct callback_head rcu;
	struct net_device___75 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct fib6_nh___11 {
	struct in6_addr nh_gw;
	struct net_device___75 *nh_dev;
	struct lwtunnel_state___6 *nh_lwtstate;
	unsigned int nh_flags;
	atomic_t nh_upper_bound;
	int nh_weight;
};

struct fib6_node___11;

struct fib6_info___11 {
	struct fib6_table___11 *fib6_table;
	struct fib6_info___11 *fib6_next;
	struct fib6_node___11 *fib6_node;
	struct list_head fib6_siblings;
	unsigned int fib6_nsiblings;
	atomic_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	struct rt6_info___11 **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
	long unsigned int last_probe;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 exception_bucket_flushed: 1;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 dst_host: 1;
	u8 fib6_destroying: 1;
	u8 unused: 2;
	struct fib6_nh___11 fib6_nh;
	struct callback_head rcu;
};

struct rt6_info___11 {
	struct dst_entry___54 dst;
	struct fib6_info___11 *from;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___32 *rt6i_idev;
	u32 rt6i_flags;
	struct rt6key rt6i_prefsrc;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct fib6_node___11 {
	struct fib6_node___11 *parent;
	struct fib6_node___11 *left;
	struct fib6_node___11 *right;
	struct fib6_info___11 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info___11 *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table___11 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node___11 tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

struct ucounts___294 {
	struct hlist_node node;
	struct user_namespace___294 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_prog_aux___67;

struct bpf_prog___64 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___67 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

typedef int (*key_restrict_link_func_t___398)(struct key___397 *, const struct key_type *, const union key_payload *, struct key___397 *);

struct key_restriction___397;

struct key___397 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___431 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___397 *restrict_link;
};

struct key_restriction___397 {
	key_restrict_link_func_t___398 check;
	struct key___397 *key;
	struct key_type *keytype;
};

struct seq_operations___368 {
	void * (*start)(struct seq_file___368 *, loff_t *);
	void (*stop)(struct seq_file___368 *, void *);
	void * (*next)(struct seq_file___368 *, void *, loff_t *);
	int (*show)(struct seq_file___368 *, void *);
};

struct pernet_operations___75 {
	struct list_head list;
	int (*init)(struct net___86 *);
	void (*exit)(struct net___86 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct ethtool_ops___74 {
	int (*get_settings)(struct net_device___75 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___75 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___75 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___75 *);
	void (*get_regs)(struct net_device___75 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___75 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___75 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___75 *);
	void (*set_msglevel)(struct net_device___75 *, u32);
	int (*nway_reset)(struct net_device___75 *);
	u32 (*get_link)(struct net_device___75 *);
	int (*get_eeprom_len)(struct net_device___75 *);
	int (*get_eeprom)(struct net_device___75 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___75 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___75 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___75 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___75 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___75 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___75 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___75 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___75 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___75 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___75 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___75 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___75 *);
	void (*complete)(struct net_device___75 *);
	u32 (*get_priv_flags)(struct net_device___75 *);
	int (*set_priv_flags)(struct net_device___75 *, u32);
	int (*get_sset_count)(struct net_device___75 *, int);
	int (*get_rxnfc)(struct net_device___75 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___75 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___75 *, struct ethtool_flash *);
	int (*reset)(struct net_device___75 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___75 *);
	u32 (*get_rxfh_indir_size)(struct net_device___75 *);
	int (*get_rxfh)(struct net_device___75 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___75 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___75 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___75 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___75 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___75 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___75 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___75 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___75 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___75 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___75 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___75 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___75 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___75 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___75 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___75 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___75 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___75 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___75 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___75 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___75 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___75 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	int (*get_fecparam)(struct net_device___75 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___75 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___75 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___75 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___75 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct dcbnl_rtnl_ops___74 {
	int (*ieee_getets)(struct net_device___75 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___75 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___75 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___75 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___75 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___75 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___75 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___75 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___75 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___75 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___75 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___75 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___75 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___75 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___75 *);
	u8 (*setstate)(struct net_device___75 *, u8);
	void (*getpermhwaddr)(struct net_device___75 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___75 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___75 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___75 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___75 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___75 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___75 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___75 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___75 *, int, u8 *);
	void (*setpfccfg)(struct net_device___75 *, int, u8);
	void (*getpfccfg)(struct net_device___75 *, int, u8 *);
	u8 (*setall)(struct net_device___75 *);
	u8 (*getcap)(struct net_device___75 *, int, u8 *);
	int (*getnumtcs)(struct net_device___75 *, int, u8 *);
	int (*setnumtcs)(struct net_device___75 *, int, u8);
	u8 (*getpfcstate)(struct net_device___75 *);
	void (*setpfcstate)(struct net_device___75 *, u8);
	void (*getbcncfg)(struct net_device___75 *, int, u32 *);
	void (*setbcncfg)(struct net_device___75 *, int, u32);
	void (*getbcnrp)(struct net_device___75 *, int, u8 *);
	void (*setbcnrp)(struct net_device___75 *, int, u8);
	int (*setapp)(struct net_device___75 *, u8, u16, u8);
	int (*getapp)(struct net_device___75 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___75 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___75 *, int, u8);
	u8 (*getdcbx)(struct net_device___75 *);
	u8 (*setdcbx)(struct net_device___75 *, u8);
	int (*peer_getappinfo)(struct net_device___75 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___75 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___75 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___75 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___75 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___75 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___278 {
	refcount_t count;
	struct ns_common___29 ns;
	struct user_namespace___294 *user_ns;
	struct ucounts___294 *ucounts;
	struct css_set___278 *root_cset;
};

struct bpf_map___279;

struct bpf_map_ops___278 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___279 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___279 *, struct file___429 *);
	void (*map_free)(struct bpf_map___279 *);
	int (*map_get_next_key)(struct bpf_map___279 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___279 *);
	void * (*map_lookup_elem)(struct bpf_map___279 *, void *);
	int (*map_update_elem)(struct bpf_map___279 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___279 *, void *);
	int (*map_push_elem)(struct bpf_map___279 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___279 *, void *);
	int (*map_peek_elem)(struct bpf_map___279 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___279 *, struct file___429 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___279 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___279 *, void *, struct seq_file___368 *);
	int (*map_check_btf)(const struct bpf_map___279 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___279 {
	const struct bpf_map_ops___278 *ops;
	struct bpf_map___279 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___397 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___74;

struct bpf_map_dev_ops___74 {
	int (*map_get_next_key)(struct bpf_offloaded_map___74 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___74 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___74 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___74 *, void *);
};

struct bpf_offloaded_map___74 {
	struct bpf_map___279 map;
	struct net_device___75 *netdev;
	const struct bpf_map_dev_ops___74 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___64 {
	int (*test_run)(struct bpf_prog___64 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___64 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___64 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___64 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___64 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___64 *, u32 *);
};

struct bpf_prog_offload_ops___64 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___64 *);
	int (*translate)(struct bpf_prog___64 *);
	void (*destroy)(struct bpf_prog___64 *);
};

struct bpf_prog_offload___64 {
	struct bpf_prog___64 *prog;
	struct net_device___75 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___64 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___67 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___64 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___64 *ops;
	struct bpf_map___279 **used_maps;
	struct bpf_prog___64 *prog;
	struct user_struct___397 *user;
	u64 load_time;
	struct bpf_map___279 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___64 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___64 {
	struct bpf_prog___64 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___64 {
	struct callback_head rcu;
	struct bpf_prog_array_item___64 items[0];
};

struct cgroup_bpf___64 {
	struct bpf_prog_array___64 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___64 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___279;

typedef void (*kthread_work_func_t___279)(struct kthread_work___279 *);

struct kthread_worker___279;

struct kthread_work___279 {
	struct list_head node;
	kthread_work_func_t___279 func;
	struct kthread_worker___279 *worker;
	int canceling;
};

struct kthread_worker___279 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___431 *task;
	struct kthread_work___279 *current_work;
};

struct kthread_delayed_work___278 {
	struct kthread_work___279 work;
	struct timer_list timer;
};

struct psi_group___278 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___279 *poll_kworker;
	struct kthread_delayed_work___278 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___278;

struct cgroup_rstat_cpu___278;

struct cgroup___278 {
	struct cgroup_subsys_state___278 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___424 *kn;
	struct cgroup_file___278 procs_file;
	struct cgroup_file___278 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___278 *subsys[13];
	struct cgroup_root___278 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___278 *dom_cgrp;
	struct cgroup_rstat_cpu___278 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___64 bpf;
	atomic_t congestion_count;
	struct cgroup___278 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___278 psi;
	int ancestor_ids[0];
};

struct cftype___278;

struct cgroup_subsys___278 {
	struct cgroup_subsys_state___278 * (*css_alloc)(struct cgroup_subsys_state___278 *);
	int (*css_online)(struct cgroup_subsys_state___278 *);
	void (*css_offline)(struct cgroup_subsys_state___278 *);
	void (*css_released)(struct cgroup_subsys_state___278 *);
	void (*css_free)(struct cgroup_subsys_state___278 *);
	void (*css_reset)(struct cgroup_subsys_state___278 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___278 *, int);
	int (*css_extra_stat_show)(struct seq_file___368 *, struct cgroup_subsys_state___278 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___431 *);
	void (*cancel_fork)(struct task_struct___431 *);
	void (*fork)(struct task_struct___431 *);
	void (*exit)(struct task_struct___431 *);
	void (*free)(struct task_struct___431 *);
	void (*bind)(struct cgroup_subsys_state___278 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___278 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___278 *dfl_cftypes;
	struct cftype___278 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___278 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___278 *updated_children;
	struct cgroup___278 *updated_next;
};

struct cgroup_root___278 {
	struct kernfs_root___423 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___278 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___278 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___278 *ss;
	struct list_head node;
	struct kernfs_ops___423 *kf_ops;
	int (*open)(struct kernfs_open_file___423 *);
	void (*release)(struct kernfs_open_file___423 *);
	u64 (*read_u64)(struct cgroup_subsys_state___278 *, struct cftype___278 *);
	s64 (*read_s64)(struct cgroup_subsys_state___278 *, struct cftype___278 *);
	int (*seq_show)(struct seq_file___368 *, void *);
	void * (*seq_start)(struct seq_file___368 *, loff_t *);
	void * (*seq_next)(struct seq_file___368 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___368 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___278 *, struct cftype___278 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___278 *, struct cftype___278 *, s64);
	ssize_t (*write)(struct kernfs_open_file___423 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___423 *, struct poll_table_struct___268 *);
};

struct xdp_rxq_info___74 {
	struct net_device___75 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___74 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___75 *dev_rx;
};

struct netlink_skb_parms___12 {
	struct scm_creds creds;
	__u32 portid;
	__u32 dst_group;
	__u32 flags;
	struct sock___55 *sk;
	bool nsid_is_set;
	int nsid;
};

struct netlink_callback___76 {
	struct sk_buff___76 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___76 *);
	int (*dump)(struct sk_buff___76 *, struct netlink_callback___76 *);
	int (*done)(struct netlink_callback___76 *);
	void *data;
	struct module___357 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

enum {
	TCA_ACT_UNSPEC = 0,
	TCA_ACT_KIND = 1,
	TCA_ACT_OPTIONS = 2,
	TCA_ACT_INDEX = 3,
	TCA_ACT_STATS = 4,
	TCA_ACT_PAD = 5,
	TCA_ACT_COOKIE = 6,
	__TCA_ACT_MAX = 7,
};

enum tca_id {
	TCA_ID_UNSPEC = 0,
	TCA_ID_POLICE = 1,
	TCA_ID_GACT = 5,
	TCA_ID_IPT = 6,
	TCA_ID_PEDIT = 7,
	TCA_ID_MIRRED = 8,
	TCA_ID_NAT = 9,
	TCA_ID_XT = 10,
	TCA_ID_SKBEDIT = 11,
	TCA_ID_VLAN = 12,
	TCA_ID_BPF = 13,
	TCA_ID_CONNMARK = 14,
	TCA_ID_SKBMOD = 15,
	TCA_ID_CSUM = 16,
	TCA_ID_TUNNEL_KEY = 17,
	TCA_ID_SIMP = 22,
	TCA_ID_IFE = 25,
	TCA_ID_SAMPLE = 26,
	__TCA_ID_MAX = 255,
};

struct tcf_t {
	__u64 install;
	__u64 lastuse;
	__u64 expires;
	__u64 firstuse;
};

struct header_ops___74 {
	int (*create)(struct sk_buff___76 *, struct net_device___75 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___76 *, unsigned char *);
	int (*cache)(const struct neighbour___54 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___75 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___74 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___74 *, int);
	int poll_owner;
	struct net_device___75 *dev;
	struct sk_buff___76 *gro_list;
	struct sk_buff___76 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___74 {
	struct net_device___75 *dev;
	struct Qdisc___66 *qdisc;
	struct Qdisc___66 *qdisc_sleeping;
	struct kobject___417 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___75 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem___3 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___66 {
	struct sk_buff___76 *head;
	struct sk_buff___76 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___66;

struct Qdisc___66 {
	int (*enqueue)(struct sk_buff___76 *, struct Qdisc___66 *, struct sk_buff___76 **);
	struct sk_buff___76 * (*dequeue)(struct Qdisc___66 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___66 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___74 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___74 gso_skb;
	struct qdisc_skb_head___66 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___66 *next_sched;
	struct sk_buff_head___74 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___74 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___417 kobj;
	struct net_device___75 *dev;
	long: 64;
	struct xdp_rxq_info___74 xdp_rxq;
	union {
		struct xdp_umem___3 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___74)(struct net_device___75 *, struct sk_buff___76 *, struct net_device___75 *);

struct netdev_bpf___74 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___64 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___64 *prog;
			const struct bpf_prog_offload_ops___64 *ops;
		} verifier;
		struct {
			struct bpf_prog___64 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___74 *offmap;
		};
		struct {
			struct xdp_umem___3 *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___74 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___76 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___74 {
	int (*tls_dev_add)(struct net_device___75 *, struct sock___55 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___75 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___75 *, struct sock___55 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___74 {
	int (*ndo_init)(struct net_device___75 *);
	void (*ndo_uninit)(struct net_device___75 *);
	int (*ndo_open)(struct net_device___75 *);
	int (*ndo_stop)(struct net_device___75 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___76 *, struct net_device___75 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___76 *, struct net_device___75 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___75 *, struct sk_buff___76 *, struct net_device___75 *, select_queue_fallback_t___74);
	void (*ndo_change_rx_flags)(struct net_device___75 *, int);
	void (*ndo_set_rx_mode)(struct net_device___75 *);
	int (*ndo_set_mac_address)(struct net_device___75 *, void *);
	int (*ndo_validate_addr)(struct net_device___75 *);
	int (*ndo_do_ioctl)(struct net_device___75 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___75 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___75 *, int);
	int (*ndo_neigh_setup)(struct net_device___75 *, struct neigh_parms___54 *);
	void (*ndo_tx_timeout)(struct net_device___75 *);
	void (*ndo_get_stats64)(struct net_device___75 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___75 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___75 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___75 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___75 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___75 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___75 *);
	int (*ndo_netpoll_setup)(struct net_device___75 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___75 *);
	int (*ndo_set_vf_mac)(struct net_device___75 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___75 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___75 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___75 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___75 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___75 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___75 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___75 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___75 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___75 *, int, struct sk_buff___76 *);
	int (*ndo_set_vf_guid)(struct net_device___75 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___75 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___75 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___75 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___75 *, const struct sk_buff___76 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___75 *, struct net_device___75 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___75 *, struct net_device___75 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___75 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___75 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___75 *, struct neighbour___54 *);
	void (*ndo_neigh_destroy)(struct net_device___75 *, struct neighbour___54 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___75 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___75 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___75 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___76 *, struct netlink_callback___76 *, struct net_device___75 *, struct net_device___75 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___75 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___75 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___76 *, u32, u32, struct net_device___75 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___75 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___75 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___75 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___75 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___75 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___75 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___75 *, struct net_device___75 *);
	void (*ndo_dfwd_del_station)(struct net_device___75 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___75 *);
	int (*ndo_set_tx_maxrate)(struct net_device___75 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___75 *);
	int (*ndo_change_proto_down)(struct net_device___75 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___75 *, struct sk_buff___76 *);
	void (*ndo_set_rx_headroom)(struct net_device___75 *, int);
	int (*ndo_bpf)(struct net_device___75 *, struct netdev_bpf___74 *);
	int (*ndo_xdp_xmit)(struct net_device___75 *, int, struct xdp_frame___74 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___75 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___75 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___54 {
	possible_net_t___76 net;
	struct net_device___75 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___54 *);
	void (*neigh_cleanup)(struct neighbour___54 *);
	struct neigh_table___54 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___54 {
	u32 (*l3mdev_fib_table)(const struct net_device___75 *);
	struct sk_buff___76 * (*l3mdev_l3_rcv)(struct net_device___75 *, struct sk_buff___76 *, u16);
	struct sk_buff___76 * (*l3mdev_l3_out)(struct net_device___75 *, struct sock___55 *, struct sk_buff___76 *, u16);
	struct dst_entry___54 * (*l3mdev_link_scope_lookup)(const struct net_device___75 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct ndisc_ops___32 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___75 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___75 *, struct neighbour___54 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___75 *, u8, struct neighbour___54 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___75 *, struct sk_buff___76 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___86 *, struct net_device___75 *, const struct prefix_info *, struct inet6_dev___32 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___32;

struct ifacaddr6___11;

struct inet6_dev___32 {
	struct net_device___75 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___32 *mc_list;
	struct ifmcaddr6___32 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___11 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	u8 rndid[8];
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___54 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
};

struct tcf_proto___66;

struct mini_Qdisc___66 {
	struct tcf_proto___66 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___66 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___75 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___86 *, struct net_device___75 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___75 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___75 *, struct list_head *);
	size_t (*get_size)(const struct net_device___75 *);
	int (*fill_info)(struct sk_buff___76 *, const struct net_device___75 *);
	size_t (*get_xstats_size)(const struct net_device___75 *);
	int (*fill_xstats)(struct sk_buff___76 *, const struct net_device___75 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___75 *, struct net_device___75 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___75 *, const struct net_device___75 *);
	int (*fill_slave_info)(struct sk_buff___76 *, const struct net_device___75 *, const struct net_device___75 *);
	struct net___86 * (*get_link_net)(const struct net_device___75 *);
	size_t (*get_linkxstats_size)(const struct net_device___75 *, int);
	int (*fill_linkxstats)(struct sk_buff___76 *, const struct net_device___75 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___74 {
	struct list_head poll_list;
	struct sk_buff_head___74 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___74 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___66 *output_queue;
	struct Qdisc___66 **output_queue_tailp;
	struct sk_buff___76 *completion_queue;
	struct sk_buff_head___74 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___74 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___74 input_pkt_queue;
	struct napi_struct___74 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bdi_writeback_congested___219 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___219 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___219 {
	struct bio___219 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___221 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___221 bip_inline_vecs[0];
};

struct bio_set___219 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___219 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___162 {
	struct mem_cgroup___162 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___162 {
	struct lruvec___430 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___162 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___162 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct gnet_dump___66 {
	spinlock_t *lock;
	struct sk_buff___76 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

typedef int tc_indr_block_bind_cb_t(struct net_device___75 *, void *, enum tc_setup_type, void *);

struct Qdisc_class_ops___66;

struct Qdisc_ops___66 {
	struct Qdisc_ops___66 *next;
	const struct Qdisc_class_ops___66 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___76 *, struct Qdisc___66 *, struct sk_buff___76 **);
	struct sk_buff___76 * (*dequeue)(struct Qdisc___66 *);
	struct sk_buff___76 * (*peek)(struct Qdisc___66 *);
	int (*init)(struct Qdisc___66 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___66 *);
	void (*destroy)(struct Qdisc___66 *);
	int (*change)(struct Qdisc___66 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___66 *);
	int (*change_tx_queue_len)(struct Qdisc___66 *, unsigned int);
	int (*dump)(struct Qdisc___66 *, struct sk_buff___76 *);
	int (*dump_stats)(struct Qdisc___66 *, struct gnet_dump___66 *);
	void (*ingress_block_set)(struct Qdisc___66 *, u32);
	void (*egress_block_set)(struct Qdisc___66 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___66 *);
	u32 (*egress_block_get)(struct Qdisc___66 *);
	struct module___357 *owner;
};

struct qdisc_walker___10;

struct tcf_block___66;

struct Qdisc_class_ops___66 {
	unsigned int flags;
	struct netdev_queue___74 * (*select_queue)(struct Qdisc___66 *, struct tcmsg *);
	int (*graft)(struct Qdisc___66 *, long unsigned int, struct Qdisc___66 *, struct Qdisc___66 **, struct netlink_ext_ack *);
	struct Qdisc___66 * (*leaf)(struct Qdisc___66 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___66 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___66 *, u32);
	int (*change)(struct Qdisc___66 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___66 *, long unsigned int);
	void (*walk)(struct Qdisc___66 *, struct qdisc_walker___10 *);
	struct tcf_block___66 * (*tcf_block)(struct Qdisc___66 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___66 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___66 *, long unsigned int);
	int (*dump)(struct Qdisc___66 *, long unsigned int, struct sk_buff___76 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___66 *, long unsigned int, struct gnet_dump___66 *);
};

struct qdisc_walker___10 {
	int stop;
	int skip;
	int count;
	int (*fn)(struct Qdisc___66 *, long unsigned int, struct qdisc_walker___10 *);
};

struct tcf_chain___66;

struct tcf_block___66 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___86 *net;
	struct Qdisc___66 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___66 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

enum qdisc_class_ops_flags {
	QDISC_CLASS_OPS_DOIT_UNLOCKED = 1,
};

struct tcf_result___66;

struct tcf_proto_ops___66;

struct tcf_proto___66 {
	struct tcf_proto___66 *next;
	void *root;
	int (*classify)(struct sk_buff___76 *, const struct tcf_proto___66 *, struct tcf_result___66 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___66 *ops;
	struct tcf_chain___66 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___66 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___66 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_walker___5;

struct tcf_proto_ops___66 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___76 *, const struct tcf_proto___66 *, struct tcf_result___66 *);
	int (*init)(struct tcf_proto___66 *);
	void (*destroy)(struct tcf_proto___66 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___66 *, u32);
	void (*put)(struct tcf_proto___66 *, void *);
	int (*change)(struct net___86 *, struct sk_buff___76 *, struct tcf_proto___66 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___66 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___66 *, struct tcf_walker___5 *, bool);
	int (*reoffload)(struct tcf_proto___66 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___86 *, struct tcf_chain___66 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___86 *, struct tcf_proto___66 *, void *, struct sk_buff___76 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___76 *, struct net___86 *, void *);
	struct module___357 *owner;
	int flags;
};

struct tcf_walker___5 {
	int stop;
	int skip;
	int count;
	bool nonempty;
	long unsigned int cookie;
	int (*fn)(struct tcf_proto___66 *, void *, struct tcf_walker___5 *);
};

struct tcf_chain___66 {
	struct mutex filter_chain_lock;
	struct tcf_proto___66 *filter_chain;
	struct list_head list;
	struct tcf_block___66 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___66 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

enum tcf_proto_ops_flags {
	TCF_PROTO_OPS_DOIT_UNLOCKED = 1,
};

typedef void tcf_chain_head_change_t(struct tcf_proto___66 *, void *);

struct sk_filter___54 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___64 *prog;
};

struct bpf_redirect_info___64 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___279 *map;
	struct bpf_map___279 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___54;

struct neigh_hash_table___54;

struct neigh_table___54 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___75 *, __u32 *);
	bool (*key_eq)(const struct neighbour___54 *, const void *);
	int (*constructor)(struct neighbour___54 *);
	int (*pconstructor)(struct pneigh_entry___54 *);
	void (*pdestructor)(struct pneigh_entry___54 *);
	void (*proxy_redo)(struct sk_buff___76 *);
	char *id;
	struct neigh_parms___54 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___74 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___54 *nht;
	struct pneigh_entry___54 **phash_buckets;
};

struct neigh_ops___54 {
	int family;
	void (*solicit)(struct neighbour___54 *, struct sk_buff___76 *);
	void (*error_report)(struct neighbour___54 *, struct sk_buff___76 *);
	int (*output)(struct neighbour___54 *, struct sk_buff___76 *);
	int (*connected_output)(struct neighbour___54 *, struct sk_buff___76 *);
};

struct pneigh_entry___54 {
	struct pneigh_entry___54 *next;
	possible_net_t___76 net;
	struct net_device___75 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___54 {
	struct neighbour___54 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___6 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___86 *, struct sock___55 *, struct sk_buff___76 *);
	int (*orig_input)(struct sk_buff___76 *);
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	__u8 data[0];
};

struct fib_rule___54 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___54 *ctarget;
	struct net___86 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___54 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___54 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___38;

struct timewait_sock_ops___35;

struct proto___54 {
	void (*close)(struct sock___55 *, long int);
	int (*pre_connect)(struct sock___55 *, struct sockaddr *, int);
	int (*connect)(struct sock___55 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___55 *, int);
	struct sock___55 * (*accept)(struct sock___55 *, int, int *, bool);
	int (*ioctl)(struct sock___55 *, int, long unsigned int);
	int (*init)(struct sock___55 *);
	void (*destroy)(struct sock___55 *);
	void (*shutdown)(struct sock___55 *, int);
	int (*setsockopt)(struct sock___55 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___55 *, int, int, char *, int *);
	void (*keepalive)(struct sock___55 *, int);
	int (*sendmsg)(struct sock___55 *, struct msghdr___57 *, size_t);
	int (*recvmsg)(struct sock___55 *, struct msghdr___57 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___55 *, struct page___430 *, int, size_t, int);
	int (*bind)(struct sock___55 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___55 *, struct sk_buff___76 *);
	void (*release_cb)(struct sock___55 *);
	int (*hash)(struct sock___55 *);
	void (*unhash)(struct sock___55 *);
	void (*rehash)(struct sock___55 *);
	int (*get_port)(struct sock___55 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___55 *);
	bool (*stream_memory_read)(const struct sock___55 *);
	void (*enter_memory_pressure)(struct sock___55 *);
	void (*leave_memory_pressure)(struct sock___55 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___38 *rsk_prot;
	struct timewait_sock_ops___35 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___357 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___55 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct request_sock___39;

struct request_sock_ops___38 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___55 *, struct request_sock___39 *);
	void (*send_ack)(const struct sock___55 *, struct sk_buff___76 *, struct request_sock___39 *);
	void (*send_reset)(const struct sock___55 *, struct sk_buff___76 *);
	void (*destructor)(struct request_sock___39 *);
	void (*syn_ack_timeout)(const struct request_sock___39 *);
};

struct timewait_sock_ops___35 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___55 *, struct sock___55 *, void *);
	void (*twsk_destructor)(struct sock___55 *);
};

struct tcf_idrinfo {
	struct mutex lock;
	struct idr action_idr;
};

struct tc_action_ops;

struct tc_cookie;

struct tc_action {
	const struct tc_action_ops *ops;
	__u32 type;
	__u32 order;
	struct tcf_idrinfo *idrinfo;
	u32 tcfa_index;
	refcount_t tcfa_refcnt;
	atomic_t tcfa_bindcnt;
	int tcfa_action;
	struct tcf_t tcfa_tm;
	struct gnet_stats_basic_packed tcfa_bstats;
	struct gnet_stats_basic_packed tcfa_bstats_hw;
	struct gnet_stats_queue tcfa_qstats;
	int: 32;
	struct net_rate_estimator *tcfa_rate_est;
	spinlock_t tcfa_lock;
	int: 32;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_basic_cpu *cpu_bstats_hw;
	struct gnet_stats_queue *cpu_qstats;
	struct tc_cookie *act_cookie;
	struct tcf_chain___66 *goto_chain;
} __attribute__((packed));

struct tc_action_ops {
	struct list_head head;
	char kind[16];
	enum tca_id id;
	size_t size;
	struct module___357 *owner;
	int (*act)(struct sk_buff___76 *, const struct tc_action *, struct tcf_result___66 *);
	int (*dump)(struct sk_buff___76 *, struct tc_action *, int, int);
	void (*cleanup)(struct tc_action *);
	int (*lookup)(struct net___86 *, struct tc_action **, u32);
	int (*init)(struct net___86 *, struct nlattr *, struct nlattr *, struct tc_action **, int, int, bool, struct tcf_proto___66 *, struct netlink_ext_ack *);
	int (*walk)(struct net___86 *, struct sk_buff___76 *, struct netlink_callback___76 *, int, const struct tc_action_ops *, struct netlink_ext_ack *);
	void (*stats_update)(struct tc_action *, u64, u32, u64, bool);
	size_t (*get_fill_size)(const struct tc_action *);
	struct net_device___75 * (*get_dev)(const struct tc_action *);
	void (*put_dev)(struct net_device___75 *);
};

struct tc_cookie {
	u8 *data;
	u32 len;
	struct callback_head rcu;
};

struct psample_group {
	struct list_head list;
	struct net___86 *net;
	u32 group_num;
	u32 refcount;
	u32 seq;
};

struct flow_action_entry___2 {
	enum flow_action_id id;
	union {
		u32 chain_index;
		struct net_device___75 *dev;
		struct {
			u16 vid;
			__be16 proto;
			u8 prio;
		} vlan;
		struct {
			enum flow_action_mangle_base htype;
			u32 offset;
			u32 mask;
			u32 val;
		} mangle;
		const struct ip_tunnel_info *tunnel;
		u32 csum_flags;
		u32 mark;
		struct {
			u32 ctx;
			u32 index;
			u8 vf;
		} queue;
		struct {
			struct psample_group *psample_group;
			u32 rate;
			u32 trunc_size;
			bool truncate;
		} sample;
	};
};

struct flow_action___2 {
	unsigned int num_entries;
	struct flow_action_entry___2 entries[0];
};

enum tcf_block_binder_type {
	TCF_BLOCK_BINDER_TYPE_UNSPEC = 0,
	TCF_BLOCK_BINDER_TYPE_CLSACT_INGRESS = 1,
	TCF_BLOCK_BINDER_TYPE_CLSACT_EGRESS = 2,
};

struct tcf_block_ext_info {
	enum tcf_block_binder_type binder_type;
	tcf_chain_head_change_t *chain_head_change;
	void *chain_head_change_priv;
	u32 block_index;
};

struct tcf_exts {
	__u32 type;
	int nr_actions;
	struct tc_action **actions;
	struct net___86 *net;
	int action;
	int police;
};

enum tc_block_command {
	TC_BLOCK_BIND = 0,
	TC_BLOCK_UNBIND = 1,
};

struct tc_block_offload {
	enum tc_block_command command;
	enum tcf_block_binder_type binder_type;
	struct tcf_block___66 *block;
	struct netlink_ext_ack *extack;
};

enum pedit_header_type {
	TCA_PEDIT_KEY_EX_HDR_TYPE_NETWORK = 0,
	TCA_PEDIT_KEY_EX_HDR_TYPE_ETH = 1,
	TCA_PEDIT_KEY_EX_HDR_TYPE_IP4 = 2,
	TCA_PEDIT_KEY_EX_HDR_TYPE_IP6 = 3,
	TCA_PEDIT_KEY_EX_HDR_TYPE_TCP = 4,
	TCA_PEDIT_KEY_EX_HDR_TYPE_UDP = 5,
	__PEDIT_HDR_TYPE_MAX = 6,
};

enum pedit_cmd {
	TCA_PEDIT_KEY_EX_CMD_SET = 0,
	TCA_PEDIT_KEY_EX_CMD_ADD = 1,
	__PEDIT_CMD_MAX = 2,
};

struct tc_pedit_key {
	__u32 mask;
	__u32 val;
	__u32 off;
	__u32 at;
	__u32 offmask;
	__u32 shift;
};

struct tcf_pedit_key_ex {
	enum pedit_header_type htype;
	enum pedit_cmd cmd;
};

struct tcf_pedit {
	struct tc_action common;
	unsigned char tcfp_nkeys;
	unsigned char tcfp_flags;
	struct tc_pedit_key *tcfp_keys;
	struct tcf_pedit_key_ex *tcfp_keys_ex;
};

struct tcf_mirred {
	struct tc_action common;
	int tcfm_eaction;
	bool tcfm_mac_header_xmit;
	struct net_device___75 *tcfm_dev;
	struct list_head tcfm_list;
};

struct tcf_vlan_params {
	int tcfv_action;
	u16 tcfv_push_vid;
	__be16 tcfv_push_proto;
	u8 tcfv_push_prio;
	struct callback_head rcu;
};

struct tcf_vlan {
	struct tc_action common;
	struct tcf_vlan_params *vlan_p;
};

struct request_sock___39 {
	struct sock_common___54 __req_common;
	struct request_sock___39 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___38 *rsk_ops;
	struct sock___55 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___32 {
	struct in6_addr mca_addr;
	struct inet6_dev___32 *idev;
	struct ifmcaddr6___32 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___11 {
	struct in6_addr aca_addr;
	struct fib6_info___11 *aca_rt;
	struct ifacaddr6___11 *aca_next;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct ip6_ra_chain___32 {
	struct ip6_ra_chain___32 *next;
	struct sock___55 *sk;
	int sel;
	void (*destructor)(struct sock___55 *);
};

struct ipv6_stub___8 {
	int (*ipv6_sock_mc_join)(struct sock___55 *, int, const struct in6_addr *);
	int (*ipv6_sock_mc_drop)(struct sock___55 *, int, const struct in6_addr *);
	int (*ipv6_dst_lookup)(struct net___86 *, struct sock___55 *, struct dst_entry___54 **, struct flowi6 *);
	struct fib6_table___11 * (*fib6_get_table)(struct net___86 *, u32);
	struct fib6_info___11 * (*fib6_lookup)(struct net___86 *, int, struct flowi6 *, int);
	struct fib6_info___11 * (*fib6_table_lookup)(struct net___86 *, struct fib6_table___11 *, int, struct flowi6 *, int);
	struct fib6_info___11 * (*fib6_multipath_select)(const struct net___86 *, struct fib6_info___11 *, struct flowi6 *, int, const struct sk_buff___76 *, int);
	u32 (*ip6_mtu_from_fib6)(struct fib6_info___11 *, struct in6_addr *, struct in6_addr *);
	void (*udpv6_encap_enable)();
	void (*ndisc_send_na)(struct net_device___75 *, const struct in6_addr *, const struct in6_addr *, bool, bool, bool, bool);
	struct neigh_table___54 *nd_tbl;
};

struct ipv6_bpf_stub___8 {
	int (*inet6_bind)(struct sock___55 *, struct sockaddr *, int, bool, bool);
	struct sock___55 * (*udp6_lib_lookup)(struct net___86 *, const struct in6_addr *, __be16, const struct in6_addr *, __be16, int, int, struct udp_table *, struct sk_buff___76 *);
};

struct ip_tunnel_encap_ops___6 {
	size_t (*encap_hlen)(struct ip_tunnel_encap *);
	int (*build_header)(struct sk_buff___76 *, struct ip_tunnel_encap *, u8 *, struct flowi4 *);
};

struct hw_port_info___5 {
	struct net_device___75 *lower_dev;
	u32 port_id;
};

struct metadata_dst___5 {
	struct dst_entry___54 dst;
	enum metadata_type type;
	union {
		struct ip_tunnel_info tun_info;
		struct hw_port_info___5 port_info;
	} u;
};

struct tcf_tunnel_key_params {
	struct callback_head rcu;
	int tcft_action;
	struct metadata_dst___5 *tcft_enc_metadata;
};

struct tcf_tunnel_key {
	struct tc_action common;
	struct tcf_tunnel_key_params *params;
};

struct tcf_csum_params {
	u32 update_flags;
	struct callback_head rcu;
};

struct tcf_csum {
	struct tc_action common;
	struct tcf_csum_params *params;
};

struct tcf_gact {
	struct tc_action common;
	u16 tcfg_ptype;
	u16 tcfg_pval;
	int tcfg_paction;
	atomic_t packets;
};

struct tcf_sample {
	struct tc_action common;
	u32 rate;
	bool truncate;
	u32 trunc_size;
	struct psample_group *psample_group;
	u32 psample_group_num;
	struct list_head tcfm_list;
};

struct tcf_skbedit_params {
	u32 flags;
	u32 priority;
	u32 mark;
	u32 mask;
	u16 queue_mapping;
	u16 ptype;
	struct callback_head rcu;
};

struct tcf_skbedit {
	struct tc_action common;
	struct tcf_skbedit_params *params;
};

struct tcf_filter_chain_list_item {
	struct list_head list;
	tcf_chain_head_change_t *chain_head_change;
	void *chain_head_change_priv;
};

struct tc_indr_block_dev {
	struct rhash_head ht_node;
	struct net_device___75 *dev;
	unsigned int refcnt;
	struct list_head cb_list;
	struct tcf_block___66 *block;
};

struct tc_indr_block_cb {
	struct list_head list;
	void *cb_priv;
	tc_indr_block_bind_cb_t *cb;
	void *cb_ident;
};

struct tcf_net {
	spinlock_t idr_lock;
	struct idr idr;
};

struct tcf_block_owner_item {
	struct list_head list;
	struct Qdisc___66 *q;
	enum tcf_block_binder_type binder_type;
};

struct tcf_block_cb {
	struct list_head list;
	tc_setup_cb_t *cb;
	void *cb_ident;
	void *cb_priv;
	unsigned int refcnt;
};

struct tcf_chain_info {
	struct tcf_proto___66 **pprev;
	struct tcf_proto___66 *next;
};

struct tcf_dump_args {
	struct tcf_walker___5 w;
	struct sk_buff___76 *skb;
	struct netlink_callback___76 *cb;
	struct tcf_block___66 *block;
	struct Qdisc___66 *q;
	u32 parent;
};

struct module___358;

struct file___430;

struct kiocb___430;

struct iov_iter___197;

struct poll_table_struct___269;

struct vm_area_struct___431;

struct inode___430;

struct file_lock___430;

struct page___431;

struct pipe_inode_info___111;

struct seq_file___369;

struct file_operations___430 {
	struct module___358 *owner;
	loff_t (*llseek)(struct file___430 *, loff_t, int);
	ssize_t (*read)(struct file___430 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___430 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___430 *, struct iov_iter___197 *);
	ssize_t (*write_iter)(struct kiocb___430 *, struct iov_iter___197 *);
	int (*iopoll)(struct kiocb___430 *, bool);
	int (*iterate)(struct file___430 *, struct dir_context *);
	int (*iterate_shared)(struct file___430 *, struct dir_context *);
	__poll_t (*poll)(struct file___430 *, struct poll_table_struct___269 *);
	long int (*unlocked_ioctl)(struct file___430 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___430 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___430 *, struct vm_area_struct___431 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___430 *, struct file___430 *);
	int (*flush)(struct file___430 *, fl_owner_t);
	int (*release)(struct inode___430 *, struct file___430 *);
	int (*fsync)(struct file___430 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___430 *, int);
	int (*lock)(struct file___430 *, int, struct file_lock___430 *);
	ssize_t (*sendpage)(struct file___430 *, struct page___431 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___430 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___430 *, int, struct file_lock___430 *);
	ssize_t (*splice_write)(struct pipe_inode_info___111 *, struct file___430 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___430 *, loff_t *, struct pipe_inode_info___111 *, size_t, unsigned int);
	int (*setlease)(struct file___430 *, long int, struct file_lock___430 **, void **);
	long int (*fallocate)(struct file___430 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___369 *, struct file___430 *);
	ssize_t (*copy_file_range)(struct file___430 *, loff_t, struct file___430 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___430 *, loff_t, struct file___430 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___430 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___431 {
	u64 seqnum;
	struct vm_area_struct___431 *vmas[4];
};

struct page_frag___431 {
	struct page___431 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___431;

struct mem_cgroup___163;

struct cred___398;

struct nsproxy___325;

struct signal_struct___305;

struct bio_list___220;

struct backing_dev_info___220;

struct css_set___279;

struct vm_struct___334;

struct task_struct___432 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___432 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___431 *mm;
	struct mm_struct___431 *active_mm;
	struct vmacache___431 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___432 *real_parent;
	struct task_struct___432 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___432 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___163 *active_memcg;
	long int rh_reserved2;
	struct pid___241 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___241 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___241 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___398 *ptracer_cred;
	const struct cred___398 *real_cred;
	const struct cred___398 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___325 *nsproxy;
	struct signal_struct___305 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___432 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___220 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___220 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___279 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___111 *splice_pipe;
	struct page_frag___431 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___163 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___432 *oom_reaper_list;
	struct vm_struct___334 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___156 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___431 *pgtable_t___431;

struct address_space___430;

struct dev_pagemap___418;

struct page___431 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___430 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___431 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___431 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___431 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___418 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___163 *mem_cgroup;
};

struct pglist_data___431;

struct lruvec___431 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___431 *pgdat;
};

struct zone___431 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___431 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___431 {
	struct zone___431 *zone;
	int zone_idx;
};

struct zonelist___431 {
	struct zoneref___431 _zonerefs[25];
};

struct pglist_data___431 {
	struct zone___431 node_zones[3];
	struct zonelist___431 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___432 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___432 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___431 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___432 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___432 *owner;
};

struct secondary_data___432 {
	void *stack;
	struct task_struct___432 *task;
	long int status;
};

struct blocking_notifier_head___431 {
	struct rw_semaphore___432 rwsem;
	struct notifier_block *head;
};

struct cgroup___279;

struct cgroup_subsys___279;

struct cgroup_subsys_state___279 {
	struct cgroup___279 *cgroup;
	struct cgroup_subsys___279 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___279 *parent;
};

struct kernfs_node___425;

struct cgroup_file___279 {
	struct kernfs_node___425 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___163;

struct mem_cgroup___163 {
	struct cgroup_subsys_state___279 css;
	struct mem_cgroup_id___13 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___279 events_file;
	struct cgroup_file___279 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___432 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___163 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct key___398;

struct ucounts___295;

struct user_namespace___295 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___295 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___29 ns;
	long unsigned int flags;
	struct key___398 *persistent_keyring_register;
	struct rw_semaphore___432 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___295 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct user_struct___398 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___398 *uid_keyring;
	struct key___398 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___418;

struct vm_area_struct___431 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___431 *vm_next;
	struct vm_area_struct___431 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___431 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___418 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___430 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___431;

struct mm_struct___431 {
	struct {
		struct vm_area_struct___431 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___430 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___432 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___431 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___432 *owner;
		struct user_namespace___295 *user_ns;
		struct file___430 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___431 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___398 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___398 *session_keyring;
	struct key___398 *process_keyring;
	struct key___398 *thread_keyring;
	struct key___398 *request_key_auth;
	void *security;
	struct user_struct___398 *user;
	struct user_namespace___295 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___87;

struct cgroup_namespace___279;

struct nsproxy___325 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net___87 *net_ns;
	struct cgroup_namespace___279 *cgroup_ns;
};

struct signal_struct___305 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___432 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___432 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___241 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___241 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___431 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___241 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___220;

struct bio_list___220 {
	struct bio___220 *head;
	struct bio___220 *tail;
};

struct bdi_writeback_congested___220;

struct bdi_writeback___220 {
	struct backing_dev_info___220 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___220 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___279 *memcg_css;
	struct cgroup_subsys_state___279 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___398;

struct dentry___430;

struct backing_dev_info___220 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___220 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___398 *dev;
	struct device___398 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___430 *debug_dir;
	struct dentry___430 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___279 {
	struct cgroup_subsys_state___279 *subsys[13];
	refcount_t refcount;
	struct css_set___279 *dom_cset;
	struct cgroup___279 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___279 *mg_src_cgrp;
	struct cgroup___279 *mg_dst_cgrp;
	struct css_set___279 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___430;

struct pipe_buffer___111;

struct pipe_inode_info___111 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___431 *tmp_page;
	struct fasync_struct___430 *fasync_readers;
	struct fasync_struct___430 *fasync_writers;
	struct pipe_buffer___111 *bufs;
	struct user_struct___398 *user;
};

struct vm_struct___334 {
	struct vm_struct___334 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___431 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___317 {
	struct task_struct___432 task;
	long unsigned int stack[8192];
};

struct address_space_operations___430;

struct address_space___430 {
	struct inode___430 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___432 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___430 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___418)(struct vm_area_struct___431 *, long unsigned int, const struct page___431 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___418)(struct page___431 *, void *);

struct dev_pagemap___418 {
	dev_page_fault_t___418 page_fault;
	dev_page_free_t___418 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___398 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___431 {
	struct vfsmount *mnt;
	struct dentry___430 *dentry;
};

struct file___430 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___431 f_path;
	struct inode___430 *f_inode;
	const struct file_operations___430 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___241 f_owner;
	const struct cred___398 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___430 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___418;

struct vm_operations_struct___418 {
	void (*open)(struct vm_area_struct___431 *);
	void (*close)(struct vm_area_struct___431 *);
	int (*split)(struct vm_area_struct___431 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___431 *);
	vm_fault_t (*fault)(struct vm_fault___418 *);
	vm_fault_t (*huge_fault)(struct vm_fault___418 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___418 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___431 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___418 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___418 *);
	int (*access)(struct vm_area_struct___431 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___431 *);
	int (*set_policy)(struct vm_area_struct___431 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___431 *, long unsigned int);
	struct page___431 * (*find_special_page)(struct vm_area_struct___431 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___431 {
	struct task_struct___432 *task;
	struct core_thread___431 *next;
};

struct core_state___431 {
	atomic_t nr_threads;
	struct core_thread___431 dumper;
	struct completion startup;
};

struct vm_fault___418 {
	struct vm_area_struct___431 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___431 *cow_page;
	struct mem_cgroup___163 *memcg;
	struct page___431 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___431 prealloc_pte;
};

struct kset___417;

struct kobj_type___417;

struct kobject___418 {
	const char *name;
	struct list_head entry;
	struct kobject___418 *parent;
	struct kset___417 *kset;
	struct kobj_type___417 *ktype;
	struct kernfs_node___425 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___356 {
	struct kobject___418 kobj;
	struct module___358 *mod;
	struct kobject___418 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___356 {
	struct module___358 *mod;
	struct latch_tree_node node;
};

struct module_layout___356 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___356 mtn;
};

struct module_attribute___356;

struct kernel_param___356;

struct module___358 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___356 mkobj;
	struct module_attribute___356 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___418 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___356 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___356 core_layout;
	struct module_layout___356 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bio_vec___222 {
	struct page___431 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___197 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___222 *bvec;
		struct pipe_inode_info___111 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct msghdr___58 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___197 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___430 *msg_iocb;
};

struct kiocb___430 {
	struct file___430 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___430 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dentry_operations___430;

struct super_block___430;

struct dentry___430 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___430 *d_parent;
	struct qstr d_name;
	struct inode___430 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___430 *d_op;
	struct super_block___430 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___430;

struct block_device___430;

struct inode___430 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___430 *i_op;
	struct super_block___430 *i_sb;
	struct address_space___430 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___432 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___220 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___430 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___430 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___111 *i_pipe;
		struct block_device___430 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___430 {
	int (*d_revalidate)(struct dentry___430 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___430 *, unsigned int);
	int (*d_hash)(const struct dentry___430 *, struct qstr *);
	int (*d_compare)(const struct dentry___430 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___430 *);
	int (*d_init)(struct dentry___430 *);
	void (*d_release)(struct dentry___430 *);
	void (*d_prune)(struct dentry___430 *);
	void (*d_iput)(struct dentry___430 *, struct inode___430 *);
	char * (*d_dname)(struct dentry___430 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___431 *);
	int (*d_manage)(const struct path___431 *, bool);
	struct dentry___430 * (*d_real)(struct dentry___430 *, const struct inode___430 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___430;

struct mem_dqinfo___430 {
	struct quota_format_type___430 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___430;

struct quota_info___430 {
	unsigned int flags;
	struct rw_semaphore___432 dqio_sem;
	struct inode___430 *files[3];
	struct mem_dqinfo___430 info[3];
	const struct quota_format_ops___430 *ops[3];
};

struct rcuwait___430 {
	struct task_struct___432 *task;
};

struct percpu_rw_semaphore___430 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___432 rw_sem;
	struct rcuwait___430 writer;
	int readers_block;
};

struct sb_writers___430 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___430 rw_sem[3];
};

struct shrink_control___163;

struct shrinker___163 {
	long unsigned int (*count_objects)(struct shrinker___163 *, struct shrink_control___163 *);
	long unsigned int (*scan_objects)(struct shrinker___163 *, struct shrink_control___163 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___430;

struct super_operations___430;

struct dquot_operations___430;

struct quotactl_ops___430;

struct super_block___430 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___430 *s_type;
	const struct super_operations___430 *s_op;
	const struct dquot_operations___430 *dq_op;
	const struct quotactl_ops___430 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___430 *s_root;
	struct rw_semaphore___432 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___430 *s_bdev;
	struct backing_dev_info___220 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___430 s_dquot;
	struct sb_writers___430 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___430 *s_d_op;
	int cleancache_poolid;
	struct shrinker___163 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___295 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___163 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___163 *memcg;
};

struct iattr___430 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___430 *ia_file;
};

struct dquot___430 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___430 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___430 {
	int qf_fmt_id;
	const struct quota_format_ops___430 *qf_ops;
	struct module___358 *qf_owner;
	struct quota_format_type___430 *qf_next;
};

struct quota_format_ops___430 {
	int (*check_quota_file)(struct super_block___430 *, int);
	int (*read_file_info)(struct super_block___430 *, int);
	int (*write_file_info)(struct super_block___430 *, int);
	int (*free_file_info)(struct super_block___430 *, int);
	int (*read_dqblk)(struct dquot___430 *);
	int (*commit_dqblk)(struct dquot___430 *);
	int (*release_dqblk)(struct dquot___430 *);
	int (*get_next_id)(struct super_block___430 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___430 {
	int (*write_dquot)(struct dquot___430 *);
	struct dquot___430 * (*alloc_dquot)(struct super_block___430 *, int);
	void (*destroy_dquot)(struct dquot___430 *);
	int (*acquire_dquot)(struct dquot___430 *);
	int (*release_dquot)(struct dquot___430 *);
	int (*mark_dirty)(struct dquot___430 *);
	int (*write_info)(struct super_block___430 *, int);
	qsize_t * (*get_reserved_space)(struct inode___430 *);
	int (*get_projid)(struct inode___430 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___430 *, qsize_t *);
	int (*get_next_id)(struct super_block___430 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___430 {
	int (*quota_on)(struct super_block___430 *, int, int, const struct path___431 *);
	int (*quota_off)(struct super_block___430 *, int);
	int (*quota_enable)(struct super_block___430 *, unsigned int);
	int (*quota_disable)(struct super_block___430 *, unsigned int);
	int (*quota_sync)(struct super_block___430 *, int);
	int (*set_info)(struct super_block___430 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___430 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___430 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___430 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___430 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___430 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___183;

struct address_space_operations___430 {
	int (*writepage)(struct page___431 *, struct writeback_control___183 *);
	int (*readpage)(struct file___430 *, struct page___431 *);
	int (*writepages)(struct address_space___430 *, struct writeback_control___183 *);
	int (*set_page_dirty)(struct page___431 *);
	int (*readpages)(struct file___430 *, struct address_space___430 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___430 *, struct address_space___430 *, loff_t, unsigned int, unsigned int, struct page___431 **, void **);
	int (*write_end)(struct file___430 *, struct address_space___430 *, loff_t, unsigned int, unsigned int, struct page___431 *, void *);
	sector_t (*bmap)(struct address_space___430 *, sector_t);
	void (*invalidatepage)(struct page___431 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___431 *, gfp_t);
	void (*freepage)(struct page___431 *);
	ssize_t (*direct_IO)(struct kiocb___430 *, struct iov_iter___197 *);
	int (*migratepage)(struct address_space___430 *, struct page___431 *, struct page___431 *, enum migrate_mode);
	bool (*isolate_page)(struct page___431 *, isolate_mode_t);
	void (*putback_page)(struct page___431 *);
	int (*launder_page)(struct page___431 *);
	int (*is_partially_uptodate)(struct page___431 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___431 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___430 *, struct page___431 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___430 *, sector_t *);
	void (*swap_deactivate)(struct file___430 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___183 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___220 *wb;
	struct inode___430 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___430 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___430 *bd_inode;
	struct super_block___430 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___430 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___220 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___430 {
	struct dentry___430 * (*lookup)(struct inode___430 *, struct dentry___430 *, unsigned int);
	const char * (*get_link)(struct dentry___430 *, struct inode___430 *, struct delayed_call *);
	int (*permission)(struct inode___430 *, int);
	struct posix_acl * (*get_acl)(struct inode___430 *, int);
	int (*readlink)(struct dentry___430 *, char *, int);
	int (*create)(struct inode___430 *, struct dentry___430 *, umode_t, bool);
	int (*link)(struct dentry___430 *, struct inode___430 *, struct dentry___430 *);
	int (*unlink)(struct inode___430 *, struct dentry___430 *);
	int (*symlink)(struct inode___430 *, struct dentry___430 *, const char *);
	int (*mkdir)(struct inode___430 *, struct dentry___430 *, umode_t);
	int (*rmdir)(struct inode___430 *, struct dentry___430 *);
	int (*mknod)(struct inode___430 *, struct dentry___430 *, umode_t, dev_t);
	int (*rename)(struct inode___430 *, struct dentry___430 *, struct inode___430 *, struct dentry___430 *, unsigned int);
	int (*setattr)(struct dentry___430 *, struct iattr___430 *);
	int (*getattr)(const struct path___431 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___430 *, char *, size_t);
	int (*fiemap)(struct inode___430 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___430 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___430 *, struct dentry___430 *, struct file___430 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___430 *, struct dentry___430 *, umode_t);
	int (*set_acl)(struct inode___430 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___430 {
	void (*fl_copy_lock)(struct file_lock___430 *, struct file_lock___430 *);
	void (*fl_release_private)(struct file_lock___430 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___430;

struct file_lock___430 {
	struct file_lock___430 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___430 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___430 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___430 *fl_ops;
	const struct lock_manager_operations___430 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___430 {
	int (*lm_compare_owner)(struct file_lock___430 *, struct file_lock___430 *);
	long unsigned int (*lm_owner_key)(struct file_lock___430 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___430 *);
	int (*lm_grant)(struct file_lock___430 *, int);
	bool (*lm_break)(struct file_lock___430 *);
	int (*lm_change)(struct file_lock___430 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___430 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___430 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___430 *fa_next;
	struct file___430 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___430 {
	const char *name;
	int fs_flags;
	struct dentry___430 * (*mount)(struct file_system_type___430 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___430 *);
	struct module___358 *owner;
	struct file_system_type___430 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___430 {
	struct inode___430 * (*alloc_inode)(struct super_block___430 *);
	void (*destroy_inode)(struct inode___430 *);
	void (*dirty_inode)(struct inode___430 *, int);
	int (*write_inode)(struct inode___430 *, struct writeback_control___183 *);
	int (*drop_inode)(struct inode___430 *);
	void (*evict_inode)(struct inode___430 *);
	void (*put_super)(struct super_block___430 *);
	int (*sync_fs)(struct super_block___430 *, int);
	int (*freeze_super)(struct super_block___430 *);
	int (*freeze_fs)(struct super_block___430 *);
	int (*thaw_super)(struct super_block___430 *);
	int (*unfreeze_fs)(struct super_block___430 *);
	int (*statfs)(struct dentry___430 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___430 *, int *, char *);
	void (*umount_begin)(struct super_block___430 *);
	int (*show_options)(struct seq_file___369 *, struct dentry___430 *);
	int (*show_devname)(struct seq_file___369 *, struct dentry___430 *);
	int (*show_path)(struct seq_file___369 *, struct dentry___430 *);
	int (*show_stats)(struct seq_file___369 *, struct dentry___430 *);
	ssize_t (*quota_read)(struct super_block___430 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___430 *, int, const char *, size_t, loff_t);
	struct dquot___430 ** (*get_dquots)(struct inode___430 *);
	int (*bdev_try_to_free_page)(struct super_block___430 *, struct page___431 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___430 *, struct shrink_control___163 *);
	long int (*free_cached_objects)(struct super_block___430 *, struct shrink_control___163 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___279)(struct file___430 *, wait_queue_head_t *, struct poll_table_struct___269 *);

struct poll_table_struct___269 {
	poll_queue_proc___279 _qproc;
	__poll_t _key;
};

struct seq_operations___369;

struct seq_file___369 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___369 *op;
	int poll_event;
	const struct file___430 *file;
	void *private;
};

typedef void bio_end_io_t___220(struct bio___220 *);

struct bio_integrity_payload___220;

struct bio_set___220;

struct bio___220 {
	struct bio___220 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___220 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___220 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___222 *bi_io_vec;
	struct bio_set___220 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___222 bi_inline_vecs[0];
};

struct socket_wq___56 {
	wait_queue_head_t wait;
	struct fasync_struct___430 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct sock___56;

struct proto_ops___56;

struct socket___57 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___56 *wq;
	struct file___430 *file;
	struct sock___56 *sk;
	const struct proto_ops___56 *ops;
};

typedef struct {
	struct net___87 *net;
} possible_net_t___77;

struct proto___55;

struct sock_common___55 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___55 *skc_prot;
	possible_net_t___77 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___56 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___77;

struct sk_buff_head___75 {
	struct sk_buff___77 *next;
	struct sk_buff___77 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___55;

struct dst_entry___55;

struct net_device___76;

struct sock___56 {
	struct sock_common___55 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___75 sk_error_queue;
	struct sk_buff_head___75 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___77 *head;
		struct sk_buff___77 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___55 *sk_filter;
	union {
		struct socket_wq___56 *sk_wq;
		struct socket_wq___56 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___55 *sk_rx_dst;
	struct dst_entry___55 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___77 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___75 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___431 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___55 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___241 *sk_peer_pid;
	const struct cred___398 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___57 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___163 *sk_memcg;
	void (*sk_state_change)(struct sock___56 *);
	void (*sk_data_ready)(struct sock___56 *);
	void (*sk_write_space)(struct sock___56 *);
	void (*sk_error_report)(struct sock___56 *);
	int (*sk_backlog_rcv)(struct sock___56 *, struct sk_buff___77 *);
	struct sk_buff___77 * (*sk_validate_xmit_skb)(struct sock___56 *, struct net_device___76 *, struct sk_buff___77 *);
	void (*sk_destruct)(struct sock___56 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

typedef int (*sk_read_actor_t___55)(read_descriptor_t *, struct sk_buff___77 *, unsigned int, size_t);

struct proto_ops___56 {
	int family;
	struct module___358 *owner;
	int (*release)(struct socket___57 *);
	int (*bind)(struct socket___57 *, struct sockaddr *, int);
	int (*connect)(struct socket___57 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___57 *, struct socket___57 *);
	int (*accept)(struct socket___57 *, struct socket___57 *, int, bool);
	int (*getname)(struct socket___57 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___430 *, struct socket___57 *, struct poll_table_struct___269 *);
	int (*ioctl)(struct socket___57 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___57 *, int);
	int (*shutdown)(struct socket___57 *, int);
	int (*setsockopt)(struct socket___57 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___57 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___57 *, struct msghdr___58 *, size_t);
	int (*recvmsg)(struct socket___57 *, struct msghdr___58 *, size_t, int);
	int (*mmap)(struct file___430 *, struct socket___57 *, struct vm_area_struct___431 *);
	ssize_t (*sendpage)(struct socket___57 *, struct page___431 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___57 *, loff_t *, struct pipe_inode_info___111 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___56 *, int);
	int (*peek_len)(struct socket___57 *);
	int (*read_sock)(struct sock___56 *, read_descriptor_t *, sk_read_actor_t___55);
	int (*sendpage_locked)(struct sock___56 *, struct page___431 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___56 *, struct msghdr___58 *, size_t);
	int (*set_rcvlowat)(struct sock___56 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct nf_bridge_info___75;

struct sk_buff___77 {
	union {
		struct {
			struct sk_buff___77 *next;
			struct sk_buff___77 *prev;
			union {
				struct net_device___76 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___56 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___77 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___75 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___75;

struct netns_frags___75 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___75 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_rules_ops___55;

struct fib_notifier_ops___56;

struct netns_ipv4___75 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___55 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___56 *fibnl;
	struct sock___56 **icmp_sk;
	struct sock___56 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___56 **tcp_sk;
	struct netns_frags___75 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___55 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___56 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___56 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___55;

struct dst_ops___86 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___86 *);
	struct dst_entry___55 * (*check)(struct dst_entry___55 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___55 *);
	unsigned int (*mtu)(const struct dst_entry___55 *);
	u32 * (*cow_metrics)(struct dst_entry___55 *, long unsigned int);
	void (*destroy)(struct dst_entry___55 *);
	void (*ifdown)(struct dst_entry___55 *, struct net_device___76 *, int);
	struct dst_entry___55 * (*negative_advice)(struct dst_entry___55 *);
	void (*link_failure)(struct sk_buff___77 *);
	void (*update_pmtu)(struct dst_entry___55 *, struct sock___56 *, struct sk_buff___77 *, u32);
	void (*redirect)(struct dst_entry___55 *, struct sock___56 *, struct sk_buff___77 *);
	int (*local_out)(struct net___87 *, struct sock___56 *, struct sk_buff___77 *);
	struct neighbour___55 * (*neigh_lookup)(const struct dst_entry___55 *, struct sk_buff___77 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___55 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___86 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___75 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___86 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___55 *fib6_rules_ops;
	struct sock___56 **icmp_sk;
	struct sock___56 *ndisc_sk;
	struct sock___56 *tcp_sk;
	struct sock___56 *igmp_sk;
	struct sock___56 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___55 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___56 *notifier_ops;
	struct fib_notifier_ops___56 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___56 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___56 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___75 {
	struct netns_frags___75 frags;
};

struct netns_xfrm___86 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___56 *nlsk;
	struct sock___56 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___86 xfrm4_dst_ops;
	struct dst_ops___86 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___65;

struct net___87 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___295 *user_ns;
	struct ucounts___295 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___29 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___56 *rtnl;
	struct sock___56 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___76 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___75 ipv4;
	struct netns_ipv6___86 ipv6;
	struct netns_sctp___56 sctp;
	struct netns_nf___4 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___75 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___56 *nfnl;
	struct sock___56 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___86 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___56 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___65 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kernfs_root___424;

struct kernfs_elem_dir___424 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___424 *root;
};

struct kernfs_syscall_ops___424;

struct kernfs_root___424 {
	struct kernfs_node___425 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___424 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___424 {
	struct kernfs_node___425 *target_kn;
};

struct kernfs_ops___424;

struct kernfs_elem_attr___424 {
	const struct kernfs_ops___424 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___425 *notify_next;
};

struct kernfs_node___425 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___425 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___424 dir;
		struct kernfs_elem_symlink___424 symlink;
		struct kernfs_elem_attr___424 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___424;

struct kernfs_ops___424 {
	int (*open)(struct kernfs_open_file___424 *);
	void (*release)(struct kernfs_open_file___424 *);
	int (*seq_show)(struct seq_file___369 *, void *);
	void * (*seq_start)(struct seq_file___369 *, loff_t *);
	void * (*seq_next)(struct seq_file___369 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___369 *, void *);
	ssize_t (*read)(struct kernfs_open_file___424 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___424 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___424 *, struct vm_area_struct___431 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___424 *, struct poll_table_struct___269 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___424 {
	int (*remount_fs)(struct kernfs_root___424 *, int *, char *);
	int (*show_options)(struct seq_file___369 *, struct kernfs_root___424 *);
	int (*mkdir)(struct kernfs_node___425 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___425 *);
	int (*rename)(struct kernfs_node___425 *, struct kernfs_node___425 *, const char *);
	int (*show_path)(struct seq_file___369 *, struct kernfs_node___425 *, struct kernfs_root___424 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___424 {
	struct kernfs_node___425 *kn;
	struct file___430 *file;
	struct seq_file___369 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___418 *vm_ops;
};

struct kobj_ns_type_operations___55 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___56 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___394;

struct attribute_group___395 {
	const char *name;
	umode_t (*is_visible)(struct kobject___418 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___418 *, struct bin_attribute___394 *, int);
	struct attribute **attrs;
	struct bin_attribute___394 **bin_attrs;
};

struct bin_attribute___394 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___430 *, struct kobject___418 *, struct bin_attribute___394 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___430 *, struct kobject___418 *, struct bin_attribute___394 *, char *, loff_t, size_t);
	int (*mmap)(struct file___430 *, struct kobject___418 *, struct bin_attribute___394 *, struct vm_area_struct___431 *);
};

struct sysfs_ops___417 {
	ssize_t (*show)(struct kobject___418 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___418 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___417;

struct kset___417 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___418 kobj;
	const struct kset_uevent_ops___417 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___417 {
	void (*release)(struct kobject___418 *);
	const struct sysfs_ops___417 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___55 * (*child_ns_type)(struct kobject___418 *);
	const void * (*namespace)(struct kobject___418 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___417 {
	int (* const filter)(struct kset___417 *, struct kobject___418 *);
	const char * (* const name)(struct kset___417 *, struct kobject___418 *);
	int (* const uevent)(struct kset___417 *, struct kobject___418 *, struct kobj_uevent_env *);
};

struct kobj_attribute___408 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___418 *, struct kobj_attribute___408 *, char *);
	ssize_t (*store)(struct kobject___418 *, struct kobj_attribute___408 *, const char *, size_t);
};

struct dev_pm_ops___398 {
	int (*prepare)(struct device___398 *);
	void (*complete)(struct device___398 *);
	int (*suspend)(struct device___398 *);
	int (*resume)(struct device___398 *);
	int (*freeze)(struct device___398 *);
	int (*thaw)(struct device___398 *);
	int (*poweroff)(struct device___398 *);
	int (*restore)(struct device___398 *);
	int (*suspend_late)(struct device___398 *);
	int (*resume_early)(struct device___398 *);
	int (*freeze_late)(struct device___398 *);
	int (*thaw_early)(struct device___398 *);
	int (*poweroff_late)(struct device___398 *);
	int (*restore_early)(struct device___398 *);
	int (*suspend_noirq)(struct device___398 *);
	int (*resume_noirq)(struct device___398 *);
	int (*freeze_noirq)(struct device___398 *);
	int (*thaw_noirq)(struct device___398 *);
	int (*poweroff_noirq)(struct device___398 *);
	int (*restore_noirq)(struct device___398 *);
	int (*runtime_suspend)(struct device___398 *);
	int (*runtime_resume)(struct device___398 *);
	int (*runtime_idle)(struct device___398 *);
};

struct dev_pm_info___398 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___398 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___398;

struct bus_type___398;

struct device_driver___398;

struct dev_pm_domain___398;

struct dma_map_ops___170;

struct fwnode_handle___318;

struct class___398;

struct device___398 {
	struct device___398 *parent;
	struct device_private *p;
	struct kobject___418 kobj;
	const char *init_name;
	const struct device_type___398 *type;
	struct mutex mutex;
	struct bus_type___398 *bus;
	struct device_driver___398 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___398 power;
	struct dev_pm_domain___398 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___170 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___318 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___398 *class;
	const struct attribute_group___395 **groups;
	void (*release)(struct device___398 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___398 {
	struct dev_pm_ops___398 ops;
	void (*detach)(struct device___398 *, bool);
	int (*activate)(struct device___398 *);
	void (*sync)(struct device___398 *);
	void (*dismiss)(struct device___398 *);
};

struct bus_type___398 {
	const char *name;
	const char *dev_name;
	struct device___398 *dev_root;
	const struct attribute_group___395 **bus_groups;
	const struct attribute_group___395 **dev_groups;
	const struct attribute_group___395 **drv_groups;
	int (*match)(struct device___398 *, struct device_driver___398 *);
	int (*uevent)(struct device___398 *, struct kobj_uevent_env *);
	int (*probe)(struct device___398 *);
	int (*remove)(struct device___398 *);
	void (*shutdown)(struct device___398 *);
	int (*online)(struct device___398 *);
	int (*offline)(struct device___398 *);
	int (*suspend)(struct device___398 *, pm_message_t);
	int (*resume)(struct device___398 *);
	int (*num_vf)(struct device___398 *);
	int (*dma_configure)(struct device___398 *);
	const struct dev_pm_ops___398 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___398 {
	const char *name;
	struct bus_type___398 *bus;
	struct module___358 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___398 *);
	int (*remove)(struct device___398 *);
	void (*shutdown)(struct device___398 *);
	int (*suspend)(struct device___398 *, pm_message_t);
	int (*resume)(struct device___398 *);
	const struct attribute_group___395 **groups;
	const struct dev_pm_ops___398 *pm;
	void (*coredump)(struct device___398 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___398 {
	const char *name;
	const struct attribute_group___395 **groups;
	int (*uevent)(struct device___398 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___398 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___398 *);
	const struct dev_pm_ops___398 *pm;
};

struct class___398 {
	const char *name;
	struct module___358 *owner;
	const struct attribute_group___395 **class_groups;
	const struct attribute_group___395 **dev_groups;
	struct kobject___418 *dev_kobj;
	int (*dev_uevent)(struct device___398 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___398 *, umode_t *);
	void (*class_release)(struct class___398 *);
	void (*dev_release)(struct device___398 *);
	int (*shutdown_pre)(struct device___398 *);
	const struct kobj_ns_type_operations___55 *ns_type;
	const void * (*namespace)(struct device___398 *);
	const struct dev_pm_ops___398 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___170 {
	void * (*alloc)(struct device___398 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___398 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___398 *, struct vm_area_struct___431 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___398 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___398 *, struct page___431 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___398 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___398 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___398 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___398 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___398 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___398 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___398 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___398 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___398 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___398 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___398 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___398 *, u64);
	u64 (*get_required_mask)(struct device___398 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___318;

struct fwnode_handle___318 {
	struct fwnode_handle___318 *secondary;
	const struct fwnode_operations___318 *ops;
};

typedef void compound_page_dtor___418(struct page___431 *);

struct fwnode_reference_args___318;

struct fwnode_endpoint___318;

struct fwnode_operations___318 {
	struct fwnode_handle___318 * (*get)(struct fwnode_handle___318 *);
	void (*put)(struct fwnode_handle___318 *);
	bool (*device_is_available)(const struct fwnode_handle___318 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___318 *, const struct device___398 *);
	bool (*property_present)(const struct fwnode_handle___318 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___318 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___318 *, const char *, const char **, size_t);
	struct fwnode_handle___318 * (*get_parent)(const struct fwnode_handle___318 *);
	struct fwnode_handle___318 * (*get_next_child_node)(const struct fwnode_handle___318 *, struct fwnode_handle___318 *);
	struct fwnode_handle___318 * (*get_named_child_node)(const struct fwnode_handle___318 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___318 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___318 *);
	struct fwnode_handle___318 * (*graph_get_next_endpoint)(const struct fwnode_handle___318 *, struct fwnode_handle___318 *);
	struct fwnode_handle___318 * (*graph_get_remote_endpoint)(const struct fwnode_handle___318 *);
	struct fwnode_handle___318 * (*graph_get_port_parent)(struct fwnode_handle___318 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___318 *, struct fwnode_endpoint___318 *);
};

struct fwnode_endpoint___318 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___318 *local_fwnode;
};

struct fwnode_reference_args___318 {
	struct fwnode_handle___318 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___111;

struct pipe_buffer___111 {
	struct page___431 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___111 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___111 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___111 *, struct pipe_buffer___111 *);
	void (*release)(struct pipe_inode_info___111 *, struct pipe_buffer___111 *);
	int (*steal)(struct pipe_inode_info___111 *, struct pipe_buffer___111 *);
	union {
		bool (*get)(struct pipe_inode_info___111 *, struct pipe_buffer___111 *);
		struct {
			void (*get)(struct pipe_inode_info___111 *, struct pipe_buffer___111 *);
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
};

struct nf_bridge_info___75 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___75 = 0,
		BRNF_PROTO_8021Q___75 = 1,
		BRNF_PROTO_PPPOE___75 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___76 *physindev;
	struct net_device___76 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___75(struct sk_buff___77 **);

struct net_device_ops___75;

struct ethtool_ops___75;

struct l3mdev_ops___55;

struct xfrmdev_ops___75;

struct tlsdev_ops___75;

struct header_ops___75;

struct netdev_rx_queue___75;

struct mini_Qdisc___67;

struct netdev_queue___75;

struct Qdisc___67;

struct rtnl_link_ops___67;

struct dcbnl_rtnl_ops___75;

struct net_device___76 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___75 *netdev_ops;
	const struct ethtool_ops___75 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___55 *l3mdev_ops;
	const struct ndisc_ops___2 *ndisc_ops;
	const struct xfrmdev_ops___75 *xfrmdev_ops;
	const struct tlsdev_ops___75 *tlsdev_ops;
	const struct header_ops___75 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___417 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___2 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___75 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___65 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___75 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___67 *miniq_ingress;
	struct netdev_queue___75 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___75 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___67 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___67 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___75 = 0,
		NETREG_REGISTERED___75 = 1,
		NETREG_UNREGISTERING___75 = 2,
		NETREG_UNREGISTERED___75 = 3,
		NETREG_RELEASED___75 = 4,
		NETREG_DUMMY___75 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___75 = 0,
		RTNL_LINK_INITIALIZING___75 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___76 *);
	struct netpoll_info *npinfo;
	possible_net_t___77 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___398 dev;
	const struct attribute_group___395 *sysfs_groups[4];
	const struct attribute_group___395 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___67 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___75 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide35;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct kernel_param_ops___356 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___356 *);
	int (*get)(char *, const struct kernel_param___356 *);
	void (*free)(void *);
};

struct kparam_array___356;

struct kernel_param___356 {
	const char *name;
	struct module___358 *mod;
	const struct kernel_param_ops___356 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___356 *arr;
	};
};

struct kparam_array___356 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___356 *ops;
	void *elem;
};

struct module_attribute___356 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___356 *, struct module_kobject___356 *, char *);
	ssize_t (*store)(struct module_attribute___356 *, struct module_kobject___356 *, const char *, size_t);
	void (*setup)(struct module___358 *, const char *);
	int (*test)(struct module___358 *);
	void (*free)(struct module___358 *);
};

struct inet_frag_queue___75;

struct inet_frags___75 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___75 *, const void *);
	void (*destructor)(struct inet_frag_queue___75 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___75 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___77 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___77 *fragments_tail;
	struct sk_buff___77 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___75 *net;
	struct callback_head rcu;
};

struct fib_rule___55;

struct fib_lookup_arg___55;

struct fib_rules_ops___55 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___55 *, struct flowi *, int, struct fib_lookup_arg___55 *);
	bool (*suppress)(struct fib_rule___55 *, struct fib_lookup_arg___55 *);
	int (*match)(struct fib_rule___55 *, struct flowi *, int);
	int (*configure)(struct fib_rule___55 *, struct sk_buff___77 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___55 *);
	int (*compare)(struct fib_rule___55 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___55 *, struct sk_buff___77 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___55 *);
	void (*flush_cache)(struct fib_rules_ops___55 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___358 *owner;
	struct net___87 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___56 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___87 *);
	int (*fib_dump)(struct net___87 *, struct notifier_block *);
	struct module___358 *owner;
	struct callback_head rcu;
};

struct dst_entry___55 {
	struct net_device___76 *dev;
	struct dst_ops___86 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___77 *);
	int (*output)(struct net___87 *, struct sock___56 *, struct sk_buff___77 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___55;

struct neigh_parms___55;

struct neigh_ops___55;

struct neighbour___55 {
	struct neighbour___55 *next;
	struct neigh_table___55 *tbl;
	struct neigh_parms___55 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___75 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___55 *, struct sk_buff___77 *);
	const struct neigh_ops___55 *ops;
	struct callback_head rcu;
	struct net_device___76 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct ucounts___295 {
	struct hlist_node node;
	struct user_namespace___295 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_prog_aux___68;

struct bpf_prog___65 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___68 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

typedef int (*key_restrict_link_func_t___399)(struct key___398 *, const struct key_type *, const union key_payload *, struct key___398 *);

struct key_restriction___398;

struct key___398 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___432 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___398 *restrict_link;
};

struct key_restriction___398 {
	key_restrict_link_func_t___399 check;
	struct key___398 *key;
	struct key_type *keytype;
};

struct seq_operations___369 {
	void * (*start)(struct seq_file___369 *, loff_t *);
	void (*stop)(struct seq_file___369 *, void *);
	void * (*next)(struct seq_file___369 *, void *, loff_t *);
	int (*show)(struct seq_file___369 *, void *);
};

struct pernet_operations___76 {
	struct list_head list;
	int (*init)(struct net___87 *);
	void (*exit)(struct net___87 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct ethtool_ops___75 {
	int (*get_settings)(struct net_device___76 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___76 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___76 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___76 *);
	void (*get_regs)(struct net_device___76 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___76 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___76 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___76 *);
	void (*set_msglevel)(struct net_device___76 *, u32);
	int (*nway_reset)(struct net_device___76 *);
	u32 (*get_link)(struct net_device___76 *);
	int (*get_eeprom_len)(struct net_device___76 *);
	int (*get_eeprom)(struct net_device___76 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___76 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___76 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___76 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___76 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___76 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___76 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___76 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___76 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___76 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___76 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___76 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___76 *);
	void (*complete)(struct net_device___76 *);
	u32 (*get_priv_flags)(struct net_device___76 *);
	int (*set_priv_flags)(struct net_device___76 *, u32);
	int (*get_sset_count)(struct net_device___76 *, int);
	int (*get_rxnfc)(struct net_device___76 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___76 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___76 *, struct ethtool_flash *);
	int (*reset)(struct net_device___76 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___76 *);
	u32 (*get_rxfh_indir_size)(struct net_device___76 *);
	int (*get_rxfh)(struct net_device___76 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___76 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___76 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___76 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___76 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___76 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___76 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___76 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___76 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___76 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___76 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___76 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___76 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___76 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___76 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___76 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___76 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___76 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___76 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___76 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___76 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___76 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	int (*get_fecparam)(struct net_device___76 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___76 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___76 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___76 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___76 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct dcbnl_rtnl_ops___75 {
	int (*ieee_getets)(struct net_device___76 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___76 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___76 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___76 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___76 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___76 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___76 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___76 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___76 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___76 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___76 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___76 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___76 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___76 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___76 *);
	u8 (*setstate)(struct net_device___76 *, u8);
	void (*getpermhwaddr)(struct net_device___76 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___76 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___76 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___76 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___76 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___76 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___76 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___76 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___76 *, int, u8 *);
	void (*setpfccfg)(struct net_device___76 *, int, u8);
	void (*getpfccfg)(struct net_device___76 *, int, u8 *);
	u8 (*setall)(struct net_device___76 *);
	u8 (*getcap)(struct net_device___76 *, int, u8 *);
	int (*getnumtcs)(struct net_device___76 *, int, u8 *);
	int (*setnumtcs)(struct net_device___76 *, int, u8);
	u8 (*getpfcstate)(struct net_device___76 *);
	void (*setpfcstate)(struct net_device___76 *, u8);
	void (*getbcncfg)(struct net_device___76 *, int, u32 *);
	void (*setbcncfg)(struct net_device___76 *, int, u32);
	void (*getbcnrp)(struct net_device___76 *, int, u8 *);
	void (*setbcnrp)(struct net_device___76 *, int, u8);
	int (*setapp)(struct net_device___76 *, u8, u16, u8);
	int (*getapp)(struct net_device___76 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___76 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___76 *, int, u8);
	u8 (*getdcbx)(struct net_device___76 *);
	u8 (*setdcbx)(struct net_device___76 *, u8);
	int (*peer_getappinfo)(struct net_device___76 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___76 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___76 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___76 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___76 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___76 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___279 {
	refcount_t count;
	struct ns_common___29 ns;
	struct user_namespace___295 *user_ns;
	struct ucounts___295 *ucounts;
	struct css_set___279 *root_cset;
};

struct bpf_map___280;

struct bpf_map_ops___279 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___280 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___280 *, struct file___430 *);
	void (*map_free)(struct bpf_map___280 *);
	int (*map_get_next_key)(struct bpf_map___280 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___280 *);
	void * (*map_lookup_elem)(struct bpf_map___280 *, void *);
	int (*map_update_elem)(struct bpf_map___280 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___280 *, void *);
	int (*map_push_elem)(struct bpf_map___280 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___280 *, void *);
	int (*map_peek_elem)(struct bpf_map___280 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___280 *, struct file___430 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___280 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___280 *, void *, struct seq_file___369 *);
	int (*map_check_btf)(const struct bpf_map___280 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___280 {
	const struct bpf_map_ops___279 *ops;
	struct bpf_map___280 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___398 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___75;

struct bpf_map_dev_ops___75 {
	int (*map_get_next_key)(struct bpf_offloaded_map___75 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___75 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___75 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___75 *, void *);
};

struct bpf_offloaded_map___75 {
	struct bpf_map___280 map;
	struct net_device___76 *netdev;
	const struct bpf_map_dev_ops___75 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___65 {
	int (*test_run)(struct bpf_prog___65 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___65 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___65 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___65 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___65 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___65 *, u32 *);
};

struct bpf_prog_offload_ops___65 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___65 *);
	int (*translate)(struct bpf_prog___65 *);
	void (*destroy)(struct bpf_prog___65 *);
};

struct bpf_prog_offload___65 {
	struct bpf_prog___65 *prog;
	struct net_device___76 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___65 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___68 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___65 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___65 *ops;
	struct bpf_map___280 **used_maps;
	struct bpf_prog___65 *prog;
	struct user_struct___398 *user;
	u64 load_time;
	struct bpf_map___280 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___65 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___65 {
	struct bpf_prog___65 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___65 {
	struct callback_head rcu;
	struct bpf_prog_array_item___65 items[0];
};

struct cgroup_bpf___65 {
	struct bpf_prog_array___65 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___65 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___280;

typedef void (*kthread_work_func_t___280)(struct kthread_work___280 *);

struct kthread_worker___280;

struct kthread_work___280 {
	struct list_head node;
	kthread_work_func_t___280 func;
	struct kthread_worker___280 *worker;
	int canceling;
};

struct kthread_worker___280 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___432 *task;
	struct kthread_work___280 *current_work;
};

struct kthread_delayed_work___279 {
	struct kthread_work___280 work;
	struct timer_list timer;
};

struct psi_group___279 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___280 *poll_kworker;
	struct kthread_delayed_work___279 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___279;

struct cgroup_rstat_cpu___279;

struct cgroup___279 {
	struct cgroup_subsys_state___279 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___425 *kn;
	struct cgroup_file___279 procs_file;
	struct cgroup_file___279 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___279 *subsys[13];
	struct cgroup_root___279 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___279 *dom_cgrp;
	struct cgroup_rstat_cpu___279 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___65 bpf;
	atomic_t congestion_count;
	struct cgroup___279 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___279 psi;
	int ancestor_ids[0];
};

struct cftype___279;

struct cgroup_subsys___279 {
	struct cgroup_subsys_state___279 * (*css_alloc)(struct cgroup_subsys_state___279 *);
	int (*css_online)(struct cgroup_subsys_state___279 *);
	void (*css_offline)(struct cgroup_subsys_state___279 *);
	void (*css_released)(struct cgroup_subsys_state___279 *);
	void (*css_free)(struct cgroup_subsys_state___279 *);
	void (*css_reset)(struct cgroup_subsys_state___279 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___279 *, int);
	int (*css_extra_stat_show)(struct seq_file___369 *, struct cgroup_subsys_state___279 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___432 *);
	void (*cancel_fork)(struct task_struct___432 *);
	void (*fork)(struct task_struct___432 *);
	void (*exit)(struct task_struct___432 *);
	void (*free)(struct task_struct___432 *);
	void (*bind)(struct cgroup_subsys_state___279 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___279 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___279 *dfl_cftypes;
	struct cftype___279 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___279 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___279 *updated_children;
	struct cgroup___279 *updated_next;
};

struct cgroup_root___279 {
	struct kernfs_root___424 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___279 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___279 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___279 *ss;
	struct list_head node;
	struct kernfs_ops___424 *kf_ops;
	int (*open)(struct kernfs_open_file___424 *);
	void (*release)(struct kernfs_open_file___424 *);
	u64 (*read_u64)(struct cgroup_subsys_state___279 *, struct cftype___279 *);
	s64 (*read_s64)(struct cgroup_subsys_state___279 *, struct cftype___279 *);
	int (*seq_show)(struct seq_file___369 *, void *);
	void * (*seq_start)(struct seq_file___369 *, loff_t *);
	void * (*seq_next)(struct seq_file___369 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___369 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___279 *, struct cftype___279 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___279 *, struct cftype___279 *, s64);
	ssize_t (*write)(struct kernfs_open_file___424 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___424 *, struct poll_table_struct___269 *);
};

struct xdp_rxq_info___75 {
	struct net_device___76 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___75 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___76 *dev_rx;
};

struct netlink_skb_parms___13 {
	struct scm_creds creds;
	__u32 portid;
	__u32 dst_group;
	__u32 flags;
	struct sock___56 *sk;
	bool nsid_is_set;
	int nsid;
};

struct netlink_callback___77 {
	struct sk_buff___77 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___77 *);
	int (*dump)(struct sk_buff___77 *, struct netlink_callback___77 *);
	int (*done)(struct netlink_callback___77 *);
	void *data;
	struct module___358 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___75 {
	int (*create)(struct sk_buff___77 *, struct net_device___76 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___77 *, unsigned char *);
	int (*cache)(const struct neighbour___55 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___76 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___75 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___75 *, int);
	int poll_owner;
	struct net_device___76 *dev;
	struct sk_buff___77 *gro_list;
	struct sk_buff___77 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___75 {
	struct net_device___76 *dev;
	struct Qdisc___67 *qdisc;
	struct Qdisc___67 *qdisc_sleeping;
	struct kobject___418 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___76 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem___3 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___67 {
	struct sk_buff___77 *head;
	struct sk_buff___77 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___67;

struct Qdisc___67 {
	int (*enqueue)(struct sk_buff___77 *, struct Qdisc___67 *, struct sk_buff___77 **);
	struct sk_buff___77 * (*dequeue)(struct Qdisc___67 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___67 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___75 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___75 gso_skb;
	struct qdisc_skb_head___67 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___67 *next_sched;
	struct sk_buff_head___75 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___75 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___418 kobj;
	struct net_device___76 *dev;
	long: 64;
	struct xdp_rxq_info___75 xdp_rxq;
	union {
		struct xdp_umem___3 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___75)(struct net_device___76 *, struct sk_buff___77 *, struct net_device___76 *);

struct netdev_bpf___75 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___65 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___65 *prog;
			const struct bpf_prog_offload_ops___65 *ops;
		} verifier;
		struct {
			struct bpf_prog___65 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___75 *offmap;
		};
		struct {
			struct xdp_umem___3 *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___75 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___77 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___75 {
	int (*tls_dev_add)(struct net_device___76 *, struct sock___56 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___76 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___76 *, struct sock___56 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___75 {
	int (*ndo_init)(struct net_device___76 *);
	void (*ndo_uninit)(struct net_device___76 *);
	int (*ndo_open)(struct net_device___76 *);
	int (*ndo_stop)(struct net_device___76 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___77 *, struct net_device___76 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___77 *, struct net_device___76 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___76 *, struct sk_buff___77 *, struct net_device___76 *, select_queue_fallback_t___75);
	void (*ndo_change_rx_flags)(struct net_device___76 *, int);
	void (*ndo_set_rx_mode)(struct net_device___76 *);
	int (*ndo_set_mac_address)(struct net_device___76 *, void *);
	int (*ndo_validate_addr)(struct net_device___76 *);
	int (*ndo_do_ioctl)(struct net_device___76 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___76 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___76 *, int);
	int (*ndo_neigh_setup)(struct net_device___76 *, struct neigh_parms___55 *);
	void (*ndo_tx_timeout)(struct net_device___76 *);
	void (*ndo_get_stats64)(struct net_device___76 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___76 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___76 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___76 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___76 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___76 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___76 *);
	int (*ndo_netpoll_setup)(struct net_device___76 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___76 *);
	int (*ndo_set_vf_mac)(struct net_device___76 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___76 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___76 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___76 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___76 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___76 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___76 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___76 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___76 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___76 *, int, struct sk_buff___77 *);
	int (*ndo_set_vf_guid)(struct net_device___76 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___76 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___76 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___76 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___76 *, const struct sk_buff___77 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___76 *, struct net_device___76 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___76 *, struct net_device___76 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___76 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___76 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___76 *, struct neighbour___55 *);
	void (*ndo_neigh_destroy)(struct net_device___76 *, struct neighbour___55 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___76 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___76 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___76 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___77 *, struct netlink_callback___77 *, struct net_device___76 *, struct net_device___76 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___76 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___76 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___77 *, u32, u32, struct net_device___76 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___76 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___76 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___76 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___76 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___76 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___76 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___76 *, struct net_device___76 *);
	void (*ndo_dfwd_del_station)(struct net_device___76 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___76 *);
	int (*ndo_set_tx_maxrate)(struct net_device___76 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___76 *);
	int (*ndo_change_proto_down)(struct net_device___76 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___76 *, struct sk_buff___77 *);
	void (*ndo_set_rx_headroom)(struct net_device___76 *, int);
	int (*ndo_bpf)(struct net_device___76 *, struct netdev_bpf___75 *);
	int (*ndo_xdp_xmit)(struct net_device___76 *, int, struct xdp_frame___75 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___76 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___76 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___55 {
	possible_net_t___77 net;
	struct net_device___76 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___55 *);
	void (*neigh_cleanup)(struct neighbour___55 *);
	struct neigh_table___55 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___55 {
	u32 (*l3mdev_fib_table)(const struct net_device___76 *);
	struct sk_buff___77 * (*l3mdev_l3_rcv)(struct net_device___76 *, struct sk_buff___77 *, u16);
	struct sk_buff___77 * (*l3mdev_l3_out)(struct net_device___76 *, struct sock___56 *, struct sk_buff___77 *, u16);
	struct dst_entry___55 * (*l3mdev_link_scope_lookup)(const struct net_device___76 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct tcf_proto___67;

struct mini_Qdisc___67 {
	struct tcf_proto___67 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___67 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___76 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___87 *, struct net_device___76 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___76 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___76 *, struct list_head *);
	size_t (*get_size)(const struct net_device___76 *);
	int (*fill_info)(struct sk_buff___77 *, const struct net_device___76 *);
	size_t (*get_xstats_size)(const struct net_device___76 *);
	int (*fill_xstats)(struct sk_buff___77 *, const struct net_device___76 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___76 *, struct net_device___76 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___76 *, const struct net_device___76 *);
	int (*fill_slave_info)(struct sk_buff___77 *, const struct net_device___76 *, const struct net_device___76 *);
	struct net___87 * (*get_link_net)(const struct net_device___76 *);
	size_t (*get_linkxstats_size)(const struct net_device___76 *, int);
	int (*fill_linkxstats)(struct sk_buff___77 *, const struct net_device___76 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___75 {
	struct list_head poll_list;
	struct sk_buff_head___75 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___75 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___67 *output_queue;
	struct Qdisc___67 **output_queue_tailp;
	struct sk_buff___77 *completion_queue;
	struct sk_buff_head___75 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___75 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___75 input_pkt_queue;
	struct napi_struct___75 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bdi_writeback_congested___220 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___220 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___220 {
	struct bio___220 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___222 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___222 bip_inline_vecs[0];
};

struct bio_set___220 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___220 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___163 {
	struct mem_cgroup___163 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___163 {
	struct lruvec___431 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___163 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___163 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct tcamsg {
	unsigned char tca_family;
	unsigned char tca__pad1;
	short unsigned int tca__pad2;
};

enum {
	TCA_ROOT_UNSPEC = 0,
	TCA_ROOT_TAB = 1,
	TCA_ROOT_FLAGS = 2,
	TCA_ROOT_COUNT = 3,
	TCA_ROOT_TIME_DELTA = 4,
	__TCA_ROOT_MAX = 5,
};

struct gnet_dump___67 {
	spinlock_t *lock;
	struct sk_buff___77 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___67;

struct Qdisc_ops___67 {
	struct Qdisc_ops___67 *next;
	const struct Qdisc_class_ops___67 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___77 *, struct Qdisc___67 *, struct sk_buff___77 **);
	struct sk_buff___77 * (*dequeue)(struct Qdisc___67 *);
	struct sk_buff___77 * (*peek)(struct Qdisc___67 *);
	int (*init)(struct Qdisc___67 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___67 *);
	void (*destroy)(struct Qdisc___67 *);
	int (*change)(struct Qdisc___67 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___67 *);
	int (*change_tx_queue_len)(struct Qdisc___67 *, unsigned int);
	int (*dump)(struct Qdisc___67 *, struct sk_buff___77 *);
	int (*dump_stats)(struct Qdisc___67 *, struct gnet_dump___67 *);
	void (*ingress_block_set)(struct Qdisc___67 *, u32);
	void (*egress_block_set)(struct Qdisc___67 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___67 *);
	u32 (*egress_block_get)(struct Qdisc___67 *);
	struct module___358 *owner;
};

struct qdisc_walker___11;

struct tcf_block___67;

struct Qdisc_class_ops___67 {
	unsigned int flags;
	struct netdev_queue___75 * (*select_queue)(struct Qdisc___67 *, struct tcmsg *);
	int (*graft)(struct Qdisc___67 *, long unsigned int, struct Qdisc___67 *, struct Qdisc___67 **, struct netlink_ext_ack *);
	struct Qdisc___67 * (*leaf)(struct Qdisc___67 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___67 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___67 *, u32);
	int (*change)(struct Qdisc___67 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___67 *, long unsigned int);
	void (*walk)(struct Qdisc___67 *, struct qdisc_walker___11 *);
	struct tcf_block___67 * (*tcf_block)(struct Qdisc___67 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___67 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___67 *, long unsigned int);
	int (*dump)(struct Qdisc___67 *, long unsigned int, struct sk_buff___77 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___67 *, long unsigned int, struct gnet_dump___67 *);
};

struct qdisc_walker___11 {
	int stop;
	int skip;
	int count;
	int (*fn)(struct Qdisc___67 *, long unsigned int, struct qdisc_walker___11 *);
};

struct tcf_chain___67;

struct tcf_block___67 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___87 *net;
	struct Qdisc___67 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___67 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___67;

struct tcf_proto_ops___67;

struct tcf_proto___67 {
	struct tcf_proto___67 *next;
	void *root;
	int (*classify)(struct sk_buff___77 *, const struct tcf_proto___67 *, struct tcf_result___67 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___67 *ops;
	struct tcf_chain___67 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___67 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___67 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_walker___6;

struct tcf_proto_ops___67 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___77 *, const struct tcf_proto___67 *, struct tcf_result___67 *);
	int (*init)(struct tcf_proto___67 *);
	void (*destroy)(struct tcf_proto___67 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___67 *, u32);
	void (*put)(struct tcf_proto___67 *, void *);
	int (*change)(struct net___87 *, struct sk_buff___77 *, struct tcf_proto___67 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___67 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___67 *, struct tcf_walker___6 *, bool);
	int (*reoffload)(struct tcf_proto___67 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___87 *, struct tcf_chain___67 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___87 *, struct tcf_proto___67 *, void *, struct sk_buff___77 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___77 *, struct net___87 *, void *);
	struct module___358 *owner;
	int flags;
};

struct tcf_walker___6 {
	int stop;
	int skip;
	int count;
	bool nonempty;
	long unsigned int cookie;
	int (*fn)(struct tcf_proto___67 *, void *, struct tcf_walker___6 *);
};

struct tcf_chain___67 {
	struct mutex filter_chain_lock;
	struct tcf_proto___67 *filter_chain;
	struct list_head list;
	struct tcf_block___67 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___67 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___55 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___65 *prog;
};

struct bpf_redirect_info___65 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___280 *map;
	struct bpf_map___280 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___55;

struct neigh_hash_table___55;

struct neigh_table___55 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___76 *, __u32 *);
	bool (*key_eq)(const struct neighbour___55 *, const void *);
	int (*constructor)(struct neighbour___55 *);
	int (*pconstructor)(struct pneigh_entry___55 *);
	void (*pdestructor)(struct pneigh_entry___55 *);
	void (*proxy_redo)(struct sk_buff___77 *);
	char *id;
	struct neigh_parms___55 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___75 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___55 *nht;
	struct pneigh_entry___55 **phash_buckets;
};

struct neigh_ops___55 {
	int family;
	void (*solicit)(struct neighbour___55 *, struct sk_buff___77 *);
	void (*error_report)(struct neighbour___55 *, struct sk_buff___77 *);
	int (*output)(struct neighbour___55 *, struct sk_buff___77 *);
	int (*connected_output)(struct neighbour___55 *, struct sk_buff___77 *);
};

struct pneigh_entry___55 {
	struct pneigh_entry___55 *next;
	possible_net_t___77 net;
	struct net_device___76 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___55 {
	struct neighbour___55 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___55 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___55 *ctarget;
	struct net___87 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___55 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___55 *rule;
	u32 table;
	int flags;
};

struct proto___55 {
	void (*close)(struct sock___56 *, long int);
	int (*pre_connect)(struct sock___56 *, struct sockaddr *, int);
	int (*connect)(struct sock___56 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___56 *, int);
	struct sock___56 * (*accept)(struct sock___56 *, int, int *, bool);
	int (*ioctl)(struct sock___56 *, int, long unsigned int);
	int (*init)(struct sock___56 *);
	void (*destroy)(struct sock___56 *);
	void (*shutdown)(struct sock___56 *, int);
	int (*setsockopt)(struct sock___56 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___56 *, int, int, char *, int *);
	void (*keepalive)(struct sock___56 *, int);
	int (*sendmsg)(struct sock___56 *, struct msghdr___58 *, size_t);
	int (*recvmsg)(struct sock___56 *, struct msghdr___58 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___56 *, struct page___431 *, int, size_t, int);
	int (*bind)(struct sock___56 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___56 *, struct sk_buff___77 *);
	void (*release_cb)(struct sock___56 *);
	int (*hash)(struct sock___56 *);
	void (*unhash)(struct sock___56 *);
	void (*rehash)(struct sock___56 *);
	int (*get_port)(struct sock___56 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___56 *);
	bool (*stream_memory_read)(const struct sock___56 *);
	void (*enter_memory_pressure)(struct sock___56 *);
	void (*leave_memory_pressure)(struct sock___56 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___3 *rsk_prot;
	struct timewait_sock_ops___3 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___358 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___56 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct tc_action_ops___2;

struct tc_action___2 {
	const struct tc_action_ops___2 *ops;
	__u32 type;
	__u32 order;
	struct tcf_idrinfo *idrinfo;
	u32 tcfa_index;
	refcount_t tcfa_refcnt;
	atomic_t tcfa_bindcnt;
	int tcfa_action;
	struct tcf_t tcfa_tm;
	struct gnet_stats_basic_packed tcfa_bstats;
	struct gnet_stats_basic_packed tcfa_bstats_hw;
	struct gnet_stats_queue tcfa_qstats;
	int: 32;
	struct net_rate_estimator *tcfa_rate_est;
	spinlock_t tcfa_lock;
	int: 32;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_basic_cpu *cpu_bstats_hw;
	struct gnet_stats_queue *cpu_qstats;
	struct tc_cookie *act_cookie;
	struct tcf_chain___67 *goto_chain;
} __attribute__((packed));

struct tc_action_ops___2 {
	struct list_head head;
	char kind[16];
	enum tca_id id;
	size_t size;
	struct module___358 *owner;
	int (*act)(struct sk_buff___77 *, const struct tc_action___2 *, struct tcf_result___67 *);
	int (*dump)(struct sk_buff___77 *, struct tc_action___2 *, int, int);
	void (*cleanup)(struct tc_action___2 *);
	int (*lookup)(struct net___87 *, struct tc_action___2 **, u32);
	int (*init)(struct net___87 *, struct nlattr *, struct nlattr *, struct tc_action___2 **, int, int, bool, struct tcf_proto___67 *, struct netlink_ext_ack *);
	int (*walk)(struct net___87 *, struct sk_buff___77 *, struct netlink_callback___77 *, int, const struct tc_action_ops___2 *, struct netlink_ext_ack *);
	void (*stats_update)(struct tc_action___2 *, u64, u32, u64, bool);
	size_t (*get_fill_size)(const struct tc_action___2 *);
	struct net_device___76 * (*get_dev)(const struct tc_action___2 *);
	void (*put_dev)(struct net_device___76 *);
};

struct tc_action_net {
	struct tcf_idrinfo *idrinfo;
	const struct tc_action_ops___2 *ops;
};

struct tc_fifo_qopt {
	__u32 limit;
};

struct module___359;

struct file___431;

struct kiocb___431;

struct iov_iter___198;

struct poll_table_struct___270;

struct vm_area_struct___432;

struct inode___431;

struct file_lock___431;

struct page___432;

struct pipe_inode_info___112;

struct seq_file___370;

struct file_operations___431 {
	struct module___359 *owner;
	loff_t (*llseek)(struct file___431 *, loff_t, int);
	ssize_t (*read)(struct file___431 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___431 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___431 *, struct iov_iter___198 *);
	ssize_t (*write_iter)(struct kiocb___431 *, struct iov_iter___198 *);
	int (*iopoll)(struct kiocb___431 *, bool);
	int (*iterate)(struct file___431 *, struct dir_context *);
	int (*iterate_shared)(struct file___431 *, struct dir_context *);
	__poll_t (*poll)(struct file___431 *, struct poll_table_struct___270 *);
	long int (*unlocked_ioctl)(struct file___431 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___431 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___431 *, struct vm_area_struct___432 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___431 *, struct file___431 *);
	int (*flush)(struct file___431 *, fl_owner_t);
	int (*release)(struct inode___431 *, struct file___431 *);
	int (*fsync)(struct file___431 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___431 *, int);
	int (*lock)(struct file___431 *, int, struct file_lock___431 *);
	ssize_t (*sendpage)(struct file___431 *, struct page___432 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___431 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___431 *, int, struct file_lock___431 *);
	ssize_t (*splice_write)(struct pipe_inode_info___112 *, struct file___431 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___431 *, loff_t *, struct pipe_inode_info___112 *, size_t, unsigned int);
	int (*setlease)(struct file___431 *, long int, struct file_lock___431 **, void **);
	long int (*fallocate)(struct file___431 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___370 *, struct file___431 *);
	ssize_t (*copy_file_range)(struct file___431 *, loff_t, struct file___431 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___431 *, loff_t, struct file___431 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___431 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___432 {
	u64 seqnum;
	struct vm_area_struct___432 *vmas[4];
};

struct page_frag___432 {
	struct page___432 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___432;

struct mem_cgroup___164;

struct cred___399;

struct nsproxy___326;

struct signal_struct___306;

struct bio_list___221;

struct backing_dev_info___221;

struct css_set___280;

struct vm_struct___335;

struct task_struct___433 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___433 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___432 *mm;
	struct mm_struct___432 *active_mm;
	struct vmacache___432 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___433 *real_parent;
	struct task_struct___433 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___433 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___164 *active_memcg;
	long int rh_reserved2;
	struct pid___241 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___241 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___241 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___399 *ptracer_cred;
	const struct cred___399 *real_cred;
	const struct cred___399 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___326 *nsproxy;
	struct signal_struct___306 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___433 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___221 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___221 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___280 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___112 *splice_pipe;
	struct page_frag___432 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___164 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___433 *oom_reaper_list;
	struct vm_struct___335 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___156 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rw_semaphore___433 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___433 *owner;
};

struct key___399;

struct ucounts___296;

struct user_namespace___296 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___296 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___29 ns;
	long unsigned int flags;
	struct key___399 *persistent_keyring_register;
	struct rw_semaphore___433 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___296 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___432 *pgtable_t___432;

struct address_space___431;

struct dev_pagemap___419;

struct page___432 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___431 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___432 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___432 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___432 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___419 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___164 *mem_cgroup;
};

struct pglist_data___432;

struct lruvec___432 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___432 *pgdat;
};

struct zone___432 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___432 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___432 {
	struct zone___432 *zone;
	int zone_idx;
};

struct zonelist___432 {
	struct zoneref___432 _zonerefs[25];
};

struct pglist_data___432 {
	struct zone___432 node_zones[3];
	struct zonelist___432 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___433 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___433 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___432 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___433 {
	void *stack;
	struct task_struct___433 *task;
	long int status;
};

struct blocking_notifier_head___432 {
	struct rw_semaphore___433 rwsem;
	struct notifier_block *head;
};

struct dentry___431;

struct path___432 {
	struct vfsmount *mnt;
	struct dentry___431 *dentry;
};

struct file___431 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___432 f_path;
	struct inode___431 *f_inode;
	const struct file_operations___431 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___241 f_owner;
	const struct cred___399 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___431 *f_mapping;
	errseq_t f_wb_err;
};

struct user_struct___399;

struct cred___399 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___399 *session_keyring;
	struct key___399 *process_keyring;
	struct key___399 *thread_keyring;
	struct key___399 *request_key_auth;
	void *security;
	struct user_struct___399 *user;
	struct user_namespace___296 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___425;

struct kernfs_elem_dir___425 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___425 *root;
};

struct kernfs_node___426;

struct kernfs_syscall_ops___425;

struct kernfs_root___425 {
	struct kernfs_node___426 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___425 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___425 {
	struct kernfs_node___426 *target_kn;
};

struct kernfs_ops___425;

struct kernfs_elem_attr___425 {
	const struct kernfs_ops___425 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___426 *notify_next;
};

struct kernfs_node___426 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___426 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___425 dir;
		struct kernfs_elem_symlink___425 symlink;
		struct kernfs_elem_attr___425 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___425;

struct kernfs_ops___425 {
	int (*open)(struct kernfs_open_file___425 *);
	void (*release)(struct kernfs_open_file___425 *);
	int (*seq_show)(struct seq_file___370 *, void *);
	void * (*seq_start)(struct seq_file___370 *, loff_t *);
	void * (*seq_next)(struct seq_file___370 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___370 *, void *);
	ssize_t (*read)(struct kernfs_open_file___425 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___425 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___425 *, struct vm_area_struct___432 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___425 *, struct poll_table_struct___270 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___425 {
	int (*remount_fs)(struct kernfs_root___425 *, int *, char *);
	int (*show_options)(struct seq_file___370 *, struct kernfs_root___425 *);
	int (*mkdir)(struct kernfs_node___426 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___426 *);
	int (*rename)(struct kernfs_node___426 *, struct kernfs_node___426 *, const char *);
	int (*show_path)(struct seq_file___370 *, struct kernfs_node___426 *, struct kernfs_root___425 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___370;

struct seq_file___370 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___370 *op;
	int poll_event;
	const struct file___431 *file;
	void *private;
};

struct vm_operations_struct___419;

struct kernfs_open_file___425 {
	struct kernfs_node___426 *kn;
	struct file___431 *file;
	struct seq_file___370 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___419 *vm_ops;
};

struct vm_fault___419;

struct vm_operations_struct___419 {
	void (*open)(struct vm_area_struct___432 *);
	void (*close)(struct vm_area_struct___432 *);
	int (*split)(struct vm_area_struct___432 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___432 *);
	vm_fault_t (*fault)(struct vm_fault___419 *);
	vm_fault_t (*huge_fault)(struct vm_fault___419 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___419 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___432 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___419 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___419 *);
	int (*access)(struct vm_area_struct___432 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___432 *);
	int (*set_policy)(struct vm_area_struct___432 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___432 *, long unsigned int);
	struct page___432 * (*find_special_page)(struct vm_area_struct___432 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___280)(struct file___431 *, wait_queue_head_t *, struct poll_table_struct___270 *);

struct poll_table_struct___270 {
	poll_queue_proc___280 _qproc;
	__poll_t _key;
};

struct vm_area_struct___432 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___432 *vm_next;
	struct vm_area_struct___432 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___432 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___419 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___431 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sock___57;

struct kobj_ns_type_operations___56 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___57 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct net___88;

typedef struct {
	struct net___88 *net;
} possible_net_t___78;

struct proto___56;

struct sock_common___56 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___56 *skc_prot;
	possible_net_t___78 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___57 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___78;

struct sk_buff_head___76 {
	struct sk_buff___78 *next;
	struct sk_buff___78 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___56;

struct socket_wq___57;

struct dst_entry___56;

struct socket___58;

struct net_device___77;

struct sock___57 {
	struct sock_common___56 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___76 sk_error_queue;
	struct sk_buff_head___76 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___78 *head;
		struct sk_buff___78 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___56 *sk_filter;
	union {
		struct socket_wq___57 *sk_wq;
		struct socket_wq___57 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___56 *sk_rx_dst;
	struct dst_entry___56 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___78 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___76 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___432 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___56 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___241 *sk_peer_pid;
	const struct cred___399 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___58 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___164 *sk_memcg;
	void (*sk_state_change)(struct sock___57 *);
	void (*sk_data_ready)(struct sock___57 *);
	void (*sk_write_space)(struct sock___57 *);
	void (*sk_error_report)(struct sock___57 *);
	int (*sk_backlog_rcv)(struct sock___57 *, struct sk_buff___78 *);
	struct sk_buff___78 * (*sk_validate_xmit_skb)(struct sock___57 *, struct net_device___77 *, struct sk_buff___78 *);
	void (*sk_destruct)(struct sock___57 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kobject___419;

struct bin_attribute___395;

struct attribute_group___396 {
	const char *name;
	umode_t (*is_visible)(struct kobject___419 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___419 *, struct bin_attribute___395 *, int);
	struct attribute **attrs;
	struct bin_attribute___395 **bin_attrs;
};

struct kset___418;

struct kobj_type___418;

struct kobject___419 {
	const char *name;
	struct list_head entry;
	struct kobject___419 *parent;
	struct kset___418 *kset;
	struct kobj_type___418 *ktype;
	struct kernfs_node___426 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___395 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___431 *, struct kobject___419 *, struct bin_attribute___395 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___431 *, struct kobject___419 *, struct bin_attribute___395 *, char *, loff_t, size_t);
	int (*mmap)(struct file___431 *, struct kobject___419 *, struct bin_attribute___395 *, struct vm_area_struct___432 *);
};

struct sysfs_ops___418 {
	ssize_t (*show)(struct kobject___419 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___419 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___418;

struct kset___418 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___419 kobj;
	const struct kset_uevent_ops___418 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___418 {
	void (*release)(struct kobject___419 *);
	const struct sysfs_ops___418 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___56 * (*child_ns_type)(struct kobject___419 *);
	const void * (*namespace)(struct kobject___419 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___418 {
	int (* const filter)(struct kset___418 *, struct kobject___419 *);
	const char * (* const name)(struct kset___418 *, struct kobject___419 *);
	int (* const uevent)(struct kset___418 *, struct kobject___419 *, struct kobj_uevent_env *);
};

struct kobj_attribute___409 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___419 *, struct kobj_attribute___409 *, char *);
	ssize_t (*store)(struct kobject___419 *, struct kobj_attribute___409 *, const char *, size_t);
};

struct kernel_param___357;

struct kernel_param_ops___357 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___357 *);
	int (*get)(char *, const struct kernel_param___357 *);
	void (*free)(void *);
};

struct kparam_array___357;

struct kernel_param___357 {
	const char *name;
	struct module___359 *mod;
	const struct kernel_param_ops___357 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___357 *arr;
	};
};

struct kparam_array___357 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___357 *ops;
	void *elem;
};

struct module_kobject___357 {
	struct kobject___419 kobj;
	struct module___359 *mod;
	struct kobject___419 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___357 {
	struct module___359 *mod;
	struct latch_tree_node node;
};

struct module_layout___357 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___357 mtn;
};

struct module_attribute___357;

struct module___359 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___357 mkobj;
	struct module_attribute___357 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___419 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___357 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___357 core_layout;
	struct module_layout___357 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___357 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___357 *, struct module_kobject___357 *, char *);
	ssize_t (*store)(struct module_attribute___357 *, struct module_kobject___357 *, const char *, size_t);
	void (*setup)(struct module___359 *, const char *);
	int (*test)(struct module___359 *);
	void (*free)(struct module___359 *);
};

struct cgroup___280;

struct cgroup_subsys___280;

struct cgroup_subsys_state___280 {
	struct cgroup___280 *cgroup;
	struct cgroup_subsys___280 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___280 *parent;
};

struct cgroup_file___280 {
	struct kernfs_node___426 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___164;

struct mem_cgroup___164 {
	struct cgroup_subsys_state___280 css;
	struct mem_cgroup_id___15 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___280 events_file;
	struct cgroup_file___280 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___433 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___164 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct user_struct___399 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___399 *uid_keyring;
	struct key___399 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___432;

struct mm_struct___432 {
	struct {
		struct vm_area_struct___432 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___431 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___433 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___432 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___433 *owner;
		struct user_namespace___296 *user_ns;
		struct file___431 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___432 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___280;

struct nsproxy___326 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net___88 *net_ns;
	struct cgroup_namespace___280 *cgroup_ns;
};

struct signal_struct___306 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___433 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___433 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___241 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___241 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___432 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___241 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___221;

struct bio_list___221 {
	struct bio___221 *head;
	struct bio___221 *tail;
};

struct bdi_writeback_congested___221;

struct bdi_writeback___221 {
	struct backing_dev_info___221 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___221 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___280 *memcg_css;
	struct cgroup_subsys_state___280 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___399;

struct backing_dev_info___221 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___221 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___399 *dev;
	struct device___399 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___431 *debug_dir;
	struct dentry___431 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___280 {
	struct cgroup_subsys_state___280 *subsys[13];
	refcount_t refcount;
	struct css_set___280 *dom_cset;
	struct cgroup___280 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___280 *mg_src_cgrp;
	struct cgroup___280 *mg_dst_cgrp;
	struct css_set___280 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___431;

struct pipe_buffer___112;

struct pipe_inode_info___112 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___432 *tmp_page;
	struct fasync_struct___431 *fasync_readers;
	struct fasync_struct___431 *fasync_writers;
	struct pipe_buffer___112 *bufs;
	struct user_struct___399 *user;
};

struct vm_struct___335 {
	struct vm_struct___335 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___432 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___318 {
	struct task_struct___433 task;
	long unsigned int stack[8192];
};

struct address_space_operations___431;

struct address_space___431 {
	struct inode___431 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___433 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___431 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___419)(struct vm_area_struct___432 *, long unsigned int, const struct page___432 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___419)(struct page___432 *, void *);

struct dev_pagemap___419 {
	dev_page_fault_t___419 page_fault;
	dev_page_free_t___419 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___399 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___432 {
	struct task_struct___433 *task;
	struct core_thread___432 *next;
};

struct core_state___432 {
	atomic_t nr_threads;
	struct core_thread___432 dumper;
	struct completion startup;
};

struct vm_fault___419 {
	struct vm_area_struct___432 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___432 *cow_page;
	struct mem_cgroup___164 *memcg;
	struct page___432 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___432 prealloc_pte;
};

struct bio_vec___223 {
	struct page___432 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___198 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___223 *bvec;
		struct pipe_inode_info___112 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct msghdr___59 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___198 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___431 *msg_iocb;
};

struct kiocb___431 {
	struct file___431 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___431 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dentry_operations___431;

struct super_block___431;

struct dentry___431 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___431 *d_parent;
	struct qstr d_name;
	struct inode___431 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___431 *d_op;
	struct super_block___431 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___431;

struct block_device___431;

struct inode___431 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___431 *i_op;
	struct super_block___431 *i_sb;
	struct address_space___431 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___433 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___221 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___431 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___431 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___112 *i_pipe;
		struct block_device___431 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___431 {
	int (*d_revalidate)(struct dentry___431 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___431 *, unsigned int);
	int (*d_hash)(const struct dentry___431 *, struct qstr *);
	int (*d_compare)(const struct dentry___431 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___431 *);
	int (*d_init)(struct dentry___431 *);
	void (*d_release)(struct dentry___431 *);
	void (*d_prune)(struct dentry___431 *);
	void (*d_iput)(struct dentry___431 *, struct inode___431 *);
	char * (*d_dname)(struct dentry___431 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___432 *);
	int (*d_manage)(const struct path___432 *, bool);
	struct dentry___431 * (*d_real)(struct dentry___431 *, const struct inode___431 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___431;

struct mem_dqinfo___431 {
	struct quota_format_type___431 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___431;

struct quota_info___431 {
	unsigned int flags;
	struct rw_semaphore___433 dqio_sem;
	struct inode___431 *files[3];
	struct mem_dqinfo___431 info[3];
	const struct quota_format_ops___431 *ops[3];
};

struct rcuwait___431 {
	struct task_struct___433 *task;
};

struct percpu_rw_semaphore___431 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___433 rw_sem;
	struct rcuwait___431 writer;
	int readers_block;
};

struct sb_writers___431 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___431 rw_sem[3];
};

struct shrink_control___164;

struct shrinker___164 {
	long unsigned int (*count_objects)(struct shrinker___164 *, struct shrink_control___164 *);
	long unsigned int (*scan_objects)(struct shrinker___164 *, struct shrink_control___164 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___431;

struct super_operations___431;

struct dquot_operations___431;

struct quotactl_ops___431;

struct super_block___431 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___431 *s_type;
	const struct super_operations___431 *s_op;
	const struct dquot_operations___431 *dq_op;
	const struct quotactl_ops___431 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___431 *s_root;
	struct rw_semaphore___433 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___431 *s_bdev;
	struct backing_dev_info___221 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___431 s_dquot;
	struct sb_writers___431 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___431 *s_d_op;
	int cleancache_poolid;
	struct shrinker___164 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___296 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___164 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___164 *memcg;
};

struct iattr___431 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___431 *ia_file;
};

struct dquot___431 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___431 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___431 {
	int qf_fmt_id;
	const struct quota_format_ops___431 *qf_ops;
	struct module___359 *qf_owner;
	struct quota_format_type___431 *qf_next;
};

struct quota_format_ops___431 {
	int (*check_quota_file)(struct super_block___431 *, int);
	int (*read_file_info)(struct super_block___431 *, int);
	int (*write_file_info)(struct super_block___431 *, int);
	int (*free_file_info)(struct super_block___431 *, int);
	int (*read_dqblk)(struct dquot___431 *);
	int (*commit_dqblk)(struct dquot___431 *);
	int (*release_dqblk)(struct dquot___431 *);
	int (*get_next_id)(struct super_block___431 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___431 {
	int (*write_dquot)(struct dquot___431 *);
	struct dquot___431 * (*alloc_dquot)(struct super_block___431 *, int);
	void (*destroy_dquot)(struct dquot___431 *);
	int (*acquire_dquot)(struct dquot___431 *);
	int (*release_dquot)(struct dquot___431 *);
	int (*mark_dirty)(struct dquot___431 *);
	int (*write_info)(struct super_block___431 *, int);
	qsize_t * (*get_reserved_space)(struct inode___431 *);
	int (*get_projid)(struct inode___431 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___431 *, qsize_t *);
	int (*get_next_id)(struct super_block___431 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___431 {
	int (*quota_on)(struct super_block___431 *, int, int, const struct path___432 *);
	int (*quota_off)(struct super_block___431 *, int);
	int (*quota_enable)(struct super_block___431 *, unsigned int);
	int (*quota_disable)(struct super_block___431 *, unsigned int);
	int (*quota_sync)(struct super_block___431 *, int);
	int (*set_info)(struct super_block___431 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___431 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___431 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___431 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___431 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___431 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___184;

struct address_space_operations___431 {
	int (*writepage)(struct page___432 *, struct writeback_control___184 *);
	int (*readpage)(struct file___431 *, struct page___432 *);
	int (*writepages)(struct address_space___431 *, struct writeback_control___184 *);
	int (*set_page_dirty)(struct page___432 *);
	int (*readpages)(struct file___431 *, struct address_space___431 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___431 *, struct address_space___431 *, loff_t, unsigned int, unsigned int, struct page___432 **, void **);
	int (*write_end)(struct file___431 *, struct address_space___431 *, loff_t, unsigned int, unsigned int, struct page___432 *, void *);
	sector_t (*bmap)(struct address_space___431 *, sector_t);
	void (*invalidatepage)(struct page___432 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___432 *, gfp_t);
	void (*freepage)(struct page___432 *);
	ssize_t (*direct_IO)(struct kiocb___431 *, struct iov_iter___198 *);
	int (*migratepage)(struct address_space___431 *, struct page___432 *, struct page___432 *, enum migrate_mode);
	bool (*isolate_page)(struct page___432 *, isolate_mode_t);
	void (*putback_page)(struct page___432 *);
	int (*launder_page)(struct page___432 *);
	int (*is_partially_uptodate)(struct page___432 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___432 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___431 *, struct page___432 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___431 *, sector_t *);
	void (*swap_deactivate)(struct file___431 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___184 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___221 *wb;
	struct inode___431 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___431 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___431 *bd_inode;
	struct super_block___431 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___431 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___221 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___431 {
	struct dentry___431 * (*lookup)(struct inode___431 *, struct dentry___431 *, unsigned int);
	const char * (*get_link)(struct dentry___431 *, struct inode___431 *, struct delayed_call *);
	int (*permission)(struct inode___431 *, int);
	struct posix_acl * (*get_acl)(struct inode___431 *, int);
	int (*readlink)(struct dentry___431 *, char *, int);
	int (*create)(struct inode___431 *, struct dentry___431 *, umode_t, bool);
	int (*link)(struct dentry___431 *, struct inode___431 *, struct dentry___431 *);
	int (*unlink)(struct inode___431 *, struct dentry___431 *);
	int (*symlink)(struct inode___431 *, struct dentry___431 *, const char *);
	int (*mkdir)(struct inode___431 *, struct dentry___431 *, umode_t);
	int (*rmdir)(struct inode___431 *, struct dentry___431 *);
	int (*mknod)(struct inode___431 *, struct dentry___431 *, umode_t, dev_t);
	int (*rename)(struct inode___431 *, struct dentry___431 *, struct inode___431 *, struct dentry___431 *, unsigned int);
	int (*setattr)(struct dentry___431 *, struct iattr___431 *);
	int (*getattr)(const struct path___432 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___431 *, char *, size_t);
	int (*fiemap)(struct inode___431 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___431 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___431 *, struct dentry___431 *, struct file___431 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___431 *, struct dentry___431 *, umode_t);
	int (*set_acl)(struct inode___431 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___431 {
	void (*fl_copy_lock)(struct file_lock___431 *, struct file_lock___431 *);
	void (*fl_release_private)(struct file_lock___431 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___431;

struct file_lock___431 {
	struct file_lock___431 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___431 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___431 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___431 *fl_ops;
	const struct lock_manager_operations___431 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___431 {
	int (*lm_compare_owner)(struct file_lock___431 *, struct file_lock___431 *);
	long unsigned int (*lm_owner_key)(struct file_lock___431 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___431 *);
	int (*lm_grant)(struct file_lock___431 *, int);
	bool (*lm_break)(struct file_lock___431 *);
	int (*lm_change)(struct file_lock___431 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___431 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___431 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___431 *fa_next;
	struct file___431 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___431 {
	const char *name;
	int fs_flags;
	struct dentry___431 * (*mount)(struct file_system_type___431 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___431 *);
	struct module___359 *owner;
	struct file_system_type___431 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___431 {
	struct inode___431 * (*alloc_inode)(struct super_block___431 *);
	void (*destroy_inode)(struct inode___431 *);
	void (*dirty_inode)(struct inode___431 *, int);
	int (*write_inode)(struct inode___431 *, struct writeback_control___184 *);
	int (*drop_inode)(struct inode___431 *);
	void (*evict_inode)(struct inode___431 *);
	void (*put_super)(struct super_block___431 *);
	int (*sync_fs)(struct super_block___431 *, int);
	int (*freeze_super)(struct super_block___431 *);
	int (*freeze_fs)(struct super_block___431 *);
	int (*thaw_super)(struct super_block___431 *);
	int (*unfreeze_fs)(struct super_block___431 *);
	int (*statfs)(struct dentry___431 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___431 *, int *, char *);
	void (*umount_begin)(struct super_block___431 *);
	int (*show_options)(struct seq_file___370 *, struct dentry___431 *);
	int (*show_devname)(struct seq_file___370 *, struct dentry___431 *);
	int (*show_path)(struct seq_file___370 *, struct dentry___431 *);
	int (*show_stats)(struct seq_file___370 *, struct dentry___431 *);
	ssize_t (*quota_read)(struct super_block___431 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___431 *, int, const char *, size_t, loff_t);
	struct dquot___431 ** (*get_dquots)(struct inode___431 *);
	int (*bdev_try_to_free_page)(struct super_block___431 *, struct page___432 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___431 *, struct shrink_control___164 *);
	long int (*free_cached_objects)(struct super_block___431 *, struct shrink_control___164 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___221(struct bio___221 *);

struct bio_integrity_payload___221;

struct bio_set___221;

struct bio___221 {
	struct bio___221 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___221 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___221 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___223 *bi_io_vec;
	struct bio_set___221 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___223 bi_inline_vecs[0];
};

struct socket_wq___57 {
	wait_queue_head_t wait;
	struct fasync_struct___431 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___57;

struct socket___58 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___57 *wq;
	struct file___431 *file;
	struct sock___57 *sk;
	const struct proto_ops___57 *ops;
};

typedef int (*sk_read_actor_t___56)(read_descriptor_t *, struct sk_buff___78 *, unsigned int, size_t);

struct proto_ops___57 {
	int family;
	struct module___359 *owner;
	int (*release)(struct socket___58 *);
	int (*bind)(struct socket___58 *, struct sockaddr *, int);
	int (*connect)(struct socket___58 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___58 *, struct socket___58 *);
	int (*accept)(struct socket___58 *, struct socket___58 *, int, bool);
	int (*getname)(struct socket___58 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___431 *, struct socket___58 *, struct poll_table_struct___270 *);
	int (*ioctl)(struct socket___58 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___58 *, int);
	int (*shutdown)(struct socket___58 *, int);
	int (*setsockopt)(struct socket___58 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___58 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___58 *, struct msghdr___59 *, size_t);
	int (*recvmsg)(struct socket___58 *, struct msghdr___59 *, size_t, int);
	int (*mmap)(struct file___431 *, struct socket___58 *, struct vm_area_struct___432 *);
	ssize_t (*sendpage)(struct socket___58 *, struct page___432 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___58 *, loff_t *, struct pipe_inode_info___112 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___57 *, int);
	int (*peek_len)(struct socket___58 *);
	int (*read_sock)(struct sock___57 *, read_descriptor_t *, sk_read_actor_t___56);
	int (*sendpage_locked)(struct sock___57 *, struct page___432 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___57 *, struct msghdr___59 *, size_t);
	int (*set_rcvlowat)(struct sock___57 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct nf_bridge_info___76;

struct sk_buff___78 {
	union {
		struct {
			struct sk_buff___78 *next;
			struct sk_buff___78 *prev;
			union {
				struct net_device___77 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___57 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___78 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___76 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___76;

struct netns_frags___76 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___76 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_rules_ops___56;

struct fib_notifier_ops___57;

struct netns_ipv4___76 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___56 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___57 *fibnl;
	struct sock___57 **icmp_sk;
	struct sock___57 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___57 **tcp_sk;
	struct netns_frags___76 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___56 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___57 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___57 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___56;

struct dst_ops___87 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___87 *);
	struct dst_entry___56 * (*check)(struct dst_entry___56 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___56 *);
	unsigned int (*mtu)(const struct dst_entry___56 *);
	u32 * (*cow_metrics)(struct dst_entry___56 *, long unsigned int);
	void (*destroy)(struct dst_entry___56 *);
	void (*ifdown)(struct dst_entry___56 *, struct net_device___77 *, int);
	struct dst_entry___56 * (*negative_advice)(struct dst_entry___56 *);
	void (*link_failure)(struct sk_buff___78 *);
	void (*update_pmtu)(struct dst_entry___56 *, struct sock___57 *, struct sk_buff___78 *, u32);
	void (*redirect)(struct dst_entry___56 *, struct sock___57 *, struct sk_buff___78 *);
	int (*local_out)(struct net___88 *, struct sock___57 *, struct sk_buff___78 *);
	struct neighbour___56 * (*neigh_lookup)(const struct dst_entry___56 *, struct sk_buff___78 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___56 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___87 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___76 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___87 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___56 *fib6_rules_ops;
	struct sock___57 **icmp_sk;
	struct sock___57 *ndisc_sk;
	struct sock___57 *tcp_sk;
	struct sock___57 *igmp_sk;
	struct sock___57 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___56 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___57 *notifier_ops;
	struct fib_notifier_ops___57 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___57 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___57 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___76 {
	struct netns_frags___76 frags;
};

struct netns_xfrm___87 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___57 *nlsk;
	struct sock___57 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___87 xfrm4_dst_ops;
	struct dst_ops___87 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___66;

struct net___88 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___296 *user_ns;
	struct ucounts___296 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___29 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___57 *rtnl;
	struct sock___57 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___77 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___76 ipv4;
	struct netns_ipv6___87 ipv6;
	struct netns_sctp___57 sctp;
	struct netns_nf___4 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___76 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___57 *nfnl;
	struct sock___57 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___87 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___57 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___66 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___399 {
	int (*prepare)(struct device___399 *);
	void (*complete)(struct device___399 *);
	int (*suspend)(struct device___399 *);
	int (*resume)(struct device___399 *);
	int (*freeze)(struct device___399 *);
	int (*thaw)(struct device___399 *);
	int (*poweroff)(struct device___399 *);
	int (*restore)(struct device___399 *);
	int (*suspend_late)(struct device___399 *);
	int (*resume_early)(struct device___399 *);
	int (*freeze_late)(struct device___399 *);
	int (*thaw_early)(struct device___399 *);
	int (*poweroff_late)(struct device___399 *);
	int (*restore_early)(struct device___399 *);
	int (*suspend_noirq)(struct device___399 *);
	int (*resume_noirq)(struct device___399 *);
	int (*freeze_noirq)(struct device___399 *);
	int (*thaw_noirq)(struct device___399 *);
	int (*poweroff_noirq)(struct device___399 *);
	int (*restore_noirq)(struct device___399 *);
	int (*runtime_suspend)(struct device___399 *);
	int (*runtime_resume)(struct device___399 *);
	int (*runtime_idle)(struct device___399 *);
};

struct dev_pm_info___399 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___399 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___399;

struct bus_type___399;

struct device_driver___399;

struct dev_pm_domain___399;

struct dma_map_ops___171;

struct fwnode_handle___319;

struct class___399;

struct device___399 {
	struct device___399 *parent;
	struct device_private *p;
	struct kobject___419 kobj;
	const char *init_name;
	const struct device_type___399 *type;
	struct mutex mutex;
	struct bus_type___399 *bus;
	struct device_driver___399 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___399 power;
	struct dev_pm_domain___399 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___171 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___319 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___399 *class;
	const struct attribute_group___396 **groups;
	void (*release)(struct device___399 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___399 {
	struct dev_pm_ops___399 ops;
	void (*detach)(struct device___399 *, bool);
	int (*activate)(struct device___399 *);
	void (*sync)(struct device___399 *);
	void (*dismiss)(struct device___399 *);
};

struct bus_type___399 {
	const char *name;
	const char *dev_name;
	struct device___399 *dev_root;
	const struct attribute_group___396 **bus_groups;
	const struct attribute_group___396 **dev_groups;
	const struct attribute_group___396 **drv_groups;
	int (*match)(struct device___399 *, struct device_driver___399 *);
	int (*uevent)(struct device___399 *, struct kobj_uevent_env *);
	int (*probe)(struct device___399 *);
	int (*remove)(struct device___399 *);
	void (*shutdown)(struct device___399 *);
	int (*online)(struct device___399 *);
	int (*offline)(struct device___399 *);
	int (*suspend)(struct device___399 *, pm_message_t);
	int (*resume)(struct device___399 *);
	int (*num_vf)(struct device___399 *);
	int (*dma_configure)(struct device___399 *);
	const struct dev_pm_ops___399 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___399 {
	const char *name;
	struct bus_type___399 *bus;
	struct module___359 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___399 *);
	int (*remove)(struct device___399 *);
	void (*shutdown)(struct device___399 *);
	int (*suspend)(struct device___399 *, pm_message_t);
	int (*resume)(struct device___399 *);
	const struct attribute_group___396 **groups;
	const struct dev_pm_ops___399 *pm;
	void (*coredump)(struct device___399 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___399 {
	const char *name;
	const struct attribute_group___396 **groups;
	int (*uevent)(struct device___399 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___399 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___399 *);
	const struct dev_pm_ops___399 *pm;
};

struct class___399 {
	const char *name;
	struct module___359 *owner;
	const struct attribute_group___396 **class_groups;
	const struct attribute_group___396 **dev_groups;
	struct kobject___419 *dev_kobj;
	int (*dev_uevent)(struct device___399 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___399 *, umode_t *);
	void (*class_release)(struct class___399 *);
	void (*dev_release)(struct device___399 *);
	int (*shutdown_pre)(struct device___399 *);
	const struct kobj_ns_type_operations___56 *ns_type;
	const void * (*namespace)(struct device___399 *);
	const struct dev_pm_ops___399 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___171 {
	void * (*alloc)(struct device___399 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___399 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___399 *, struct vm_area_struct___432 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___399 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___399 *, struct page___432 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___399 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___399 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___399 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___399 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___399 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___399 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___399 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___399 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___399 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___399 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___399 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___399 *, u64);
	u64 (*get_required_mask)(struct device___399 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___319;

struct fwnode_handle___319 {
	struct fwnode_handle___319 *secondary;
	const struct fwnode_operations___319 *ops;
};

typedef void compound_page_dtor___419(struct page___432 *);

struct fwnode_reference_args___319;

struct fwnode_endpoint___319;

struct fwnode_operations___319 {
	struct fwnode_handle___319 * (*get)(struct fwnode_handle___319 *);
	void (*put)(struct fwnode_handle___319 *);
	bool (*device_is_available)(const struct fwnode_handle___319 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___319 *, const struct device___399 *);
	bool (*property_present)(const struct fwnode_handle___319 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___319 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___319 *, const char *, const char **, size_t);
	struct fwnode_handle___319 * (*get_parent)(const struct fwnode_handle___319 *);
	struct fwnode_handle___319 * (*get_next_child_node)(const struct fwnode_handle___319 *, struct fwnode_handle___319 *);
	struct fwnode_handle___319 * (*get_named_child_node)(const struct fwnode_handle___319 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___319 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___319 *);
	struct fwnode_handle___319 * (*graph_get_next_endpoint)(const struct fwnode_handle___319 *, struct fwnode_handle___319 *);
	struct fwnode_handle___319 * (*graph_get_remote_endpoint)(const struct fwnode_handle___319 *);
	struct fwnode_handle___319 * (*graph_get_port_parent)(struct fwnode_handle___319 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___319 *, struct fwnode_endpoint___319 *);
};

struct fwnode_endpoint___319 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___319 *local_fwnode;
};

struct fwnode_reference_args___319 {
	struct fwnode_handle___319 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___112;

struct pipe_buffer___112 {
	struct page___432 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___112 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___112 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___112 *, struct pipe_buffer___112 *);
	void (*release)(struct pipe_inode_info___112 *, struct pipe_buffer___112 *);
	int (*steal)(struct pipe_inode_info___112 *, struct pipe_buffer___112 *);
	union {
		bool (*get)(struct pipe_inode_info___112 *, struct pipe_buffer___112 *);
		struct {
			void (*get)(struct pipe_inode_info___112 *, struct pipe_buffer___112 *);
		} __UNIQUE_ID_rh_kabi_hide21;
		union {		};
	};
};

struct nf_bridge_info___76 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___76 = 0,
		BRNF_PROTO_8021Q___76 = 1,
		BRNF_PROTO_PPPOE___76 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___77 *physindev;
	struct net_device___77 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___76(struct sk_buff___78 **);

struct net_device_ops___76;

struct ethtool_ops___76;

struct l3mdev_ops___56;

struct xfrmdev_ops___76;

struct tlsdev_ops___76;

struct header_ops___76;

struct netdev_rx_queue___76;

struct mini_Qdisc___68;

struct netdev_queue___76;

struct Qdisc___68;

struct rtnl_link_ops___68;

struct dcbnl_rtnl_ops___76;

struct net_device___77 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___76 *netdev_ops;
	const struct ethtool_ops___76 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___56 *l3mdev_ops;
	const struct ndisc_ops___2 *ndisc_ops;
	const struct xfrmdev_ops___76 *xfrmdev_ops;
	const struct tlsdev_ops___76 *tlsdev_ops;
	const struct header_ops___76 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___418 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___2 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___76 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___66 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___76 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___68 *miniq_ingress;
	struct netdev_queue___76 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___76 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___68 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___68 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___76 = 0,
		NETREG_REGISTERED___76 = 1,
		NETREG_UNREGISTERING___76 = 2,
		NETREG_UNREGISTERED___76 = 3,
		NETREG_RELEASED___76 = 4,
		NETREG_DUMMY___76 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___76 = 0,
		RTNL_LINK_INITIALIZING___76 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___77 *);
	struct netpoll_info *npinfo;
	possible_net_t___78 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___399 dev;
	const struct attribute_group___396 *sysfs_groups[4];
	const struct attribute_group___396 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___68 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___76 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide35;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct skb_frag_struct___13 {
	struct {
		struct page___432 *p;
	} page;
	__u32 page_offset;
	__u32 size;
};

typedef struct skb_frag_struct___13 skb_frag_t___13;

struct skb_shared_info___13 {
	__u8 __unused;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___78 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___13 frags[16];
};

typedef int (*key_restrict_link_func_t___400)(struct key___399 *, const struct key_type *, const union key_payload *, struct key___399 *);

struct key_restriction___399;

struct key___399 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___433 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___399 *restrict_link;
};

struct key_restriction___399 {
	key_restrict_link_func_t___400 check;
	struct key___399 *key;
	struct key_type *keytype;
};

struct cgroup_namespace___280 {
	refcount_t count;
	struct ns_common___29 ns;
	struct user_namespace___296 *user_ns;
	struct ucounts___296 *ucounts;
	struct css_set___280 *root_cset;
};

struct netlink_callback___78 {
	struct sk_buff___78 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___78 *);
	int (*dump)(struct sk_buff___78 *, struct netlink_callback___78 *);
	int (*done)(struct netlink_callback___78 *);
	void *data;
	struct module___359 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct ethtool_ops___76 {
	int (*get_settings)(struct net_device___77 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___77 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___77 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___77 *);
	void (*get_regs)(struct net_device___77 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___77 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___77 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___77 *);
	void (*set_msglevel)(struct net_device___77 *, u32);
	int (*nway_reset)(struct net_device___77 *);
	u32 (*get_link)(struct net_device___77 *);
	int (*get_eeprom_len)(struct net_device___77 *);
	int (*get_eeprom)(struct net_device___77 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___77 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___77 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___77 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___77 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___77 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___77 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___77 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___77 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___77 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___77 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___77 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___77 *);
	void (*complete)(struct net_device___77 *);
	u32 (*get_priv_flags)(struct net_device___77 *);
	int (*set_priv_flags)(struct net_device___77 *, u32);
	int (*get_sset_count)(struct net_device___77 *, int);
	int (*get_rxnfc)(struct net_device___77 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___77 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___77 *, struct ethtool_flash *);
	int (*reset)(struct net_device___77 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___77 *);
	u32 (*get_rxfh_indir_size)(struct net_device___77 *);
	int (*get_rxfh)(struct net_device___77 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___77 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___77 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___77 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___77 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___77 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___77 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___77 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___77 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___77 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___77 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___77 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___77 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___77 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___77 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___77 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___77 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___77 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___77 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___77 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___77 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___77 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	int (*get_fecparam)(struct net_device___77 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___77 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___77 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___77 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___77 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___76;

struct inet_frags___76 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___76 *, const void *);
	void (*destructor)(struct inet_frag_queue___76 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___76 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___78 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___78 *fragments_tail;
	struct sk_buff___78 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___76 *net;
	struct callback_head rcu;
};

struct fib_rule___56;

struct fib_lookup_arg___56;

struct fib_rules_ops___56 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___56 *, struct flowi *, int, struct fib_lookup_arg___56 *);
	bool (*suppress)(struct fib_rule___56 *, struct fib_lookup_arg___56 *);
	int (*match)(struct fib_rule___56 *, struct flowi *, int);
	int (*configure)(struct fib_rule___56 *, struct sk_buff___78 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___56 *);
	int (*compare)(struct fib_rule___56 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___56 *, struct sk_buff___78 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___56 *);
	void (*flush_cache)(struct fib_rules_ops___56 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___359 *owner;
	struct net___88 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___57 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___88 *);
	int (*fib_dump)(struct net___88 *, struct notifier_block *);
	struct module___359 *owner;
	struct callback_head rcu;
};

struct dst_entry___56 {
	struct net_device___77 *dev;
	struct dst_ops___87 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___78 *);
	int (*output)(struct net___88 *, struct sock___57 *, struct sk_buff___78 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___56;

struct neigh_parms___56;

struct neigh_ops___56;

struct neighbour___56 {
	struct neighbour___56 *next;
	struct neigh_table___56 *tbl;
	struct neigh_parms___56 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___76 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___56 *, struct sk_buff___78 *);
	const struct neigh_ops___56 *ops;
	struct callback_head rcu;
	struct net_device___77 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct ucounts___296 {
	struct hlist_node node;
	struct user_namespace___296 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_prog_aux___69;

struct bpf_prog___66 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___69 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

struct seq_operations___370 {
	void * (*start)(struct seq_file___370 *, loff_t *);
	void (*stop)(struct seq_file___370 *, void *);
	void * (*next)(struct seq_file___370 *, void *, loff_t *);
	int (*show)(struct seq_file___370 *, void *);
};

struct pernet_operations___77 {
	struct list_head list;
	int (*init)(struct net___88 *);
	void (*exit)(struct net___88 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___76 {
	int (*ieee_getets)(struct net_device___77 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___77 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___77 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___77 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___77 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___77 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___77 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___77 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___77 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___77 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___77 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___77 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___77 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___77 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___77 *);
	u8 (*setstate)(struct net_device___77 *, u8);
	void (*getpermhwaddr)(struct net_device___77 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___77 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___77 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___77 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___77 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___77 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___77 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___77 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___77 *, int, u8 *);
	void (*setpfccfg)(struct net_device___77 *, int, u8);
	void (*getpfccfg)(struct net_device___77 *, int, u8 *);
	u8 (*setall)(struct net_device___77 *);
	u8 (*getcap)(struct net_device___77 *, int, u8 *);
	int (*getnumtcs)(struct net_device___77 *, int, u8 *);
	int (*setnumtcs)(struct net_device___77 *, int, u8);
	u8 (*getpfcstate)(struct net_device___77 *);
	void (*setpfcstate)(struct net_device___77 *, u8);
	void (*getbcncfg)(struct net_device___77 *, int, u32 *);
	void (*setbcncfg)(struct net_device___77 *, int, u32);
	void (*getbcnrp)(struct net_device___77 *, int, u8 *);
	void (*setbcnrp)(struct net_device___77 *, int, u8);
	int (*setapp)(struct net_device___77 *, u8, u16, u8);
	int (*getapp)(struct net_device___77 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___77 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___77 *, int, u8);
	u8 (*getdcbx)(struct net_device___77 *);
	u8 (*setdcbx)(struct net_device___77 *, u8);
	int (*peer_getappinfo)(struct net_device___77 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___77 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___77 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___77 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___77 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___77 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct bpf_map___281;

struct bpf_map_ops___280 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___281 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___281 *, struct file___431 *);
	void (*map_free)(struct bpf_map___281 *);
	int (*map_get_next_key)(struct bpf_map___281 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___281 *);
	void * (*map_lookup_elem)(struct bpf_map___281 *, void *);
	int (*map_update_elem)(struct bpf_map___281 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___281 *, void *);
	int (*map_push_elem)(struct bpf_map___281 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___281 *, void *);
	int (*map_peek_elem)(struct bpf_map___281 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___281 *, struct file___431 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___281 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___281 *, void *, struct seq_file___370 *);
	int (*map_check_btf)(const struct bpf_map___281 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___281 {
	const struct bpf_map_ops___280 *ops;
	struct bpf_map___281 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___399 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___76;

struct bpf_map_dev_ops___76 {
	int (*map_get_next_key)(struct bpf_offloaded_map___76 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___76 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___76 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___76 *, void *);
};

struct bpf_offloaded_map___76 {
	struct bpf_map___281 map;
	struct net_device___77 *netdev;
	const struct bpf_map_dev_ops___76 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___66 {
	int (*test_run)(struct bpf_prog___66 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___66 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___66 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___66 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___66 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___66 *, u32 *);
};

struct bpf_prog_offload_ops___66 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___66 *);
	int (*translate)(struct bpf_prog___66 *);
	void (*destroy)(struct bpf_prog___66 *);
};

struct bpf_prog_offload___66 {
	struct bpf_prog___66 *prog;
	struct net_device___77 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___66 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___69 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___66 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___66 *ops;
	struct bpf_map___281 **used_maps;
	struct bpf_prog___66 *prog;
	struct user_struct___399 *user;
	u64 load_time;
	struct bpf_map___281 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___66 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___66 {
	struct bpf_prog___66 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___66 {
	struct callback_head rcu;
	struct bpf_prog_array_item___66 items[0];
};

struct cgroup_bpf___66 {
	struct bpf_prog_array___66 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___66 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___281;

typedef void (*kthread_work_func_t___281)(struct kthread_work___281 *);

struct kthread_worker___281;

struct kthread_work___281 {
	struct list_head node;
	kthread_work_func_t___281 func;
	struct kthread_worker___281 *worker;
	int canceling;
};

struct kthread_worker___281 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___433 *task;
	struct kthread_work___281 *current_work;
};

struct kthread_delayed_work___280 {
	struct kthread_work___281 work;
	struct timer_list timer;
};

struct psi_group___280 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___281 *poll_kworker;
	struct kthread_delayed_work___280 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___280;

struct cgroup_rstat_cpu___280;

struct cgroup___280 {
	struct cgroup_subsys_state___280 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___426 *kn;
	struct cgroup_file___280 procs_file;
	struct cgroup_file___280 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___280 *subsys[13];
	struct cgroup_root___280 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___280 *dom_cgrp;
	struct cgroup_rstat_cpu___280 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___66 bpf;
	atomic_t congestion_count;
	struct cgroup___280 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___280 psi;
	int ancestor_ids[0];
};

struct cftype___280;

struct cgroup_subsys___280 {
	struct cgroup_subsys_state___280 * (*css_alloc)(struct cgroup_subsys_state___280 *);
	int (*css_online)(struct cgroup_subsys_state___280 *);
	void (*css_offline)(struct cgroup_subsys_state___280 *);
	void (*css_released)(struct cgroup_subsys_state___280 *);
	void (*css_free)(struct cgroup_subsys_state___280 *);
	void (*css_reset)(struct cgroup_subsys_state___280 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___280 *, int);
	int (*css_extra_stat_show)(struct seq_file___370 *, struct cgroup_subsys_state___280 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___433 *);
	void (*cancel_fork)(struct task_struct___433 *);
	void (*fork)(struct task_struct___433 *);
	void (*exit)(struct task_struct___433 *);
	void (*free)(struct task_struct___433 *);
	void (*bind)(struct cgroup_subsys_state___280 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___280 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___280 *dfl_cftypes;
	struct cftype___280 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___280 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___280 *updated_children;
	struct cgroup___280 *updated_next;
};

struct cgroup_root___280 {
	struct kernfs_root___425 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___280 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___280 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___280 *ss;
	struct list_head node;
	struct kernfs_ops___425 *kf_ops;
	int (*open)(struct kernfs_open_file___425 *);
	void (*release)(struct kernfs_open_file___425 *);
	u64 (*read_u64)(struct cgroup_subsys_state___280 *, struct cftype___280 *);
	s64 (*read_s64)(struct cgroup_subsys_state___280 *, struct cftype___280 *);
	int (*seq_show)(struct seq_file___370 *, void *);
	void * (*seq_start)(struct seq_file___370 *, loff_t *);
	void * (*seq_next)(struct seq_file___370 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___370 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___280 *, struct cftype___280 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___280 *, struct cftype___280 *, s64);
	ssize_t (*write)(struct kernfs_open_file___425 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___425 *, struct poll_table_struct___270 *);
};

struct xdp_rxq_info___76 {
	struct net_device___77 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___76 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___77 *dev_rx;
};

enum {
	TCA_FQ_CODEL_UNSPEC = 0,
	TCA_FQ_CODEL_TARGET = 1,
	TCA_FQ_CODEL_LIMIT = 2,
	TCA_FQ_CODEL_INTERVAL = 3,
	TCA_FQ_CODEL_ECN = 4,
	TCA_FQ_CODEL_FLOWS = 5,
	TCA_FQ_CODEL_QUANTUM = 6,
	TCA_FQ_CODEL_CE_THRESHOLD = 7,
	TCA_FQ_CODEL_DROP_BATCH_SIZE = 8,
	TCA_FQ_CODEL_MEMORY_LIMIT = 9,
	__TCA_FQ_CODEL_MAX = 10,
};

enum {
	TCA_FQ_CODEL_XSTATS_QDISC = 0,
	TCA_FQ_CODEL_XSTATS_CLASS = 1,
};

struct tc_fq_codel_qd_stats {
	__u32 maxpacket;
	__u32 drop_overlimit;
	__u32 ecn_mark;
	__u32 new_flow_count;
	__u32 new_flows_len;
	__u32 old_flows_len;
	__u32 ce_mark;
	__u32 memory_usage;
	__u32 drop_overmemory;
};

struct tc_fq_codel_cl_stats {
	__s32 deficit;
	__u32 ldelay;
	__u32 count;
	__u32 lastcount;
	__u32 dropping;
	__s32 drop_next;
};

struct tc_fq_codel_xstats {
	__u32 type;
	union {
		struct tc_fq_codel_qd_stats qdisc_stats;
		struct tc_fq_codel_cl_stats class_stats;
	};
};

struct header_ops___76 {
	int (*create)(struct sk_buff___78 *, struct net_device___77 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___78 *, unsigned char *);
	int (*cache)(const struct neighbour___56 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___77 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___76 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___76 *, int);
	int poll_owner;
	struct net_device___77 *dev;
	struct sk_buff___78 *gro_list;
	struct sk_buff___78 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___76 {
	struct net_device___77 *dev;
	struct Qdisc___68 *qdisc;
	struct Qdisc___68 *qdisc_sleeping;
	struct kobject___419 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___77 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem___3 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___68 {
	struct sk_buff___78 *head;
	struct sk_buff___78 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___68;

struct Qdisc___68 {
	int (*enqueue)(struct sk_buff___78 *, struct Qdisc___68 *, struct sk_buff___78 **);
	struct sk_buff___78 * (*dequeue)(struct Qdisc___68 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___68 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___76 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___76 gso_skb;
	struct qdisc_skb_head___68 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___68 *next_sched;
	struct sk_buff_head___76 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___76 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___419 kobj;
	struct net_device___77 *dev;
	long: 64;
	struct xdp_rxq_info___76 xdp_rxq;
	union {
		struct xdp_umem___3 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___76)(struct net_device___77 *, struct sk_buff___78 *, struct net_device___77 *);

struct netdev_bpf___76 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___66 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___66 *prog;
			const struct bpf_prog_offload_ops___66 *ops;
		} verifier;
		struct {
			struct bpf_prog___66 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___76 *offmap;
		};
		struct {
			struct xdp_umem___3 *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___76 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___78 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___76 {
	int (*tls_dev_add)(struct net_device___77 *, struct sock___57 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___77 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___77 *, struct sock___57 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___76 {
	int (*ndo_init)(struct net_device___77 *);
	void (*ndo_uninit)(struct net_device___77 *);
	int (*ndo_open)(struct net_device___77 *);
	int (*ndo_stop)(struct net_device___77 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___78 *, struct net_device___77 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___78 *, struct net_device___77 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___77 *, struct sk_buff___78 *, struct net_device___77 *, select_queue_fallback_t___76);
	void (*ndo_change_rx_flags)(struct net_device___77 *, int);
	void (*ndo_set_rx_mode)(struct net_device___77 *);
	int (*ndo_set_mac_address)(struct net_device___77 *, void *);
	int (*ndo_validate_addr)(struct net_device___77 *);
	int (*ndo_do_ioctl)(struct net_device___77 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___77 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___77 *, int);
	int (*ndo_neigh_setup)(struct net_device___77 *, struct neigh_parms___56 *);
	void (*ndo_tx_timeout)(struct net_device___77 *);
	void (*ndo_get_stats64)(struct net_device___77 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___77 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___77 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___77 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___77 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___77 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___77 *);
	int (*ndo_netpoll_setup)(struct net_device___77 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___77 *);
	int (*ndo_set_vf_mac)(struct net_device___77 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___77 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___77 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___77 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___77 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___77 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___77 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___77 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___77 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___77 *, int, struct sk_buff___78 *);
	int (*ndo_set_vf_guid)(struct net_device___77 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___77 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___77 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___77 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___77 *, const struct sk_buff___78 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___77 *, struct net_device___77 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___77 *, struct net_device___77 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___77 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___77 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___77 *, struct neighbour___56 *);
	void (*ndo_neigh_destroy)(struct net_device___77 *, struct neighbour___56 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___77 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___77 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___77 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___78 *, struct netlink_callback___78 *, struct net_device___77 *, struct net_device___77 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___77 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___77 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___78 *, u32, u32, struct net_device___77 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___77 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___77 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___77 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___77 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___77 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___77 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___77 *, struct net_device___77 *);
	void (*ndo_dfwd_del_station)(struct net_device___77 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___77 *);
	int (*ndo_set_tx_maxrate)(struct net_device___77 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___77 *);
	int (*ndo_change_proto_down)(struct net_device___77 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___77 *, struct sk_buff___78 *);
	void (*ndo_set_rx_headroom)(struct net_device___77 *, int);
	int (*ndo_bpf)(struct net_device___77 *, struct netdev_bpf___76 *);
	int (*ndo_xdp_xmit)(struct net_device___77 *, int, struct xdp_frame___76 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___77 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___77 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___56 {
	possible_net_t___78 net;
	struct net_device___77 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___56 *);
	void (*neigh_cleanup)(struct neighbour___56 *);
	struct neigh_table___56 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___56 {
	u32 (*l3mdev_fib_table)(const struct net_device___77 *);
	struct sk_buff___78 * (*l3mdev_l3_rcv)(struct net_device___77 *, struct sk_buff___78 *, u16);
	struct sk_buff___78 * (*l3mdev_l3_out)(struct net_device___77 *, struct sock___57 *, struct sk_buff___78 *, u16);
	struct dst_entry___56 * (*l3mdev_link_scope_lookup)(const struct net_device___77 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct tcf_proto___68;

struct mini_Qdisc___68 {
	struct tcf_proto___68 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___68 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___77 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___88 *, struct net_device___77 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___77 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___77 *, struct list_head *);
	size_t (*get_size)(const struct net_device___77 *);
	int (*fill_info)(struct sk_buff___78 *, const struct net_device___77 *);
	size_t (*get_xstats_size)(const struct net_device___77 *);
	int (*fill_xstats)(struct sk_buff___78 *, const struct net_device___77 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___77 *, struct net_device___77 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___77 *, const struct net_device___77 *);
	int (*fill_slave_info)(struct sk_buff___78 *, const struct net_device___77 *, const struct net_device___77 *);
	struct net___88 * (*get_link_net)(const struct net_device___77 *);
	size_t (*get_linkxstats_size)(const struct net_device___77 *, int);
	int (*fill_linkxstats)(struct sk_buff___78 *, const struct net_device___77 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___76 {
	struct list_head poll_list;
	struct sk_buff_head___76 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___76 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___68 *output_queue;
	struct Qdisc___68 **output_queue_tailp;
	struct sk_buff___78 *completion_queue;
	struct sk_buff_head___76 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___76 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___76 input_pkt_queue;
	struct napi_struct___76 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct gnet_dump___68 {
	spinlock_t *lock;
	struct sk_buff___78 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___68;

struct Qdisc_ops___68 {
	struct Qdisc_ops___68 *next;
	const struct Qdisc_class_ops___68 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___78 *, struct Qdisc___68 *, struct sk_buff___78 **);
	struct sk_buff___78 * (*dequeue)(struct Qdisc___68 *);
	struct sk_buff___78 * (*peek)(struct Qdisc___68 *);
	int (*init)(struct Qdisc___68 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___68 *);
	void (*destroy)(struct Qdisc___68 *);
	int (*change)(struct Qdisc___68 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___68 *);
	int (*change_tx_queue_len)(struct Qdisc___68 *, unsigned int);
	int (*dump)(struct Qdisc___68 *, struct sk_buff___78 *);
	int (*dump_stats)(struct Qdisc___68 *, struct gnet_dump___68 *);
	void (*ingress_block_set)(struct Qdisc___68 *, u32);
	void (*egress_block_set)(struct Qdisc___68 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___68 *);
	u32 (*egress_block_get)(struct Qdisc___68 *);
	struct module___359 *owner;
};

struct qdisc_walker___12;

struct tcf_block___68;

struct Qdisc_class_ops___68 {
	unsigned int flags;
	struct netdev_queue___76 * (*select_queue)(struct Qdisc___68 *, struct tcmsg *);
	int (*graft)(struct Qdisc___68 *, long unsigned int, struct Qdisc___68 *, struct Qdisc___68 **, struct netlink_ext_ack *);
	struct Qdisc___68 * (*leaf)(struct Qdisc___68 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___68 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___68 *, u32);
	int (*change)(struct Qdisc___68 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___68 *, long unsigned int);
	void (*walk)(struct Qdisc___68 *, struct qdisc_walker___12 *);
	struct tcf_block___68 * (*tcf_block)(struct Qdisc___68 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___68 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___68 *, long unsigned int);
	int (*dump)(struct Qdisc___68 *, long unsigned int, struct sk_buff___78 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___68 *, long unsigned int, struct gnet_dump___68 *);
};

struct qdisc_walker___12 {
	int stop;
	int skip;
	int count;
	int (*fn)(struct Qdisc___68 *, long unsigned int, struct qdisc_walker___12 *);
};

struct tcf_chain___68;

struct tcf_block___68 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___88 *net;
	struct Qdisc___68 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___68 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___68;

struct tcf_proto_ops___68;

struct tcf_proto___68 {
	struct tcf_proto___68 *next;
	void *root;
	int (*classify)(struct sk_buff___78 *, const struct tcf_proto___68 *, struct tcf_result___68 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___68 *ops;
	struct tcf_chain___68 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___68 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___68 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_walker___7;

struct tcf_proto_ops___68 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___78 *, const struct tcf_proto___68 *, struct tcf_result___68 *);
	int (*init)(struct tcf_proto___68 *);
	void (*destroy)(struct tcf_proto___68 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___68 *, u32);
	void (*put)(struct tcf_proto___68 *, void *);
	int (*change)(struct net___88 *, struct sk_buff___78 *, struct tcf_proto___68 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___68 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___68 *, struct tcf_walker___7 *, bool);
	int (*reoffload)(struct tcf_proto___68 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___88 *, struct tcf_chain___68 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___88 *, struct tcf_proto___68 *, void *, struct sk_buff___78 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___78 *, struct net___88 *, void *);
	struct module___359 *owner;
	int flags;
};

struct tcf_walker___7 {
	int stop;
	int skip;
	int count;
	bool nonempty;
	long unsigned int cookie;
	int (*fn)(struct tcf_proto___68 *, void *, struct tcf_walker___7 *);
};

struct tcf_chain___68 {
	struct mutex filter_chain_lock;
	struct tcf_proto___68 *filter_chain;
	struct list_head list;
	struct tcf_block___68 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___68 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct bdi_writeback_congested___221 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___221 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___221 {
	struct bio___221 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___223 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___223 bip_inline_vecs[0];
};

struct bio_set___221 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___221 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___164 {
	struct mem_cgroup___164 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___164 {
	struct lruvec___432 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___164 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___164 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct sk_filter___56 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___66 *prog;
};

struct bpf_redirect_info___66 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___281 *map;
	struct bpf_map___281 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___56;

struct neigh_hash_table___56;

struct neigh_table___56 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___77 *, __u32 *);
	bool (*key_eq)(const struct neighbour___56 *, const void *);
	int (*constructor)(struct neighbour___56 *);
	int (*pconstructor)(struct pneigh_entry___56 *);
	void (*pdestructor)(struct pneigh_entry___56 *);
	void (*proxy_redo)(struct sk_buff___78 *);
	char *id;
	struct neigh_parms___56 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___76 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___56 *nht;
	struct pneigh_entry___56 **phash_buckets;
};

struct neigh_ops___56 {
	int family;
	void (*solicit)(struct neighbour___56 *, struct sk_buff___78 *);
	void (*error_report)(struct neighbour___56 *, struct sk_buff___78 *);
	int (*output)(struct neighbour___56 *, struct sk_buff___78 *);
	int (*connected_output)(struct neighbour___56 *, struct sk_buff___78 *);
};

struct pneigh_entry___56 {
	struct pneigh_entry___56 *next;
	possible_net_t___78 net;
	struct net_device___77 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___56 {
	struct neighbour___56 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___56 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___56 *ctarget;
	struct net___88 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___56 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___56 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___39;

struct timewait_sock_ops___36;

struct proto___56 {
	void (*close)(struct sock___57 *, long int);
	int (*pre_connect)(struct sock___57 *, struct sockaddr *, int);
	int (*connect)(struct sock___57 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___57 *, int);
	struct sock___57 * (*accept)(struct sock___57 *, int, int *, bool);
	int (*ioctl)(struct sock___57 *, int, long unsigned int);
	int (*init)(struct sock___57 *);
	void (*destroy)(struct sock___57 *);
	void (*shutdown)(struct sock___57 *, int);
	int (*setsockopt)(struct sock___57 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___57 *, int, int, char *, int *);
	void (*keepalive)(struct sock___57 *, int);
	int (*sendmsg)(struct sock___57 *, struct msghdr___59 *, size_t);
	int (*recvmsg)(struct sock___57 *, struct msghdr___59 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___57 *, struct page___432 *, int, size_t, int);
	int (*bind)(struct sock___57 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___57 *, struct sk_buff___78 *);
	void (*release_cb)(struct sock___57 *);
	int (*hash)(struct sock___57 *);
	void (*unhash)(struct sock___57 *);
	void (*rehash)(struct sock___57 *);
	int (*get_port)(struct sock___57 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___57 *);
	bool (*stream_memory_read)(const struct sock___57 *);
	void (*enter_memory_pressure)(struct sock___57 *);
	void (*leave_memory_pressure)(struct sock___57 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___39 *rsk_prot;
	struct timewait_sock_ops___36 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___359 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___57 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct request_sock___40;

struct request_sock_ops___39 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___57 *, struct request_sock___40 *);
	void (*send_ack)(const struct sock___57 *, struct sk_buff___78 *, struct request_sock___40 *);
	void (*send_reset)(const struct sock___57 *, struct sk_buff___78 *);
	void (*destructor)(struct request_sock___40 *);
	void (*syn_ack_timeout)(const struct request_sock___40 *);
};

struct timewait_sock_ops___36 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___57 *, struct sock___57 *, void *);
	void (*twsk_destructor)(struct sock___57 *);
};

struct request_sock___40 {
	struct sock_common___56 __req_common;
	struct request_sock___40 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___39 *rsk_ops;
	struct sock___57 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

enum {
	INET_ECN_NOT_ECT = 0,
	INET_ECN_ECT_1 = 1,
	INET_ECN_ECT_0 = 2,
	INET_ECN_CE = 3,
	INET_ECN_MASK = 3,
};

typedef u32 codel_time_t;

typedef s32 codel_tdiff_t;

struct codel_params {
	codel_time_t target;
	codel_time_t ce_threshold;
	codel_time_t interval;
	u32 mtu;
	bool ecn;
};

struct codel_vars {
	u32 count;
	u32 lastcount;
	bool dropping;
	u16 rec_inv_sqrt;
	codel_time_t first_above_time;
	codel_time_t drop_next;
	codel_time_t ldelay;
};

struct codel_stats {
	u32 maxpacket;
	u32 drop_count;
	u32 drop_len;
	u32 ecn_mark;
	u32 ce_mark;
};

typedef u32 (*codel_skb_len_t)(const struct sk_buff___78 *);

typedef codel_time_t (*codel_skb_time_t)(const struct sk_buff___78 *);

typedef void (*codel_skb_drop_t)(struct sk_buff___78 *, void *);

typedef struct sk_buff___78 * (*codel_skb_dequeue_t)(struct codel_vars *, void *);

struct codel_skb_cb {
	codel_time_t enqueue_time;
	unsigned int mem_usage;
};

struct fq_codel_flow {
	struct sk_buff___78 *head;
	struct sk_buff___78 *tail;
	struct list_head flowchain;
	int deficit;
	u32 dropped;
	struct codel_vars cvars;
};

struct fq_codel_sched_data {
	struct tcf_proto___68 *filter_list;
	struct tcf_block___68 *block;
	struct fq_codel_flow *flows;
	u32 *backlogs;
	u32 flows_cnt;
	u32 quantum;
	u32 drop_batch_size;
	u32 memory_limit;
	struct codel_params cparams;
	struct codel_stats cstats;
	u32 memory_usage;
	u32 drop_overmemory;
	u32 drop_overlimit;
	u32 new_flow_count;
	struct list_head new_flows;
	struct list_head old_flows;
};

struct module___360;

struct file___432;

struct kiocb___432;

struct iov_iter___199;

struct poll_table_struct___271;

struct vm_area_struct___433;

struct inode___432;

struct file_lock___432;

struct page___433;

struct pipe_inode_info___113;

struct seq_file___371;

struct file_operations___432 {
	struct module___360 *owner;
	loff_t (*llseek)(struct file___432 *, loff_t, int);
	ssize_t (*read)(struct file___432 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___432 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___432 *, struct iov_iter___199 *);
	ssize_t (*write_iter)(struct kiocb___432 *, struct iov_iter___199 *);
	int (*iopoll)(struct kiocb___432 *, bool);
	int (*iterate)(struct file___432 *, struct dir_context *);
	int (*iterate_shared)(struct file___432 *, struct dir_context *);
	__poll_t (*poll)(struct file___432 *, struct poll_table_struct___271 *);
	long int (*unlocked_ioctl)(struct file___432 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___432 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___432 *, struct vm_area_struct___433 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___432 *, struct file___432 *);
	int (*flush)(struct file___432 *, fl_owner_t);
	int (*release)(struct inode___432 *, struct file___432 *);
	int (*fsync)(struct file___432 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___432 *, int);
	int (*lock)(struct file___432 *, int, struct file_lock___432 *);
	ssize_t (*sendpage)(struct file___432 *, struct page___433 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___432 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___432 *, int, struct file_lock___432 *);
	ssize_t (*splice_write)(struct pipe_inode_info___113 *, struct file___432 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___432 *, loff_t *, struct pipe_inode_info___113 *, size_t, unsigned int);
	int (*setlease)(struct file___432 *, long int, struct file_lock___432 **, void **);
	long int (*fallocate)(struct file___432 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___371 *, struct file___432 *);
	ssize_t (*copy_file_range)(struct file___432 *, loff_t, struct file___432 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___432 *, loff_t, struct file___432 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___432 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___433 {
	u64 seqnum;
	struct vm_area_struct___433 *vmas[4];
};

struct page_frag___433 {
	struct page___433 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___433;

struct mem_cgroup___165;

struct cred___400;

struct nsproxy___327;

struct signal_struct___307;

struct bio_list___222;

struct backing_dev_info___222;

struct css_set___281;

struct vm_struct___336;

struct task_struct___434 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___434 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___433 *mm;
	struct mm_struct___433 *active_mm;
	struct vmacache___433 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___434 *real_parent;
	struct task_struct___434 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___434 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___165 *active_memcg;
	long int rh_reserved2;
	struct pid___241 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___241 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___241 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___400 *ptracer_cred;
	const struct cred___400 *real_cred;
	const struct cred___400 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___327 *nsproxy;
	struct signal_struct___307 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___434 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___222 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___222 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___281 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___113 *splice_pipe;
	struct page_frag___433 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___165 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___434 *oom_reaper_list;
	struct vm_struct___336 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___156 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rw_semaphore___434 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___434 *owner;
};

struct key___400;

struct ucounts___297;

struct user_namespace___297 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___297 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___29 ns;
	long unsigned int flags;
	struct key___400 *persistent_keyring_register;
	struct rw_semaphore___434 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___297 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___433 *pgtable_t___433;

struct address_space___432;

struct dev_pagemap___420;

struct page___433 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___432 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___433 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___433 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___433 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___420 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___165 *mem_cgroup;
};

struct pglist_data___433;

struct lruvec___433 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___433 *pgdat;
};

struct zone___433 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___433 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___433 {
	struct zone___433 *zone;
	int zone_idx;
};

struct zonelist___433 {
	struct zoneref___433 _zonerefs[25];
};

struct pglist_data___433 {
	struct zone___433 node_zones[3];
	struct zonelist___433 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___434 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___434 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___433 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___434 {
	void *stack;
	struct task_struct___434 *task;
	long int status;
};

struct blocking_notifier_head___433 {
	struct rw_semaphore___434 rwsem;
	struct notifier_block *head;
};

struct dentry___432;

struct path___433 {
	struct vfsmount *mnt;
	struct dentry___432 *dentry;
};

struct file___432 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___433 f_path;
	struct inode___432 *f_inode;
	const struct file_operations___432 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___241 f_owner;
	const struct cred___400 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___432 *f_mapping;
	errseq_t f_wb_err;
};

struct user_struct___400;

struct cred___400 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___400 *session_keyring;
	struct key___400 *process_keyring;
	struct key___400 *thread_keyring;
	struct key___400 *request_key_auth;
	void *security;
	struct user_struct___400 *user;
	struct user_namespace___297 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___426;

struct kernfs_elem_dir___426 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___426 *root;
};

struct kernfs_node___427;

struct kernfs_syscall_ops___426;

struct kernfs_root___426 {
	struct kernfs_node___427 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___426 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___426 {
	struct kernfs_node___427 *target_kn;
};

struct kernfs_ops___426;

struct kernfs_elem_attr___426 {
	const struct kernfs_ops___426 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___427 *notify_next;
};

struct kernfs_node___427 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___427 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___426 dir;
		struct kernfs_elem_symlink___426 symlink;
		struct kernfs_elem_attr___426 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___426;

struct kernfs_ops___426 {
	int (*open)(struct kernfs_open_file___426 *);
	void (*release)(struct kernfs_open_file___426 *);
	int (*seq_show)(struct seq_file___371 *, void *);
	void * (*seq_start)(struct seq_file___371 *, loff_t *);
	void * (*seq_next)(struct seq_file___371 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___371 *, void *);
	ssize_t (*read)(struct kernfs_open_file___426 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___426 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___426 *, struct vm_area_struct___433 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___426 *, struct poll_table_struct___271 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___426 {
	int (*remount_fs)(struct kernfs_root___426 *, int *, char *);
	int (*show_options)(struct seq_file___371 *, struct kernfs_root___426 *);
	int (*mkdir)(struct kernfs_node___427 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___427 *);
	int (*rename)(struct kernfs_node___427 *, struct kernfs_node___427 *, const char *);
	int (*show_path)(struct seq_file___371 *, struct kernfs_node___427 *, struct kernfs_root___426 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___371;

struct seq_file___371 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___371 *op;
	int poll_event;
	const struct file___432 *file;
	void *private;
};

struct vm_operations_struct___420;

struct kernfs_open_file___426 {
	struct kernfs_node___427 *kn;
	struct file___432 *file;
	struct seq_file___371 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___420 *vm_ops;
};

struct vm_fault___420;

struct vm_operations_struct___420 {
	void (*open)(struct vm_area_struct___433 *);
	void (*close)(struct vm_area_struct___433 *);
	int (*split)(struct vm_area_struct___433 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___433 *);
	vm_fault_t (*fault)(struct vm_fault___420 *);
	vm_fault_t (*huge_fault)(struct vm_fault___420 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___420 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___433 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___420 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___420 *);
	int (*access)(struct vm_area_struct___433 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___433 *);
	int (*set_policy)(struct vm_area_struct___433 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___433 *, long unsigned int);
	struct page___433 * (*find_special_page)(struct vm_area_struct___433 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___281)(struct file___432 *, wait_queue_head_t *, struct poll_table_struct___271 *);

struct poll_table_struct___271 {
	poll_queue_proc___281 _qproc;
	__poll_t _key;
};

struct vm_area_struct___433 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___433 *vm_next;
	struct vm_area_struct___433 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___433 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___420 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___432 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sock___58;

struct kobj_ns_type_operations___57 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___58 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct net___89;

typedef struct {
	struct net___89 *net;
} possible_net_t___79;

struct proto___57;

struct sock_common___57 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___57 *skc_prot;
	possible_net_t___79 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___58 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___79;

struct sk_buff_head___77 {
	struct sk_buff___79 *next;
	struct sk_buff___79 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___57;

struct socket_wq___58;

struct dst_entry___57;

struct socket___59;

struct net_device___78;

struct sock___58 {
	struct sock_common___57 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___77 sk_error_queue;
	struct sk_buff_head___77 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___79 *head;
		struct sk_buff___79 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___57 *sk_filter;
	union {
		struct socket_wq___58 *sk_wq;
		struct socket_wq___58 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___57 *sk_rx_dst;
	struct dst_entry___57 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___79 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___77 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___433 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___57 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___241 *sk_peer_pid;
	const struct cred___400 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___59 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___165 *sk_memcg;
	void (*sk_state_change)(struct sock___58 *);
	void (*sk_data_ready)(struct sock___58 *);
	void (*sk_write_space)(struct sock___58 *);
	void (*sk_error_report)(struct sock___58 *);
	int (*sk_backlog_rcv)(struct sock___58 *, struct sk_buff___79 *);
	struct sk_buff___79 * (*sk_validate_xmit_skb)(struct sock___58 *, struct net_device___78 *, struct sk_buff___79 *);
	void (*sk_destruct)(struct sock___58 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kobject___420;

struct bin_attribute___396;

struct attribute_group___397 {
	const char *name;
	umode_t (*is_visible)(struct kobject___420 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___420 *, struct bin_attribute___396 *, int);
	struct attribute **attrs;
	struct bin_attribute___396 **bin_attrs;
};

struct kset___419;

struct kobj_type___419;

struct kobject___420 {
	const char *name;
	struct list_head entry;
	struct kobject___420 *parent;
	struct kset___419 *kset;
	struct kobj_type___419 *ktype;
	struct kernfs_node___427 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___396 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___432 *, struct kobject___420 *, struct bin_attribute___396 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___432 *, struct kobject___420 *, struct bin_attribute___396 *, char *, loff_t, size_t);
	int (*mmap)(struct file___432 *, struct kobject___420 *, struct bin_attribute___396 *, struct vm_area_struct___433 *);
};

struct sysfs_ops___419 {
	ssize_t (*show)(struct kobject___420 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___420 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___419;

struct kset___419 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___420 kobj;
	const struct kset_uevent_ops___419 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___419 {
	void (*release)(struct kobject___420 *);
	const struct sysfs_ops___419 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___57 * (*child_ns_type)(struct kobject___420 *);
	const void * (*namespace)(struct kobject___420 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___419 {
	int (* const filter)(struct kset___419 *, struct kobject___420 *);
	const char * (* const name)(struct kset___419 *, struct kobject___420 *);
	int (* const uevent)(struct kset___419 *, struct kobject___420 *, struct kobj_uevent_env *);
};

struct kobj_attribute___410 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___420 *, struct kobj_attribute___410 *, char *);
	ssize_t (*store)(struct kobject___420 *, struct kobj_attribute___410 *, const char *, size_t);
};

struct kernel_param___358;

struct kernel_param_ops___358 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___358 *);
	int (*get)(char *, const struct kernel_param___358 *);
	void (*free)(void *);
};

struct kparam_array___358;

struct kernel_param___358 {
	const char *name;
	struct module___360 *mod;
	const struct kernel_param_ops___358 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___358 *arr;
	};
};

struct kparam_array___358 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___358 *ops;
	void *elem;
};

struct module_kobject___358 {
	struct kobject___420 kobj;
	struct module___360 *mod;
	struct kobject___420 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___358 {
	struct module___360 *mod;
	struct latch_tree_node node;
};

struct module_layout___358 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___358 mtn;
};

struct module_attribute___358;

struct module___360 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___358 mkobj;
	struct module_attribute___358 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___420 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___358 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___358 core_layout;
	struct module_layout___358 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___358 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___358 *, struct module_kobject___358 *, char *);
	ssize_t (*store)(struct module_attribute___358 *, struct module_kobject___358 *, const char *, size_t);
	void (*setup)(struct module___360 *, const char *);
	int (*test)(struct module___360 *);
	void (*free)(struct module___360 *);
};

struct cgroup___281;

struct cgroup_subsys___281;

struct cgroup_subsys_state___281 {
	struct cgroup___281 *cgroup;
	struct cgroup_subsys___281 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___281 *parent;
};

struct cgroup_file___281 {
	struct kernfs_node___427 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___165;

struct mem_cgroup___165 {
	struct cgroup_subsys_state___281 css;
	struct mem_cgroup_id___15 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___281 events_file;
	struct cgroup_file___281 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___434 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___165 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct user_struct___400 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___400 *uid_keyring;
	struct key___400 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___433;

struct mm_struct___433 {
	struct {
		struct vm_area_struct___433 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___432 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___434 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___433 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___434 *owner;
		struct user_namespace___297 *user_ns;
		struct file___432 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___433 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___281;

struct nsproxy___327 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net___89 *net_ns;
	struct cgroup_namespace___281 *cgroup_ns;
};

struct signal_struct___307 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___434 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___434 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___241 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___241 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___433 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___241 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___222;

struct bio_list___222 {
	struct bio___222 *head;
	struct bio___222 *tail;
};

struct bdi_writeback_congested___222;

struct bdi_writeback___222 {
	struct backing_dev_info___222 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___222 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___281 *memcg_css;
	struct cgroup_subsys_state___281 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___400;

struct backing_dev_info___222 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___222 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___400 *dev;
	struct device___400 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___432 *debug_dir;
	struct dentry___432 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___281 {
	struct cgroup_subsys_state___281 *subsys[13];
	refcount_t refcount;
	struct css_set___281 *dom_cset;
	struct cgroup___281 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___281 *mg_src_cgrp;
	struct cgroup___281 *mg_dst_cgrp;
	struct css_set___281 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___432;

struct pipe_buffer___113;

struct pipe_inode_info___113 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___433 *tmp_page;
	struct fasync_struct___432 *fasync_readers;
	struct fasync_struct___432 *fasync_writers;
	struct pipe_buffer___113 *bufs;
	struct user_struct___400 *user;
};

struct vm_struct___336 {
	struct vm_struct___336 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___433 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___319 {
	struct task_struct___434 task;
	long unsigned int stack[8192];
};

struct address_space_operations___432;

struct address_space___432 {
	struct inode___432 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___434 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___432 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___420)(struct vm_area_struct___433 *, long unsigned int, const struct page___433 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___420)(struct page___433 *, void *);

struct dev_pagemap___420 {
	dev_page_fault_t___420 page_fault;
	dev_page_free_t___420 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___400 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___433 {
	struct task_struct___434 *task;
	struct core_thread___433 *next;
};

struct core_state___433 {
	atomic_t nr_threads;
	struct core_thread___433 dumper;
	struct completion startup;
};

struct vm_fault___420 {
	struct vm_area_struct___433 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___433 *cow_page;
	struct mem_cgroup___165 *memcg;
	struct page___433 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___433 prealloc_pte;
};

struct bio_vec___224 {
	struct page___433 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___199 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___224 *bvec;
		struct pipe_inode_info___113 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct msghdr___60 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___199 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___432 *msg_iocb;
};

struct kiocb___432 {
	struct file___432 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___432 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dentry_operations___432;

struct super_block___432;

struct dentry___432 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___432 *d_parent;
	struct qstr d_name;
	struct inode___432 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___432 *d_op;
	struct super_block___432 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___432;

struct block_device___432;

struct inode___432 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___432 *i_op;
	struct super_block___432 *i_sb;
	struct address_space___432 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___434 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___222 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___432 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___432 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___113 *i_pipe;
		struct block_device___432 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___432 {
	int (*d_revalidate)(struct dentry___432 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___432 *, unsigned int);
	int (*d_hash)(const struct dentry___432 *, struct qstr *);
	int (*d_compare)(const struct dentry___432 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___432 *);
	int (*d_init)(struct dentry___432 *);
	void (*d_release)(struct dentry___432 *);
	void (*d_prune)(struct dentry___432 *);
	void (*d_iput)(struct dentry___432 *, struct inode___432 *);
	char * (*d_dname)(struct dentry___432 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___433 *);
	int (*d_manage)(const struct path___433 *, bool);
	struct dentry___432 * (*d_real)(struct dentry___432 *, const struct inode___432 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___432;

struct mem_dqinfo___432 {
	struct quota_format_type___432 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___432;

struct quota_info___432 {
	unsigned int flags;
	struct rw_semaphore___434 dqio_sem;
	struct inode___432 *files[3];
	struct mem_dqinfo___432 info[3];
	const struct quota_format_ops___432 *ops[3];
};

struct rcuwait___432 {
	struct task_struct___434 *task;
};

struct percpu_rw_semaphore___432 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___434 rw_sem;
	struct rcuwait___432 writer;
	int readers_block;
};

struct sb_writers___432 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___432 rw_sem[3];
};

struct shrink_control___165;

struct shrinker___165 {
	long unsigned int (*count_objects)(struct shrinker___165 *, struct shrink_control___165 *);
	long unsigned int (*scan_objects)(struct shrinker___165 *, struct shrink_control___165 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___432;

struct super_operations___432;

struct dquot_operations___432;

struct quotactl_ops___432;

struct super_block___432 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___432 *s_type;
	const struct super_operations___432 *s_op;
	const struct dquot_operations___432 *dq_op;
	const struct quotactl_ops___432 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___432 *s_root;
	struct rw_semaphore___434 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___432 *s_bdev;
	struct backing_dev_info___222 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___432 s_dquot;
	struct sb_writers___432 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___432 *s_d_op;
	int cleancache_poolid;
	struct shrinker___165 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___297 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___165 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___165 *memcg;
};

struct iattr___432 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___432 *ia_file;
};

struct dquot___432 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___432 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___432 {
	int qf_fmt_id;
	const struct quota_format_ops___432 *qf_ops;
	struct module___360 *qf_owner;
	struct quota_format_type___432 *qf_next;
};

struct quota_format_ops___432 {
	int (*check_quota_file)(struct super_block___432 *, int);
	int (*read_file_info)(struct super_block___432 *, int);
	int (*write_file_info)(struct super_block___432 *, int);
	int (*free_file_info)(struct super_block___432 *, int);
	int (*read_dqblk)(struct dquot___432 *);
	int (*commit_dqblk)(struct dquot___432 *);
	int (*release_dqblk)(struct dquot___432 *);
	int (*get_next_id)(struct super_block___432 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___432 {
	int (*write_dquot)(struct dquot___432 *);
	struct dquot___432 * (*alloc_dquot)(struct super_block___432 *, int);
	void (*destroy_dquot)(struct dquot___432 *);
	int (*acquire_dquot)(struct dquot___432 *);
	int (*release_dquot)(struct dquot___432 *);
	int (*mark_dirty)(struct dquot___432 *);
	int (*write_info)(struct super_block___432 *, int);
	qsize_t * (*get_reserved_space)(struct inode___432 *);
	int (*get_projid)(struct inode___432 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___432 *, qsize_t *);
	int (*get_next_id)(struct super_block___432 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___432 {
	int (*quota_on)(struct super_block___432 *, int, int, const struct path___433 *);
	int (*quota_off)(struct super_block___432 *, int);
	int (*quota_enable)(struct super_block___432 *, unsigned int);
	int (*quota_disable)(struct super_block___432 *, unsigned int);
	int (*quota_sync)(struct super_block___432 *, int);
	int (*set_info)(struct super_block___432 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___432 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___432 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___432 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___432 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___432 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___185;

struct address_space_operations___432 {
	int (*writepage)(struct page___433 *, struct writeback_control___185 *);
	int (*readpage)(struct file___432 *, struct page___433 *);
	int (*writepages)(struct address_space___432 *, struct writeback_control___185 *);
	int (*set_page_dirty)(struct page___433 *);
	int (*readpages)(struct file___432 *, struct address_space___432 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___432 *, struct address_space___432 *, loff_t, unsigned int, unsigned int, struct page___433 **, void **);
	int (*write_end)(struct file___432 *, struct address_space___432 *, loff_t, unsigned int, unsigned int, struct page___433 *, void *);
	sector_t (*bmap)(struct address_space___432 *, sector_t);
	void (*invalidatepage)(struct page___433 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___433 *, gfp_t);
	void (*freepage)(struct page___433 *);
	ssize_t (*direct_IO)(struct kiocb___432 *, struct iov_iter___199 *);
	int (*migratepage)(struct address_space___432 *, struct page___433 *, struct page___433 *, enum migrate_mode);
	bool (*isolate_page)(struct page___433 *, isolate_mode_t);
	void (*putback_page)(struct page___433 *);
	int (*launder_page)(struct page___433 *);
	int (*is_partially_uptodate)(struct page___433 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___433 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___432 *, struct page___433 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___432 *, sector_t *);
	void (*swap_deactivate)(struct file___432 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___185 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___222 *wb;
	struct inode___432 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___432 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___432 *bd_inode;
	struct super_block___432 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___432 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___222 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___432 {
	struct dentry___432 * (*lookup)(struct inode___432 *, struct dentry___432 *, unsigned int);
	const char * (*get_link)(struct dentry___432 *, struct inode___432 *, struct delayed_call *);
	int (*permission)(struct inode___432 *, int);
	struct posix_acl * (*get_acl)(struct inode___432 *, int);
	int (*readlink)(struct dentry___432 *, char *, int);
	int (*create)(struct inode___432 *, struct dentry___432 *, umode_t, bool);
	int (*link)(struct dentry___432 *, struct inode___432 *, struct dentry___432 *);
	int (*unlink)(struct inode___432 *, struct dentry___432 *);
	int (*symlink)(struct inode___432 *, struct dentry___432 *, const char *);
	int (*mkdir)(struct inode___432 *, struct dentry___432 *, umode_t);
	int (*rmdir)(struct inode___432 *, struct dentry___432 *);
	int (*mknod)(struct inode___432 *, struct dentry___432 *, umode_t, dev_t);
	int (*rename)(struct inode___432 *, struct dentry___432 *, struct inode___432 *, struct dentry___432 *, unsigned int);
	int (*setattr)(struct dentry___432 *, struct iattr___432 *);
	int (*getattr)(const struct path___433 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___432 *, char *, size_t);
	int (*fiemap)(struct inode___432 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___432 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___432 *, struct dentry___432 *, struct file___432 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___432 *, struct dentry___432 *, umode_t);
	int (*set_acl)(struct inode___432 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___432 {
	void (*fl_copy_lock)(struct file_lock___432 *, struct file_lock___432 *);
	void (*fl_release_private)(struct file_lock___432 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___432;

struct file_lock___432 {
	struct file_lock___432 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___432 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___432 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___432 *fl_ops;
	const struct lock_manager_operations___432 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___432 {
	int (*lm_compare_owner)(struct file_lock___432 *, struct file_lock___432 *);
	long unsigned int (*lm_owner_key)(struct file_lock___432 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___432 *);
	int (*lm_grant)(struct file_lock___432 *, int);
	bool (*lm_break)(struct file_lock___432 *);
	int (*lm_change)(struct file_lock___432 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___432 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___432 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___432 *fa_next;
	struct file___432 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___432 {
	const char *name;
	int fs_flags;
	struct dentry___432 * (*mount)(struct file_system_type___432 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___432 *);
	struct module___360 *owner;
	struct file_system_type___432 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___432 {
	struct inode___432 * (*alloc_inode)(struct super_block___432 *);
	void (*destroy_inode)(struct inode___432 *);
	void (*dirty_inode)(struct inode___432 *, int);
	int (*write_inode)(struct inode___432 *, struct writeback_control___185 *);
	int (*drop_inode)(struct inode___432 *);
	void (*evict_inode)(struct inode___432 *);
	void (*put_super)(struct super_block___432 *);
	int (*sync_fs)(struct super_block___432 *, int);
	int (*freeze_super)(struct super_block___432 *);
	int (*freeze_fs)(struct super_block___432 *);
	int (*thaw_super)(struct super_block___432 *);
	int (*unfreeze_fs)(struct super_block___432 *);
	int (*statfs)(struct dentry___432 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___432 *, int *, char *);
	void (*umount_begin)(struct super_block___432 *);
	int (*show_options)(struct seq_file___371 *, struct dentry___432 *);
	int (*show_devname)(struct seq_file___371 *, struct dentry___432 *);
	int (*show_path)(struct seq_file___371 *, struct dentry___432 *);
	int (*show_stats)(struct seq_file___371 *, struct dentry___432 *);
	ssize_t (*quota_read)(struct super_block___432 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___432 *, int, const char *, size_t, loff_t);
	struct dquot___432 ** (*get_dquots)(struct inode___432 *);
	int (*bdev_try_to_free_page)(struct super_block___432 *, struct page___433 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___432 *, struct shrink_control___165 *);
	long int (*free_cached_objects)(struct super_block___432 *, struct shrink_control___165 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___222(struct bio___222 *);

struct bio_integrity_payload___222;

struct bio_set___222;

struct bio___222 {
	struct bio___222 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___222 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___222 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___224 *bi_io_vec;
	struct bio_set___222 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___224 bi_inline_vecs[0];
};

struct socket_wq___58 {
	wait_queue_head_t wait;
	struct fasync_struct___432 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___58;

struct socket___59 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___58 *wq;
	struct file___432 *file;
	struct sock___58 *sk;
	const struct proto_ops___58 *ops;
};

typedef int (*sk_read_actor_t___57)(read_descriptor_t *, struct sk_buff___79 *, unsigned int, size_t);

struct proto_ops___58 {
	int family;
	struct module___360 *owner;
	int (*release)(struct socket___59 *);
	int (*bind)(struct socket___59 *, struct sockaddr *, int);
	int (*connect)(struct socket___59 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___59 *, struct socket___59 *);
	int (*accept)(struct socket___59 *, struct socket___59 *, int, bool);
	int (*getname)(struct socket___59 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___432 *, struct socket___59 *, struct poll_table_struct___271 *);
	int (*ioctl)(struct socket___59 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___59 *, int);
	int (*shutdown)(struct socket___59 *, int);
	int (*setsockopt)(struct socket___59 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___59 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___59 *, struct msghdr___60 *, size_t);
	int (*recvmsg)(struct socket___59 *, struct msghdr___60 *, size_t, int);
	int (*mmap)(struct file___432 *, struct socket___59 *, struct vm_area_struct___433 *);
	ssize_t (*sendpage)(struct socket___59 *, struct page___433 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___59 *, loff_t *, struct pipe_inode_info___113 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___58 *, int);
	int (*peek_len)(struct socket___59 *);
	int (*read_sock)(struct sock___58 *, read_descriptor_t *, sk_read_actor_t___57);
	int (*sendpage_locked)(struct sock___58 *, struct page___433 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___58 *, struct msghdr___60 *, size_t);
	int (*set_rcvlowat)(struct sock___58 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct nf_bridge_info___77;

struct sk_buff___79 {
	union {
		struct {
			struct sk_buff___79 *next;
			struct sk_buff___79 *prev;
			union {
				struct net_device___78 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___58 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___79 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___77 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___77;

struct netns_frags___77 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___77 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_rules_ops___57;

struct fib_notifier_ops___58;

struct netns_ipv4___77 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___57 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___58 *fibnl;
	struct sock___58 **icmp_sk;
	struct sock___58 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___58 **tcp_sk;
	struct netns_frags___77 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___57 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___58 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___58 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___57;

struct dst_ops___88 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___88 *);
	struct dst_entry___57 * (*check)(struct dst_entry___57 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___57 *);
	unsigned int (*mtu)(const struct dst_entry___57 *);
	u32 * (*cow_metrics)(struct dst_entry___57 *, long unsigned int);
	void (*destroy)(struct dst_entry___57 *);
	void (*ifdown)(struct dst_entry___57 *, struct net_device___78 *, int);
	struct dst_entry___57 * (*negative_advice)(struct dst_entry___57 *);
	void (*link_failure)(struct sk_buff___79 *);
	void (*update_pmtu)(struct dst_entry___57 *, struct sock___58 *, struct sk_buff___79 *, u32);
	void (*redirect)(struct dst_entry___57 *, struct sock___58 *, struct sk_buff___79 *);
	int (*local_out)(struct net___89 *, struct sock___58 *, struct sk_buff___79 *);
	struct neighbour___57 * (*neigh_lookup)(const struct dst_entry___57 *, struct sk_buff___79 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___57 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___88 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___77 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___88 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___57 *fib6_rules_ops;
	struct sock___58 **icmp_sk;
	struct sock___58 *ndisc_sk;
	struct sock___58 *tcp_sk;
	struct sock___58 *igmp_sk;
	struct sock___58 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___57 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___58 *notifier_ops;
	struct fib_notifier_ops___58 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___58 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___58 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___77 {
	struct netns_frags___77 frags;
};

struct netns_xfrm___88 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___58 *nlsk;
	struct sock___58 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___88 xfrm4_dst_ops;
	struct dst_ops___88 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___67;

struct net___89 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___297 *user_ns;
	struct ucounts___297 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___29 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___58 *rtnl;
	struct sock___58 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___78 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___77 ipv4;
	struct netns_ipv6___88 ipv6;
	struct netns_sctp___58 sctp;
	struct netns_nf___4 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___77 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___58 *nfnl;
	struct sock___58 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___88 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___58 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___67 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___400 {
	int (*prepare)(struct device___400 *);
	void (*complete)(struct device___400 *);
	int (*suspend)(struct device___400 *);
	int (*resume)(struct device___400 *);
	int (*freeze)(struct device___400 *);
	int (*thaw)(struct device___400 *);
	int (*poweroff)(struct device___400 *);
	int (*restore)(struct device___400 *);
	int (*suspend_late)(struct device___400 *);
	int (*resume_early)(struct device___400 *);
	int (*freeze_late)(struct device___400 *);
	int (*thaw_early)(struct device___400 *);
	int (*poweroff_late)(struct device___400 *);
	int (*restore_early)(struct device___400 *);
	int (*suspend_noirq)(struct device___400 *);
	int (*resume_noirq)(struct device___400 *);
	int (*freeze_noirq)(struct device___400 *);
	int (*thaw_noirq)(struct device___400 *);
	int (*poweroff_noirq)(struct device___400 *);
	int (*restore_noirq)(struct device___400 *);
	int (*runtime_suspend)(struct device___400 *);
	int (*runtime_resume)(struct device___400 *);
	int (*runtime_idle)(struct device___400 *);
};

struct dev_pm_info___400 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___400 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___400;

struct bus_type___400;

struct device_driver___400;

struct dev_pm_domain___400;

struct dma_map_ops___172;

struct fwnode_handle___320;

struct class___400;

struct device___400 {
	struct device___400 *parent;
	struct device_private *p;
	struct kobject___420 kobj;
	const char *init_name;
	const struct device_type___400 *type;
	struct mutex mutex;
	struct bus_type___400 *bus;
	struct device_driver___400 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___400 power;
	struct dev_pm_domain___400 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___172 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___320 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___400 *class;
	const struct attribute_group___397 **groups;
	void (*release)(struct device___400 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___400 {
	struct dev_pm_ops___400 ops;
	void (*detach)(struct device___400 *, bool);
	int (*activate)(struct device___400 *);
	void (*sync)(struct device___400 *);
	void (*dismiss)(struct device___400 *);
};

struct bus_type___400 {
	const char *name;
	const char *dev_name;
	struct device___400 *dev_root;
	const struct attribute_group___397 **bus_groups;
	const struct attribute_group___397 **dev_groups;
	const struct attribute_group___397 **drv_groups;
	int (*match)(struct device___400 *, struct device_driver___400 *);
	int (*uevent)(struct device___400 *, struct kobj_uevent_env *);
	int (*probe)(struct device___400 *);
	int (*remove)(struct device___400 *);
	void (*shutdown)(struct device___400 *);
	int (*online)(struct device___400 *);
	int (*offline)(struct device___400 *);
	int (*suspend)(struct device___400 *, pm_message_t);
	int (*resume)(struct device___400 *);
	int (*num_vf)(struct device___400 *);
	int (*dma_configure)(struct device___400 *);
	const struct dev_pm_ops___400 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___400 {
	const char *name;
	struct bus_type___400 *bus;
	struct module___360 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___400 *);
	int (*remove)(struct device___400 *);
	void (*shutdown)(struct device___400 *);
	int (*suspend)(struct device___400 *, pm_message_t);
	int (*resume)(struct device___400 *);
	const struct attribute_group___397 **groups;
	const struct dev_pm_ops___400 *pm;
	void (*coredump)(struct device___400 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___400 {
	const char *name;
	const struct attribute_group___397 **groups;
	int (*uevent)(struct device___400 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___400 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___400 *);
	const struct dev_pm_ops___400 *pm;
};

struct class___400 {
	const char *name;
	struct module___360 *owner;
	const struct attribute_group___397 **class_groups;
	const struct attribute_group___397 **dev_groups;
	struct kobject___420 *dev_kobj;
	int (*dev_uevent)(struct device___400 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___400 *, umode_t *);
	void (*class_release)(struct class___400 *);
	void (*dev_release)(struct device___400 *);
	int (*shutdown_pre)(struct device___400 *);
	const struct kobj_ns_type_operations___57 *ns_type;
	const void * (*namespace)(struct device___400 *);
	const struct dev_pm_ops___400 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___172 {
	void * (*alloc)(struct device___400 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___400 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___400 *, struct vm_area_struct___433 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___400 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___400 *, struct page___433 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___400 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___400 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___400 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___400 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___400 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___400 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___400 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___400 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___400 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___400 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___400 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___400 *, u64);
	u64 (*get_required_mask)(struct device___400 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___320;

struct fwnode_handle___320 {
	struct fwnode_handle___320 *secondary;
	const struct fwnode_operations___320 *ops;
};

typedef void compound_page_dtor___420(struct page___433 *);

struct fwnode_reference_args___320;

struct fwnode_endpoint___320;

struct fwnode_operations___320 {
	struct fwnode_handle___320 * (*get)(struct fwnode_handle___320 *);
	void (*put)(struct fwnode_handle___320 *);
	bool (*device_is_available)(const struct fwnode_handle___320 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___320 *, const struct device___400 *);
	bool (*property_present)(const struct fwnode_handle___320 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___320 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___320 *, const char *, const char **, size_t);
	struct fwnode_handle___320 * (*get_parent)(const struct fwnode_handle___320 *);
	struct fwnode_handle___320 * (*get_next_child_node)(const struct fwnode_handle___320 *, struct fwnode_handle___320 *);
	struct fwnode_handle___320 * (*get_named_child_node)(const struct fwnode_handle___320 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___320 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___320 *);
	struct fwnode_handle___320 * (*graph_get_next_endpoint)(const struct fwnode_handle___320 *, struct fwnode_handle___320 *);
	struct fwnode_handle___320 * (*graph_get_remote_endpoint)(const struct fwnode_handle___320 *);
	struct fwnode_handle___320 * (*graph_get_port_parent)(struct fwnode_handle___320 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___320 *, struct fwnode_endpoint___320 *);
};

struct fwnode_endpoint___320 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___320 *local_fwnode;
};

struct fwnode_reference_args___320 {
	struct fwnode_handle___320 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___113;

struct pipe_buffer___113 {
	struct page___433 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___113 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___113 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___113 *, struct pipe_buffer___113 *);
	void (*release)(struct pipe_inode_info___113 *, struct pipe_buffer___113 *);
	int (*steal)(struct pipe_inode_info___113 *, struct pipe_buffer___113 *);
	union {
		bool (*get)(struct pipe_inode_info___113 *, struct pipe_buffer___113 *);
		struct {
			void (*get)(struct pipe_inode_info___113 *, struct pipe_buffer___113 *);
		} __UNIQUE_ID_rh_kabi_hide21;
		union {		};
	};
};

struct nf_bridge_info___77 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___77 = 0,
		BRNF_PROTO_8021Q___77 = 1,
		BRNF_PROTO_PPPOE___77 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___78 *physindev;
	struct net_device___78 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___77(struct sk_buff___79 **);

struct net_device_ops___77;

struct ethtool_ops___77;

struct l3mdev_ops___57;

struct xfrmdev_ops___77;

struct tlsdev_ops___77;

struct header_ops___77;

struct netdev_rx_queue___77;

struct mini_Qdisc___69;

struct netdev_queue___77;

struct Qdisc___69;

struct rtnl_link_ops___69;

struct dcbnl_rtnl_ops___77;

struct net_device___78 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___77 *netdev_ops;
	const struct ethtool_ops___77 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___57 *l3mdev_ops;
	const struct ndisc_ops___2 *ndisc_ops;
	const struct xfrmdev_ops___77 *xfrmdev_ops;
	const struct tlsdev_ops___77 *tlsdev_ops;
	const struct header_ops___77 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___419 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___2 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___77 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___67 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___77 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___69 *miniq_ingress;
	struct netdev_queue___77 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___77 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___69 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___69 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___77 = 0,
		NETREG_REGISTERED___77 = 1,
		NETREG_UNREGISTERING___77 = 2,
		NETREG_UNREGISTERED___77 = 3,
		NETREG_RELEASED___77 = 4,
		NETREG_DUMMY___77 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___77 = 0,
		RTNL_LINK_INITIALIZING___77 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___78 *);
	struct netpoll_info *npinfo;
	possible_net_t___79 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___400 dev;
	const struct attribute_group___397 *sysfs_groups[4];
	const struct attribute_group___397 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___69 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___77 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide35;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct ethtool_ops___77 {
	int (*get_settings)(struct net_device___78 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___78 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___78 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___78 *);
	void (*get_regs)(struct net_device___78 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___78 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___78 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___78 *);
	void (*set_msglevel)(struct net_device___78 *, u32);
	int (*nway_reset)(struct net_device___78 *);
	u32 (*get_link)(struct net_device___78 *);
	int (*get_eeprom_len)(struct net_device___78 *);
	int (*get_eeprom)(struct net_device___78 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___78 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___78 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___78 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___78 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___78 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___78 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___78 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___78 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___78 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___78 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___78 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___78 *);
	void (*complete)(struct net_device___78 *);
	u32 (*get_priv_flags)(struct net_device___78 *);
	int (*set_priv_flags)(struct net_device___78 *, u32);
	int (*get_sset_count)(struct net_device___78 *, int);
	int (*get_rxnfc)(struct net_device___78 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___78 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___78 *, struct ethtool_flash *);
	int (*reset)(struct net_device___78 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___78 *);
	u32 (*get_rxfh_indir_size)(struct net_device___78 *);
	int (*get_rxfh)(struct net_device___78 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___78 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___78 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___78 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___78 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___78 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___78 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___78 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___78 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___78 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___78 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___78 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___78 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___78 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___78 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___78 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___78 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___78 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___78 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___78 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___78 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___78 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	int (*get_fecparam)(struct net_device___78 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___78 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___78 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___78 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___78 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___77;

struct inet_frags___77 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___77 *, const void *);
	void (*destructor)(struct inet_frag_queue___77 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___77 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___79 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___79 *fragments_tail;
	struct sk_buff___79 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___77 *net;
	struct callback_head rcu;
};

struct fib_rule___57;

struct fib_lookup_arg___57;

struct fib_rules_ops___57 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___57 *, struct flowi *, int, struct fib_lookup_arg___57 *);
	bool (*suppress)(struct fib_rule___57 *, struct fib_lookup_arg___57 *);
	int (*match)(struct fib_rule___57 *, struct flowi *, int);
	int (*configure)(struct fib_rule___57 *, struct sk_buff___79 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___57 *);
	int (*compare)(struct fib_rule___57 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___57 *, struct sk_buff___79 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___57 *);
	void (*flush_cache)(struct fib_rules_ops___57 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___360 *owner;
	struct net___89 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___58 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___89 *);
	int (*fib_dump)(struct net___89 *, struct notifier_block *);
	struct module___360 *owner;
	struct callback_head rcu;
};

struct dst_entry___57 {
	struct net_device___78 *dev;
	struct dst_ops___88 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___79 *);
	int (*output)(struct net___89 *, struct sock___58 *, struct sk_buff___79 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___57;

struct neigh_parms___57;

struct neigh_ops___57;

struct neighbour___57 {
	struct neighbour___57 *next;
	struct neigh_table___57 *tbl;
	struct neigh_parms___57 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___77 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___57 *, struct sk_buff___79 *);
	const struct neigh_ops___57 *ops;
	struct callback_head rcu;
	struct net_device___78 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct ucounts___297 {
	struct hlist_node node;
	struct user_namespace___297 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_prog_aux___70;

struct bpf_prog___67 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___70 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

typedef int (*key_restrict_link_func_t___401)(struct key___400 *, const struct key_type *, const union key_payload *, struct key___400 *);

struct key_restriction___400;

struct key___400 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___434 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___400 *restrict_link;
};

struct key_restriction___400 {
	key_restrict_link_func_t___401 check;
	struct key___400 *key;
	struct key_type *keytype;
};

struct seq_operations___371 {
	void * (*start)(struct seq_file___371 *, loff_t *);
	void (*stop)(struct seq_file___371 *, void *);
	void * (*next)(struct seq_file___371 *, void *, loff_t *);
	int (*show)(struct seq_file___371 *, void *);
};

struct pernet_operations___78 {
	struct list_head list;
	int (*init)(struct net___89 *);
	void (*exit)(struct net___89 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___77 {
	int (*ieee_getets)(struct net_device___78 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___78 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___78 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___78 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___78 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___78 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___78 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___78 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___78 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___78 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___78 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___78 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___78 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___78 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___78 *);
	u8 (*setstate)(struct net_device___78 *, u8);
	void (*getpermhwaddr)(struct net_device___78 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___78 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___78 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___78 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___78 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___78 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___78 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___78 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___78 *, int, u8 *);
	void (*setpfccfg)(struct net_device___78 *, int, u8);
	void (*getpfccfg)(struct net_device___78 *, int, u8 *);
	u8 (*setall)(struct net_device___78 *);
	u8 (*getcap)(struct net_device___78 *, int, u8 *);
	int (*getnumtcs)(struct net_device___78 *, int, u8 *);
	int (*setnumtcs)(struct net_device___78 *, int, u8);
	u8 (*getpfcstate)(struct net_device___78 *);
	void (*setpfcstate)(struct net_device___78 *, u8);
	void (*getbcncfg)(struct net_device___78 *, int, u32 *);
	void (*setbcncfg)(struct net_device___78 *, int, u32);
	void (*getbcnrp)(struct net_device___78 *, int, u8 *);
	void (*setbcnrp)(struct net_device___78 *, int, u8);
	int (*setapp)(struct net_device___78 *, u8, u16, u8);
	int (*getapp)(struct net_device___78 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___78 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___78 *, int, u8);
	u8 (*getdcbx)(struct net_device___78 *);
	u8 (*setdcbx)(struct net_device___78 *, u8);
	int (*peer_getappinfo)(struct net_device___78 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___78 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___78 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___78 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___78 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___78 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___281 {
	refcount_t count;
	struct ns_common___29 ns;
	struct user_namespace___297 *user_ns;
	struct ucounts___297 *ucounts;
	struct css_set___281 *root_cset;
};

struct bpf_map___282;

struct bpf_map_ops___281 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___282 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___282 *, struct file___432 *);
	void (*map_free)(struct bpf_map___282 *);
	int (*map_get_next_key)(struct bpf_map___282 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___282 *);
	void * (*map_lookup_elem)(struct bpf_map___282 *, void *);
	int (*map_update_elem)(struct bpf_map___282 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___282 *, void *);
	int (*map_push_elem)(struct bpf_map___282 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___282 *, void *);
	int (*map_peek_elem)(struct bpf_map___282 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___282 *, struct file___432 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___282 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___282 *, void *, struct seq_file___371 *);
	int (*map_check_btf)(const struct bpf_map___282 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___282 {
	const struct bpf_map_ops___281 *ops;
	struct bpf_map___282 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___400 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___77;

struct bpf_map_dev_ops___77 {
	int (*map_get_next_key)(struct bpf_offloaded_map___77 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___77 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___77 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___77 *, void *);
};

struct bpf_offloaded_map___77 {
	struct bpf_map___282 map;
	struct net_device___78 *netdev;
	const struct bpf_map_dev_ops___77 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___67 {
	int (*test_run)(struct bpf_prog___67 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___67 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___67 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___67 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___67 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___67 *, u32 *);
};

struct bpf_prog_offload_ops___67 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___67 *);
	int (*translate)(struct bpf_prog___67 *);
	void (*destroy)(struct bpf_prog___67 *);
};

struct bpf_prog_offload___67 {
	struct bpf_prog___67 *prog;
	struct net_device___78 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___67 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___70 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___67 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___67 *ops;
	struct bpf_map___282 **used_maps;
	struct bpf_prog___67 *prog;
	struct user_struct___400 *user;
	u64 load_time;
	struct bpf_map___282 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___67 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___67 {
	struct bpf_prog___67 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___67 {
	struct callback_head rcu;
	struct bpf_prog_array_item___67 items[0];
};

struct cgroup_bpf___67 {
	struct bpf_prog_array___67 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___67 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___282;

typedef void (*kthread_work_func_t___282)(struct kthread_work___282 *);

struct kthread_worker___282;

struct kthread_work___282 {
	struct list_head node;
	kthread_work_func_t___282 func;
	struct kthread_worker___282 *worker;
	int canceling;
};

struct kthread_worker___282 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___434 *task;
	struct kthread_work___282 *current_work;
};

struct kthread_delayed_work___281 {
	struct kthread_work___282 work;
	struct timer_list timer;
};

struct psi_group___281 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___282 *poll_kworker;
	struct kthread_delayed_work___281 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___281;

struct cgroup_rstat_cpu___281;

struct cgroup___281 {
	struct cgroup_subsys_state___281 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___427 *kn;
	struct cgroup_file___281 procs_file;
	struct cgroup_file___281 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___281 *subsys[13];
	struct cgroup_root___281 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___281 *dom_cgrp;
	struct cgroup_rstat_cpu___281 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___67 bpf;
	atomic_t congestion_count;
	struct cgroup___281 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___281 psi;
	int ancestor_ids[0];
};

struct cftype___281;

struct cgroup_subsys___281 {
	struct cgroup_subsys_state___281 * (*css_alloc)(struct cgroup_subsys_state___281 *);
	int (*css_online)(struct cgroup_subsys_state___281 *);
	void (*css_offline)(struct cgroup_subsys_state___281 *);
	void (*css_released)(struct cgroup_subsys_state___281 *);
	void (*css_free)(struct cgroup_subsys_state___281 *);
	void (*css_reset)(struct cgroup_subsys_state___281 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___281 *, int);
	int (*css_extra_stat_show)(struct seq_file___371 *, struct cgroup_subsys_state___281 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___434 *);
	void (*cancel_fork)(struct task_struct___434 *);
	void (*fork)(struct task_struct___434 *);
	void (*exit)(struct task_struct___434 *);
	void (*free)(struct task_struct___434 *);
	void (*bind)(struct cgroup_subsys_state___281 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___281 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___281 *dfl_cftypes;
	struct cftype___281 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___281 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___281 *updated_children;
	struct cgroup___281 *updated_next;
};

struct cgroup_root___281 {
	struct kernfs_root___426 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___281 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___281 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___281 *ss;
	struct list_head node;
	struct kernfs_ops___426 *kf_ops;
	int (*open)(struct kernfs_open_file___426 *);
	void (*release)(struct kernfs_open_file___426 *);
	u64 (*read_u64)(struct cgroup_subsys_state___281 *, struct cftype___281 *);
	s64 (*read_s64)(struct cgroup_subsys_state___281 *, struct cftype___281 *);
	int (*seq_show)(struct seq_file___371 *, void *);
	void * (*seq_start)(struct seq_file___371 *, loff_t *);
	void * (*seq_next)(struct seq_file___371 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___371 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___281 *, struct cftype___281 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___281 *, struct cftype___281 *, s64);
	ssize_t (*write)(struct kernfs_open_file___426 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___426 *, struct poll_table_struct___271 *);
};

struct xdp_rxq_info___77 {
	struct net_device___78 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___77 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___78 *dev_rx;
};

struct netlink_callback___79 {
	struct sk_buff___79 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___79 *);
	int (*dump)(struct sk_buff___79 *, struct netlink_callback___79 *);
	int (*done)(struct netlink_callback___79 *);
	void *data;
	struct module___360 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

enum {
	TCA_CGROUP_UNSPEC = 0,
	TCA_CGROUP_ACT = 1,
	TCA_CGROUP_POLICE = 2,
	TCA_CGROUP_EMATCHES = 3,
	__TCA_CGROUP_MAX = 4,
};

struct tcf_ematch_tree_hdr {
	__u16 nmatches;
	__u16 progid;
};

struct header_ops___77 {
	int (*create)(struct sk_buff___79 *, struct net_device___78 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___79 *, unsigned char *);
	int (*cache)(const struct neighbour___57 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___78 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___77 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___77 *, int);
	int poll_owner;
	struct net_device___78 *dev;
	struct sk_buff___79 *gro_list;
	struct sk_buff___79 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___77 {
	struct net_device___78 *dev;
	struct Qdisc___69 *qdisc;
	struct Qdisc___69 *qdisc_sleeping;
	struct kobject___420 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___78 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem___3 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___69 {
	struct sk_buff___79 *head;
	struct sk_buff___79 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___69;

struct Qdisc___69 {
	int (*enqueue)(struct sk_buff___79 *, struct Qdisc___69 *, struct sk_buff___79 **);
	struct sk_buff___79 * (*dequeue)(struct Qdisc___69 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___69 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___77 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___77 gso_skb;
	struct qdisc_skb_head___69 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___69 *next_sched;
	struct sk_buff_head___77 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___77 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___420 kobj;
	struct net_device___78 *dev;
	long: 64;
	struct xdp_rxq_info___77 xdp_rxq;
	union {
		struct xdp_umem___3 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___77)(struct net_device___78 *, struct sk_buff___79 *, struct net_device___78 *);

struct netdev_bpf___77 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___67 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___67 *prog;
			const struct bpf_prog_offload_ops___67 *ops;
		} verifier;
		struct {
			struct bpf_prog___67 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___77 *offmap;
		};
		struct {
			struct xdp_umem___3 *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___77 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___79 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___77 {
	int (*tls_dev_add)(struct net_device___78 *, struct sock___58 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___78 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___78 *, struct sock___58 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___77 {
	int (*ndo_init)(struct net_device___78 *);
	void (*ndo_uninit)(struct net_device___78 *);
	int (*ndo_open)(struct net_device___78 *);
	int (*ndo_stop)(struct net_device___78 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___79 *, struct net_device___78 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___79 *, struct net_device___78 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___78 *, struct sk_buff___79 *, struct net_device___78 *, select_queue_fallback_t___77);
	void (*ndo_change_rx_flags)(struct net_device___78 *, int);
	void (*ndo_set_rx_mode)(struct net_device___78 *);
	int (*ndo_set_mac_address)(struct net_device___78 *, void *);
	int (*ndo_validate_addr)(struct net_device___78 *);
	int (*ndo_do_ioctl)(struct net_device___78 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___78 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___78 *, int);
	int (*ndo_neigh_setup)(struct net_device___78 *, struct neigh_parms___57 *);
	void (*ndo_tx_timeout)(struct net_device___78 *);
	void (*ndo_get_stats64)(struct net_device___78 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___78 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___78 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___78 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___78 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___78 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___78 *);
	int (*ndo_netpoll_setup)(struct net_device___78 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___78 *);
	int (*ndo_set_vf_mac)(struct net_device___78 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___78 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___78 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___78 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___78 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___78 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___78 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___78 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___78 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___78 *, int, struct sk_buff___79 *);
	int (*ndo_set_vf_guid)(struct net_device___78 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___78 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___78 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___78 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___78 *, const struct sk_buff___79 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___78 *, struct net_device___78 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___78 *, struct net_device___78 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___78 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___78 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___78 *, struct neighbour___57 *);
	void (*ndo_neigh_destroy)(struct net_device___78 *, struct neighbour___57 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___78 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___78 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___78 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___79 *, struct netlink_callback___79 *, struct net_device___78 *, struct net_device___78 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___78 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___78 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___79 *, u32, u32, struct net_device___78 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___78 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___78 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___78 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___78 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___78 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___78 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___78 *, struct net_device___78 *);
	void (*ndo_dfwd_del_station)(struct net_device___78 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___78 *);
	int (*ndo_set_tx_maxrate)(struct net_device___78 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___78 *);
	int (*ndo_change_proto_down)(struct net_device___78 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___78 *, struct sk_buff___79 *);
	void (*ndo_set_rx_headroom)(struct net_device___78 *, int);
	int (*ndo_bpf)(struct net_device___78 *, struct netdev_bpf___77 *);
	int (*ndo_xdp_xmit)(struct net_device___78 *, int, struct xdp_frame___77 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___78 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___78 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___57 {
	possible_net_t___79 net;
	struct net_device___78 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___57 *);
	void (*neigh_cleanup)(struct neighbour___57 *);
	struct neigh_table___57 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___57 {
	u32 (*l3mdev_fib_table)(const struct net_device___78 *);
	struct sk_buff___79 * (*l3mdev_l3_rcv)(struct net_device___78 *, struct sk_buff___79 *, u16);
	struct sk_buff___79 * (*l3mdev_l3_out)(struct net_device___78 *, struct sock___58 *, struct sk_buff___79 *, u16);
	struct dst_entry___57 * (*l3mdev_link_scope_lookup)(const struct net_device___78 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct tcf_proto___69;

struct mini_Qdisc___69 {
	struct tcf_proto___69 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___69 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___78 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___89 *, struct net_device___78 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___78 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___78 *, struct list_head *);
	size_t (*get_size)(const struct net_device___78 *);
	int (*fill_info)(struct sk_buff___79 *, const struct net_device___78 *);
	size_t (*get_xstats_size)(const struct net_device___78 *);
	int (*fill_xstats)(struct sk_buff___79 *, const struct net_device___78 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___78 *, struct net_device___78 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___78 *, const struct net_device___78 *);
	int (*fill_slave_info)(struct sk_buff___79 *, const struct net_device___78 *, const struct net_device___78 *);
	struct net___89 * (*get_link_net)(const struct net_device___78 *);
	size_t (*get_linkxstats_size)(const struct net_device___78 *, int);
	int (*fill_linkxstats)(struct sk_buff___79 *, const struct net_device___78 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___77 {
	struct list_head poll_list;
	struct sk_buff_head___77 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___77 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___69 *output_queue;
	struct Qdisc___69 **output_queue_tailp;
	struct sk_buff___79 *completion_queue;
	struct sk_buff_head___77 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___77 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___77 input_pkt_queue;
	struct napi_struct___77 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct gnet_dump___69 {
	spinlock_t *lock;
	struct sk_buff___79 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___69;

struct Qdisc_ops___69 {
	struct Qdisc_ops___69 *next;
	const struct Qdisc_class_ops___69 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___79 *, struct Qdisc___69 *, struct sk_buff___79 **);
	struct sk_buff___79 * (*dequeue)(struct Qdisc___69 *);
	struct sk_buff___79 * (*peek)(struct Qdisc___69 *);
	int (*init)(struct Qdisc___69 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___69 *);
	void (*destroy)(struct Qdisc___69 *);
	int (*change)(struct Qdisc___69 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___69 *);
	int (*change_tx_queue_len)(struct Qdisc___69 *, unsigned int);
	int (*dump)(struct Qdisc___69 *, struct sk_buff___79 *);
	int (*dump_stats)(struct Qdisc___69 *, struct gnet_dump___69 *);
	void (*ingress_block_set)(struct Qdisc___69 *, u32);
	void (*egress_block_set)(struct Qdisc___69 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___69 *);
	u32 (*egress_block_get)(struct Qdisc___69 *);
	struct module___360 *owner;
};

struct qdisc_walker___13;

struct tcf_block___69;

struct Qdisc_class_ops___69 {
	unsigned int flags;
	struct netdev_queue___77 * (*select_queue)(struct Qdisc___69 *, struct tcmsg *);
	int (*graft)(struct Qdisc___69 *, long unsigned int, struct Qdisc___69 *, struct Qdisc___69 **, struct netlink_ext_ack *);
	struct Qdisc___69 * (*leaf)(struct Qdisc___69 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___69 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___69 *, u32);
	int (*change)(struct Qdisc___69 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___69 *, long unsigned int);
	void (*walk)(struct Qdisc___69 *, struct qdisc_walker___13 *);
	struct tcf_block___69 * (*tcf_block)(struct Qdisc___69 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___69 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___69 *, long unsigned int);
	int (*dump)(struct Qdisc___69 *, long unsigned int, struct sk_buff___79 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___69 *, long unsigned int, struct gnet_dump___69 *);
};

struct qdisc_walker___13 {
	int stop;
	int skip;
	int count;
	int (*fn)(struct Qdisc___69 *, long unsigned int, struct qdisc_walker___13 *);
};

struct tcf_chain___69;

struct tcf_block___69 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___89 *net;
	struct Qdisc___69 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___69 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___69;

struct tcf_proto_ops___69;

struct tcf_proto___69 {
	struct tcf_proto___69 *next;
	void *root;
	int (*classify)(struct sk_buff___79 *, const struct tcf_proto___69 *, struct tcf_result___69 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___69 *ops;
	struct tcf_chain___69 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___69 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___69 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_walker___8;

struct tcf_proto_ops___69 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___79 *, const struct tcf_proto___69 *, struct tcf_result___69 *);
	int (*init)(struct tcf_proto___69 *);
	void (*destroy)(struct tcf_proto___69 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___69 *, u32);
	void (*put)(struct tcf_proto___69 *, void *);
	int (*change)(struct net___89 *, struct sk_buff___79 *, struct tcf_proto___69 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___69 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___69 *, struct tcf_walker___8 *, bool);
	int (*reoffload)(struct tcf_proto___69 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___89 *, struct tcf_chain___69 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___89 *, struct tcf_proto___69 *, void *, struct sk_buff___79 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___79 *, struct net___89 *, void *);
	struct module___360 *owner;
	int flags;
};

struct tcf_walker___8 {
	int stop;
	int skip;
	int count;
	bool nonempty;
	long unsigned int cookie;
	int (*fn)(struct tcf_proto___69 *, void *, struct tcf_walker___8 *);
};

struct tcf_chain___69 {
	struct mutex filter_chain_lock;
	struct tcf_proto___69 *filter_chain;
	struct list_head list;
	struct tcf_block___69 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___69 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct tc_action_ops___3;

struct tc_action___3 {
	const struct tc_action_ops___3 *ops;
	__u32 type;
	__u32 order;
	struct tcf_idrinfo *idrinfo;
	u32 tcfa_index;
	refcount_t tcfa_refcnt;
	atomic_t tcfa_bindcnt;
	int tcfa_action;
	struct tcf_t tcfa_tm;
	struct gnet_stats_basic_packed tcfa_bstats;
	struct gnet_stats_basic_packed tcfa_bstats_hw;
	struct gnet_stats_queue tcfa_qstats;
	int: 32;
	struct net_rate_estimator *tcfa_rate_est;
	spinlock_t tcfa_lock;
	int: 32;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_basic_cpu *cpu_bstats_hw;
	struct gnet_stats_queue *cpu_qstats;
	struct tc_cookie *act_cookie;
	struct tcf_chain___69 *goto_chain;
} __attribute__((packed));

struct tc_action_ops___3 {
	struct list_head head;
	char kind[16];
	enum tca_id id;
	size_t size;
	struct module___360 *owner;
	int (*act)(struct sk_buff___79 *, const struct tc_action___3 *, struct tcf_result___69 *);
	int (*dump)(struct sk_buff___79 *, struct tc_action___3 *, int, int);
	void (*cleanup)(struct tc_action___3 *);
	int (*lookup)(struct net___89 *, struct tc_action___3 **, u32);
	int (*init)(struct net___89 *, struct nlattr *, struct nlattr *, struct tc_action___3 **, int, int, bool, struct tcf_proto___69 *, struct netlink_ext_ack *);
	int (*walk)(struct net___89 *, struct sk_buff___79 *, struct netlink_callback___79 *, int, const struct tc_action_ops___3 *, struct netlink_ext_ack *);
	void (*stats_update)(struct tc_action___3 *, u64, u32, u64, bool);
	size_t (*get_fill_size)(const struct tc_action___3 *);
	struct net_device___78 * (*get_dev)(const struct tc_action___3 *);
	void (*put_dev)(struct net_device___78 *);
};

struct tcf_exts___2 {
	__u32 type;
	int nr_actions;
	struct tc_action___3 **actions;
	struct net___89 *net;
	int action;
	int police;
};

struct tcf_pkt_info {
	unsigned char *ptr;
	int nexthdr;
};

struct tcf_ematch_ops;

struct tcf_ematch {
	struct tcf_ematch_ops *ops;
	long unsigned int data;
	unsigned int datalen;
	u16 matchid;
	u16 flags;
	struct net___89 *net;
};

struct tcf_ematch_ops {
	int kind;
	int datalen;
	int (*change)(struct net___89 *, void *, int, struct tcf_ematch *);
	int (*match)(struct sk_buff___79 *, struct tcf_ematch *, struct tcf_pkt_info *);
	void (*destroy)(struct tcf_ematch *);
	int (*dump)(struct sk_buff___79 *, struct tcf_ematch *);
	struct module___360 *owner;
	struct list_head link;
};

struct tcf_ematch_tree {
	struct tcf_ematch_tree_hdr hdr;
	struct tcf_ematch *matches;
};

struct bdi_writeback_congested___222 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___222 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___222 {
	struct bio___222 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___224 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___224 bip_inline_vecs[0];
};

struct bio_set___222 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___222 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___165 {
	struct mem_cgroup___165 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___165 {
	struct lruvec___433 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___165 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___165 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct sk_filter___57 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___67 *prog;
};

struct bpf_redirect_info___67 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___282 *map;
	struct bpf_map___282 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___57;

struct neigh_hash_table___57;

struct neigh_table___57 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___78 *, __u32 *);
	bool (*key_eq)(const struct neighbour___57 *, const void *);
	int (*constructor)(struct neighbour___57 *);
	int (*pconstructor)(struct pneigh_entry___57 *);
	void (*pdestructor)(struct pneigh_entry___57 *);
	void (*proxy_redo)(struct sk_buff___79 *);
	char *id;
	struct neigh_parms___57 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___77 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___57 *nht;
	struct pneigh_entry___57 **phash_buckets;
};

struct neigh_ops___57 {
	int family;
	void (*solicit)(struct neighbour___57 *, struct sk_buff___79 *);
	void (*error_report)(struct neighbour___57 *, struct sk_buff___79 *);
	int (*output)(struct neighbour___57 *, struct sk_buff___79 *);
	int (*connected_output)(struct neighbour___57 *, struct sk_buff___79 *);
};

struct pneigh_entry___57 {
	struct pneigh_entry___57 *next;
	possible_net_t___79 net;
	struct net_device___78 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___57 {
	struct neighbour___57 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___57 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___57 *ctarget;
	struct net___89 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___57 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___57 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___40;

struct proto___57 {
	void (*close)(struct sock___58 *, long int);
	int (*pre_connect)(struct sock___58 *, struct sockaddr *, int);
	int (*connect)(struct sock___58 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___58 *, int);
	struct sock___58 * (*accept)(struct sock___58 *, int, int *, bool);
	int (*ioctl)(struct sock___58 *, int, long unsigned int);
	int (*init)(struct sock___58 *);
	void (*destroy)(struct sock___58 *);
	void (*shutdown)(struct sock___58 *, int);
	int (*setsockopt)(struct sock___58 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___58 *, int, int, char *, int *);
	void (*keepalive)(struct sock___58 *, int);
	int (*sendmsg)(struct sock___58 *, struct msghdr___60 *, size_t);
	int (*recvmsg)(struct sock___58 *, struct msghdr___60 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___58 *, struct page___433 *, int, size_t, int);
	int (*bind)(struct sock___58 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___58 *, struct sk_buff___79 *);
	void (*release_cb)(struct sock___58 *);
	int (*hash)(struct sock___58 *);
	void (*unhash)(struct sock___58 *);
	void (*rehash)(struct sock___58 *);
	int (*get_port)(struct sock___58 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___58 *);
	bool (*stream_memory_read)(const struct sock___58 *);
	void (*enter_memory_pressure)(struct sock___58 *);
	void (*leave_memory_pressure)(struct sock___58 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___40 *rsk_prot;
	struct timewait_sock_ops___3 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___360 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___58 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct request_sock___41;

struct request_sock_ops___40 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___58 *, struct request_sock___41 *);
	void (*send_ack)(const struct sock___58 *, struct sk_buff___79 *, struct request_sock___41 *);
	void (*send_reset)(const struct sock___58 *, struct sk_buff___79 *);
	void (*destructor)(struct request_sock___41 *);
	void (*syn_ack_timeout)(const struct request_sock___41 *);
};

struct request_sock___41 {
	struct sock_common___57 __req_common;
	struct request_sock___41 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___40 *rsk_ops;
	struct sock___58 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct cls_cgroup_head {
	u32 handle;
	struct tcf_exts___2 exts;
	struct tcf_ematch_tree ematches;
	struct tcf_proto___69 *tp;
	struct rcu_work rwork;
};

enum {
	TCA_EMATCH_TREE_UNSPEC = 0,
	TCA_EMATCH_TREE_HDR = 1,
	TCA_EMATCH_TREE_LIST = 2,
	__TCA_EMATCH_TREE_MAX = 3,
};

struct tcf_ematch_hdr {
	__u16 matchid;
	__u16 kind;
	__u16 flags;
	__u16 pad;
};

struct net_proto_family___3 {
	int family;
	int (*create)(struct net___81 *, struct socket___53 *, int, int);
	struct module___354 *owner;
};

struct seq_net_private___4 {
	struct net___81 *net;
};

struct sockaddr_nl {
	__kernel_sa_family_t nl_family;
	short unsigned int nl_pad;
	__u32 nl_pid;
	__u32 nl_groups;
};

struct nlmsgerr {
	int error;
	struct nlmsghdr msg;
};

enum nlmsgerr_attrs {
	NLMSGERR_ATTR_UNUSED = 0,
	NLMSGERR_ATTR_MSG = 1,
	NLMSGERR_ATTR_OFFS = 2,
	NLMSGERR_ATTR_COOKIE = 3,
	__NLMSGERR_ATTR_MAX = 4,
	NLMSGERR_ATTR_MAX = 3,
};

struct nl_pktinfo {
	__u32 group;
};

enum {
	NETLINK_UNCONNECTED = 0,
	NETLINK_CONNECTED = 1,
};

enum netlink_skb_flags {
	NETLINK_SKB_DST = 8,
};

struct netlink_kernel_cfg___6 {
	unsigned int groups;
	unsigned int flags;
	void (*input)(struct sk_buff___71 *);
	struct mutex *cb_mutex;
	int (*bind)(struct net___81 *, int);
	void (*unbind)(struct net___81 *, int);
	bool (*compare)(struct net___81 *, struct sock___52 *);
};

struct netlink_notify {
	struct net___81 *net;
	u32 portid;
	int protocol;
};

struct netlink_dump_control___2 {
	int (*start)(struct netlink_callback___71 *);
	int (*dump)(struct sk_buff___71 *, struct netlink_callback___71 *);
	int (*done)(struct netlink_callback___71 *);
	void *data;
	struct module___354 *module;
	u16 min_dump_alloc;
};

struct netlink_tap {
	struct net_device___70 *dev;
	struct module___354 *module;
	struct list_head list;
};

struct socket_alloc___4 {
	struct socket___53 socket;
	struct inode___424 vfs_inode;
};

struct netlink_sock {
	struct sock___52 sk;
	u32 portid;
	u32 dst_portid;
	u32 dst_group;
	u32 flags;
	u32 subscriptions;
	u32 ngroups;
	long unsigned int *groups;
	long unsigned int state;
	size_t max_recvmsg_len;
	wait_queue_head_t wait;
	bool bound;
	bool cb_running;
	int dump_done_errno;
	struct netlink_callback___71 cb;
	struct mutex *cb_mutex;
	struct mutex cb_def_mutex;
	void (*netlink_rcv)(struct sk_buff___71 *);
	int (*netlink_bind)(struct net___81 *, int);
	void (*netlink_unbind)(struct net___81 *, int);
	struct module___354 *module;
	struct rhash_head node;
	struct callback_head rcu;
	struct work_struct work;
};

struct listeners;

struct netlink_table {
	struct rhashtable hash;
	struct hlist_head mc_list;
	struct listeners *listeners;
	unsigned int flags;
	unsigned int groups;
	struct mutex *cb_mutex;
	struct module___354 *module;
	int (*bind)(struct net___81 *, int);
	void (*unbind)(struct net___81 *, int);
	bool (*compare)(struct net___81 *, struct sock___52 *);
	int registered;
};

struct listeners {
	struct callback_head rcu;
	long unsigned int masks[0];
};

struct netlink_tap_net {
	struct list_head netlink_tap_all;
	struct mutex netlink_tap_lock;
};

struct netlink_compare_arg {
	possible_net_t___71 pnet;
	u32 portid;
};

struct netlink_broadcast_data {
	struct sock___52 *exclude_sk;
	struct net___81 *net;
	u32 portid;
	u32 group;
	int failure;
	int delivery_failure;
	int congested;
	int delivered;
	gfp_t allocation;
	struct sk_buff___71 *skb;
	struct sk_buff___71 *skb2;
	int (*tx_filter)(struct sock___52 *, struct sk_buff___71 *, void *);
	void *tx_data;
};

struct netlink_set_err_data {
	struct sock___52 *exclude_sk;
	u32 portid;
	u32 group;
	int code;
};

struct nl_seq_iter {
	struct seq_net_private___4 p;
	struct rhashtable_iter hti;
	int link;
};

enum {
	CTRL_CMD_UNSPEC = 0,
	CTRL_CMD_NEWFAMILY = 1,
	CTRL_CMD_DELFAMILY = 2,
	CTRL_CMD_GETFAMILY = 3,
	CTRL_CMD_NEWOPS = 4,
	CTRL_CMD_DELOPS = 5,
	CTRL_CMD_GETOPS = 6,
	CTRL_CMD_NEWMCAST_GRP = 7,
	CTRL_CMD_DELMCAST_GRP = 8,
	CTRL_CMD_GETMCAST_GRP = 9,
	__CTRL_CMD_MAX = 10,
};

enum {
	CTRL_ATTR_UNSPEC = 0,
	CTRL_ATTR_FAMILY_ID = 1,
	CTRL_ATTR_FAMILY_NAME = 2,
	CTRL_ATTR_VERSION = 3,
	CTRL_ATTR_HDRSIZE = 4,
	CTRL_ATTR_MAXATTR = 5,
	CTRL_ATTR_OPS = 6,
	CTRL_ATTR_MCAST_GROUPS = 7,
	__CTRL_ATTR_MAX = 8,
};

enum {
	CTRL_ATTR_OP_UNSPEC = 0,
	CTRL_ATTR_OP_ID = 1,
	CTRL_ATTR_OP_FLAGS = 2,
	__CTRL_ATTR_OP_MAX = 3,
};

enum {
	CTRL_ATTR_MCAST_GRP_UNSPEC = 0,
	CTRL_ATTR_MCAST_GRP_NAME = 1,
	CTRL_ATTR_MCAST_GRP_ID = 2,
	__CTRL_ATTR_MCAST_GRP_MAX = 3,
};

struct module___361;

struct file___433;

struct kiocb___433;

struct iov_iter___200;

struct poll_table_struct___272;

struct vm_area_struct___434;

struct inode___433;

struct file_lock___433;

struct page___434;

struct pipe_inode_info___114;

struct seq_file___372;

struct file_operations___433 {
	struct module___361 *owner;
	loff_t (*llseek)(struct file___433 *, loff_t, int);
	ssize_t (*read)(struct file___433 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___433 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___433 *, struct iov_iter___200 *);
	ssize_t (*write_iter)(struct kiocb___433 *, struct iov_iter___200 *);
	int (*iopoll)(struct kiocb___433 *, bool);
	int (*iterate)(struct file___433 *, struct dir_context *);
	int (*iterate_shared)(struct file___433 *, struct dir_context *);
	__poll_t (*poll)(struct file___433 *, struct poll_table_struct___272 *);
	long int (*unlocked_ioctl)(struct file___433 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___433 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___433 *, struct vm_area_struct___434 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___433 *, struct file___433 *);
	int (*flush)(struct file___433 *, fl_owner_t);
	int (*release)(struct inode___433 *, struct file___433 *);
	int (*fsync)(struct file___433 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___433 *, int);
	int (*lock)(struct file___433 *, int, struct file_lock___433 *);
	ssize_t (*sendpage)(struct file___433 *, struct page___434 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___433 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___433 *, int, struct file_lock___433 *);
	ssize_t (*splice_write)(struct pipe_inode_info___114 *, struct file___433 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___433 *, loff_t *, struct pipe_inode_info___114 *, size_t, unsigned int);
	int (*setlease)(struct file___433 *, long int, struct file_lock___433 **, void **);
	long int (*fallocate)(struct file___433 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___372 *, struct file___433 *);
	ssize_t (*copy_file_range)(struct file___433 *, loff_t, struct file___433 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___433 *, loff_t, struct file___433 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___433 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___434 {
	u64 seqnum;
	struct vm_area_struct___434 *vmas[4];
};

struct page_frag___434 {
	struct page___434 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___434;

struct mem_cgroup___166;

struct cred___401;

struct nsproxy___328;

struct signal_struct___308;

struct bio_list___223;

struct backing_dev_info___223;

struct css_set___282;

struct vm_struct___337;

struct task_struct___435 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___435 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___434 *mm;
	struct mm_struct___434 *active_mm;
	struct vmacache___434 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___435 *real_parent;
	struct task_struct___435 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___435 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___166 *active_memcg;
	long int rh_reserved2;
	struct pid___241 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___241 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___241 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___401 *ptracer_cred;
	const struct cred___401 *real_cred;
	const struct cred___401 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___328 *nsproxy;
	struct signal_struct___308 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___435 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___223 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___223 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___282 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___114 *splice_pipe;
	struct page_frag___434 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___166 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___435 *oom_reaper_list;
	struct vm_struct___337 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___156 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct secondary_data___435 {
	void *stack;
	struct task_struct___435 *task;
	long int status;
};

struct dentry___433;

struct path___434 {
	struct vfsmount *mnt;
	struct dentry___433 *dentry;
};

struct address_space___433;

struct file___433 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___434 f_path;
	struct inode___433 *f_inode;
	const struct file_operations___433 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___241 f_owner;
	const struct cred___401 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___433 *f_mapping;
	errseq_t f_wb_err;
};

struct bpf_map___283;

struct bpf_map_ops___282 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___283 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___283 *, struct file___433 *);
	void (*map_free)(struct bpf_map___283 *);
	int (*map_get_next_key)(struct bpf_map___283 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___283 *);
	void * (*map_lookup_elem)(struct bpf_map___283 *, void *);
	int (*map_update_elem)(struct bpf_map___283 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___283 *, void *);
	int (*map_push_elem)(struct bpf_map___283 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___283 *, void *);
	int (*map_peek_elem)(struct bpf_map___283 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___283 *, struct file___433 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___283 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___283 *, void *, struct seq_file___372 *);
	int (*map_check_btf)(const struct bpf_map___283 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct user_struct___401;

struct bpf_map___283 {
	const struct bpf_map_ops___282 *ops;
	struct bpf_map___283 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___401 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct seq_operations___372;

struct seq_file___372 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___372 *op;
	int poll_event;
	const struct file___433 *file;
	void *private;
};

struct key___401;

struct user_struct___401 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___401 *uid_keyring;
	struct key___401 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bpf_offloaded_map___78;

struct bpf_map_dev_ops___78 {
	int (*map_get_next_key)(struct bpf_offloaded_map___78 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___78 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___78 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___78 *, void *);
};

struct net_device___79;

struct bpf_offloaded_map___78 {
	struct bpf_map___283 map;
	struct net_device___79 *netdev;
	const struct bpf_map_dev_ops___78 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___80;

typedef rx_handler_result_t rx_handler_func_t___78(struct sk_buff___80 **);

struct net___90;

typedef struct {
	struct net___90 *net;
} possible_net_t___80;

struct kset___420;

struct kobj_type___420;

struct kernfs_node___428;

struct kobject___421 {
	const char *name;
	struct list_head entry;
	struct kobject___421 *parent;
	struct kset___420 *kset;
	struct kobj_type___420 *ktype;
	struct kernfs_node___428 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___401;

struct dev_pm_info___401 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___401 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___401;

struct bus_type___401;

struct device_driver___401;

struct dev_pm_domain___401;

struct dma_map_ops___173;

struct fwnode_handle___321;

struct class___401;

struct attribute_group___398;

struct device___401 {
	struct device___401 *parent;
	struct device_private *p;
	struct kobject___421 kobj;
	const char *init_name;
	const struct device_type___401 *type;
	struct mutex mutex;
	struct bus_type___401 *bus;
	struct device_driver___401 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___401 power;
	struct dev_pm_domain___401 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___173 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___321 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___401 *class;
	const struct attribute_group___398 **groups;
	void (*release)(struct device___401 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct net_device_ops___78;

struct ethtool_ops___78;

struct l3mdev_ops___58;

struct ndisc_ops___33;

struct xfrmdev_ops___78;

struct tlsdev_ops___78;

struct header_ops___78;

struct inet6_dev___33;

struct netdev_rx_queue___78;

struct bpf_prog___68;

struct mini_Qdisc___70;

struct netdev_queue___78;

struct Qdisc___70;

struct rtnl_link_ops___70;

struct dcbnl_rtnl_ops___78;

struct net_device___79 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___78 *netdev_ops;
	const struct ethtool_ops___78 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___58 *l3mdev_ops;
	const struct ndisc_ops___33 *ndisc_ops;
	const struct xfrmdev_ops___78 *xfrmdev_ops;
	const struct tlsdev_ops___78 *tlsdev_ops;
	const struct header_ops___78 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___420 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___33 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___78 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___68 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___78 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___70 *miniq_ingress;
	struct netdev_queue___78 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___78 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___70 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___70 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___78 = 0,
		NETREG_REGISTERED___78 = 1,
		NETREG_UNREGISTERING___78 = 2,
		NETREG_UNREGISTERED___78 = 3,
		NETREG_RELEASED___78 = 4,
		NETREG_DUMMY___78 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___78 = 0,
		RTNL_LINK_INITIALIZING___78 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___79 *);
	struct netpoll_info *npinfo;
	possible_net_t___80 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___401 dev;
	const struct attribute_group___398 *sysfs_groups[4];
	const struct attribute_group___398 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___70 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___78 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct bpf_prog_ops___68 {
	int (*test_run)(struct bpf_prog___68 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_aux___71;

struct bpf_prog___68 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___71 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

struct bpf_verifier_ops___68 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___68 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___68 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___68 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___68 *, u32 *);
};

struct bpf_prog_offload_ops___68 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___68 *);
	int (*translate)(struct bpf_prog___68 *);
	void (*destroy)(struct bpf_prog___68 *);
};

struct bpf_prog_offload___68 {
	struct bpf_prog___68 *prog;
	struct net_device___79 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___68 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___71 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___68 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___68 *ops;
	struct bpf_map___283 **used_maps;
	struct bpf_prog___68 *prog;
	struct user_struct___401 *user;
	u64 load_time;
	struct bpf_map___283 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___68 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___68 {
	struct bpf_prog___68 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___68 {
	struct callback_head rcu;
	struct bpf_prog_array_item___68 items[0];
};

typedef struct page___434 *pgtable_t___434;

struct dev_pagemap___421;

struct page___434 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___433 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___434 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___434 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___434 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___421 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___166 *mem_cgroup;
};

struct pglist_data___434;

struct lruvec___434 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___434 *pgdat;
};

struct zone___434 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___434 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___434 {
	struct zone___434 *zone;
	int zone_idx;
};

struct zonelist___434 {
	struct zoneref___434 _zonerefs[25];
};

struct pglist_data___434 {
	struct zone___434 node_zones[3];
	struct zonelist___434 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___435 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___435 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___434 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___435 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___435 *owner;
};

struct blocking_notifier_head___434 {
	struct rw_semaphore___435 rwsem;
	struct notifier_block *head;
};

struct cgroup___282;

struct cgroup_subsys___282;

struct cgroup_subsys_state___282 {
	struct cgroup___282 *cgroup;
	struct cgroup_subsys___282 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___282 *parent;
};

struct cgroup_file___282 {
	struct kernfs_node___428 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___166;

struct mem_cgroup___166 {
	struct cgroup_subsys_state___282 css;
	struct mem_cgroup_id___21 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___282 events_file;
	struct cgroup_file___282 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___435 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___166 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct vm_struct___337 {
	struct vm_struct___337 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___434 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct ucounts___298;

struct user_namespace___298 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___298 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___29 ns;
	long unsigned int flags;
	struct key___401 *persistent_keyring_register;
	struct rw_semaphore___435 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___298 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_operations_struct___421;

struct vm_area_struct___434 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___434 *vm_next;
	struct vm_area_struct___434 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___434 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___421 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___433 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___434;

struct mm_struct___434 {
	struct {
		struct vm_area_struct___434 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___433 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___435 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___434 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___435 *owner;
		struct user_namespace___298 *user_ns;
		struct file___433 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___434 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___401 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___401 *session_keyring;
	struct key___401 *process_keyring;
	struct key___401 *thread_keyring;
	struct key___401 *request_key_auth;
	void *security;
	struct user_struct___401 *user;
	struct user_namespace___298 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup_namespace___282;

struct nsproxy___328 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net___90 *net_ns;
	struct cgroup_namespace___282 *cgroup_ns;
};

struct signal_struct___308 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___435 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___435 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___241 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___241 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___434 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___241 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___223;

struct bio_list___223 {
	struct bio___223 *head;
	struct bio___223 *tail;
};

struct bdi_writeback_congested___223;

struct bdi_writeback___223 {
	struct backing_dev_info___223 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___223 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___282 *memcg_css;
	struct cgroup_subsys_state___282 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___223 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___223 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___401 *dev;
	struct device___401 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___433 *debug_dir;
	struct dentry___433 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___282 {
	struct cgroup_subsys_state___282 *subsys[13];
	refcount_t refcount;
	struct css_set___282 *dom_cset;
	struct cgroup___282 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___282 *mg_src_cgrp;
	struct cgroup___282 *mg_dst_cgrp;
	struct css_set___282 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___433;

struct pipe_buffer___114;

struct pipe_inode_info___114 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___434 *tmp_page;
	struct fasync_struct___433 *fasync_readers;
	struct fasync_struct___433 *fasync_writers;
	struct pipe_buffer___114 *bufs;
	struct user_struct___401 *user;
};

union thread_union___320 {
	struct task_struct___435 task;
	long unsigned int stack[8192];
};

struct address_space_operations___433;

struct address_space___433 {
	struct inode___433 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___435 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___433 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___421)(struct vm_area_struct___434 *, long unsigned int, const struct page___434 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___421)(struct page___434 *, void *);

struct dev_pagemap___421 {
	dev_page_fault_t___421 page_fault;
	dev_page_free_t___421 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___401 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct vm_fault___421;

struct vm_operations_struct___421 {
	void (*open)(struct vm_area_struct___434 *);
	void (*close)(struct vm_area_struct___434 *);
	int (*split)(struct vm_area_struct___434 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___434 *);
	vm_fault_t (*fault)(struct vm_fault___421 *);
	vm_fault_t (*huge_fault)(struct vm_fault___421 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___421 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___434 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___421 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___421 *);
	int (*access)(struct vm_area_struct___434 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___434 *);
	int (*set_policy)(struct vm_area_struct___434 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___434 *, long unsigned int);
	struct page___434 * (*find_special_page)(struct vm_area_struct___434 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___434 {
	struct task_struct___435 *task;
	struct core_thread___434 *next;
};

struct core_state___434 {
	atomic_t nr_threads;
	struct core_thread___434 dumper;
	struct completion startup;
};

struct vm_fault___421 {
	struct vm_area_struct___434 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___434 *cow_page;
	struct mem_cgroup___166 *memcg;
	struct page___434 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___434 prealloc_pte;
};

struct crypto_async_request___28;

typedef void (*crypto_completion_t___28)(struct crypto_async_request___28 *, int);

struct crypto_tfm___28;

struct crypto_async_request___28 {
	struct list_head list;
	crypto_completion_t___28 complete;
	void *data;
	struct crypto_tfm___28 *tfm;
	u32 flags;
};

struct crypto_ablkcipher___28;

struct ablkcipher_request___28;

struct ablkcipher_tfm___28 {
	int (*setkey)(struct crypto_ablkcipher___28 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___28 *);
	int (*decrypt)(struct ablkcipher_request___28 *);
	struct crypto_ablkcipher___28 *base;
	unsigned int ivsize;
	unsigned int reqsize;
};

struct blkcipher_desc___28;

struct blkcipher_tfm___28 {
	void *iv;
	int (*setkey)(struct crypto_tfm___28 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___28 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___28 *, struct scatterlist *, struct scatterlist *, unsigned int);
};

struct cipher_tfm___28 {
	int (*cit_setkey)(struct crypto_tfm___28 *, const u8 *, unsigned int);
	void (*cit_encrypt_one)(struct crypto_tfm___28 *, u8 *, const u8 *);
	void (*cit_decrypt_one)(struct crypto_tfm___28 *, u8 *, const u8 *);
};

struct compress_tfm___28 {
	int (*cot_compress)(struct crypto_tfm___28 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*cot_decompress)(struct crypto_tfm___28 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___28;

struct crypto_tfm___28 {
	u32 crt_flags;
	union {
		struct ablkcipher_tfm___28 ablkcipher;
		struct blkcipher_tfm___28 blkcipher;
		struct cipher_tfm___28 cipher;
		struct compress_tfm___28 compress;
	} crt_u;
	void (*exit)(struct crypto_tfm___28 *);
	struct crypto_alg___28 *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct ablkcipher_request___28 {
	struct crypto_async_request___28 base;
	unsigned int nbytes;
	void *info;
	struct scatterlist *src;
	struct scatterlist *dst;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_blkcipher___28;

struct blkcipher_desc___28 {
	struct crypto_blkcipher___28 *tfm;
	void *info;
	u32 flags;
};

struct crypto_blkcipher___28 {
	struct crypto_tfm___28 base;
};

struct ablkcipher_alg___28 {
	int (*setkey)(struct crypto_ablkcipher___28 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___28 *);
	int (*decrypt)(struct ablkcipher_request___28 *);
	int (*givencrypt)(struct skcipher_givcrypt_request *);
	int (*givdecrypt)(struct skcipher_givcrypt_request *);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct crypto_ablkcipher___28 {
	struct crypto_tfm___28 base;
};

struct blkcipher_alg___28 {
	int (*setkey)(struct crypto_tfm___28 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___28 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___28 *, struct scatterlist *, struct scatterlist *, unsigned int);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct cipher_alg___28 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___28 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___28 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___28 *, u8 *, const u8 *);
};

struct compress_alg___28 {
	int (*coa_compress)(struct crypto_tfm___28 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___28 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___28 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type *cra_type;
	union {
		struct ablkcipher_alg___28 ablkcipher;
		struct blkcipher_alg___28 blkcipher;
		struct cipher_alg___28 cipher;
		struct compress_alg___28 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___28 *);
	void (*cra_exit)(struct crypto_tfm___28 *);
	void (*cra_destroy)(struct crypto_alg___28 *);
	struct module___361 *cra_module;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___359 {
	struct kobject___421 kobj;
	struct module___361 *mod;
	struct kobject___421 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___359 {
	struct module___361 *mod;
	struct latch_tree_node node;
};

struct module_layout___359 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___359 mtn;
};

struct module_attribute___359;

struct kernel_param___359;

struct module___361 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___359 mkobj;
	struct module_attribute___359 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___421 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___359 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___359 core_layout;
	struct module_layout___359 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide38;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide39;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct crypto_cipher___12 {
	struct crypto_tfm___28 base;
};

struct bio_vec___225 {
	struct page___434 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___200 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___225 *bvec;
		struct pipe_inode_info___114 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct msghdr___61 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___200 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___433 *msg_iocb;
};

struct kiocb___433 {
	struct file___433 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___433 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dentry_operations___433;

struct super_block___433;

struct dentry___433 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___433 *d_parent;
	struct qstr d_name;
	struct inode___433 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___433 *d_op;
	struct super_block___433 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___433;

struct block_device___433;

struct inode___433 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___433 *i_op;
	struct super_block___433 *i_sb;
	struct address_space___433 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___435 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___223 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___433 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___433 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___114 *i_pipe;
		struct block_device___433 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___433 {
	int (*d_revalidate)(struct dentry___433 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___433 *, unsigned int);
	int (*d_hash)(const struct dentry___433 *, struct qstr *);
	int (*d_compare)(const struct dentry___433 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___433 *);
	int (*d_init)(struct dentry___433 *);
	void (*d_release)(struct dentry___433 *);
	void (*d_prune)(struct dentry___433 *);
	void (*d_iput)(struct dentry___433 *, struct inode___433 *);
	char * (*d_dname)(struct dentry___433 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___434 *);
	int (*d_manage)(const struct path___434 *, bool);
	struct dentry___433 * (*d_real)(struct dentry___433 *, const struct inode___433 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___433;

struct mem_dqinfo___433 {
	struct quota_format_type___433 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___433;

struct quota_info___433 {
	unsigned int flags;
	struct rw_semaphore___435 dqio_sem;
	struct inode___433 *files[3];
	struct mem_dqinfo___433 info[3];
	const struct quota_format_ops___433 *ops[3];
};

struct rcuwait___433 {
	struct task_struct___435 *task;
};

struct percpu_rw_semaphore___433 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___435 rw_sem;
	struct rcuwait___433 writer;
	int readers_block;
};

struct sb_writers___433 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___433 rw_sem[3];
};

struct shrink_control___166;

struct shrinker___166 {
	long unsigned int (*count_objects)(struct shrinker___166 *, struct shrink_control___166 *);
	long unsigned int (*scan_objects)(struct shrinker___166 *, struct shrink_control___166 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___433;

struct super_operations___433;

struct dquot_operations___433;

struct quotactl_ops___433;

struct super_block___433 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___433 *s_type;
	const struct super_operations___433 *s_op;
	const struct dquot_operations___433 *dq_op;
	const struct quotactl_ops___433 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___433 *s_root;
	struct rw_semaphore___435 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___433 *s_bdev;
	struct backing_dev_info___223 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___433 s_dquot;
	struct sb_writers___433 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___433 *s_d_op;
	int cleancache_poolid;
	struct shrinker___166 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___298 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___166 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___166 *memcg;
};

struct iattr___433 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___433 *ia_file;
};

struct dquot___433 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___433 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___433 {
	int qf_fmt_id;
	const struct quota_format_ops___433 *qf_ops;
	struct module___361 *qf_owner;
	struct quota_format_type___433 *qf_next;
};

struct quota_format_ops___433 {
	int (*check_quota_file)(struct super_block___433 *, int);
	int (*read_file_info)(struct super_block___433 *, int);
	int (*write_file_info)(struct super_block___433 *, int);
	int (*free_file_info)(struct super_block___433 *, int);
	int (*read_dqblk)(struct dquot___433 *);
	int (*commit_dqblk)(struct dquot___433 *);
	int (*release_dqblk)(struct dquot___433 *);
	int (*get_next_id)(struct super_block___433 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___433 {
	int (*write_dquot)(struct dquot___433 *);
	struct dquot___433 * (*alloc_dquot)(struct super_block___433 *, int);
	void (*destroy_dquot)(struct dquot___433 *);
	int (*acquire_dquot)(struct dquot___433 *);
	int (*release_dquot)(struct dquot___433 *);
	int (*mark_dirty)(struct dquot___433 *);
	int (*write_info)(struct super_block___433 *, int);
	qsize_t * (*get_reserved_space)(struct inode___433 *);
	int (*get_projid)(struct inode___433 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___433 *, qsize_t *);
	int (*get_next_id)(struct super_block___433 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___433 {
	int (*quota_on)(struct super_block___433 *, int, int, const struct path___434 *);
	int (*quota_off)(struct super_block___433 *, int);
	int (*quota_enable)(struct super_block___433 *, unsigned int);
	int (*quota_disable)(struct super_block___433 *, unsigned int);
	int (*quota_sync)(struct super_block___433 *, int);
	int (*set_info)(struct super_block___433 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___433 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___433 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___433 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___433 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___433 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___186;

struct address_space_operations___433 {
	int (*writepage)(struct page___434 *, struct writeback_control___186 *);
	int (*readpage)(struct file___433 *, struct page___434 *);
	int (*writepages)(struct address_space___433 *, struct writeback_control___186 *);
	int (*set_page_dirty)(struct page___434 *);
	int (*readpages)(struct file___433 *, struct address_space___433 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___433 *, struct address_space___433 *, loff_t, unsigned int, unsigned int, struct page___434 **, void **);
	int (*write_end)(struct file___433 *, struct address_space___433 *, loff_t, unsigned int, unsigned int, struct page___434 *, void *);
	sector_t (*bmap)(struct address_space___433 *, sector_t);
	void (*invalidatepage)(struct page___434 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___434 *, gfp_t);
	void (*freepage)(struct page___434 *);
	ssize_t (*direct_IO)(struct kiocb___433 *, struct iov_iter___200 *);
	int (*migratepage)(struct address_space___433 *, struct page___434 *, struct page___434 *, enum migrate_mode);
	bool (*isolate_page)(struct page___434 *, isolate_mode_t);
	void (*putback_page)(struct page___434 *);
	int (*launder_page)(struct page___434 *);
	int (*is_partially_uptodate)(struct page___434 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___434 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___433 *, struct page___434 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___433 *, sector_t *);
	void (*swap_deactivate)(struct file___433 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___186 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___223 *wb;
	struct inode___433 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___433 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___433 *bd_inode;
	struct super_block___433 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___433 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___223 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___433 {
	struct dentry___433 * (*lookup)(struct inode___433 *, struct dentry___433 *, unsigned int);
	const char * (*get_link)(struct dentry___433 *, struct inode___433 *, struct delayed_call *);
	int (*permission)(struct inode___433 *, int);
	struct posix_acl * (*get_acl)(struct inode___433 *, int);
	int (*readlink)(struct dentry___433 *, char *, int);
	int (*create)(struct inode___433 *, struct dentry___433 *, umode_t, bool);
	int (*link)(struct dentry___433 *, struct inode___433 *, struct dentry___433 *);
	int (*unlink)(struct inode___433 *, struct dentry___433 *);
	int (*symlink)(struct inode___433 *, struct dentry___433 *, const char *);
	int (*mkdir)(struct inode___433 *, struct dentry___433 *, umode_t);
	int (*rmdir)(struct inode___433 *, struct dentry___433 *);
	int (*mknod)(struct inode___433 *, struct dentry___433 *, umode_t, dev_t);
	int (*rename)(struct inode___433 *, struct dentry___433 *, struct inode___433 *, struct dentry___433 *, unsigned int);
	int (*setattr)(struct dentry___433 *, struct iattr___433 *);
	int (*getattr)(const struct path___434 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___433 *, char *, size_t);
	int (*fiemap)(struct inode___433 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___433 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___433 *, struct dentry___433 *, struct file___433 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___433 *, struct dentry___433 *, umode_t);
	int (*set_acl)(struct inode___433 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___433 {
	void (*fl_copy_lock)(struct file_lock___433 *, struct file_lock___433 *);
	void (*fl_release_private)(struct file_lock___433 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___433;

struct file_lock___433 {
	struct file_lock___433 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___433 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___433 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___433 *fl_ops;
	const struct lock_manager_operations___433 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___433 {
	int (*lm_compare_owner)(struct file_lock___433 *, struct file_lock___433 *);
	long unsigned int (*lm_owner_key)(struct file_lock___433 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___433 *);
	int (*lm_grant)(struct file_lock___433 *, int);
	bool (*lm_break)(struct file_lock___433 *);
	int (*lm_change)(struct file_lock___433 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___433 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___433 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___433 *fa_next;
	struct file___433 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___433 {
	const char *name;
	int fs_flags;
	struct dentry___433 * (*mount)(struct file_system_type___433 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___433 *);
	struct module___361 *owner;
	struct file_system_type___433 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___433 {
	struct inode___433 * (*alloc_inode)(struct super_block___433 *);
	void (*destroy_inode)(struct inode___433 *);
	void (*dirty_inode)(struct inode___433 *, int);
	int (*write_inode)(struct inode___433 *, struct writeback_control___186 *);
	int (*drop_inode)(struct inode___433 *);
	void (*evict_inode)(struct inode___433 *);
	void (*put_super)(struct super_block___433 *);
	int (*sync_fs)(struct super_block___433 *, int);
	int (*freeze_super)(struct super_block___433 *);
	int (*freeze_fs)(struct super_block___433 *);
	int (*thaw_super)(struct super_block___433 *);
	int (*unfreeze_fs)(struct super_block___433 *);
	int (*statfs)(struct dentry___433 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___433 *, int *, char *);
	void (*umount_begin)(struct super_block___433 *);
	int (*show_options)(struct seq_file___372 *, struct dentry___433 *);
	int (*show_devname)(struct seq_file___372 *, struct dentry___433 *);
	int (*show_path)(struct seq_file___372 *, struct dentry___433 *);
	int (*show_stats)(struct seq_file___372 *, struct dentry___433 *);
	ssize_t (*quota_read)(struct super_block___433 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___433 *, int, const char *, size_t, loff_t);
	struct dquot___433 ** (*get_dquots)(struct inode___433 *);
	int (*bdev_try_to_free_page)(struct super_block___433 *, struct page___434 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___433 *, struct shrink_control___166 *);
	long int (*free_cached_objects)(struct super_block___433 *, struct shrink_control___166 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___282)(struct file___433 *, wait_queue_head_t *, struct poll_table_struct___272 *);

struct poll_table_struct___272 {
	poll_queue_proc___282 _qproc;
	__poll_t _key;
};

typedef void bio_end_io_t___223(struct bio___223 *);

struct bio_integrity_payload___223;

struct bio_set___223;

struct bio___223 {
	struct bio___223 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___223 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___223 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___225 *bi_io_vec;
	struct bio_set___223 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___225 bi_inline_vecs[0];
};

struct socket_wq___59 {
	wait_queue_head_t wait;
	struct fasync_struct___433 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct sock___59;

struct proto_ops___59;

struct socket___60 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___59 *wq;
	struct file___433 *file;
	struct sock___59 *sk;
	const struct proto_ops___59 *ops;
};

struct proto___58;

struct sock_common___58 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___58 *skc_prot;
	possible_net_t___80 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___59 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff_head___78 {
	struct sk_buff___80 *next;
	struct sk_buff___80 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___58;

struct dst_entry___58;

struct sock___59 {
	struct sock_common___58 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___78 sk_error_queue;
	struct sk_buff_head___78 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___80 *head;
		struct sk_buff___80 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___58 *sk_filter;
	union {
		struct socket_wq___59 *sk_wq;
		struct socket_wq___59 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___58 *sk_rx_dst;
	struct dst_entry___58 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___80 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___78 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___434 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___58 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___241 *sk_peer_pid;
	const struct cred___401 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___60 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___166 *sk_memcg;
	void (*sk_state_change)(struct sock___59 *);
	void (*sk_data_ready)(struct sock___59 *);
	void (*sk_write_space)(struct sock___59 *);
	void (*sk_error_report)(struct sock___59 *);
	int (*sk_backlog_rcv)(struct sock___59 *, struct sk_buff___80 *);
	struct sk_buff___80 * (*sk_validate_xmit_skb)(struct sock___59 *, struct net_device___79 *, struct sk_buff___80 *);
	void (*sk_destruct)(struct sock___59 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

typedef int (*sk_read_actor_t___58)(read_descriptor_t *, struct sk_buff___80 *, unsigned int, size_t);

struct proto_ops___59 {
	int family;
	struct module___361 *owner;
	int (*release)(struct socket___60 *);
	int (*bind)(struct socket___60 *, struct sockaddr *, int);
	int (*connect)(struct socket___60 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___60 *, struct socket___60 *);
	int (*accept)(struct socket___60 *, struct socket___60 *, int, bool);
	int (*getname)(struct socket___60 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___433 *, struct socket___60 *, struct poll_table_struct___272 *);
	int (*ioctl)(struct socket___60 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___60 *, int);
	int (*shutdown)(struct socket___60 *, int);
	int (*setsockopt)(struct socket___60 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___60 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___60 *, struct msghdr___61 *, size_t);
	int (*recvmsg)(struct socket___60 *, struct msghdr___61 *, size_t, int);
	int (*mmap)(struct file___433 *, struct socket___60 *, struct vm_area_struct___434 *);
	ssize_t (*sendpage)(struct socket___60 *, struct page___434 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___60 *, loff_t *, struct pipe_inode_info___114 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___59 *, int);
	int (*peek_len)(struct socket___60 *);
	int (*read_sock)(struct sock___59 *, read_descriptor_t *, sk_read_actor_t___58);
	int (*sendpage_locked)(struct sock___59 *, struct page___434 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___59 *, struct msghdr___61 *, size_t);
	int (*set_rcvlowat)(struct sock___59 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct nf_bridge_info___78;

struct sk_buff___80 {
	union {
		struct {
			struct sk_buff___80 *next;
			struct sk_buff___80 *prev;
			union {
				struct net_device___79 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___59 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___80 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___78 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___78;

struct netns_frags___78 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___78 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ip_ra_chain___28;

struct fib_rules_ops___58;

struct tcp_congestion_ops___9;

struct tcp_fastopen_context___9;

struct fib_notifier_ops___59;

struct netns_ipv4___78 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___28 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___58 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___59 *fibnl;
	struct sock___59 **icmp_sk;
	struct sock___59 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___59 **tcp_sk;
	struct netns_frags___78 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops___9 *tcp_congestion_control;
	struct tcp_fastopen_context___9 *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___58 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___59 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___59 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___58;

struct dst_ops___89 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___89 *);
	struct dst_entry___58 * (*check)(struct dst_entry___58 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___58 *);
	unsigned int (*mtu)(const struct dst_entry___58 *);
	u32 * (*cow_metrics)(struct dst_entry___58 *, long unsigned int);
	void (*destroy)(struct dst_entry___58 *);
	void (*ifdown)(struct dst_entry___58 *, struct net_device___79 *, int);
	struct dst_entry___58 * (*negative_advice)(struct dst_entry___58 *);
	void (*link_failure)(struct sk_buff___80 *);
	void (*update_pmtu)(struct dst_entry___58 *, struct sock___59 *, struct sk_buff___80 *, u32);
	void (*redirect)(struct dst_entry___58 *, struct sock___59 *, struct sk_buff___80 *);
	int (*local_out)(struct net___90 *, struct sock___59 *, struct sk_buff___80 *);
	struct neighbour___58 * (*neigh_lookup)(const struct dst_entry___58 *, struct sk_buff___80 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___58 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___89 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___78 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___89 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___58 *fib6_rules_ops;
	struct sock___59 **icmp_sk;
	struct sock___59 *ndisc_sk;
	struct sock___59 *tcp_sk;
	struct sock___59 *igmp_sk;
	struct sock___59 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___58 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___59 *notifier_ops;
	struct fib_notifier_ops___59 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___59 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___59 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___78 {
	struct netns_frags___78 frags;
};

struct netns_xfrm___89 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___59 *nlsk;
	struct sock___59 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___89 xfrm4_dst_ops;
	struct dst_ops___89 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct net___90 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___298 *user_ns;
	struct ucounts___298 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___29 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___59 *rtnl;
	struct sock___59 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___79 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___78 ipv4;
	struct netns_ipv6___89 ipv6;
	struct netns_sctp___59 sctp;
	struct netns_nf___4 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___78 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___59 *nfnl;
	struct sock___59 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___89 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___59 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___68 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kernfs_root___427;

struct kernfs_elem_dir___427 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___427 *root;
};

struct kernfs_syscall_ops___427;

struct kernfs_root___427 {
	struct kernfs_node___428 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___427 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___427 {
	struct kernfs_node___428 *target_kn;
};

struct kernfs_ops___427;

struct kernfs_elem_attr___427 {
	const struct kernfs_ops___427 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___428 *notify_next;
};

struct kernfs_node___428 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___428 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___427 dir;
		struct kernfs_elem_symlink___427 symlink;
		struct kernfs_elem_attr___427 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___427;

struct kernfs_ops___427 {
	int (*open)(struct kernfs_open_file___427 *);
	void (*release)(struct kernfs_open_file___427 *);
	int (*seq_show)(struct seq_file___372 *, void *);
	void * (*seq_start)(struct seq_file___372 *, loff_t *);
	void * (*seq_next)(struct seq_file___372 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___372 *, void *);
	ssize_t (*read)(struct kernfs_open_file___427 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___427 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___427 *, struct vm_area_struct___434 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___427 *, struct poll_table_struct___272 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___427 {
	int (*remount_fs)(struct kernfs_root___427 *, int *, char *);
	int (*show_options)(struct seq_file___372 *, struct kernfs_root___427 *);
	int (*mkdir)(struct kernfs_node___428 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___428 *);
	int (*rename)(struct kernfs_node___428 *, struct kernfs_node___428 *, const char *);
	int (*show_path)(struct seq_file___372 *, struct kernfs_node___428 *, struct kernfs_root___427 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___427 {
	struct kernfs_node___428 *kn;
	struct file___433 *file;
	struct seq_file___372 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___421 *vm_ops;
};

struct kobj_ns_type_operations___58 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___59 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___397;

struct attribute_group___398 {
	const char *name;
	umode_t (*is_visible)(struct kobject___421 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___421 *, struct bin_attribute___397 *, int);
	struct attribute **attrs;
	struct bin_attribute___397 **bin_attrs;
};

struct bin_attribute___397 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___433 *, struct kobject___421 *, struct bin_attribute___397 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___433 *, struct kobject___421 *, struct bin_attribute___397 *, char *, loff_t, size_t);
	int (*mmap)(struct file___433 *, struct kobject___421 *, struct bin_attribute___397 *, struct vm_area_struct___434 *);
};

struct sysfs_ops___420 {
	ssize_t (*show)(struct kobject___421 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___421 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___420;

struct kset___420 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___421 kobj;
	const struct kset_uevent_ops___420 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___420 {
	void (*release)(struct kobject___421 *);
	const struct sysfs_ops___420 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___58 * (*child_ns_type)(struct kobject___421 *);
	const void * (*namespace)(struct kobject___421 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___420 {
	int (* const filter)(struct kset___420 *, struct kobject___421 *);
	const char * (* const name)(struct kset___420 *, struct kobject___421 *);
	int (* const uevent)(struct kset___420 *, struct kobject___421 *, struct kobj_uevent_env *);
};

struct kobj_attribute___411 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___421 *, struct kobj_attribute___411 *, char *);
	ssize_t (*store)(struct kobject___421 *, struct kobj_attribute___411 *, const char *, size_t);
};

struct dev_pm_ops___401 {
	int (*prepare)(struct device___401 *);
	void (*complete)(struct device___401 *);
	int (*suspend)(struct device___401 *);
	int (*resume)(struct device___401 *);
	int (*freeze)(struct device___401 *);
	int (*thaw)(struct device___401 *);
	int (*poweroff)(struct device___401 *);
	int (*restore)(struct device___401 *);
	int (*suspend_late)(struct device___401 *);
	int (*resume_early)(struct device___401 *);
	int (*freeze_late)(struct device___401 *);
	int (*thaw_early)(struct device___401 *);
	int (*poweroff_late)(struct device___401 *);
	int (*restore_early)(struct device___401 *);
	int (*suspend_noirq)(struct device___401 *);
	int (*resume_noirq)(struct device___401 *);
	int (*freeze_noirq)(struct device___401 *);
	int (*thaw_noirq)(struct device___401 *);
	int (*poweroff_noirq)(struct device___401 *);
	int (*restore_noirq)(struct device___401 *);
	int (*runtime_suspend)(struct device___401 *);
	int (*runtime_resume)(struct device___401 *);
	int (*runtime_idle)(struct device___401 *);
};

struct dev_pm_domain___401 {
	struct dev_pm_ops___401 ops;
	void (*detach)(struct device___401 *, bool);
	int (*activate)(struct device___401 *);
	void (*sync)(struct device___401 *);
	void (*dismiss)(struct device___401 *);
};

struct bus_type___401 {
	const char *name;
	const char *dev_name;
	struct device___401 *dev_root;
	const struct attribute_group___398 **bus_groups;
	const struct attribute_group___398 **dev_groups;
	const struct attribute_group___398 **drv_groups;
	int (*match)(struct device___401 *, struct device_driver___401 *);
	int (*uevent)(struct device___401 *, struct kobj_uevent_env *);
	int (*probe)(struct device___401 *);
	int (*remove)(struct device___401 *);
	void (*shutdown)(struct device___401 *);
	int (*online)(struct device___401 *);
	int (*offline)(struct device___401 *);
	int (*suspend)(struct device___401 *, pm_message_t);
	int (*resume)(struct device___401 *);
	int (*num_vf)(struct device___401 *);
	int (*dma_configure)(struct device___401 *);
	const struct dev_pm_ops___401 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___401 {
	const char *name;
	struct bus_type___401 *bus;
	struct module___361 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___401 *);
	int (*remove)(struct device___401 *);
	void (*shutdown)(struct device___401 *);
	int (*suspend)(struct device___401 *, pm_message_t);
	int (*resume)(struct device___401 *);
	const struct attribute_group___398 **groups;
	const struct dev_pm_ops___401 *pm;
	void (*coredump)(struct device___401 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___401 {
	const char *name;
	const struct attribute_group___398 **groups;
	int (*uevent)(struct device___401 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___401 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___401 *);
	const struct dev_pm_ops___401 *pm;
};

struct class___401 {
	const char *name;
	struct module___361 *owner;
	const struct attribute_group___398 **class_groups;
	const struct attribute_group___398 **dev_groups;
	struct kobject___421 *dev_kobj;
	int (*dev_uevent)(struct device___401 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___401 *, umode_t *);
	void (*class_release)(struct class___401 *);
	void (*dev_release)(struct device___401 *);
	int (*shutdown_pre)(struct device___401 *);
	const struct kobj_ns_type_operations___58 *ns_type;
	const void * (*namespace)(struct device___401 *);
	const struct dev_pm_ops___401 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___173 {
	void * (*alloc)(struct device___401 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___401 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___401 *, struct vm_area_struct___434 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___401 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___401 *, struct page___434 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___401 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___401 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___401 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___401 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___401 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___401 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___401 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___401 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___401 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___401 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___401 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___401 *, u64);
	u64 (*get_required_mask)(struct device___401 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___321;

struct fwnode_handle___321 {
	struct fwnode_handle___321 *secondary;
	const struct fwnode_operations___321 *ops;
};

typedef void compound_page_dtor___421(struct page___434 *);

struct fwnode_reference_args___321;

struct fwnode_endpoint___321;

struct fwnode_operations___321 {
	struct fwnode_handle___321 * (*get)(struct fwnode_handle___321 *);
	void (*put)(struct fwnode_handle___321 *);
	bool (*device_is_available)(const struct fwnode_handle___321 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___321 *, const struct device___401 *);
	bool (*property_present)(const struct fwnode_handle___321 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___321 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___321 *, const char *, const char **, size_t);
	struct fwnode_handle___321 * (*get_parent)(const struct fwnode_handle___321 *);
	struct fwnode_handle___321 * (*get_next_child_node)(const struct fwnode_handle___321 *, struct fwnode_handle___321 *);
	struct fwnode_handle___321 * (*get_named_child_node)(const struct fwnode_handle___321 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___321 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___321 *);
	struct fwnode_handle___321 * (*graph_get_next_endpoint)(const struct fwnode_handle___321 *, struct fwnode_handle___321 *);
	struct fwnode_handle___321 * (*graph_get_remote_endpoint)(const struct fwnode_handle___321 *);
	struct fwnode_handle___321 * (*graph_get_port_parent)(struct fwnode_handle___321 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___321 *, struct fwnode_endpoint___321 *);
};

struct fwnode_endpoint___321 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___321 *local_fwnode;
};

struct fwnode_reference_args___321 {
	struct fwnode_handle___321 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___114;

struct pipe_buffer___114 {
	struct page___434 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___114 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___114 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___114 *, struct pipe_buffer___114 *);
	void (*release)(struct pipe_inode_info___114 *, struct pipe_buffer___114 *);
	int (*steal)(struct pipe_inode_info___114 *, struct pipe_buffer___114 *);
	union {
		bool (*get)(struct pipe_inode_info___114 *, struct pipe_buffer___114 *);
		struct {
			void (*get)(struct pipe_inode_info___114 *, struct pipe_buffer___114 *);
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
};

struct nf_bridge_info___78 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___78 = 0,
		BRNF_PROTO_8021Q___78 = 1,
		BRNF_PROTO_PPPOE___78 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___79 *physindev;
	struct net_device___79 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

struct skb_frag_struct___14 {
	struct {
		struct page___434 *p;
	} page;
	__u32 page_offset;
	__u32 size;
};

typedef struct skb_frag_struct___14 skb_frag_t___14;

struct skb_shared_info___14 {
	__u8 __unused;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___80 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___14 frags[16];
};

struct ethtool_ops___78 {
	int (*get_settings)(struct net_device___79 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___79 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___79 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___79 *);
	void (*get_regs)(struct net_device___79 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___79 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___79 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___79 *);
	void (*set_msglevel)(struct net_device___79 *, u32);
	int (*nway_reset)(struct net_device___79 *);
	u32 (*get_link)(struct net_device___79 *);
	int (*get_eeprom_len)(struct net_device___79 *);
	int (*get_eeprom)(struct net_device___79 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___79 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___79 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___79 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___79 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___79 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___79 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___79 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___79 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___79 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___79 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___79 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___79 *);
	void (*complete)(struct net_device___79 *);
	u32 (*get_priv_flags)(struct net_device___79 *);
	int (*set_priv_flags)(struct net_device___79 *, u32);
	int (*get_sset_count)(struct net_device___79 *, int);
	int (*get_rxnfc)(struct net_device___79 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___79 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___79 *, struct ethtool_flash *);
	int (*reset)(struct net_device___79 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___79 *);
	u32 (*get_rxfh_indir_size)(struct net_device___79 *);
	int (*get_rxfh)(struct net_device___79 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___79 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___79 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___79 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___79 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___79 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___79 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___79 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___79 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___79 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___79 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___79 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___79 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___79 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___79 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___79 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___79 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___79 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___79 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___79 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___79 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___79 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	int (*get_fecparam)(struct net_device___79 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___79 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___79 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___79 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___79 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___78;

struct inet_frags___78 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___78 *, const void *);
	void (*destructor)(struct inet_frag_queue___78 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___78 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___80 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___80 *fragments_tail;
	struct sk_buff___80 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___78 *net;
	struct callback_head rcu;
};

struct ip_ra_chain___28 {
	struct ip_ra_chain___28 *next;
	struct sock___59 *sk;
	union {
		void (*destructor)(struct sock___59 *);
		struct sock___59 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___58;

struct fib_lookup_arg___58;

struct fib_rules_ops___58 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___58 *, struct flowi *, int, struct fib_lookup_arg___58 *);
	bool (*suppress)(struct fib_rule___58 *, struct fib_lookup_arg___58 *);
	int (*match)(struct fib_rule___58 *, struct flowi *, int);
	int (*configure)(struct fib_rule___58 *, struct sk_buff___80 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___58 *);
	int (*compare)(struct fib_rule___58 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___58 *, struct sk_buff___80 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___58 *);
	void (*flush_cache)(struct fib_rules_ops___58 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___361 *owner;
	struct net___90 *fro_net;
	struct callback_head rcu;
};

struct tcp_congestion_ops___9 {
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___59 *);
	void (*release)(struct sock___59 *);
	u32 (*ssthresh)(struct sock___59 *);
	void (*cong_avoid)(struct sock___59 *, u32, u32);
	void (*set_state)(struct sock___59 *, u8);
	void (*cwnd_event)(struct sock___59 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___59 *, u32);
	u32 (*undo_cwnd)(struct sock___59 *);
	void (*pkts_acked)(struct sock___59 *, const struct ack_sample *);
	u32 (*min_tso_segs)(struct sock___59 *);
	u32 (*sndbuf_expand)(struct sock___59 *);
	void (*cong_control)(struct sock___59 *, const struct rate_sample *);
	size_t (*get_info)(struct sock___59 *, u32, int *, union tcp_cc_info *);
	char name[16];
	struct module___361 *owner;
};

struct tcp_fastopen_context___9 {
	struct crypto_cipher___12 *tfm;
	__u8 key[16];
	struct callback_head rcu;
};

struct fib_notifier_ops___59 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___90 *);
	int (*fib_dump)(struct net___90 *, struct notifier_block *);
	struct module___361 *owner;
	struct callback_head rcu;
};

struct dst_entry___58 {
	struct net_device___79 *dev;
	struct dst_ops___89 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___80 *);
	int (*output)(struct net___90 *, struct sock___59 *, struct sk_buff___80 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___58;

struct neigh_parms___58;

struct neigh_ops___58;

struct neighbour___58 {
	struct neighbour___58 *next;
	struct neigh_table___58 *tbl;
	struct neigh_parms___58 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___78 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___58 *, struct sk_buff___80 *);
	const struct neigh_ops___58 *ops;
	struct callback_head rcu;
	struct net_device___79 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct ucounts___298 {
	struct hlist_node node;
	struct user_namespace___298 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

typedef int (*key_restrict_link_func_t___402)(struct key___401 *, const struct key_type *, const union key_payload *, struct key___401 *);

struct key_restriction___401;

struct key___401 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___435 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___401 *restrict_link;
};

struct key_restriction___401 {
	key_restrict_link_func_t___402 check;
	struct key___401 *key;
	struct key_type *keytype;
};

struct seq_operations___372 {
	void * (*start)(struct seq_file___372 *, loff_t *);
	void (*stop)(struct seq_file___372 *, void *);
	void * (*next)(struct seq_file___372 *, void *, loff_t *);
	int (*show)(struct seq_file___372 *, void *);
};

struct pernet_operations___79 {
	struct list_head list;
	int (*init)(struct net___90 *);
	void (*exit)(struct net___90 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___78 {
	int (*ieee_getets)(struct net_device___79 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___79 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___79 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___79 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___79 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___79 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___79 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___79 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___79 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___79 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___79 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___79 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___79 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___79 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___79 *);
	u8 (*setstate)(struct net_device___79 *, u8);
	void (*getpermhwaddr)(struct net_device___79 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___79 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___79 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___79 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___79 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___79 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___79 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___79 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___79 *, int, u8 *);
	void (*setpfccfg)(struct net_device___79 *, int, u8);
	void (*getpfccfg)(struct net_device___79 *, int, u8 *);
	u8 (*setall)(struct net_device___79 *);
	u8 (*getcap)(struct net_device___79 *, int, u8 *);
	int (*getnumtcs)(struct net_device___79 *, int, u8 *);
	int (*setnumtcs)(struct net_device___79 *, int, u8);
	u8 (*getpfcstate)(struct net_device___79 *);
	void (*setpfcstate)(struct net_device___79 *, u8);
	void (*getbcncfg)(struct net_device___79 *, int, u32 *);
	void (*setbcncfg)(struct net_device___79 *, int, u32);
	void (*getbcnrp)(struct net_device___79 *, int, u8 *);
	void (*setbcnrp)(struct net_device___79 *, int, u8);
	int (*setapp)(struct net_device___79 *, u8, u16, u8);
	int (*getapp)(struct net_device___79 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___79 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___79 *, int, u8);
	u8 (*getdcbx)(struct net_device___79 *);
	u8 (*setdcbx)(struct net_device___79 *, u8);
	int (*peer_getappinfo)(struct net_device___79 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___79 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___79 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___79 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___79 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___79 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___282 {
	refcount_t count;
	struct ns_common___29 ns;
	struct user_namespace___298 *user_ns;
	struct ucounts___298 *ucounts;
	struct css_set___282 *root_cset;
};

struct cgroup_bpf___68 {
	struct bpf_prog_array___68 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___68 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___283;

typedef void (*kthread_work_func_t___283)(struct kthread_work___283 *);

struct kthread_worker___283;

struct kthread_work___283 {
	struct list_head node;
	kthread_work_func_t___283 func;
	struct kthread_worker___283 *worker;
	int canceling;
};

struct kthread_worker___283 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___435 *task;
	struct kthread_work___283 *current_work;
};

struct kthread_delayed_work___282 {
	struct kthread_work___283 work;
	struct timer_list timer;
};

struct psi_group___282 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___283 *poll_kworker;
	struct kthread_delayed_work___282 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___282;

struct cgroup_rstat_cpu___282;

struct cgroup___282 {
	struct cgroup_subsys_state___282 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___428 *kn;
	struct cgroup_file___282 procs_file;
	struct cgroup_file___282 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___282 *subsys[13];
	struct cgroup_root___282 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___282 *dom_cgrp;
	struct cgroup_rstat_cpu___282 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___68 bpf;
	atomic_t congestion_count;
	struct cgroup___282 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___282 psi;
	int ancestor_ids[0];
};

struct cftype___282;

struct cgroup_subsys___282 {
	struct cgroup_subsys_state___282 * (*css_alloc)(struct cgroup_subsys_state___282 *);
	int (*css_online)(struct cgroup_subsys_state___282 *);
	void (*css_offline)(struct cgroup_subsys_state___282 *);
	void (*css_released)(struct cgroup_subsys_state___282 *);
	void (*css_free)(struct cgroup_subsys_state___282 *);
	void (*css_reset)(struct cgroup_subsys_state___282 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___282 *, int);
	int (*css_extra_stat_show)(struct seq_file___372 *, struct cgroup_subsys_state___282 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___435 *);
	void (*cancel_fork)(struct task_struct___435 *);
	void (*fork)(struct task_struct___435 *);
	void (*exit)(struct task_struct___435 *);
	void (*free)(struct task_struct___435 *);
	void (*bind)(struct cgroup_subsys_state___282 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___282 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___282 *dfl_cftypes;
	struct cftype___282 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___282 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___282 *updated_children;
	struct cgroup___282 *updated_next;
};

struct cgroup_root___282 {
	struct kernfs_root___427 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___282 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___282 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___282 *ss;
	struct list_head node;
	struct kernfs_ops___427 *kf_ops;
	int (*open)(struct kernfs_open_file___427 *);
	void (*release)(struct kernfs_open_file___427 *);
	u64 (*read_u64)(struct cgroup_subsys_state___282 *, struct cftype___282 *);
	s64 (*read_s64)(struct cgroup_subsys_state___282 *, struct cftype___282 *);
	int (*seq_show)(struct seq_file___372 *, void *);
	void * (*seq_start)(struct seq_file___372 *, loff_t *);
	void * (*seq_next)(struct seq_file___372 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___372 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___282 *, struct cftype___282 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___282 *, struct cftype___282 *, s64);
	ssize_t (*write)(struct kernfs_open_file___427 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___427 *, struct poll_table_struct___272 *);
};

struct xdp_rxq_info___78 {
	struct net_device___79 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_buff___5 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	long unsigned int handle;
	struct xdp_rxq_info___78 *rxq;
};

struct xdp_frame___78 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___79 *dev_rx;
};

struct netlink_callback___80 {
	struct sk_buff___80 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___80 *);
	int (*dump)(struct sk_buff___80 *, struct netlink_callback___80 *);
	int (*done)(struct netlink_callback___80 *);
	void *data;
	struct module___361 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___78 {
	int (*create)(struct sk_buff___80 *, struct net_device___79 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___80 *, unsigned char *);
	int (*cache)(const struct neighbour___58 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___79 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___78 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___78 *, int);
	int poll_owner;
	struct net_device___79 *dev;
	struct sk_buff___80 *gro_list;
	struct sk_buff___80 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___78 {
	struct net_device___79 *dev;
	struct Qdisc___70 *qdisc;
	struct Qdisc___70 *qdisc_sleeping;
	struct kobject___421 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___79 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___70 {
	struct sk_buff___80 *head;
	struct sk_buff___80 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___70;

struct Qdisc___70 {
	int (*enqueue)(struct sk_buff___80 *, struct Qdisc___70 *, struct sk_buff___80 **);
	struct sk_buff___80 * (*dequeue)(struct Qdisc___70 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___70 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___78 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___78 gso_skb;
	struct qdisc_skb_head___70 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___70 *next_sched;
	struct sk_buff_head___78 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___78 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___421 kobj;
	struct net_device___79 *dev;
	long: 64;
	struct xdp_rxq_info___78 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___78)(struct net_device___79 *, struct sk_buff___80 *, struct net_device___79 *);

struct netdev_bpf___78 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___68 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___68 *prog;
			const struct bpf_prog_offload_ops___68 *ops;
		} verifier;
		struct {
			struct bpf_prog___68 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___78 *offmap;
		};
		struct {
			struct xdp_umem___3 *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___78 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___80 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___78 {
	int (*tls_dev_add)(struct net_device___79 *, struct sock___59 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___79 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___79 *, struct sock___59 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___78 {
	int (*ndo_init)(struct net_device___79 *);
	void (*ndo_uninit)(struct net_device___79 *);
	int (*ndo_open)(struct net_device___79 *);
	int (*ndo_stop)(struct net_device___79 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___80 *, struct net_device___79 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___80 *, struct net_device___79 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___79 *, struct sk_buff___80 *, struct net_device___79 *, select_queue_fallback_t___78);
	void (*ndo_change_rx_flags)(struct net_device___79 *, int);
	void (*ndo_set_rx_mode)(struct net_device___79 *);
	int (*ndo_set_mac_address)(struct net_device___79 *, void *);
	int (*ndo_validate_addr)(struct net_device___79 *);
	int (*ndo_do_ioctl)(struct net_device___79 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___79 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___79 *, int);
	int (*ndo_neigh_setup)(struct net_device___79 *, struct neigh_parms___58 *);
	void (*ndo_tx_timeout)(struct net_device___79 *);
	void (*ndo_get_stats64)(struct net_device___79 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___79 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___79 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___79 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___79 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___79 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___79 *);
	int (*ndo_netpoll_setup)(struct net_device___79 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___79 *);
	int (*ndo_set_vf_mac)(struct net_device___79 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___79 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___79 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___79 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___79 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___79 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___79 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___79 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___79 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___79 *, int, struct sk_buff___80 *);
	int (*ndo_set_vf_guid)(struct net_device___79 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___79 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___79 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___79 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___79 *, const struct sk_buff___80 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___79 *, struct net_device___79 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___79 *, struct net_device___79 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___79 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___79 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___79 *, struct neighbour___58 *);
	void (*ndo_neigh_destroy)(struct net_device___79 *, struct neighbour___58 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___79 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___79 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___79 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___80 *, struct netlink_callback___80 *, struct net_device___79 *, struct net_device___79 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___79 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___79 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___80 *, u32, u32, struct net_device___79 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___79 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___79 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___79 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___79 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___79 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___79 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___79 *, struct net_device___79 *);
	void (*ndo_dfwd_del_station)(struct net_device___79 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___79 *);
	int (*ndo_set_tx_maxrate)(struct net_device___79 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___79 *);
	int (*ndo_change_proto_down)(struct net_device___79 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___79 *, struct sk_buff___80 *);
	void (*ndo_set_rx_headroom)(struct net_device___79 *, int);
	int (*ndo_bpf)(struct net_device___79 *, struct netdev_bpf___78 *);
	int (*ndo_xdp_xmit)(struct net_device___79 *, int, struct xdp_frame___78 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___79 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___79 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___58 {
	possible_net_t___80 net;
	struct net_device___79 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___58 *);
	void (*neigh_cleanup)(struct neighbour___58 *);
	struct neigh_table___58 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___58 {
	u32 (*l3mdev_fib_table)(const struct net_device___79 *);
	struct sk_buff___80 * (*l3mdev_l3_rcv)(struct net_device___79 *, struct sk_buff___80 *, u16);
	struct sk_buff___80 * (*l3mdev_l3_out)(struct net_device___79 *, struct sock___59 *, struct sk_buff___80 *, u16);
	struct dst_entry___58 * (*l3mdev_link_scope_lookup)(const struct net_device___79 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct ndisc_ops___33 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___79 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___79 *, struct neighbour___58 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___79 *, u8, struct neighbour___58 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___79 *, struct sk_buff___80 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___90 *, struct net_device___79 *, const struct prefix_info *, struct inet6_dev___33 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___33;

struct inet6_dev___33 {
	struct net_device___79 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___33 *mc_list;
	struct ifmcaddr6___33 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___11 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	u8 rndid[8];
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___58 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
};

struct tcf_proto___70;

struct mini_Qdisc___70 {
	struct tcf_proto___70 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___70 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___79 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___90 *, struct net_device___79 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___79 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___79 *, struct list_head *);
	size_t (*get_size)(const struct net_device___79 *);
	int (*fill_info)(struct sk_buff___80 *, const struct net_device___79 *);
	size_t (*get_xstats_size)(const struct net_device___79 *);
	int (*fill_xstats)(struct sk_buff___80 *, const struct net_device___79 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___79 *, struct net_device___79 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___79 *, const struct net_device___79 *);
	int (*fill_slave_info)(struct sk_buff___80 *, const struct net_device___79 *, const struct net_device___79 *);
	struct net___90 * (*get_link_net)(const struct net_device___79 *);
	size_t (*get_linkxstats_size)(const struct net_device___79 *, int);
	int (*fill_linkxstats)(struct sk_buff___80 *, const struct net_device___79 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___78 {
	struct list_head poll_list;
	struct sk_buff_head___78 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___78 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___70 *output_queue;
	struct Qdisc___70 **output_queue_tailp;
	struct sk_buff___80 *completion_queue;
	struct sk_buff_head___78 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___78 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___78 input_pkt_queue;
	struct napi_struct___78 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kernel_param_ops___359 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___359 *);
	int (*get)(char *, const struct kernel_param___359 *);
	void (*free)(void *);
};

struct kparam_array___359;

struct kernel_param___359 {
	const char *name;
	struct module___361 *mod;
	const struct kernel_param_ops___359 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___359 *arr;
	};
};

struct kparam_array___359 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___359 *ops;
	void *elem;
};

struct module_attribute___359 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___359 *, struct module_kobject___359 *, char *);
	ssize_t (*store)(struct module_attribute___359 *, struct module_kobject___359 *, const char *, size_t);
	void (*setup)(struct module___361 *, const char *);
	int (*test)(struct module___361 *);
	void (*free)(struct module___361 *);
};

struct gnet_dump___70 {
	spinlock_t *lock;
	struct sk_buff___80 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___70;

struct Qdisc_ops___70 {
	struct Qdisc_ops___70 *next;
	const struct Qdisc_class_ops___70 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___80 *, struct Qdisc___70 *, struct sk_buff___80 **);
	struct sk_buff___80 * (*dequeue)(struct Qdisc___70 *);
	struct sk_buff___80 * (*peek)(struct Qdisc___70 *);
	int (*init)(struct Qdisc___70 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___70 *);
	void (*destroy)(struct Qdisc___70 *);
	int (*change)(struct Qdisc___70 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___70 *);
	int (*change_tx_queue_len)(struct Qdisc___70 *, unsigned int);
	int (*dump)(struct Qdisc___70 *, struct sk_buff___80 *);
	int (*dump_stats)(struct Qdisc___70 *, struct gnet_dump___70 *);
	void (*ingress_block_set)(struct Qdisc___70 *, u32);
	void (*egress_block_set)(struct Qdisc___70 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___70 *);
	u32 (*egress_block_get)(struct Qdisc___70 *);
	struct module___361 *owner;
};

struct tcf_block___70;

struct Qdisc_class_ops___70 {
	unsigned int flags;
	struct netdev_queue___78 * (*select_queue)(struct Qdisc___70 *, struct tcmsg *);
	int (*graft)(struct Qdisc___70 *, long unsigned int, struct Qdisc___70 *, struct Qdisc___70 **, struct netlink_ext_ack *);
	struct Qdisc___70 * (*leaf)(struct Qdisc___70 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___70 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___70 *, u32);
	int (*change)(struct Qdisc___70 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___70 *, long unsigned int);
	void (*walk)(struct Qdisc___70 *, struct qdisc_walker *);
	struct tcf_block___70 * (*tcf_block)(struct Qdisc___70 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___70 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___70 *, long unsigned int);
	int (*dump)(struct Qdisc___70 *, long unsigned int, struct sk_buff___80 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___70 *, long unsigned int, struct gnet_dump___70 *);
};

struct tcf_chain___70;

struct tcf_block___70 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___90 *net;
	struct Qdisc___70 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___70 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___70;

struct tcf_proto_ops___70;

struct tcf_proto___70 {
	struct tcf_proto___70 *next;
	void *root;
	int (*classify)(struct sk_buff___80 *, const struct tcf_proto___70 *, struct tcf_result___70 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___70 *ops;
	struct tcf_chain___70 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___70 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___70 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___70 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___80 *, const struct tcf_proto___70 *, struct tcf_result___70 *);
	int (*init)(struct tcf_proto___70 *);
	void (*destroy)(struct tcf_proto___70 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___70 *, u32);
	void (*put)(struct tcf_proto___70 *, void *);
	int (*change)(struct net___90 *, struct sk_buff___80 *, struct tcf_proto___70 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___70 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___70 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___70 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___90 *, struct tcf_chain___70 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___90 *, struct tcf_proto___70 *, void *, struct sk_buff___80 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___80 *, struct net___90 *, void *);
	struct module___361 *owner;
	int flags;
};

struct tcf_chain___70 {
	struct mutex filter_chain_lock;
	struct tcf_proto___70 *filter_chain;
	struct list_head list;
	struct tcf_block___70 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___70 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___58 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___68 *prog;
};

struct bpf_redirect_info___68 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___283 *map;
	struct bpf_map___283 *map_to_flush;
	u32 kern_flags;
};

struct bdi_writeback_congested___223 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___223 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___223 {
	struct bio___223 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___225 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___225 bip_inline_vecs[0];
};

struct bio_set___223 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___223 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___166 {
	struct mem_cgroup___166 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___166 {
	struct lruvec___434 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___166 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___166 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct pneigh_entry___58;

struct neigh_hash_table___58;

struct neigh_table___58 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___79 *, __u32 *);
	bool (*key_eq)(const struct neighbour___58 *, const void *);
	int (*constructor)(struct neighbour___58 *);
	int (*pconstructor)(struct pneigh_entry___58 *);
	void (*pdestructor)(struct pneigh_entry___58 *);
	void (*proxy_redo)(struct sk_buff___80 *);
	char *id;
	struct neigh_parms___58 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___78 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___58 *nht;
	struct pneigh_entry___58 **phash_buckets;
};

struct neigh_ops___58 {
	int family;
	void (*solicit)(struct neighbour___58 *, struct sk_buff___80 *);
	void (*error_report)(struct neighbour___58 *, struct sk_buff___80 *);
	int (*output)(struct neighbour___58 *, struct sk_buff___80 *);
	int (*connected_output)(struct neighbour___58 *, struct sk_buff___80 *);
};

struct pneigh_entry___58 {
	struct pneigh_entry___58 *next;
	possible_net_t___80 net;
	struct net_device___79 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___58 {
	struct neighbour___58 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___58 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___58 *ctarget;
	struct net___90 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___58 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___58 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___41;

struct timewait_sock_ops___37;

struct proto___58 {
	void (*close)(struct sock___59 *, long int);
	int (*pre_connect)(struct sock___59 *, struct sockaddr *, int);
	int (*connect)(struct sock___59 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___59 *, int);
	struct sock___59 * (*accept)(struct sock___59 *, int, int *, bool);
	int (*ioctl)(struct sock___59 *, int, long unsigned int);
	int (*init)(struct sock___59 *);
	void (*destroy)(struct sock___59 *);
	void (*shutdown)(struct sock___59 *, int);
	int (*setsockopt)(struct sock___59 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___59 *, int, int, char *, int *);
	void (*keepalive)(struct sock___59 *, int);
	int (*sendmsg)(struct sock___59 *, struct msghdr___61 *, size_t);
	int (*recvmsg)(struct sock___59 *, struct msghdr___61 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___59 *, struct page___434 *, int, size_t, int);
	int (*bind)(struct sock___59 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___59 *, struct sk_buff___80 *);
	void (*release_cb)(struct sock___59 *);
	int (*hash)(struct sock___59 *);
	void (*unhash)(struct sock___59 *);
	void (*rehash)(struct sock___59 *);
	int (*get_port)(struct sock___59 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___59 *);
	bool (*stream_memory_read)(const struct sock___59 *);
	void (*enter_memory_pressure)(struct sock___59 *);
	void (*leave_memory_pressure)(struct sock___59 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___41 *rsk_prot;
	struct timewait_sock_ops___37 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___361 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___59 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct request_sock___42;

struct request_sock_ops___41 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___59 *, struct request_sock___42 *);
	void (*send_ack)(const struct sock___59 *, struct sk_buff___80 *, struct request_sock___42 *);
	void (*send_reset)(const struct sock___59 *, struct sk_buff___80 *);
	void (*destructor)(struct request_sock___42 *);
	void (*syn_ack_timeout)(const struct request_sock___42 *);
};

struct timewait_sock_ops___37 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___59 *, struct sock___59 *, void *);
	void (*twsk_destructor)(struct sock___59 *);
};

struct request_sock___42 {
	struct sock_common___58 __req_common;
	struct request_sock___42 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___41 *rsk_ops;
	struct sock___59 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___33 {
	struct in6_addr mca_addr;
	struct inet6_dev___33 *idev;
	struct ifmcaddr6___33 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ip6_ra_chain___33 {
	struct ip6_ra_chain___33 *next;
	struct sock___59 *sk;
	int sel;
	void (*destructor)(struct sock___59 *);
};

struct module___362;

struct file___434;

struct kiocb___434;

struct iov_iter___201;

struct poll_table_struct___273;

struct vm_area_struct___435;

struct inode___434;

struct file_lock___434;

struct page___435;

struct pipe_inode_info___115;

struct seq_file___373;

struct file_operations___434 {
	struct module___362 *owner;
	loff_t (*llseek)(struct file___434 *, loff_t, int);
	ssize_t (*read)(struct file___434 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___434 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___434 *, struct iov_iter___201 *);
	ssize_t (*write_iter)(struct kiocb___434 *, struct iov_iter___201 *);
	int (*iopoll)(struct kiocb___434 *, bool);
	int (*iterate)(struct file___434 *, struct dir_context *);
	int (*iterate_shared)(struct file___434 *, struct dir_context *);
	__poll_t (*poll)(struct file___434 *, struct poll_table_struct___273 *);
	long int (*unlocked_ioctl)(struct file___434 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___434 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___434 *, struct vm_area_struct___435 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___434 *, struct file___434 *);
	int (*flush)(struct file___434 *, fl_owner_t);
	int (*release)(struct inode___434 *, struct file___434 *);
	int (*fsync)(struct file___434 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___434 *, int);
	int (*lock)(struct file___434 *, int, struct file_lock___434 *);
	ssize_t (*sendpage)(struct file___434 *, struct page___435 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___434 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___434 *, int, struct file_lock___434 *);
	ssize_t (*splice_write)(struct pipe_inode_info___115 *, struct file___434 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___434 *, loff_t *, struct pipe_inode_info___115 *, size_t, unsigned int);
	int (*setlease)(struct file___434 *, long int, struct file_lock___434 **, void **);
	long int (*fallocate)(struct file___434 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___373 *, struct file___434 *);
	ssize_t (*copy_file_range)(struct file___434 *, loff_t, struct file___434 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___434 *, loff_t, struct file___434 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___434 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___435 {
	u64 seqnum;
	struct vm_area_struct___435 *vmas[4];
};

struct page_frag___435 {
	struct page___435 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___435;

struct mem_cgroup___167;

struct cred___402;

struct nsproxy___329;

struct signal_struct___309;

struct bio_list___224;

struct backing_dev_info___224;

struct css_set___283;

struct vm_struct___338;

struct task_struct___436 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___436 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___435 *mm;
	struct mm_struct___435 *active_mm;
	struct vmacache___435 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___436 *real_parent;
	struct task_struct___436 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___436 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___167 *active_memcg;
	long int rh_reserved2;
	struct pid___241 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___241 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___241 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___402 *ptracer_cred;
	const struct cred___402 *real_cred;
	const struct cred___402 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___329 *nsproxy;
	struct signal_struct___309 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___436 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___224 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___224 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___283 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___115 *splice_pipe;
	struct page_frag___435 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___167 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___436 *oom_reaper_list;
	struct vm_struct___338 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___156 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___435 *pgtable_t___435;

struct address_space___434;

struct dev_pagemap___422;

struct page___435 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___434 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___435 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___435 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___435 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___422 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___167 *mem_cgroup;
};

struct pglist_data___435;

struct lruvec___435 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___435 *pgdat;
};

struct zone___435 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___435 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___435 {
	struct zone___435 *zone;
	int zone_idx;
};

struct zonelist___435 {
	struct zoneref___435 _zonerefs[25];
};

struct pglist_data___435 {
	struct zone___435 node_zones[3];
	struct zonelist___435 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___436 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___436 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___435 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___436 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___436 *owner;
};

struct secondary_data___436 {
	void *stack;
	struct task_struct___436 *task;
	long int status;
};

struct blocking_notifier_head___435 {
	struct rw_semaphore___436 rwsem;
	struct notifier_block *head;
};

struct cgroup___283;

struct cgroup_subsys___283;

struct cgroup_subsys_state___283 {
	struct cgroup___283 *cgroup;
	struct cgroup_subsys___283 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___283 *parent;
};

struct kernfs_node___429;

struct cgroup_file___283 {
	struct kernfs_node___429 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___167;

struct mem_cgroup___167 {
	struct cgroup_subsys_state___283 css;
	struct mem_cgroup_id___16 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___283 events_file;
	struct cgroup_file___283 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___436 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___167 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct key___402;

struct ucounts___299;

struct user_namespace___299 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___299 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___29 ns;
	long unsigned int flags;
	struct key___402 *persistent_keyring_register;
	struct rw_semaphore___436 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___299 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct user_struct___402 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___402 *uid_keyring;
	struct key___402 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___422;

struct vm_area_struct___435 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___435 *vm_next;
	struct vm_area_struct___435 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___435 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___422 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___434 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___435;

struct mm_struct___435 {
	struct {
		struct vm_area_struct___435 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___434 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___436 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___435 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___436 *owner;
		struct user_namespace___299 *user_ns;
		struct file___434 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___435 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___402 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___402 *session_keyring;
	struct key___402 *process_keyring;
	struct key___402 *thread_keyring;
	struct key___402 *request_key_auth;
	void *security;
	struct user_struct___402 *user;
	struct user_namespace___299 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___91;

struct cgroup_namespace___283;

struct nsproxy___329 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net___91 *net_ns;
	struct cgroup_namespace___283 *cgroup_ns;
};

struct signal_struct___309 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___436 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___436 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___241 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___241 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___435 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___241 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___224;

struct bio_list___224 {
	struct bio___224 *head;
	struct bio___224 *tail;
};

struct bdi_writeback_congested___224;

struct bdi_writeback___224 {
	struct backing_dev_info___224 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___224 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___283 *memcg_css;
	struct cgroup_subsys_state___283 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___402;

struct dentry___434;

struct backing_dev_info___224 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___224 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___402 *dev;
	struct device___402 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___434 *debug_dir;
	struct dentry___434 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___283 {
	struct cgroup_subsys_state___283 *subsys[13];
	refcount_t refcount;
	struct css_set___283 *dom_cset;
	struct cgroup___283 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___283 *mg_src_cgrp;
	struct cgroup___283 *mg_dst_cgrp;
	struct css_set___283 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___434;

struct pipe_buffer___115;

struct pipe_inode_info___115 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___435 *tmp_page;
	struct fasync_struct___434 *fasync_readers;
	struct fasync_struct___434 *fasync_writers;
	struct pipe_buffer___115 *bufs;
	struct user_struct___402 *user;
};

struct vm_struct___338 {
	struct vm_struct___338 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___435 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___321 {
	struct task_struct___436 task;
	long unsigned int stack[8192];
};

struct address_space_operations___434;

struct address_space___434 {
	struct inode___434 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___436 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___434 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___422)(struct vm_area_struct___435 *, long unsigned int, const struct page___435 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___422)(struct page___435 *, void *);

struct dev_pagemap___422 {
	dev_page_fault_t___422 page_fault;
	dev_page_free_t___422 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___402 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___435 {
	struct vfsmount *mnt;
	struct dentry___434 *dentry;
};

struct file___434 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___435 f_path;
	struct inode___434 *f_inode;
	const struct file_operations___434 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___241 f_owner;
	const struct cred___402 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___434 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___422;

struct vm_operations_struct___422 {
	void (*open)(struct vm_area_struct___435 *);
	void (*close)(struct vm_area_struct___435 *);
	int (*split)(struct vm_area_struct___435 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___435 *);
	vm_fault_t (*fault)(struct vm_fault___422 *);
	vm_fault_t (*huge_fault)(struct vm_fault___422 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___422 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___435 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___422 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___422 *);
	int (*access)(struct vm_area_struct___435 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___435 *);
	int (*set_policy)(struct vm_area_struct___435 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___435 *, long unsigned int);
	struct page___435 * (*find_special_page)(struct vm_area_struct___435 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___435 {
	struct task_struct___436 *task;
	struct core_thread___435 *next;
};

struct core_state___435 {
	atomic_t nr_threads;
	struct core_thread___435 dumper;
	struct completion startup;
};

struct vm_fault___422 {
	struct vm_area_struct___435 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___435 *cow_page;
	struct mem_cgroup___167 *memcg;
	struct page___435 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___435 prealloc_pte;
};

struct kset___421;

struct kobj_type___421;

struct kobject___422 {
	const char *name;
	struct list_head entry;
	struct kobject___422 *parent;
	struct kset___421 *kset;
	struct kobj_type___421 *ktype;
	struct kernfs_node___429 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___360 {
	struct kobject___422 kobj;
	struct module___362 *mod;
	struct kobject___422 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___360 {
	struct module___362 *mod;
	struct latch_tree_node node;
};

struct module_layout___360 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___360 mtn;
};

struct module_attribute___360;

struct kernel_param___360;

struct module___362 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___360 mkobj;
	struct module_attribute___360 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___422 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___360 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___360 core_layout;
	struct module_layout___360 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide53;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide54;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bio_vec___226 {
	struct page___435 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___201 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___226 *bvec;
		struct pipe_inode_info___115 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct msghdr___62 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___201 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___434 *msg_iocb;
};

struct kiocb___434 {
	struct file___434 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___434 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dentry_operations___434;

struct super_block___434;

struct dentry___434 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___434 *d_parent;
	struct qstr d_name;
	struct inode___434 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___434 *d_op;
	struct super_block___434 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___434;

struct block_device___434;

struct inode___434 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___434 *i_op;
	struct super_block___434 *i_sb;
	struct address_space___434 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___436 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___224 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___434 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___434 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___115 *i_pipe;
		struct block_device___434 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___434 {
	int (*d_revalidate)(struct dentry___434 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___434 *, unsigned int);
	int (*d_hash)(const struct dentry___434 *, struct qstr *);
	int (*d_compare)(const struct dentry___434 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___434 *);
	int (*d_init)(struct dentry___434 *);
	void (*d_release)(struct dentry___434 *);
	void (*d_prune)(struct dentry___434 *);
	void (*d_iput)(struct dentry___434 *, struct inode___434 *);
	char * (*d_dname)(struct dentry___434 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___435 *);
	int (*d_manage)(const struct path___435 *, bool);
	struct dentry___434 * (*d_real)(struct dentry___434 *, const struct inode___434 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___434;

struct mem_dqinfo___434 {
	struct quota_format_type___434 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___434;

struct quota_info___434 {
	unsigned int flags;
	struct rw_semaphore___436 dqio_sem;
	struct inode___434 *files[3];
	struct mem_dqinfo___434 info[3];
	const struct quota_format_ops___434 *ops[3];
};

struct rcuwait___434 {
	struct task_struct___436 *task;
};

struct percpu_rw_semaphore___434 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___436 rw_sem;
	struct rcuwait___434 writer;
	int readers_block;
};

struct sb_writers___434 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___434 rw_sem[3];
};

struct shrink_control___167;

struct shrinker___167 {
	long unsigned int (*count_objects)(struct shrinker___167 *, struct shrink_control___167 *);
	long unsigned int (*scan_objects)(struct shrinker___167 *, struct shrink_control___167 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___434;

struct super_operations___434;

struct dquot_operations___434;

struct quotactl_ops___434;

struct super_block___434 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___434 *s_type;
	const struct super_operations___434 *s_op;
	const struct dquot_operations___434 *dq_op;
	const struct quotactl_ops___434 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___434 *s_root;
	struct rw_semaphore___436 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___434 *s_bdev;
	struct backing_dev_info___224 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___434 s_dquot;
	struct sb_writers___434 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___434 *s_d_op;
	int cleancache_poolid;
	struct shrinker___167 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___299 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___167 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___167 *memcg;
};

struct iattr___434 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___434 *ia_file;
};

struct dquot___434 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___434 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___434 {
	int qf_fmt_id;
	const struct quota_format_ops___434 *qf_ops;
	struct module___362 *qf_owner;
	struct quota_format_type___434 *qf_next;
};

struct quota_format_ops___434 {
	int (*check_quota_file)(struct super_block___434 *, int);
	int (*read_file_info)(struct super_block___434 *, int);
	int (*write_file_info)(struct super_block___434 *, int);
	int (*free_file_info)(struct super_block___434 *, int);
	int (*read_dqblk)(struct dquot___434 *);
	int (*commit_dqblk)(struct dquot___434 *);
	int (*release_dqblk)(struct dquot___434 *);
	int (*get_next_id)(struct super_block___434 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___434 {
	int (*write_dquot)(struct dquot___434 *);
	struct dquot___434 * (*alloc_dquot)(struct super_block___434 *, int);
	void (*destroy_dquot)(struct dquot___434 *);
	int (*acquire_dquot)(struct dquot___434 *);
	int (*release_dquot)(struct dquot___434 *);
	int (*mark_dirty)(struct dquot___434 *);
	int (*write_info)(struct super_block___434 *, int);
	qsize_t * (*get_reserved_space)(struct inode___434 *);
	int (*get_projid)(struct inode___434 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___434 *, qsize_t *);
	int (*get_next_id)(struct super_block___434 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___434 {
	int (*quota_on)(struct super_block___434 *, int, int, const struct path___435 *);
	int (*quota_off)(struct super_block___434 *, int);
	int (*quota_enable)(struct super_block___434 *, unsigned int);
	int (*quota_disable)(struct super_block___434 *, unsigned int);
	int (*quota_sync)(struct super_block___434 *, int);
	int (*set_info)(struct super_block___434 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___434 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___434 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___434 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___434 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___434 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___187;

struct address_space_operations___434 {
	int (*writepage)(struct page___435 *, struct writeback_control___187 *);
	int (*readpage)(struct file___434 *, struct page___435 *);
	int (*writepages)(struct address_space___434 *, struct writeback_control___187 *);
	int (*set_page_dirty)(struct page___435 *);
	int (*readpages)(struct file___434 *, struct address_space___434 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___434 *, struct address_space___434 *, loff_t, unsigned int, unsigned int, struct page___435 **, void **);
	int (*write_end)(struct file___434 *, struct address_space___434 *, loff_t, unsigned int, unsigned int, struct page___435 *, void *);
	sector_t (*bmap)(struct address_space___434 *, sector_t);
	void (*invalidatepage)(struct page___435 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___435 *, gfp_t);
	void (*freepage)(struct page___435 *);
	ssize_t (*direct_IO)(struct kiocb___434 *, struct iov_iter___201 *);
	int (*migratepage)(struct address_space___434 *, struct page___435 *, struct page___435 *, enum migrate_mode);
	bool (*isolate_page)(struct page___435 *, isolate_mode_t);
	void (*putback_page)(struct page___435 *);
	int (*launder_page)(struct page___435 *);
	int (*is_partially_uptodate)(struct page___435 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___435 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___434 *, struct page___435 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___434 *, sector_t *);
	void (*swap_deactivate)(struct file___434 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___187 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___224 *wb;
	struct inode___434 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___434 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___434 *bd_inode;
	struct super_block___434 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___434 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___224 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___434 {
	struct dentry___434 * (*lookup)(struct inode___434 *, struct dentry___434 *, unsigned int);
	const char * (*get_link)(struct dentry___434 *, struct inode___434 *, struct delayed_call *);
	int (*permission)(struct inode___434 *, int);
	struct posix_acl * (*get_acl)(struct inode___434 *, int);
	int (*readlink)(struct dentry___434 *, char *, int);
	int (*create)(struct inode___434 *, struct dentry___434 *, umode_t, bool);
	int (*link)(struct dentry___434 *, struct inode___434 *, struct dentry___434 *);
	int (*unlink)(struct inode___434 *, struct dentry___434 *);
	int (*symlink)(struct inode___434 *, struct dentry___434 *, const char *);
	int (*mkdir)(struct inode___434 *, struct dentry___434 *, umode_t);
	int (*rmdir)(struct inode___434 *, struct dentry___434 *);
	int (*mknod)(struct inode___434 *, struct dentry___434 *, umode_t, dev_t);
	int (*rename)(struct inode___434 *, struct dentry___434 *, struct inode___434 *, struct dentry___434 *, unsigned int);
	int (*setattr)(struct dentry___434 *, struct iattr___434 *);
	int (*getattr)(const struct path___435 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___434 *, char *, size_t);
	int (*fiemap)(struct inode___434 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___434 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___434 *, struct dentry___434 *, struct file___434 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___434 *, struct dentry___434 *, umode_t);
	int (*set_acl)(struct inode___434 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___434 {
	void (*fl_copy_lock)(struct file_lock___434 *, struct file_lock___434 *);
	void (*fl_release_private)(struct file_lock___434 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___434;

struct file_lock___434 {
	struct file_lock___434 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___434 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___434 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___434 *fl_ops;
	const struct lock_manager_operations___434 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___434 {
	int (*lm_compare_owner)(struct file_lock___434 *, struct file_lock___434 *);
	long unsigned int (*lm_owner_key)(struct file_lock___434 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___434 *);
	int (*lm_grant)(struct file_lock___434 *, int);
	bool (*lm_break)(struct file_lock___434 *);
	int (*lm_change)(struct file_lock___434 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___434 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___434 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___434 *fa_next;
	struct file___434 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___434 {
	const char *name;
	int fs_flags;
	struct dentry___434 * (*mount)(struct file_system_type___434 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___434 *);
	struct module___362 *owner;
	struct file_system_type___434 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___434 {
	struct inode___434 * (*alloc_inode)(struct super_block___434 *);
	void (*destroy_inode)(struct inode___434 *);
	void (*dirty_inode)(struct inode___434 *, int);
	int (*write_inode)(struct inode___434 *, struct writeback_control___187 *);
	int (*drop_inode)(struct inode___434 *);
	void (*evict_inode)(struct inode___434 *);
	void (*put_super)(struct super_block___434 *);
	int (*sync_fs)(struct super_block___434 *, int);
	int (*freeze_super)(struct super_block___434 *);
	int (*freeze_fs)(struct super_block___434 *);
	int (*thaw_super)(struct super_block___434 *);
	int (*unfreeze_fs)(struct super_block___434 *);
	int (*statfs)(struct dentry___434 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___434 *, int *, char *);
	void (*umount_begin)(struct super_block___434 *);
	int (*show_options)(struct seq_file___373 *, struct dentry___434 *);
	int (*show_devname)(struct seq_file___373 *, struct dentry___434 *);
	int (*show_path)(struct seq_file___373 *, struct dentry___434 *);
	int (*show_stats)(struct seq_file___373 *, struct dentry___434 *);
	ssize_t (*quota_read)(struct super_block___434 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___434 *, int, const char *, size_t, loff_t);
	struct dquot___434 ** (*get_dquots)(struct inode___434 *);
	int (*bdev_try_to_free_page)(struct super_block___434 *, struct page___435 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___434 *, struct shrink_control___167 *);
	long int (*free_cached_objects)(struct super_block___434 *, struct shrink_control___167 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___283)(struct file___434 *, wait_queue_head_t *, struct poll_table_struct___273 *);

struct poll_table_struct___273 {
	poll_queue_proc___283 _qproc;
	__poll_t _key;
};

struct seq_operations___373;

struct seq_file___373 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___373 *op;
	int poll_event;
	const struct file___434 *file;
	void *private;
};

typedef void bio_end_io_t___224(struct bio___224 *);

struct bio_integrity_payload___224;

struct bio_set___224;

struct bio___224 {
	struct bio___224 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___224 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___224 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___226 *bi_io_vec;
	struct bio_set___224 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___226 bi_inline_vecs[0];
};

struct socket_wq___60 {
	wait_queue_head_t wait;
	struct fasync_struct___434 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct sock___60;

struct proto_ops___60;

struct socket___61 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___60 *wq;
	struct file___434 *file;
	struct sock___60 *sk;
	const struct proto_ops___60 *ops;
};

typedef struct {
	struct net___91 *net;
} possible_net_t___81;

struct proto___59;

struct sock_common___59 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___59 *skc_prot;
	possible_net_t___81 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___60 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___81;

struct sk_buff_head___79 {
	struct sk_buff___81 *next;
	struct sk_buff___81 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___59;

struct dst_entry___59;

struct net_device___80;

struct sock___60 {
	struct sock_common___59 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___79 sk_error_queue;
	struct sk_buff_head___79 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___81 *head;
		struct sk_buff___81 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___59 *sk_filter;
	union {
		struct socket_wq___60 *sk_wq;
		struct socket_wq___60 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___59 *sk_rx_dst;
	struct dst_entry___59 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___81 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___79 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___435 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___59 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___241 *sk_peer_pid;
	const struct cred___402 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___61 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___167 *sk_memcg;
	void (*sk_state_change)(struct sock___60 *);
	void (*sk_data_ready)(struct sock___60 *);
	void (*sk_write_space)(struct sock___60 *);
	void (*sk_error_report)(struct sock___60 *);
	int (*sk_backlog_rcv)(struct sock___60 *, struct sk_buff___81 *);
	struct sk_buff___81 * (*sk_validate_xmit_skb)(struct sock___60 *, struct net_device___80 *, struct sk_buff___81 *);
	void (*sk_destruct)(struct sock___60 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

typedef int (*sk_read_actor_t___59)(read_descriptor_t *, struct sk_buff___81 *, unsigned int, size_t);

struct proto_ops___60 {
	int family;
	struct module___362 *owner;
	int (*release)(struct socket___61 *);
	int (*bind)(struct socket___61 *, struct sockaddr *, int);
	int (*connect)(struct socket___61 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___61 *, struct socket___61 *);
	int (*accept)(struct socket___61 *, struct socket___61 *, int, bool);
	int (*getname)(struct socket___61 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___434 *, struct socket___61 *, struct poll_table_struct___273 *);
	int (*ioctl)(struct socket___61 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___61 *, int);
	int (*shutdown)(struct socket___61 *, int);
	int (*setsockopt)(struct socket___61 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___61 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___61 *, struct msghdr___62 *, size_t);
	int (*recvmsg)(struct socket___61 *, struct msghdr___62 *, size_t, int);
	int (*mmap)(struct file___434 *, struct socket___61 *, struct vm_area_struct___435 *);
	ssize_t (*sendpage)(struct socket___61 *, struct page___435 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___61 *, loff_t *, struct pipe_inode_info___115 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___60 *, int);
	int (*peek_len)(struct socket___61 *);
	int (*read_sock)(struct sock___60 *, read_descriptor_t *, sk_read_actor_t___59);
	int (*sendpage_locked)(struct sock___60 *, struct page___435 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___60 *, struct msghdr___62 *, size_t);
	int (*set_rcvlowat)(struct sock___60 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct nf_bridge_info___79;

struct sk_buff___81 {
	union {
		struct {
			struct sk_buff___81 *next;
			struct sk_buff___81 *prev;
			union {
				struct net_device___80 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___60 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___81 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___79 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___79;

struct netns_frags___79 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___79 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_rules_ops___59;

struct fib_notifier_ops___60;

struct netns_ipv4___79 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___59 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___60 *fibnl;
	struct sock___60 **icmp_sk;
	struct sock___60 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___60 **tcp_sk;
	struct netns_frags___79 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___59 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___60 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___60 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___59;

struct dst_ops___90 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___90 *);
	struct dst_entry___59 * (*check)(struct dst_entry___59 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___59 *);
	unsigned int (*mtu)(const struct dst_entry___59 *);
	u32 * (*cow_metrics)(struct dst_entry___59 *, long unsigned int);
	void (*destroy)(struct dst_entry___59 *);
	void (*ifdown)(struct dst_entry___59 *, struct net_device___80 *, int);
	struct dst_entry___59 * (*negative_advice)(struct dst_entry___59 *);
	void (*link_failure)(struct sk_buff___81 *);
	void (*update_pmtu)(struct dst_entry___59 *, struct sock___60 *, struct sk_buff___81 *, u32);
	void (*redirect)(struct dst_entry___59 *, struct sock___60 *, struct sk_buff___81 *);
	int (*local_out)(struct net___91 *, struct sock___60 *, struct sk_buff___81 *);
	struct neighbour___59 * (*neigh_lookup)(const struct dst_entry___59 *, struct sk_buff___81 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___59 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___90 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___79 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___90 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___59 *fib6_rules_ops;
	struct sock___60 **icmp_sk;
	struct sock___60 *ndisc_sk;
	struct sock___60 *tcp_sk;
	struct sock___60 *igmp_sk;
	struct sock___60 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___59 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___60 *notifier_ops;
	struct fib_notifier_ops___60 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___60 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___60 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct nf_hook_entries___4;

struct netns_nf___5 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_queue_handler *queue_handler;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header *nf_log_dir_header;
	struct nf_hook_entries___4 *hooks_ipv4[5];
	struct nf_hook_entries___4 *hooks_ipv6[5];
	struct nf_hook_entries___4 *hooks_arp[3];
	struct nf_hook_entries___4 *hooks_bridge[5];
	bool defrag_ipv4;
	bool defrag_ipv6;
};

struct netns_nf_frag___79 {
	struct netns_frags___79 frags;
};

struct netns_xfrm___90 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___60 *nlsk;
	struct sock___60 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___90 xfrm4_dst_ops;
	struct dst_ops___90 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___69;

struct net___91 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___299 *user_ns;
	struct ucounts___299 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___29 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___60 *rtnl;
	struct sock___60 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___80 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___79 ipv4;
	struct netns_ipv6___90 ipv6;
	struct netns_sctp___60 sctp;
	struct netns_nf___5 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___79 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___60 *nfnl;
	struct sock___60 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___90 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___60 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___69 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kernfs_root___428;

struct kernfs_elem_dir___428 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___428 *root;
};

struct kernfs_syscall_ops___428;

struct kernfs_root___428 {
	struct kernfs_node___429 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___428 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___428 {
	struct kernfs_node___429 *target_kn;
};

struct kernfs_ops___428;

struct kernfs_elem_attr___428 {
	const struct kernfs_ops___428 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___429 *notify_next;
};

struct kernfs_node___429 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___429 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___428 dir;
		struct kernfs_elem_symlink___428 symlink;
		struct kernfs_elem_attr___428 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___428;

struct kernfs_ops___428 {
	int (*open)(struct kernfs_open_file___428 *);
	void (*release)(struct kernfs_open_file___428 *);
	int (*seq_show)(struct seq_file___373 *, void *);
	void * (*seq_start)(struct seq_file___373 *, loff_t *);
	void * (*seq_next)(struct seq_file___373 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___373 *, void *);
	ssize_t (*read)(struct kernfs_open_file___428 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___428 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___428 *, struct vm_area_struct___435 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___428 *, struct poll_table_struct___273 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___428 {
	int (*remount_fs)(struct kernfs_root___428 *, int *, char *);
	int (*show_options)(struct seq_file___373 *, struct kernfs_root___428 *);
	int (*mkdir)(struct kernfs_node___429 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___429 *);
	int (*rename)(struct kernfs_node___429 *, struct kernfs_node___429 *, const char *);
	int (*show_path)(struct seq_file___373 *, struct kernfs_node___429 *, struct kernfs_root___428 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___428 {
	struct kernfs_node___429 *kn;
	struct file___434 *file;
	struct seq_file___373 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___422 *vm_ops;
};

struct kobj_ns_type_operations___59 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___60 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___398;

struct attribute_group___399 {
	const char *name;
	umode_t (*is_visible)(struct kobject___422 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___422 *, struct bin_attribute___398 *, int);
	struct attribute **attrs;
	struct bin_attribute___398 **bin_attrs;
};

struct bin_attribute___398 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___434 *, struct kobject___422 *, struct bin_attribute___398 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___434 *, struct kobject___422 *, struct bin_attribute___398 *, char *, loff_t, size_t);
	int (*mmap)(struct file___434 *, struct kobject___422 *, struct bin_attribute___398 *, struct vm_area_struct___435 *);
};

struct sysfs_ops___421 {
	ssize_t (*show)(struct kobject___422 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___422 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___421;

struct kset___421 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___422 kobj;
	const struct kset_uevent_ops___421 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___421 {
	void (*release)(struct kobject___422 *);
	const struct sysfs_ops___421 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___59 * (*child_ns_type)(struct kobject___422 *);
	const void * (*namespace)(struct kobject___422 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___421 {
	int (* const filter)(struct kset___421 *, struct kobject___422 *);
	const char * (* const name)(struct kset___421 *, struct kobject___422 *);
	int (* const uevent)(struct kset___421 *, struct kobject___422 *, struct kobj_uevent_env *);
};

struct kobj_attribute___412 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___422 *, struct kobj_attribute___412 *, char *);
	ssize_t (*store)(struct kobject___422 *, struct kobj_attribute___412 *, const char *, size_t);
};

struct dev_pm_ops___402 {
	int (*prepare)(struct device___402 *);
	void (*complete)(struct device___402 *);
	int (*suspend)(struct device___402 *);
	int (*resume)(struct device___402 *);
	int (*freeze)(struct device___402 *);
	int (*thaw)(struct device___402 *);
	int (*poweroff)(struct device___402 *);
	int (*restore)(struct device___402 *);
	int (*suspend_late)(struct device___402 *);
	int (*resume_early)(struct device___402 *);
	int (*freeze_late)(struct device___402 *);
	int (*thaw_early)(struct device___402 *);
	int (*poweroff_late)(struct device___402 *);
	int (*restore_early)(struct device___402 *);
	int (*suspend_noirq)(struct device___402 *);
	int (*resume_noirq)(struct device___402 *);
	int (*freeze_noirq)(struct device___402 *);
	int (*thaw_noirq)(struct device___402 *);
	int (*poweroff_noirq)(struct device___402 *);
	int (*restore_noirq)(struct device___402 *);
	int (*runtime_suspend)(struct device___402 *);
	int (*runtime_resume)(struct device___402 *);
	int (*runtime_idle)(struct device___402 *);
};

struct dev_pm_info___402 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___402 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___402;

struct bus_type___402;

struct device_driver___402;

struct dev_pm_domain___402;

struct dma_map_ops___174;

struct fwnode_handle___322;

struct class___402;

struct device___402 {
	struct device___402 *parent;
	struct device_private *p;
	struct kobject___422 kobj;
	const char *init_name;
	const struct device_type___402 *type;
	struct mutex mutex;
	struct bus_type___402 *bus;
	struct device_driver___402 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___402 power;
	struct dev_pm_domain___402 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___174 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___322 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___402 *class;
	const struct attribute_group___399 **groups;
	void (*release)(struct device___402 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___402 {
	struct dev_pm_ops___402 ops;
	void (*detach)(struct device___402 *, bool);
	int (*activate)(struct device___402 *);
	void (*sync)(struct device___402 *);
	void (*dismiss)(struct device___402 *);
};

struct bus_type___402 {
	const char *name;
	const char *dev_name;
	struct device___402 *dev_root;
	const struct attribute_group___399 **bus_groups;
	const struct attribute_group___399 **dev_groups;
	const struct attribute_group___399 **drv_groups;
	int (*match)(struct device___402 *, struct device_driver___402 *);
	int (*uevent)(struct device___402 *, struct kobj_uevent_env *);
	int (*probe)(struct device___402 *);
	int (*remove)(struct device___402 *);
	void (*shutdown)(struct device___402 *);
	int (*online)(struct device___402 *);
	int (*offline)(struct device___402 *);
	int (*suspend)(struct device___402 *, pm_message_t);
	int (*resume)(struct device___402 *);
	int (*num_vf)(struct device___402 *);
	int (*dma_configure)(struct device___402 *);
	const struct dev_pm_ops___402 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___402 {
	const char *name;
	struct bus_type___402 *bus;
	struct module___362 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___402 *);
	int (*remove)(struct device___402 *);
	void (*shutdown)(struct device___402 *);
	int (*suspend)(struct device___402 *, pm_message_t);
	int (*resume)(struct device___402 *);
	const struct attribute_group___399 **groups;
	const struct dev_pm_ops___402 *pm;
	void (*coredump)(struct device___402 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___402 {
	const char *name;
	const struct attribute_group___399 **groups;
	int (*uevent)(struct device___402 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___402 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___402 *);
	const struct dev_pm_ops___402 *pm;
};

struct class___402 {
	const char *name;
	struct module___362 *owner;
	const struct attribute_group___399 **class_groups;
	const struct attribute_group___399 **dev_groups;
	struct kobject___422 *dev_kobj;
	int (*dev_uevent)(struct device___402 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___402 *, umode_t *);
	void (*class_release)(struct class___402 *);
	void (*dev_release)(struct device___402 *);
	int (*shutdown_pre)(struct device___402 *);
	const struct kobj_ns_type_operations___59 *ns_type;
	const void * (*namespace)(struct device___402 *);
	const struct dev_pm_ops___402 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___174 {
	void * (*alloc)(struct device___402 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___402 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___402 *, struct vm_area_struct___435 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___402 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___402 *, struct page___435 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___402 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___402 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___402 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___402 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___402 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___402 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___402 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___402 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___402 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___402 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___402 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___402 *, u64);
	u64 (*get_required_mask)(struct device___402 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___322;

struct fwnode_handle___322 {
	struct fwnode_handle___322 *secondary;
	const struct fwnode_operations___322 *ops;
};

typedef void compound_page_dtor___422(struct page___435 *);

struct fwnode_reference_args___322;

struct fwnode_endpoint___322;

struct fwnode_operations___322 {
	struct fwnode_handle___322 * (*get)(struct fwnode_handle___322 *);
	void (*put)(struct fwnode_handle___322 *);
	bool (*device_is_available)(const struct fwnode_handle___322 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___322 *, const struct device___402 *);
	bool (*property_present)(const struct fwnode_handle___322 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___322 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___322 *, const char *, const char **, size_t);
	struct fwnode_handle___322 * (*get_parent)(const struct fwnode_handle___322 *);
	struct fwnode_handle___322 * (*get_next_child_node)(const struct fwnode_handle___322 *, struct fwnode_handle___322 *);
	struct fwnode_handle___322 * (*get_named_child_node)(const struct fwnode_handle___322 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___322 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___322 *);
	struct fwnode_handle___322 * (*graph_get_next_endpoint)(const struct fwnode_handle___322 *, struct fwnode_handle___322 *);
	struct fwnode_handle___322 * (*graph_get_remote_endpoint)(const struct fwnode_handle___322 *);
	struct fwnode_handle___322 * (*graph_get_port_parent)(struct fwnode_handle___322 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___322 *, struct fwnode_endpoint___322 *);
};

struct fwnode_endpoint___322 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___322 *local_fwnode;
};

struct fwnode_reference_args___322 {
	struct fwnode_handle___322 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___115;

struct pipe_buffer___115 {
	struct page___435 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___115 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___115 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___115 *, struct pipe_buffer___115 *);
	void (*release)(struct pipe_inode_info___115 *, struct pipe_buffer___115 *);
	int (*steal)(struct pipe_inode_info___115 *, struct pipe_buffer___115 *);
	union {
		bool (*get)(struct pipe_inode_info___115 *, struct pipe_buffer___115 *);
		struct {
			void (*get)(struct pipe_inode_info___115 *, struct pipe_buffer___115 *);
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
};

struct nf_bridge_info___79 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___79 = 0,
		BRNF_PROTO_8021Q___79 = 1,
		BRNF_PROTO_PPPOE___79 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___80 *physindev;
	struct net_device___80 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___79(struct sk_buff___81 **);

struct net_device_ops___79;

struct ethtool_ops___79;

struct l3mdev_ops___59;

struct xfrmdev_ops___79;

struct tlsdev_ops___79;

struct header_ops___79;

struct in_device___7;

struct netdev_rx_queue___79;

struct mini_Qdisc___71;

struct netdev_queue___79;

struct Qdisc___71;

struct rtnl_link_ops___71;

struct dcbnl_rtnl_ops___79;

struct net_device___80 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___79 *netdev_ops;
	const struct ethtool_ops___79 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___59 *l3mdev_ops;
	const struct ndisc_ops___2 *ndisc_ops;
	const struct xfrmdev_ops___79 *xfrmdev_ops;
	const struct tlsdev_ops___79 *tlsdev_ops;
	const struct header_ops___79 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___421 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device___7 *ip_ptr;
	struct inet6_dev___2 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___79 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___69 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___79 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___71 *miniq_ingress;
	struct netdev_queue___79 *ingress_queue;
	struct nf_hook_entries___4 *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___79 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___71 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___71 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___79 = 0,
		NETREG_REGISTERED___79 = 1,
		NETREG_UNREGISTERING___79 = 2,
		NETREG_UNREGISTERED___79 = 3,
		NETREG_RELEASED___79 = 4,
		NETREG_DUMMY___79 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___79 = 0,
		RTNL_LINK_INITIALIZING___79 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___80 *);
	struct netpoll_info *npinfo;
	possible_net_t___81 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___402 dev;
	const struct attribute_group___399 *sysfs_groups[4];
	const struct attribute_group___399 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___71 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___79 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct skb_frag_struct___15 {
	struct {
		struct page___435 *p;
	} page;
	__u32 page_offset;
	__u32 size;
};

typedef struct skb_frag_struct___15 skb_frag_t___15;

struct skb_shared_info___15 {
	__u8 __unused;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___81 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___15 frags[16];
};

struct ethtool_ops___79 {
	int (*get_settings)(struct net_device___80 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___80 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___80 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___80 *);
	void (*get_regs)(struct net_device___80 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___80 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___80 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___80 *);
	void (*set_msglevel)(struct net_device___80 *, u32);
	int (*nway_reset)(struct net_device___80 *);
	u32 (*get_link)(struct net_device___80 *);
	int (*get_eeprom_len)(struct net_device___80 *);
	int (*get_eeprom)(struct net_device___80 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___80 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___80 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___80 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___80 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___80 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___80 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___80 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___80 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___80 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___80 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___80 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___80 *);
	void (*complete)(struct net_device___80 *);
	u32 (*get_priv_flags)(struct net_device___80 *);
	int (*set_priv_flags)(struct net_device___80 *, u32);
	int (*get_sset_count)(struct net_device___80 *, int);
	int (*get_rxnfc)(struct net_device___80 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___80 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___80 *, struct ethtool_flash *);
	int (*reset)(struct net_device___80 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___80 *);
	u32 (*get_rxfh_indir_size)(struct net_device___80 *);
	int (*get_rxfh)(struct net_device___80 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___80 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___80 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___80 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___80 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___80 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___80 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___80 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___80 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___80 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___80 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___80 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___80 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___80 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___80 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___80 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___80 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___80 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___80 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___80 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___80 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___80 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	int (*get_fecparam)(struct net_device___80 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___80 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___80 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___80 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___80 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___79;

struct inet_frags___79 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___79 *, const void *);
	void (*destructor)(struct inet_frag_queue___79 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___79 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___81 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___81 *fragments_tail;
	struct sk_buff___81 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___79 *net;
	struct callback_head rcu;
};

struct fib_rule___59;

struct fib_lookup_arg___59;

struct fib_rules_ops___59 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___59 *, struct flowi *, int, struct fib_lookup_arg___59 *);
	bool (*suppress)(struct fib_rule___59 *, struct fib_lookup_arg___59 *);
	int (*match)(struct fib_rule___59 *, struct flowi *, int);
	int (*configure)(struct fib_rule___59 *, struct sk_buff___81 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___59 *);
	int (*compare)(struct fib_rule___59 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___59 *, struct sk_buff___81 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___59 *);
	void (*flush_cache)(struct fib_rules_ops___59 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___362 *owner;
	struct net___91 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___60 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___91 *);
	int (*fib_dump)(struct net___91 *, struct notifier_block *);
	struct module___362 *owner;
	struct callback_head rcu;
};

struct dst_entry___59 {
	struct net_device___80 *dev;
	struct dst_ops___90 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___81 *);
	int (*output)(struct net___91 *, struct sock___60 *, struct sk_buff___81 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___59;

struct neigh_parms___59;

struct neigh_ops___59;

struct neighbour___59 {
	struct neighbour___59 *next;
	struct neigh_table___59 *tbl;
	struct neigh_parms___59 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___79 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___59 *, struct sk_buff___81 *);
	const struct neigh_ops___59 *ops;
	struct callback_head rcu;
	struct net_device___80 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct nf_hook_state___4;

typedef unsigned int nf_hookfn___4(void *, struct sk_buff___81 *, const struct nf_hook_state___4 *);

struct nf_hook_entry___4 {
	nf_hookfn___4 *hook;
	void *priv;
};

struct nf_hook_entries___4 {
	u16 num_hook_entries;
	struct nf_hook_entry___4 hooks[0];
};

struct ucounts___299 {
	struct hlist_node node;
	struct user_namespace___299 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_prog_aux___72;

struct bpf_prog___69 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___72 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

typedef int (*key_restrict_link_func_t___403)(struct key___402 *, const struct key_type *, const union key_payload *, struct key___402 *);

struct key_restriction___402;

struct key___402 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___436 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___402 *restrict_link;
};

struct key_restriction___402 {
	key_restrict_link_func_t___403 check;
	struct key___402 *key;
	struct key_type *keytype;
};

struct seq_operations___373 {
	void * (*start)(struct seq_file___373 *, loff_t *);
	void (*stop)(struct seq_file___373 *, void *);
	void * (*next)(struct seq_file___373 *, void *, loff_t *);
	int (*show)(struct seq_file___373 *, void *);
};

struct pernet_operations___80 {
	struct list_head list;
	int (*init)(struct net___91 *);
	void (*exit)(struct net___91 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___79 {
	int (*ieee_getets)(struct net_device___80 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___80 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___80 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___80 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___80 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___80 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___80 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___80 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___80 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___80 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___80 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___80 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___80 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___80 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___80 *);
	u8 (*setstate)(struct net_device___80 *, u8);
	void (*getpermhwaddr)(struct net_device___80 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___80 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___80 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___80 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___80 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___80 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___80 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___80 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___80 *, int, u8 *);
	void (*setpfccfg)(struct net_device___80 *, int, u8);
	void (*getpfccfg)(struct net_device___80 *, int, u8 *);
	u8 (*setall)(struct net_device___80 *);
	u8 (*getcap)(struct net_device___80 *, int, u8 *);
	int (*getnumtcs)(struct net_device___80 *, int, u8 *);
	int (*setnumtcs)(struct net_device___80 *, int, u8);
	u8 (*getpfcstate)(struct net_device___80 *);
	void (*setpfcstate)(struct net_device___80 *, u8);
	void (*getbcncfg)(struct net_device___80 *, int, u32 *);
	void (*setbcncfg)(struct net_device___80 *, int, u32);
	void (*getbcnrp)(struct net_device___80 *, int, u8 *);
	void (*setbcnrp)(struct net_device___80 *, int, u8);
	int (*setapp)(struct net_device___80 *, u8, u16, u8);
	int (*getapp)(struct net_device___80 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___80 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___80 *, int, u8);
	u8 (*getdcbx)(struct net_device___80 *);
	u8 (*setdcbx)(struct net_device___80 *, u8);
	int (*peer_getappinfo)(struct net_device___80 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___80 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___80 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___80 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___80 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___80 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___283 {
	refcount_t count;
	struct ns_common___29 ns;
	struct user_namespace___299 *user_ns;
	struct ucounts___299 *ucounts;
	struct css_set___283 *root_cset;
};

struct bpf_map___284;

struct bpf_map_ops___283 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___284 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___284 *, struct file___434 *);
	void (*map_free)(struct bpf_map___284 *);
	int (*map_get_next_key)(struct bpf_map___284 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___284 *);
	void * (*map_lookup_elem)(struct bpf_map___284 *, void *);
	int (*map_update_elem)(struct bpf_map___284 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___284 *, void *);
	int (*map_push_elem)(struct bpf_map___284 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___284 *, void *);
	int (*map_peek_elem)(struct bpf_map___284 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___284 *, struct file___434 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___284 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___284 *, void *, struct seq_file___373 *);
	int (*map_check_btf)(const struct bpf_map___284 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___284 {
	const struct bpf_map_ops___283 *ops;
	struct bpf_map___284 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___402 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___79;

struct bpf_map_dev_ops___79 {
	int (*map_get_next_key)(struct bpf_offloaded_map___79 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___79 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___79 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___79 *, void *);
};

struct bpf_offloaded_map___79 {
	struct bpf_map___284 map;
	struct net_device___80 *netdev;
	const struct bpf_map_dev_ops___79 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___69 {
	int (*test_run)(struct bpf_prog___69 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___69 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___69 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___69 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___69 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___69 *, u32 *);
};

struct bpf_prog_offload_ops___69 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___69 *);
	int (*translate)(struct bpf_prog___69 *);
	void (*destroy)(struct bpf_prog___69 *);
};

struct bpf_prog_offload___69 {
	struct bpf_prog___69 *prog;
	struct net_device___80 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___69 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___72 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___69 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___69 *ops;
	struct bpf_map___284 **used_maps;
	struct bpf_prog___69 *prog;
	struct user_struct___402 *user;
	u64 load_time;
	struct bpf_map___284 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___69 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___69 {
	struct bpf_prog___69 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___69 {
	struct callback_head rcu;
	struct bpf_prog_array_item___69 items[0];
};

struct cgroup_bpf___69 {
	struct bpf_prog_array___69 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___69 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___284;

typedef void (*kthread_work_func_t___284)(struct kthread_work___284 *);

struct kthread_worker___284;

struct kthread_work___284 {
	struct list_head node;
	kthread_work_func_t___284 func;
	struct kthread_worker___284 *worker;
	int canceling;
};

struct kthread_worker___284 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___436 *task;
	struct kthread_work___284 *current_work;
};

struct kthread_delayed_work___283 {
	struct kthread_work___284 work;
	struct timer_list timer;
};

struct psi_group___283 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___284 *poll_kworker;
	struct kthread_delayed_work___283 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___283;

struct cgroup_rstat_cpu___283;

struct cgroup___283 {
	struct cgroup_subsys_state___283 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___429 *kn;
	struct cgroup_file___283 procs_file;
	struct cgroup_file___283 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___283 *subsys[13];
	struct cgroup_root___283 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___283 *dom_cgrp;
	struct cgroup_rstat_cpu___283 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___69 bpf;
	atomic_t congestion_count;
	struct cgroup___283 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___283 psi;
	int ancestor_ids[0];
};

struct cftype___283;

struct cgroup_subsys___283 {
	struct cgroup_subsys_state___283 * (*css_alloc)(struct cgroup_subsys_state___283 *);
	int (*css_online)(struct cgroup_subsys_state___283 *);
	void (*css_offline)(struct cgroup_subsys_state___283 *);
	void (*css_released)(struct cgroup_subsys_state___283 *);
	void (*css_free)(struct cgroup_subsys_state___283 *);
	void (*css_reset)(struct cgroup_subsys_state___283 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___283 *, int);
	int (*css_extra_stat_show)(struct seq_file___373 *, struct cgroup_subsys_state___283 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___436 *);
	void (*cancel_fork)(struct task_struct___436 *);
	void (*fork)(struct task_struct___436 *);
	void (*exit)(struct task_struct___436 *);
	void (*free)(struct task_struct___436 *);
	void (*bind)(struct cgroup_subsys_state___283 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___283 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___283 *dfl_cftypes;
	struct cftype___283 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___283 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___283 *updated_children;
	struct cgroup___283 *updated_next;
};

struct cgroup_root___283 {
	struct kernfs_root___428 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___283 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___283 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___283 *ss;
	struct list_head node;
	struct kernfs_ops___428 *kf_ops;
	int (*open)(struct kernfs_open_file___428 *);
	void (*release)(struct kernfs_open_file___428 *);
	u64 (*read_u64)(struct cgroup_subsys_state___283 *, struct cftype___283 *);
	s64 (*read_s64)(struct cgroup_subsys_state___283 *, struct cftype___283 *);
	int (*seq_show)(struct seq_file___373 *, void *);
	void * (*seq_start)(struct seq_file___373 *, loff_t *);
	void * (*seq_next)(struct seq_file___373 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___373 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___283 *, struct cftype___283 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___283 *, struct cftype___283 *, s64);
	ssize_t (*write)(struct kernfs_open_file___428 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___428 *, struct poll_table_struct___273 *);
};

struct xdp_rxq_info___79 {
	struct net_device___80 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___79 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___80 *dev_rx;
};

struct netlink_callback___81 {
	struct sk_buff___81 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___81 *);
	int (*dump)(struct sk_buff___81 *, struct netlink_callback___81 *);
	int (*done)(struct netlink_callback___81 *);
	void *data;
	struct module___362 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___79 {
	int (*create)(struct sk_buff___81 *, struct net_device___80 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___81 *, unsigned char *);
	int (*cache)(const struct neighbour___59 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___80 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___79 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___79 *, int);
	int poll_owner;
	struct net_device___80 *dev;
	struct sk_buff___81 *gro_list;
	struct sk_buff___81 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___79 {
	struct net_device___80 *dev;
	struct Qdisc___71 *qdisc;
	struct Qdisc___71 *qdisc_sleeping;
	struct kobject___422 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___80 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___71 {
	struct sk_buff___81 *head;
	struct sk_buff___81 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___71;

struct Qdisc___71 {
	int (*enqueue)(struct sk_buff___81 *, struct Qdisc___71 *, struct sk_buff___81 **);
	struct sk_buff___81 * (*dequeue)(struct Qdisc___71 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___71 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___79 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___79 gso_skb;
	struct qdisc_skb_head___71 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___71 *next_sched;
	struct sk_buff_head___79 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___79 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___422 kobj;
	struct net_device___80 *dev;
	long: 64;
	struct xdp_rxq_info___79 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___79)(struct net_device___80 *, struct sk_buff___81 *, struct net_device___80 *);

struct netdev_bpf___79 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___69 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___69 *prog;
			const struct bpf_prog_offload_ops___69 *ops;
		} verifier;
		struct {
			struct bpf_prog___69 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___79 *offmap;
		};
		struct {
			struct xdp_umem___3 *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___79 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___81 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___79 {
	int (*tls_dev_add)(struct net_device___80 *, struct sock___60 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___80 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___80 *, struct sock___60 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___79 {
	int (*ndo_init)(struct net_device___80 *);
	void (*ndo_uninit)(struct net_device___80 *);
	int (*ndo_open)(struct net_device___80 *);
	int (*ndo_stop)(struct net_device___80 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___81 *, struct net_device___80 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___81 *, struct net_device___80 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___80 *, struct sk_buff___81 *, struct net_device___80 *, select_queue_fallback_t___79);
	void (*ndo_change_rx_flags)(struct net_device___80 *, int);
	void (*ndo_set_rx_mode)(struct net_device___80 *);
	int (*ndo_set_mac_address)(struct net_device___80 *, void *);
	int (*ndo_validate_addr)(struct net_device___80 *);
	int (*ndo_do_ioctl)(struct net_device___80 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___80 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___80 *, int);
	int (*ndo_neigh_setup)(struct net_device___80 *, struct neigh_parms___59 *);
	void (*ndo_tx_timeout)(struct net_device___80 *);
	void (*ndo_get_stats64)(struct net_device___80 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___80 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___80 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___80 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___80 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___80 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___80 *);
	int (*ndo_netpoll_setup)(struct net_device___80 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___80 *);
	int (*ndo_set_vf_mac)(struct net_device___80 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___80 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___80 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___80 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___80 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___80 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___80 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___80 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___80 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___80 *, int, struct sk_buff___81 *);
	int (*ndo_set_vf_guid)(struct net_device___80 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___80 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___80 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___80 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___80 *, const struct sk_buff___81 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___80 *, struct net_device___80 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___80 *, struct net_device___80 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___80 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___80 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___80 *, struct neighbour___59 *);
	void (*ndo_neigh_destroy)(struct net_device___80 *, struct neighbour___59 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___80 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___80 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___80 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___81 *, struct netlink_callback___81 *, struct net_device___80 *, struct net_device___80 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___80 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___80 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___81 *, u32, u32, struct net_device___80 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___80 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___80 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___80 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___80 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___80 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___80 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___80 *, struct net_device___80 *);
	void (*ndo_dfwd_del_station)(struct net_device___80 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___80 *);
	int (*ndo_set_tx_maxrate)(struct net_device___80 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___80 *);
	int (*ndo_change_proto_down)(struct net_device___80 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___80 *, struct sk_buff___81 *);
	void (*ndo_set_rx_headroom)(struct net_device___80 *, int);
	int (*ndo_bpf)(struct net_device___80 *, struct netdev_bpf___79 *);
	int (*ndo_xdp_xmit)(struct net_device___80 *, int, struct xdp_frame___79 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___80 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___80 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___59 {
	possible_net_t___81 net;
	struct net_device___80 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___59 *);
	void (*neigh_cleanup)(struct neighbour___59 *);
	struct neigh_table___59 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___59 {
	u32 (*l3mdev_fib_table)(const struct net_device___80 *);
	struct sk_buff___81 * (*l3mdev_l3_rcv)(struct net_device___80 *, struct sk_buff___81 *, u16);
	struct sk_buff___81 * (*l3mdev_l3_out)(struct net_device___80 *, struct sock___60 *, struct sk_buff___81 *, u16);
	struct dst_entry___59 * (*l3mdev_link_scope_lookup)(const struct net_device___80 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct in_ifaddr___7;

struct in_device___7 {
	struct net_device___80 *dev;
	refcount_t refcnt;
	int dead;
	struct in_ifaddr___7 *ifa_list;
	struct ip_mc_list *mc_list;
	struct ip_mc_list **mc_hash;
	int mc_count;
	spinlock_t mc_tomb_lock;
	struct ip_mc_list *mc_tomb;
	long unsigned int mr_v1_seen;
	long unsigned int mr_v2_seen;
	long unsigned int mr_maxdelay;
	long unsigned int mr_qi;
	long unsigned int mr_qri;
	unsigned char mr_qrv;
	unsigned char mr_gq_running;
	unsigned char mr_ifc_count;
	struct timer_list mr_gq_timer;
	struct timer_list mr_ifc_timer;
	struct neigh_parms___59 *arp_parms;
	struct ipv4_devconf cnf;
	struct callback_head callback_head;
};

struct tcf_proto___71;

struct mini_Qdisc___71 {
	struct tcf_proto___71 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___71 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___80 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___91 *, struct net_device___80 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___80 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___80 *, struct list_head *);
	size_t (*get_size)(const struct net_device___80 *);
	int (*fill_info)(struct sk_buff___81 *, const struct net_device___80 *);
	size_t (*get_xstats_size)(const struct net_device___80 *);
	int (*fill_xstats)(struct sk_buff___81 *, const struct net_device___80 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___80 *, struct net_device___80 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___80 *, const struct net_device___80 *);
	int (*fill_slave_info)(struct sk_buff___81 *, const struct net_device___80 *, const struct net_device___80 *);
	struct net___91 * (*get_link_net)(const struct net_device___80 *);
	size_t (*get_linkxstats_size)(const struct net_device___80 *, int);
	int (*fill_linkxstats)(struct sk_buff___81 *, const struct net_device___80 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct offload_callbacks___7 {
	struct sk_buff___81 * (*gso_segment)(struct sk_buff___81 *, netdev_features_t);
	struct sk_buff___81 ** (*gro_receive)(struct sk_buff___81 **, struct sk_buff___81 *);
	int (*gro_complete)(struct sk_buff___81 *, int);
};

struct softnet_data___79 {
	struct list_head poll_list;
	struct sk_buff_head___79 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___79 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___71 *output_queue;
	struct Qdisc___71 **output_queue_tailp;
	struct sk_buff___81 *completion_queue;
	struct sk_buff_head___79 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___79 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___79 input_pkt_queue;
	struct napi_struct___79 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct nf_hook_state___4 {
	unsigned int hook;
	u_int8_t pf;
	struct net_device___80 *in;
	struct net_device___80 *out;
	struct sock___60 *sk;
	struct net___91 *net;
	int (*okfn)(struct net___91 *, struct sock___60 *, struct sk_buff___81 *);
};

struct nf_hook_ops___2 {
	nf_hookfn___4 *hook;
	struct net_device___80 *dev;
	void *priv;
	u_int8_t pf;
	unsigned int hooknum;
	int priority;
};

struct nf_hook_entries_rcu_head {
	struct callback_head head;
	void *allocation;
};

struct nf_nat_hook___4 {
	int (*parse_nat_setup)(struct nf_conn *, enum nf_nat_manip_type, const struct nlattr *);
	void (*decode_session)(struct sk_buff___81 *, struct flowi *);
	unsigned int (*manip_pkt)(struct sk_buff___81 *, struct nf_conn *, enum nf_nat_manip_type, enum ip_conntrack_dir);
};

struct nf_ct_hook___4 {
	int (*update)(struct net___91 *, struct sk_buff___81 *);
	void (*destroy)(struct nf_conntrack *);
	bool (*get_tuple_skb)(struct nf_conntrack_tuple *, const struct sk_buff___81 *);
};

struct nfnl_ct_hook___4 {
	struct nf_conn * (*get_ct)(const struct sk_buff___81 *, enum ip_conntrack_info *);
	size_t (*build_size)(const struct nf_conn *);
	int (*build)(struct sk_buff___81 *, struct nf_conn *, enum ip_conntrack_info, u_int16_t, u_int16_t);
	int (*parse)(const struct nlattr *, struct nf_conn *);
	int (*attach_expect)(const struct nlattr *, struct nf_conn *, u32, u32);
	void (*seq_adjust)(struct sk_buff___81 *, struct nf_conn *, enum ip_conntrack_info, s32);
};

struct bdi_writeback_congested___224 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___224 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___224 {
	struct bio___224 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___226 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___226 bip_inline_vecs[0];
};

struct bio_set___224 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___224 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___167 {
	struct mem_cgroup___167 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___167 {
	struct lruvec___435 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___167 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___167 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct kernel_param_ops___360 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___360 *);
	int (*get)(char *, const struct kernel_param___360 *);
	void (*free)(void *);
};

struct kparam_array___360;

struct kernel_param___360 {
	const char *name;
	struct module___362 *mod;
	const struct kernel_param_ops___360 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___360 *arr;
	};
};

struct kparam_array___360 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___360 *ops;
	void *elem;
};

struct module_attribute___360 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___360 *, struct module_kobject___360 *, char *);
	ssize_t (*store)(struct module_attribute___360 *, struct module_kobject___360 *, const char *, size_t);
	void (*setup)(struct module___362 *, const char *);
	int (*test)(struct module___362 *);
	void (*free)(struct module___362 *);
};

struct gnet_dump___71 {
	spinlock_t *lock;
	struct sk_buff___81 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___71;

struct Qdisc_ops___71 {
	struct Qdisc_ops___71 *next;
	const struct Qdisc_class_ops___71 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___81 *, struct Qdisc___71 *, struct sk_buff___81 **);
	struct sk_buff___81 * (*dequeue)(struct Qdisc___71 *);
	struct sk_buff___81 * (*peek)(struct Qdisc___71 *);
	int (*init)(struct Qdisc___71 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___71 *);
	void (*destroy)(struct Qdisc___71 *);
	int (*change)(struct Qdisc___71 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___71 *);
	int (*change_tx_queue_len)(struct Qdisc___71 *, unsigned int);
	int (*dump)(struct Qdisc___71 *, struct sk_buff___81 *);
	int (*dump_stats)(struct Qdisc___71 *, struct gnet_dump___71 *);
	void (*ingress_block_set)(struct Qdisc___71 *, u32);
	void (*egress_block_set)(struct Qdisc___71 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___71 *);
	u32 (*egress_block_get)(struct Qdisc___71 *);
	struct module___362 *owner;
};

struct tcf_block___71;

struct Qdisc_class_ops___71 {
	unsigned int flags;
	struct netdev_queue___79 * (*select_queue)(struct Qdisc___71 *, struct tcmsg *);
	int (*graft)(struct Qdisc___71 *, long unsigned int, struct Qdisc___71 *, struct Qdisc___71 **, struct netlink_ext_ack *);
	struct Qdisc___71 * (*leaf)(struct Qdisc___71 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___71 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___71 *, u32);
	int (*change)(struct Qdisc___71 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___71 *, long unsigned int);
	void (*walk)(struct Qdisc___71 *, struct qdisc_walker *);
	struct tcf_block___71 * (*tcf_block)(struct Qdisc___71 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___71 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___71 *, long unsigned int);
	int (*dump)(struct Qdisc___71 *, long unsigned int, struct sk_buff___81 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___71 *, long unsigned int, struct gnet_dump___71 *);
};

struct tcf_chain___71;

struct tcf_block___71 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___91 *net;
	struct Qdisc___71 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___71 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___71;

struct tcf_proto_ops___71;

struct tcf_proto___71 {
	struct tcf_proto___71 *next;
	void *root;
	int (*classify)(struct sk_buff___81 *, const struct tcf_proto___71 *, struct tcf_result___71 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___71 *ops;
	struct tcf_chain___71 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___71 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___71 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___71 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___81 *, const struct tcf_proto___71 *, struct tcf_result___71 *);
	int (*init)(struct tcf_proto___71 *);
	void (*destroy)(struct tcf_proto___71 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___71 *, u32);
	void (*put)(struct tcf_proto___71 *, void *);
	int (*change)(struct net___91 *, struct sk_buff___81 *, struct tcf_proto___71 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___71 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___71 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___71 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___91 *, struct tcf_chain___71 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___91 *, struct tcf_proto___71 *, void *, struct sk_buff___81 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___81 *, struct net___91 *, void *);
	struct module___362 *owner;
	int flags;
};

struct tcf_chain___71 {
	struct mutex filter_chain_lock;
	struct tcf_proto___71 *filter_chain;
	struct list_head list;
	struct tcf_block___71 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___71 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___59 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___69 *prog;
};

struct bpf_redirect_info___69 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___284 *map;
	struct bpf_map___284 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___59;

struct neigh_hash_table___59;

struct neigh_table___59 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___80 *, __u32 *);
	bool (*key_eq)(const struct neighbour___59 *, const void *);
	int (*constructor)(struct neighbour___59 *);
	int (*pconstructor)(struct pneigh_entry___59 *);
	void (*pdestructor)(struct pneigh_entry___59 *);
	void (*proxy_redo)(struct sk_buff___81 *);
	char *id;
	struct neigh_parms___59 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___79 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___59 *nht;
	struct pneigh_entry___59 **phash_buckets;
};

struct neigh_ops___59 {
	int family;
	void (*solicit)(struct neighbour___59 *, struct sk_buff___81 *);
	void (*error_report)(struct neighbour___59 *, struct sk_buff___81 *);
	int (*output)(struct neighbour___59 *, struct sk_buff___81 *);
	int (*connected_output)(struct neighbour___59 *, struct sk_buff___81 *);
};

struct pneigh_entry___59 {
	struct pneigh_entry___59 *next;
	possible_net_t___81 net;
	struct net_device___80 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___59 {
	struct neighbour___59 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___59 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___59 *ctarget;
	struct net___91 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___59 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___59 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___42;

struct timewait_sock_ops___38;

struct proto___59 {
	void (*close)(struct sock___60 *, long int);
	int (*pre_connect)(struct sock___60 *, struct sockaddr *, int);
	int (*connect)(struct sock___60 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___60 *, int);
	struct sock___60 * (*accept)(struct sock___60 *, int, int *, bool);
	int (*ioctl)(struct sock___60 *, int, long unsigned int);
	int (*init)(struct sock___60 *);
	void (*destroy)(struct sock___60 *);
	void (*shutdown)(struct sock___60 *, int);
	int (*setsockopt)(struct sock___60 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___60 *, int, int, char *, int *);
	void (*keepalive)(struct sock___60 *, int);
	int (*sendmsg)(struct sock___60 *, struct msghdr___62 *, size_t);
	int (*recvmsg)(struct sock___60 *, struct msghdr___62 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___60 *, struct page___435 *, int, size_t, int);
	int (*bind)(struct sock___60 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___60 *, struct sk_buff___81 *);
	void (*release_cb)(struct sock___60 *);
	int (*hash)(struct sock___60 *);
	void (*unhash)(struct sock___60 *);
	void (*rehash)(struct sock___60 *);
	int (*get_port)(struct sock___60 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___60 *);
	bool (*stream_memory_read)(const struct sock___60 *);
	void (*enter_memory_pressure)(struct sock___60 *);
	void (*leave_memory_pressure)(struct sock___60 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___42 *rsk_prot;
	struct timewait_sock_ops___38 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___362 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___60 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct request_sock___43;

struct request_sock_ops___42 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___60 *, struct request_sock___43 *);
	void (*send_ack)(const struct sock___60 *, struct sk_buff___81 *, struct request_sock___43 *);
	void (*send_reset)(const struct sock___60 *, struct sk_buff___81 *);
	void (*destructor)(struct request_sock___43 *);
	void (*syn_ack_timeout)(const struct request_sock___43 *);
};

struct timewait_sock_ops___38 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___60 *, struct sock___60 *, void *);
	void (*twsk_destructor)(struct sock___60 *);
};

struct request_sock___43 {
	struct sock_common___59 __req_common;
	struct request_sock___43 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___42 *rsk_ops;
	struct sock___60 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct net_protocol___5 {
	int (*early_demux)(struct sk_buff___81 *);
	int (*early_demux_handler)(struct sk_buff___81 *);
	int (*handler)(struct sk_buff___81 *);
	void (*err_handler)(struct sk_buff___81 *, u32);
	unsigned int no_policy: 1;
	unsigned int netns_ok: 1;
	unsigned int icmp_strict_tag_validation: 1;
};

struct inet6_protocol___5 {
	void (*early_demux)(struct sk_buff___81 *);
	void (*early_demux_handler)(struct sk_buff___81 *);
	int (*handler)(struct sk_buff___81 *);
	void (*err_handler)(struct sk_buff___81 *, struct inet6_skb_parm *, u8, u8, int, __be32);
	unsigned int flags;
};

struct net_offload___5 {
	struct offload_callbacks___7 callbacks;
	unsigned int flags;
};

struct nf_ipv6_ops___2 {
	int (*chk_addr)(struct net___91 *, const struct in6_addr *, const struct net_device___80 *, int);
	void (*route_input)(struct sk_buff___81 *);
	int (*fragment)(struct net___91 *, struct sock___60 *, struct sk_buff___81 *, int (*)(struct net___91 *, struct sock___60 *, struct sk_buff___81 *));
	__sum16 (*checksum)(struct sk_buff___81 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___81 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___91 *, struct dst_entry___59 **, struct flowi *, bool);
	int (*reroute)(struct sk_buff___81 *, const struct nf_queue_entry___2 *);
};

struct in_ifaddr___7 {
	struct hlist_node hash;
	struct in_ifaddr___7 *ifa_next;
	struct in_device___7 *ifa_dev;
	struct callback_head callback_head;
	__be32 ifa_local;
	__be32 ifa_address;
	__be32 ifa_mask;
	__u32 ifa_rt_priority;
	__be32 ifa_broadcast;
	unsigned char ifa_scope;
	unsigned char ifa_prefixlen;
	__u32 ifa_flags;
	char ifa_label[16];
	__u32 ifa_valid_lft;
	__u32 ifa_preferred_lft;
	long unsigned int ifa_cstamp;
	long unsigned int ifa_tstamp;
};

typedef u32 u_int32_t;

struct file___435;

struct kiocb___435;

struct iov_iter___202;

struct poll_table_struct___274;

struct vm_area_struct___436;

struct inode___435;

struct file_lock___435;

struct page___436;

struct pipe_inode_info___116;

struct seq_file___374;

struct file_operations___435 {
	struct module___5 *owner;
	loff_t (*llseek)(struct file___435 *, loff_t, int);
	ssize_t (*read)(struct file___435 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___435 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___435 *, struct iov_iter___202 *);
	ssize_t (*write_iter)(struct kiocb___435 *, struct iov_iter___202 *);
	int (*iopoll)(struct kiocb___435 *, bool);
	int (*iterate)(struct file___435 *, struct dir_context *);
	int (*iterate_shared)(struct file___435 *, struct dir_context *);
	__poll_t (*poll)(struct file___435 *, struct poll_table_struct___274 *);
	long int (*unlocked_ioctl)(struct file___435 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___435 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___435 *, struct vm_area_struct___436 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___435 *, struct file___435 *);
	int (*flush)(struct file___435 *, fl_owner_t);
	int (*release)(struct inode___435 *, struct file___435 *);
	int (*fsync)(struct file___435 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___435 *, int);
	int (*lock)(struct file___435 *, int, struct file_lock___435 *);
	ssize_t (*sendpage)(struct file___435 *, struct page___436 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___435 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___435 *, int, struct file_lock___435 *);
	ssize_t (*splice_write)(struct pipe_inode_info___116 *, struct file___435 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___435 *, loff_t *, struct pipe_inode_info___116 *, size_t, unsigned int);
	int (*setlease)(struct file___435 *, long int, struct file_lock___435 **, void **);
	long int (*fallocate)(struct file___435 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___374 *, struct file___435 *);
	ssize_t (*copy_file_range)(struct file___435 *, loff_t, struct file___435 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___435 *, loff_t, struct file___435 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___435 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___436 {
	u64 seqnum;
	struct vm_area_struct___436 *vmas[4];
};

struct page_frag___436 {
	struct page___436 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___436;

struct mem_cgroup___168;

struct cred___403;

struct nsproxy___330;

struct signal_struct___310;

struct bio_list___225;

struct backing_dev_info___225;

struct css_set___284;

struct vm_struct___339;

struct task_struct___437 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___437 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___436 *mm;
	struct mm_struct___436 *active_mm;
	struct vmacache___436 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___437 *real_parent;
	struct task_struct___437 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___437 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___168 *active_memcg;
	long int rh_reserved2;
	struct pid___241 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___241 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___241 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___403 *ptracer_cred;
	const struct cred___403 *real_cred;
	const struct cred___403 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___330 *nsproxy;
	struct signal_struct___310 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___437 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___225 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___225 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___284 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___116 *splice_pipe;
	struct page_frag___436 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___168 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___437 *oom_reaper_list;
	struct vm_struct___339 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___156 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rw_semaphore___437 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___437 *owner;
};

struct key___403;

struct ucounts___300;

struct user_namespace___300 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___300 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___29 ns;
	long unsigned int flags;
	struct key___403 *persistent_keyring_register;
	struct rw_semaphore___437 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___300 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___436 *pgtable_t___436;

struct address_space___435;

struct dev_pagemap___423;

struct page___436 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___435 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___436 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___436 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___436 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___423 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___168 *mem_cgroup;
};

struct pglist_data___436;

struct lruvec___436 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___436 *pgdat;
};

struct zone___436 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___436 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___436 {
	struct zone___436 *zone;
	int zone_idx;
};

struct zonelist___436 {
	struct zoneref___436 _zonerefs[25];
};

struct pglist_data___436 {
	struct zone___436 node_zones[3];
	struct zonelist___436 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___437 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___437 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___436 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___437 {
	void *stack;
	struct task_struct___437 *task;
	long int status;
};

struct blocking_notifier_head___436 {
	struct rw_semaphore___437 rwsem;
	struct notifier_block *head;
};

struct dentry___435;

struct path___436 {
	struct vfsmount *mnt;
	struct dentry___435 *dentry;
};

struct file___435 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___436 f_path;
	struct inode___435 *f_inode;
	const struct file_operations___435 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___241 f_owner;
	const struct cred___403 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___435 *f_mapping;
	errseq_t f_wb_err;
};

struct user_struct___403;

struct cred___403 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___403 *session_keyring;
	struct key___403 *process_keyring;
	struct key___403 *thread_keyring;
	struct key___403 *request_key_auth;
	void *security;
	struct user_struct___403 *user;
	struct user_namespace___300 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___429;

struct kernfs_elem_dir___429 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___429 *root;
};

struct kernfs_node___430;

struct kernfs_syscall_ops___429;

struct kernfs_root___429 {
	struct kernfs_node___430 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___429 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___429 {
	struct kernfs_node___430 *target_kn;
};

struct kernfs_ops___429;

struct kernfs_elem_attr___429 {
	const struct kernfs_ops___429 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___430 *notify_next;
};

struct kernfs_node___430 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___430 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___429 dir;
		struct kernfs_elem_symlink___429 symlink;
		struct kernfs_elem_attr___429 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___429;

struct kernfs_ops___429 {
	int (*open)(struct kernfs_open_file___429 *);
	void (*release)(struct kernfs_open_file___429 *);
	int (*seq_show)(struct seq_file___374 *, void *);
	void * (*seq_start)(struct seq_file___374 *, loff_t *);
	void * (*seq_next)(struct seq_file___374 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___374 *, void *);
	ssize_t (*read)(struct kernfs_open_file___429 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___429 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___429 *, struct vm_area_struct___436 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___429 *, struct poll_table_struct___274 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___429 {
	int (*remount_fs)(struct kernfs_root___429 *, int *, char *);
	int (*show_options)(struct seq_file___374 *, struct kernfs_root___429 *);
	int (*mkdir)(struct kernfs_node___430 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___430 *);
	int (*rename)(struct kernfs_node___430 *, struct kernfs_node___430 *, const char *);
	int (*show_path)(struct seq_file___374 *, struct kernfs_node___430 *, struct kernfs_root___429 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___374;

struct seq_file___374 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___374 *op;
	int poll_event;
	const struct file___435 *file;
	void *private;
};

struct vm_operations_struct___423;

struct kernfs_open_file___429 {
	struct kernfs_node___430 *kn;
	struct file___435 *file;
	struct seq_file___374 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___423 *vm_ops;
};

struct vm_fault___423;

struct vm_operations_struct___423 {
	void (*open)(struct vm_area_struct___436 *);
	void (*close)(struct vm_area_struct___436 *);
	int (*split)(struct vm_area_struct___436 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___436 *);
	vm_fault_t (*fault)(struct vm_fault___423 *);
	vm_fault_t (*huge_fault)(struct vm_fault___423 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___423 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___436 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___423 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___423 *);
	int (*access)(struct vm_area_struct___436 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___436 *);
	int (*set_policy)(struct vm_area_struct___436 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___436 *, long unsigned int);
	struct page___436 * (*find_special_page)(struct vm_area_struct___436 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___284)(struct file___435 *, wait_queue_head_t *, struct poll_table_struct___274 *);

struct poll_table_struct___274 {
	poll_queue_proc___284 _qproc;
	__poll_t _key;
};

struct vm_area_struct___436 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___436 *vm_next;
	struct vm_area_struct___436 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___436 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___423 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___435 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sock___61;

struct kobj_ns_type_operations___60 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___61 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___3 *net;
} possible_net_t___82;

struct proto___60;

struct sock_common___60 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___60 *skc_prot;
	possible_net_t___82 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___61 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff_head___80 {
	struct sk_buff___2 *next;
	struct sk_buff___2 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___60;

struct socket_wq___61;

struct dst_entry___60;

struct socket___62;

struct sock___61 {
	struct sock_common___60 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___80 sk_error_queue;
	struct sk_buff_head___80 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___2 *head;
		struct sk_buff___2 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___60 *sk_filter;
	union {
		struct socket_wq___61 *sk_wq;
		struct socket_wq___61 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___60 *sk_rx_dst;
	struct dst_entry___60 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___2 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___80 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___436 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___60 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___241 *sk_peer_pid;
	const struct cred___403 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___62 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___168 *sk_memcg;
	void (*sk_state_change)(struct sock___61 *);
	void (*sk_data_ready)(struct sock___61 *);
	void (*sk_write_space)(struct sock___61 *);
	void (*sk_error_report)(struct sock___61 *);
	int (*sk_backlog_rcv)(struct sock___61 *, struct sk_buff___2 *);
	struct sk_buff___2 * (*sk_validate_xmit_skb)(struct sock___61 *, struct net_device___2 *, struct sk_buff___2 *);
	void (*sk_destruct)(struct sock___61 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kobject___423;

struct bin_attribute___399;

struct attribute_group___400 {
	const char *name;
	umode_t (*is_visible)(struct kobject___423 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___423 *, struct bin_attribute___399 *, int);
	struct attribute **attrs;
	struct bin_attribute___399 **bin_attrs;
};

struct kset___422;

struct kobj_type___422;

struct kobject___423 {
	const char *name;
	struct list_head entry;
	struct kobject___423 *parent;
	struct kset___422 *kset;
	struct kobj_type___422 *ktype;
	struct kernfs_node___430 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___399 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___435 *, struct kobject___423 *, struct bin_attribute___399 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___435 *, struct kobject___423 *, struct bin_attribute___399 *, char *, loff_t, size_t);
	int (*mmap)(struct file___435 *, struct kobject___423 *, struct bin_attribute___399 *, struct vm_area_struct___436 *);
};

struct sysfs_ops___422 {
	ssize_t (*show)(struct kobject___423 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___423 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___422;

struct kset___422 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___423 kobj;
	const struct kset_uevent_ops___422 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___422 {
	void (*release)(struct kobject___423 *);
	const struct sysfs_ops___422 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___60 * (*child_ns_type)(struct kobject___423 *);
	const void * (*namespace)(struct kobject___423 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___422 {
	int (* const filter)(struct kset___422 *, struct kobject___423 *);
	const char * (* const name)(struct kset___422 *, struct kobject___423 *);
	int (* const uevent)(struct kset___422 *, struct kobject___423 *, struct kobj_uevent_env *);
};

struct kobj_attribute___413 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___423 *, struct kobj_attribute___413 *, char *);
	ssize_t (*store)(struct kobject___423 *, struct kobj_attribute___413 *, const char *, size_t);
};

struct kernel_param___361;

struct kernel_param_ops___361 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___361 *);
	int (*get)(char *, const struct kernel_param___361 *);
	void (*free)(void *);
};

struct kparam_array___361;

struct kernel_param___361 {
	const char *name;
	struct module___5 *mod;
	const struct kernel_param_ops___361 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___361 *arr;
	};
};

struct kparam_array___361 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___361 *ops;
	void *elem;
};

struct module_kobject___361 {
	struct kobject___423 kobj;
	struct module___5 *mod;
	struct kobject___423 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___361 {
	struct module___5 *mod;
	struct latch_tree_node node;
};

struct module_layout___361 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___361 mtn;
};

struct module_attribute___361;

struct module___5 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___361 mkobj;
	struct module_attribute___361 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___423 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___361 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___361 core_layout;
	struct module_layout___361 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___361 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___361 *, struct module_kobject___361 *, char *);
	ssize_t (*store)(struct module_attribute___361 *, struct module_kobject___361 *, const char *, size_t);
	void (*setup)(struct module___5 *, const char *);
	int (*test)(struct module___5 *);
	void (*free)(struct module___5 *);
};

struct dentry_operations___435;

struct super_block___435;

struct dentry___435 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___435 *d_parent;
	struct qstr d_name;
	struct inode___435 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___435 *d_op;
	struct super_block___435 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___435;

struct address_space___435 {
	struct inode___435 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___437 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___435 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___435;

struct bdi_writeback___225;

struct block_device___435;

struct inode___435 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___435 *i_op;
	struct super_block___435 *i_sb;
	struct address_space___435 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___437 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___225 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___435 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___435 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___116 *i_pipe;
		struct block_device___435 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___435 {
	int (*d_revalidate)(struct dentry___435 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___435 *, unsigned int);
	int (*d_hash)(const struct dentry___435 *, struct qstr *);
	int (*d_compare)(const struct dentry___435 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___435 *);
	int (*d_init)(struct dentry___435 *);
	void (*d_release)(struct dentry___435 *);
	void (*d_prune)(struct dentry___435 *);
	void (*d_iput)(struct dentry___435 *, struct inode___435 *);
	char * (*d_dname)(struct dentry___435 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___436 *);
	int (*d_manage)(const struct path___436 *, bool);
	struct dentry___435 * (*d_real)(struct dentry___435 *, const struct inode___435 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___435;

struct mem_dqinfo___435 {
	struct quota_format_type___435 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___435;

struct quota_info___435 {
	unsigned int flags;
	struct rw_semaphore___437 dqio_sem;
	struct inode___435 *files[3];
	struct mem_dqinfo___435 info[3];
	const struct quota_format_ops___435 *ops[3];
};

struct rcuwait___435 {
	struct task_struct___437 *task;
};

struct percpu_rw_semaphore___435 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___437 rw_sem;
	struct rcuwait___435 writer;
	int readers_block;
};

struct sb_writers___435 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___435 rw_sem[3];
};

struct shrink_control___168;

struct shrinker___168 {
	long unsigned int (*count_objects)(struct shrinker___168 *, struct shrink_control___168 *);
	long unsigned int (*scan_objects)(struct shrinker___168 *, struct shrink_control___168 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___435;

struct super_operations___435;

struct dquot_operations___435;

struct quotactl_ops___435;

struct super_block___435 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___435 *s_type;
	const struct super_operations___435 *s_op;
	const struct dquot_operations___435 *dq_op;
	const struct quotactl_ops___435 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___435 *s_root;
	struct rw_semaphore___437 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___435 *s_bdev;
	struct backing_dev_info___225 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___435 s_dquot;
	struct sb_writers___435 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___435 *s_d_op;
	int cleancache_poolid;
	struct shrinker___168 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___300 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___168 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___168 *memcg;
};

struct cgroup___284;

struct cgroup_subsys___284;

struct cgroup_subsys_state___284 {
	struct cgroup___284 *cgroup;
	struct cgroup_subsys___284 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___284 *parent;
};

struct cgroup_file___284 {
	struct kernfs_node___430 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___168;

struct mem_cgroup___168 {
	struct cgroup_subsys_state___284 css;
	struct mem_cgroup_id___13 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___284 events_file;
	struct cgroup_file___284 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___437 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___168 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct core_state___436;

struct mm_struct___436 {
	struct {
		struct vm_area_struct___436 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___435 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___437 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___436 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___437 *owner;
		struct user_namespace___300 *user_ns;
		struct file___435 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___436 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___423)(struct vm_area_struct___436 *, long unsigned int, const struct page___436 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___423)(struct page___436 *, void *);

struct device___403;

struct dev_pagemap___423 {
	dev_page_fault_t___423 page_fault;
	dev_page_free_t___423 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___403 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___436 {
	struct task_struct___437 *task;
	struct core_thread___436 *next;
};

struct core_state___436 {
	atomic_t nr_threads;
	struct core_thread___436 dumper;
	struct completion startup;
};

struct vm_fault___423 {
	struct vm_area_struct___436 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___436 *cow_page;
	struct mem_cgroup___168 *memcg;
	struct page___436 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___436 prealloc_pte;
};

struct user_struct___403 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___403 *uid_keyring;
	struct key___403 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cgroup_namespace___284;

struct nsproxy___330 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net___3 *net_ns;
	struct cgroup_namespace___284 *cgroup_ns;
};

struct signal_struct___310 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___437 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___437 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___241 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___241 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___436 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___241 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___225;

struct bio_list___225 {
	struct bio___225 *head;
	struct bio___225 *tail;
};

struct bdi_writeback_congested___225;

struct bdi_writeback___225 {
	struct backing_dev_info___225 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___225 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___284 *memcg_css;
	struct cgroup_subsys_state___284 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___225 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___225 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___403 *dev;
	struct device___403 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___435 *debug_dir;
	struct dentry___435 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___284 {
	struct cgroup_subsys_state___284 *subsys[13];
	refcount_t refcount;
	struct css_set___284 *dom_cset;
	struct cgroup___284 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___284 *mg_src_cgrp;
	struct cgroup___284 *mg_dst_cgrp;
	struct css_set___284 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___435;

struct pipe_buffer___116;

struct pipe_inode_info___116 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___436 *tmp_page;
	struct fasync_struct___435 *fasync_readers;
	struct fasync_struct___435 *fasync_writers;
	struct pipe_buffer___116 *bufs;
	struct user_struct___403 *user;
};

struct vm_struct___339 {
	struct vm_struct___339 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___436 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___322 {
	struct task_struct___437 task;
	long unsigned int stack[8192];
};

struct kiocb___435 {
	struct file___435 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___435 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___435 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___435 *ia_file;
};

struct dquot___435 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___435 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___435 {
	int qf_fmt_id;
	const struct quota_format_ops___435 *qf_ops;
	struct module___5 *qf_owner;
	struct quota_format_type___435 *qf_next;
};

struct quota_format_ops___435 {
	int (*check_quota_file)(struct super_block___435 *, int);
	int (*read_file_info)(struct super_block___435 *, int);
	int (*write_file_info)(struct super_block___435 *, int);
	int (*free_file_info)(struct super_block___435 *, int);
	int (*read_dqblk)(struct dquot___435 *);
	int (*commit_dqblk)(struct dquot___435 *);
	int (*release_dqblk)(struct dquot___435 *);
	int (*get_next_id)(struct super_block___435 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___435 {
	int (*write_dquot)(struct dquot___435 *);
	struct dquot___435 * (*alloc_dquot)(struct super_block___435 *, int);
	void (*destroy_dquot)(struct dquot___435 *);
	int (*acquire_dquot)(struct dquot___435 *);
	int (*release_dquot)(struct dquot___435 *);
	int (*mark_dirty)(struct dquot___435 *);
	int (*write_info)(struct super_block___435 *, int);
	qsize_t * (*get_reserved_space)(struct inode___435 *);
	int (*get_projid)(struct inode___435 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___435 *, qsize_t *);
	int (*get_next_id)(struct super_block___435 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___435 {
	int (*quota_on)(struct super_block___435 *, int, int, const struct path___436 *);
	int (*quota_off)(struct super_block___435 *, int);
	int (*quota_enable)(struct super_block___435 *, unsigned int);
	int (*quota_disable)(struct super_block___435 *, unsigned int);
	int (*quota_sync)(struct super_block___435 *, int);
	int (*set_info)(struct super_block___435 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___435 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___435 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___435 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___435 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___435 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___188;

struct address_space_operations___435 {
	int (*writepage)(struct page___436 *, struct writeback_control___188 *);
	int (*readpage)(struct file___435 *, struct page___436 *);
	int (*writepages)(struct address_space___435 *, struct writeback_control___188 *);
	int (*set_page_dirty)(struct page___436 *);
	int (*readpages)(struct file___435 *, struct address_space___435 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___435 *, struct address_space___435 *, loff_t, unsigned int, unsigned int, struct page___436 **, void **);
	int (*write_end)(struct file___435 *, struct address_space___435 *, loff_t, unsigned int, unsigned int, struct page___436 *, void *);
	sector_t (*bmap)(struct address_space___435 *, sector_t);
	void (*invalidatepage)(struct page___436 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___436 *, gfp_t);
	void (*freepage)(struct page___436 *);
	ssize_t (*direct_IO)(struct kiocb___435 *, struct iov_iter___202 *);
	int (*migratepage)(struct address_space___435 *, struct page___436 *, struct page___436 *, enum migrate_mode);
	bool (*isolate_page)(struct page___436 *, isolate_mode_t);
	void (*putback_page)(struct page___436 *);
	int (*launder_page)(struct page___436 *);
	int (*is_partially_uptodate)(struct page___436 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___436 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___435 *, struct page___436 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___435 *, sector_t *);
	void (*swap_deactivate)(struct file___435 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___188 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___225 *wb;
	struct inode___435 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___227;

struct iov_iter___202 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___227 *bvec;
		struct pipe_inode_info___116 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___435 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___435 *bd_inode;
	struct super_block___435 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___435 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___225 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___435 {
	struct dentry___435 * (*lookup)(struct inode___435 *, struct dentry___435 *, unsigned int);
	const char * (*get_link)(struct dentry___435 *, struct inode___435 *, struct delayed_call *);
	int (*permission)(struct inode___435 *, int);
	struct posix_acl * (*get_acl)(struct inode___435 *, int);
	int (*readlink)(struct dentry___435 *, char *, int);
	int (*create)(struct inode___435 *, struct dentry___435 *, umode_t, bool);
	int (*link)(struct dentry___435 *, struct inode___435 *, struct dentry___435 *);
	int (*unlink)(struct inode___435 *, struct dentry___435 *);
	int (*symlink)(struct inode___435 *, struct dentry___435 *, const char *);
	int (*mkdir)(struct inode___435 *, struct dentry___435 *, umode_t);
	int (*rmdir)(struct inode___435 *, struct dentry___435 *);
	int (*mknod)(struct inode___435 *, struct dentry___435 *, umode_t, dev_t);
	int (*rename)(struct inode___435 *, struct dentry___435 *, struct inode___435 *, struct dentry___435 *, unsigned int);
	int (*setattr)(struct dentry___435 *, struct iattr___435 *);
	int (*getattr)(const struct path___436 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___435 *, char *, size_t);
	int (*fiemap)(struct inode___435 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___435 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___435 *, struct dentry___435 *, struct file___435 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___435 *, struct dentry___435 *, umode_t);
	int (*set_acl)(struct inode___435 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___435 {
	void (*fl_copy_lock)(struct file_lock___435 *, struct file_lock___435 *);
	void (*fl_release_private)(struct file_lock___435 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___435;

struct file_lock___435 {
	struct file_lock___435 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___435 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___435 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___435 *fl_ops;
	const struct lock_manager_operations___435 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___435 {
	int (*lm_compare_owner)(struct file_lock___435 *, struct file_lock___435 *);
	long unsigned int (*lm_owner_key)(struct file_lock___435 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___435 *);
	int (*lm_grant)(struct file_lock___435 *, int);
	bool (*lm_break)(struct file_lock___435 *);
	int (*lm_change)(struct file_lock___435 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___435 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___435 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___435 *fa_next;
	struct file___435 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___435 {
	const char *name;
	int fs_flags;
	struct dentry___435 * (*mount)(struct file_system_type___435 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___435 *);
	struct module___5 *owner;
	struct file_system_type___435 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___435 {
	struct inode___435 * (*alloc_inode)(struct super_block___435 *);
	void (*destroy_inode)(struct inode___435 *);
	void (*dirty_inode)(struct inode___435 *, int);
	int (*write_inode)(struct inode___435 *, struct writeback_control___188 *);
	int (*drop_inode)(struct inode___435 *);
	void (*evict_inode)(struct inode___435 *);
	void (*put_super)(struct super_block___435 *);
	int (*sync_fs)(struct super_block___435 *, int);
	int (*freeze_super)(struct super_block___435 *);
	int (*freeze_fs)(struct super_block___435 *);
	int (*thaw_super)(struct super_block___435 *);
	int (*unfreeze_fs)(struct super_block___435 *);
	int (*statfs)(struct dentry___435 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___435 *, int *, char *);
	void (*umount_begin)(struct super_block___435 *);
	int (*show_options)(struct seq_file___374 *, struct dentry___435 *);
	int (*show_devname)(struct seq_file___374 *, struct dentry___435 *);
	int (*show_path)(struct seq_file___374 *, struct dentry___435 *);
	int (*show_stats)(struct seq_file___374 *, struct dentry___435 *);
	ssize_t (*quota_read)(struct super_block___435 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___435 *, int, const char *, size_t, loff_t);
	struct dquot___435 ** (*get_dquots)(struct inode___435 *);
	int (*bdev_try_to_free_page)(struct super_block___435 *, struct page___436 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___435 *, struct shrink_control___168 *);
	long int (*free_cached_objects)(struct super_block___435 *, struct shrink_control___168 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___225(struct bio___225 *);

struct bio_vec___227 {
	struct page___436 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___225;

struct bio_set___225;

struct bio___225 {
	struct bio___225 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___225 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___225 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___227 *bi_io_vec;
	struct bio_set___225 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___227 bi_inline_vecs[0];
};

struct msghdr___63 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___202 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___435 *msg_iocb;
};

struct socket_wq___61 {
	wait_queue_head_t wait;
	struct fasync_struct___435 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___61;

struct socket___62 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___61 *wq;
	struct file___435 *file;
	struct sock___61 *sk;
	const struct proto_ops___61 *ops;
};

typedef int (*sk_read_actor_t___60)(read_descriptor_t *, struct sk_buff___2 *, unsigned int, size_t);

struct proto_ops___61 {
	int family;
	struct module___5 *owner;
	int (*release)(struct socket___62 *);
	int (*bind)(struct socket___62 *, struct sockaddr *, int);
	int (*connect)(struct socket___62 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___62 *, struct socket___62 *);
	int (*accept)(struct socket___62 *, struct socket___62 *, int, bool);
	int (*getname)(struct socket___62 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___435 *, struct socket___62 *, struct poll_table_struct___274 *);
	int (*ioctl)(struct socket___62 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___62 *, int);
	int (*shutdown)(struct socket___62 *, int);
	int (*setsockopt)(struct socket___62 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___62 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___62 *, struct msghdr___63 *, size_t);
	int (*recvmsg)(struct socket___62 *, struct msghdr___63 *, size_t, int);
	int (*mmap)(struct file___435 *, struct socket___62 *, struct vm_area_struct___436 *);
	ssize_t (*sendpage)(struct socket___62 *, struct page___436 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___62 *, loff_t *, struct pipe_inode_info___116 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___61 *, int);
	int (*peek_len)(struct socket___62 *);
	int (*read_sock)(struct sock___61 *, read_descriptor_t *, sk_read_actor_t___60);
	int (*sendpage_locked)(struct sock___61 *, struct page___436 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___61 *, struct msghdr___63 *, size_t);
	int (*set_rcvlowat)(struct sock___61 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct nf_bridge_info___80;

struct sk_buff___2 {
	union {
		struct {
			struct sk_buff___2 *next;
			struct sk_buff___2 *prev;
			union {
				struct net_device___2 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___61 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___2 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___80 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___80;

struct netns_frags___80 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___80 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_rules_ops___60;

struct fib_notifier_ops___61;

struct netns_ipv4___80 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___60 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___61 *fibnl;
	struct sock___61 **icmp_sk;
	struct sock___61 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___61 **tcp_sk;
	struct netns_frags___80 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___60 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___61 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___61 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___60;

struct dst_ops___91 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___91 *);
	struct dst_entry___60 * (*check)(struct dst_entry___60 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___60 *);
	unsigned int (*mtu)(const struct dst_entry___60 *);
	u32 * (*cow_metrics)(struct dst_entry___60 *, long unsigned int);
	void (*destroy)(struct dst_entry___60 *);
	void (*ifdown)(struct dst_entry___60 *, struct net_device___2 *, int);
	struct dst_entry___60 * (*negative_advice)(struct dst_entry___60 *);
	void (*link_failure)(struct sk_buff___2 *);
	void (*update_pmtu)(struct dst_entry___60 *, struct sock___61 *, struct sk_buff___2 *, u32);
	void (*redirect)(struct dst_entry___60 *, struct sock___61 *, struct sk_buff___2 *);
	int (*local_out)(struct net___3 *, struct sock___61 *, struct sk_buff___2 *);
	struct neighbour___60 * (*neigh_lookup)(const struct dst_entry___60 *, struct sk_buff___2 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___60 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___91 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___80 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___91 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___60 *fib6_rules_ops;
	struct sock___61 **icmp_sk;
	struct sock___61 *ndisc_sk;
	struct sock___61 *tcp_sk;
	struct sock___61 *igmp_sk;
	struct sock___61 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___60 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___61 *notifier_ops;
	struct fib_notifier_ops___61 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___61 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___61 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct nf_hook_entries___5;

struct netns_nf___6 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_queue_handler *queue_handler;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header *nf_log_dir_header;
	struct nf_hook_entries___5 *hooks_ipv4[5];
	struct nf_hook_entries___5 *hooks_ipv6[5];
	struct nf_hook_entries___5 *hooks_arp[3];
	struct nf_hook_entries___5 *hooks_bridge[5];
	bool defrag_ipv4;
	bool defrag_ipv6;
};

struct netns_nf_frag___80 {
	struct netns_frags___80 frags;
};

struct netns_xfrm___91 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___61 *nlsk;
	struct sock___61 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___91 xfrm4_dst_ops;
	struct dst_ops___91 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___70;

struct net___3 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___300 *user_ns;
	struct ucounts___300 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___29 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___61 *rtnl;
	struct sock___61 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___2 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___80 ipv4;
	struct netns_ipv6___91 ipv6;
	struct netns_sctp___61 sctp;
	struct netns_nf___6 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___80 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___61 *nfnl;
	struct sock___61 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___91 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___61 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___70 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___403 {
	int (*prepare)(struct device___403 *);
	void (*complete)(struct device___403 *);
	int (*suspend)(struct device___403 *);
	int (*resume)(struct device___403 *);
	int (*freeze)(struct device___403 *);
	int (*thaw)(struct device___403 *);
	int (*poweroff)(struct device___403 *);
	int (*restore)(struct device___403 *);
	int (*suspend_late)(struct device___403 *);
	int (*resume_early)(struct device___403 *);
	int (*freeze_late)(struct device___403 *);
	int (*thaw_early)(struct device___403 *);
	int (*poweroff_late)(struct device___403 *);
	int (*restore_early)(struct device___403 *);
	int (*suspend_noirq)(struct device___403 *);
	int (*resume_noirq)(struct device___403 *);
	int (*freeze_noirq)(struct device___403 *);
	int (*thaw_noirq)(struct device___403 *);
	int (*poweroff_noirq)(struct device___403 *);
	int (*restore_noirq)(struct device___403 *);
	int (*runtime_suspend)(struct device___403 *);
	int (*runtime_resume)(struct device___403 *);
	int (*runtime_idle)(struct device___403 *);
};

struct dev_pm_info___403 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___403 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___403;

struct bus_type___403;

struct device_driver___403;

struct dev_pm_domain___403;

struct dma_map_ops___175;

struct fwnode_handle___323;

struct class___403;

struct device___403 {
	struct device___403 *parent;
	struct device_private *p;
	struct kobject___423 kobj;
	const char *init_name;
	const struct device_type___403 *type;
	struct mutex mutex;
	struct bus_type___403 *bus;
	struct device_driver___403 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___403 power;
	struct dev_pm_domain___403 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___175 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___323 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___403 *class;
	const struct attribute_group___400 **groups;
	void (*release)(struct device___403 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___403 {
	struct dev_pm_ops___403 ops;
	void (*detach)(struct device___403 *, bool);
	int (*activate)(struct device___403 *);
	void (*sync)(struct device___403 *);
	void (*dismiss)(struct device___403 *);
};

struct bus_type___403 {
	const char *name;
	const char *dev_name;
	struct device___403 *dev_root;
	const struct attribute_group___400 **bus_groups;
	const struct attribute_group___400 **dev_groups;
	const struct attribute_group___400 **drv_groups;
	int (*match)(struct device___403 *, struct device_driver___403 *);
	int (*uevent)(struct device___403 *, struct kobj_uevent_env *);
	int (*probe)(struct device___403 *);
	int (*remove)(struct device___403 *);
	void (*shutdown)(struct device___403 *);
	int (*online)(struct device___403 *);
	int (*offline)(struct device___403 *);
	int (*suspend)(struct device___403 *, pm_message_t);
	int (*resume)(struct device___403 *);
	int (*num_vf)(struct device___403 *);
	int (*dma_configure)(struct device___403 *);
	const struct dev_pm_ops___403 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___403 {
	const char *name;
	struct bus_type___403 *bus;
	struct module___5 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___403 *);
	int (*remove)(struct device___403 *);
	void (*shutdown)(struct device___403 *);
	int (*suspend)(struct device___403 *, pm_message_t);
	int (*resume)(struct device___403 *);
	const struct attribute_group___400 **groups;
	const struct dev_pm_ops___403 *pm;
	void (*coredump)(struct device___403 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___403 {
	const char *name;
	const struct attribute_group___400 **groups;
	int (*uevent)(struct device___403 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___403 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___403 *);
	const struct dev_pm_ops___403 *pm;
};

struct class___403 {
	const char *name;
	struct module___5 *owner;
	const struct attribute_group___400 **class_groups;
	const struct attribute_group___400 **dev_groups;
	struct kobject___423 *dev_kobj;
	int (*dev_uevent)(struct device___403 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___403 *, umode_t *);
	void (*class_release)(struct class___403 *);
	void (*dev_release)(struct device___403 *);
	int (*shutdown_pre)(struct device___403 *);
	const struct kobj_ns_type_operations___60 *ns_type;
	const void * (*namespace)(struct device___403 *);
	const struct dev_pm_ops___403 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___175 {
	void * (*alloc)(struct device___403 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___403 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___403 *, struct vm_area_struct___436 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___403 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___403 *, struct page___436 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___403 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___403 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___403 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___403 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___403 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___403 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___403 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___403 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___403 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___403 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___403 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___403 *, u64);
	u64 (*get_required_mask)(struct device___403 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___323;

struct fwnode_handle___323 {
	struct fwnode_handle___323 *secondary;
	const struct fwnode_operations___323 *ops;
};

typedef void compound_page_dtor___423(struct page___436 *);

struct fwnode_reference_args___323;

struct fwnode_endpoint___323;

struct fwnode_operations___323 {
	struct fwnode_handle___323 * (*get)(struct fwnode_handle___323 *);
	void (*put)(struct fwnode_handle___323 *);
	bool (*device_is_available)(const struct fwnode_handle___323 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___323 *, const struct device___403 *);
	bool (*property_present)(const struct fwnode_handle___323 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___323 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___323 *, const char *, const char **, size_t);
	struct fwnode_handle___323 * (*get_parent)(const struct fwnode_handle___323 *);
	struct fwnode_handle___323 * (*get_next_child_node)(const struct fwnode_handle___323 *, struct fwnode_handle___323 *);
	struct fwnode_handle___323 * (*get_named_child_node)(const struct fwnode_handle___323 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___323 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___323 *);
	struct fwnode_handle___323 * (*graph_get_next_endpoint)(const struct fwnode_handle___323 *, struct fwnode_handle___323 *);
	struct fwnode_handle___323 * (*graph_get_remote_endpoint)(const struct fwnode_handle___323 *);
	struct fwnode_handle___323 * (*graph_get_port_parent)(struct fwnode_handle___323 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___323 *, struct fwnode_endpoint___323 *);
};

struct fwnode_endpoint___323 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___323 *local_fwnode;
};

struct fwnode_reference_args___323 {
	struct fwnode_handle___323 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___116;

struct pipe_buffer___116 {
	struct page___436 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___116 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___116 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___116 *, struct pipe_buffer___116 *);
	void (*release)(struct pipe_inode_info___116 *, struct pipe_buffer___116 *);
	int (*steal)(struct pipe_inode_info___116 *, struct pipe_buffer___116 *);
	union {
		bool (*get)(struct pipe_inode_info___116 *, struct pipe_buffer___116 *);
		struct {
			void (*get)(struct pipe_inode_info___116 *, struct pipe_buffer___116 *);
		} __UNIQUE_ID_rh_kabi_hide21;
		union {		};
	};
};

struct nf_bridge_info___80 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___80 = 0,
		BRNF_PROTO_8021Q___80 = 1,
		BRNF_PROTO_PPPOE___80 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___2 *physindev;
	struct net_device___2 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___80(struct sk_buff___2 **);

struct net_device_ops___80;

struct ethtool_ops___80;

struct l3mdev_ops___60;

struct xfrmdev_ops___80;

struct tlsdev_ops___80;

struct header_ops___80;

struct netdev_rx_queue___80;

struct mini_Qdisc___72;

struct netdev_queue___80;

struct Qdisc___72;

struct rtnl_link_ops___72;

struct dcbnl_rtnl_ops___80;

struct net_device___2 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___80 *netdev_ops;
	const struct ethtool_ops___80 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___60 *l3mdev_ops;
	const struct ndisc_ops___2 *ndisc_ops;
	const struct xfrmdev_ops___80 *xfrmdev_ops;
	const struct tlsdev_ops___80 *tlsdev_ops;
	const struct header_ops___80 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___422 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___2 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___80 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___70 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___80 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___72 *miniq_ingress;
	struct netdev_queue___80 *ingress_queue;
	struct nf_hook_entries___5 *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___80 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___72 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___72 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___80 = 0,
		NETREG_REGISTERED___80 = 1,
		NETREG_UNREGISTERING___80 = 2,
		NETREG_UNREGISTERED___80 = 3,
		NETREG_RELEASED___80 = 4,
		NETREG_DUMMY___80 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___80 = 0,
		RTNL_LINK_INITIALIZING___80 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___2 *);
	struct netpoll_info *npinfo;
	possible_net_t___82 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___403 dev;
	const struct attribute_group___400 *sysfs_groups[4];
	const struct attribute_group___400 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___72 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___80 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide35;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct ethtool_ops___80 {
	int (*get_settings)(struct net_device___2 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___2 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___2 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___2 *);
	void (*get_regs)(struct net_device___2 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___2 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___2 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___2 *);
	void (*set_msglevel)(struct net_device___2 *, u32);
	int (*nway_reset)(struct net_device___2 *);
	u32 (*get_link)(struct net_device___2 *);
	int (*get_eeprom_len)(struct net_device___2 *);
	int (*get_eeprom)(struct net_device___2 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___2 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___2 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___2 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___2 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___2 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___2 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___2 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___2 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___2 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___2 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___2 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___2 *);
	void (*complete)(struct net_device___2 *);
	u32 (*get_priv_flags)(struct net_device___2 *);
	int (*set_priv_flags)(struct net_device___2 *, u32);
	int (*get_sset_count)(struct net_device___2 *, int);
	int (*get_rxnfc)(struct net_device___2 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___2 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___2 *, struct ethtool_flash *);
	int (*reset)(struct net_device___2 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___2 *);
	u32 (*get_rxfh_indir_size)(struct net_device___2 *);
	int (*get_rxfh)(struct net_device___2 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___2 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___2 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___2 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___2 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___2 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___2 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___2 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___2 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___2 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___2 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___2 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___2 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___2 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___2 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___2 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___2 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___2 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___2 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___2 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___2 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___2 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	int (*get_fecparam)(struct net_device___2 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___2 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___2 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___2 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___2 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___80;

struct inet_frags___80 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___80 *, const void *);
	void (*destructor)(struct inet_frag_queue___80 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___80 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___2 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___2 *fragments_tail;
	struct sk_buff___2 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___80 *net;
	struct callback_head rcu;
};

struct fib_rule___60;

struct fib_lookup_arg___60;

struct fib_rules_ops___60 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___60 *, struct flowi *, int, struct fib_lookup_arg___60 *);
	bool (*suppress)(struct fib_rule___60 *, struct fib_lookup_arg___60 *);
	int (*match)(struct fib_rule___60 *, struct flowi *, int);
	int (*configure)(struct fib_rule___60 *, struct sk_buff___2 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___60 *);
	int (*compare)(struct fib_rule___60 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___60 *, struct sk_buff___2 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___60 *);
	void (*flush_cache)(struct fib_rules_ops___60 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___5 *owner;
	struct net___3 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___61 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___3 *);
	int (*fib_dump)(struct net___3 *, struct notifier_block *);
	struct module___5 *owner;
	struct callback_head rcu;
};

struct dst_entry___60 {
	struct net_device___2 *dev;
	struct dst_ops___91 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___2 *);
	int (*output)(struct net___3 *, struct sock___61 *, struct sk_buff___2 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___60;

struct neigh_parms___60;

struct neigh_ops___60;

struct neighbour___60 {
	struct neighbour___60 *next;
	struct neigh_table___60 *tbl;
	struct neigh_parms___60 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___80 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___60 *, struct sk_buff___2 *);
	const struct neigh_ops___60 *ops;
	struct callback_head rcu;
	struct net_device___2 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct nf_hook_state___5;

typedef unsigned int nf_hookfn___5(void *, struct sk_buff___2 *, const struct nf_hook_state___5 *);

struct nf_hook_entry___5 {
	nf_hookfn___5 *hook;
	void *priv;
};

struct nf_hook_entries___5 {
	u16 num_hook_entries;
	struct nf_hook_entry___5 hooks[0];
};

struct ucounts___300 {
	struct hlist_node node;
	struct user_namespace___300 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_prog_aux___73;

struct bpf_prog___70 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___73 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

typedef int (*key_restrict_link_func_t___404)(struct key___403 *, const struct key_type *, const union key_payload *, struct key___403 *);

struct key_restriction___403;

struct key___403 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___437 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___403 *restrict_link;
};

struct key_restriction___403 {
	key_restrict_link_func_t___404 check;
	struct key___403 *key;
	struct key_type *keytype;
};

struct seq_operations___374 {
	void * (*start)(struct seq_file___374 *, loff_t *);
	void (*stop)(struct seq_file___374 *, void *);
	void * (*next)(struct seq_file___374 *, void *, loff_t *);
	int (*show)(struct seq_file___374 *, void *);
};

struct seq_net_private___5 {
	struct net___3 *net;
};

struct pernet_operations___81 {
	struct list_head list;
	int (*init)(struct net___3 *);
	void (*exit)(struct net___3 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___80 {
	int (*ieee_getets)(struct net_device___2 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___2 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___2 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___2 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___2 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___2 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___2 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___2 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___2 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___2 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___2 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___2 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___2 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___2 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___2 *);
	u8 (*setstate)(struct net_device___2 *, u8);
	void (*getpermhwaddr)(struct net_device___2 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___2 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___2 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___2 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___2 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___2 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___2 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___2 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___2 *, int, u8 *);
	void (*setpfccfg)(struct net_device___2 *, int, u8);
	void (*getpfccfg)(struct net_device___2 *, int, u8 *);
	u8 (*setall)(struct net_device___2 *);
	u8 (*getcap)(struct net_device___2 *, int, u8 *);
	int (*getnumtcs)(struct net_device___2 *, int, u8 *);
	int (*setnumtcs)(struct net_device___2 *, int, u8);
	u8 (*getpfcstate)(struct net_device___2 *);
	void (*setpfcstate)(struct net_device___2 *, u8);
	void (*getbcncfg)(struct net_device___2 *, int, u32 *);
	void (*setbcncfg)(struct net_device___2 *, int, u32);
	void (*getbcnrp)(struct net_device___2 *, int, u8 *);
	void (*setbcnrp)(struct net_device___2 *, int, u8);
	int (*setapp)(struct net_device___2 *, u8, u16, u8);
	int (*getapp)(struct net_device___2 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___2 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___2 *, int, u8);
	u8 (*getdcbx)(struct net_device___2 *);
	u8 (*setdcbx)(struct net_device___2 *, u8);
	int (*peer_getappinfo)(struct net_device___2 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___2 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___2 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___2 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___2 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___2 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___284 {
	refcount_t count;
	struct ns_common___29 ns;
	struct user_namespace___300 *user_ns;
	struct ucounts___300 *ucounts;
	struct css_set___284 *root_cset;
};

struct bpf_map___285;

struct bpf_map_ops___284 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___285 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___285 *, struct file___435 *);
	void (*map_free)(struct bpf_map___285 *);
	int (*map_get_next_key)(struct bpf_map___285 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___285 *);
	void * (*map_lookup_elem)(struct bpf_map___285 *, void *);
	int (*map_update_elem)(struct bpf_map___285 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___285 *, void *);
	int (*map_push_elem)(struct bpf_map___285 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___285 *, void *);
	int (*map_peek_elem)(struct bpf_map___285 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___285 *, struct file___435 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___285 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___285 *, void *, struct seq_file___374 *);
	int (*map_check_btf)(const struct bpf_map___285 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___285 {
	const struct bpf_map_ops___284 *ops;
	struct bpf_map___285 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___403 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___80;

struct bpf_map_dev_ops___80 {
	int (*map_get_next_key)(struct bpf_offloaded_map___80 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___80 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___80 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___80 *, void *);
};

struct bpf_offloaded_map___80 {
	struct bpf_map___285 map;
	struct net_device___2 *netdev;
	const struct bpf_map_dev_ops___80 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___70 {
	int (*test_run)(struct bpf_prog___70 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___70 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___70 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___70 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___70 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___70 *, u32 *);
};

struct bpf_prog_offload_ops___70 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___70 *);
	int (*translate)(struct bpf_prog___70 *);
	void (*destroy)(struct bpf_prog___70 *);
};

struct bpf_prog_offload___70 {
	struct bpf_prog___70 *prog;
	struct net_device___2 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___70 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___73 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___70 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___70 *ops;
	struct bpf_map___285 **used_maps;
	struct bpf_prog___70 *prog;
	struct user_struct___403 *user;
	u64 load_time;
	struct bpf_map___285 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___70 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___70 {
	struct bpf_prog___70 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___70 {
	struct callback_head rcu;
	struct bpf_prog_array_item___70 items[0];
};

struct cgroup_bpf___70 {
	struct bpf_prog_array___70 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___70 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___285;

typedef void (*kthread_work_func_t___285)(struct kthread_work___285 *);

struct kthread_worker___285;

struct kthread_work___285 {
	struct list_head node;
	kthread_work_func_t___285 func;
	struct kthread_worker___285 *worker;
	int canceling;
};

struct kthread_worker___285 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___437 *task;
	struct kthread_work___285 *current_work;
};

struct kthread_delayed_work___284 {
	struct kthread_work___285 work;
	struct timer_list timer;
};

struct psi_group___284 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___285 *poll_kworker;
	struct kthread_delayed_work___284 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___284;

struct cgroup_rstat_cpu___284;

struct cgroup___284 {
	struct cgroup_subsys_state___284 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___430 *kn;
	struct cgroup_file___284 procs_file;
	struct cgroup_file___284 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___284 *subsys[13];
	struct cgroup_root___284 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___284 *dom_cgrp;
	struct cgroup_rstat_cpu___284 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___70 bpf;
	atomic_t congestion_count;
	struct cgroup___284 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___284 psi;
	int ancestor_ids[0];
};

struct cftype___284;

struct cgroup_subsys___284 {
	struct cgroup_subsys_state___284 * (*css_alloc)(struct cgroup_subsys_state___284 *);
	int (*css_online)(struct cgroup_subsys_state___284 *);
	void (*css_offline)(struct cgroup_subsys_state___284 *);
	void (*css_released)(struct cgroup_subsys_state___284 *);
	void (*css_free)(struct cgroup_subsys_state___284 *);
	void (*css_reset)(struct cgroup_subsys_state___284 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___284 *, int);
	int (*css_extra_stat_show)(struct seq_file___374 *, struct cgroup_subsys_state___284 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___437 *);
	void (*cancel_fork)(struct task_struct___437 *);
	void (*fork)(struct task_struct___437 *);
	void (*exit)(struct task_struct___437 *);
	void (*free)(struct task_struct___437 *);
	void (*bind)(struct cgroup_subsys_state___284 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___284 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___284 *dfl_cftypes;
	struct cftype___284 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___284 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___284 *updated_children;
	struct cgroup___284 *updated_next;
};

struct cgroup_root___284 {
	struct kernfs_root___429 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___284 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___284 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___284 *ss;
	struct list_head node;
	struct kernfs_ops___429 *kf_ops;
	int (*open)(struct kernfs_open_file___429 *);
	void (*release)(struct kernfs_open_file___429 *);
	u64 (*read_u64)(struct cgroup_subsys_state___284 *, struct cftype___284 *);
	s64 (*read_s64)(struct cgroup_subsys_state___284 *, struct cftype___284 *);
	int (*seq_show)(struct seq_file___374 *, void *);
	void * (*seq_start)(struct seq_file___374 *, loff_t *);
	void * (*seq_next)(struct seq_file___374 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___374 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___284 *, struct cftype___284 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___284 *, struct cftype___284 *, s64);
	ssize_t (*write)(struct kernfs_open_file___429 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___429 *, struct poll_table_struct___274 *);
};

struct xdp_rxq_info___80 {
	struct net_device___2 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___80 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___2 *dev_rx;
};

struct netlink_callback___82 {
	struct sk_buff___2 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___82 *);
	int (*dump)(struct sk_buff___2 *, struct netlink_callback___82 *);
	int (*done)(struct netlink_callback___82 *);
	void *data;
	struct module___5 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___80 {
	int (*create)(struct sk_buff___2 *, struct net_device___2 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___2 *, unsigned char *);
	int (*cache)(const struct neighbour___60 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___2 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___80 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___80 *, int);
	int poll_owner;
	struct net_device___2 *dev;
	struct sk_buff___2 *gro_list;
	struct sk_buff___2 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___80 {
	struct net_device___2 *dev;
	struct Qdisc___72 *qdisc;
	struct Qdisc___72 *qdisc_sleeping;
	struct kobject___423 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___2 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem___3 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___72 {
	struct sk_buff___2 *head;
	struct sk_buff___2 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___72;

struct Qdisc___72 {
	int (*enqueue)(struct sk_buff___2 *, struct Qdisc___72 *, struct sk_buff___2 **);
	struct sk_buff___2 * (*dequeue)(struct Qdisc___72 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___72 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___80 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___80 gso_skb;
	struct qdisc_skb_head___72 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___72 *next_sched;
	struct sk_buff_head___80 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___80 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___423 kobj;
	struct net_device___2 *dev;
	long: 64;
	struct xdp_rxq_info___80 xdp_rxq;
	union {
		struct xdp_umem___3 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___80)(struct net_device___2 *, struct sk_buff___2 *, struct net_device___2 *);

struct netdev_bpf___80 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___70 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___70 *prog;
			const struct bpf_prog_offload_ops___70 *ops;
		} verifier;
		struct {
			struct bpf_prog___70 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___80 *offmap;
		};
		struct {
			struct xdp_umem___3 *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___80 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___2 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___80 {
	int (*tls_dev_add)(struct net_device___2 *, struct sock___61 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___2 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___2 *, struct sock___61 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___80 {
	int (*ndo_init)(struct net_device___2 *);
	void (*ndo_uninit)(struct net_device___2 *);
	int (*ndo_open)(struct net_device___2 *);
	int (*ndo_stop)(struct net_device___2 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___2 *, struct net_device___2 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___2 *, struct net_device___2 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___2 *, struct sk_buff___2 *, struct net_device___2 *, select_queue_fallback_t___80);
	void (*ndo_change_rx_flags)(struct net_device___2 *, int);
	void (*ndo_set_rx_mode)(struct net_device___2 *);
	int (*ndo_set_mac_address)(struct net_device___2 *, void *);
	int (*ndo_validate_addr)(struct net_device___2 *);
	int (*ndo_do_ioctl)(struct net_device___2 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___2 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___2 *, int);
	int (*ndo_neigh_setup)(struct net_device___2 *, struct neigh_parms___60 *);
	void (*ndo_tx_timeout)(struct net_device___2 *);
	void (*ndo_get_stats64)(struct net_device___2 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___2 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___2 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___2 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___2 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___2 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___2 *);
	int (*ndo_netpoll_setup)(struct net_device___2 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___2 *);
	int (*ndo_set_vf_mac)(struct net_device___2 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___2 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___2 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___2 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___2 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___2 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___2 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___2 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___2 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___2 *, int, struct sk_buff___2 *);
	int (*ndo_set_vf_guid)(struct net_device___2 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___2 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___2 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___2 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___2 *, const struct sk_buff___2 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___2 *, struct net_device___2 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___2 *, struct net_device___2 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___2 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___2 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___2 *, struct neighbour___60 *);
	void (*ndo_neigh_destroy)(struct net_device___2 *, struct neighbour___60 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___2 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___2 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___2 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___2 *, struct netlink_callback___82 *, struct net_device___2 *, struct net_device___2 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___2 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___2 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___2 *, u32, u32, struct net_device___2 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___2 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___2 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___2 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___2 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___2 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___2 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___2 *, struct net_device___2 *);
	void (*ndo_dfwd_del_station)(struct net_device___2 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___2 *);
	int (*ndo_set_tx_maxrate)(struct net_device___2 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___2 *);
	int (*ndo_change_proto_down)(struct net_device___2 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___2 *, struct sk_buff___2 *);
	void (*ndo_set_rx_headroom)(struct net_device___2 *, int);
	int (*ndo_bpf)(struct net_device___2 *, struct netdev_bpf___80 *);
	int (*ndo_xdp_xmit)(struct net_device___2 *, int, struct xdp_frame___80 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___2 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___2 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___60 {
	possible_net_t___82 net;
	struct net_device___2 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___60 *);
	void (*neigh_cleanup)(struct neighbour___60 *);
	struct neigh_table___60 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___60 {
	u32 (*l3mdev_fib_table)(const struct net_device___2 *);
	struct sk_buff___2 * (*l3mdev_l3_rcv)(struct net_device___2 *, struct sk_buff___2 *, u16);
	struct sk_buff___2 * (*l3mdev_l3_out)(struct net_device___2 *, struct sock___61 *, struct sk_buff___2 *, u16);
	struct dst_entry___60 * (*l3mdev_link_scope_lookup)(const struct net_device___2 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct tcf_proto___72;

struct mini_Qdisc___72 {
	struct tcf_proto___72 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___72 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___2 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___3 *, struct net_device___2 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___2 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___2 *, struct list_head *);
	size_t (*get_size)(const struct net_device___2 *);
	int (*fill_info)(struct sk_buff___2 *, const struct net_device___2 *);
	size_t (*get_xstats_size)(const struct net_device___2 *);
	int (*fill_xstats)(struct sk_buff___2 *, const struct net_device___2 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___2 *, struct net_device___2 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___2 *, const struct net_device___2 *);
	int (*fill_slave_info)(struct sk_buff___2 *, const struct net_device___2 *, const struct net_device___2 *);
	struct net___3 * (*get_link_net)(const struct net_device___2 *);
	size_t (*get_linkxstats_size)(const struct net_device___2 *, int);
	int (*fill_linkxstats)(struct sk_buff___2 *, const struct net_device___2 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct offload_callbacks___8 {
	struct sk_buff___2 * (*gso_segment)(struct sk_buff___2 *, netdev_features_t);
	struct sk_buff___2 ** (*gro_receive)(struct sk_buff___2 **, struct sk_buff___2 *);
	int (*gro_complete)(struct sk_buff___2 *, int);
};

struct softnet_data___80 {
	struct list_head poll_list;
	struct sk_buff_head___80 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___80 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___72 *output_queue;
	struct Qdisc___72 **output_queue_tailp;
	struct sk_buff___2 *completion_queue;
	struct sk_buff_head___80 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___80 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___80 input_pkt_queue;
	struct napi_struct___80 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct nf_hook_state___5 {
	unsigned int hook;
	u_int8_t pf;
	struct net_device___2 *in;
	struct net_device___2 *out;
	struct sock___61 *sk;
	struct net___3 *net;
	int (*okfn)(struct net___3 *, struct sock___61 *, struct sk_buff___2 *);
};

struct nf_nat_hook___5 {
	int (*parse_nat_setup)(struct nf_conn *, enum nf_nat_manip_type, const struct nlattr *);
	void (*decode_session)(struct sk_buff___2 *, struct flowi *);
	unsigned int (*manip_pkt)(struct sk_buff___2 *, struct nf_conn *, enum nf_nat_manip_type, enum ip_conntrack_dir);
};

struct nf_ct_hook___5 {
	int (*update)(struct net___3 *, struct sk_buff___2 *);
	void (*destroy)(struct nf_conntrack *);
	bool (*get_tuple_skb)(struct nf_conntrack_tuple *, const struct sk_buff___2 *);
};

struct nfnl_ct_hook___5 {
	struct nf_conn * (*get_ct)(const struct sk_buff___2 *, enum ip_conntrack_info *);
	size_t (*build_size)(const struct nf_conn *);
	int (*build)(struct sk_buff___2 *, struct nf_conn *, enum ip_conntrack_info, u_int16_t, u_int16_t);
	int (*parse)(const struct nlattr *, struct nf_conn *);
	int (*attach_expect)(const struct nlattr *, struct nf_conn *, u32, u32);
	void (*seq_adjust)(struct sk_buff___2 *, struct nf_conn *, enum ip_conntrack_info, s32);
};

struct bdi_writeback_congested___225 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___225 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___225 {
	struct bio___225 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___227 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___227 bip_inline_vecs[0];
};

struct bio_set___225 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___225 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___168 {
	struct mem_cgroup___168 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___168 {
	struct lruvec___436 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___168 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___168 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct gnet_dump___72 {
	spinlock_t *lock;
	struct sk_buff___2 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___72;

struct Qdisc_ops___72 {
	struct Qdisc_ops___72 *next;
	const struct Qdisc_class_ops___72 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___2 *, struct Qdisc___72 *, struct sk_buff___2 **);
	struct sk_buff___2 * (*dequeue)(struct Qdisc___72 *);
	struct sk_buff___2 * (*peek)(struct Qdisc___72 *);
	int (*init)(struct Qdisc___72 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___72 *);
	void (*destroy)(struct Qdisc___72 *);
	int (*change)(struct Qdisc___72 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___72 *);
	int (*change_tx_queue_len)(struct Qdisc___72 *, unsigned int);
	int (*dump)(struct Qdisc___72 *, struct sk_buff___2 *);
	int (*dump_stats)(struct Qdisc___72 *, struct gnet_dump___72 *);
	void (*ingress_block_set)(struct Qdisc___72 *, u32);
	void (*egress_block_set)(struct Qdisc___72 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___72 *);
	u32 (*egress_block_get)(struct Qdisc___72 *);
	struct module___5 *owner;
};

struct tcf_block___72;

struct Qdisc_class_ops___72 {
	unsigned int flags;
	struct netdev_queue___80 * (*select_queue)(struct Qdisc___72 *, struct tcmsg *);
	int (*graft)(struct Qdisc___72 *, long unsigned int, struct Qdisc___72 *, struct Qdisc___72 **, struct netlink_ext_ack *);
	struct Qdisc___72 * (*leaf)(struct Qdisc___72 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___72 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___72 *, u32);
	int (*change)(struct Qdisc___72 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___72 *, long unsigned int);
	void (*walk)(struct Qdisc___72 *, struct qdisc_walker *);
	struct tcf_block___72 * (*tcf_block)(struct Qdisc___72 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___72 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___72 *, long unsigned int);
	int (*dump)(struct Qdisc___72 *, long unsigned int, struct sk_buff___2 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___72 *, long unsigned int, struct gnet_dump___72 *);
};

struct tcf_chain___72;

struct tcf_block___72 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___3 *net;
	struct Qdisc___72 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___72 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___72;

struct tcf_proto_ops___72;

struct tcf_proto___72 {
	struct tcf_proto___72 *next;
	void *root;
	int (*classify)(struct sk_buff___2 *, const struct tcf_proto___72 *, struct tcf_result___72 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___72 *ops;
	struct tcf_chain___72 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___72 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___72 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___72 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___2 *, const struct tcf_proto___72 *, struct tcf_result___72 *);
	int (*init)(struct tcf_proto___72 *);
	void (*destroy)(struct tcf_proto___72 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___72 *, u32);
	void (*put)(struct tcf_proto___72 *, void *);
	int (*change)(struct net___3 *, struct sk_buff___2 *, struct tcf_proto___72 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___72 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___72 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___72 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___3 *, struct tcf_chain___72 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___3 *, struct tcf_proto___72 *, void *, struct sk_buff___2 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___2 *, struct net___3 *, void *);
	struct module___5 *owner;
	int flags;
};

struct tcf_chain___72 {
	struct mutex filter_chain_lock;
	struct tcf_proto___72 *filter_chain;
	struct list_head list;
	struct tcf_block___72 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___72 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___60 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___70 *prog;
};

struct bpf_redirect_info___70 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___285 *map;
	struct bpf_map___285 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___60;

struct neigh_hash_table___60;

struct neigh_table___60 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___2 *, __u32 *);
	bool (*key_eq)(const struct neighbour___60 *, const void *);
	int (*constructor)(struct neighbour___60 *);
	int (*pconstructor)(struct pneigh_entry___60 *);
	void (*pdestructor)(struct pneigh_entry___60 *);
	void (*proxy_redo)(struct sk_buff___2 *);
	char *id;
	struct neigh_parms___60 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___80 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___60 *nht;
	struct pneigh_entry___60 **phash_buckets;
};

struct neigh_ops___60 {
	int family;
	void (*solicit)(struct neighbour___60 *, struct sk_buff___2 *);
	void (*error_report)(struct neighbour___60 *, struct sk_buff___2 *);
	int (*output)(struct neighbour___60 *, struct sk_buff___2 *);
	int (*connected_output)(struct neighbour___60 *, struct sk_buff___2 *);
};

struct pneigh_entry___60 {
	struct pneigh_entry___60 *next;
	possible_net_t___82 net;
	struct net_device___2 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___60 {
	struct neighbour___60 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___60 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___60 *ctarget;
	struct net___3 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___60 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___60 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___43;

struct timewait_sock_ops___39;

struct proto___60 {
	void (*close)(struct sock___61 *, long int);
	int (*pre_connect)(struct sock___61 *, struct sockaddr *, int);
	int (*connect)(struct sock___61 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___61 *, int);
	struct sock___61 * (*accept)(struct sock___61 *, int, int *, bool);
	int (*ioctl)(struct sock___61 *, int, long unsigned int);
	int (*init)(struct sock___61 *);
	void (*destroy)(struct sock___61 *);
	void (*shutdown)(struct sock___61 *, int);
	int (*setsockopt)(struct sock___61 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___61 *, int, int, char *, int *);
	void (*keepalive)(struct sock___61 *, int);
	int (*sendmsg)(struct sock___61 *, struct msghdr___63 *, size_t);
	int (*recvmsg)(struct sock___61 *, struct msghdr___63 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___61 *, struct page___436 *, int, size_t, int);
	int (*bind)(struct sock___61 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___61 *, struct sk_buff___2 *);
	void (*release_cb)(struct sock___61 *);
	int (*hash)(struct sock___61 *);
	void (*unhash)(struct sock___61 *);
	void (*rehash)(struct sock___61 *);
	int (*get_port)(struct sock___61 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___61 *);
	bool (*stream_memory_read)(const struct sock___61 *);
	void (*enter_memory_pressure)(struct sock___61 *);
	void (*leave_memory_pressure)(struct sock___61 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___43 *rsk_prot;
	struct timewait_sock_ops___39 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___5 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___61 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct request_sock___44;

struct request_sock_ops___43 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___61 *, struct request_sock___44 *);
	void (*send_ack)(const struct sock___61 *, struct sk_buff___2 *, struct request_sock___44 *);
	void (*send_reset)(const struct sock___61 *, struct sk_buff___2 *);
	void (*destructor)(struct request_sock___44 *);
	void (*syn_ack_timeout)(const struct request_sock___44 *);
};

struct timewait_sock_ops___39 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___61 *, struct sock___61 *, void *);
	void (*twsk_destructor)(struct sock___61 *);
};

struct request_sock___44 {
	struct sock_common___60 __req_common;
	struct request_sock___44 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___43 *rsk_ops;
	struct sock___61 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct net_protocol___6 {
	int (*early_demux)(struct sk_buff___2 *);
	int (*early_demux_handler)(struct sk_buff___2 *);
	int (*handler)(struct sk_buff___2 *);
	void (*err_handler)(struct sk_buff___2 *, u32);
	unsigned int no_policy: 1;
	unsigned int netns_ok: 1;
	unsigned int icmp_strict_tag_validation: 1;
};

struct inet6_protocol___6 {
	void (*early_demux)(struct sk_buff___2 *);
	void (*early_demux_handler)(struct sk_buff___2 *);
	int (*handler)(struct sk_buff___2 *);
	void (*err_handler)(struct sk_buff___2 *, struct inet6_skb_parm *, u8, u8, int, __be32);
	unsigned int flags;
};

struct net_offload___6 {
	struct offload_callbacks___8 callbacks;
	unsigned int flags;
};

struct nf_loginfo {
	u_int8_t type;
	union {
		struct {
			u_int32_t copy_len;
			u_int16_t group;
			u_int16_t qthreshold;
			u_int16_t flags;
		} ulog;
		struct {
			u_int8_t level;
			u_int8_t logflags;
		} log;
	} u;
};

struct nf_log_buf {
	unsigned int count;
	char buf[1020];
};

struct ip_rt_info {
	__be32 daddr;
	__be32 saddr;
	u_int8_t tos;
	u_int32_t mark;
};

struct ip6_rt_info {
	struct in6_addr daddr;
	struct in6_addr saddr;
	u_int32_t mark;
};

struct nf_ipv6_ops___3 {
	int (*chk_addr)(struct net___3 *, const struct in6_addr *, const struct net_device___2 *, int);
	void (*route_input)(struct sk_buff___2 *);
	int (*fragment)(struct net___3 *, struct sock___61 *, struct sk_buff___2 *, int (*)(struct net___3 *, struct sock___61 *, struct sk_buff___2 *));
	__sum16 (*checksum)(struct sk_buff___2 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___2 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___3 *, struct dst_entry___60 **, struct flowi *, bool);
	int (*reroute)(struct sk_buff___2 *, const struct nf_queue_entry *);
};

struct nf_queue_entry {
	struct list_head list;
	struct sk_buff___2 *skb;
	unsigned int id;
	unsigned int hook_index;
	struct nf_hook_state___5 state;
	u16 size;
};

struct nf_sockopt_ops {
	struct list_head list;
	u_int8_t pf;
	int set_optmin;
	int set_optmax;
	int (*set)(struct sock___61 *, int, void *, unsigned int);
	int get_optmin;
	int get_optmax;
	int (*get)(struct sock___61 *, int, void *, int *);
	struct module___5 *owner;
};

struct module___363;

struct file___436;

struct kiocb___436;

struct iov_iter___203;

struct poll_table_struct___275;

struct vm_area_struct___437;

struct inode___436;

struct file_lock___436;

struct page___437;

struct pipe_inode_info___117;

struct seq_file___375;

struct file_operations___436 {
	struct module___363 *owner;
	loff_t (*llseek)(struct file___436 *, loff_t, int);
	ssize_t (*read)(struct file___436 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___436 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___436 *, struct iov_iter___203 *);
	ssize_t (*write_iter)(struct kiocb___436 *, struct iov_iter___203 *);
	int (*iopoll)(struct kiocb___436 *, bool);
	int (*iterate)(struct file___436 *, struct dir_context *);
	int (*iterate_shared)(struct file___436 *, struct dir_context *);
	__poll_t (*poll)(struct file___436 *, struct poll_table_struct___275 *);
	long int (*unlocked_ioctl)(struct file___436 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___436 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___436 *, struct vm_area_struct___437 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___436 *, struct file___436 *);
	int (*flush)(struct file___436 *, fl_owner_t);
	int (*release)(struct inode___436 *, struct file___436 *);
	int (*fsync)(struct file___436 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___436 *, int);
	int (*lock)(struct file___436 *, int, struct file_lock___436 *);
	ssize_t (*sendpage)(struct file___436 *, struct page___437 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___436 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___436 *, int, struct file_lock___436 *);
	ssize_t (*splice_write)(struct pipe_inode_info___117 *, struct file___436 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___436 *, loff_t *, struct pipe_inode_info___117 *, size_t, unsigned int);
	int (*setlease)(struct file___436 *, long int, struct file_lock___436 **, void **);
	long int (*fallocate)(struct file___436 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___375 *, struct file___436 *);
	ssize_t (*copy_file_range)(struct file___436 *, loff_t, struct file___436 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___436 *, loff_t, struct file___436 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___436 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___437 {
	u64 seqnum;
	struct vm_area_struct___437 *vmas[4];
};

struct page_frag___437 {
	struct page___437 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___437;

struct mem_cgroup___169;

struct cred___404;

struct nsproxy___331;

struct signal_struct___311;

struct bio_list___226;

struct backing_dev_info___226;

struct css_set___285;

struct vm_struct___340;

struct task_struct___438 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___438 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___437 *mm;
	struct mm_struct___437 *active_mm;
	struct vmacache___437 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___438 *real_parent;
	struct task_struct___438 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___438 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___169 *active_memcg;
	long int rh_reserved2;
	struct pid___241 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___241 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___241 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___404 *ptracer_cred;
	const struct cred___404 *real_cred;
	const struct cred___404 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___331 *nsproxy;
	struct signal_struct___311 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___438 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___226 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___226 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___285 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___117 *splice_pipe;
	struct page_frag___437 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___169 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___438 *oom_reaper_list;
	struct vm_struct___340 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___156 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___437 *pgtable_t___437;

struct address_space___436;

struct dev_pagemap___424;

struct page___437 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___436 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___437 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___437 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___437 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___424 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___169 *mem_cgroup;
};

struct pglist_data___437;

struct lruvec___437 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___437 *pgdat;
};

struct zone___437 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___437 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___437 {
	struct zone___437 *zone;
	int zone_idx;
};

struct zonelist___437 {
	struct zoneref___437 _zonerefs[25];
};

struct pglist_data___437 {
	struct zone___437 node_zones[3];
	struct zonelist___437 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___438 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___438 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___437 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___438 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___438 *owner;
};

struct secondary_data___438 {
	void *stack;
	struct task_struct___438 *task;
	long int status;
};

struct blocking_notifier_head___437 {
	struct rw_semaphore___438 rwsem;
	struct notifier_block *head;
};

struct cgroup___285;

struct cgroup_subsys___285;

struct cgroup_subsys_state___285 {
	struct cgroup___285 *cgroup;
	struct cgroup_subsys___285 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___285 *parent;
};

struct kernfs_node___431;

struct cgroup_file___285 {
	struct kernfs_node___431 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___169;

struct mem_cgroup___169 {
	struct cgroup_subsys_state___285 css;
	struct mem_cgroup_id___16 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___285 events_file;
	struct cgroup_file___285 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___438 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___169 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct key___404;

struct ucounts___301;

struct user_namespace___301 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___301 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___29 ns;
	long unsigned int flags;
	struct key___404 *persistent_keyring_register;
	struct rw_semaphore___438 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___301 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct user_struct___404 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___404 *uid_keyring;
	struct key___404 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___424;

struct vm_area_struct___437 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___437 *vm_next;
	struct vm_area_struct___437 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___437 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___424 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___436 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___437;

struct mm_struct___437 {
	struct {
		struct vm_area_struct___437 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___436 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___438 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___437 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___438 *owner;
		struct user_namespace___301 *user_ns;
		struct file___436 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___437 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___404 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___404 *session_keyring;
	struct key___404 *process_keyring;
	struct key___404 *thread_keyring;
	struct key___404 *request_key_auth;
	void *security;
	struct user_struct___404 *user;
	struct user_namespace___301 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___92;

struct cgroup_namespace___285;

struct nsproxy___331 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net___92 *net_ns;
	struct cgroup_namespace___285 *cgroup_ns;
};

struct signal_struct___311 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___438 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___438 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___241 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___241 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___437 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___241 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___226;

struct bio_list___226 {
	struct bio___226 *head;
	struct bio___226 *tail;
};

struct bdi_writeback_congested___226;

struct bdi_writeback___226 {
	struct backing_dev_info___226 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___226 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___285 *memcg_css;
	struct cgroup_subsys_state___285 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___404;

struct dentry___436;

struct backing_dev_info___226 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___226 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___404 *dev;
	struct device___404 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___436 *debug_dir;
	struct dentry___436 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___285 {
	struct cgroup_subsys_state___285 *subsys[13];
	refcount_t refcount;
	struct css_set___285 *dom_cset;
	struct cgroup___285 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___285 *mg_src_cgrp;
	struct cgroup___285 *mg_dst_cgrp;
	struct css_set___285 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___436;

struct pipe_buffer___117;

struct pipe_inode_info___117 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___437 *tmp_page;
	struct fasync_struct___436 *fasync_readers;
	struct fasync_struct___436 *fasync_writers;
	struct pipe_buffer___117 *bufs;
	struct user_struct___404 *user;
};

struct vm_struct___340 {
	struct vm_struct___340 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___437 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___323 {
	struct task_struct___438 task;
	long unsigned int stack[8192];
};

struct address_space_operations___436;

struct address_space___436 {
	struct inode___436 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___438 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___436 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___424)(struct vm_area_struct___437 *, long unsigned int, const struct page___437 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___424)(struct page___437 *, void *);

struct dev_pagemap___424 {
	dev_page_fault_t___424 page_fault;
	dev_page_free_t___424 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___404 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___437 {
	struct vfsmount *mnt;
	struct dentry___436 *dentry;
};

struct file___436 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___437 f_path;
	struct inode___436 *f_inode;
	const struct file_operations___436 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___241 f_owner;
	const struct cred___404 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___436 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___424;

struct vm_operations_struct___424 {
	void (*open)(struct vm_area_struct___437 *);
	void (*close)(struct vm_area_struct___437 *);
	int (*split)(struct vm_area_struct___437 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___437 *);
	vm_fault_t (*fault)(struct vm_fault___424 *);
	vm_fault_t (*huge_fault)(struct vm_fault___424 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___424 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___437 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___424 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___424 *);
	int (*access)(struct vm_area_struct___437 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___437 *);
	int (*set_policy)(struct vm_area_struct___437 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___437 *, long unsigned int);
	struct page___437 * (*find_special_page)(struct vm_area_struct___437 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___437 {
	struct task_struct___438 *task;
	struct core_thread___437 *next;
};

struct core_state___437 {
	atomic_t nr_threads;
	struct core_thread___437 dumper;
	struct completion startup;
};

struct vm_fault___424 {
	struct vm_area_struct___437 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___437 *cow_page;
	struct mem_cgroup___169 *memcg;
	struct page___437 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___437 prealloc_pte;
};

struct kset___423;

struct kobj_type___423;

struct kobject___424 {
	const char *name;
	struct list_head entry;
	struct kobject___424 *parent;
	struct kset___423 *kset;
	struct kobj_type___423 *ktype;
	struct kernfs_node___431 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___362 {
	struct kobject___424 kobj;
	struct module___363 *mod;
	struct kobject___424 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___362 {
	struct module___363 *mod;
	struct latch_tree_node node;
};

struct module_layout___362 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___362 mtn;
};

struct module_attribute___362;

struct kernel_param___362;

struct module___363 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___362 mkobj;
	struct module_attribute___362 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___424 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___362 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___362 core_layout;
	struct module_layout___362 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide53;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide54;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bio_vec___228 {
	struct page___437 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___203 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___228 *bvec;
		struct pipe_inode_info___117 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct msghdr___64 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___203 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___436 *msg_iocb;
};

struct kiocb___436 {
	struct file___436 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___436 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dentry_operations___436;

struct super_block___436;

struct dentry___436 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___436 *d_parent;
	struct qstr d_name;
	struct inode___436 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___436 *d_op;
	struct super_block___436 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___436;

struct block_device___436;

struct inode___436 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___436 *i_op;
	struct super_block___436 *i_sb;
	struct address_space___436 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___438 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___226 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___436 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___436 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___117 *i_pipe;
		struct block_device___436 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___436 {
	int (*d_revalidate)(struct dentry___436 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___436 *, unsigned int);
	int (*d_hash)(const struct dentry___436 *, struct qstr *);
	int (*d_compare)(const struct dentry___436 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___436 *);
	int (*d_init)(struct dentry___436 *);
	void (*d_release)(struct dentry___436 *);
	void (*d_prune)(struct dentry___436 *);
	void (*d_iput)(struct dentry___436 *, struct inode___436 *);
	char * (*d_dname)(struct dentry___436 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___437 *);
	int (*d_manage)(const struct path___437 *, bool);
	struct dentry___436 * (*d_real)(struct dentry___436 *, const struct inode___436 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___436;

struct mem_dqinfo___436 {
	struct quota_format_type___436 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___436;

struct quota_info___436 {
	unsigned int flags;
	struct rw_semaphore___438 dqio_sem;
	struct inode___436 *files[3];
	struct mem_dqinfo___436 info[3];
	const struct quota_format_ops___436 *ops[3];
};

struct rcuwait___436 {
	struct task_struct___438 *task;
};

struct percpu_rw_semaphore___436 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___438 rw_sem;
	struct rcuwait___436 writer;
	int readers_block;
};

struct sb_writers___436 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___436 rw_sem[3];
};

struct shrink_control___169;

struct shrinker___169 {
	long unsigned int (*count_objects)(struct shrinker___169 *, struct shrink_control___169 *);
	long unsigned int (*scan_objects)(struct shrinker___169 *, struct shrink_control___169 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___436;

struct super_operations___436;

struct dquot_operations___436;

struct quotactl_ops___436;

struct super_block___436 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___436 *s_type;
	const struct super_operations___436 *s_op;
	const struct dquot_operations___436 *dq_op;
	const struct quotactl_ops___436 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___436 *s_root;
	struct rw_semaphore___438 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___436 *s_bdev;
	struct backing_dev_info___226 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___436 s_dquot;
	struct sb_writers___436 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___436 *s_d_op;
	int cleancache_poolid;
	struct shrinker___169 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___301 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___169 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___169 *memcg;
};

struct iattr___436 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___436 *ia_file;
};

struct dquot___436 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___436 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___436 {
	int qf_fmt_id;
	const struct quota_format_ops___436 *qf_ops;
	struct module___363 *qf_owner;
	struct quota_format_type___436 *qf_next;
};

struct quota_format_ops___436 {
	int (*check_quota_file)(struct super_block___436 *, int);
	int (*read_file_info)(struct super_block___436 *, int);
	int (*write_file_info)(struct super_block___436 *, int);
	int (*free_file_info)(struct super_block___436 *, int);
	int (*read_dqblk)(struct dquot___436 *);
	int (*commit_dqblk)(struct dquot___436 *);
	int (*release_dqblk)(struct dquot___436 *);
	int (*get_next_id)(struct super_block___436 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___436 {
	int (*write_dquot)(struct dquot___436 *);
	struct dquot___436 * (*alloc_dquot)(struct super_block___436 *, int);
	void (*destroy_dquot)(struct dquot___436 *);
	int (*acquire_dquot)(struct dquot___436 *);
	int (*release_dquot)(struct dquot___436 *);
	int (*mark_dirty)(struct dquot___436 *);
	int (*write_info)(struct super_block___436 *, int);
	qsize_t * (*get_reserved_space)(struct inode___436 *);
	int (*get_projid)(struct inode___436 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___436 *, qsize_t *);
	int (*get_next_id)(struct super_block___436 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___436 {
	int (*quota_on)(struct super_block___436 *, int, int, const struct path___437 *);
	int (*quota_off)(struct super_block___436 *, int);
	int (*quota_enable)(struct super_block___436 *, unsigned int);
	int (*quota_disable)(struct super_block___436 *, unsigned int);
	int (*quota_sync)(struct super_block___436 *, int);
	int (*set_info)(struct super_block___436 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___436 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___436 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___436 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___436 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___436 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___189;

struct address_space_operations___436 {
	int (*writepage)(struct page___437 *, struct writeback_control___189 *);
	int (*readpage)(struct file___436 *, struct page___437 *);
	int (*writepages)(struct address_space___436 *, struct writeback_control___189 *);
	int (*set_page_dirty)(struct page___437 *);
	int (*readpages)(struct file___436 *, struct address_space___436 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___436 *, struct address_space___436 *, loff_t, unsigned int, unsigned int, struct page___437 **, void **);
	int (*write_end)(struct file___436 *, struct address_space___436 *, loff_t, unsigned int, unsigned int, struct page___437 *, void *);
	sector_t (*bmap)(struct address_space___436 *, sector_t);
	void (*invalidatepage)(struct page___437 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___437 *, gfp_t);
	void (*freepage)(struct page___437 *);
	ssize_t (*direct_IO)(struct kiocb___436 *, struct iov_iter___203 *);
	int (*migratepage)(struct address_space___436 *, struct page___437 *, struct page___437 *, enum migrate_mode);
	bool (*isolate_page)(struct page___437 *, isolate_mode_t);
	void (*putback_page)(struct page___437 *);
	int (*launder_page)(struct page___437 *);
	int (*is_partially_uptodate)(struct page___437 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___437 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___436 *, struct page___437 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___436 *, sector_t *);
	void (*swap_deactivate)(struct file___436 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___189 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___226 *wb;
	struct inode___436 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___436 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___436 *bd_inode;
	struct super_block___436 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___436 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___226 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___436 {
	struct dentry___436 * (*lookup)(struct inode___436 *, struct dentry___436 *, unsigned int);
	const char * (*get_link)(struct dentry___436 *, struct inode___436 *, struct delayed_call *);
	int (*permission)(struct inode___436 *, int);
	struct posix_acl * (*get_acl)(struct inode___436 *, int);
	int (*readlink)(struct dentry___436 *, char *, int);
	int (*create)(struct inode___436 *, struct dentry___436 *, umode_t, bool);
	int (*link)(struct dentry___436 *, struct inode___436 *, struct dentry___436 *);
	int (*unlink)(struct inode___436 *, struct dentry___436 *);
	int (*symlink)(struct inode___436 *, struct dentry___436 *, const char *);
	int (*mkdir)(struct inode___436 *, struct dentry___436 *, umode_t);
	int (*rmdir)(struct inode___436 *, struct dentry___436 *);
	int (*mknod)(struct inode___436 *, struct dentry___436 *, umode_t, dev_t);
	int (*rename)(struct inode___436 *, struct dentry___436 *, struct inode___436 *, struct dentry___436 *, unsigned int);
	int (*setattr)(struct dentry___436 *, struct iattr___436 *);
	int (*getattr)(const struct path___437 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___436 *, char *, size_t);
	int (*fiemap)(struct inode___436 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___436 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___436 *, struct dentry___436 *, struct file___436 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___436 *, struct dentry___436 *, umode_t);
	int (*set_acl)(struct inode___436 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___436 {
	void (*fl_copy_lock)(struct file_lock___436 *, struct file_lock___436 *);
	void (*fl_release_private)(struct file_lock___436 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___436;

struct file_lock___436 {
	struct file_lock___436 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___436 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___436 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___436 *fl_ops;
	const struct lock_manager_operations___436 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___436 {
	int (*lm_compare_owner)(struct file_lock___436 *, struct file_lock___436 *);
	long unsigned int (*lm_owner_key)(struct file_lock___436 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___436 *);
	int (*lm_grant)(struct file_lock___436 *, int);
	bool (*lm_break)(struct file_lock___436 *);
	int (*lm_change)(struct file_lock___436 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___436 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___436 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___436 *fa_next;
	struct file___436 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___436 {
	const char *name;
	int fs_flags;
	struct dentry___436 * (*mount)(struct file_system_type___436 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___436 *);
	struct module___363 *owner;
	struct file_system_type___436 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___436 {
	struct inode___436 * (*alloc_inode)(struct super_block___436 *);
	void (*destroy_inode)(struct inode___436 *);
	void (*dirty_inode)(struct inode___436 *, int);
	int (*write_inode)(struct inode___436 *, struct writeback_control___189 *);
	int (*drop_inode)(struct inode___436 *);
	void (*evict_inode)(struct inode___436 *);
	void (*put_super)(struct super_block___436 *);
	int (*sync_fs)(struct super_block___436 *, int);
	int (*freeze_super)(struct super_block___436 *);
	int (*freeze_fs)(struct super_block___436 *);
	int (*thaw_super)(struct super_block___436 *);
	int (*unfreeze_fs)(struct super_block___436 *);
	int (*statfs)(struct dentry___436 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___436 *, int *, char *);
	void (*umount_begin)(struct super_block___436 *);
	int (*show_options)(struct seq_file___375 *, struct dentry___436 *);
	int (*show_devname)(struct seq_file___375 *, struct dentry___436 *);
	int (*show_path)(struct seq_file___375 *, struct dentry___436 *);
	int (*show_stats)(struct seq_file___375 *, struct dentry___436 *);
	ssize_t (*quota_read)(struct super_block___436 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___436 *, int, const char *, size_t, loff_t);
	struct dquot___436 ** (*get_dquots)(struct inode___436 *);
	int (*bdev_try_to_free_page)(struct super_block___436 *, struct page___437 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___436 *, struct shrink_control___169 *);
	long int (*free_cached_objects)(struct super_block___436 *, struct shrink_control___169 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___285)(struct file___436 *, wait_queue_head_t *, struct poll_table_struct___275 *);

struct poll_table_struct___275 {
	poll_queue_proc___285 _qproc;
	__poll_t _key;
};

struct seq_operations___375;

struct seq_file___375 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___375 *op;
	int poll_event;
	const struct file___436 *file;
	void *private;
};

typedef void bio_end_io_t___226(struct bio___226 *);

struct bio_integrity_payload___226;

struct bio_set___226;

struct bio___226 {
	struct bio___226 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___226 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___226 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___228 *bi_io_vec;
	struct bio_set___226 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___228 bi_inline_vecs[0];
};

struct socket_wq___62 {
	wait_queue_head_t wait;
	struct fasync_struct___436 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct sock___62;

struct proto_ops___62;

struct socket___63 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___62 *wq;
	struct file___436 *file;
	struct sock___62 *sk;
	const struct proto_ops___62 *ops;
};

typedef struct {
	struct net___92 *net;
} possible_net_t___83;

struct proto___61;

struct sock_common___61 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___61 *skc_prot;
	possible_net_t___83 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___62 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___82;

struct sk_buff_head___81 {
	struct sk_buff___82 *next;
	struct sk_buff___82 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___61;

struct dst_entry___61;

struct net_device___81;

struct sock___62 {
	struct sock_common___61 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___81 sk_error_queue;
	struct sk_buff_head___81 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___82 *head;
		struct sk_buff___82 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___61 *sk_filter;
	union {
		struct socket_wq___62 *sk_wq;
		struct socket_wq___62 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___61 *sk_rx_dst;
	struct dst_entry___61 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___82 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___81 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___437 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___61 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___241 *sk_peer_pid;
	const struct cred___404 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___63 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___169 *sk_memcg;
	void (*sk_state_change)(struct sock___62 *);
	void (*sk_data_ready)(struct sock___62 *);
	void (*sk_write_space)(struct sock___62 *);
	void (*sk_error_report)(struct sock___62 *);
	int (*sk_backlog_rcv)(struct sock___62 *, struct sk_buff___82 *);
	struct sk_buff___82 * (*sk_validate_xmit_skb)(struct sock___62 *, struct net_device___81 *, struct sk_buff___82 *);
	void (*sk_destruct)(struct sock___62 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

typedef int (*sk_read_actor_t___61)(read_descriptor_t *, struct sk_buff___82 *, unsigned int, size_t);

struct proto_ops___62 {
	int family;
	struct module___363 *owner;
	int (*release)(struct socket___63 *);
	int (*bind)(struct socket___63 *, struct sockaddr *, int);
	int (*connect)(struct socket___63 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___63 *, struct socket___63 *);
	int (*accept)(struct socket___63 *, struct socket___63 *, int, bool);
	int (*getname)(struct socket___63 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___436 *, struct socket___63 *, struct poll_table_struct___275 *);
	int (*ioctl)(struct socket___63 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___63 *, int);
	int (*shutdown)(struct socket___63 *, int);
	int (*setsockopt)(struct socket___63 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___63 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___63 *, struct msghdr___64 *, size_t);
	int (*recvmsg)(struct socket___63 *, struct msghdr___64 *, size_t, int);
	int (*mmap)(struct file___436 *, struct socket___63 *, struct vm_area_struct___437 *);
	ssize_t (*sendpage)(struct socket___63 *, struct page___437 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___63 *, loff_t *, struct pipe_inode_info___117 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___62 *, int);
	int (*peek_len)(struct socket___63 *);
	int (*read_sock)(struct sock___62 *, read_descriptor_t *, sk_read_actor_t___61);
	int (*sendpage_locked)(struct sock___62 *, struct page___437 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___62 *, struct msghdr___64 *, size_t);
	int (*set_rcvlowat)(struct sock___62 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct nf_bridge_info___81;

struct sk_buff___82 {
	union {
		struct {
			struct sk_buff___82 *next;
			struct sk_buff___82 *prev;
			union {
				struct net_device___81 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___62 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___82 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___81 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___81;

struct netns_frags___81 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___81 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_rules_ops___61;

struct fib_notifier_ops___62;

struct netns_ipv4___81 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___61 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___62 *fibnl;
	struct sock___62 **icmp_sk;
	struct sock___62 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___62 **tcp_sk;
	struct netns_frags___81 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___61 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___62 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___62 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___61;

struct dst_ops___92 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___92 *);
	struct dst_entry___61 * (*check)(struct dst_entry___61 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___61 *);
	unsigned int (*mtu)(const struct dst_entry___61 *);
	u32 * (*cow_metrics)(struct dst_entry___61 *, long unsigned int);
	void (*destroy)(struct dst_entry___61 *);
	void (*ifdown)(struct dst_entry___61 *, struct net_device___81 *, int);
	struct dst_entry___61 * (*negative_advice)(struct dst_entry___61 *);
	void (*link_failure)(struct sk_buff___82 *);
	void (*update_pmtu)(struct dst_entry___61 *, struct sock___62 *, struct sk_buff___82 *, u32);
	void (*redirect)(struct dst_entry___61 *, struct sock___62 *, struct sk_buff___82 *);
	int (*local_out)(struct net___92 *, struct sock___62 *, struct sk_buff___82 *);
	struct neighbour___61 * (*neigh_lookup)(const struct dst_entry___61 *, struct sk_buff___82 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___61 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___92 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___81 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___92 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___61 *fib6_rules_ops;
	struct sock___62 **icmp_sk;
	struct sock___62 *ndisc_sk;
	struct sock___62 *tcp_sk;
	struct sock___62 *igmp_sk;
	struct sock___62 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___61 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___62 *notifier_ops;
	struct fib_notifier_ops___62 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___62 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___62 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct nf_queue_handler___2;

struct nf_hook_entries___6;

struct netns_nf___7 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_queue_handler___2 *queue_handler;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header *nf_log_dir_header;
	struct nf_hook_entries___6 *hooks_ipv4[5];
	struct nf_hook_entries___6 *hooks_ipv6[5];
	struct nf_hook_entries___6 *hooks_arp[3];
	struct nf_hook_entries___6 *hooks_bridge[5];
	bool defrag_ipv4;
	bool defrag_ipv6;
};

struct netns_nf_frag___81 {
	struct netns_frags___81 frags;
};

struct netns_xfrm___92 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___62 *nlsk;
	struct sock___62 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___92 xfrm4_dst_ops;
	struct dst_ops___92 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___71;

struct net___92 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___301 *user_ns;
	struct ucounts___301 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___29 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___62 *rtnl;
	struct sock___62 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___81 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___81 ipv4;
	struct netns_ipv6___92 ipv6;
	struct netns_sctp___62 sctp;
	struct netns_nf___7 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___81 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___62 *nfnl;
	struct sock___62 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___92 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___62 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___71 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kernfs_root___430;

struct kernfs_elem_dir___430 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___430 *root;
};

struct kernfs_syscall_ops___430;

struct kernfs_root___430 {
	struct kernfs_node___431 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___430 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___430 {
	struct kernfs_node___431 *target_kn;
};

struct kernfs_ops___430;

struct kernfs_elem_attr___430 {
	const struct kernfs_ops___430 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___431 *notify_next;
};

struct kernfs_node___431 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___431 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___430 dir;
		struct kernfs_elem_symlink___430 symlink;
		struct kernfs_elem_attr___430 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___430;

struct kernfs_ops___430 {
	int (*open)(struct kernfs_open_file___430 *);
	void (*release)(struct kernfs_open_file___430 *);
	int (*seq_show)(struct seq_file___375 *, void *);
	void * (*seq_start)(struct seq_file___375 *, loff_t *);
	void * (*seq_next)(struct seq_file___375 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___375 *, void *);
	ssize_t (*read)(struct kernfs_open_file___430 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___430 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___430 *, struct vm_area_struct___437 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___430 *, struct poll_table_struct___275 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___430 {
	int (*remount_fs)(struct kernfs_root___430 *, int *, char *);
	int (*show_options)(struct seq_file___375 *, struct kernfs_root___430 *);
	int (*mkdir)(struct kernfs_node___431 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___431 *);
	int (*rename)(struct kernfs_node___431 *, struct kernfs_node___431 *, const char *);
	int (*show_path)(struct seq_file___375 *, struct kernfs_node___431 *, struct kernfs_root___430 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___430 {
	struct kernfs_node___431 *kn;
	struct file___436 *file;
	struct seq_file___375 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___424 *vm_ops;
};

struct kobj_ns_type_operations___61 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___62 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___400;

struct attribute_group___401 {
	const char *name;
	umode_t (*is_visible)(struct kobject___424 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___424 *, struct bin_attribute___400 *, int);
	struct attribute **attrs;
	struct bin_attribute___400 **bin_attrs;
};

struct bin_attribute___400 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___436 *, struct kobject___424 *, struct bin_attribute___400 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___436 *, struct kobject___424 *, struct bin_attribute___400 *, char *, loff_t, size_t);
	int (*mmap)(struct file___436 *, struct kobject___424 *, struct bin_attribute___400 *, struct vm_area_struct___437 *);
};

struct sysfs_ops___423 {
	ssize_t (*show)(struct kobject___424 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___424 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___423;

struct kset___423 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___424 kobj;
	const struct kset_uevent_ops___423 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___423 {
	void (*release)(struct kobject___424 *);
	const struct sysfs_ops___423 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___61 * (*child_ns_type)(struct kobject___424 *);
	const void * (*namespace)(struct kobject___424 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___423 {
	int (* const filter)(struct kset___423 *, struct kobject___424 *);
	const char * (* const name)(struct kset___423 *, struct kobject___424 *);
	int (* const uevent)(struct kset___423 *, struct kobject___424 *, struct kobj_uevent_env *);
};

struct kobj_attribute___414 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___424 *, struct kobj_attribute___414 *, char *);
	ssize_t (*store)(struct kobject___424 *, struct kobj_attribute___414 *, const char *, size_t);
};

struct dev_pm_ops___404 {
	int (*prepare)(struct device___404 *);
	void (*complete)(struct device___404 *);
	int (*suspend)(struct device___404 *);
	int (*resume)(struct device___404 *);
	int (*freeze)(struct device___404 *);
	int (*thaw)(struct device___404 *);
	int (*poweroff)(struct device___404 *);
	int (*restore)(struct device___404 *);
	int (*suspend_late)(struct device___404 *);
	int (*resume_early)(struct device___404 *);
	int (*freeze_late)(struct device___404 *);
	int (*thaw_early)(struct device___404 *);
	int (*poweroff_late)(struct device___404 *);
	int (*restore_early)(struct device___404 *);
	int (*suspend_noirq)(struct device___404 *);
	int (*resume_noirq)(struct device___404 *);
	int (*freeze_noirq)(struct device___404 *);
	int (*thaw_noirq)(struct device___404 *);
	int (*poweroff_noirq)(struct device___404 *);
	int (*restore_noirq)(struct device___404 *);
	int (*runtime_suspend)(struct device___404 *);
	int (*runtime_resume)(struct device___404 *);
	int (*runtime_idle)(struct device___404 *);
};

struct dev_pm_info___404 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___404 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___404;

struct bus_type___404;

struct device_driver___404;

struct dev_pm_domain___404;

struct dma_map_ops___176;

struct fwnode_handle___324;

struct class___404;

struct device___404 {
	struct device___404 *parent;
	struct device_private *p;
	struct kobject___424 kobj;
	const char *init_name;
	const struct device_type___404 *type;
	struct mutex mutex;
	struct bus_type___404 *bus;
	struct device_driver___404 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___404 power;
	struct dev_pm_domain___404 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___176 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___324 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___404 *class;
	const struct attribute_group___401 **groups;
	void (*release)(struct device___404 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___404 {
	struct dev_pm_ops___404 ops;
	void (*detach)(struct device___404 *, bool);
	int (*activate)(struct device___404 *);
	void (*sync)(struct device___404 *);
	void (*dismiss)(struct device___404 *);
};

struct bus_type___404 {
	const char *name;
	const char *dev_name;
	struct device___404 *dev_root;
	const struct attribute_group___401 **bus_groups;
	const struct attribute_group___401 **dev_groups;
	const struct attribute_group___401 **drv_groups;
	int (*match)(struct device___404 *, struct device_driver___404 *);
	int (*uevent)(struct device___404 *, struct kobj_uevent_env *);
	int (*probe)(struct device___404 *);
	int (*remove)(struct device___404 *);
	void (*shutdown)(struct device___404 *);
	int (*online)(struct device___404 *);
	int (*offline)(struct device___404 *);
	int (*suspend)(struct device___404 *, pm_message_t);
	int (*resume)(struct device___404 *);
	int (*num_vf)(struct device___404 *);
	int (*dma_configure)(struct device___404 *);
	const struct dev_pm_ops___404 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___404 {
	const char *name;
	struct bus_type___404 *bus;
	struct module___363 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___404 *);
	int (*remove)(struct device___404 *);
	void (*shutdown)(struct device___404 *);
	int (*suspend)(struct device___404 *, pm_message_t);
	int (*resume)(struct device___404 *);
	const struct attribute_group___401 **groups;
	const struct dev_pm_ops___404 *pm;
	void (*coredump)(struct device___404 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___404 {
	const char *name;
	const struct attribute_group___401 **groups;
	int (*uevent)(struct device___404 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___404 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___404 *);
	const struct dev_pm_ops___404 *pm;
};

struct class___404 {
	const char *name;
	struct module___363 *owner;
	const struct attribute_group___401 **class_groups;
	const struct attribute_group___401 **dev_groups;
	struct kobject___424 *dev_kobj;
	int (*dev_uevent)(struct device___404 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___404 *, umode_t *);
	void (*class_release)(struct class___404 *);
	void (*dev_release)(struct device___404 *);
	int (*shutdown_pre)(struct device___404 *);
	const struct kobj_ns_type_operations___61 *ns_type;
	const void * (*namespace)(struct device___404 *);
	const struct dev_pm_ops___404 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___176 {
	void * (*alloc)(struct device___404 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___404 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___404 *, struct vm_area_struct___437 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___404 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___404 *, struct page___437 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___404 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___404 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___404 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___404 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___404 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___404 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___404 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___404 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___404 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___404 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___404 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___404 *, u64);
	u64 (*get_required_mask)(struct device___404 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___324;

struct fwnode_handle___324 {
	struct fwnode_handle___324 *secondary;
	const struct fwnode_operations___324 *ops;
};

typedef void compound_page_dtor___424(struct page___437 *);

struct fwnode_reference_args___324;

struct fwnode_endpoint___324;

struct fwnode_operations___324 {
	struct fwnode_handle___324 * (*get)(struct fwnode_handle___324 *);
	void (*put)(struct fwnode_handle___324 *);
	bool (*device_is_available)(const struct fwnode_handle___324 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___324 *, const struct device___404 *);
	bool (*property_present)(const struct fwnode_handle___324 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___324 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___324 *, const char *, const char **, size_t);
	struct fwnode_handle___324 * (*get_parent)(const struct fwnode_handle___324 *);
	struct fwnode_handle___324 * (*get_next_child_node)(const struct fwnode_handle___324 *, struct fwnode_handle___324 *);
	struct fwnode_handle___324 * (*get_named_child_node)(const struct fwnode_handle___324 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___324 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___324 *);
	struct fwnode_handle___324 * (*graph_get_next_endpoint)(const struct fwnode_handle___324 *, struct fwnode_handle___324 *);
	struct fwnode_handle___324 * (*graph_get_remote_endpoint)(const struct fwnode_handle___324 *);
	struct fwnode_handle___324 * (*graph_get_port_parent)(struct fwnode_handle___324 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___324 *, struct fwnode_endpoint___324 *);
};

struct fwnode_endpoint___324 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___324 *local_fwnode;
};

struct fwnode_reference_args___324 {
	struct fwnode_handle___324 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___117;

struct pipe_buffer___117 {
	struct page___437 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___117 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___117 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___117 *, struct pipe_buffer___117 *);
	void (*release)(struct pipe_inode_info___117 *, struct pipe_buffer___117 *);
	int (*steal)(struct pipe_inode_info___117 *, struct pipe_buffer___117 *);
	union {
		bool (*get)(struct pipe_inode_info___117 *, struct pipe_buffer___117 *);
		struct {
			void (*get)(struct pipe_inode_info___117 *, struct pipe_buffer___117 *);
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
};

struct nf_bridge_info___81 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___81 = 0,
		BRNF_PROTO_8021Q___81 = 1,
		BRNF_PROTO_PPPOE___81 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___81 *physindev;
	struct net_device___81 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___81(struct sk_buff___82 **);

struct net_device_ops___81;

struct ethtool_ops___81;

struct l3mdev_ops___61;

struct xfrmdev_ops___81;

struct tlsdev_ops___81;

struct header_ops___81;

struct netdev_rx_queue___81;

struct mini_Qdisc___73;

struct netdev_queue___81;

struct Qdisc___73;

struct rtnl_link_ops___73;

struct dcbnl_rtnl_ops___81;

struct net_device___81 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___81 *netdev_ops;
	const struct ethtool_ops___81 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___61 *l3mdev_ops;
	const struct ndisc_ops___2 *ndisc_ops;
	const struct xfrmdev_ops___81 *xfrmdev_ops;
	const struct tlsdev_ops___81 *tlsdev_ops;
	const struct header_ops___81 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___423 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___2 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___81 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___71 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___81 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___73 *miniq_ingress;
	struct netdev_queue___81 *ingress_queue;
	struct nf_hook_entries___6 *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___81 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___73 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___73 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___81 = 0,
		NETREG_REGISTERED___81 = 1,
		NETREG_UNREGISTERING___81 = 2,
		NETREG_UNREGISTERED___81 = 3,
		NETREG_RELEASED___81 = 4,
		NETREG_DUMMY___81 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___81 = 0,
		RTNL_LINK_INITIALIZING___81 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___81 *);
	struct netpoll_info *npinfo;
	possible_net_t___83 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___404 dev;
	const struct attribute_group___401 *sysfs_groups[4];
	const struct attribute_group___401 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___73 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___81 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct ethtool_ops___81 {
	int (*get_settings)(struct net_device___81 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___81 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___81 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___81 *);
	void (*get_regs)(struct net_device___81 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___81 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___81 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___81 *);
	void (*set_msglevel)(struct net_device___81 *, u32);
	int (*nway_reset)(struct net_device___81 *);
	u32 (*get_link)(struct net_device___81 *);
	int (*get_eeprom_len)(struct net_device___81 *);
	int (*get_eeprom)(struct net_device___81 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___81 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___81 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___81 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___81 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___81 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___81 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___81 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___81 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___81 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___81 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___81 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___81 *);
	void (*complete)(struct net_device___81 *);
	u32 (*get_priv_flags)(struct net_device___81 *);
	int (*set_priv_flags)(struct net_device___81 *, u32);
	int (*get_sset_count)(struct net_device___81 *, int);
	int (*get_rxnfc)(struct net_device___81 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___81 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___81 *, struct ethtool_flash *);
	int (*reset)(struct net_device___81 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___81 *);
	u32 (*get_rxfh_indir_size)(struct net_device___81 *);
	int (*get_rxfh)(struct net_device___81 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___81 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___81 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___81 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___81 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___81 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___81 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___81 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___81 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___81 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___81 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___81 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___81 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___81 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___81 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___81 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___81 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___81 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___81 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___81 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___81 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___81 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	int (*get_fecparam)(struct net_device___81 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___81 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___81 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___81 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___81 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___81;

struct inet_frags___81 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___81 *, const void *);
	void (*destructor)(struct inet_frag_queue___81 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___81 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___82 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___82 *fragments_tail;
	struct sk_buff___82 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___81 *net;
	struct callback_head rcu;
};

struct fib_rule___61;

struct fib_lookup_arg___61;

struct fib_rules_ops___61 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___61 *, struct flowi *, int, struct fib_lookup_arg___61 *);
	bool (*suppress)(struct fib_rule___61 *, struct fib_lookup_arg___61 *);
	int (*match)(struct fib_rule___61 *, struct flowi *, int);
	int (*configure)(struct fib_rule___61 *, struct sk_buff___82 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___61 *);
	int (*compare)(struct fib_rule___61 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___61 *, struct sk_buff___82 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___61 *);
	void (*flush_cache)(struct fib_rules_ops___61 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___363 *owner;
	struct net___92 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___62 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___92 *);
	int (*fib_dump)(struct net___92 *, struct notifier_block *);
	struct module___363 *owner;
	struct callback_head rcu;
};

struct dst_entry___61 {
	struct net_device___81 *dev;
	struct dst_ops___92 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___82 *);
	int (*output)(struct net___92 *, struct sock___62 *, struct sk_buff___82 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___61;

struct neigh_parms___61;

struct neigh_ops___61;

struct neighbour___61 {
	struct neighbour___61 *next;
	struct neigh_table___61 *tbl;
	struct neigh_parms___61 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___81 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___61 *, struct sk_buff___82 *);
	const struct neigh_ops___61 *ops;
	struct callback_head rcu;
	struct net_device___81 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct nf_queue_entry___3;

struct nf_queue_handler___2 {
	int (*outfn)(struct nf_queue_entry___3 *, unsigned int);
	void (*nf_hook_drop)(struct net___92 *);
};

struct nf_hook_state___6;

typedef unsigned int nf_hookfn___6(void *, struct sk_buff___82 *, const struct nf_hook_state___6 *);

struct nf_hook_entry___6 {
	nf_hookfn___6 *hook;
	void *priv;
};

struct nf_hook_entries___6 {
	u16 num_hook_entries;
	struct nf_hook_entry___6 hooks[0];
};

struct ucounts___301 {
	struct hlist_node node;
	struct user_namespace___301 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_prog_aux___74;

struct bpf_prog___71 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___74 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

typedef int (*key_restrict_link_func_t___405)(struct key___404 *, const struct key_type *, const union key_payload *, struct key___404 *);

struct key_restriction___404;

struct key___404 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___438 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___404 *restrict_link;
};

struct key_restriction___404 {
	key_restrict_link_func_t___405 check;
	struct key___404 *key;
	struct key_type *keytype;
};

struct seq_operations___375 {
	void * (*start)(struct seq_file___375 *, loff_t *);
	void (*stop)(struct seq_file___375 *, void *);
	void * (*next)(struct seq_file___375 *, void *, loff_t *);
	int (*show)(struct seq_file___375 *, void *);
};

struct pernet_operations___82 {
	struct list_head list;
	int (*init)(struct net___92 *);
	void (*exit)(struct net___92 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___81 {
	int (*ieee_getets)(struct net_device___81 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___81 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___81 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___81 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___81 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___81 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___81 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___81 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___81 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___81 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___81 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___81 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___81 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___81 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___81 *);
	u8 (*setstate)(struct net_device___81 *, u8);
	void (*getpermhwaddr)(struct net_device___81 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___81 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___81 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___81 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___81 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___81 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___81 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___81 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___81 *, int, u8 *);
	void (*setpfccfg)(struct net_device___81 *, int, u8);
	void (*getpfccfg)(struct net_device___81 *, int, u8 *);
	u8 (*setall)(struct net_device___81 *);
	u8 (*getcap)(struct net_device___81 *, int, u8 *);
	int (*getnumtcs)(struct net_device___81 *, int, u8 *);
	int (*setnumtcs)(struct net_device___81 *, int, u8);
	u8 (*getpfcstate)(struct net_device___81 *);
	void (*setpfcstate)(struct net_device___81 *, u8);
	void (*getbcncfg)(struct net_device___81 *, int, u32 *);
	void (*setbcncfg)(struct net_device___81 *, int, u32);
	void (*getbcnrp)(struct net_device___81 *, int, u8 *);
	void (*setbcnrp)(struct net_device___81 *, int, u8);
	int (*setapp)(struct net_device___81 *, u8, u16, u8);
	int (*getapp)(struct net_device___81 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___81 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___81 *, int, u8);
	u8 (*getdcbx)(struct net_device___81 *);
	u8 (*setdcbx)(struct net_device___81 *, u8);
	int (*peer_getappinfo)(struct net_device___81 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___81 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___81 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___81 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___81 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___81 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___285 {
	refcount_t count;
	struct ns_common___29 ns;
	struct user_namespace___301 *user_ns;
	struct ucounts___301 *ucounts;
	struct css_set___285 *root_cset;
};

struct bpf_map___286;

struct bpf_map_ops___285 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___286 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___286 *, struct file___436 *);
	void (*map_free)(struct bpf_map___286 *);
	int (*map_get_next_key)(struct bpf_map___286 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___286 *);
	void * (*map_lookup_elem)(struct bpf_map___286 *, void *);
	int (*map_update_elem)(struct bpf_map___286 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___286 *, void *);
	int (*map_push_elem)(struct bpf_map___286 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___286 *, void *);
	int (*map_peek_elem)(struct bpf_map___286 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___286 *, struct file___436 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___286 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___286 *, void *, struct seq_file___375 *);
	int (*map_check_btf)(const struct bpf_map___286 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___286 {
	const struct bpf_map_ops___285 *ops;
	struct bpf_map___286 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___404 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___81;

struct bpf_map_dev_ops___81 {
	int (*map_get_next_key)(struct bpf_offloaded_map___81 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___81 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___81 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___81 *, void *);
};

struct bpf_offloaded_map___81 {
	struct bpf_map___286 map;
	struct net_device___81 *netdev;
	const struct bpf_map_dev_ops___81 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___71 {
	int (*test_run)(struct bpf_prog___71 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___71 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___71 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___71 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___71 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___71 *, u32 *);
};

struct bpf_prog_offload_ops___71 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___71 *);
	int (*translate)(struct bpf_prog___71 *);
	void (*destroy)(struct bpf_prog___71 *);
};

struct bpf_prog_offload___71 {
	struct bpf_prog___71 *prog;
	struct net_device___81 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___71 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___74 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___71 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___71 *ops;
	struct bpf_map___286 **used_maps;
	struct bpf_prog___71 *prog;
	struct user_struct___404 *user;
	u64 load_time;
	struct bpf_map___286 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___71 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___71 {
	struct bpf_prog___71 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___71 {
	struct callback_head rcu;
	struct bpf_prog_array_item___71 items[0];
};

struct cgroup_bpf___71 {
	struct bpf_prog_array___71 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___71 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___286;

typedef void (*kthread_work_func_t___286)(struct kthread_work___286 *);

struct kthread_worker___286;

struct kthread_work___286 {
	struct list_head node;
	kthread_work_func_t___286 func;
	struct kthread_worker___286 *worker;
	int canceling;
};

struct kthread_worker___286 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___438 *task;
	struct kthread_work___286 *current_work;
};

struct kthread_delayed_work___285 {
	struct kthread_work___286 work;
	struct timer_list timer;
};

struct psi_group___285 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___286 *poll_kworker;
	struct kthread_delayed_work___285 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___285;

struct cgroup_rstat_cpu___285;

struct cgroup___285 {
	struct cgroup_subsys_state___285 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___431 *kn;
	struct cgroup_file___285 procs_file;
	struct cgroup_file___285 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___285 *subsys[13];
	struct cgroup_root___285 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___285 *dom_cgrp;
	struct cgroup_rstat_cpu___285 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___71 bpf;
	atomic_t congestion_count;
	struct cgroup___285 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___285 psi;
	int ancestor_ids[0];
};

struct cftype___285;

struct cgroup_subsys___285 {
	struct cgroup_subsys_state___285 * (*css_alloc)(struct cgroup_subsys_state___285 *);
	int (*css_online)(struct cgroup_subsys_state___285 *);
	void (*css_offline)(struct cgroup_subsys_state___285 *);
	void (*css_released)(struct cgroup_subsys_state___285 *);
	void (*css_free)(struct cgroup_subsys_state___285 *);
	void (*css_reset)(struct cgroup_subsys_state___285 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___285 *, int);
	int (*css_extra_stat_show)(struct seq_file___375 *, struct cgroup_subsys_state___285 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___438 *);
	void (*cancel_fork)(struct task_struct___438 *);
	void (*fork)(struct task_struct___438 *);
	void (*exit)(struct task_struct___438 *);
	void (*free)(struct task_struct___438 *);
	void (*bind)(struct cgroup_subsys_state___285 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___285 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___285 *dfl_cftypes;
	struct cftype___285 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___285 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___285 *updated_children;
	struct cgroup___285 *updated_next;
};

struct cgroup_root___285 {
	struct kernfs_root___430 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___285 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___285 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___285 *ss;
	struct list_head node;
	struct kernfs_ops___430 *kf_ops;
	int (*open)(struct kernfs_open_file___430 *);
	void (*release)(struct kernfs_open_file___430 *);
	u64 (*read_u64)(struct cgroup_subsys_state___285 *, struct cftype___285 *);
	s64 (*read_s64)(struct cgroup_subsys_state___285 *, struct cftype___285 *);
	int (*seq_show)(struct seq_file___375 *, void *);
	void * (*seq_start)(struct seq_file___375 *, loff_t *);
	void * (*seq_next)(struct seq_file___375 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___375 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___285 *, struct cftype___285 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___285 *, struct cftype___285 *, s64);
	ssize_t (*write)(struct kernfs_open_file___430 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___430 *, struct poll_table_struct___275 *);
};

struct xdp_rxq_info___81 {
	struct net_device___81 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___81 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___81 *dev_rx;
};

struct netlink_callback___83 {
	struct sk_buff___82 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___83 *);
	int (*dump)(struct sk_buff___82 *, struct netlink_callback___83 *);
	int (*done)(struct netlink_callback___83 *);
	void *data;
	struct module___363 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___81 {
	int (*create)(struct sk_buff___82 *, struct net_device___81 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___82 *, unsigned char *);
	int (*cache)(const struct neighbour___61 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___81 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___81 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___81 *, int);
	int poll_owner;
	struct net_device___81 *dev;
	struct sk_buff___82 *gro_list;
	struct sk_buff___82 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___81 {
	struct net_device___81 *dev;
	struct Qdisc___73 *qdisc;
	struct Qdisc___73 *qdisc_sleeping;
	struct kobject___424 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___81 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___73 {
	struct sk_buff___82 *head;
	struct sk_buff___82 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___73;

struct Qdisc___73 {
	int (*enqueue)(struct sk_buff___82 *, struct Qdisc___73 *, struct sk_buff___82 **);
	struct sk_buff___82 * (*dequeue)(struct Qdisc___73 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___73 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___81 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___81 gso_skb;
	struct qdisc_skb_head___73 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___73 *next_sched;
	struct sk_buff_head___81 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___81 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___424 kobj;
	struct net_device___81 *dev;
	long: 64;
	struct xdp_rxq_info___81 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___81)(struct net_device___81 *, struct sk_buff___82 *, struct net_device___81 *);

struct netdev_bpf___81 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___71 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___71 *prog;
			const struct bpf_prog_offload_ops___71 *ops;
		} verifier;
		struct {
			struct bpf_prog___71 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___81 *offmap;
		};
		struct {
			struct xdp_umem___3 *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___81 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___82 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___81 {
	int (*tls_dev_add)(struct net_device___81 *, struct sock___62 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___81 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___81 *, struct sock___62 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___81 {
	int (*ndo_init)(struct net_device___81 *);
	void (*ndo_uninit)(struct net_device___81 *);
	int (*ndo_open)(struct net_device___81 *);
	int (*ndo_stop)(struct net_device___81 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___82 *, struct net_device___81 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___82 *, struct net_device___81 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___81 *, struct sk_buff___82 *, struct net_device___81 *, select_queue_fallback_t___81);
	void (*ndo_change_rx_flags)(struct net_device___81 *, int);
	void (*ndo_set_rx_mode)(struct net_device___81 *);
	int (*ndo_set_mac_address)(struct net_device___81 *, void *);
	int (*ndo_validate_addr)(struct net_device___81 *);
	int (*ndo_do_ioctl)(struct net_device___81 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___81 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___81 *, int);
	int (*ndo_neigh_setup)(struct net_device___81 *, struct neigh_parms___61 *);
	void (*ndo_tx_timeout)(struct net_device___81 *);
	void (*ndo_get_stats64)(struct net_device___81 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___81 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___81 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___81 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___81 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___81 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___81 *);
	int (*ndo_netpoll_setup)(struct net_device___81 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___81 *);
	int (*ndo_set_vf_mac)(struct net_device___81 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___81 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___81 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___81 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___81 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___81 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___81 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___81 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___81 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___81 *, int, struct sk_buff___82 *);
	int (*ndo_set_vf_guid)(struct net_device___81 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___81 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___81 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___81 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___81 *, const struct sk_buff___82 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___81 *, struct net_device___81 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___81 *, struct net_device___81 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___81 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___81 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___81 *, struct neighbour___61 *);
	void (*ndo_neigh_destroy)(struct net_device___81 *, struct neighbour___61 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___81 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___81 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___81 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___82 *, struct netlink_callback___83 *, struct net_device___81 *, struct net_device___81 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___81 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___81 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___82 *, u32, u32, struct net_device___81 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___81 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___81 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___81 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___81 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___81 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___81 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___81 *, struct net_device___81 *);
	void (*ndo_dfwd_del_station)(struct net_device___81 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___81 *);
	int (*ndo_set_tx_maxrate)(struct net_device___81 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___81 *);
	int (*ndo_change_proto_down)(struct net_device___81 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___81 *, struct sk_buff___82 *);
	void (*ndo_set_rx_headroom)(struct net_device___81 *, int);
	int (*ndo_bpf)(struct net_device___81 *, struct netdev_bpf___81 *);
	int (*ndo_xdp_xmit)(struct net_device___81 *, int, struct xdp_frame___81 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___81 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___81 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___61 {
	possible_net_t___83 net;
	struct net_device___81 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___61 *);
	void (*neigh_cleanup)(struct neighbour___61 *);
	struct neigh_table___61 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___61 {
	u32 (*l3mdev_fib_table)(const struct net_device___81 *);
	struct sk_buff___82 * (*l3mdev_l3_rcv)(struct net_device___81 *, struct sk_buff___82 *, u16);
	struct sk_buff___82 * (*l3mdev_l3_out)(struct net_device___81 *, struct sock___62 *, struct sk_buff___82 *, u16);
	struct dst_entry___61 * (*l3mdev_link_scope_lookup)(const struct net_device___81 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct tcf_proto___73;

struct mini_Qdisc___73 {
	struct tcf_proto___73 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___73 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___81 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___92 *, struct net_device___81 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___81 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___81 *, struct list_head *);
	size_t (*get_size)(const struct net_device___81 *);
	int (*fill_info)(struct sk_buff___82 *, const struct net_device___81 *);
	size_t (*get_xstats_size)(const struct net_device___81 *);
	int (*fill_xstats)(struct sk_buff___82 *, const struct net_device___81 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___81 *, struct net_device___81 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___81 *, const struct net_device___81 *);
	int (*fill_slave_info)(struct sk_buff___82 *, const struct net_device___81 *, const struct net_device___81 *);
	struct net___92 * (*get_link_net)(const struct net_device___81 *);
	size_t (*get_linkxstats_size)(const struct net_device___81 *, int);
	int (*fill_linkxstats)(struct sk_buff___82 *, const struct net_device___81 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___81 {
	struct list_head poll_list;
	struct sk_buff_head___81 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___81 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___73 *output_queue;
	struct Qdisc___73 **output_queue_tailp;
	struct sk_buff___82 *completion_queue;
	struct sk_buff_head___81 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___81 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___81 input_pkt_queue;
	struct napi_struct___81 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct nf_hook_state___6 {
	unsigned int hook;
	u_int8_t pf;
	struct net_device___81 *in;
	struct net_device___81 *out;
	struct sock___62 *sk;
	struct net___92 *net;
	int (*okfn)(struct net___92 *, struct sock___62 *, struct sk_buff___82 *);
};

struct nf_nat_hook___6 {
	int (*parse_nat_setup)(struct nf_conn *, enum nf_nat_manip_type, const struct nlattr *);
	void (*decode_session)(struct sk_buff___82 *, struct flowi *);
	unsigned int (*manip_pkt)(struct sk_buff___82 *, struct nf_conn *, enum nf_nat_manip_type, enum ip_conntrack_dir);
};

struct nf_ct_hook___6 {
	int (*update)(struct net___92 *, struct sk_buff___82 *);
	void (*destroy)(struct nf_conntrack *);
	bool (*get_tuple_skb)(struct nf_conntrack_tuple *, const struct sk_buff___82 *);
};

struct nfnl_ct_hook___6 {
	struct nf_conn * (*get_ct)(const struct sk_buff___82 *, enum ip_conntrack_info *);
	size_t (*build_size)(const struct nf_conn *);
	int (*build)(struct sk_buff___82 *, struct nf_conn *, enum ip_conntrack_info, u_int16_t, u_int16_t);
	int (*parse)(const struct nlattr *, struct nf_conn *);
	int (*attach_expect)(const struct nlattr *, struct nf_conn *, u32, u32);
	void (*seq_adjust)(struct sk_buff___82 *, struct nf_conn *, enum ip_conntrack_info, s32);
};

struct nf_ipv6_ops___4 {
	int (*chk_addr)(struct net___92 *, const struct in6_addr *, const struct net_device___81 *, int);
	void (*route_input)(struct sk_buff___82 *);
	int (*fragment)(struct net___92 *, struct sock___62 *, struct sk_buff___82 *, int (*)(struct net___92 *, struct sock___62 *, struct sk_buff___82 *));
	__sum16 (*checksum)(struct sk_buff___82 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___82 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___92 *, struct dst_entry___61 **, struct flowi *, bool);
	int (*reroute)(struct sk_buff___82 *, const struct nf_queue_entry___3 *);
};

struct nf_queue_entry___3 {
	struct list_head list;
	struct sk_buff___82 *skb;
	unsigned int id;
	unsigned int hook_index;
	struct nf_hook_state___6 state;
	u16 size;
};

struct bdi_writeback_congested___226 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___226 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___226 {
	struct bio___226 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___228 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___228 bip_inline_vecs[0];
};

struct bio_set___226 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___226 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___169 {
	struct mem_cgroup___169 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___169 {
	struct lruvec___437 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___169 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___169 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct kernel_param_ops___362 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___362 *);
	int (*get)(char *, const struct kernel_param___362 *);
	void (*free)(void *);
};

struct kparam_array___362;

struct kernel_param___362 {
	const char *name;
	struct module___363 *mod;
	const struct kernel_param_ops___362 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___362 *arr;
	};
};

struct kparam_array___362 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___362 *ops;
	void *elem;
};

struct module_attribute___362 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___362 *, struct module_kobject___362 *, char *);
	ssize_t (*store)(struct module_attribute___362 *, struct module_kobject___362 *, const char *, size_t);
	void (*setup)(struct module___363 *, const char *);
	int (*test)(struct module___363 *);
	void (*free)(struct module___363 *);
};

struct gnet_dump___73 {
	spinlock_t *lock;
	struct sk_buff___82 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___73;

struct Qdisc_ops___73 {
	struct Qdisc_ops___73 *next;
	const struct Qdisc_class_ops___73 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___82 *, struct Qdisc___73 *, struct sk_buff___82 **);
	struct sk_buff___82 * (*dequeue)(struct Qdisc___73 *);
	struct sk_buff___82 * (*peek)(struct Qdisc___73 *);
	int (*init)(struct Qdisc___73 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___73 *);
	void (*destroy)(struct Qdisc___73 *);
	int (*change)(struct Qdisc___73 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___73 *);
	int (*change_tx_queue_len)(struct Qdisc___73 *, unsigned int);
	int (*dump)(struct Qdisc___73 *, struct sk_buff___82 *);
	int (*dump_stats)(struct Qdisc___73 *, struct gnet_dump___73 *);
	void (*ingress_block_set)(struct Qdisc___73 *, u32);
	void (*egress_block_set)(struct Qdisc___73 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___73 *);
	u32 (*egress_block_get)(struct Qdisc___73 *);
	struct module___363 *owner;
};

struct tcf_block___73;

struct Qdisc_class_ops___73 {
	unsigned int flags;
	struct netdev_queue___81 * (*select_queue)(struct Qdisc___73 *, struct tcmsg *);
	int (*graft)(struct Qdisc___73 *, long unsigned int, struct Qdisc___73 *, struct Qdisc___73 **, struct netlink_ext_ack *);
	struct Qdisc___73 * (*leaf)(struct Qdisc___73 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___73 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___73 *, u32);
	int (*change)(struct Qdisc___73 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___73 *, long unsigned int);
	void (*walk)(struct Qdisc___73 *, struct qdisc_walker *);
	struct tcf_block___73 * (*tcf_block)(struct Qdisc___73 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___73 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___73 *, long unsigned int);
	int (*dump)(struct Qdisc___73 *, long unsigned int, struct sk_buff___82 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___73 *, long unsigned int, struct gnet_dump___73 *);
};

struct tcf_chain___73;

struct tcf_block___73 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___92 *net;
	struct Qdisc___73 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___73 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___73;

struct tcf_proto_ops___73;

struct tcf_proto___73 {
	struct tcf_proto___73 *next;
	void *root;
	int (*classify)(struct sk_buff___82 *, const struct tcf_proto___73 *, struct tcf_result___73 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___73 *ops;
	struct tcf_chain___73 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___73 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___73 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___73 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___82 *, const struct tcf_proto___73 *, struct tcf_result___73 *);
	int (*init)(struct tcf_proto___73 *);
	void (*destroy)(struct tcf_proto___73 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___73 *, u32);
	void (*put)(struct tcf_proto___73 *, void *);
	int (*change)(struct net___92 *, struct sk_buff___82 *, struct tcf_proto___73 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___73 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___73 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___73 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___92 *, struct tcf_chain___73 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___92 *, struct tcf_proto___73 *, void *, struct sk_buff___82 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___82 *, struct net___92 *, void *);
	struct module___363 *owner;
	int flags;
};

struct tcf_chain___73 {
	struct mutex filter_chain_lock;
	struct tcf_proto___73 *filter_chain;
	struct list_head list;
	struct tcf_block___73 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___73 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___61 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___71 *prog;
};

struct bpf_redirect_info___71 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___286 *map;
	struct bpf_map___286 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___61;

struct neigh_hash_table___61;

struct neigh_table___61 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___81 *, __u32 *);
	bool (*key_eq)(const struct neighbour___61 *, const void *);
	int (*constructor)(struct neighbour___61 *);
	int (*pconstructor)(struct pneigh_entry___61 *);
	void (*pdestructor)(struct pneigh_entry___61 *);
	void (*proxy_redo)(struct sk_buff___82 *);
	char *id;
	struct neigh_parms___61 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___81 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___61 *nht;
	struct pneigh_entry___61 **phash_buckets;
};

struct neigh_ops___61 {
	int family;
	void (*solicit)(struct neighbour___61 *, struct sk_buff___82 *);
	void (*error_report)(struct neighbour___61 *, struct sk_buff___82 *);
	int (*output)(struct neighbour___61 *, struct sk_buff___82 *);
	int (*connected_output)(struct neighbour___61 *, struct sk_buff___82 *);
};

struct pneigh_entry___61 {
	struct pneigh_entry___61 *next;
	possible_net_t___83 net;
	struct net_device___81 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___61 {
	struct neighbour___61 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___61 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___61 *ctarget;
	struct net___92 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___61 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___61 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___44;

struct timewait_sock_ops___40;

struct proto___61 {
	void (*close)(struct sock___62 *, long int);
	int (*pre_connect)(struct sock___62 *, struct sockaddr *, int);
	int (*connect)(struct sock___62 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___62 *, int);
	struct sock___62 * (*accept)(struct sock___62 *, int, int *, bool);
	int (*ioctl)(struct sock___62 *, int, long unsigned int);
	int (*init)(struct sock___62 *);
	void (*destroy)(struct sock___62 *);
	void (*shutdown)(struct sock___62 *, int);
	int (*setsockopt)(struct sock___62 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___62 *, int, int, char *, int *);
	void (*keepalive)(struct sock___62 *, int);
	int (*sendmsg)(struct sock___62 *, struct msghdr___64 *, size_t);
	int (*recvmsg)(struct sock___62 *, struct msghdr___64 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___62 *, struct page___437 *, int, size_t, int);
	int (*bind)(struct sock___62 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___62 *, struct sk_buff___82 *);
	void (*release_cb)(struct sock___62 *);
	int (*hash)(struct sock___62 *);
	void (*unhash)(struct sock___62 *);
	void (*rehash)(struct sock___62 *);
	int (*get_port)(struct sock___62 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___62 *);
	bool (*stream_memory_read)(const struct sock___62 *);
	void (*enter_memory_pressure)(struct sock___62 *);
	void (*leave_memory_pressure)(struct sock___62 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___44 *rsk_prot;
	struct timewait_sock_ops___40 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___363 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___62 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct request_sock___45;

struct request_sock_ops___44 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___62 *, struct request_sock___45 *);
	void (*send_ack)(const struct sock___62 *, struct sk_buff___82 *, struct request_sock___45 *);
	void (*send_reset)(const struct sock___62 *, struct sk_buff___82 *);
	void (*destructor)(struct request_sock___45 *);
	void (*syn_ack_timeout)(const struct request_sock___45 *);
};

struct timewait_sock_ops___40 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___62 *, struct sock___62 *, void *);
	void (*twsk_destructor)(struct sock___62 *);
};

struct request_sock___45 {
	struct sock_common___61 __req_common;
	struct request_sock___45 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___44 *rsk_ops;
	struct sock___62 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct module___364;

struct file___437;

struct kiocb___437;

struct iov_iter___204;

struct poll_table_struct___276;

struct vm_area_struct___438;

struct inode___437;

struct file_lock___437;

struct page___438;

struct pipe_inode_info___118;

struct seq_file___376;

struct file_operations___437 {
	struct module___364 *owner;
	loff_t (*llseek)(struct file___437 *, loff_t, int);
	ssize_t (*read)(struct file___437 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___437 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___437 *, struct iov_iter___204 *);
	ssize_t (*write_iter)(struct kiocb___437 *, struct iov_iter___204 *);
	int (*iopoll)(struct kiocb___437 *, bool);
	int (*iterate)(struct file___437 *, struct dir_context *);
	int (*iterate_shared)(struct file___437 *, struct dir_context *);
	__poll_t (*poll)(struct file___437 *, struct poll_table_struct___276 *);
	long int (*unlocked_ioctl)(struct file___437 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___437 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___437 *, struct vm_area_struct___438 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___437 *, struct file___437 *);
	int (*flush)(struct file___437 *, fl_owner_t);
	int (*release)(struct inode___437 *, struct file___437 *);
	int (*fsync)(struct file___437 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___437 *, int);
	int (*lock)(struct file___437 *, int, struct file_lock___437 *);
	ssize_t (*sendpage)(struct file___437 *, struct page___438 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___437 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___437 *, int, struct file_lock___437 *);
	ssize_t (*splice_write)(struct pipe_inode_info___118 *, struct file___437 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___437 *, loff_t *, struct pipe_inode_info___118 *, size_t, unsigned int);
	int (*setlease)(struct file___437 *, long int, struct file_lock___437 **, void **);
	long int (*fallocate)(struct file___437 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___376 *, struct file___437 *);
	ssize_t (*copy_file_range)(struct file___437 *, loff_t, struct file___437 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___437 *, loff_t, struct file___437 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___437 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___438 {
	u64 seqnum;
	struct vm_area_struct___438 *vmas[4];
};

struct page_frag___438 {
	struct page___438 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___438;

struct mem_cgroup___170;

struct pid___242;

struct cred___405;

struct nsproxy___332;

struct signal_struct___312;

struct bio_list___227;

struct backing_dev_info___227;

struct css_set___286;

struct vm_struct___341;

struct task_struct___439 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___439 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___438 *mm;
	struct mm_struct___438 *active_mm;
	struct vmacache___438 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___439 *real_parent;
	struct task_struct___439 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___439 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___170 *active_memcg;
	long int rh_reserved2;
	struct pid___242 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___242 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___242 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___405 *ptracer_cred;
	const struct cred___405 *real_cred;
	const struct cred___405 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___332 *nsproxy;
	struct signal_struct___312 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___439 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___227 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___227 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___286 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___118 *splice_pipe;
	struct page_frag___438 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___170 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___439 *oom_reaper_list;
	struct vm_struct___341 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___156 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rw_semaphore___439 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___439 *owner;
};

struct key___405;

struct ucounts___302;

struct user_namespace___302 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___302 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___29 ns;
	long unsigned int flags;
	struct key___405 *persistent_keyring_register;
	struct rw_semaphore___439 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___302 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___438 *pgtable_t___438;

struct address_space___437;

struct dev_pagemap___425;

struct page___438 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___437 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___438 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___438 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___438 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___425 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___170 *mem_cgroup;
};

struct pglist_data___438;

struct lruvec___438 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___438 *pgdat;
};

struct zone___438 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___438 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___438 {
	struct zone___438 *zone;
	int zone_idx;
};

struct zonelist___438 {
	struct zoneref___438 _zonerefs[25];
};

struct pglist_data___438 {
	struct zone___438 node_zones[3];
	struct zonelist___438 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___439 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___439 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___438 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___439 {
	void *stack;
	struct task_struct___439 *task;
	long int status;
};

struct blocking_notifier_head___438 {
	struct rw_semaphore___439 rwsem;
	struct notifier_block *head;
};

struct dentry___437;

struct path___438 {
	struct vfsmount *mnt;
	struct dentry___437 *dentry;
};

struct fown_struct___242 {
	rwlock_t lock;
	struct pid___242 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___437 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___438 f_path;
	struct inode___437 *f_inode;
	const struct file_operations___437 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___242 f_owner;
	const struct cred___405 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___437 *f_mapping;
	errseq_t f_wb_err;
};

struct user_struct___405;

struct cred___405 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___405 *session_keyring;
	struct key___405 *process_keyring;
	struct key___405 *thread_keyring;
	struct key___405 *request_key_auth;
	void *security;
	struct user_struct___405 *user;
	struct user_namespace___302 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___431;

struct kernfs_elem_dir___431 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___431 *root;
};

struct kernfs_node___432;

struct kernfs_syscall_ops___431;

struct kernfs_root___431 {
	struct kernfs_node___432 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___431 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___431 {
	struct kernfs_node___432 *target_kn;
};

struct kernfs_ops___431;

struct kernfs_elem_attr___431 {
	const struct kernfs_ops___431 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___432 *notify_next;
};

struct kernfs_node___432 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___432 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___431 dir;
		struct kernfs_elem_symlink___431 symlink;
		struct kernfs_elem_attr___431 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___431;

struct kernfs_ops___431 {
	int (*open)(struct kernfs_open_file___431 *);
	void (*release)(struct kernfs_open_file___431 *);
	int (*seq_show)(struct seq_file___376 *, void *);
	void * (*seq_start)(struct seq_file___376 *, loff_t *);
	void * (*seq_next)(struct seq_file___376 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___376 *, void *);
	ssize_t (*read)(struct kernfs_open_file___431 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___431 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___431 *, struct vm_area_struct___438 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___431 *, struct poll_table_struct___276 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___431 {
	int (*remount_fs)(struct kernfs_root___431 *, int *, char *);
	int (*show_options)(struct seq_file___376 *, struct kernfs_root___431 *);
	int (*mkdir)(struct kernfs_node___432 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___432 *);
	int (*rename)(struct kernfs_node___432 *, struct kernfs_node___432 *, const char *);
	int (*show_path)(struct seq_file___376 *, struct kernfs_node___432 *, struct kernfs_root___431 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___376;

struct seq_file___376 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___376 *op;
	int poll_event;
	const struct file___437 *file;
	void *private;
};

struct vm_operations_struct___425;

struct kernfs_open_file___431 {
	struct kernfs_node___432 *kn;
	struct file___437 *file;
	struct seq_file___376 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___425 *vm_ops;
};

struct vm_fault___425;

struct vm_operations_struct___425 {
	void (*open)(struct vm_area_struct___438 *);
	void (*close)(struct vm_area_struct___438 *);
	int (*split)(struct vm_area_struct___438 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___438 *);
	vm_fault_t (*fault)(struct vm_fault___425 *);
	vm_fault_t (*huge_fault)(struct vm_fault___425 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___425 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___438 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___425 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___425 *);
	int (*access)(struct vm_area_struct___438 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___438 *);
	int (*set_policy)(struct vm_area_struct___438 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___438 *, long unsigned int);
	struct page___438 * (*find_special_page)(struct vm_area_struct___438 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___286)(struct file___437 *, wait_queue_head_t *, struct poll_table_struct___276 *);

struct poll_table_struct___276 {
	poll_queue_proc___286 _qproc;
	__poll_t _key;
};

struct vm_area_struct___438 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___438 *vm_next;
	struct vm_area_struct___438 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___438 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___425 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___437 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sock___63;

struct kobj_ns_type_operations___62 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___63 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct net___93;

typedef struct {
	struct net___93 *net;
} possible_net_t___84;

struct proto___62;

struct sock_common___62 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___62 *skc_prot;
	possible_net_t___84 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___63 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___83;

struct sk_buff_head___82 {
	struct sk_buff___83 *next;
	struct sk_buff___83 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___62;

struct socket_wq___63;

struct dst_entry___62;

struct socket___64;

struct net_device___82;

struct sock___63 {
	struct sock_common___62 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___82 sk_error_queue;
	struct sk_buff_head___82 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___83 *head;
		struct sk_buff___83 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___62 *sk_filter;
	union {
		struct socket_wq___63 *sk_wq;
		struct socket_wq___63 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___62 *sk_rx_dst;
	struct dst_entry___62 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___83 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___82 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___438 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___62 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___242 *sk_peer_pid;
	const struct cred___405 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___64 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___170 *sk_memcg;
	void (*sk_state_change)(struct sock___63 *);
	void (*sk_data_ready)(struct sock___63 *);
	void (*sk_write_space)(struct sock___63 *);
	void (*sk_error_report)(struct sock___63 *);
	int (*sk_backlog_rcv)(struct sock___63 *, struct sk_buff___83 *);
	struct sk_buff___83 * (*sk_validate_xmit_skb)(struct sock___63 *, struct net_device___82 *, struct sk_buff___83 *);
	void (*sk_destruct)(struct sock___63 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kobject___425;

struct bin_attribute___401;

struct attribute_group___402 {
	const char *name;
	umode_t (*is_visible)(struct kobject___425 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___425 *, struct bin_attribute___401 *, int);
	struct attribute **attrs;
	struct bin_attribute___401 **bin_attrs;
};

struct kset___424;

struct kobj_type___424;

struct kobject___425 {
	const char *name;
	struct list_head entry;
	struct kobject___425 *parent;
	struct kset___424 *kset;
	struct kobj_type___424 *ktype;
	struct kernfs_node___432 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___401 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___437 *, struct kobject___425 *, struct bin_attribute___401 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___437 *, struct kobject___425 *, struct bin_attribute___401 *, char *, loff_t, size_t);
	int (*mmap)(struct file___437 *, struct kobject___425 *, struct bin_attribute___401 *, struct vm_area_struct___438 *);
};

struct sysfs_ops___424 {
	ssize_t (*show)(struct kobject___425 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___425 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___424;

struct kset___424 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___425 kobj;
	const struct kset_uevent_ops___424 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___424 {
	void (*release)(struct kobject___425 *);
	const struct sysfs_ops___424 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___62 * (*child_ns_type)(struct kobject___425 *);
	const void * (*namespace)(struct kobject___425 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___424 {
	int (* const filter)(struct kset___424 *, struct kobject___425 *);
	const char * (* const name)(struct kset___424 *, struct kobject___425 *);
	int (* const uevent)(struct kset___424 *, struct kobject___425 *, struct kobj_uevent_env *);
};

struct kobj_attribute___415 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___425 *, struct kobj_attribute___415 *, char *);
	ssize_t (*store)(struct kobject___425 *, struct kobj_attribute___415 *, const char *, size_t);
};

struct kernel_param___363;

struct kernel_param_ops___363 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___363 *);
	int (*get)(char *, const struct kernel_param___363 *);
	void (*free)(void *);
};

struct kparam_array___363;

struct kernel_param___363 {
	const char *name;
	struct module___364 *mod;
	const struct kernel_param_ops___363 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___363 *arr;
	};
};

struct kparam_array___363 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___363 *ops;
	void *elem;
};

struct module_kobject___363 {
	struct kobject___425 kobj;
	struct module___364 *mod;
	struct kobject___425 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___363 {
	struct module___364 *mod;
	struct latch_tree_node node;
};

struct module_layout___363 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___363 mtn;
};

struct module_attribute___363;

struct module___364 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___363 mkobj;
	struct module_attribute___363 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___425 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___363 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___363 core_layout;
	struct module_layout___363 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___363 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___363 *, struct module_kobject___363 *, char *);
	ssize_t (*store)(struct module_attribute___363 *, struct module_kobject___363 *, const char *, size_t);
	void (*setup)(struct module___364 *, const char *);
	int (*test)(struct module___364 *);
	void (*free)(struct module___364 *);
};

struct cgroup___286;

struct cgroup_subsys___286;

struct cgroup_subsys_state___286 {
	struct cgroup___286 *cgroup;
	struct cgroup_subsys___286 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___286 *parent;
};

struct cgroup_file___286 {
	struct kernfs_node___432 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___170;

struct mem_cgroup___170 {
	struct cgroup_subsys_state___286 css;
	struct mem_cgroup_id___13 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___286 events_file;
	struct cgroup_file___286 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___439 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___170 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___242;

struct upid___242 {
	int nr;
	struct pid_namespace___242 *ns;
};

struct pid_namespace___242 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___439 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___242 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___437 *proc_self;
	struct dentry___437 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___302 *user_ns;
	struct ucounts___302 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___29 ns;
};

struct pid___242 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___242 numbers[1];
};

struct user_struct___405 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___405 *uid_keyring;
	struct key___405 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___438;

struct mm_struct___438 {
	struct {
		struct vm_area_struct___438 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___437 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___439 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___438 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___439 *owner;
		struct user_namespace___302 *user_ns;
		struct file___437 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___438 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___286;

struct nsproxy___332 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___242 *pid_ns_for_children;
	struct net___93 *net_ns;
	struct cgroup_namespace___286 *cgroup_ns;
};

struct signal_struct___312 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___439 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___439 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___242 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___242 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___438 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___242 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___227;

struct bio_list___227 {
	struct bio___227 *head;
	struct bio___227 *tail;
};

struct bdi_writeback_congested___227;

struct bdi_writeback___227 {
	struct backing_dev_info___227 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___227 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___286 *memcg_css;
	struct cgroup_subsys_state___286 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___405;

struct backing_dev_info___227 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___227 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___405 *dev;
	struct device___405 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___437 *debug_dir;
	struct dentry___437 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___286 {
	struct cgroup_subsys_state___286 *subsys[13];
	refcount_t refcount;
	struct css_set___286 *dom_cset;
	struct cgroup___286 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___286 *mg_src_cgrp;
	struct cgroup___286 *mg_dst_cgrp;
	struct css_set___286 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___437;

struct pipe_buffer___118;

struct pipe_inode_info___118 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___438 *tmp_page;
	struct fasync_struct___437 *fasync_readers;
	struct fasync_struct___437 *fasync_writers;
	struct pipe_buffer___118 *bufs;
	struct user_struct___405 *user;
};

struct vm_struct___341 {
	struct vm_struct___341 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___438 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___324 {
	struct task_struct___439 task;
	long unsigned int stack[8192];
};

struct address_space_operations___437;

struct address_space___437 {
	struct inode___437 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___439 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___437 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___425)(struct vm_area_struct___438 *, long unsigned int, const struct page___438 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___425)(struct page___438 *, void *);

struct dev_pagemap___425 {
	dev_page_fault_t___425 page_fault;
	dev_page_free_t___425 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___405 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___438 {
	struct task_struct___439 *task;
	struct core_thread___438 *next;
};

struct core_state___438 {
	atomic_t nr_threads;
	struct core_thread___438 dumper;
	struct completion startup;
};

struct vm_fault___425 {
	struct vm_area_struct___438 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___438 *cow_page;
	struct mem_cgroup___170 *memcg;
	struct page___438 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___438 prealloc_pte;
};

struct bio_vec___229 {
	struct page___438 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___204 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___229 *bvec;
		struct pipe_inode_info___118 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct msghdr___65 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___204 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___437 *msg_iocb;
};

struct kiocb___437 {
	struct file___437 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___437 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dentry_operations___437;

struct super_block___437;

struct dentry___437 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___437 *d_parent;
	struct qstr d_name;
	struct inode___437 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___437 *d_op;
	struct super_block___437 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___437;

struct block_device___437;

struct inode___437 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___437 *i_op;
	struct super_block___437 *i_sb;
	struct address_space___437 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___439 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___227 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___437 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___437 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___118 *i_pipe;
		struct block_device___437 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___437 {
	int (*d_revalidate)(struct dentry___437 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___437 *, unsigned int);
	int (*d_hash)(const struct dentry___437 *, struct qstr *);
	int (*d_compare)(const struct dentry___437 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___437 *);
	int (*d_init)(struct dentry___437 *);
	void (*d_release)(struct dentry___437 *);
	void (*d_prune)(struct dentry___437 *);
	void (*d_iput)(struct dentry___437 *, struct inode___437 *);
	char * (*d_dname)(struct dentry___437 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___438 *);
	int (*d_manage)(const struct path___438 *, bool);
	struct dentry___437 * (*d_real)(struct dentry___437 *, const struct inode___437 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___437;

struct mem_dqinfo___437 {
	struct quota_format_type___437 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___437;

struct quota_info___437 {
	unsigned int flags;
	struct rw_semaphore___439 dqio_sem;
	struct inode___437 *files[3];
	struct mem_dqinfo___437 info[3];
	const struct quota_format_ops___437 *ops[3];
};

struct rcuwait___437 {
	struct task_struct___439 *task;
};

struct percpu_rw_semaphore___437 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___439 rw_sem;
	struct rcuwait___437 writer;
	int readers_block;
};

struct sb_writers___437 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___437 rw_sem[3];
};

struct shrink_control___170;

struct shrinker___170 {
	long unsigned int (*count_objects)(struct shrinker___170 *, struct shrink_control___170 *);
	long unsigned int (*scan_objects)(struct shrinker___170 *, struct shrink_control___170 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___437;

struct super_operations___437;

struct dquot_operations___437;

struct quotactl_ops___437;

struct super_block___437 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___437 *s_type;
	const struct super_operations___437 *s_op;
	const struct dquot_operations___437 *dq_op;
	const struct quotactl_ops___437 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___437 *s_root;
	struct rw_semaphore___439 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___437 *s_bdev;
	struct backing_dev_info___227 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___437 s_dquot;
	struct sb_writers___437 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___437 *s_d_op;
	int cleancache_poolid;
	struct shrinker___170 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___302 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___170 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___170 *memcg;
};

struct iattr___437 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___437 *ia_file;
};

struct dquot___437 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___437 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___437 {
	int qf_fmt_id;
	const struct quota_format_ops___437 *qf_ops;
	struct module___364 *qf_owner;
	struct quota_format_type___437 *qf_next;
};

struct quota_format_ops___437 {
	int (*check_quota_file)(struct super_block___437 *, int);
	int (*read_file_info)(struct super_block___437 *, int);
	int (*write_file_info)(struct super_block___437 *, int);
	int (*free_file_info)(struct super_block___437 *, int);
	int (*read_dqblk)(struct dquot___437 *);
	int (*commit_dqblk)(struct dquot___437 *);
	int (*release_dqblk)(struct dquot___437 *);
	int (*get_next_id)(struct super_block___437 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___437 {
	int (*write_dquot)(struct dquot___437 *);
	struct dquot___437 * (*alloc_dquot)(struct super_block___437 *, int);
	void (*destroy_dquot)(struct dquot___437 *);
	int (*acquire_dquot)(struct dquot___437 *);
	int (*release_dquot)(struct dquot___437 *);
	int (*mark_dirty)(struct dquot___437 *);
	int (*write_info)(struct super_block___437 *, int);
	qsize_t * (*get_reserved_space)(struct inode___437 *);
	int (*get_projid)(struct inode___437 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___437 *, qsize_t *);
	int (*get_next_id)(struct super_block___437 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___437 {
	int (*quota_on)(struct super_block___437 *, int, int, const struct path___438 *);
	int (*quota_off)(struct super_block___437 *, int);
	int (*quota_enable)(struct super_block___437 *, unsigned int);
	int (*quota_disable)(struct super_block___437 *, unsigned int);
	int (*quota_sync)(struct super_block___437 *, int);
	int (*set_info)(struct super_block___437 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___437 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___437 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___437 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___437 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___437 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___190;

struct address_space_operations___437 {
	int (*writepage)(struct page___438 *, struct writeback_control___190 *);
	int (*readpage)(struct file___437 *, struct page___438 *);
	int (*writepages)(struct address_space___437 *, struct writeback_control___190 *);
	int (*set_page_dirty)(struct page___438 *);
	int (*readpages)(struct file___437 *, struct address_space___437 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___437 *, struct address_space___437 *, loff_t, unsigned int, unsigned int, struct page___438 **, void **);
	int (*write_end)(struct file___437 *, struct address_space___437 *, loff_t, unsigned int, unsigned int, struct page___438 *, void *);
	sector_t (*bmap)(struct address_space___437 *, sector_t);
	void (*invalidatepage)(struct page___438 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___438 *, gfp_t);
	void (*freepage)(struct page___438 *);
	ssize_t (*direct_IO)(struct kiocb___437 *, struct iov_iter___204 *);
	int (*migratepage)(struct address_space___437 *, struct page___438 *, struct page___438 *, enum migrate_mode);
	bool (*isolate_page)(struct page___438 *, isolate_mode_t);
	void (*putback_page)(struct page___438 *);
	int (*launder_page)(struct page___438 *);
	int (*is_partially_uptodate)(struct page___438 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___438 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___437 *, struct page___438 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___437 *, sector_t *);
	void (*swap_deactivate)(struct file___437 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___190 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___227 *wb;
	struct inode___437 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___437 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___437 *bd_inode;
	struct super_block___437 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___437 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___227 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___437 {
	struct dentry___437 * (*lookup)(struct inode___437 *, struct dentry___437 *, unsigned int);
	const char * (*get_link)(struct dentry___437 *, struct inode___437 *, struct delayed_call *);
	int (*permission)(struct inode___437 *, int);
	struct posix_acl * (*get_acl)(struct inode___437 *, int);
	int (*readlink)(struct dentry___437 *, char *, int);
	int (*create)(struct inode___437 *, struct dentry___437 *, umode_t, bool);
	int (*link)(struct dentry___437 *, struct inode___437 *, struct dentry___437 *);
	int (*unlink)(struct inode___437 *, struct dentry___437 *);
	int (*symlink)(struct inode___437 *, struct dentry___437 *, const char *);
	int (*mkdir)(struct inode___437 *, struct dentry___437 *, umode_t);
	int (*rmdir)(struct inode___437 *, struct dentry___437 *);
	int (*mknod)(struct inode___437 *, struct dentry___437 *, umode_t, dev_t);
	int (*rename)(struct inode___437 *, struct dentry___437 *, struct inode___437 *, struct dentry___437 *, unsigned int);
	int (*setattr)(struct dentry___437 *, struct iattr___437 *);
	int (*getattr)(const struct path___438 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___437 *, char *, size_t);
	int (*fiemap)(struct inode___437 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___437 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___437 *, struct dentry___437 *, struct file___437 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___437 *, struct dentry___437 *, umode_t);
	int (*set_acl)(struct inode___437 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___437 {
	void (*fl_copy_lock)(struct file_lock___437 *, struct file_lock___437 *);
	void (*fl_release_private)(struct file_lock___437 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___437;

struct file_lock___437 {
	struct file_lock___437 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___437 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___437 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___437 *fl_ops;
	const struct lock_manager_operations___437 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___437 {
	int (*lm_compare_owner)(struct file_lock___437 *, struct file_lock___437 *);
	long unsigned int (*lm_owner_key)(struct file_lock___437 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___437 *);
	int (*lm_grant)(struct file_lock___437 *, int);
	bool (*lm_break)(struct file_lock___437 *);
	int (*lm_change)(struct file_lock___437 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___437 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___437 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___437 *fa_next;
	struct file___437 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___437 {
	const char *name;
	int fs_flags;
	struct dentry___437 * (*mount)(struct file_system_type___437 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___437 *);
	struct module___364 *owner;
	struct file_system_type___437 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___437 {
	struct inode___437 * (*alloc_inode)(struct super_block___437 *);
	void (*destroy_inode)(struct inode___437 *);
	void (*dirty_inode)(struct inode___437 *, int);
	int (*write_inode)(struct inode___437 *, struct writeback_control___190 *);
	int (*drop_inode)(struct inode___437 *);
	void (*evict_inode)(struct inode___437 *);
	void (*put_super)(struct super_block___437 *);
	int (*sync_fs)(struct super_block___437 *, int);
	int (*freeze_super)(struct super_block___437 *);
	int (*freeze_fs)(struct super_block___437 *);
	int (*thaw_super)(struct super_block___437 *);
	int (*unfreeze_fs)(struct super_block___437 *);
	int (*statfs)(struct dentry___437 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___437 *, int *, char *);
	void (*umount_begin)(struct super_block___437 *);
	int (*show_options)(struct seq_file___376 *, struct dentry___437 *);
	int (*show_devname)(struct seq_file___376 *, struct dentry___437 *);
	int (*show_path)(struct seq_file___376 *, struct dentry___437 *);
	int (*show_stats)(struct seq_file___376 *, struct dentry___437 *);
	ssize_t (*quota_read)(struct super_block___437 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___437 *, int, const char *, size_t, loff_t);
	struct dquot___437 ** (*get_dquots)(struct inode___437 *);
	int (*bdev_try_to_free_page)(struct super_block___437 *, struct page___438 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___437 *, struct shrink_control___170 *);
	long int (*free_cached_objects)(struct super_block___437 *, struct shrink_control___170 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___227(struct bio___227 *);

struct bio_integrity_payload___227;

struct bio_set___227;

struct bio___227 {
	struct bio___227 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___227 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___227 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___229 *bi_io_vec;
	struct bio_set___227 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___229 bi_inline_vecs[0];
};

struct socket_wq___63 {
	wait_queue_head_t wait;
	struct fasync_struct___437 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___63;

struct socket___64 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___63 *wq;
	struct file___437 *file;
	struct sock___63 *sk;
	const struct proto_ops___63 *ops;
};

typedef int (*sk_read_actor_t___62)(read_descriptor_t *, struct sk_buff___83 *, unsigned int, size_t);

struct proto_ops___63 {
	int family;
	struct module___364 *owner;
	int (*release)(struct socket___64 *);
	int (*bind)(struct socket___64 *, struct sockaddr *, int);
	int (*connect)(struct socket___64 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___64 *, struct socket___64 *);
	int (*accept)(struct socket___64 *, struct socket___64 *, int, bool);
	int (*getname)(struct socket___64 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___437 *, struct socket___64 *, struct poll_table_struct___276 *);
	int (*ioctl)(struct socket___64 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___64 *, int);
	int (*shutdown)(struct socket___64 *, int);
	int (*setsockopt)(struct socket___64 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___64 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___64 *, struct msghdr___65 *, size_t);
	int (*recvmsg)(struct socket___64 *, struct msghdr___65 *, size_t, int);
	int (*mmap)(struct file___437 *, struct socket___64 *, struct vm_area_struct___438 *);
	ssize_t (*sendpage)(struct socket___64 *, struct page___438 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___64 *, loff_t *, struct pipe_inode_info___118 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___63 *, int);
	int (*peek_len)(struct socket___64 *);
	int (*read_sock)(struct sock___63 *, read_descriptor_t *, sk_read_actor_t___62);
	int (*sendpage_locked)(struct sock___63 *, struct page___438 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___63 *, struct msghdr___65 *, size_t);
	int (*set_rcvlowat)(struct sock___63 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct nf_bridge_info___82;

struct sk_buff___83 {
	union {
		struct {
			struct sk_buff___83 *next;
			struct sk_buff___83 *prev;
			union {
				struct net_device___82 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___63 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___83 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___82 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___82;

struct netns_frags___82 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___82 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_rules_ops___62;

struct xt_table___2;

struct fib_notifier_ops___63;

struct netns_ipv4___82 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___62 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___63 *fibnl;
	struct sock___63 **icmp_sk;
	struct sock___63 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___63 **tcp_sk;
	struct netns_frags___82 frags;
	struct xt_table___2 *iptable_filter;
	struct xt_table___2 *iptable_mangle;
	struct xt_table___2 *iptable_raw;
	struct xt_table___2 *arptable_filter;
	struct xt_table___2 *iptable_security;
	struct xt_table___2 *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___62 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___63 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___63 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___62;

struct dst_ops___93 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___93 *);
	struct dst_entry___62 * (*check)(struct dst_entry___62 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___62 *);
	unsigned int (*mtu)(const struct dst_entry___62 *);
	u32 * (*cow_metrics)(struct dst_entry___62 *, long unsigned int);
	void (*destroy)(struct dst_entry___62 *);
	void (*ifdown)(struct dst_entry___62 *, struct net_device___82 *, int);
	struct dst_entry___62 * (*negative_advice)(struct dst_entry___62 *);
	void (*link_failure)(struct sk_buff___83 *);
	void (*update_pmtu)(struct dst_entry___62 *, struct sock___63 *, struct sk_buff___83 *, u32);
	void (*redirect)(struct dst_entry___62 *, struct sock___63 *, struct sk_buff___83 *);
	int (*local_out)(struct net___93 *, struct sock___63 *, struct sk_buff___83 *);
	struct neighbour___62 * (*neigh_lookup)(const struct dst_entry___62 *, struct sk_buff___83 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___62 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___93 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___82 frags;
	struct xt_table___2 *ip6table_filter;
	struct xt_table___2 *ip6table_mangle;
	struct xt_table___2 *ip6table_raw;
	struct xt_table___2 *ip6table_security;
	struct xt_table___2 *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___93 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___62 *fib6_rules_ops;
	struct sock___63 **icmp_sk;
	struct sock___63 *ndisc_sk;
	struct sock___63 *tcp_sk;
	struct sock___63 *igmp_sk;
	struct sock___63 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___62 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___63 *notifier_ops;
	struct fib_notifier_ops___63 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___63 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___63 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct nf_hook_entries___7;

struct netns_nf___8 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_queue_handler *queue_handler;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header *nf_log_dir_header;
	struct nf_hook_entries___7 *hooks_ipv4[5];
	struct nf_hook_entries___7 *hooks_ipv6[5];
	struct nf_hook_entries___7 *hooks_arp[3];
	struct nf_hook_entries___7 *hooks_bridge[5];
	bool defrag_ipv4;
	bool defrag_ipv6;
};

struct netns_nf_frag___82 {
	struct netns_frags___82 frags;
};

struct netns_xfrm___93 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___63 *nlsk;
	struct sock___63 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___93 xfrm4_dst_ops;
	struct dst_ops___93 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___72;

struct net___93 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___302 *user_ns;
	struct ucounts___302 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___29 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___63 *rtnl;
	struct sock___63 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___82 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___82 ipv4;
	struct netns_ipv6___93 ipv6;
	struct netns_sctp___63 sctp;
	struct netns_nf___8 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___82 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___63 *nfnl;
	struct sock___63 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___93 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___63 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___72 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef int (*key_restrict_link_func_t___406)(struct key___405 *, const struct key_type *, const union key_payload *, struct key___405 *);

struct key_restriction___405;

struct key___405 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___439 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___405 *restrict_link;
};

struct key_restriction___405 {
	key_restrict_link_func_t___406 check;
	struct key___405 *key;
	struct key_type *keytype;
};

struct seq_operations___376 {
	void * (*start)(struct seq_file___376 *, loff_t *);
	void (*stop)(struct seq_file___376 *, void *);
	void * (*next)(struct seq_file___376 *, void *, loff_t *);
	int (*show)(struct seq_file___376 *, void *);
};

struct dev_pm_info___405 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___405 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___405;

struct bus_type___405;

struct device_driver___405;

struct dev_pm_domain___405;

struct dma_map_ops___177;

struct fwnode_handle___325;

struct class___405;

struct device___405 {
	struct device___405 *parent;
	struct device_private *p;
	struct kobject___425 kobj;
	const char *init_name;
	const struct device_type___405 *type;
	struct mutex mutex;
	struct bus_type___405 *bus;
	struct device_driver___405 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___405 power;
	struct dev_pm_domain___405 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___177 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___325 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___405 *class;
	const struct attribute_group___402 **groups;
	void (*release)(struct device___405 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

typedef void compound_page_dtor___425(struct page___438 *);

struct cgroup_namespace___286 {
	refcount_t count;
	struct ns_common___29 ns;
	struct user_namespace___302 *user_ns;
	struct ucounts___302 *ucounts;
	struct css_set___286 *root_cset;
};

struct ucounts___302 {
	struct hlist_node node;
	struct user_namespace___302 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct inet_frag_queue___82;

struct inet_frags___82 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___82 *, const void *);
	void (*destructor)(struct inet_frag_queue___82 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___82 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___83 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___83 *fragments_tail;
	struct sk_buff___83 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___82 *net;
	struct callback_head rcu;
};

struct fib_rule___62;

struct fib_lookup_arg___62;

struct fib_rules_ops___62 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___62 *, struct flowi *, int, struct fib_lookup_arg___62 *);
	bool (*suppress)(struct fib_rule___62 *, struct fib_lookup_arg___62 *);
	int (*match)(struct fib_rule___62 *, struct flowi *, int);
	int (*configure)(struct fib_rule___62 *, struct sk_buff___83 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___62 *);
	int (*compare)(struct fib_rule___62 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___62 *, struct sk_buff___83 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___62 *);
	void (*flush_cache)(struct fib_rules_ops___62 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___364 *owner;
	struct net___93 *fro_net;
	struct callback_head rcu;
};

struct xt_table_info;

struct xt_table___2 {
	struct list_head list;
	unsigned int valid_hooks;
	struct xt_table_info *private;
	struct module___364 *me;
	u_int8_t af;
	int priority;
	int (*table_init)(struct net___93 *);
	const char name[32];
};

struct fib_notifier_ops___63 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___93 *);
	int (*fib_dump)(struct net___93 *, struct notifier_block *);
	struct module___364 *owner;
	struct callback_head rcu;
};

struct dst_entry___62 {
	struct net_device___82 *dev;
	struct dst_ops___93 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___83 *);
	int (*output)(struct net___93 *, struct sock___63 *, struct sk_buff___83 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

typedef rx_handler_result_t rx_handler_func_t___82(struct sk_buff___83 **);

struct net_device_ops___82;

struct ethtool_ops___82;

struct l3mdev_ops___62;

struct xfrmdev_ops___82;

struct tlsdev_ops___82;

struct header_ops___82;

struct netdev_rx_queue___82;

struct mini_Qdisc___74;

struct netdev_queue___82;

struct Qdisc___74;

struct rtnl_link_ops___74;

struct dcbnl_rtnl_ops___82;

struct net_device___82 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___82 *netdev_ops;
	const struct ethtool_ops___82 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___62 *l3mdev_ops;
	const struct ndisc_ops___2 *ndisc_ops;
	const struct xfrmdev_ops___82 *xfrmdev_ops;
	const struct tlsdev_ops___82 *tlsdev_ops;
	const struct header_ops___82 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___424 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___2 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___82 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___72 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___82 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___74 *miniq_ingress;
	struct netdev_queue___82 *ingress_queue;
	struct nf_hook_entries___7 *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___82 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___74 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___74 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___82 = 0,
		NETREG_REGISTERED___82 = 1,
		NETREG_UNREGISTERING___82 = 2,
		NETREG_UNREGISTERED___82 = 3,
		NETREG_RELEASED___82 = 4,
		NETREG_DUMMY___82 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___82 = 0,
		RTNL_LINK_INITIALIZING___82 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___82 *);
	struct netpoll_info *npinfo;
	possible_net_t___84 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___405 dev;
	const struct attribute_group___402 *sysfs_groups[4];
	const struct attribute_group___402 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___74 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___82 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide35;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct neigh_table___62;

struct neigh_parms___62;

struct neigh_ops___62;

struct neighbour___62 {
	struct neighbour___62 *next;
	struct neigh_table___62 *tbl;
	struct neigh_parms___62 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___82 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___62 *, struct sk_buff___83 *);
	const struct neigh_ops___62 *ops;
	struct callback_head rcu;
	struct net_device___82 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct nf_hook_state___7;

typedef unsigned int nf_hookfn___7(void *, struct sk_buff___83 *, const struct nf_hook_state___7 *);

struct nf_hook_entry___7 {
	nf_hookfn___7 *hook;
	void *priv;
};

struct nf_hook_entries___7 {
	u16 num_hook_entries;
	struct nf_hook_entry___7 hooks[0];
};

struct dev_pm_ops___405 {
	int (*prepare)(struct device___405 *);
	void (*complete)(struct device___405 *);
	int (*suspend)(struct device___405 *);
	int (*resume)(struct device___405 *);
	int (*freeze)(struct device___405 *);
	int (*thaw)(struct device___405 *);
	int (*poweroff)(struct device___405 *);
	int (*restore)(struct device___405 *);
	int (*suspend_late)(struct device___405 *);
	int (*resume_early)(struct device___405 *);
	int (*freeze_late)(struct device___405 *);
	int (*thaw_early)(struct device___405 *);
	int (*poweroff_late)(struct device___405 *);
	int (*restore_early)(struct device___405 *);
	int (*suspend_noirq)(struct device___405 *);
	int (*resume_noirq)(struct device___405 *);
	int (*freeze_noirq)(struct device___405 *);
	int (*thaw_noirq)(struct device___405 *);
	int (*poweroff_noirq)(struct device___405 *);
	int (*restore_noirq)(struct device___405 *);
	int (*runtime_suspend)(struct device___405 *);
	int (*runtime_resume)(struct device___405 *);
	int (*runtime_idle)(struct device___405 *);
};

struct dev_pm_domain___405 {
	struct dev_pm_ops___405 ops;
	void (*detach)(struct device___405 *, bool);
	int (*activate)(struct device___405 *);
	void (*sync)(struct device___405 *);
	void (*dismiss)(struct device___405 *);
};

struct bus_type___405 {
	const char *name;
	const char *dev_name;
	struct device___405 *dev_root;
	const struct attribute_group___402 **bus_groups;
	const struct attribute_group___402 **dev_groups;
	const struct attribute_group___402 **drv_groups;
	int (*match)(struct device___405 *, struct device_driver___405 *);
	int (*uevent)(struct device___405 *, struct kobj_uevent_env *);
	int (*probe)(struct device___405 *);
	int (*remove)(struct device___405 *);
	void (*shutdown)(struct device___405 *);
	int (*online)(struct device___405 *);
	int (*offline)(struct device___405 *);
	int (*suspend)(struct device___405 *, pm_message_t);
	int (*resume)(struct device___405 *);
	int (*num_vf)(struct device___405 *);
	int (*dma_configure)(struct device___405 *);
	const struct dev_pm_ops___405 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___405 {
	const char *name;
	struct bus_type___405 *bus;
	struct module___364 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___405 *);
	int (*remove)(struct device___405 *);
	void (*shutdown)(struct device___405 *);
	int (*suspend)(struct device___405 *, pm_message_t);
	int (*resume)(struct device___405 *);
	const struct attribute_group___402 **groups;
	const struct dev_pm_ops___405 *pm;
	void (*coredump)(struct device___405 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___405 {
	const char *name;
	const struct attribute_group___402 **groups;
	int (*uevent)(struct device___405 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___405 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___405 *);
	const struct dev_pm_ops___405 *pm;
};

struct class___405 {
	const char *name;
	struct module___364 *owner;
	const struct attribute_group___402 **class_groups;
	const struct attribute_group___402 **dev_groups;
	struct kobject___425 *dev_kobj;
	int (*dev_uevent)(struct device___405 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___405 *, umode_t *);
	void (*class_release)(struct class___405 *);
	void (*dev_release)(struct device___405 *);
	int (*shutdown_pre)(struct device___405 *);
	const struct kobj_ns_type_operations___62 *ns_type;
	const void * (*namespace)(struct device___405 *);
	const struct dev_pm_ops___405 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___177 {
	void * (*alloc)(struct device___405 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___405 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___405 *, struct vm_area_struct___438 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___405 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___405 *, struct page___438 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___405 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___405 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___405 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___405 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___405 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___405 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___405 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___405 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___405 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___405 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___405 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___405 *, u64);
	u64 (*get_required_mask)(struct device___405 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___325;

struct fwnode_handle___325 {
	struct fwnode_handle___325 *secondary;
	const struct fwnode_operations___325 *ops;
};

struct fwnode_reference_args___325;

struct fwnode_endpoint___325;

struct fwnode_operations___325 {
	struct fwnode_handle___325 * (*get)(struct fwnode_handle___325 *);
	void (*put)(struct fwnode_handle___325 *);
	bool (*device_is_available)(const struct fwnode_handle___325 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___325 *, const struct device___405 *);
	bool (*property_present)(const struct fwnode_handle___325 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___325 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___325 *, const char *, const char **, size_t);
	struct fwnode_handle___325 * (*get_parent)(const struct fwnode_handle___325 *);
	struct fwnode_handle___325 * (*get_next_child_node)(const struct fwnode_handle___325 *, struct fwnode_handle___325 *);
	struct fwnode_handle___325 * (*get_named_child_node)(const struct fwnode_handle___325 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___325 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___325 *);
	struct fwnode_handle___325 * (*graph_get_next_endpoint)(const struct fwnode_handle___325 *, struct fwnode_handle___325 *);
	struct fwnode_handle___325 * (*graph_get_remote_endpoint)(const struct fwnode_handle___325 *);
	struct fwnode_handle___325 * (*graph_get_port_parent)(struct fwnode_handle___325 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___325 *, struct fwnode_endpoint___325 *);
};

struct fwnode_endpoint___325 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___325 *local_fwnode;
};

struct fwnode_reference_args___325 {
	struct fwnode_handle___325 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___118;

struct pipe_buffer___118 {
	struct page___438 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___118 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___118 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___118 *, struct pipe_buffer___118 *);
	void (*release)(struct pipe_inode_info___118 *, struct pipe_buffer___118 *);
	int (*steal)(struct pipe_inode_info___118 *, struct pipe_buffer___118 *);
	union {
		bool (*get)(struct pipe_inode_info___118 *, struct pipe_buffer___118 *);
		struct {
			void (*get)(struct pipe_inode_info___118 *, struct pipe_buffer___118 *);
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
};

struct nf_bridge_info___82 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___82 = 0,
		BRNF_PROTO_8021Q___82 = 1,
		BRNF_PROTO_PPPOE___82 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___82 *physindev;
	struct net_device___82 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

struct bpf_prog_aux___75;

struct bpf_prog___72 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___75 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

struct seq_net_private___6 {
	struct net___93 *net;
};

struct pernet_operations___83 {
	struct list_head list;
	int (*init)(struct net___93 *);
	void (*exit)(struct net___93 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct ethtool_ops___82 {
	int (*get_settings)(struct net_device___82 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___82 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___82 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___82 *);
	void (*get_regs)(struct net_device___82 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___82 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___82 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___82 *);
	void (*set_msglevel)(struct net_device___82 *, u32);
	int (*nway_reset)(struct net_device___82 *);
	u32 (*get_link)(struct net_device___82 *);
	int (*get_eeprom_len)(struct net_device___82 *);
	int (*get_eeprom)(struct net_device___82 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___82 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___82 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___82 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___82 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___82 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___82 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___82 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___82 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___82 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___82 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___82 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___82 *);
	void (*complete)(struct net_device___82 *);
	u32 (*get_priv_flags)(struct net_device___82 *);
	int (*set_priv_flags)(struct net_device___82 *, u32);
	int (*get_sset_count)(struct net_device___82 *, int);
	int (*get_rxnfc)(struct net_device___82 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___82 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___82 *, struct ethtool_flash *);
	int (*reset)(struct net_device___82 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___82 *);
	u32 (*get_rxfh_indir_size)(struct net_device___82 *);
	int (*get_rxfh)(struct net_device___82 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___82 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___82 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___82 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___82 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___82 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___82 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___82 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___82 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___82 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___82 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___82 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___82 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___82 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___82 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___82 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___82 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___82 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___82 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___82 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___82 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___82 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	int (*get_fecparam)(struct net_device___82 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___82 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___82 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___82 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___82 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct dcbnl_rtnl_ops___82 {
	int (*ieee_getets)(struct net_device___82 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___82 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___82 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___82 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___82 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___82 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___82 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___82 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___82 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___82 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___82 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___82 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___82 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___82 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___82 *);
	u8 (*setstate)(struct net_device___82 *, u8);
	void (*getpermhwaddr)(struct net_device___82 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___82 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___82 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___82 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___82 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___82 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___82 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___82 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___82 *, int, u8 *);
	void (*setpfccfg)(struct net_device___82 *, int, u8);
	void (*getpfccfg)(struct net_device___82 *, int, u8 *);
	u8 (*setall)(struct net_device___82 *);
	u8 (*getcap)(struct net_device___82 *, int, u8 *);
	int (*getnumtcs)(struct net_device___82 *, int, u8 *);
	int (*setnumtcs)(struct net_device___82 *, int, u8);
	u8 (*getpfcstate)(struct net_device___82 *);
	void (*setpfcstate)(struct net_device___82 *, u8);
	void (*getbcncfg)(struct net_device___82 *, int, u32 *);
	void (*setbcncfg)(struct net_device___82 *, int, u32);
	void (*getbcnrp)(struct net_device___82 *, int, u8 *);
	void (*setbcnrp)(struct net_device___82 *, int, u8);
	int (*setapp)(struct net_device___82 *, u8, u16, u8);
	int (*getapp)(struct net_device___82 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___82 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___82 *, int, u8);
	u8 (*getdcbx)(struct net_device___82 *);
	u8 (*setdcbx)(struct net_device___82 *, u8);
	int (*peer_getappinfo)(struct net_device___82 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___82 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___82 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___82 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___82 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___82 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct bpf_map___287;

struct bpf_map_ops___286 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___287 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___287 *, struct file___437 *);
	void (*map_free)(struct bpf_map___287 *);
	int (*map_get_next_key)(struct bpf_map___287 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___287 *);
	void * (*map_lookup_elem)(struct bpf_map___287 *, void *);
	int (*map_update_elem)(struct bpf_map___287 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___287 *, void *);
	int (*map_push_elem)(struct bpf_map___287 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___287 *, void *);
	int (*map_peek_elem)(struct bpf_map___287 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___287 *, struct file___437 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___287 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___287 *, void *, struct seq_file___376 *);
	int (*map_check_btf)(const struct bpf_map___287 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___287 {
	const struct bpf_map_ops___286 *ops;
	struct bpf_map___287 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___405 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___82;

struct bpf_map_dev_ops___82 {
	int (*map_get_next_key)(struct bpf_offloaded_map___82 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___82 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___82 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___82 *, void *);
};

struct bpf_offloaded_map___82 {
	struct bpf_map___287 map;
	struct net_device___82 *netdev;
	const struct bpf_map_dev_ops___82 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___72 {
	int (*test_run)(struct bpf_prog___72 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___72 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___72 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___72 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___72 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___72 *, u32 *);
};

struct bpf_prog_offload_ops___72 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___72 *);
	int (*translate)(struct bpf_prog___72 *);
	void (*destroy)(struct bpf_prog___72 *);
};

struct bpf_prog_offload___72 {
	struct bpf_prog___72 *prog;
	struct net_device___82 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___72 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___75 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___72 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___72 *ops;
	struct bpf_map___287 **used_maps;
	struct bpf_prog___72 *prog;
	struct user_struct___405 *user;
	u64 load_time;
	struct bpf_map___287 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___72 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___72 {
	struct bpf_prog___72 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___72 {
	struct callback_head rcu;
	struct bpf_prog_array_item___72 items[0];
};

struct cgroup_bpf___72 {
	struct bpf_prog_array___72 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___72 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___287;

typedef void (*kthread_work_func_t___287)(struct kthread_work___287 *);

struct kthread_worker___287;

struct kthread_work___287 {
	struct list_head node;
	kthread_work_func_t___287 func;
	struct kthread_worker___287 *worker;
	int canceling;
};

struct kthread_worker___287 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___439 *task;
	struct kthread_work___287 *current_work;
};

struct kthread_delayed_work___286 {
	struct kthread_work___287 work;
	struct timer_list timer;
};

struct psi_group___286 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___287 *poll_kworker;
	struct kthread_delayed_work___286 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___286;

struct cgroup_rstat_cpu___286;

struct cgroup___286 {
	struct cgroup_subsys_state___286 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___432 *kn;
	struct cgroup_file___286 procs_file;
	struct cgroup_file___286 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___286 *subsys[13];
	struct cgroup_root___286 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___286 *dom_cgrp;
	struct cgroup_rstat_cpu___286 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___72 bpf;
	atomic_t congestion_count;
	struct cgroup___286 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___286 psi;
	int ancestor_ids[0];
};

struct cftype___286;

struct cgroup_subsys___286 {
	struct cgroup_subsys_state___286 * (*css_alloc)(struct cgroup_subsys_state___286 *);
	int (*css_online)(struct cgroup_subsys_state___286 *);
	void (*css_offline)(struct cgroup_subsys_state___286 *);
	void (*css_released)(struct cgroup_subsys_state___286 *);
	void (*css_free)(struct cgroup_subsys_state___286 *);
	void (*css_reset)(struct cgroup_subsys_state___286 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___286 *, int);
	int (*css_extra_stat_show)(struct seq_file___376 *, struct cgroup_subsys_state___286 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___439 *);
	void (*cancel_fork)(struct task_struct___439 *);
	void (*fork)(struct task_struct___439 *);
	void (*exit)(struct task_struct___439 *);
	void (*free)(struct task_struct___439 *);
	void (*bind)(struct cgroup_subsys_state___286 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___286 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___286 *dfl_cftypes;
	struct cftype___286 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___286 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___286 *updated_children;
	struct cgroup___286 *updated_next;
};

struct cgroup_root___286 {
	struct kernfs_root___431 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___286 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___286 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___286 *ss;
	struct list_head node;
	struct kernfs_ops___431 *kf_ops;
	int (*open)(struct kernfs_open_file___431 *);
	void (*release)(struct kernfs_open_file___431 *);
	u64 (*read_u64)(struct cgroup_subsys_state___286 *, struct cftype___286 *);
	s64 (*read_s64)(struct cgroup_subsys_state___286 *, struct cftype___286 *);
	int (*seq_show)(struct seq_file___376 *, void *);
	void * (*seq_start)(struct seq_file___376 *, loff_t *);
	void * (*seq_next)(struct seq_file___376 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___376 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___286 *, struct cftype___286 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___286 *, struct cftype___286 *, s64);
	ssize_t (*write)(struct kernfs_open_file___431 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___431 *, struct poll_table_struct___276 *);
};

struct xdp_rxq_info___82 {
	struct net_device___82 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___82 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___82 *dev_rx;
};

struct netlink_callback___84 {
	struct sk_buff___83 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___84 *);
	int (*dump)(struct sk_buff___83 *, struct netlink_callback___84 *);
	int (*done)(struct netlink_callback___84 *);
	void *data;
	struct module___364 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___82 {
	int (*create)(struct sk_buff___83 *, struct net_device___82 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___83 *, unsigned char *);
	int (*cache)(const struct neighbour___62 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___82 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___82 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___82 *, int);
	int poll_owner;
	struct net_device___82 *dev;
	struct sk_buff___83 *gro_list;
	struct sk_buff___83 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___82 {
	struct net_device___82 *dev;
	struct Qdisc___74 *qdisc;
	struct Qdisc___74 *qdisc_sleeping;
	struct kobject___425 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___82 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem___3 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___74 {
	struct sk_buff___83 *head;
	struct sk_buff___83 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___74;

struct Qdisc___74 {
	int (*enqueue)(struct sk_buff___83 *, struct Qdisc___74 *, struct sk_buff___83 **);
	struct sk_buff___83 * (*dequeue)(struct Qdisc___74 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___74 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___82 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___82 gso_skb;
	struct qdisc_skb_head___74 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___74 *next_sched;
	struct sk_buff_head___82 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___82 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___425 kobj;
	struct net_device___82 *dev;
	long: 64;
	struct xdp_rxq_info___82 xdp_rxq;
	union {
		struct xdp_umem___3 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___82)(struct net_device___82 *, struct sk_buff___83 *, struct net_device___82 *);

struct netdev_bpf___82 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___72 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___72 *prog;
			const struct bpf_prog_offload_ops___72 *ops;
		} verifier;
		struct {
			struct bpf_prog___72 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___82 *offmap;
		};
		struct {
			struct xdp_umem___3 *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___82 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___83 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___82 {
	int (*tls_dev_add)(struct net_device___82 *, struct sock___63 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___82 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___82 *, struct sock___63 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___82 {
	int (*ndo_init)(struct net_device___82 *);
	void (*ndo_uninit)(struct net_device___82 *);
	int (*ndo_open)(struct net_device___82 *);
	int (*ndo_stop)(struct net_device___82 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___83 *, struct net_device___82 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___83 *, struct net_device___82 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___82 *, struct sk_buff___83 *, struct net_device___82 *, select_queue_fallback_t___82);
	void (*ndo_change_rx_flags)(struct net_device___82 *, int);
	void (*ndo_set_rx_mode)(struct net_device___82 *);
	int (*ndo_set_mac_address)(struct net_device___82 *, void *);
	int (*ndo_validate_addr)(struct net_device___82 *);
	int (*ndo_do_ioctl)(struct net_device___82 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___82 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___82 *, int);
	int (*ndo_neigh_setup)(struct net_device___82 *, struct neigh_parms___62 *);
	void (*ndo_tx_timeout)(struct net_device___82 *);
	void (*ndo_get_stats64)(struct net_device___82 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___82 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___82 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___82 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___82 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___82 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___82 *);
	int (*ndo_netpoll_setup)(struct net_device___82 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___82 *);
	int (*ndo_set_vf_mac)(struct net_device___82 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___82 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___82 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___82 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___82 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___82 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___82 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___82 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___82 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___82 *, int, struct sk_buff___83 *);
	int (*ndo_set_vf_guid)(struct net_device___82 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___82 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___82 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___82 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___82 *, const struct sk_buff___83 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___82 *, struct net_device___82 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___82 *, struct net_device___82 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___82 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___82 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___82 *, struct neighbour___62 *);
	void (*ndo_neigh_destroy)(struct net_device___82 *, struct neighbour___62 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___82 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___82 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___82 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___83 *, struct netlink_callback___84 *, struct net_device___82 *, struct net_device___82 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___82 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___82 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___83 *, u32, u32, struct net_device___82 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___82 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___82 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___82 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___82 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___82 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___82 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___82 *, struct net_device___82 *);
	void (*ndo_dfwd_del_station)(struct net_device___82 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___82 *);
	int (*ndo_set_tx_maxrate)(struct net_device___82 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___82 *);
	int (*ndo_change_proto_down)(struct net_device___82 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___82 *, struct sk_buff___83 *);
	void (*ndo_set_rx_headroom)(struct net_device___82 *, int);
	int (*ndo_bpf)(struct net_device___82 *, struct netdev_bpf___82 *);
	int (*ndo_xdp_xmit)(struct net_device___82 *, int, struct xdp_frame___82 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___82 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___82 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___62 {
	possible_net_t___84 net;
	struct net_device___82 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___62 *);
	void (*neigh_cleanup)(struct neighbour___62 *);
	struct neigh_table___62 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___62 {
	u32 (*l3mdev_fib_table)(const struct net_device___82 *);
	struct sk_buff___83 * (*l3mdev_l3_rcv)(struct net_device___82 *, struct sk_buff___83 *, u16);
	struct sk_buff___83 * (*l3mdev_l3_out)(struct net_device___82 *, struct sock___63 *, struct sk_buff___83 *, u16);
	struct dst_entry___62 * (*l3mdev_link_scope_lookup)(const struct net_device___82 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct tcf_proto___74;

struct mini_Qdisc___74 {
	struct tcf_proto___74 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___74 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___82 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___93 *, struct net_device___82 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___82 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___82 *, struct list_head *);
	size_t (*get_size)(const struct net_device___82 *);
	int (*fill_info)(struct sk_buff___83 *, const struct net_device___82 *);
	size_t (*get_xstats_size)(const struct net_device___82 *);
	int (*fill_xstats)(struct sk_buff___83 *, const struct net_device___82 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___82 *, struct net_device___82 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___82 *, const struct net_device___82 *);
	int (*fill_slave_info)(struct sk_buff___83 *, const struct net_device___82 *, const struct net_device___82 *);
	struct net___93 * (*get_link_net)(const struct net_device___82 *);
	size_t (*get_linkxstats_size)(const struct net_device___82 *, int);
	int (*fill_linkxstats)(struct sk_buff___83 *, const struct net_device___82 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___82 {
	struct list_head poll_list;
	struct sk_buff_head___82 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___82 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___74 *output_queue;
	struct Qdisc___74 **output_queue_tailp;
	struct sk_buff___83 *completion_queue;
	struct sk_buff_head___82 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___82 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___82 input_pkt_queue;
	struct napi_struct___82 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct nf_hook_state___7 {
	unsigned int hook;
	u_int8_t pf;
	struct net_device___82 *in;
	struct net_device___82 *out;
	struct sock___63 *sk;
	struct net___93 *net;
	int (*okfn)(struct net___93 *, struct sock___63 *, struct sk_buff___83 *);
};

struct nf_hook_ops___3 {
	nf_hookfn___7 *hook;
	struct net_device___82 *dev;
	void *priv;
	u_int8_t pf;
	unsigned int hooknum;
	int priority;
};

struct nf_nat_hook___7 {
	int (*parse_nat_setup)(struct nf_conn *, enum nf_nat_manip_type, const struct nlattr *);
	void (*decode_session)(struct sk_buff___83 *, struct flowi *);
	unsigned int (*manip_pkt)(struct sk_buff___83 *, struct nf_conn *, enum nf_nat_manip_type, enum ip_conntrack_dir);
};

struct nf_ct_hook___7 {
	int (*update)(struct net___93 *, struct sk_buff___83 *);
	void (*destroy)(struct nf_conntrack *);
	bool (*get_tuple_skb)(struct nf_conntrack_tuple *, const struct sk_buff___83 *);
};

struct nfnl_ct_hook___7 {
	struct nf_conn * (*get_ct)(const struct sk_buff___83 *, enum ip_conntrack_info *);
	size_t (*build_size)(const struct nf_conn *);
	int (*build)(struct sk_buff___83 *, struct nf_conn *, enum ip_conntrack_info, u_int16_t, u_int16_t);
	int (*parse)(const struct nlattr *, struct nf_conn *);
	int (*attach_expect)(const struct nlattr *, struct nf_conn *, u32, u32);
	void (*seq_adjust)(struct sk_buff___83 *, struct nf_conn *, enum ip_conntrack_info, s32);
};

struct xt_action_param;

struct xt_mtchk_param;

struct xt_mtdtor_param;

struct xt_match {
	struct list_head list;
	const char name[29];
	u_int8_t revision;
	bool (*match)(const struct sk_buff___83 *, struct xt_action_param *);
	int (*checkentry)(const struct xt_mtchk_param *);
	void (*destroy)(const struct xt_mtdtor_param *);
	struct module___364 *me;
	const char *table;
	unsigned int matchsize;
	unsigned int usersize;
	unsigned int hooks;
	short unsigned int proto;
	short unsigned int family;
};

struct xt_entry_match {
	union {
		struct {
			__u16 match_size;
			char name[29];
			__u8 revision;
		} user;
		struct {
			__u16 match_size;
			struct xt_match *match;
		} kernel;
		__u16 match_size;
	} u;
	unsigned char data[0];
};

struct xt_tgchk_param;

struct xt_tgdtor_param;

struct xt_target {
	struct list_head list;
	const char name[29];
	u_int8_t revision;
	unsigned int (*target)(struct sk_buff___83 *, const struct xt_action_param *);
	int (*checkentry)(const struct xt_tgchk_param *);
	void (*destroy)(const struct xt_tgdtor_param *);
	struct module___364 *me;
	const char *table;
	unsigned int targetsize;
	unsigned int usersize;
	unsigned int hooks;
	short unsigned int proto;
	short unsigned int family;
};

struct xt_entry_target {
	union {
		struct {
			__u16 target_size;
			char name[29];
			__u8 revision;
		} user;
		struct {
			__u16 target_size;
			struct xt_target *target;
		} kernel;
		__u16 target_size;
	} u;
	unsigned char data[0];
};

struct xt_standard_target {
	struct xt_entry_target target;
	int verdict;
};

struct xt_error_target {
	struct xt_entry_target target;
	char errorname[30];
};

struct xt_counters {
	__u64 pcnt;
	__u64 bcnt;
};

struct xt_counters_info {
	char name[32];
	unsigned int num_counters;
	struct xt_counters counters[0];
};

struct xt_action_param {
	union {
		const struct xt_match *match;
		const struct xt_target *target;
	};
	union {
		const void *matchinfo;
		const void *targinfo;
	};
	const struct nf_hook_state___7 *state;
	int fragoff;
	unsigned int thoff;
	bool hotdrop;
};

struct xt_mtchk_param {
	struct net___93 *net;
	const char *table;
	const void *entryinfo;
	const struct xt_match *match;
	void *matchinfo;
	unsigned int hook_mask;
	u_int8_t family;
	bool nft_compat;
};

struct xt_mtdtor_param {
	struct net___93 *net;
	const struct xt_match *match;
	void *matchinfo;
	u_int8_t family;
};

struct xt_tgchk_param {
	struct net___93 *net;
	const char *table;
	const void *entryinfo;
	const struct xt_target *target;
	void *targinfo;
	unsigned int hook_mask;
	u_int8_t family;
	bool nft_compat;
};

struct xt_tgdtor_param {
	struct net___93 *net;
	const struct xt_target *target;
	void *targinfo;
	u_int8_t family;
};

struct xt_table_info {
	unsigned int size;
	unsigned int number;
	unsigned int initial_entries;
	unsigned int hook_entry[5];
	unsigned int underflow[5];
	unsigned int stacksize;
	void ***jumpstack;
	unsigned char entries[0];
};

struct xt_percpu_counter_alloc_state {
	unsigned int off;
	const char *mem;
};

struct bdi_writeback_congested___227 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___227 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___227 {
	struct bio___227 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___229 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___229 bip_inline_vecs[0];
};

struct bio_set___227 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___227 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___170 {
	struct mem_cgroup___170 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___170 {
	struct lruvec___438 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___170 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___170 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct gnet_dump___74 {
	spinlock_t *lock;
	struct sk_buff___83 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___74;

struct Qdisc_ops___74 {
	struct Qdisc_ops___74 *next;
	const struct Qdisc_class_ops___74 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___83 *, struct Qdisc___74 *, struct sk_buff___83 **);
	struct sk_buff___83 * (*dequeue)(struct Qdisc___74 *);
	struct sk_buff___83 * (*peek)(struct Qdisc___74 *);
	int (*init)(struct Qdisc___74 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___74 *);
	void (*destroy)(struct Qdisc___74 *);
	int (*change)(struct Qdisc___74 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___74 *);
	int (*change_tx_queue_len)(struct Qdisc___74 *, unsigned int);
	int (*dump)(struct Qdisc___74 *, struct sk_buff___83 *);
	int (*dump_stats)(struct Qdisc___74 *, struct gnet_dump___74 *);
	void (*ingress_block_set)(struct Qdisc___74 *, u32);
	void (*egress_block_set)(struct Qdisc___74 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___74 *);
	u32 (*egress_block_get)(struct Qdisc___74 *);
	struct module___364 *owner;
};

struct tcf_block___74;

struct Qdisc_class_ops___74 {
	unsigned int flags;
	struct netdev_queue___82 * (*select_queue)(struct Qdisc___74 *, struct tcmsg *);
	int (*graft)(struct Qdisc___74 *, long unsigned int, struct Qdisc___74 *, struct Qdisc___74 **, struct netlink_ext_ack *);
	struct Qdisc___74 * (*leaf)(struct Qdisc___74 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___74 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___74 *, u32);
	int (*change)(struct Qdisc___74 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___74 *, long unsigned int);
	void (*walk)(struct Qdisc___74 *, struct qdisc_walker *);
	struct tcf_block___74 * (*tcf_block)(struct Qdisc___74 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___74 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___74 *, long unsigned int);
	int (*dump)(struct Qdisc___74 *, long unsigned int, struct sk_buff___83 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___74 *, long unsigned int, struct gnet_dump___74 *);
};

struct tcf_chain___74;

struct tcf_block___74 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___93 *net;
	struct Qdisc___74 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___74 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___74;

struct tcf_proto_ops___74;

struct tcf_proto___74 {
	struct tcf_proto___74 *next;
	void *root;
	int (*classify)(struct sk_buff___83 *, const struct tcf_proto___74 *, struct tcf_result___74 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___74 *ops;
	struct tcf_chain___74 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___74 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___74 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___74 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___83 *, const struct tcf_proto___74 *, struct tcf_result___74 *);
	int (*init)(struct tcf_proto___74 *);
	void (*destroy)(struct tcf_proto___74 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___74 *, u32);
	void (*put)(struct tcf_proto___74 *, void *);
	int (*change)(struct net___93 *, struct sk_buff___83 *, struct tcf_proto___74 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___74 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___74 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___74 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___93 *, struct tcf_chain___74 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___93 *, struct tcf_proto___74 *, void *, struct sk_buff___83 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___83 *, struct net___93 *, void *);
	struct module___364 *owner;
	int flags;
};

struct tcf_chain___74 {
	struct mutex filter_chain_lock;
	struct tcf_proto___74 *filter_chain;
	struct list_head list;
	struct tcf_block___74 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___74 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___62 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___72 *prog;
};

struct bpf_redirect_info___72 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___287 *map;
	struct bpf_map___287 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___62;

struct neigh_hash_table___62;

struct neigh_table___62 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___82 *, __u32 *);
	bool (*key_eq)(const struct neighbour___62 *, const void *);
	int (*constructor)(struct neighbour___62 *);
	int (*pconstructor)(struct pneigh_entry___62 *);
	void (*pdestructor)(struct pneigh_entry___62 *);
	void (*proxy_redo)(struct sk_buff___83 *);
	char *id;
	struct neigh_parms___62 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___82 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___62 *nht;
	struct pneigh_entry___62 **phash_buckets;
};

struct neigh_ops___62 {
	int family;
	void (*solicit)(struct neighbour___62 *, struct sk_buff___83 *);
	void (*error_report)(struct neighbour___62 *, struct sk_buff___83 *);
	int (*output)(struct neighbour___62 *, struct sk_buff___83 *);
	int (*connected_output)(struct neighbour___62 *, struct sk_buff___83 *);
};

struct pneigh_entry___62 {
	struct pneigh_entry___62 *next;
	possible_net_t___84 net;
	struct net_device___82 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___62 {
	struct neighbour___62 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___62 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___62 *ctarget;
	struct net___93 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___62 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___62 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___45;

struct timewait_sock_ops___41;

struct proto___62 {
	void (*close)(struct sock___63 *, long int);
	int (*pre_connect)(struct sock___63 *, struct sockaddr *, int);
	int (*connect)(struct sock___63 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___63 *, int);
	struct sock___63 * (*accept)(struct sock___63 *, int, int *, bool);
	int (*ioctl)(struct sock___63 *, int, long unsigned int);
	int (*init)(struct sock___63 *);
	void (*destroy)(struct sock___63 *);
	void (*shutdown)(struct sock___63 *, int);
	int (*setsockopt)(struct sock___63 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___63 *, int, int, char *, int *);
	void (*keepalive)(struct sock___63 *, int);
	int (*sendmsg)(struct sock___63 *, struct msghdr___65 *, size_t);
	int (*recvmsg)(struct sock___63 *, struct msghdr___65 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___63 *, struct page___438 *, int, size_t, int);
	int (*bind)(struct sock___63 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___63 *, struct sk_buff___83 *);
	void (*release_cb)(struct sock___63 *);
	int (*hash)(struct sock___63 *);
	void (*unhash)(struct sock___63 *);
	void (*rehash)(struct sock___63 *);
	int (*get_port)(struct sock___63 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___63 *);
	bool (*stream_memory_read)(const struct sock___63 *);
	void (*enter_memory_pressure)(struct sock___63 *);
	void (*leave_memory_pressure)(struct sock___63 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___45 *rsk_prot;
	struct timewait_sock_ops___41 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___364 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___63 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct request_sock___46;

struct request_sock_ops___45 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___63 *, struct request_sock___46 *);
	void (*send_ack)(const struct sock___63 *, struct sk_buff___83 *, struct request_sock___46 *);
	void (*send_reset)(const struct sock___63 *, struct sk_buff___83 *);
	void (*destructor)(struct request_sock___46 *);
	void (*syn_ack_timeout)(const struct request_sock___46 *);
};

struct timewait_sock_ops___41 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___63 *, struct sock___63 *, void *);
	void (*twsk_destructor)(struct sock___63 *);
};

struct request_sock___46 {
	struct sock_common___62 __req_common;
	struct request_sock___46 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___45 *rsk_ops;
	struct sock___63 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct nf_ipv6_ops___5 {
	int (*chk_addr)(struct net___93 *, const struct in6_addr *, const struct net_device___82 *, int);
	void (*route_input)(struct sk_buff___83 *);
	int (*fragment)(struct net___93 *, struct sock___63 *, struct sk_buff___83 *, int (*)(struct net___93 *, struct sock___63 *, struct sk_buff___83 *));
	__sum16 (*checksum)(struct sk_buff___83 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___83 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___93 *, struct dst_entry___62 **, struct flowi *, bool);
	int (*reroute)(struct sk_buff___83 *, const struct nf_queue_entry___2 *);
};

struct xt_af {
	struct mutex mutex;
	struct list_head match;
	struct list_head target;
};

struct nf_mttg_trav {
	struct list_head *head;
	struct list_head *curr;
	uint8_t class;
};

enum {
	MTTG_TRAV_INIT = 0,
	MTTG_TRAV_NFP_UNSPEC = 1,
	MTTG_TRAV_NFP_SPEC = 2,
	MTTG_TRAV_DONE = 3,
};

struct module___365;

struct file___438;

struct kiocb___438;

struct iov_iter___205;

struct poll_table_struct___277;

struct vm_area_struct___439;

struct inode___438;

struct file_lock___438;

struct page___439;

struct pipe_inode_info___119;

struct seq_file___377;

struct file_operations___438 {
	struct module___365 *owner;
	loff_t (*llseek)(struct file___438 *, loff_t, int);
	ssize_t (*read)(struct file___438 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___438 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___438 *, struct iov_iter___205 *);
	ssize_t (*write_iter)(struct kiocb___438 *, struct iov_iter___205 *);
	int (*iopoll)(struct kiocb___438 *, bool);
	int (*iterate)(struct file___438 *, struct dir_context *);
	int (*iterate_shared)(struct file___438 *, struct dir_context *);
	__poll_t (*poll)(struct file___438 *, struct poll_table_struct___277 *);
	long int (*unlocked_ioctl)(struct file___438 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___438 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___438 *, struct vm_area_struct___439 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___438 *, struct file___438 *);
	int (*flush)(struct file___438 *, fl_owner_t);
	int (*release)(struct inode___438 *, struct file___438 *);
	int (*fsync)(struct file___438 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___438 *, int);
	int (*lock)(struct file___438 *, int, struct file_lock___438 *);
	ssize_t (*sendpage)(struct file___438 *, struct page___439 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___438 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___438 *, int, struct file_lock___438 *);
	ssize_t (*splice_write)(struct pipe_inode_info___119 *, struct file___438 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___438 *, loff_t *, struct pipe_inode_info___119 *, size_t, unsigned int);
	int (*setlease)(struct file___438 *, long int, struct file_lock___438 **, void **);
	long int (*fallocate)(struct file___438 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___377 *, struct file___438 *);
	ssize_t (*copy_file_range)(struct file___438 *, loff_t, struct file___438 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___438 *, loff_t, struct file___438 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___438 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___439 {
	u64 seqnum;
	struct vm_area_struct___439 *vmas[4];
};

struct page_frag___439 {
	struct page___439 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___439;

struct mem_cgroup___171;

struct cred___406;

struct nsproxy___333;

struct signal_struct___313;

struct bio_list___228;

struct backing_dev_info___228;

struct css_set___287;

struct vm_struct___342;

struct task_struct___440 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___440 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___439 *mm;
	struct mm_struct___439 *active_mm;
	struct vmacache___439 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___440 *real_parent;
	struct task_struct___440 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___440 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___171 *active_memcg;
	long int rh_reserved2;
	struct pid___242 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___242 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___242 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___406 *ptracer_cred;
	const struct cred___406 *real_cred;
	const struct cred___406 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___333 *nsproxy;
	struct signal_struct___313 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___440 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___228 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___228 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___287 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___119 *splice_pipe;
	struct page_frag___439 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___171 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___440 *oom_reaper_list;
	struct vm_struct___342 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___156 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rw_semaphore___440 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___440 *owner;
};

struct key___406;

struct ucounts___303;

struct user_namespace___303 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___303 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___29 ns;
	long unsigned int flags;
	struct key___406 *persistent_keyring_register;
	struct rw_semaphore___440 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___303 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___439 *pgtable_t___439;

struct address_space___438;

struct dev_pagemap___426;

struct page___439 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___438 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___439 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___439 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___439 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___426 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___171 *mem_cgroup;
};

struct pglist_data___439;

struct lruvec___439 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___439 *pgdat;
};

struct zone___439 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___439 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___439 {
	struct zone___439 *zone;
	int zone_idx;
};

struct zonelist___439 {
	struct zoneref___439 _zonerefs[25];
};

struct pglist_data___439 {
	struct zone___439 node_zones[3];
	struct zonelist___439 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___440 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___440 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___439 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___440 {
	void *stack;
	struct task_struct___440 *task;
	long int status;
};

struct blocking_notifier_head___439 {
	struct rw_semaphore___440 rwsem;
	struct notifier_block *head;
};

struct dentry___438;

struct path___439 {
	struct vfsmount *mnt;
	struct dentry___438 *dentry;
};

struct file___438 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___439 f_path;
	struct inode___438 *f_inode;
	const struct file_operations___438 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___242 f_owner;
	const struct cred___406 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___438 *f_mapping;
	errseq_t f_wb_err;
};

struct user_struct___406;

struct cred___406 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___406 *session_keyring;
	struct key___406 *process_keyring;
	struct key___406 *thread_keyring;
	struct key___406 *request_key_auth;
	void *security;
	struct user_struct___406 *user;
	struct user_namespace___303 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___432;

struct kernfs_elem_dir___432 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___432 *root;
};

struct kernfs_node___433;

struct kernfs_syscall_ops___432;

struct kernfs_root___432 {
	struct kernfs_node___433 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___432 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___432 {
	struct kernfs_node___433 *target_kn;
};

struct kernfs_ops___432;

struct kernfs_elem_attr___432 {
	const struct kernfs_ops___432 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___433 *notify_next;
};

struct kernfs_node___433 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___433 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___432 dir;
		struct kernfs_elem_symlink___432 symlink;
		struct kernfs_elem_attr___432 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___432;

struct kernfs_ops___432 {
	int (*open)(struct kernfs_open_file___432 *);
	void (*release)(struct kernfs_open_file___432 *);
	int (*seq_show)(struct seq_file___377 *, void *);
	void * (*seq_start)(struct seq_file___377 *, loff_t *);
	void * (*seq_next)(struct seq_file___377 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___377 *, void *);
	ssize_t (*read)(struct kernfs_open_file___432 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___432 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___432 *, struct vm_area_struct___439 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___432 *, struct poll_table_struct___277 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___432 {
	int (*remount_fs)(struct kernfs_root___432 *, int *, char *);
	int (*show_options)(struct seq_file___377 *, struct kernfs_root___432 *);
	int (*mkdir)(struct kernfs_node___433 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___433 *);
	int (*rename)(struct kernfs_node___433 *, struct kernfs_node___433 *, const char *);
	int (*show_path)(struct seq_file___377 *, struct kernfs_node___433 *, struct kernfs_root___432 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___377;

struct seq_file___377 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___377 *op;
	int poll_event;
	const struct file___438 *file;
	void *private;
};

struct vm_operations_struct___426;

struct kernfs_open_file___432 {
	struct kernfs_node___433 *kn;
	struct file___438 *file;
	struct seq_file___377 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___426 *vm_ops;
};

struct vm_fault___426;

struct vm_operations_struct___426 {
	void (*open)(struct vm_area_struct___439 *);
	void (*close)(struct vm_area_struct___439 *);
	int (*split)(struct vm_area_struct___439 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___439 *);
	vm_fault_t (*fault)(struct vm_fault___426 *);
	vm_fault_t (*huge_fault)(struct vm_fault___426 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___426 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___439 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___426 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___426 *);
	int (*access)(struct vm_area_struct___439 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___439 *);
	int (*set_policy)(struct vm_area_struct___439 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___439 *, long unsigned int);
	struct page___439 * (*find_special_page)(struct vm_area_struct___439 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___287)(struct file___438 *, wait_queue_head_t *, struct poll_table_struct___277 *);

struct poll_table_struct___277 {
	poll_queue_proc___287 _qproc;
	__poll_t _key;
};

struct vm_area_struct___439 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___439 *vm_next;
	struct vm_area_struct___439 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___439 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___426 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___438 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sock___64;

struct kobj_ns_type_operations___63 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___64 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct net___94;

typedef struct {
	struct net___94 *net;
} possible_net_t___85;

struct proto___63;

struct sock_common___63 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___63 *skc_prot;
	possible_net_t___85 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___64 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___84;

struct sk_buff_head___83 {
	struct sk_buff___84 *next;
	struct sk_buff___84 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___63;

struct socket_wq___64;

struct dst_entry___63;

struct socket___65;

struct net_device___83;

struct sock___64 {
	struct sock_common___63 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___83 sk_error_queue;
	struct sk_buff_head___83 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___84 *head;
		struct sk_buff___84 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___63 *sk_filter;
	union {
		struct socket_wq___64 *sk_wq;
		struct socket_wq___64 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___63 *sk_rx_dst;
	struct dst_entry___63 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___84 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___83 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___439 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___63 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___242 *sk_peer_pid;
	const struct cred___406 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___65 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___171 *sk_memcg;
	void (*sk_state_change)(struct sock___64 *);
	void (*sk_data_ready)(struct sock___64 *);
	void (*sk_write_space)(struct sock___64 *);
	void (*sk_error_report)(struct sock___64 *);
	int (*sk_backlog_rcv)(struct sock___64 *, struct sk_buff___84 *);
	struct sk_buff___84 * (*sk_validate_xmit_skb)(struct sock___64 *, struct net_device___83 *, struct sk_buff___84 *);
	void (*sk_destruct)(struct sock___64 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kobject___426;

struct bin_attribute___402;

struct attribute_group___403 {
	const char *name;
	umode_t (*is_visible)(struct kobject___426 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___426 *, struct bin_attribute___402 *, int);
	struct attribute **attrs;
	struct bin_attribute___402 **bin_attrs;
};

struct kset___425;

struct kobj_type___425;

struct kobject___426 {
	const char *name;
	struct list_head entry;
	struct kobject___426 *parent;
	struct kset___425 *kset;
	struct kobj_type___425 *ktype;
	struct kernfs_node___433 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___402 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___438 *, struct kobject___426 *, struct bin_attribute___402 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___438 *, struct kobject___426 *, struct bin_attribute___402 *, char *, loff_t, size_t);
	int (*mmap)(struct file___438 *, struct kobject___426 *, struct bin_attribute___402 *, struct vm_area_struct___439 *);
};

struct sysfs_ops___425 {
	ssize_t (*show)(struct kobject___426 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___426 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___425;

struct kset___425 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___426 kobj;
	const struct kset_uevent_ops___425 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___425 {
	void (*release)(struct kobject___426 *);
	const struct sysfs_ops___425 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___63 * (*child_ns_type)(struct kobject___426 *);
	const void * (*namespace)(struct kobject___426 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___425 {
	int (* const filter)(struct kset___425 *, struct kobject___426 *);
	const char * (* const name)(struct kset___425 *, struct kobject___426 *);
	int (* const uevent)(struct kset___425 *, struct kobject___426 *, struct kobj_uevent_env *);
};

struct kobj_attribute___416 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___426 *, struct kobj_attribute___416 *, char *);
	ssize_t (*store)(struct kobject___426 *, struct kobj_attribute___416 *, const char *, size_t);
};

struct kernel_param___364;

struct kernel_param_ops___364 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___364 *);
	int (*get)(char *, const struct kernel_param___364 *);
	void (*free)(void *);
};

struct kparam_array___364;

struct kernel_param___364 {
	const char *name;
	struct module___365 *mod;
	const struct kernel_param_ops___364 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___364 *arr;
	};
};

struct kparam_array___364 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___364 *ops;
	void *elem;
};

struct module_kobject___364 {
	struct kobject___426 kobj;
	struct module___365 *mod;
	struct kobject___426 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___364 {
	struct module___365 *mod;
	struct latch_tree_node node;
};

struct module_layout___364 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___364 mtn;
};

struct module_attribute___364;

struct module___365 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___364 mkobj;
	struct module_attribute___364 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___426 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___364 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___364 core_layout;
	struct module_layout___364 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___364 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___364 *, struct module_kobject___364 *, char *);
	ssize_t (*store)(struct module_attribute___364 *, struct module_kobject___364 *, const char *, size_t);
	void (*setup)(struct module___365 *, const char *);
	int (*test)(struct module___365 *);
	void (*free)(struct module___365 *);
};

struct cgroup___287;

struct cgroup_subsys___287;

struct cgroup_subsys_state___287 {
	struct cgroup___287 *cgroup;
	struct cgroup_subsys___287 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___287 *parent;
};

struct cgroup_file___287 {
	struct kernfs_node___433 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___171;

struct mem_cgroup___171 {
	struct cgroup_subsys_state___287 css;
	struct mem_cgroup_id___13 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___287 events_file;
	struct cgroup_file___287 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___440 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___171 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct user_struct___406 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___406 *uid_keyring;
	struct key___406 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___439;

struct mm_struct___439 {
	struct {
		struct vm_area_struct___439 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___438 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___440 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___439 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___440 *owner;
		struct user_namespace___303 *user_ns;
		struct file___438 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___439 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___287;

struct nsproxy___333 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net___94 *net_ns;
	struct cgroup_namespace___287 *cgroup_ns;
};

struct signal_struct___313 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___440 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___440 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___242 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___242 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___439 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___242 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___228;

struct bio_list___228 {
	struct bio___228 *head;
	struct bio___228 *tail;
};

struct bdi_writeback_congested___228;

struct bdi_writeback___228 {
	struct backing_dev_info___228 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___228 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___287 *memcg_css;
	struct cgroup_subsys_state___287 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___406;

struct backing_dev_info___228 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___228 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___406 *dev;
	struct device___406 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___438 *debug_dir;
	struct dentry___438 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___287 {
	struct cgroup_subsys_state___287 *subsys[13];
	refcount_t refcount;
	struct css_set___287 *dom_cset;
	struct cgroup___287 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___287 *mg_src_cgrp;
	struct cgroup___287 *mg_dst_cgrp;
	struct css_set___287 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___438;

struct pipe_buffer___119;

struct pipe_inode_info___119 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___439 *tmp_page;
	struct fasync_struct___438 *fasync_readers;
	struct fasync_struct___438 *fasync_writers;
	struct pipe_buffer___119 *bufs;
	struct user_struct___406 *user;
};

struct vm_struct___342 {
	struct vm_struct___342 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___439 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___325 {
	struct task_struct___440 task;
	long unsigned int stack[8192];
};

struct address_space_operations___438;

struct address_space___438 {
	struct inode___438 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___440 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___438 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___426)(struct vm_area_struct___439 *, long unsigned int, const struct page___439 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___426)(struct page___439 *, void *);

struct dev_pagemap___426 {
	dev_page_fault_t___426 page_fault;
	dev_page_free_t___426 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___406 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___439 {
	struct task_struct___440 *task;
	struct core_thread___439 *next;
};

struct core_state___439 {
	atomic_t nr_threads;
	struct core_thread___439 dumper;
	struct completion startup;
};

struct vm_fault___426 {
	struct vm_area_struct___439 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___439 *cow_page;
	struct mem_cgroup___171 *memcg;
	struct page___439 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___439 prealloc_pte;
};

struct crypto_async_request___29;

typedef void (*crypto_completion_t___29)(struct crypto_async_request___29 *, int);

struct crypto_tfm___29;

struct crypto_async_request___29 {
	struct list_head list;
	crypto_completion_t___29 complete;
	void *data;
	struct crypto_tfm___29 *tfm;
	u32 flags;
};

struct crypto_ablkcipher___29;

struct ablkcipher_request___29;

struct ablkcipher_tfm___29 {
	int (*setkey)(struct crypto_ablkcipher___29 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___29 *);
	int (*decrypt)(struct ablkcipher_request___29 *);
	struct crypto_ablkcipher___29 *base;
	unsigned int ivsize;
	unsigned int reqsize;
};

struct blkcipher_desc___29;

struct blkcipher_tfm___29 {
	void *iv;
	int (*setkey)(struct crypto_tfm___29 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___29 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___29 *, struct scatterlist *, struct scatterlist *, unsigned int);
};

struct cipher_tfm___29 {
	int (*cit_setkey)(struct crypto_tfm___29 *, const u8 *, unsigned int);
	void (*cit_encrypt_one)(struct crypto_tfm___29 *, u8 *, const u8 *);
	void (*cit_decrypt_one)(struct crypto_tfm___29 *, u8 *, const u8 *);
};

struct compress_tfm___29 {
	int (*cot_compress)(struct crypto_tfm___29 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*cot_decompress)(struct crypto_tfm___29 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___29;

struct crypto_tfm___29 {
	u32 crt_flags;
	union {
		struct ablkcipher_tfm___29 ablkcipher;
		struct blkcipher_tfm___29 blkcipher;
		struct cipher_tfm___29 cipher;
		struct compress_tfm___29 compress;
	} crt_u;
	void (*exit)(struct crypto_tfm___29 *);
	struct crypto_alg___29 *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct ablkcipher_request___29 {
	struct crypto_async_request___29 base;
	unsigned int nbytes;
	void *info;
	struct scatterlist *src;
	struct scatterlist *dst;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_blkcipher___29;

struct blkcipher_desc___29 {
	struct crypto_blkcipher___29 *tfm;
	void *info;
	u32 flags;
};

struct crypto_blkcipher___29 {
	struct crypto_tfm___29 base;
};

struct ablkcipher_alg___29 {
	int (*setkey)(struct crypto_ablkcipher___29 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___29 *);
	int (*decrypt)(struct ablkcipher_request___29 *);
	int (*givencrypt)(struct skcipher_givcrypt_request *);
	int (*givdecrypt)(struct skcipher_givcrypt_request *);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct crypto_ablkcipher___29 {
	struct crypto_tfm___29 base;
};

struct blkcipher_alg___29 {
	int (*setkey)(struct crypto_tfm___29 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___29 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___29 *, struct scatterlist *, struct scatterlist *, unsigned int);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct cipher_alg___29 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___29 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___29 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___29 *, u8 *, const u8 *);
};

struct compress_alg___29 {
	int (*coa_compress)(struct crypto_tfm___29 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___29 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___29 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type *cra_type;
	union {
		struct ablkcipher_alg___29 ablkcipher;
		struct blkcipher_alg___29 blkcipher;
		struct cipher_alg___29 cipher;
		struct compress_alg___29 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___29 *);
	void (*cra_exit)(struct crypto_tfm___29 *);
	void (*cra_destroy)(struct crypto_alg___29 *);
	struct module___365 *cra_module;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct crypto_cipher___13 {
	struct crypto_tfm___29 base;
};

struct bio_vec___230 {
	struct page___439 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___205 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___230 *bvec;
		struct pipe_inode_info___119 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct msghdr___66 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___205 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___438 *msg_iocb;
};

struct kiocb___438 {
	struct file___438 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___438 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dentry_operations___438;

struct super_block___438;

struct dentry___438 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___438 *d_parent;
	struct qstr d_name;
	struct inode___438 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___438 *d_op;
	struct super_block___438 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___438;

struct block_device___438;

struct inode___438 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___438 *i_op;
	struct super_block___438 *i_sb;
	struct address_space___438 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___440 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___228 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___438 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___438 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___119 *i_pipe;
		struct block_device___438 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___438 {
	int (*d_revalidate)(struct dentry___438 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___438 *, unsigned int);
	int (*d_hash)(const struct dentry___438 *, struct qstr *);
	int (*d_compare)(const struct dentry___438 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___438 *);
	int (*d_init)(struct dentry___438 *);
	void (*d_release)(struct dentry___438 *);
	void (*d_prune)(struct dentry___438 *);
	void (*d_iput)(struct dentry___438 *, struct inode___438 *);
	char * (*d_dname)(struct dentry___438 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___439 *);
	int (*d_manage)(const struct path___439 *, bool);
	struct dentry___438 * (*d_real)(struct dentry___438 *, const struct inode___438 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___438;

struct mem_dqinfo___438 {
	struct quota_format_type___438 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___438;

struct quota_info___438 {
	unsigned int flags;
	struct rw_semaphore___440 dqio_sem;
	struct inode___438 *files[3];
	struct mem_dqinfo___438 info[3];
	const struct quota_format_ops___438 *ops[3];
};

struct rcuwait___438 {
	struct task_struct___440 *task;
};

struct percpu_rw_semaphore___438 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___440 rw_sem;
	struct rcuwait___438 writer;
	int readers_block;
};

struct sb_writers___438 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___438 rw_sem[3];
};

struct shrink_control___171;

struct shrinker___171 {
	long unsigned int (*count_objects)(struct shrinker___171 *, struct shrink_control___171 *);
	long unsigned int (*scan_objects)(struct shrinker___171 *, struct shrink_control___171 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___438;

struct super_operations___438;

struct dquot_operations___438;

struct quotactl_ops___438;

struct super_block___438 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___438 *s_type;
	const struct super_operations___438 *s_op;
	const struct dquot_operations___438 *dq_op;
	const struct quotactl_ops___438 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___438 *s_root;
	struct rw_semaphore___440 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___438 *s_bdev;
	struct backing_dev_info___228 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___438 s_dquot;
	struct sb_writers___438 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___438 *s_d_op;
	int cleancache_poolid;
	struct shrinker___171 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___303 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___171 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___171 *memcg;
};

struct iattr___438 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___438 *ia_file;
};

struct dquot___438 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___438 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___438 {
	int qf_fmt_id;
	const struct quota_format_ops___438 *qf_ops;
	struct module___365 *qf_owner;
	struct quota_format_type___438 *qf_next;
};

struct quota_format_ops___438 {
	int (*check_quota_file)(struct super_block___438 *, int);
	int (*read_file_info)(struct super_block___438 *, int);
	int (*write_file_info)(struct super_block___438 *, int);
	int (*free_file_info)(struct super_block___438 *, int);
	int (*read_dqblk)(struct dquot___438 *);
	int (*commit_dqblk)(struct dquot___438 *);
	int (*release_dqblk)(struct dquot___438 *);
	int (*get_next_id)(struct super_block___438 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___438 {
	int (*write_dquot)(struct dquot___438 *);
	struct dquot___438 * (*alloc_dquot)(struct super_block___438 *, int);
	void (*destroy_dquot)(struct dquot___438 *);
	int (*acquire_dquot)(struct dquot___438 *);
	int (*release_dquot)(struct dquot___438 *);
	int (*mark_dirty)(struct dquot___438 *);
	int (*write_info)(struct super_block___438 *, int);
	qsize_t * (*get_reserved_space)(struct inode___438 *);
	int (*get_projid)(struct inode___438 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___438 *, qsize_t *);
	int (*get_next_id)(struct super_block___438 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___438 {
	int (*quota_on)(struct super_block___438 *, int, int, const struct path___439 *);
	int (*quota_off)(struct super_block___438 *, int);
	int (*quota_enable)(struct super_block___438 *, unsigned int);
	int (*quota_disable)(struct super_block___438 *, unsigned int);
	int (*quota_sync)(struct super_block___438 *, int);
	int (*set_info)(struct super_block___438 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___438 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___438 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___438 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___438 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___438 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___191;

struct address_space_operations___438 {
	int (*writepage)(struct page___439 *, struct writeback_control___191 *);
	int (*readpage)(struct file___438 *, struct page___439 *);
	int (*writepages)(struct address_space___438 *, struct writeback_control___191 *);
	int (*set_page_dirty)(struct page___439 *);
	int (*readpages)(struct file___438 *, struct address_space___438 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___438 *, struct address_space___438 *, loff_t, unsigned int, unsigned int, struct page___439 **, void **);
	int (*write_end)(struct file___438 *, struct address_space___438 *, loff_t, unsigned int, unsigned int, struct page___439 *, void *);
	sector_t (*bmap)(struct address_space___438 *, sector_t);
	void (*invalidatepage)(struct page___439 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___439 *, gfp_t);
	void (*freepage)(struct page___439 *);
	ssize_t (*direct_IO)(struct kiocb___438 *, struct iov_iter___205 *);
	int (*migratepage)(struct address_space___438 *, struct page___439 *, struct page___439 *, enum migrate_mode);
	bool (*isolate_page)(struct page___439 *, isolate_mode_t);
	void (*putback_page)(struct page___439 *);
	int (*launder_page)(struct page___439 *);
	int (*is_partially_uptodate)(struct page___439 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___439 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___438 *, struct page___439 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___438 *, sector_t *);
	void (*swap_deactivate)(struct file___438 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___191 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___228 *wb;
	struct inode___438 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___438 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___438 *bd_inode;
	struct super_block___438 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___438 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___228 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___438 {
	struct dentry___438 * (*lookup)(struct inode___438 *, struct dentry___438 *, unsigned int);
	const char * (*get_link)(struct dentry___438 *, struct inode___438 *, struct delayed_call *);
	int (*permission)(struct inode___438 *, int);
	struct posix_acl * (*get_acl)(struct inode___438 *, int);
	int (*readlink)(struct dentry___438 *, char *, int);
	int (*create)(struct inode___438 *, struct dentry___438 *, umode_t, bool);
	int (*link)(struct dentry___438 *, struct inode___438 *, struct dentry___438 *);
	int (*unlink)(struct inode___438 *, struct dentry___438 *);
	int (*symlink)(struct inode___438 *, struct dentry___438 *, const char *);
	int (*mkdir)(struct inode___438 *, struct dentry___438 *, umode_t);
	int (*rmdir)(struct inode___438 *, struct dentry___438 *);
	int (*mknod)(struct inode___438 *, struct dentry___438 *, umode_t, dev_t);
	int (*rename)(struct inode___438 *, struct dentry___438 *, struct inode___438 *, struct dentry___438 *, unsigned int);
	int (*setattr)(struct dentry___438 *, struct iattr___438 *);
	int (*getattr)(const struct path___439 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___438 *, char *, size_t);
	int (*fiemap)(struct inode___438 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___438 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___438 *, struct dentry___438 *, struct file___438 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___438 *, struct dentry___438 *, umode_t);
	int (*set_acl)(struct inode___438 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___438 {
	void (*fl_copy_lock)(struct file_lock___438 *, struct file_lock___438 *);
	void (*fl_release_private)(struct file_lock___438 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___438;

struct file_lock___438 {
	struct file_lock___438 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___438 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___438 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___438 *fl_ops;
	const struct lock_manager_operations___438 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___438 {
	int (*lm_compare_owner)(struct file_lock___438 *, struct file_lock___438 *);
	long unsigned int (*lm_owner_key)(struct file_lock___438 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___438 *);
	int (*lm_grant)(struct file_lock___438 *, int);
	bool (*lm_break)(struct file_lock___438 *);
	int (*lm_change)(struct file_lock___438 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___438 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___438 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___438 *fa_next;
	struct file___438 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___438 {
	const char *name;
	int fs_flags;
	struct dentry___438 * (*mount)(struct file_system_type___438 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___438 *);
	struct module___365 *owner;
	struct file_system_type___438 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___438 {
	struct inode___438 * (*alloc_inode)(struct super_block___438 *);
	void (*destroy_inode)(struct inode___438 *);
	void (*dirty_inode)(struct inode___438 *, int);
	int (*write_inode)(struct inode___438 *, struct writeback_control___191 *);
	int (*drop_inode)(struct inode___438 *);
	void (*evict_inode)(struct inode___438 *);
	void (*put_super)(struct super_block___438 *);
	int (*sync_fs)(struct super_block___438 *, int);
	int (*freeze_super)(struct super_block___438 *);
	int (*freeze_fs)(struct super_block___438 *);
	int (*thaw_super)(struct super_block___438 *);
	int (*unfreeze_fs)(struct super_block___438 *);
	int (*statfs)(struct dentry___438 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___438 *, int *, char *);
	void (*umount_begin)(struct super_block___438 *);
	int (*show_options)(struct seq_file___377 *, struct dentry___438 *);
	int (*show_devname)(struct seq_file___377 *, struct dentry___438 *);
	int (*show_path)(struct seq_file___377 *, struct dentry___438 *);
	int (*show_stats)(struct seq_file___377 *, struct dentry___438 *);
	ssize_t (*quota_read)(struct super_block___438 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___438 *, int, const char *, size_t, loff_t);
	struct dquot___438 ** (*get_dquots)(struct inode___438 *);
	int (*bdev_try_to_free_page)(struct super_block___438 *, struct page___439 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___438 *, struct shrink_control___171 *);
	long int (*free_cached_objects)(struct super_block___438 *, struct shrink_control___171 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___228(struct bio___228 *);

struct bio_integrity_payload___228;

struct bio_set___228;

struct bio___228 {
	struct bio___228 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___228 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___228 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___230 *bi_io_vec;
	struct bio_set___228 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___230 bi_inline_vecs[0];
};

struct socket_wq___64 {
	wait_queue_head_t wait;
	struct fasync_struct___438 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___64;

struct socket___65 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___64 *wq;
	struct file___438 *file;
	struct sock___64 *sk;
	const struct proto_ops___64 *ops;
};

typedef int (*sk_read_actor_t___63)(read_descriptor_t *, struct sk_buff___84 *, unsigned int, size_t);

struct proto_ops___64 {
	int family;
	struct module___365 *owner;
	int (*release)(struct socket___65 *);
	int (*bind)(struct socket___65 *, struct sockaddr *, int);
	int (*connect)(struct socket___65 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___65 *, struct socket___65 *);
	int (*accept)(struct socket___65 *, struct socket___65 *, int, bool);
	int (*getname)(struct socket___65 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___438 *, struct socket___65 *, struct poll_table_struct___277 *);
	int (*ioctl)(struct socket___65 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___65 *, int);
	int (*shutdown)(struct socket___65 *, int);
	int (*setsockopt)(struct socket___65 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___65 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___65 *, struct msghdr___66 *, size_t);
	int (*recvmsg)(struct socket___65 *, struct msghdr___66 *, size_t, int);
	int (*mmap)(struct file___438 *, struct socket___65 *, struct vm_area_struct___439 *);
	ssize_t (*sendpage)(struct socket___65 *, struct page___439 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___65 *, loff_t *, struct pipe_inode_info___119 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___64 *, int);
	int (*peek_len)(struct socket___65 *);
	int (*read_sock)(struct sock___64 *, read_descriptor_t *, sk_read_actor_t___63);
	int (*sendpage_locked)(struct sock___64 *, struct page___439 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___64 *, struct msghdr___66 *, size_t);
	int (*set_rcvlowat)(struct sock___64 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct nf_bridge_info___83;

struct sk_buff___84 {
	union {
		struct {
			struct sk_buff___84 *next;
			struct sk_buff___84 *prev;
			union {
				struct net_device___83 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___64 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___84 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___83 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___83;

struct netns_frags___83 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___83 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ip_ra_chain___29;

struct fib_rules_ops___63;

struct xt_table___3;

struct tcp_congestion_ops___10;

struct tcp_fastopen_context___10;

struct fib_notifier_ops___64;

struct netns_ipv4___83 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___29 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___63 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___64 *fibnl;
	struct sock___64 **icmp_sk;
	struct sock___64 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___64 **tcp_sk;
	struct netns_frags___83 frags;
	struct xt_table___3 *iptable_filter;
	struct xt_table___3 *iptable_mangle;
	struct xt_table___3 *iptable_raw;
	struct xt_table___3 *arptable_filter;
	struct xt_table___3 *iptable_security;
	struct xt_table___3 *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops___10 *tcp_congestion_control;
	struct tcp_fastopen_context___10 *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___63 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___64 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___64 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___63;

struct dst_ops___94 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___94 *);
	struct dst_entry___63 * (*check)(struct dst_entry___63 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___63 *);
	unsigned int (*mtu)(const struct dst_entry___63 *);
	u32 * (*cow_metrics)(struct dst_entry___63 *, long unsigned int);
	void (*destroy)(struct dst_entry___63 *);
	void (*ifdown)(struct dst_entry___63 *, struct net_device___83 *, int);
	struct dst_entry___63 * (*negative_advice)(struct dst_entry___63 *);
	void (*link_failure)(struct sk_buff___84 *);
	void (*update_pmtu)(struct dst_entry___63 *, struct sock___64 *, struct sk_buff___84 *, u32);
	void (*redirect)(struct dst_entry___63 *, struct sock___64 *, struct sk_buff___84 *);
	int (*local_out)(struct net___94 *, struct sock___64 *, struct sk_buff___84 *);
	struct neighbour___63 * (*neigh_lookup)(const struct dst_entry___63 *, struct sk_buff___84 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___63 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___94 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___83 frags;
	struct xt_table___3 *ip6table_filter;
	struct xt_table___3 *ip6table_mangle;
	struct xt_table___3 *ip6table_raw;
	struct xt_table___3 *ip6table_security;
	struct xt_table___3 *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___94 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___63 *fib6_rules_ops;
	struct sock___64 **icmp_sk;
	struct sock___64 *ndisc_sk;
	struct sock___64 *tcp_sk;
	struct sock___64 *igmp_sk;
	struct sock___64 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___63 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___64 *notifier_ops;
	struct fib_notifier_ops___64 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___64 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___64 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct nf_hook_entries___8;

struct netns_nf___9 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_queue_handler *queue_handler;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header *nf_log_dir_header;
	struct nf_hook_entries___8 *hooks_ipv4[5];
	struct nf_hook_entries___8 *hooks_ipv6[5];
	struct nf_hook_entries___8 *hooks_arp[3];
	struct nf_hook_entries___8 *hooks_bridge[5];
	bool defrag_ipv4;
	bool defrag_ipv6;
};

struct netns_nf_frag___83 {
	struct netns_frags___83 frags;
};

struct netns_xfrm___94 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___64 *nlsk;
	struct sock___64 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___94 xfrm4_dst_ops;
	struct dst_ops___94 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___73;

struct net___94 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___303 *user_ns;
	struct ucounts___303 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___29 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___64 *rtnl;
	struct sock___64 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___83 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___83 ipv4;
	struct netns_ipv6___94 ipv6;
	struct netns_sctp___64 sctp;
	struct netns_nf___9 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___83 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___64 *nfnl;
	struct sock___64 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___94 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___64 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___73 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___406 {
	int (*prepare)(struct device___406 *);
	void (*complete)(struct device___406 *);
	int (*suspend)(struct device___406 *);
	int (*resume)(struct device___406 *);
	int (*freeze)(struct device___406 *);
	int (*thaw)(struct device___406 *);
	int (*poweroff)(struct device___406 *);
	int (*restore)(struct device___406 *);
	int (*suspend_late)(struct device___406 *);
	int (*resume_early)(struct device___406 *);
	int (*freeze_late)(struct device___406 *);
	int (*thaw_early)(struct device___406 *);
	int (*poweroff_late)(struct device___406 *);
	int (*restore_early)(struct device___406 *);
	int (*suspend_noirq)(struct device___406 *);
	int (*resume_noirq)(struct device___406 *);
	int (*freeze_noirq)(struct device___406 *);
	int (*thaw_noirq)(struct device___406 *);
	int (*poweroff_noirq)(struct device___406 *);
	int (*restore_noirq)(struct device___406 *);
	int (*runtime_suspend)(struct device___406 *);
	int (*runtime_resume)(struct device___406 *);
	int (*runtime_idle)(struct device___406 *);
};

struct dev_pm_info___406 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___406 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___406;

struct bus_type___406;

struct device_driver___406;

struct dev_pm_domain___406;

struct dma_map_ops___178;

struct fwnode_handle___326;

struct class___406;

struct device___406 {
	struct device___406 *parent;
	struct device_private *p;
	struct kobject___426 kobj;
	const char *init_name;
	const struct device_type___406 *type;
	struct mutex mutex;
	struct bus_type___406 *bus;
	struct device_driver___406 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___406 power;
	struct dev_pm_domain___406 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___178 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___326 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___406 *class;
	const struct attribute_group___403 **groups;
	void (*release)(struct device___406 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___406 {
	struct dev_pm_ops___406 ops;
	void (*detach)(struct device___406 *, bool);
	int (*activate)(struct device___406 *);
	void (*sync)(struct device___406 *);
	void (*dismiss)(struct device___406 *);
};

struct bus_type___406 {
	const char *name;
	const char *dev_name;
	struct device___406 *dev_root;
	const struct attribute_group___403 **bus_groups;
	const struct attribute_group___403 **dev_groups;
	const struct attribute_group___403 **drv_groups;
	int (*match)(struct device___406 *, struct device_driver___406 *);
	int (*uevent)(struct device___406 *, struct kobj_uevent_env *);
	int (*probe)(struct device___406 *);
	int (*remove)(struct device___406 *);
	void (*shutdown)(struct device___406 *);
	int (*online)(struct device___406 *);
	int (*offline)(struct device___406 *);
	int (*suspend)(struct device___406 *, pm_message_t);
	int (*resume)(struct device___406 *);
	int (*num_vf)(struct device___406 *);
	int (*dma_configure)(struct device___406 *);
	const struct dev_pm_ops___406 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___406 {
	const char *name;
	struct bus_type___406 *bus;
	struct module___365 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___406 *);
	int (*remove)(struct device___406 *);
	void (*shutdown)(struct device___406 *);
	int (*suspend)(struct device___406 *, pm_message_t);
	int (*resume)(struct device___406 *);
	const struct attribute_group___403 **groups;
	const struct dev_pm_ops___406 *pm;
	void (*coredump)(struct device___406 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___406 {
	const char *name;
	const struct attribute_group___403 **groups;
	int (*uevent)(struct device___406 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___406 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___406 *);
	const struct dev_pm_ops___406 *pm;
};

struct class___406 {
	const char *name;
	struct module___365 *owner;
	const struct attribute_group___403 **class_groups;
	const struct attribute_group___403 **dev_groups;
	struct kobject___426 *dev_kobj;
	int (*dev_uevent)(struct device___406 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___406 *, umode_t *);
	void (*class_release)(struct class___406 *);
	void (*dev_release)(struct device___406 *);
	int (*shutdown_pre)(struct device___406 *);
	const struct kobj_ns_type_operations___63 *ns_type;
	const void * (*namespace)(struct device___406 *);
	const struct dev_pm_ops___406 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___178 {
	void * (*alloc)(struct device___406 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___406 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___406 *, struct vm_area_struct___439 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___406 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___406 *, struct page___439 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___406 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___406 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___406 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___406 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___406 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___406 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___406 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___406 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___406 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___406 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___406 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___406 *, u64);
	u64 (*get_required_mask)(struct device___406 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___326;

struct fwnode_handle___326 {
	struct fwnode_handle___326 *secondary;
	const struct fwnode_operations___326 *ops;
};

typedef void compound_page_dtor___426(struct page___439 *);

struct fwnode_reference_args___326;

struct fwnode_endpoint___326;

struct fwnode_operations___326 {
	struct fwnode_handle___326 * (*get)(struct fwnode_handle___326 *);
	void (*put)(struct fwnode_handle___326 *);
	bool (*device_is_available)(const struct fwnode_handle___326 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___326 *, const struct device___406 *);
	bool (*property_present)(const struct fwnode_handle___326 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___326 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___326 *, const char *, const char **, size_t);
	struct fwnode_handle___326 * (*get_parent)(const struct fwnode_handle___326 *);
	struct fwnode_handle___326 * (*get_next_child_node)(const struct fwnode_handle___326 *, struct fwnode_handle___326 *);
	struct fwnode_handle___326 * (*get_named_child_node)(const struct fwnode_handle___326 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___326 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___326 *);
	struct fwnode_handle___326 * (*graph_get_next_endpoint)(const struct fwnode_handle___326 *, struct fwnode_handle___326 *);
	struct fwnode_handle___326 * (*graph_get_remote_endpoint)(const struct fwnode_handle___326 *);
	struct fwnode_handle___326 * (*graph_get_port_parent)(struct fwnode_handle___326 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___326 *, struct fwnode_endpoint___326 *);
};

struct fwnode_endpoint___326 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___326 *local_fwnode;
};

struct fwnode_reference_args___326 {
	struct fwnode_handle___326 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___119;

struct pipe_buffer___119 {
	struct page___439 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___119 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___119 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___119 *, struct pipe_buffer___119 *);
	void (*release)(struct pipe_inode_info___119 *, struct pipe_buffer___119 *);
	int (*steal)(struct pipe_inode_info___119 *, struct pipe_buffer___119 *);
	union {
		bool (*get)(struct pipe_inode_info___119 *, struct pipe_buffer___119 *);
		struct {
			void (*get)(struct pipe_inode_info___119 *, struct pipe_buffer___119 *);
		} __UNIQUE_ID_rh_kabi_hide21;
		union {		};
	};
};

struct nf_bridge_info___83 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___83 = 0,
		BRNF_PROTO_8021Q___83 = 1,
		BRNF_PROTO_PPPOE___83 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___83 *physindev;
	struct net_device___83 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___83(struct sk_buff___84 **);

struct net_device_ops___83;

struct ethtool_ops___83;

struct l3mdev_ops___63;

struct ndisc_ops___34;

struct xfrmdev_ops___83;

struct tlsdev_ops___83;

struct header_ops___83;

struct inet6_dev___34;

struct netdev_rx_queue___83;

struct mini_Qdisc___75;

struct netdev_queue___83;

struct Qdisc___75;

struct rtnl_link_ops___75;

struct dcbnl_rtnl_ops___83;

struct net_device___83 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___83 *netdev_ops;
	const struct ethtool_ops___83 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___63 *l3mdev_ops;
	const struct ndisc_ops___34 *ndisc_ops;
	const struct xfrmdev_ops___83 *xfrmdev_ops;
	const struct tlsdev_ops___83 *tlsdev_ops;
	const struct header_ops___83 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___425 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___34 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___83 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___73 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___83 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___75 *miniq_ingress;
	struct netdev_queue___83 *ingress_queue;
	struct nf_hook_entries___8 *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___83 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___75 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___75 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___83 = 0,
		NETREG_REGISTERED___83 = 1,
		NETREG_UNREGISTERING___83 = 2,
		NETREG_UNREGISTERED___83 = 3,
		NETREG_RELEASED___83 = 4,
		NETREG_DUMMY___83 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___83 = 0,
		RTNL_LINK_INITIALIZING___83 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___83 *);
	struct netpoll_info *npinfo;
	possible_net_t___85 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___406 dev;
	const struct attribute_group___403 *sysfs_groups[4];
	const struct attribute_group___403 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___75 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___83 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide35;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct ethtool_ops___83 {
	int (*get_settings)(struct net_device___83 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___83 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___83 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___83 *);
	void (*get_regs)(struct net_device___83 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___83 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___83 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___83 *);
	void (*set_msglevel)(struct net_device___83 *, u32);
	int (*nway_reset)(struct net_device___83 *);
	u32 (*get_link)(struct net_device___83 *);
	int (*get_eeprom_len)(struct net_device___83 *);
	int (*get_eeprom)(struct net_device___83 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___83 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___83 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___83 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___83 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___83 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___83 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___83 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___83 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___83 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___83 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___83 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___83 *);
	void (*complete)(struct net_device___83 *);
	u32 (*get_priv_flags)(struct net_device___83 *);
	int (*set_priv_flags)(struct net_device___83 *, u32);
	int (*get_sset_count)(struct net_device___83 *, int);
	int (*get_rxnfc)(struct net_device___83 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___83 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___83 *, struct ethtool_flash *);
	int (*reset)(struct net_device___83 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___83 *);
	u32 (*get_rxfh_indir_size)(struct net_device___83 *);
	int (*get_rxfh)(struct net_device___83 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___83 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___83 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___83 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___83 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___83 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___83 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___83 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___83 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___83 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___83 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___83 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___83 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___83 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___83 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___83 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___83 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___83 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___83 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___83 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___83 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___83 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	int (*get_fecparam)(struct net_device___83 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___83 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___83 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___83 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___83 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___83;

struct inet_frags___83 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___83 *, const void *);
	void (*destructor)(struct inet_frag_queue___83 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___83 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___84 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___84 *fragments_tail;
	struct sk_buff___84 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___83 *net;
	struct callback_head rcu;
};

struct ip_ra_chain___29 {
	struct ip_ra_chain___29 *next;
	struct sock___64 *sk;
	union {
		void (*destructor)(struct sock___64 *);
		struct sock___64 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___63;

struct fib_lookup_arg___63;

struct fib_rules_ops___63 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___63 *, struct flowi *, int, struct fib_lookup_arg___63 *);
	bool (*suppress)(struct fib_rule___63 *, struct fib_lookup_arg___63 *);
	int (*match)(struct fib_rule___63 *, struct flowi *, int);
	int (*configure)(struct fib_rule___63 *, struct sk_buff___84 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___63 *);
	int (*compare)(struct fib_rule___63 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___63 *, struct sk_buff___84 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___63 *);
	void (*flush_cache)(struct fib_rules_ops___63 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___365 *owner;
	struct net___94 *fro_net;
	struct callback_head rcu;
};

struct xt_table___3 {
	struct list_head list;
	unsigned int valid_hooks;
	struct xt_table_info *private;
	struct module___365 *me;
	u_int8_t af;
	int priority;
	int (*table_init)(struct net___94 *);
	const char name[32];
};

struct tcp_congestion_ops___10 {
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___64 *);
	void (*release)(struct sock___64 *);
	u32 (*ssthresh)(struct sock___64 *);
	void (*cong_avoid)(struct sock___64 *, u32, u32);
	void (*set_state)(struct sock___64 *, u8);
	void (*cwnd_event)(struct sock___64 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___64 *, u32);
	u32 (*undo_cwnd)(struct sock___64 *);
	void (*pkts_acked)(struct sock___64 *, const struct ack_sample *);
	u32 (*min_tso_segs)(struct sock___64 *);
	u32 (*sndbuf_expand)(struct sock___64 *);
	void (*cong_control)(struct sock___64 *, const struct rate_sample *);
	size_t (*get_info)(struct sock___64 *, u32, int *, union tcp_cc_info *);
	char name[16];
	struct module___365 *owner;
};

struct tcp_fastopen_context___10 {
	struct crypto_cipher___13 *tfm;
	__u8 key[16];
	struct callback_head rcu;
};

struct fib_notifier_ops___64 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___94 *);
	int (*fib_dump)(struct net___94 *, struct notifier_block *);
	struct module___365 *owner;
	struct callback_head rcu;
};

struct dst_entry___63 {
	struct net_device___83 *dev;
	struct dst_ops___94 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___84 *);
	int (*output)(struct net___94 *, struct sock___64 *, struct sk_buff___84 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___63;

struct neigh_parms___63;

struct neigh_ops___63;

struct neighbour___63 {
	struct neighbour___63 *next;
	struct neigh_table___63 *tbl;
	struct neigh_parms___63 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___83 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___63 *, struct sk_buff___84 *);
	const struct neigh_ops___63 *ops;
	struct callback_head rcu;
	struct net_device___83 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct nf_hook_state___8;

typedef unsigned int nf_hookfn___8(void *, struct sk_buff___84 *, const struct nf_hook_state___8 *);

struct nf_hook_entry___8 {
	nf_hookfn___8 *hook;
	void *priv;
};

struct nf_hook_entries___8 {
	u16 num_hook_entries;
	struct nf_hook_entry___8 hooks[0];
};

struct ucounts___303 {
	struct hlist_node node;
	struct user_namespace___303 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_prog_aux___76;

struct bpf_prog___73 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___76 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

typedef int (*key_restrict_link_func_t___407)(struct key___406 *, const struct key_type *, const union key_payload *, struct key___406 *);

struct key_restriction___406;

struct key___406 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___440 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___406 *restrict_link;
};

struct key_restriction___406 {
	key_restrict_link_func_t___407 check;
	struct key___406 *key;
	struct key_type *keytype;
};

struct seq_operations___377 {
	void * (*start)(struct seq_file___377 *, loff_t *);
	void (*stop)(struct seq_file___377 *, void *);
	void * (*next)(struct seq_file___377 *, void *, loff_t *);
	int (*show)(struct seq_file___377 *, void *);
};

struct pernet_operations___84 {
	struct list_head list;
	int (*init)(struct net___94 *);
	void (*exit)(struct net___94 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___83 {
	int (*ieee_getets)(struct net_device___83 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___83 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___83 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___83 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___83 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___83 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___83 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___83 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___83 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___83 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___83 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___83 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___83 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___83 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___83 *);
	u8 (*setstate)(struct net_device___83 *, u8);
	void (*getpermhwaddr)(struct net_device___83 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___83 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___83 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___83 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___83 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___83 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___83 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___83 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___83 *, int, u8 *);
	void (*setpfccfg)(struct net_device___83 *, int, u8);
	void (*getpfccfg)(struct net_device___83 *, int, u8 *);
	u8 (*setall)(struct net_device___83 *);
	u8 (*getcap)(struct net_device___83 *, int, u8 *);
	int (*getnumtcs)(struct net_device___83 *, int, u8 *);
	int (*setnumtcs)(struct net_device___83 *, int, u8);
	u8 (*getpfcstate)(struct net_device___83 *);
	void (*setpfcstate)(struct net_device___83 *, u8);
	void (*getbcncfg)(struct net_device___83 *, int, u32 *);
	void (*setbcncfg)(struct net_device___83 *, int, u32);
	void (*getbcnrp)(struct net_device___83 *, int, u8 *);
	void (*setbcnrp)(struct net_device___83 *, int, u8);
	int (*setapp)(struct net_device___83 *, u8, u16, u8);
	int (*getapp)(struct net_device___83 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___83 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___83 *, int, u8);
	u8 (*getdcbx)(struct net_device___83 *);
	u8 (*setdcbx)(struct net_device___83 *, u8);
	int (*peer_getappinfo)(struct net_device___83 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___83 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___83 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___83 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___83 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___83 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___287 {
	refcount_t count;
	struct ns_common___29 ns;
	struct user_namespace___303 *user_ns;
	struct ucounts___303 *ucounts;
	struct css_set___287 *root_cset;
};

struct bpf_map___288;

struct bpf_map_ops___287 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___288 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___288 *, struct file___438 *);
	void (*map_free)(struct bpf_map___288 *);
	int (*map_get_next_key)(struct bpf_map___288 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___288 *);
	void * (*map_lookup_elem)(struct bpf_map___288 *, void *);
	int (*map_update_elem)(struct bpf_map___288 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___288 *, void *);
	int (*map_push_elem)(struct bpf_map___288 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___288 *, void *);
	int (*map_peek_elem)(struct bpf_map___288 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___288 *, struct file___438 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___288 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___288 *, void *, struct seq_file___377 *);
	int (*map_check_btf)(const struct bpf_map___288 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___288 {
	const struct bpf_map_ops___287 *ops;
	struct bpf_map___288 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___406 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___83;

struct bpf_map_dev_ops___83 {
	int (*map_get_next_key)(struct bpf_offloaded_map___83 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___83 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___83 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___83 *, void *);
};

struct bpf_offloaded_map___83 {
	struct bpf_map___288 map;
	struct net_device___83 *netdev;
	const struct bpf_map_dev_ops___83 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___73 {
	int (*test_run)(struct bpf_prog___73 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___73 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___73 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___73 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___73 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___73 *, u32 *);
};

struct bpf_prog_offload_ops___73 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___73 *);
	int (*translate)(struct bpf_prog___73 *);
	void (*destroy)(struct bpf_prog___73 *);
};

struct bpf_prog_offload___73 {
	struct bpf_prog___73 *prog;
	struct net_device___83 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___73 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___76 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___73 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___73 *ops;
	struct bpf_map___288 **used_maps;
	struct bpf_prog___73 *prog;
	struct user_struct___406 *user;
	u64 load_time;
	struct bpf_map___288 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___73 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___73 {
	struct bpf_prog___73 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___73 {
	struct callback_head rcu;
	struct bpf_prog_array_item___73 items[0];
};

struct cgroup_bpf___73 {
	struct bpf_prog_array___73 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___73 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___288;

typedef void (*kthread_work_func_t___288)(struct kthread_work___288 *);

struct kthread_worker___288;

struct kthread_work___288 {
	struct list_head node;
	kthread_work_func_t___288 func;
	struct kthread_worker___288 *worker;
	int canceling;
};

struct kthread_worker___288 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___440 *task;
	struct kthread_work___288 *current_work;
};

struct kthread_delayed_work___287 {
	struct kthread_work___288 work;
	struct timer_list timer;
};

struct psi_group___287 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___288 *poll_kworker;
	struct kthread_delayed_work___287 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___287;

struct cgroup_rstat_cpu___287;

struct cgroup___287 {
	struct cgroup_subsys_state___287 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___433 *kn;
	struct cgroup_file___287 procs_file;
	struct cgroup_file___287 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___287 *subsys[13];
	struct cgroup_root___287 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___287 *dom_cgrp;
	struct cgroup_rstat_cpu___287 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___73 bpf;
	atomic_t congestion_count;
	struct cgroup___287 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___287 psi;
	int ancestor_ids[0];
};

struct cftype___287;

struct cgroup_subsys___287 {
	struct cgroup_subsys_state___287 * (*css_alloc)(struct cgroup_subsys_state___287 *);
	int (*css_online)(struct cgroup_subsys_state___287 *);
	void (*css_offline)(struct cgroup_subsys_state___287 *);
	void (*css_released)(struct cgroup_subsys_state___287 *);
	void (*css_free)(struct cgroup_subsys_state___287 *);
	void (*css_reset)(struct cgroup_subsys_state___287 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___287 *, int);
	int (*css_extra_stat_show)(struct seq_file___377 *, struct cgroup_subsys_state___287 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___440 *);
	void (*cancel_fork)(struct task_struct___440 *);
	void (*fork)(struct task_struct___440 *);
	void (*exit)(struct task_struct___440 *);
	void (*free)(struct task_struct___440 *);
	void (*bind)(struct cgroup_subsys_state___287 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___287 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___287 *dfl_cftypes;
	struct cftype___287 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___287 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___287 *updated_children;
	struct cgroup___287 *updated_next;
};

struct cgroup_root___287 {
	struct kernfs_root___432 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___287 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___287 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___287 *ss;
	struct list_head node;
	struct kernfs_ops___432 *kf_ops;
	int (*open)(struct kernfs_open_file___432 *);
	void (*release)(struct kernfs_open_file___432 *);
	u64 (*read_u64)(struct cgroup_subsys_state___287 *, struct cftype___287 *);
	s64 (*read_s64)(struct cgroup_subsys_state___287 *, struct cftype___287 *);
	int (*seq_show)(struct seq_file___377 *, void *);
	void * (*seq_start)(struct seq_file___377 *, loff_t *);
	void * (*seq_next)(struct seq_file___377 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___377 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___287 *, struct cftype___287 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___287 *, struct cftype___287 *, s64);
	ssize_t (*write)(struct kernfs_open_file___432 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___432 *, struct poll_table_struct___277 *);
};

struct xdp_rxq_info___83 {
	struct net_device___83 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___83 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___83 *dev_rx;
};

struct netlink_callback___85 {
	struct sk_buff___84 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___85 *);
	int (*dump)(struct sk_buff___84 *, struct netlink_callback___85 *);
	int (*done)(struct netlink_callback___85 *);
	void *data;
	struct module___365 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___83 {
	int (*create)(struct sk_buff___84 *, struct net_device___83 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___84 *, unsigned char *);
	int (*cache)(const struct neighbour___63 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___83 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___83 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___83 *, int);
	int poll_owner;
	struct net_device___83 *dev;
	struct sk_buff___84 *gro_list;
	struct sk_buff___84 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___83 {
	struct net_device___83 *dev;
	struct Qdisc___75 *qdisc;
	struct Qdisc___75 *qdisc_sleeping;
	struct kobject___426 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___83 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem___3 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___75 {
	struct sk_buff___84 *head;
	struct sk_buff___84 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___75;

struct Qdisc___75 {
	int (*enqueue)(struct sk_buff___84 *, struct Qdisc___75 *, struct sk_buff___84 **);
	struct sk_buff___84 * (*dequeue)(struct Qdisc___75 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___75 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___83 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___83 gso_skb;
	struct qdisc_skb_head___75 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___75 *next_sched;
	struct sk_buff_head___83 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___83 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___426 kobj;
	struct net_device___83 *dev;
	long: 64;
	struct xdp_rxq_info___83 xdp_rxq;
	union {
		struct xdp_umem___3 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___83)(struct net_device___83 *, struct sk_buff___84 *, struct net_device___83 *);

struct netdev_bpf___83 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___73 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___73 *prog;
			const struct bpf_prog_offload_ops___73 *ops;
		} verifier;
		struct {
			struct bpf_prog___73 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___83 *offmap;
		};
		struct {
			struct xdp_umem___3 *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___83 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___84 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___83 {
	int (*tls_dev_add)(struct net_device___83 *, struct sock___64 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___83 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___83 *, struct sock___64 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___83 {
	int (*ndo_init)(struct net_device___83 *);
	void (*ndo_uninit)(struct net_device___83 *);
	int (*ndo_open)(struct net_device___83 *);
	int (*ndo_stop)(struct net_device___83 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___84 *, struct net_device___83 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___84 *, struct net_device___83 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___83 *, struct sk_buff___84 *, struct net_device___83 *, select_queue_fallback_t___83);
	void (*ndo_change_rx_flags)(struct net_device___83 *, int);
	void (*ndo_set_rx_mode)(struct net_device___83 *);
	int (*ndo_set_mac_address)(struct net_device___83 *, void *);
	int (*ndo_validate_addr)(struct net_device___83 *);
	int (*ndo_do_ioctl)(struct net_device___83 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___83 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___83 *, int);
	int (*ndo_neigh_setup)(struct net_device___83 *, struct neigh_parms___63 *);
	void (*ndo_tx_timeout)(struct net_device___83 *);
	void (*ndo_get_stats64)(struct net_device___83 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___83 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___83 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___83 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___83 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___83 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___83 *);
	int (*ndo_netpoll_setup)(struct net_device___83 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___83 *);
	int (*ndo_set_vf_mac)(struct net_device___83 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___83 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___83 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___83 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___83 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___83 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___83 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___83 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___83 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___83 *, int, struct sk_buff___84 *);
	int (*ndo_set_vf_guid)(struct net_device___83 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___83 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___83 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___83 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___83 *, const struct sk_buff___84 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___83 *, struct net_device___83 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___83 *, struct net_device___83 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___83 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___83 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___83 *, struct neighbour___63 *);
	void (*ndo_neigh_destroy)(struct net_device___83 *, struct neighbour___63 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___83 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___83 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___83 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___84 *, struct netlink_callback___85 *, struct net_device___83 *, struct net_device___83 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___83 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___83 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___84 *, u32, u32, struct net_device___83 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___83 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___83 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___83 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___83 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___83 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___83 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___83 *, struct net_device___83 *);
	void (*ndo_dfwd_del_station)(struct net_device___83 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___83 *);
	int (*ndo_set_tx_maxrate)(struct net_device___83 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___83 *);
	int (*ndo_change_proto_down)(struct net_device___83 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___83 *, struct sk_buff___84 *);
	void (*ndo_set_rx_headroom)(struct net_device___83 *, int);
	int (*ndo_bpf)(struct net_device___83 *, struct netdev_bpf___83 *);
	int (*ndo_xdp_xmit)(struct net_device___83 *, int, struct xdp_frame___83 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___83 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___83 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___63 {
	possible_net_t___85 net;
	struct net_device___83 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___63 *);
	void (*neigh_cleanup)(struct neighbour___63 *);
	struct neigh_table___63 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___63 {
	u32 (*l3mdev_fib_table)(const struct net_device___83 *);
	struct sk_buff___84 * (*l3mdev_l3_rcv)(struct net_device___83 *, struct sk_buff___84 *, u16);
	struct sk_buff___84 * (*l3mdev_l3_out)(struct net_device___83 *, struct sock___64 *, struct sk_buff___84 *, u16);
	struct dst_entry___63 * (*l3mdev_link_scope_lookup)(const struct net_device___83 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct ndisc_ops___34 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___83 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___83 *, struct neighbour___63 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___83 *, u8, struct neighbour___63 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___83 *, struct sk_buff___84 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___94 *, struct net_device___83 *, const struct prefix_info *, struct inet6_dev___34 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___34;

struct inet6_dev___34 {
	struct net_device___83 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___34 *mc_list;
	struct ifmcaddr6___34 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___11 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	u8 rndid[8];
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___63 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
};

struct tcf_proto___75;

struct mini_Qdisc___75 {
	struct tcf_proto___75 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___75 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___83 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___94 *, struct net_device___83 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___83 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___83 *, struct list_head *);
	size_t (*get_size)(const struct net_device___83 *);
	int (*fill_info)(struct sk_buff___84 *, const struct net_device___83 *);
	size_t (*get_xstats_size)(const struct net_device___83 *);
	int (*fill_xstats)(struct sk_buff___84 *, const struct net_device___83 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___83 *, struct net_device___83 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___83 *, const struct net_device___83 *);
	int (*fill_slave_info)(struct sk_buff___84 *, const struct net_device___83 *, const struct net_device___83 *);
	struct net___94 * (*get_link_net)(const struct net_device___83 *);
	size_t (*get_linkxstats_size)(const struct net_device___83 *, int);
	int (*fill_linkxstats)(struct sk_buff___84 *, const struct net_device___83 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___83 {
	struct list_head poll_list;
	struct sk_buff_head___83 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___83 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___75 *output_queue;
	struct Qdisc___75 **output_queue_tailp;
	struct sk_buff___84 *completion_queue;
	struct sk_buff_head___83 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___83 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___83 input_pkt_queue;
	struct napi_struct___83 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bdi_writeback_congested___228 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___228 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___228 {
	struct bio___228 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___230 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___230 bip_inline_vecs[0];
};

struct bio_set___228 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___228 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___171 {
	struct mem_cgroup___171 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___171 {
	struct lruvec___439 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___171 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___171 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct gnet_dump___75 {
	spinlock_t *lock;
	struct sk_buff___84 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___75;

struct Qdisc_ops___75 {
	struct Qdisc_ops___75 *next;
	const struct Qdisc_class_ops___75 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___84 *, struct Qdisc___75 *, struct sk_buff___84 **);
	struct sk_buff___84 * (*dequeue)(struct Qdisc___75 *);
	struct sk_buff___84 * (*peek)(struct Qdisc___75 *);
	int (*init)(struct Qdisc___75 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___75 *);
	void (*destroy)(struct Qdisc___75 *);
	int (*change)(struct Qdisc___75 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___75 *);
	int (*change_tx_queue_len)(struct Qdisc___75 *, unsigned int);
	int (*dump)(struct Qdisc___75 *, struct sk_buff___84 *);
	int (*dump_stats)(struct Qdisc___75 *, struct gnet_dump___75 *);
	void (*ingress_block_set)(struct Qdisc___75 *, u32);
	void (*egress_block_set)(struct Qdisc___75 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___75 *);
	u32 (*egress_block_get)(struct Qdisc___75 *);
	struct module___365 *owner;
};

struct tcf_block___75;

struct Qdisc_class_ops___75 {
	unsigned int flags;
	struct netdev_queue___83 * (*select_queue)(struct Qdisc___75 *, struct tcmsg *);
	int (*graft)(struct Qdisc___75 *, long unsigned int, struct Qdisc___75 *, struct Qdisc___75 **, struct netlink_ext_ack *);
	struct Qdisc___75 * (*leaf)(struct Qdisc___75 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___75 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___75 *, u32);
	int (*change)(struct Qdisc___75 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___75 *, long unsigned int);
	void (*walk)(struct Qdisc___75 *, struct qdisc_walker *);
	struct tcf_block___75 * (*tcf_block)(struct Qdisc___75 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___75 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___75 *, long unsigned int);
	int (*dump)(struct Qdisc___75 *, long unsigned int, struct sk_buff___84 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___75 *, long unsigned int, struct gnet_dump___75 *);
};

struct tcf_chain___75;

struct tcf_block___75 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___94 *net;
	struct Qdisc___75 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___75 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___75;

struct tcf_proto_ops___75;

struct tcf_proto___75 {
	struct tcf_proto___75 *next;
	void *root;
	int (*classify)(struct sk_buff___84 *, const struct tcf_proto___75 *, struct tcf_result___75 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___75 *ops;
	struct tcf_chain___75 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___75 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___75 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___75 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___84 *, const struct tcf_proto___75 *, struct tcf_result___75 *);
	int (*init)(struct tcf_proto___75 *);
	void (*destroy)(struct tcf_proto___75 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___75 *, u32);
	void (*put)(struct tcf_proto___75 *, void *);
	int (*change)(struct net___94 *, struct sk_buff___84 *, struct tcf_proto___75 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___75 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___75 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___75 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___94 *, struct tcf_chain___75 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___94 *, struct tcf_proto___75 *, void *, struct sk_buff___84 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___84 *, struct net___94 *, void *);
	struct module___365 *owner;
	int flags;
};

struct tcf_chain___75 {
	struct mutex filter_chain_lock;
	struct tcf_proto___75 *filter_chain;
	struct list_head list;
	struct tcf_block___75 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___75 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___63 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___73 *prog;
};

struct bpf_redirect_info___73 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___288 *map;
	struct bpf_map___288 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___63;

struct neigh_hash_table___63;

struct neigh_table___63 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___83 *, __u32 *);
	bool (*key_eq)(const struct neighbour___63 *, const void *);
	int (*constructor)(struct neighbour___63 *);
	int (*pconstructor)(struct pneigh_entry___63 *);
	void (*pdestructor)(struct pneigh_entry___63 *);
	void (*proxy_redo)(struct sk_buff___84 *);
	char *id;
	struct neigh_parms___63 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___83 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___63 *nht;
	struct pneigh_entry___63 **phash_buckets;
};

struct neigh_ops___63 {
	int family;
	void (*solicit)(struct neighbour___63 *, struct sk_buff___84 *);
	void (*error_report)(struct neighbour___63 *, struct sk_buff___84 *);
	int (*output)(struct neighbour___63 *, struct sk_buff___84 *);
	int (*connected_output)(struct neighbour___63 *, struct sk_buff___84 *);
};

struct pneigh_entry___63 {
	struct pneigh_entry___63 *next;
	possible_net_t___85 net;
	struct net_device___83 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___63 {
	struct neighbour___63 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___63 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___63 *ctarget;
	struct net___94 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___63 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___63 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___46;

struct timewait_sock_ops___42;

struct proto___63 {
	void (*close)(struct sock___64 *, long int);
	int (*pre_connect)(struct sock___64 *, struct sockaddr *, int);
	int (*connect)(struct sock___64 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___64 *, int);
	struct sock___64 * (*accept)(struct sock___64 *, int, int *, bool);
	int (*ioctl)(struct sock___64 *, int, long unsigned int);
	int (*init)(struct sock___64 *);
	void (*destroy)(struct sock___64 *);
	void (*shutdown)(struct sock___64 *, int);
	int (*setsockopt)(struct sock___64 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___64 *, int, int, char *, int *);
	void (*keepalive)(struct sock___64 *, int);
	int (*sendmsg)(struct sock___64 *, struct msghdr___66 *, size_t);
	int (*recvmsg)(struct sock___64 *, struct msghdr___66 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___64 *, struct page___439 *, int, size_t, int);
	int (*bind)(struct sock___64 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___64 *, struct sk_buff___84 *);
	void (*release_cb)(struct sock___64 *);
	int (*hash)(struct sock___64 *);
	void (*unhash)(struct sock___64 *);
	void (*rehash)(struct sock___64 *);
	int (*get_port)(struct sock___64 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___64 *);
	bool (*stream_memory_read)(const struct sock___64 *);
	void (*enter_memory_pressure)(struct sock___64 *);
	void (*leave_memory_pressure)(struct sock___64 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___46 *rsk_prot;
	struct timewait_sock_ops___42 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___365 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___64 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct request_sock___47;

struct request_sock_ops___46 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___64 *, struct request_sock___47 *);
	void (*send_ack)(const struct sock___64 *, struct sk_buff___84 *, struct request_sock___47 *);
	void (*send_reset)(const struct sock___64 *, struct sk_buff___84 *);
	void (*destructor)(struct request_sock___47 *);
	void (*syn_ack_timeout)(const struct request_sock___47 *);
};

struct timewait_sock_ops___42 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___64 *, struct sock___64 *, void *);
	void (*twsk_destructor)(struct sock___64 *);
};

struct request_sock___47 {
	struct sock_common___63 __req_common;
	struct request_sock___47 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___46 *rsk_ops;
	struct sock___64 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___34 {
	struct in6_addr mca_addr;
	struct inet6_dev___34 *idev;
	struct ifmcaddr6___34 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ip6_ra_chain___34 {
	struct ip6_ra_chain___34 *next;
	struct sock___64 *sk;
	int sel;
	void (*destructor)(struct sock___64 *);
};

struct nf_hook_state___8 {
	unsigned int hook;
	u_int8_t pf;
	struct net_device___83 *in;
	struct net_device___83 *out;
	struct sock___64 *sk;
	struct net___94 *net;
	int (*okfn)(struct net___94 *, struct sock___64 *, struct sk_buff___84 *);
};

struct nf_nat_hook___8 {
	int (*parse_nat_setup)(struct nf_conn *, enum nf_nat_manip_type, const struct nlattr *);
	void (*decode_session)(struct sk_buff___84 *, struct flowi *);
	unsigned int (*manip_pkt)(struct sk_buff___84 *, struct nf_conn *, enum nf_nat_manip_type, enum ip_conntrack_dir);
};

struct nf_ct_hook___8 {
	int (*update)(struct net___94 *, struct sk_buff___84 *);
	void (*destroy)(struct nf_conntrack *);
	bool (*get_tuple_skb)(struct nf_conntrack_tuple *, const struct sk_buff___84 *);
};

struct nfnl_ct_hook___8 {
	struct nf_conn * (*get_ct)(const struct sk_buff___84 *, enum ip_conntrack_info *);
	size_t (*build_size)(const struct nf_conn *);
	int (*build)(struct sk_buff___84 *, struct nf_conn *, enum ip_conntrack_info, u_int16_t, u_int16_t);
	int (*parse)(const struct nlattr *, struct nf_conn *);
	int (*attach_expect)(const struct nlattr *, struct nf_conn *, u32, u32);
	void (*seq_adjust)(struct sk_buff___84 *, struct nf_conn *, enum ip_conntrack_info, s32);
};

struct xt_action_param___2;

struct xt_mtchk_param___2;

struct xt_mtdtor_param___2;

struct xt_match___2 {
	struct list_head list;
	const char name[29];
	u_int8_t revision;
	bool (*match)(const struct sk_buff___84 *, struct xt_action_param___2 *);
	int (*checkentry)(const struct xt_mtchk_param___2 *);
	void (*destroy)(const struct xt_mtdtor_param___2 *);
	struct module___365 *me;
	const char *table;
	unsigned int matchsize;
	unsigned int usersize;
	unsigned int hooks;
	short unsigned int proto;
	short unsigned int family;
};

struct xt_tgchk_param___2;

struct xt_tgdtor_param___2;

struct xt_target___2 {
	struct list_head list;
	const char name[29];
	u_int8_t revision;
	unsigned int (*target)(struct sk_buff___84 *, const struct xt_action_param___2 *);
	int (*checkentry)(const struct xt_tgchk_param___2 *);
	void (*destroy)(const struct xt_tgdtor_param___2 *);
	struct module___365 *me;
	const char *table;
	unsigned int targetsize;
	unsigned int usersize;
	unsigned int hooks;
	short unsigned int proto;
	short unsigned int family;
};

struct xt_action_param___2 {
	union {
		const struct xt_match___2 *match;
		const struct xt_target___2 *target;
	};
	union {
		const void *matchinfo;
		const void *targinfo;
	};
	const struct nf_hook_state___8 *state;
	int fragoff;
	unsigned int thoff;
	bool hotdrop;
};

struct xt_mtchk_param___2 {
	struct net___94 *net;
	const char *table;
	const void *entryinfo;
	const struct xt_match___2 *match;
	void *matchinfo;
	unsigned int hook_mask;
	u_int8_t family;
	bool nft_compat;
};

struct xt_mtdtor_param___2 {
	struct net___94 *net;
	const struct xt_match___2 *match;
	void *matchinfo;
	u_int8_t family;
};

struct xt_tgchk_param___2 {
	struct net___94 *net;
	const char *table;
	const void *entryinfo;
	const struct xt_target___2 *target;
	void *targinfo;
	unsigned int hook_mask;
	u_int8_t family;
	bool nft_compat;
};

struct xt_tgdtor_param___2 {
	struct net___94 *net;
	const struct xt_target___2 *target;
	void *targinfo;
	u_int8_t family;
};

struct xt_tcp {
	__u16 spts[2];
	__u16 dpts[2];
	__u8 option;
	__u8 flg_mask;
	__u8 flg_cmp;
	__u8 invflags;
};

struct xt_udp {
	__u16 spts[2];
	__u16 dpts[2];
	__u8 invflags;
};

struct nf_ipv6_ops___6 {
	int (*chk_addr)(struct net___94 *, const struct in6_addr *, const struct net_device___83 *, int);
	void (*route_input)(struct sk_buff___84 *);
	int (*fragment)(struct net___94 *, struct sock___64 *, struct sk_buff___84 *, int (*)(struct net___94 *, struct sock___64 *, struct sk_buff___84 *));
	__sum16 (*checksum)(struct sk_buff___84 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___84 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___94 *, struct dst_entry___63 **, struct flowi *, bool);
	int (*reroute)(struct sk_buff___84 *, const struct nf_queue_entry___2 *);
};

struct module___366;

struct file___439;

struct kiocb___439;

struct iov_iter___206;

struct poll_table_struct___278;

struct vm_area_struct___440;

struct inode___439;

struct file_lock___439;

struct page___440;

struct pipe_inode_info___120;

struct seq_file___378;

struct file_operations___439 {
	struct module___366 *owner;
	loff_t (*llseek)(struct file___439 *, loff_t, int);
	ssize_t (*read)(struct file___439 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___439 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___439 *, struct iov_iter___206 *);
	ssize_t (*write_iter)(struct kiocb___439 *, struct iov_iter___206 *);
	int (*iopoll)(struct kiocb___439 *, bool);
	int (*iterate)(struct file___439 *, struct dir_context *);
	int (*iterate_shared)(struct file___439 *, struct dir_context *);
	__poll_t (*poll)(struct file___439 *, struct poll_table_struct___278 *);
	long int (*unlocked_ioctl)(struct file___439 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___439 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___439 *, struct vm_area_struct___440 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___439 *, struct file___439 *);
	int (*flush)(struct file___439 *, fl_owner_t);
	int (*release)(struct inode___439 *, struct file___439 *);
	int (*fsync)(struct file___439 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___439 *, int);
	int (*lock)(struct file___439 *, int, struct file_lock___439 *);
	ssize_t (*sendpage)(struct file___439 *, struct page___440 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___439 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___439 *, int, struct file_lock___439 *);
	ssize_t (*splice_write)(struct pipe_inode_info___120 *, struct file___439 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___439 *, loff_t *, struct pipe_inode_info___120 *, size_t, unsigned int);
	int (*setlease)(struct file___439 *, long int, struct file_lock___439 **, void **);
	long int (*fallocate)(struct file___439 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___378 *, struct file___439 *);
	ssize_t (*copy_file_range)(struct file___439 *, loff_t, struct file___439 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___439 *, loff_t, struct file___439 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___439 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___440 {
	u64 seqnum;
	struct vm_area_struct___440 *vmas[4];
};

struct page_frag___440 {
	struct page___440 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___440;

struct mem_cgroup___172;

struct pid___243;

struct cred___407;

struct nsproxy___334;

struct signal_struct___314;

struct bio_list___229;

struct backing_dev_info___229;

struct css_set___288;

struct vm_struct___343;

struct task_struct___441 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___441 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___440 *mm;
	struct mm_struct___440 *active_mm;
	struct vmacache___440 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___441 *real_parent;
	struct task_struct___441 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___441 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___172 *active_memcg;
	long int rh_reserved2;
	struct pid___243 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___243 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___243 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___407 *ptracer_cred;
	const struct cred___407 *real_cred;
	const struct cred___407 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___334 *nsproxy;
	struct signal_struct___314 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___441 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___229 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___229 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___288 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___120 *splice_pipe;
	struct page_frag___440 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___172 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___441 *oom_reaper_list;
	struct vm_struct___343 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___156 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rw_semaphore___441 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___441 *owner;
};

struct key___407;

struct ucounts___304;

struct user_namespace___304 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___304 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___29 ns;
	long unsigned int flags;
	struct key___407 *persistent_keyring_register;
	struct rw_semaphore___441 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___304 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___440 *pgtable_t___440;

struct address_space___439;

struct dev_pagemap___427;

struct page___440 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___439 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___440 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___440 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___440 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___427 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___172 *mem_cgroup;
};

struct pglist_data___440;

struct lruvec___440 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___440 *pgdat;
};

struct zone___440 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___440 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___440 {
	struct zone___440 *zone;
	int zone_idx;
};

struct zonelist___440 {
	struct zoneref___440 _zonerefs[25];
};

struct pglist_data___440 {
	struct zone___440 node_zones[3];
	struct zonelist___440 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___441 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___441 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___440 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___441 {
	void *stack;
	struct task_struct___441 *task;
	long int status;
};

struct blocking_notifier_head___440 {
	struct rw_semaphore___441 rwsem;
	struct notifier_block *head;
};

struct dentry___439;

struct path___440 {
	struct vfsmount *mnt;
	struct dentry___439 *dentry;
};

struct fown_struct___243 {
	rwlock_t lock;
	struct pid___243 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___439 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___440 f_path;
	struct inode___439 *f_inode;
	const struct file_operations___439 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___243 f_owner;
	const struct cred___407 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___439 *f_mapping;
	errseq_t f_wb_err;
};

struct user_struct___407;

struct cred___407 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___407 *session_keyring;
	struct key___407 *process_keyring;
	struct key___407 *thread_keyring;
	struct key___407 *request_key_auth;
	void *security;
	struct user_struct___407 *user;
	struct user_namespace___304 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___433;

struct kernfs_elem_dir___433 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___433 *root;
};

struct kernfs_node___434;

struct kernfs_syscall_ops___433;

struct kernfs_root___433 {
	struct kernfs_node___434 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___433 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___433 {
	struct kernfs_node___434 *target_kn;
};

struct kernfs_ops___433;

struct kernfs_elem_attr___433 {
	const struct kernfs_ops___433 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___434 *notify_next;
};

struct kernfs_node___434 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___434 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___433 dir;
		struct kernfs_elem_symlink___433 symlink;
		struct kernfs_elem_attr___433 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___433;

struct kernfs_ops___433 {
	int (*open)(struct kernfs_open_file___433 *);
	void (*release)(struct kernfs_open_file___433 *);
	int (*seq_show)(struct seq_file___378 *, void *);
	void * (*seq_start)(struct seq_file___378 *, loff_t *);
	void * (*seq_next)(struct seq_file___378 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___378 *, void *);
	ssize_t (*read)(struct kernfs_open_file___433 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___433 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___433 *, struct vm_area_struct___440 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___433 *, struct poll_table_struct___278 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___433 {
	int (*remount_fs)(struct kernfs_root___433 *, int *, char *);
	int (*show_options)(struct seq_file___378 *, struct kernfs_root___433 *);
	int (*mkdir)(struct kernfs_node___434 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___434 *);
	int (*rename)(struct kernfs_node___434 *, struct kernfs_node___434 *, const char *);
	int (*show_path)(struct seq_file___378 *, struct kernfs_node___434 *, struct kernfs_root___433 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___378;

struct seq_file___378 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___378 *op;
	int poll_event;
	const struct file___439 *file;
	void *private;
};

struct vm_operations_struct___427;

struct kernfs_open_file___433 {
	struct kernfs_node___434 *kn;
	struct file___439 *file;
	struct seq_file___378 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___427 *vm_ops;
};

struct vm_fault___427;

struct vm_operations_struct___427 {
	void (*open)(struct vm_area_struct___440 *);
	void (*close)(struct vm_area_struct___440 *);
	int (*split)(struct vm_area_struct___440 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___440 *);
	vm_fault_t (*fault)(struct vm_fault___427 *);
	vm_fault_t (*huge_fault)(struct vm_fault___427 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___427 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___440 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___427 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___427 *);
	int (*access)(struct vm_area_struct___440 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___440 *);
	int (*set_policy)(struct vm_area_struct___440 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___440 *, long unsigned int);
	struct page___440 * (*find_special_page)(struct vm_area_struct___440 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___288)(struct file___439 *, wait_queue_head_t *, struct poll_table_struct___278 *);

struct poll_table_struct___278 {
	poll_queue_proc___288 _qproc;
	__poll_t _key;
};

struct vm_area_struct___440 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___440 *vm_next;
	struct vm_area_struct___440 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___440 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___427 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___439 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sock___65;

struct kobj_ns_type_operations___64 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___65 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct net___95;

typedef struct {
	struct net___95 *net;
} possible_net_t___86;

struct proto___64;

struct sock_common___64 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___64 *skc_prot;
	possible_net_t___86 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___65 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___85;

struct sk_buff_head___84 {
	struct sk_buff___85 *next;
	struct sk_buff___85 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___64;

struct socket_wq___65;

struct xfrm_policy___8;

struct dst_entry___64;

struct socket___66;

struct net_device___84;

struct sock___65 {
	struct sock_common___64 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___84 sk_error_queue;
	struct sk_buff_head___84 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___85 *head;
		struct sk_buff___85 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___64 *sk_filter;
	union {
		struct socket_wq___65 *sk_wq;
		struct socket_wq___65 *sk_wq_raw;
	};
	struct xfrm_policy___8 *sk_policy[2];
	struct dst_entry___64 *sk_rx_dst;
	struct dst_entry___64 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___85 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___84 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___440 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___64 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___243 *sk_peer_pid;
	const struct cred___407 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___66 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___172 *sk_memcg;
	void (*sk_state_change)(struct sock___65 *);
	void (*sk_data_ready)(struct sock___65 *);
	void (*sk_write_space)(struct sock___65 *);
	void (*sk_error_report)(struct sock___65 *);
	int (*sk_backlog_rcv)(struct sock___65 *, struct sk_buff___85 *);
	struct sk_buff___85 * (*sk_validate_xmit_skb)(struct sock___65 *, struct net_device___84 *, struct sk_buff___85 *);
	void (*sk_destruct)(struct sock___65 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kobject___427;

struct bin_attribute___403;

struct attribute_group___404 {
	const char *name;
	umode_t (*is_visible)(struct kobject___427 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___427 *, struct bin_attribute___403 *, int);
	struct attribute **attrs;
	struct bin_attribute___403 **bin_attrs;
};

struct kset___426;

struct kobj_type___426;

struct kobject___427 {
	const char *name;
	struct list_head entry;
	struct kobject___427 *parent;
	struct kset___426 *kset;
	struct kobj_type___426 *ktype;
	struct kernfs_node___434 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___403 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___439 *, struct kobject___427 *, struct bin_attribute___403 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___439 *, struct kobject___427 *, struct bin_attribute___403 *, char *, loff_t, size_t);
	int (*mmap)(struct file___439 *, struct kobject___427 *, struct bin_attribute___403 *, struct vm_area_struct___440 *);
};

struct sysfs_ops___426 {
	ssize_t (*show)(struct kobject___427 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___427 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___426;

struct kset___426 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___427 kobj;
	const struct kset_uevent_ops___426 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___426 {
	void (*release)(struct kobject___427 *);
	const struct sysfs_ops___426 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___64 * (*child_ns_type)(struct kobject___427 *);
	const void * (*namespace)(struct kobject___427 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___426 {
	int (* const filter)(struct kset___426 *, struct kobject___427 *);
	const char * (* const name)(struct kset___426 *, struct kobject___427 *);
	int (* const uevent)(struct kset___426 *, struct kobject___427 *, struct kobj_uevent_env *);
};

struct kobj_attribute___417 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___427 *, struct kobj_attribute___417 *, char *);
	ssize_t (*store)(struct kobject___427 *, struct kobj_attribute___417 *, const char *, size_t);
};

struct kernel_param___365;

struct kernel_param_ops___365 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___365 *);
	int (*get)(char *, const struct kernel_param___365 *);
	void (*free)(void *);
};

struct kparam_array___365;

struct kernel_param___365 {
	const char *name;
	struct module___366 *mod;
	const struct kernel_param_ops___365 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___365 *arr;
	};
};

struct kparam_array___365 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___365 *ops;
	void *elem;
};

struct module_kobject___365 {
	struct kobject___427 kobj;
	struct module___366 *mod;
	struct kobject___427 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___365 {
	struct module___366 *mod;
	struct latch_tree_node node;
};

struct module_layout___365 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___365 mtn;
};

struct module_attribute___365;

struct module___366 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___365 mkobj;
	struct module_attribute___365 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___427 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___365 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___365 core_layout;
	struct module_layout___365 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___365 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___365 *, struct module_kobject___365 *, char *);
	ssize_t (*store)(struct module_attribute___365 *, struct module_kobject___365 *, const char *, size_t);
	void (*setup)(struct module___366 *, const char *);
	int (*test)(struct module___366 *);
	void (*free)(struct module___366 *);
};

struct pid_namespace___243;

struct upid___243 {
	int nr;
	struct pid_namespace___243 *ns;
};

struct pid_namespace___243 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___441 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___243 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___439 *proc_self;
	struct dentry___439 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___304 *user_ns;
	struct ucounts___304 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___29 ns;
};

struct pid___243 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___243 numbers[1];
};

struct user_struct___407 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___407 *uid_keyring;
	struct key___407 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___440;

struct mm_struct___440 {
	struct {
		struct vm_area_struct___440 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___439 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___441 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___440 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___441 *owner;
		struct user_namespace___304 *user_ns;
		struct file___439 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___440 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup___288;

struct cgroup_subsys___288;

struct cgroup_subsys_state___288 {
	struct cgroup___288 *cgroup;
	struct cgroup_subsys___288 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___288 *parent;
};

struct cgroup_file___288 {
	struct kernfs_node___434 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___172;

struct mem_cgroup___172 {
	struct cgroup_subsys_state___288 css;
	struct mem_cgroup_id___13 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___288 events_file;
	struct cgroup_file___288 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___441 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___172 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cgroup_namespace___288;

struct nsproxy___334 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___243 *pid_ns_for_children;
	struct net___95 *net_ns;
	struct cgroup_namespace___288 *cgroup_ns;
};

struct signal_struct___314 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___441 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___441 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___243 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___243 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___440 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___243 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___229;

struct bio_list___229 {
	struct bio___229 *head;
	struct bio___229 *tail;
};

struct bdi_writeback_congested___229;

struct bdi_writeback___229 {
	struct backing_dev_info___229 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___229 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___288 *memcg_css;
	struct cgroup_subsys_state___288 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___407;

struct backing_dev_info___229 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___229 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___407 *dev;
	struct device___407 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___439 *debug_dir;
	struct dentry___439 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___288 {
	struct cgroup_subsys_state___288 *subsys[13];
	refcount_t refcount;
	struct css_set___288 *dom_cset;
	struct cgroup___288 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___288 *mg_src_cgrp;
	struct cgroup___288 *mg_dst_cgrp;
	struct css_set___288 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___439;

struct pipe_buffer___120;

struct pipe_inode_info___120 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___440 *tmp_page;
	struct fasync_struct___439 *fasync_readers;
	struct fasync_struct___439 *fasync_writers;
	struct pipe_buffer___120 *bufs;
	struct user_struct___407 *user;
};

struct vm_struct___343 {
	struct vm_struct___343 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___440 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___326 {
	struct task_struct___441 task;
	long unsigned int stack[8192];
};

struct address_space_operations___439;

struct address_space___439 {
	struct inode___439 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___441 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___439 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___427)(struct vm_area_struct___440 *, long unsigned int, const struct page___440 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___427)(struct page___440 *, void *);

struct dev_pagemap___427 {
	dev_page_fault_t___427 page_fault;
	dev_page_free_t___427 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___407 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___440 {
	struct task_struct___441 *task;
	struct core_thread___440 *next;
};

struct core_state___440 {
	atomic_t nr_threads;
	struct core_thread___440 dumper;
	struct completion startup;
};

struct vm_fault___427 {
	struct vm_area_struct___440 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___440 *cow_page;
	struct mem_cgroup___172 *memcg;
	struct page___440 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___440 prealloc_pte;
};

struct shrink_control___172 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___172 *memcg;
};

struct shrinker___172 {
	long unsigned int (*count_objects)(struct shrinker___172 *, struct shrink_control___172 *);
	long unsigned int (*scan_objects)(struct shrinker___172 *, struct shrink_control___172 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct dev_pm_info___407 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___407 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___407;

struct bus_type___407;

struct device_driver___407;

struct dev_pm_domain___407;

struct dma_map_ops___179;

struct fwnode_handle___327;

struct class___407;

struct device___407 {
	struct device___407 *parent;
	struct device_private *p;
	struct kobject___427 kobj;
	const char *init_name;
	const struct device_type___407 *type;
	struct mutex mutex;
	struct bus_type___407 *bus;
	struct device_driver___407 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___407 power;
	struct dev_pm_domain___407 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___179 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___327 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___407 *class;
	const struct attribute_group___404 **groups;
	void (*release)(struct device___407 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___439;

struct super_block___439;

struct dentry___439 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___439 *d_parent;
	struct qstr d_name;
	struct inode___439 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___439 *d_op;
	struct super_block___439 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___439;

struct block_device___439;

struct inode___439 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___439 *i_op;
	struct super_block___439 *i_sb;
	struct address_space___439 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___441 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___229 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___439 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___439 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___120 *i_pipe;
		struct block_device___439 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___439 {
	int (*d_revalidate)(struct dentry___439 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___439 *, unsigned int);
	int (*d_hash)(const struct dentry___439 *, struct qstr *);
	int (*d_compare)(const struct dentry___439 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___439 *);
	int (*d_init)(struct dentry___439 *);
	void (*d_release)(struct dentry___439 *);
	void (*d_prune)(struct dentry___439 *);
	void (*d_iput)(struct dentry___439 *, struct inode___439 *);
	char * (*d_dname)(struct dentry___439 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___440 *);
	int (*d_manage)(const struct path___440 *, bool);
	struct dentry___439 * (*d_real)(struct dentry___439 *, const struct inode___439 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___439;

struct mem_dqinfo___439 {
	struct quota_format_type___439 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___439;

struct quota_info___439 {
	unsigned int flags;
	struct rw_semaphore___441 dqio_sem;
	struct inode___439 *files[3];
	struct mem_dqinfo___439 info[3];
	const struct quota_format_ops___439 *ops[3];
};

struct rcuwait___439 {
	struct task_struct___441 *task;
};

struct percpu_rw_semaphore___439 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___441 rw_sem;
	struct rcuwait___439 writer;
	int readers_block;
};

struct sb_writers___439 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___439 rw_sem[3];
};

struct file_system_type___439;

struct super_operations___439;

struct dquot_operations___439;

struct quotactl_ops___439;

struct super_block___439 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___439 *s_type;
	const struct super_operations___439 *s_op;
	const struct dquot_operations___439 *dq_op;
	const struct quotactl_ops___439 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___439 *s_root;
	struct rw_semaphore___441 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___439 *s_bdev;
	struct backing_dev_info___229 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___439 s_dquot;
	struct sb_writers___439 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___439 *s_d_op;
	int cleancache_poolid;
	struct shrinker___172 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___304 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___439 {
	struct file___439 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___439 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___439 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___439 *ia_file;
};

struct dquot___439 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___439 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___439 {
	int qf_fmt_id;
	const struct quota_format_ops___439 *qf_ops;
	struct module___366 *qf_owner;
	struct quota_format_type___439 *qf_next;
};

struct quota_format_ops___439 {
	int (*check_quota_file)(struct super_block___439 *, int);
	int (*read_file_info)(struct super_block___439 *, int);
	int (*write_file_info)(struct super_block___439 *, int);
	int (*free_file_info)(struct super_block___439 *, int);
	int (*read_dqblk)(struct dquot___439 *);
	int (*commit_dqblk)(struct dquot___439 *);
	int (*release_dqblk)(struct dquot___439 *);
	int (*get_next_id)(struct super_block___439 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___439 {
	int (*write_dquot)(struct dquot___439 *);
	struct dquot___439 * (*alloc_dquot)(struct super_block___439 *, int);
	void (*destroy_dquot)(struct dquot___439 *);
	int (*acquire_dquot)(struct dquot___439 *);
	int (*release_dquot)(struct dquot___439 *);
	int (*mark_dirty)(struct dquot___439 *);
	int (*write_info)(struct super_block___439 *, int);
	qsize_t * (*get_reserved_space)(struct inode___439 *);
	int (*get_projid)(struct inode___439 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___439 *, qsize_t *);
	int (*get_next_id)(struct super_block___439 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___439 {
	int (*quota_on)(struct super_block___439 *, int, int, const struct path___440 *);
	int (*quota_off)(struct super_block___439 *, int);
	int (*quota_enable)(struct super_block___439 *, unsigned int);
	int (*quota_disable)(struct super_block___439 *, unsigned int);
	int (*quota_sync)(struct super_block___439 *, int);
	int (*set_info)(struct super_block___439 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___439 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___439 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___439 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___439 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___439 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___192;

struct address_space_operations___439 {
	int (*writepage)(struct page___440 *, struct writeback_control___192 *);
	int (*readpage)(struct file___439 *, struct page___440 *);
	int (*writepages)(struct address_space___439 *, struct writeback_control___192 *);
	int (*set_page_dirty)(struct page___440 *);
	int (*readpages)(struct file___439 *, struct address_space___439 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___439 *, struct address_space___439 *, loff_t, unsigned int, unsigned int, struct page___440 **, void **);
	int (*write_end)(struct file___439 *, struct address_space___439 *, loff_t, unsigned int, unsigned int, struct page___440 *, void *);
	sector_t (*bmap)(struct address_space___439 *, sector_t);
	void (*invalidatepage)(struct page___440 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___440 *, gfp_t);
	void (*freepage)(struct page___440 *);
	ssize_t (*direct_IO)(struct kiocb___439 *, struct iov_iter___206 *);
	int (*migratepage)(struct address_space___439 *, struct page___440 *, struct page___440 *, enum migrate_mode);
	bool (*isolate_page)(struct page___440 *, isolate_mode_t);
	void (*putback_page)(struct page___440 *);
	int (*launder_page)(struct page___440 *);
	int (*is_partially_uptodate)(struct page___440 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___440 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___439 *, struct page___440 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___439 *, sector_t *);
	void (*swap_deactivate)(struct file___439 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___192 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___229 *wb;
	struct inode___439 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___231;

struct iov_iter___206 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___231 *bvec;
		struct pipe_inode_info___120 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___439 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___439 *bd_inode;
	struct super_block___439 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___439 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___229 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___439 {
	struct dentry___439 * (*lookup)(struct inode___439 *, struct dentry___439 *, unsigned int);
	const char * (*get_link)(struct dentry___439 *, struct inode___439 *, struct delayed_call *);
	int (*permission)(struct inode___439 *, int);
	struct posix_acl * (*get_acl)(struct inode___439 *, int);
	int (*readlink)(struct dentry___439 *, char *, int);
	int (*create)(struct inode___439 *, struct dentry___439 *, umode_t, bool);
	int (*link)(struct dentry___439 *, struct inode___439 *, struct dentry___439 *);
	int (*unlink)(struct inode___439 *, struct dentry___439 *);
	int (*symlink)(struct inode___439 *, struct dentry___439 *, const char *);
	int (*mkdir)(struct inode___439 *, struct dentry___439 *, umode_t);
	int (*rmdir)(struct inode___439 *, struct dentry___439 *);
	int (*mknod)(struct inode___439 *, struct dentry___439 *, umode_t, dev_t);
	int (*rename)(struct inode___439 *, struct dentry___439 *, struct inode___439 *, struct dentry___439 *, unsigned int);
	int (*setattr)(struct dentry___439 *, struct iattr___439 *);
	int (*getattr)(const struct path___440 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___439 *, char *, size_t);
	int (*fiemap)(struct inode___439 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___439 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___439 *, struct dentry___439 *, struct file___439 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___439 *, struct dentry___439 *, umode_t);
	int (*set_acl)(struct inode___439 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___439 {
	void (*fl_copy_lock)(struct file_lock___439 *, struct file_lock___439 *);
	void (*fl_release_private)(struct file_lock___439 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___439;

struct file_lock___439 {
	struct file_lock___439 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___439 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___439 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___439 *fl_ops;
	const struct lock_manager_operations___439 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___439 {
	int (*lm_compare_owner)(struct file_lock___439 *, struct file_lock___439 *);
	long unsigned int (*lm_owner_key)(struct file_lock___439 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___439 *);
	int (*lm_grant)(struct file_lock___439 *, int);
	bool (*lm_break)(struct file_lock___439 *);
	int (*lm_change)(struct file_lock___439 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___439 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___439 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___439 *fa_next;
	struct file___439 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___439 {
	const char *name;
	int fs_flags;
	struct dentry___439 * (*mount)(struct file_system_type___439 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___439 *);
	struct module___366 *owner;
	struct file_system_type___439 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___439 {
	struct inode___439 * (*alloc_inode)(struct super_block___439 *);
	void (*destroy_inode)(struct inode___439 *);
	void (*dirty_inode)(struct inode___439 *, int);
	int (*write_inode)(struct inode___439 *, struct writeback_control___192 *);
	int (*drop_inode)(struct inode___439 *);
	void (*evict_inode)(struct inode___439 *);
	void (*put_super)(struct super_block___439 *);
	int (*sync_fs)(struct super_block___439 *, int);
	int (*freeze_super)(struct super_block___439 *);
	int (*freeze_fs)(struct super_block___439 *);
	int (*thaw_super)(struct super_block___439 *);
	int (*unfreeze_fs)(struct super_block___439 *);
	int (*statfs)(struct dentry___439 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___439 *, int *, char *);
	void (*umount_begin)(struct super_block___439 *);
	int (*show_options)(struct seq_file___378 *, struct dentry___439 *);
	int (*show_devname)(struct seq_file___378 *, struct dentry___439 *);
	int (*show_path)(struct seq_file___378 *, struct dentry___439 *);
	int (*show_stats)(struct seq_file___378 *, struct dentry___439 *);
	ssize_t (*quota_read)(struct super_block___439 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___439 *, int, const char *, size_t, loff_t);
	struct dquot___439 ** (*get_dquots)(struct inode___439 *);
	int (*bdev_try_to_free_page)(struct super_block___439 *, struct page___440 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___439 *, struct shrink_control___172 *);
	long int (*free_cached_objects)(struct super_block___439 *, struct shrink_control___172 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___229(struct bio___229 *);

struct bio_vec___231 {
	struct page___440 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___229;

struct bio_set___229;

struct bio___229 {
	struct bio___229 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___229 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___229 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___231 *bi_io_vec;
	struct bio_set___229 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___231 bi_inline_vecs[0];
};

typedef void compound_page_dtor___427(struct page___440 *);

struct crypto_async_request___30;

typedef void (*crypto_completion_t___30)(struct crypto_async_request___30 *, int);

struct crypto_tfm___30;

struct crypto_async_request___30 {
	struct list_head list;
	crypto_completion_t___30 complete;
	void *data;
	struct crypto_tfm___30 *tfm;
	u32 flags;
};

struct crypto_ablkcipher___30;

struct ablkcipher_request___30;

struct ablkcipher_tfm___30 {
	int (*setkey)(struct crypto_ablkcipher___30 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___30 *);
	int (*decrypt)(struct ablkcipher_request___30 *);
	struct crypto_ablkcipher___30 *base;
	unsigned int ivsize;
	unsigned int reqsize;
};

struct blkcipher_desc___30;

struct blkcipher_tfm___30 {
	void *iv;
	int (*setkey)(struct crypto_tfm___30 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___30 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___30 *, struct scatterlist *, struct scatterlist *, unsigned int);
};

struct cipher_tfm___30 {
	int (*cit_setkey)(struct crypto_tfm___30 *, const u8 *, unsigned int);
	void (*cit_encrypt_one)(struct crypto_tfm___30 *, u8 *, const u8 *);
	void (*cit_decrypt_one)(struct crypto_tfm___30 *, u8 *, const u8 *);
};

struct compress_tfm___30 {
	int (*cot_compress)(struct crypto_tfm___30 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*cot_decompress)(struct crypto_tfm___30 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___30;

struct crypto_tfm___30 {
	u32 crt_flags;
	union {
		struct ablkcipher_tfm___30 ablkcipher;
		struct blkcipher_tfm___30 blkcipher;
		struct cipher_tfm___30 cipher;
		struct compress_tfm___30 compress;
	} crt_u;
	void (*exit)(struct crypto_tfm___30 *);
	struct crypto_alg___30 *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct ablkcipher_request___30 {
	struct crypto_async_request___30 base;
	unsigned int nbytes;
	void *info;
	struct scatterlist *src;
	struct scatterlist *dst;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_blkcipher___30;

struct blkcipher_desc___30 {
	struct crypto_blkcipher___30 *tfm;
	void *info;
	u32 flags;
};

struct crypto_blkcipher___30 {
	struct crypto_tfm___30 base;
};

struct ablkcipher_alg___30 {
	int (*setkey)(struct crypto_ablkcipher___30 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___30 *);
	int (*decrypt)(struct ablkcipher_request___30 *);
	int (*givencrypt)(struct skcipher_givcrypt_request *);
	int (*givdecrypt)(struct skcipher_givcrypt_request *);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct crypto_ablkcipher___30 {
	struct crypto_tfm___30 base;
};

struct blkcipher_alg___30 {
	int (*setkey)(struct crypto_tfm___30 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___30 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___30 *, struct scatterlist *, struct scatterlist *, unsigned int);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct cipher_alg___30 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___30 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___30 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___30 *, u8 *, const u8 *);
};

struct compress_alg___30 {
	int (*coa_compress)(struct crypto_tfm___30 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___30 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___30 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type *cra_type;
	union {
		struct ablkcipher_alg___30 ablkcipher;
		struct blkcipher_alg___30 blkcipher;
		struct cipher_alg___30 cipher;
		struct compress_alg___30 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___30 *);
	void (*cra_exit)(struct crypto_tfm___30 *);
	void (*cra_destroy)(struct crypto_alg___30 *);
	struct module___366 *cra_module;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct crypto_cipher___14 {
	struct crypto_tfm___30 base;
};

struct msghdr___67 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___206 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___439 *msg_iocb;
};

struct ip_mreqn {
	struct in_addr imr_multiaddr;
	struct in_addr imr_address;
	int imr_ifindex;
};

struct inet_frags___84;

struct netns_frags___84 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___84 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct inet_frag_queue___84;

struct inet_frags___84 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___84 *, const void *);
	void (*destructor)(struct inet_frag_queue___84 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___84 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___85 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___85 *fragments_tail;
	struct sk_buff___85 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___84 *net;
	struct callback_head rcu;
};

struct sec_path___8;

struct nf_bridge_info___84;

struct sk_buff___85 {
	union {
		struct {
			struct sk_buff___85 *next;
			struct sk_buff___85 *prev;
			union {
				struct net_device___84 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___65 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___85 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path___8 *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___84 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct ip_ra_chain___30;

struct fib_rules_ops___64;

struct tcp_congestion_ops___11;

struct tcp_fastopen_context___11;

struct fib_notifier_ops___65;

struct netns_ipv4___84 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___30 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___64 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___65 *fibnl;
	struct sock___65 **icmp_sk;
	struct sock___65 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___65 **tcp_sk;
	struct netns_frags___84 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops___11 *tcp_congestion_control;
	struct tcp_fastopen_context___11 *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___64 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___65 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___65 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct ip_ra_chain___30 {
	struct ip_ra_chain___30 *next;
	struct sock___65 *sk;
	union {
		void (*destructor)(struct sock___65 *);
		struct sock___65 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___64;

struct fib_lookup_arg___64;

struct fib_rules_ops___64 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___64 *, struct flowi *, int, struct fib_lookup_arg___64 *);
	bool (*suppress)(struct fib_rule___64 *, struct fib_lookup_arg___64 *);
	int (*match)(struct fib_rule___64 *, struct flowi *, int);
	int (*configure)(struct fib_rule___64 *, struct sk_buff___85 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___64 *);
	int (*compare)(struct fib_rule___64 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___64 *, struct sk_buff___85 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___64 *);
	void (*flush_cache)(struct fib_rules_ops___64 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___366 *owner;
	struct net___95 *fro_net;
	struct callback_head rcu;
};

struct tcp_congestion_ops___11 {
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___65 *);
	void (*release)(struct sock___65 *);
	u32 (*ssthresh)(struct sock___65 *);
	void (*cong_avoid)(struct sock___65 *, u32, u32);
	void (*set_state)(struct sock___65 *, u8);
	void (*cwnd_event)(struct sock___65 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___65 *, u32);
	u32 (*undo_cwnd)(struct sock___65 *);
	void (*pkts_acked)(struct sock___65 *, const struct ack_sample *);
	u32 (*min_tso_segs)(struct sock___65 *);
	u32 (*sndbuf_expand)(struct sock___65 *);
	void (*cong_control)(struct sock___65 *, const struct rate_sample *);
	size_t (*get_info)(struct sock___65 *, u32, int *, union tcp_cc_info *);
	char name[16];
	struct module___366 *owner;
};

struct tcp_fastopen_context___11 {
	struct crypto_cipher___14 *tfm;
	__u8 key[16];
	struct callback_head rcu;
};

struct fib_notifier_ops___65 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___95 *);
	int (*fib_dump)(struct net___95 *, struct notifier_block *);
	struct module___366 *owner;
	struct callback_head rcu;
};

struct neighbour___64;

struct dst_ops___95 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___95 *);
	struct dst_entry___64 * (*check)(struct dst_entry___64 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___64 *);
	unsigned int (*mtu)(const struct dst_entry___64 *);
	u32 * (*cow_metrics)(struct dst_entry___64 *, long unsigned int);
	void (*destroy)(struct dst_entry___64 *);
	void (*ifdown)(struct dst_entry___64 *, struct net_device___84 *, int);
	struct dst_entry___64 * (*negative_advice)(struct dst_entry___64 *);
	void (*link_failure)(struct sk_buff___85 *);
	void (*update_pmtu)(struct dst_entry___64 *, struct sock___65 *, struct sk_buff___85 *, u32);
	void (*redirect)(struct dst_entry___64 *, struct sock___65 *, struct sk_buff___85 *);
	int (*local_out)(struct net___95 *, struct sock___65 *, struct sk_buff___85 *);
	struct neighbour___64 * (*neigh_lookup)(const struct dst_entry___64 *, struct sk_buff___85 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___64 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct xfrm_state___8;

struct lwtunnel_state___7;

struct dst_entry___64 {
	struct net_device___84 *dev;
	struct dst_ops___95 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state___8 *xfrm;
	int (*input)(struct sk_buff___85 *);
	int (*output)(struct net___95 *, struct sock___65 *, struct sk_buff___85 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___7 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

typedef rx_handler_result_t rx_handler_func_t___84(struct sk_buff___85 **);

struct net_device_ops___84;

struct ethtool_ops___84;

struct l3mdev_ops___64;

struct ndisc_ops___35;

struct xfrmdev_ops___84;

struct tlsdev_ops___84;

struct header_ops___84;

struct in_device___8;

struct inet6_dev___35;

struct netdev_rx_queue___84;

struct bpf_prog___74;

struct mini_Qdisc___76;

struct netdev_queue___84;

struct nf_hook_entries___9;

struct Qdisc___76;

struct rtnl_link_ops___76;

struct dcbnl_rtnl_ops___84;

struct net_device___84 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___84 *netdev_ops;
	const struct ethtool_ops___84 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___64 *l3mdev_ops;
	const struct ndisc_ops___35 *ndisc_ops;
	const struct xfrmdev_ops___84 *xfrmdev_ops;
	const struct tlsdev_ops___84 *tlsdev_ops;
	const struct header_ops___84 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___426 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device___8 *ip_ptr;
	struct inet6_dev___35 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___84 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___74 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___84 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___76 *miniq_ingress;
	struct netdev_queue___84 *ingress_queue;
	struct nf_hook_entries___9 *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___84 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___76 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___76 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___84 = 0,
		NETREG_REGISTERED___84 = 1,
		NETREG_UNREGISTERING___84 = 2,
		NETREG_UNREGISTERED___84 = 3,
		NETREG_RELEASED___84 = 4,
		NETREG_DUMMY___84 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___84 = 0,
		RTNL_LINK_INITIALIZING___84 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___84 *);
	struct netpoll_info *npinfo;
	possible_net_t___86 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___407 dev;
	const struct attribute_group___404 *sysfs_groups[4];
	const struct attribute_group___404 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___76 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___84 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide35;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct fib6_info___12;

struct rt6_info___12;

struct fib6_table___12;

struct netns_ipv6___95 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___84 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info___12 *fib6_null_entry;
	struct rt6_info___12 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___12 *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___95 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info___12 *ip6_prohibit_entry;
	struct rt6_info___12 *ip6_blk_hole_entry;
	struct fib6_table___12 *fib6_local_tbl;
	struct fib_rules_ops___64 *fib6_rules_ops;
	struct sock___65 **icmp_sk;
	struct sock___65 *ndisc_sk;
	struct sock___65 *tcp_sk;
	struct sock___65 *igmp_sk;
	struct sock___65 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___64 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___65 *notifier_ops;
	struct fib_notifier_ops___65 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___65 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___65 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf___10 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_queue_handler *queue_handler;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header *nf_log_dir_header;
	struct nf_hook_entries___9 *hooks_ipv4[5];
	struct nf_hook_entries___9 *hooks_ipv6[5];
	struct nf_hook_entries___9 *hooks_arp[3];
	struct nf_hook_entries___9 *hooks_bridge[5];
	bool defrag_ipv4;
	bool defrag_ipv6;
};

struct netns_nf_frag___84 {
	struct netns_frags___84 frags;
};

struct netns_xfrm___95 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___65 *nlsk;
	struct sock___65 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___95 xfrm4_dst_ops;
	struct dst_ops___95 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct net___95 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___304 *user_ns;
	struct ucounts___304 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___29 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___65 *rtnl;
	struct sock___65 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___84 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___84 ipv4;
	struct netns_ipv6___95 ipv6;
	struct netns_sctp___65 sctp;
	struct netns_nf___10 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___84 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___65 *nfnl;
	struct sock___65 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___95 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___65 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___74 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neigh_table___64;

struct neigh_parms___64;

struct neigh_ops___64;

struct neighbour___64 {
	struct neighbour___64 *next;
	struct neigh_table___64 *tbl;
	struct neigh_parms___64 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___84 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___64 *, struct sk_buff___85 *);
	const struct neigh_ops___64 *ops;
	struct callback_head rcu;
	struct net_device___84 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct fib6_nh___12 {
	struct in6_addr nh_gw;
	struct net_device___84 *nh_dev;
	struct lwtunnel_state___7 *nh_lwtstate;
	unsigned int nh_flags;
	atomic_t nh_upper_bound;
	int nh_weight;
};

struct fib6_node___12;

struct fib6_info___12 {
	struct fib6_table___12 *fib6_table;
	struct fib6_info___12 *fib6_next;
	struct fib6_node___12 *fib6_node;
	struct list_head fib6_siblings;
	unsigned int fib6_nsiblings;
	atomic_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	struct rt6_info___12 **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
	long unsigned int last_probe;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 exception_bucket_flushed: 1;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 dst_host: 1;
	u8 fib6_destroying: 1;
	u8 unused: 2;
	struct fib6_nh___12 fib6_nh;
	struct callback_head rcu;
};

struct rt6_info___12 {
	struct dst_entry___64 dst;
	struct fib6_info___12 *from;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___35 *rt6i_idev;
	u32 rt6i_flags;
	struct rt6key rt6i_prefsrc;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct fib6_node___12 {
	struct fib6_node___12 *parent;
	struct fib6_node___12 *left;
	struct fib6_node___12 *right;
	struct fib6_info___12 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info___12 *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table___12 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node___12 tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

struct nf_hook_state___9;

typedef unsigned int nf_hookfn___9(void *, struct sk_buff___85 *, const struct nf_hook_state___9 *);

struct nf_hook_entry___9 {
	nf_hookfn___9 *hook;
	void *priv;
};

struct nf_hook_entries___9 {
	u16 num_hook_entries;
	struct nf_hook_entry___9 hooks[0];
};

struct socket_wq___65 {
	wait_queue_head_t wait;
	struct fasync_struct___439 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___65;

struct socket___66 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___65 *wq;
	struct file___439 *file;
	struct sock___65 *sk;
	const struct proto_ops___65 *ops;
};

typedef int (*sk_read_actor_t___64)(read_descriptor_t *, struct sk_buff___85 *, unsigned int, size_t);

struct proto_ops___65 {
	int family;
	struct module___366 *owner;
	int (*release)(struct socket___66 *);
	int (*bind)(struct socket___66 *, struct sockaddr *, int);
	int (*connect)(struct socket___66 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___66 *, struct socket___66 *);
	int (*accept)(struct socket___66 *, struct socket___66 *, int, bool);
	int (*getname)(struct socket___66 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___439 *, struct socket___66 *, struct poll_table_struct___278 *);
	int (*ioctl)(struct socket___66 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___66 *, int);
	int (*shutdown)(struct socket___66 *, int);
	int (*setsockopt)(struct socket___66 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___66 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___66 *, struct msghdr___67 *, size_t);
	int (*recvmsg)(struct socket___66 *, struct msghdr___67 *, size_t, int);
	int (*mmap)(struct file___439 *, struct socket___66 *, struct vm_area_struct___440 *);
	ssize_t (*sendpage)(struct socket___66 *, struct page___440 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___66 *, loff_t *, struct pipe_inode_info___120 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___65 *, int);
	int (*peek_len)(struct socket___66 *);
	int (*read_sock)(struct sock___65 *, read_descriptor_t *, sk_read_actor_t___64);
	int (*sendpage_locked)(struct sock___65 *, struct page___440 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___65 *, struct msghdr___67 *, size_t);
	int (*set_rcvlowat)(struct sock___65 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct dev_pm_ops___407 {
	int (*prepare)(struct device___407 *);
	void (*complete)(struct device___407 *);
	int (*suspend)(struct device___407 *);
	int (*resume)(struct device___407 *);
	int (*freeze)(struct device___407 *);
	int (*thaw)(struct device___407 *);
	int (*poweroff)(struct device___407 *);
	int (*restore)(struct device___407 *);
	int (*suspend_late)(struct device___407 *);
	int (*resume_early)(struct device___407 *);
	int (*freeze_late)(struct device___407 *);
	int (*thaw_early)(struct device___407 *);
	int (*poweroff_late)(struct device___407 *);
	int (*restore_early)(struct device___407 *);
	int (*suspend_noirq)(struct device___407 *);
	int (*resume_noirq)(struct device___407 *);
	int (*freeze_noirq)(struct device___407 *);
	int (*thaw_noirq)(struct device___407 *);
	int (*poweroff_noirq)(struct device___407 *);
	int (*restore_noirq)(struct device___407 *);
	int (*runtime_suspend)(struct device___407 *);
	int (*runtime_resume)(struct device___407 *);
	int (*runtime_idle)(struct device___407 *);
};

struct dev_pm_domain___407 {
	struct dev_pm_ops___407 ops;
	void (*detach)(struct device___407 *, bool);
	int (*activate)(struct device___407 *);
	void (*sync)(struct device___407 *);
	void (*dismiss)(struct device___407 *);
};

struct bus_type___407 {
	const char *name;
	const char *dev_name;
	struct device___407 *dev_root;
	const struct attribute_group___404 **bus_groups;
	const struct attribute_group___404 **dev_groups;
	const struct attribute_group___404 **drv_groups;
	int (*match)(struct device___407 *, struct device_driver___407 *);
	int (*uevent)(struct device___407 *, struct kobj_uevent_env *);
	int (*probe)(struct device___407 *);
	int (*remove)(struct device___407 *);
	void (*shutdown)(struct device___407 *);
	int (*online)(struct device___407 *);
	int (*offline)(struct device___407 *);
	int (*suspend)(struct device___407 *, pm_message_t);
	int (*resume)(struct device___407 *);
	int (*num_vf)(struct device___407 *);
	int (*dma_configure)(struct device___407 *);
	const struct dev_pm_ops___407 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___407 {
	const char *name;
	struct bus_type___407 *bus;
	struct module___366 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___407 *);
	int (*remove)(struct device___407 *);
	void (*shutdown)(struct device___407 *);
	int (*suspend)(struct device___407 *, pm_message_t);
	int (*resume)(struct device___407 *);
	const struct attribute_group___404 **groups;
	const struct dev_pm_ops___407 *pm;
	void (*coredump)(struct device___407 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___407 {
	const char *name;
	const struct attribute_group___404 **groups;
	int (*uevent)(struct device___407 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___407 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___407 *);
	const struct dev_pm_ops___407 *pm;
};

struct class___407 {
	const char *name;
	struct module___366 *owner;
	const struct attribute_group___404 **class_groups;
	const struct attribute_group___404 **dev_groups;
	struct kobject___427 *dev_kobj;
	int (*dev_uevent)(struct device___407 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___407 *, umode_t *);
	void (*class_release)(struct class___407 *);
	void (*dev_release)(struct device___407 *);
	int (*shutdown_pre)(struct device___407 *);
	const struct kobj_ns_type_operations___64 *ns_type;
	const void * (*namespace)(struct device___407 *);
	const struct dev_pm_ops___407 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___179 {
	void * (*alloc)(struct device___407 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___407 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___407 *, struct vm_area_struct___440 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___407 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___407 *, struct page___440 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___407 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___407 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___407 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___407 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___407 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___407 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___407 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___407 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___407 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___407 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___407 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___407 *, u64);
	u64 (*get_required_mask)(struct device___407 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___327;

struct fwnode_handle___327 {
	struct fwnode_handle___327 *secondary;
	const struct fwnode_operations___327 *ops;
};

struct fwnode_reference_args___327;

struct fwnode_endpoint___327;

struct fwnode_operations___327 {
	struct fwnode_handle___327 * (*get)(struct fwnode_handle___327 *);
	void (*put)(struct fwnode_handle___327 *);
	bool (*device_is_available)(const struct fwnode_handle___327 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___327 *, const struct device___407 *);
	bool (*property_present)(const struct fwnode_handle___327 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___327 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___327 *, const char *, const char **, size_t);
	struct fwnode_handle___327 * (*get_parent)(const struct fwnode_handle___327 *);
	struct fwnode_handle___327 * (*get_next_child_node)(const struct fwnode_handle___327 *, struct fwnode_handle___327 *);
	struct fwnode_handle___327 * (*get_named_child_node)(const struct fwnode_handle___327 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___327 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___327 *);
	struct fwnode_handle___327 * (*graph_get_next_endpoint)(const struct fwnode_handle___327 *, struct fwnode_handle___327 *);
	struct fwnode_handle___327 * (*graph_get_remote_endpoint)(const struct fwnode_handle___327 *);
	struct fwnode_handle___327 * (*graph_get_port_parent)(struct fwnode_handle___327 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___327 *, struct fwnode_endpoint___327 *);
};

struct fwnode_endpoint___327 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___327 *local_fwnode;
};

struct fwnode_reference_args___327 {
	struct fwnode_handle___327 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___120;

struct pipe_buffer___120 {
	struct page___440 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___120 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___120 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___120 *, struct pipe_buffer___120 *);
	void (*release)(struct pipe_inode_info___120 *, struct pipe_buffer___120 *);
	int (*steal)(struct pipe_inode_info___120 *, struct pipe_buffer___120 *);
	union {
		bool (*get)(struct pipe_inode_info___120 *, struct pipe_buffer___120 *);
		struct {
			void (*get)(struct pipe_inode_info___120 *, struct pipe_buffer___120 *);
		} __UNIQUE_ID_rh_kabi_hide21;
		union {		};
	};
};

struct nf_bridge_info___84 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___84 = 0,
		BRNF_PROTO_8021Q___84 = 1,
		BRNF_PROTO_PPPOE___84 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___84 *physindev;
	struct net_device___84 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

struct sec_path___8 {
	refcount_t refcnt;
	int len;
	int olen;
	struct xfrm_state___8 *xvec[6];
	struct xfrm_offload ovec[1];
};

struct ucounts___304 {
	struct hlist_node node;
	struct user_namespace___304 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_prog_aux___77;

struct bpf_prog___74 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___77 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

typedef int (*key_restrict_link_func_t___408)(struct key___407 *, const struct key_type *, const union key_payload *, struct key___407 *);

struct key_restriction___407;

struct key___407 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___441 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___407 *restrict_link;
};

struct key_restriction___407 {
	key_restrict_link_func_t___408 check;
	struct key___407 *key;
	struct key_type *keytype;
};

struct seq_operations___378 {
	void * (*start)(struct seq_file___378 *, loff_t *);
	void (*stop)(struct seq_file___378 *, void *);
	void * (*next)(struct seq_file___378 *, void *, loff_t *);
	int (*show)(struct seq_file___378 *, void *);
};

struct pernet_operations___85 {
	struct list_head list;
	int (*init)(struct net___95 *);
	void (*exit)(struct net___95 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct ethtool_ops___84 {
	int (*get_settings)(struct net_device___84 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___84 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___84 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___84 *);
	void (*get_regs)(struct net_device___84 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___84 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___84 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___84 *);
	void (*set_msglevel)(struct net_device___84 *, u32);
	int (*nway_reset)(struct net_device___84 *);
	u32 (*get_link)(struct net_device___84 *);
	int (*get_eeprom_len)(struct net_device___84 *);
	int (*get_eeprom)(struct net_device___84 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___84 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___84 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___84 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___84 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___84 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___84 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___84 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___84 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___84 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___84 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___84 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___84 *);
	void (*complete)(struct net_device___84 *);
	u32 (*get_priv_flags)(struct net_device___84 *);
	int (*set_priv_flags)(struct net_device___84 *, u32);
	int (*get_sset_count)(struct net_device___84 *, int);
	int (*get_rxnfc)(struct net_device___84 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___84 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___84 *, struct ethtool_flash *);
	int (*reset)(struct net_device___84 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___84 *);
	u32 (*get_rxfh_indir_size)(struct net_device___84 *);
	int (*get_rxfh)(struct net_device___84 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___84 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___84 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___84 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___84 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___84 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___84 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___84 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___84 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___84 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___84 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___84 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___84 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___84 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___84 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___84 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___84 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___84 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___84 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___84 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___84 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___84 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	int (*get_fecparam)(struct net_device___84 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___84 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___84 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___84 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___84 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct dcbnl_rtnl_ops___84 {
	int (*ieee_getets)(struct net_device___84 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___84 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___84 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___84 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___84 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___84 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___84 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___84 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___84 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___84 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___84 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___84 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___84 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___84 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___84 *);
	u8 (*setstate)(struct net_device___84 *, u8);
	void (*getpermhwaddr)(struct net_device___84 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___84 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___84 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___84 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___84 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___84 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___84 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___84 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___84 *, int, u8 *);
	void (*setpfccfg)(struct net_device___84 *, int, u8);
	void (*getpfccfg)(struct net_device___84 *, int, u8 *);
	u8 (*setall)(struct net_device___84 *);
	u8 (*getcap)(struct net_device___84 *, int, u8 *);
	int (*getnumtcs)(struct net_device___84 *, int, u8 *);
	int (*setnumtcs)(struct net_device___84 *, int, u8);
	u8 (*getpfcstate)(struct net_device___84 *);
	void (*setpfcstate)(struct net_device___84 *, u8);
	void (*getbcncfg)(struct net_device___84 *, int, u32 *);
	void (*setbcncfg)(struct net_device___84 *, int, u32);
	void (*getbcnrp)(struct net_device___84 *, int, u8 *);
	void (*setbcnrp)(struct net_device___84 *, int, u8);
	int (*setapp)(struct net_device___84 *, u8, u16, u8);
	int (*getapp)(struct net_device___84 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___84 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___84 *, int, u8);
	u8 (*getdcbx)(struct net_device___84 *);
	u8 (*setdcbx)(struct net_device___84 *, u8);
	int (*peer_getappinfo)(struct net_device___84 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___84 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___84 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___84 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___84 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___84 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___288 {
	refcount_t count;
	struct ns_common___29 ns;
	struct user_namespace___304 *user_ns;
	struct ucounts___304 *ucounts;
	struct css_set___288 *root_cset;
};

struct bpf_map___289;

struct bpf_map_ops___288 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___289 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___289 *, struct file___439 *);
	void (*map_free)(struct bpf_map___289 *);
	int (*map_get_next_key)(struct bpf_map___289 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___289 *);
	void * (*map_lookup_elem)(struct bpf_map___289 *, void *);
	int (*map_update_elem)(struct bpf_map___289 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___289 *, void *);
	int (*map_push_elem)(struct bpf_map___289 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___289 *, void *);
	int (*map_peek_elem)(struct bpf_map___289 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___289 *, struct file___439 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___289 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___289 *, void *, struct seq_file___378 *);
	int (*map_check_btf)(const struct bpf_map___289 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___289 {
	const struct bpf_map_ops___288 *ops;
	struct bpf_map___289 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___407 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___84;

struct bpf_map_dev_ops___84 {
	int (*map_get_next_key)(struct bpf_offloaded_map___84 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___84 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___84 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___84 *, void *);
};

struct bpf_offloaded_map___84 {
	struct bpf_map___289 map;
	struct net_device___84 *netdev;
	const struct bpf_map_dev_ops___84 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___74 {
	int (*test_run)(struct bpf_prog___74 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___74 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___74 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___74 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___74 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___74 *, u32 *);
};

struct bpf_prog_offload_ops___74 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___74 *);
	int (*translate)(struct bpf_prog___74 *);
	void (*destroy)(struct bpf_prog___74 *);
};

struct bpf_prog_offload___74 {
	struct bpf_prog___74 *prog;
	struct net_device___84 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___74 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___77 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___74 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___74 *ops;
	struct bpf_map___289 **used_maps;
	struct bpf_prog___74 *prog;
	struct user_struct___407 *user;
	u64 load_time;
	struct bpf_map___289 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___74 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___74 {
	struct bpf_prog___74 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___74 {
	struct callback_head rcu;
	struct bpf_prog_array_item___74 items[0];
};

struct cgroup_bpf___74 {
	struct bpf_prog_array___74 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___74 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___289;

typedef void (*kthread_work_func_t___289)(struct kthread_work___289 *);

struct kthread_worker___289;

struct kthread_work___289 {
	struct list_head node;
	kthread_work_func_t___289 func;
	struct kthread_worker___289 *worker;
	int canceling;
};

struct kthread_worker___289 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___441 *task;
	struct kthread_work___289 *current_work;
};

struct kthread_delayed_work___288 {
	struct kthread_work___289 work;
	struct timer_list timer;
};

struct psi_group___288 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___289 *poll_kworker;
	struct kthread_delayed_work___288 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___288;

struct cgroup_rstat_cpu___288;

struct cgroup___288 {
	struct cgroup_subsys_state___288 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___434 *kn;
	struct cgroup_file___288 procs_file;
	struct cgroup_file___288 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___288 *subsys[13];
	struct cgroup_root___288 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___288 *dom_cgrp;
	struct cgroup_rstat_cpu___288 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___74 bpf;
	atomic_t congestion_count;
	struct cgroup___288 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___288 psi;
	int ancestor_ids[0];
};

struct cftype___288;

struct cgroup_subsys___288 {
	struct cgroup_subsys_state___288 * (*css_alloc)(struct cgroup_subsys_state___288 *);
	int (*css_online)(struct cgroup_subsys_state___288 *);
	void (*css_offline)(struct cgroup_subsys_state___288 *);
	void (*css_released)(struct cgroup_subsys_state___288 *);
	void (*css_free)(struct cgroup_subsys_state___288 *);
	void (*css_reset)(struct cgroup_subsys_state___288 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___288 *, int);
	int (*css_extra_stat_show)(struct seq_file___378 *, struct cgroup_subsys_state___288 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___441 *);
	void (*cancel_fork)(struct task_struct___441 *);
	void (*fork)(struct task_struct___441 *);
	void (*exit)(struct task_struct___441 *);
	void (*free)(struct task_struct___441 *);
	void (*bind)(struct cgroup_subsys_state___288 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___288 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___288 *dfl_cftypes;
	struct cftype___288 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___288 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___288 *updated_children;
	struct cgroup___288 *updated_next;
};

struct cgroup_root___288 {
	struct kernfs_root___433 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___288 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___288 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___288 *ss;
	struct list_head node;
	struct kernfs_ops___433 *kf_ops;
	int (*open)(struct kernfs_open_file___433 *);
	void (*release)(struct kernfs_open_file___433 *);
	u64 (*read_u64)(struct cgroup_subsys_state___288 *, struct cftype___288 *);
	s64 (*read_s64)(struct cgroup_subsys_state___288 *, struct cftype___288 *);
	int (*seq_show)(struct seq_file___378 *, void *);
	void * (*seq_start)(struct seq_file___378 *, loff_t *);
	void * (*seq_next)(struct seq_file___378 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___378 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___288 *, struct cftype___288 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___288 *, struct cftype___288 *, s64);
	ssize_t (*write)(struct kernfs_open_file___433 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___433 *, struct poll_table_struct___278 *);
};

struct xdp_rxq_info___84 {
	struct net_device___84 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___84 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___84 *dev_rx;
};

struct netlink_skb_parms___14 {
	struct scm_creds creds;
	__u32 portid;
	__u32 dst_group;
	__u32 flags;
	struct sock___65 *sk;
	bool nsid_is_set;
	int nsid;
};

struct netlink_callback___86 {
	struct sk_buff___85 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___86 *);
	int (*dump)(struct sk_buff___85 *, struct netlink_callback___86 *);
	int (*done)(struct netlink_callback___86 *);
	void *data;
	struct module___366 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___84 {
	int (*create)(struct sk_buff___85 *, struct net_device___84 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___85 *, unsigned char *);
	int (*cache)(const struct neighbour___64 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___84 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___84 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___84 *, int);
	int poll_owner;
	struct net_device___84 *dev;
	struct sk_buff___85 *gro_list;
	struct sk_buff___85 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___84 {
	struct net_device___84 *dev;
	struct Qdisc___76 *qdisc;
	struct Qdisc___76 *qdisc_sleeping;
	struct kobject___427 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___84 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem___3 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___76 {
	struct sk_buff___85 *head;
	struct sk_buff___85 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___76;

struct Qdisc___76 {
	int (*enqueue)(struct sk_buff___85 *, struct Qdisc___76 *, struct sk_buff___85 **);
	struct sk_buff___85 * (*dequeue)(struct Qdisc___76 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___76 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___84 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___84 gso_skb;
	struct qdisc_skb_head___76 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___76 *next_sched;
	struct sk_buff_head___84 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___84 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___427 kobj;
	struct net_device___84 *dev;
	long: 64;
	struct xdp_rxq_info___84 xdp_rxq;
	union {
		struct xdp_umem___3 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___84)(struct net_device___84 *, struct sk_buff___85 *, struct net_device___84 *);

struct netdev_bpf___84 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___74 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___74 *prog;
			const struct bpf_prog_offload_ops___74 *ops;
		} verifier;
		struct {
			struct bpf_prog___74 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___84 *offmap;
		};
		struct {
			struct xdp_umem___3 *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___84 {
	int (*xdo_dev_state_add)(struct xfrm_state___8 *);
	void (*xdo_dev_state_delete)(struct xfrm_state___8 *);
	void (*xdo_dev_state_free)(struct xfrm_state___8 *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___85 *, struct xfrm_state___8 *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state___8 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct xfrm_state_offload___8 {
	struct net_device___84 *dev;
	long unsigned int offload_handle;
	unsigned int num_exthdrs;
	u8 flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct xfrm_replay___8;

struct xfrm_type___8;

struct xfrm_mode___8;

struct xfrm_type_offload___8;

struct xfrm_state___8 {
	possible_net_t___86 xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	refcount_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
		u32 output_mark;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	const char *geniv;
	struct xfrm_encap_tmpl *encap;
	xfrm_address_t *coaddr;
	struct xfrm_state___8 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	const struct xfrm_replay___8 *repl;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct tasklet_hrtimer mtimer;
	struct xfrm_state_offload___8 xso;
	long int saved_tmo;
	long unsigned int lastused;
	struct page_frag___440 xfrag;
	const struct xfrm_type___8 *type;
	struct xfrm_mode___8 *inner_mode;
	struct xfrm_mode___8 *inner_mode_iaf;
	struct xfrm_mode___8 *outer_mode;
	const struct xfrm_type_offload___8 *type_offload;
	struct xfrm_sec_ctx___2 *security;
	void *data;
	u32 output_mark_mask;
	u32 if_id;
};

struct tlsdev_ops___84 {
	int (*tls_dev_add)(struct net_device___84 *, struct sock___65 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___84 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___84 *, struct sock___65 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___84 {
	int (*ndo_init)(struct net_device___84 *);
	void (*ndo_uninit)(struct net_device___84 *);
	int (*ndo_open)(struct net_device___84 *);
	int (*ndo_stop)(struct net_device___84 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___85 *, struct net_device___84 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___85 *, struct net_device___84 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___84 *, struct sk_buff___85 *, struct net_device___84 *, select_queue_fallback_t___84);
	void (*ndo_change_rx_flags)(struct net_device___84 *, int);
	void (*ndo_set_rx_mode)(struct net_device___84 *);
	int (*ndo_set_mac_address)(struct net_device___84 *, void *);
	int (*ndo_validate_addr)(struct net_device___84 *);
	int (*ndo_do_ioctl)(struct net_device___84 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___84 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___84 *, int);
	int (*ndo_neigh_setup)(struct net_device___84 *, struct neigh_parms___64 *);
	void (*ndo_tx_timeout)(struct net_device___84 *);
	void (*ndo_get_stats64)(struct net_device___84 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___84 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___84 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___84 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___84 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___84 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___84 *);
	int (*ndo_netpoll_setup)(struct net_device___84 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___84 *);
	int (*ndo_set_vf_mac)(struct net_device___84 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___84 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___84 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___84 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___84 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___84 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___84 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___84 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___84 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___84 *, int, struct sk_buff___85 *);
	int (*ndo_set_vf_guid)(struct net_device___84 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___84 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___84 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___84 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___84 *, const struct sk_buff___85 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___84 *, struct net_device___84 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___84 *, struct net_device___84 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___84 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___84 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___84 *, struct neighbour___64 *);
	void (*ndo_neigh_destroy)(struct net_device___84 *, struct neighbour___64 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___84 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___84 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___84 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___85 *, struct netlink_callback___86 *, struct net_device___84 *, struct net_device___84 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___84 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___84 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___85 *, u32, u32, struct net_device___84 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___84 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___84 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___84 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___84 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___84 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___84 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___84 *, struct net_device___84 *);
	void (*ndo_dfwd_del_station)(struct net_device___84 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___84 *);
	int (*ndo_set_tx_maxrate)(struct net_device___84 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___84 *);
	int (*ndo_change_proto_down)(struct net_device___84 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___84 *, struct sk_buff___85 *);
	void (*ndo_set_rx_headroom)(struct net_device___84 *, int);
	int (*ndo_bpf)(struct net_device___84 *, struct netdev_bpf___84 *);
	int (*ndo_xdp_xmit)(struct net_device___84 *, int, struct xdp_frame___84 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___84 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___84 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___64 {
	possible_net_t___86 net;
	struct net_device___84 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___64 *);
	void (*neigh_cleanup)(struct neighbour___64 *);
	struct neigh_table___64 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___64 {
	u32 (*l3mdev_fib_table)(const struct net_device___84 *);
	struct sk_buff___85 * (*l3mdev_l3_rcv)(struct net_device___84 *, struct sk_buff___85 *, u16);
	struct sk_buff___85 * (*l3mdev_l3_out)(struct net_device___84 *, struct sock___65 *, struct sk_buff___85 *, u16);
	struct dst_entry___64 * (*l3mdev_link_scope_lookup)(const struct net_device___84 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct ndisc_ops___35 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___84 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___84 *, struct neighbour___64 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___84 *, u8, struct neighbour___64 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___84 *, struct sk_buff___85 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___95 *, struct net_device___84 *, const struct prefix_info *, struct inet6_dev___35 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct in_ifaddr___8;

struct in_device___8 {
	struct net_device___84 *dev;
	refcount_t refcnt;
	int dead;
	struct in_ifaddr___8 *ifa_list;
	struct ip_mc_list *mc_list;
	struct ip_mc_list **mc_hash;
	int mc_count;
	spinlock_t mc_tomb_lock;
	struct ip_mc_list *mc_tomb;
	long unsigned int mr_v1_seen;
	long unsigned int mr_v2_seen;
	long unsigned int mr_maxdelay;
	long unsigned int mr_qi;
	long unsigned int mr_qri;
	unsigned char mr_qrv;
	unsigned char mr_gq_running;
	unsigned char mr_ifc_count;
	struct timer_list mr_gq_timer;
	struct timer_list mr_ifc_timer;
	struct neigh_parms___64 *arp_parms;
	struct ipv4_devconf cnf;
	struct callback_head callback_head;
};

struct ifmcaddr6___35;

struct ifacaddr6___12;

struct inet6_dev___35 {
	struct net_device___84 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___35 *mc_list;
	struct ifmcaddr6___35 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___12 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	u8 rndid[8];
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___64 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
};

struct tcf_proto___76;

struct mini_Qdisc___76 {
	struct tcf_proto___76 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___76 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___84 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___95 *, struct net_device___84 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___84 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___84 *, struct list_head *);
	size_t (*get_size)(const struct net_device___84 *);
	int (*fill_info)(struct sk_buff___85 *, const struct net_device___84 *);
	size_t (*get_xstats_size)(const struct net_device___84 *);
	int (*fill_xstats)(struct sk_buff___85 *, const struct net_device___84 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___84 *, struct net_device___84 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___84 *, const struct net_device___84 *);
	int (*fill_slave_info)(struct sk_buff___85 *, const struct net_device___84 *, const struct net_device___84 *);
	struct net___95 * (*get_link_net)(const struct net_device___84 *);
	size_t (*get_linkxstats_size)(const struct net_device___84 *, int);
	int (*fill_linkxstats)(struct sk_buff___85 *, const struct net_device___84 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct offload_callbacks___9 {
	struct sk_buff___85 * (*gso_segment)(struct sk_buff___85 *, netdev_features_t);
	struct sk_buff___85 ** (*gro_receive)(struct sk_buff___85 **, struct sk_buff___85 *);
	int (*gro_complete)(struct sk_buff___85 *, int);
};

struct softnet_data___84 {
	struct list_head poll_list;
	struct sk_buff_head___84 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___84 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___76 *output_queue;
	struct Qdisc___76 **output_queue_tailp;
	struct sk_buff___85 *completion_queue;
	struct sk_buff_head___84 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___84 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___84 input_pkt_queue;
	struct napi_struct___84 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rtmsg {
	unsigned char rtm_family;
	unsigned char rtm_dst_len;
	unsigned char rtm_src_len;
	unsigned char rtm_tos;
	unsigned char rtm_table;
	unsigned char rtm_protocol;
	unsigned char rtm_scope;
	unsigned char rtm_type;
	unsigned int rtm_flags;
};

struct in_ifaddr___8 {
	struct hlist_node hash;
	struct in_ifaddr___8 *ifa_next;
	struct in_device___8 *ifa_dev;
	struct callback_head callback_head;
	__be32 ifa_local;
	__be32 ifa_address;
	__be32 ifa_mask;
	__u32 ifa_rt_priority;
	__be32 ifa_broadcast;
	unsigned char ifa_scope;
	unsigned char ifa_prefixlen;
	__u32 ifa_flags;
	char ifa_label[16];
	__u32 ifa_valid_lft;
	__u32 ifa_preferred_lft;
	long unsigned int ifa_cstamp;
	long unsigned int ifa_tstamp;
};

struct ip_sf_list;

struct ip_mc_list {
	struct in_device___8 *interface;
	__be32 multiaddr;
	unsigned int sfmode;
	struct ip_sf_list *sources;
	struct ip_sf_list *tomb;
	long unsigned int sfcount[2];
	union {
		struct ip_mc_list *next;
		struct ip_mc_list *next_rcu;
	};
	struct ip_mc_list *next_hash;
	struct timer_list timer;
	int users;
	refcount_t refcnt;
	spinlock_t lock;
	char tm_running;
	char reporter;
	char unsolicit_count;
	char loaded;
	unsigned char gsquery;
	unsigned char crcount;
	struct callback_head rcu;
};

struct ip_sf_socklist {
	unsigned int sl_max;
	unsigned int sl_count;
	struct callback_head rcu;
	__be32 sl_addr[0];
};

struct ip_mc_socklist {
	struct ip_mc_socklist *next_rcu;
	struct ip_mreqn multi;
	unsigned int sfmode;
	struct ip_sf_socklist *sflist;
	struct callback_head rcu;
};

struct ip_sf_list {
	struct ip_sf_list *sf_next;
	__be32 sf_inaddr;
	long unsigned int sf_count[2];
	unsigned char sf_gsresp;
	unsigned char sf_oldin;
	unsigned char sf_crcount;
};

struct fib_rule___64 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___64 *ctarget;
	struct net___95 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___64 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___64 *rule;
	u32 table;
	int flags;
};

struct bdi_writeback_congested___229 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___229 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___229 {
	struct bio___229 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___231 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___231 bip_inline_vecs[0];
};

struct bio_set___229 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___229 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___172 {
	struct mem_cgroup___172 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___172 {
	struct lruvec___440 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___172 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___172 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct gnet_dump___76 {
	spinlock_t *lock;
	struct sk_buff___85 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___76;

struct Qdisc_ops___76 {
	struct Qdisc_ops___76 *next;
	const struct Qdisc_class_ops___76 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___85 *, struct Qdisc___76 *, struct sk_buff___85 **);
	struct sk_buff___85 * (*dequeue)(struct Qdisc___76 *);
	struct sk_buff___85 * (*peek)(struct Qdisc___76 *);
	int (*init)(struct Qdisc___76 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___76 *);
	void (*destroy)(struct Qdisc___76 *);
	int (*change)(struct Qdisc___76 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___76 *);
	int (*change_tx_queue_len)(struct Qdisc___76 *, unsigned int);
	int (*dump)(struct Qdisc___76 *, struct sk_buff___85 *);
	int (*dump_stats)(struct Qdisc___76 *, struct gnet_dump___76 *);
	void (*ingress_block_set)(struct Qdisc___76 *, u32);
	void (*egress_block_set)(struct Qdisc___76 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___76 *);
	u32 (*egress_block_get)(struct Qdisc___76 *);
	struct module___366 *owner;
};

struct tcf_block___76;

struct Qdisc_class_ops___76 {
	unsigned int flags;
	struct netdev_queue___84 * (*select_queue)(struct Qdisc___76 *, struct tcmsg *);
	int (*graft)(struct Qdisc___76 *, long unsigned int, struct Qdisc___76 *, struct Qdisc___76 **, struct netlink_ext_ack *);
	struct Qdisc___76 * (*leaf)(struct Qdisc___76 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___76 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___76 *, u32);
	int (*change)(struct Qdisc___76 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___76 *, long unsigned int);
	void (*walk)(struct Qdisc___76 *, struct qdisc_walker *);
	struct tcf_block___76 * (*tcf_block)(struct Qdisc___76 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___76 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___76 *, long unsigned int);
	int (*dump)(struct Qdisc___76 *, long unsigned int, struct sk_buff___85 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___76 *, long unsigned int, struct gnet_dump___76 *);
};

struct tcf_chain___76;

struct tcf_block___76 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___95 *net;
	struct Qdisc___76 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___76 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___76;

struct tcf_proto_ops___76;

struct tcf_proto___76 {
	struct tcf_proto___76 *next;
	void *root;
	int (*classify)(struct sk_buff___85 *, const struct tcf_proto___76 *, struct tcf_result___76 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___76 *ops;
	struct tcf_chain___76 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___76 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___76 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___76 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___85 *, const struct tcf_proto___76 *, struct tcf_result___76 *);
	int (*init)(struct tcf_proto___76 *);
	void (*destroy)(struct tcf_proto___76 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___76 *, u32);
	void (*put)(struct tcf_proto___76 *, void *);
	int (*change)(struct net___95 *, struct sk_buff___85 *, struct tcf_proto___76 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___76 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___76 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___76 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___95 *, struct tcf_chain___76 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___95 *, struct tcf_proto___76 *, void *, struct sk_buff___85 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___85 *, struct net___95 *, void *);
	struct module___366 *owner;
	int flags;
};

struct tcf_chain___76 {
	struct mutex filter_chain_lock;
	struct tcf_proto___76 *filter_chain;
	struct list_head list;
	struct tcf_block___76 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___76 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___64 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___74 *prog;
};

struct bpf_redirect_info___74 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___289 *map;
	struct bpf_map___289 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___64;

struct neigh_hash_table___64;

struct neigh_table___64 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___84 *, __u32 *);
	bool (*key_eq)(const struct neighbour___64 *, const void *);
	int (*constructor)(struct neighbour___64 *);
	int (*pconstructor)(struct pneigh_entry___64 *);
	void (*pdestructor)(struct pneigh_entry___64 *);
	void (*proxy_redo)(struct sk_buff___85 *);
	char *id;
	struct neigh_parms___64 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___84 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___64 *nht;
	struct pneigh_entry___64 **phash_buckets;
};

struct neigh_ops___64 {
	int family;
	void (*solicit)(struct neighbour___64 *, struct sk_buff___85 *);
	void (*error_report)(struct neighbour___64 *, struct sk_buff___85 *);
	int (*output)(struct neighbour___64 *, struct sk_buff___85 *);
	int (*connected_output)(struct neighbour___64 *, struct sk_buff___85 *);
};

struct pneigh_entry___64 {
	struct pneigh_entry___64 *next;
	possible_net_t___86 net;
	struct net_device___84 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___64 {
	struct neighbour___64 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___7 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___95 *, struct sock___65 *, struct sk_buff___85 *);
	int (*orig_input)(struct sk_buff___85 *);
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	__u8 data[0];
};

struct request_sock_ops___47;

struct timewait_sock_ops___43;

struct proto___64 {
	void (*close)(struct sock___65 *, long int);
	int (*pre_connect)(struct sock___65 *, struct sockaddr *, int);
	int (*connect)(struct sock___65 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___65 *, int);
	struct sock___65 * (*accept)(struct sock___65 *, int, int *, bool);
	int (*ioctl)(struct sock___65 *, int, long unsigned int);
	int (*init)(struct sock___65 *);
	void (*destroy)(struct sock___65 *);
	void (*shutdown)(struct sock___65 *, int);
	int (*setsockopt)(struct sock___65 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___65 *, int, int, char *, int *);
	void (*keepalive)(struct sock___65 *, int);
	int (*sendmsg)(struct sock___65 *, struct msghdr___67 *, size_t);
	int (*recvmsg)(struct sock___65 *, struct msghdr___67 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___65 *, struct page___440 *, int, size_t, int);
	int (*bind)(struct sock___65 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___65 *, struct sk_buff___85 *);
	void (*release_cb)(struct sock___65 *);
	int (*hash)(struct sock___65 *);
	void (*unhash)(struct sock___65 *);
	void (*rehash)(struct sock___65 *);
	int (*get_port)(struct sock___65 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___65 *);
	bool (*stream_memory_read)(const struct sock___65 *);
	void (*enter_memory_pressure)(struct sock___65 *);
	void (*leave_memory_pressure)(struct sock___65 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___47 *rsk_prot;
	struct timewait_sock_ops___43 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___366 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___65 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct xfrm_policy_queue___8 {
	struct sk_buff_head___84 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___8 {
	possible_net_t___86 xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	refcount_t refcnt;
	struct timer_list timer;
	atomic_t genid;
	u32 priority;
	u32 index;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___8 polq;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx___2 *security;
	struct xfrm_tmpl xfrm_vec[6];
	struct callback_head rcu;
	u32 if_id;
};

struct request_sock___48;

struct request_sock_ops___47 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___65 *, struct request_sock___48 *);
	void (*send_ack)(const struct sock___65 *, struct sk_buff___85 *, struct request_sock___48 *);
	void (*send_reset)(const struct sock___65 *, struct sk_buff___85 *);
	void (*destructor)(struct request_sock___48 *);
	void (*syn_ack_timeout)(const struct request_sock___48 *);
};

struct timewait_sock_ops___43 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___65 *, struct sock___65 *, void *);
	void (*twsk_destructor)(struct sock___65 *);
};

struct request_sock___48 {
	struct sock_common___64 __req_common;
	struct request_sock___48 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___47 *rsk_ops;
	struct sock___65 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct inet_cork___8 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___64 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
	__u16 gso_size;
	u64 transmit_time;
};

struct inet_cork_full___8 {
	struct inet_cork___8 base;
	struct flowi fl;
};

struct ipv6_pinfo___8;

struct inet_sock___8 {
	struct sock___65 sk;
	struct ipv6_pinfo___8 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	__be16 inet_sport;
	__u16 inet_id;
	struct ip_options_rcu *inet_opt;
	int rx_dst_ifindex;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 bind_address_no_port: 1;
	__u8 defer_connect: 1;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___8 cork;
};

struct ipv6_fl_socklist___7;

struct ipv6_pinfo___8 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
			__u16 recvfragsize: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 repflow: 1;
	__u16 pmtudisc: 3;
	__u16 padding: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u16 autoflowlabel: 1;
	__u16 autoflowlabel_set: 1;
	__u8 min_hopcount;
	__u8 tclass;
	__be32 rcv_flowinfo;
	__u32 dst_cookie;
	__u32 rx_dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___7 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___85 *pktoptions;
	struct sk_buff___85 *rxpmtu;
	struct inet6_cork cork;
};

struct ip6_flowlabel___7;

struct ipv6_fl_socklist___7 {
	struct ipv6_fl_socklist___7 *next;
	struct ip6_flowlabel___7 *fl;
	struct callback_head rcu;
};

struct ifmcaddr6___35 {
	struct in6_addr mca_addr;
	struct inet6_dev___35 *idev;
	struct ifmcaddr6___35 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___12 {
	struct in6_addr aca_addr;
	struct fib6_info___12 *aca_rt;
	struct ifacaddr6___12 *aca_next;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct ip6_ra_chain___35 {
	struct ip6_ra_chain___35 *next;
	struct sock___65 *sk;
	int sel;
	void (*destructor)(struct sock___65 *);
};

struct ip6_flowlabel___7 {
	struct ip6_flowlabel___7 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___243 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___95 *fl_net;
};

struct ipv4_addr_key {
	__be32 addr;
	int vif;
};

struct inetpeer_addr {
	union {
		struct ipv4_addr_key a4;
		struct in6_addr a6;
		u32 key[4];
	};
	__u16 family;
};

struct inet_peer {
	struct rb_node rb_node;
	struct inetpeer_addr daddr;
	u32 metrics[17];
	u32 rate_tokens;
	u32 n_redirects;
	long unsigned int rate_last;
	union {
		struct {
			atomic_t rid;
		};
		struct callback_head rcu;
	};
	__u32 dtime;
	refcount_t refcnt;
};

struct rtable___6;

struct fib_nh_exception___3 {
	struct fib_nh_exception___3 *fnhe_next;
	int fnhe_genid;
	__be32 fnhe_daddr;
	u32 fnhe_pmtu;
	bool fnhe_mtu_locked;
	__be32 fnhe_gw;
	long unsigned int fnhe_expires;
	struct rtable___6 *fnhe_rth_input;
	struct rtable___6 *fnhe_rth_output;
	long unsigned int fnhe_stamp;
	struct callback_head rcu;
};

struct rtable___6 {
	struct dst_entry___64 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	__be32 rt_gateway;
	u32 rt_mtu_locked: 1;
	u32 rt_pmtu: 31;
	struct list_head rt_uncached;
	struct uncached_list *rt_uncached_list;
};

struct fnhe_hash_bucket___3 {
	struct fib_nh_exception___3 *chain;
};

struct fib_info___3;

struct fib_nh___3 {
	struct net_device___84 *nh_dev;
	struct hlist_node nh_hash;
	struct fib_info___3 *nh_parent;
	unsigned int nh_flags;
	unsigned char nh_scope;
	int nh_weight;
	atomic_t nh_upper_bound;
	__u32 nh_tclassid;
	int nh_oif;
	__be32 nh_gw;
	__be32 nh_saddr;
	int nh_saddr_genid;
	struct rtable___6 **nh_pcpu_rth_output;
	struct rtable___6 *nh_rth_input;
	struct fnhe_hash_bucket___3 *nh_exceptions;
	struct lwtunnel_state___7 *nh_lwtstate;
};

struct fib_info___3 {
	struct hlist_node fib_hash;
	struct hlist_node fib_lhash;
	struct net___95 *fib_net;
	int fib_treeref;
	refcount_t fib_clntref;
	unsigned int fib_flags;
	unsigned char fib_dead;
	unsigned char fib_protocol;
	unsigned char fib_scope;
	unsigned char fib_type;
	__be32 fib_prefsrc;
	u32 fib_tb_id;
	u32 fib_priority;
	struct dst_metrics *fib_metrics;
	int fib_nhs;
	struct callback_head rcu;
	struct fib_nh___3 fib_nh[0];
};

struct fib_result___2 {
	__be32 prefix;
	unsigned char prefixlen;
	unsigned char nh_sel;
	unsigned char type;
	unsigned char scope;
	u32 tclassid;
	struct fib_info___3 *fi;
	struct fib_table *table;
	struct hlist_head *fa_head;
};

struct nf_hook_state___9 {
	unsigned int hook;
	u_int8_t pf;
	struct net_device___84 *in;
	struct net_device___84 *out;
	struct sock___65 *sk;
	struct net___95 *net;
	int (*okfn)(struct net___95 *, struct sock___65 *, struct sk_buff___85 *);
};

struct nf_nat_hook___9 {
	int (*parse_nat_setup)(struct nf_conn *, enum nf_nat_manip_type, const struct nlattr *);
	void (*decode_session)(struct sk_buff___85 *, struct flowi *);
	unsigned int (*manip_pkt)(struct sk_buff___85 *, struct nf_conn *, enum nf_nat_manip_type, enum ip_conntrack_dir);
};

struct nf_ct_hook___9 {
	int (*update)(struct net___95 *, struct sk_buff___85 *);
	void (*destroy)(struct nf_conntrack *);
	bool (*get_tuple_skb)(struct nf_conntrack_tuple *, const struct sk_buff___85 *);
};

struct nfnl_ct_hook___9 {
	struct nf_conn * (*get_ct)(const struct sk_buff___85 *, enum ip_conntrack_info *);
	size_t (*build_size)(const struct nf_conn *);
	int (*build)(struct sk_buff___85 *, struct nf_conn *, enum ip_conntrack_info, u_int16_t, u_int16_t);
	int (*parse)(const struct nlattr *, struct nf_conn *);
	int (*attach_expect)(const struct nlattr *, struct nf_conn *, u32, u32);
	void (*seq_adjust)(struct sk_buff___85 *, struct nf_conn *, enum ip_conntrack_info, s32);
};

struct uncached_list {
	spinlock_t lock;
	struct list_head head;
};

struct rt_cache_stat {
	unsigned int in_slow_tot;
	unsigned int in_slow_mc;
	unsigned int in_no_route;
	unsigned int in_brd;
	unsigned int in_martian_dst;
	unsigned int in_martian_src;
	unsigned int out_slow_tot;
	unsigned int out_slow_mc;
};

struct ipv6_stub___9 {
	int (*ipv6_sock_mc_join)(struct sock___65 *, int, const struct in6_addr *);
	int (*ipv6_sock_mc_drop)(struct sock___65 *, int, const struct in6_addr *);
	int (*ipv6_dst_lookup)(struct net___95 *, struct sock___65 *, struct dst_entry___64 **, struct flowi6 *);
	struct fib6_table___12 * (*fib6_get_table)(struct net___95 *, u32);
	struct fib6_info___12 * (*fib6_lookup)(struct net___95 *, int, struct flowi6 *, int);
	struct fib6_info___12 * (*fib6_table_lookup)(struct net___95 *, struct fib6_table___12 *, int, struct flowi6 *, int);
	struct fib6_info___12 * (*fib6_multipath_select)(const struct net___95 *, struct fib6_info___12 *, struct flowi6 *, int, const struct sk_buff___85 *, int);
	u32 (*ip6_mtu_from_fib6)(struct fib6_info___12 *, struct in6_addr *, struct in6_addr *);
	void (*udpv6_encap_enable)();
	void (*ndisc_send_na)(struct net_device___84 *, const struct in6_addr *, const struct in6_addr *, bool, bool, bool, bool);
	struct neigh_table___64 *nd_tbl;
};

struct ipv6_bpf_stub___9 {
	int (*inet6_bind)(struct sock___65 *, struct sockaddr *, int, bool, bool);
	struct sock___65 * (*udp6_lib_lookup)(struct net___95 *, const struct in6_addr *, __be16, const struct in6_addr *, __be16, int, int, struct udp_table *, struct sk_buff___85 *);
};

struct ip_tunnel_encap_ops___7 {
	size_t (*encap_hlen)(struct ip_tunnel_encap *);
	int (*build_header)(struct sk_buff___85 *, struct ip_tunnel_encap *, u8 *, struct flowi4 *);
};

struct hw_port_info___6 {
	struct net_device___84 *lower_dev;
	u32 port_id;
};

struct metadata_dst___6 {
	struct dst_entry___64 dst;
	enum metadata_type type;
	union {
		struct ip_tunnel_info tun_info;
		struct hw_port_info___6 port_info;
	} u;
};

struct net_protocol___7 {
	int (*early_demux)(struct sk_buff___85 *);
	int (*early_demux_handler)(struct sk_buff___85 *);
	int (*handler)(struct sk_buff___85 *);
	void (*err_handler)(struct sk_buff___85 *, u32);
	unsigned int no_policy: 1;
	unsigned int netns_ok: 1;
	unsigned int icmp_strict_tag_validation: 1;
};

struct inet6_protocol___7 {
	void (*early_demux)(struct sk_buff___85 *);
	void (*early_demux_handler)(struct sk_buff___85 *);
	int (*handler)(struct sk_buff___85 *);
	void (*err_handler)(struct sk_buff___85 *, struct inet6_skb_parm *, u8, u8, int, __be32);
	unsigned int flags;
};

struct net_offload___7 {
	struct offload_callbacks___9 callbacks;
	unsigned int flags;
};

struct icmphdr {
	__u8 type;
	__u8 code;
	__sum16 checksum;
	union {
		struct {
			__be16 id;
			__be16 sequence;
		} echo;
		__be32 gateway;
		struct {
			__be16 __unused;
			__be16 mtu;
		} frag;
		__u8 reserved[4];
	} un;
};

struct xfrm_replay___8 {
	void (*advance)(struct xfrm_state___8 *, __be32);
	int (*check)(struct xfrm_state___8 *, struct sk_buff___85 *, __be32);
	int (*recheck)(struct xfrm_state___8 *, struct sk_buff___85 *, __be32);
	void (*notify)(struct xfrm_state___8 *, int);
	int (*overflow)(struct xfrm_state___8 *, struct sk_buff___85 *);
};

struct xfrm_type___8 {
	char *description;
	struct module___366 *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___8 *);
	void (*destructor)(struct xfrm_state___8 *);
	int (*input)(struct xfrm_state___8 *, struct sk_buff___85 *);
	int (*output)(struct xfrm_state___8 *, struct sk_buff___85 *);
	int (*reject)(struct xfrm_state___8 *, struct sk_buff___85 *, const struct flowi *);
	int (*hdr_offset)(struct xfrm_state___8 *, struct sk_buff___85 *, u8 **);
	u32 (*get_mtu)(struct xfrm_state___8 *, int);
};

struct xfrm_state_afinfo___8;

struct xfrm_mode___8 {
	int (*input2)(struct xfrm_state___8 *, struct sk_buff___85 *);
	int (*input)(struct xfrm_state___8 *, struct sk_buff___85 *);
	int (*output2)(struct xfrm_state___8 *, struct sk_buff___85 *);
	int (*output)(struct xfrm_state___8 *, struct sk_buff___85 *);
	struct sk_buff___85 * (*gso_segment)(struct xfrm_state___8 *, struct sk_buff___85 *, netdev_features_t);
	void (*xmit)(struct xfrm_state___8 *, struct sk_buff___85 *);
	struct xfrm_state_afinfo___8 *afinfo;
	struct module___366 *owner;
	unsigned int encap;
	int flags;
};

struct xfrm_type_offload___8 {
	char *description;
	struct module___366 *owner;
	u8 proto;
	void (*encap)(struct xfrm_state___8 *, struct sk_buff___85 *);
	int (*input_tail)(struct xfrm_state___8 *, struct sk_buff___85 *);
	int (*xmit)(struct xfrm_state___8 *, struct sk_buff___85 *, netdev_features_t);
};

struct xfrm_dst___4 {
	union {
		struct dst_entry___64 dst;
		struct rtable___6 rt;
		struct rt6_info___12 rt6;
	} u;
	struct dst_entry___64 *route;
	struct dst_entry___64 *child;
	struct dst_entry___64 *path;
	struct xfrm_policy___8 *pols[2];
	int num_pols;
	int num_xfrms;
	u32 xfrm_genid;
	u32 policy_genid;
	u32 route_mtu_cached;
	u32 child_mtu_cached;
	u32 route_cookie;
	u32 path_cookie;
};

struct xfrm_state_afinfo___8 {
	unsigned int family;
	unsigned int proto;
	__be16 eth_proto;
	struct module___366 *owner;
	const struct xfrm_type___8 *type_map[256];
	const struct xfrm_type_offload___8 *type_offload_map[256];
	struct xfrm_mode___8 *mode_map[5];
	int (*init_flags)(struct xfrm_state___8 *);
	void (*init_tempsel)(struct xfrm_selector *, const struct flowi *);
	void (*init_temprop)(struct xfrm_state___8 *, const struct xfrm_tmpl *, const xfrm_address_t *, const xfrm_address_t *);
	int (*tmpl_sort)(struct xfrm_tmpl **, struct xfrm_tmpl **, int);
	int (*state_sort)(struct xfrm_state___8 **, struct xfrm_state___8 **, int);
	int (*output)(struct net___95 *, struct sock___65 *, struct sk_buff___85 *);
	int (*output_finish)(struct sock___65 *, struct sk_buff___85 *);
	int (*extract_input)(struct xfrm_state___8 *, struct sk_buff___85 *);
	int (*extract_output)(struct xfrm_state___8 *, struct sk_buff___85 *);
	int (*transport_finish)(struct sk_buff___85 *, int);
	void (*local_error)(struct sk_buff___85 *, u32);
};

struct fib_prop {
	int error;
	u8 scope;
};

struct skb_frag_struct___16 {
	struct {
		struct page___440 *p;
	} page;
	__u32 page_offset;
	__u32 size;
};

typedef struct skb_frag_struct___16 skb_frag_t___16;

struct skb_shared_info___16 {
	__u8 __unused;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___85 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___16 frags[16];
};

struct packet_type___3 {
	__be16 type;
	struct net_device___84 *dev;
	int (*func)(struct sk_buff___85 *, struct net_device___84 *, struct packet_type___3 *, struct net_device___84 *);
	bool (*id_match)(struct packet_type___3 *, struct sock___65 *);
	void *af_packet_priv;
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct raw_hashinfo {
	rwlock_t lock;
	struct hlist_head ht[256];
};

enum ip_defrag_users {
	IP_DEFRAG_LOCAL_DELIVER = 0,
	IP_DEFRAG_CALL_RA_CHAIN = 1,
	IP_DEFRAG_CONNTRACK_IN = 2,
	__IP_DEFRAG_CONNTRACK_IN_END = 65537,
	IP_DEFRAG_CONNTRACK_OUT = 65538,
	__IP_DEFRAG_CONNTRACK_OUT_END = 131073,
	IP_DEFRAG_CONNTRACK_BRIDGE_IN = 131074,
	__IP_DEFRAG_CONNTRACK_BRIDGE_IN = 196609,
	IP_DEFRAG_VS_IN = 196610,
	IP_DEFRAG_VS_OUT = 196611,
	IP_DEFRAG_VS_FWD = 196612,
	IP_DEFRAG_AF_PACKET = 196613,
	IP_DEFRAG_MACVLAN = 196614,
};

enum {
	INET_FRAG_FIRST_IN = 1,
	INET_FRAG_LAST_IN = 2,
	INET_FRAG_COMPLETE = 4,
};

struct ipq {
	struct inet_frag_queue___84 q;
	u8 ecn;
	u16 max_df_size;
	int iif;
	unsigned int rid;
	struct inet_peer *peer;
};

struct module___367;

struct file___440;

struct kiocb___440;

struct iov_iter___207;

struct poll_table_struct___279;

struct vm_area_struct___441;

struct inode___440;

struct file_lock___440;

struct page___441;

struct pipe_inode_info___121;

struct seq_file___379;

struct file_operations___440 {
	struct module___367 *owner;
	loff_t (*llseek)(struct file___440 *, loff_t, int);
	ssize_t (*read)(struct file___440 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___440 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___440 *, struct iov_iter___207 *);
	ssize_t (*write_iter)(struct kiocb___440 *, struct iov_iter___207 *);
	int (*iopoll)(struct kiocb___440 *, bool);
	int (*iterate)(struct file___440 *, struct dir_context *);
	int (*iterate_shared)(struct file___440 *, struct dir_context *);
	__poll_t (*poll)(struct file___440 *, struct poll_table_struct___279 *);
	long int (*unlocked_ioctl)(struct file___440 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___440 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___440 *, struct vm_area_struct___441 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___440 *, struct file___440 *);
	int (*flush)(struct file___440 *, fl_owner_t);
	int (*release)(struct inode___440 *, struct file___440 *);
	int (*fsync)(struct file___440 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___440 *, int);
	int (*lock)(struct file___440 *, int, struct file_lock___440 *);
	ssize_t (*sendpage)(struct file___440 *, struct page___441 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___440 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___440 *, int, struct file_lock___440 *);
	ssize_t (*splice_write)(struct pipe_inode_info___121 *, struct file___440 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___440 *, loff_t *, struct pipe_inode_info___121 *, size_t, unsigned int);
	int (*setlease)(struct file___440 *, long int, struct file_lock___440 **, void **);
	long int (*fallocate)(struct file___440 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___379 *, struct file___440 *);
	ssize_t (*copy_file_range)(struct file___440 *, loff_t, struct file___440 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___440 *, loff_t, struct file___440 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___440 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___441 {
	u64 seqnum;
	struct vm_area_struct___441 *vmas[4];
};

struct page_frag___441 {
	struct page___441 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___441;

struct mem_cgroup___173;

struct pid___244;

struct cred___408;

struct nsproxy___335;

struct signal_struct___315;

struct bio_list___230;

struct backing_dev_info___230;

struct css_set___289;

struct vm_struct___344;

struct task_struct___442 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___442 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___441 *mm;
	struct mm_struct___441 *active_mm;
	struct vmacache___441 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___442 *real_parent;
	struct task_struct___442 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___442 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___173 *active_memcg;
	long int rh_reserved2;
	struct pid___244 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___244 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___244 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___408 *ptracer_cred;
	const struct cred___408 *real_cred;
	const struct cred___408 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___335 *nsproxy;
	struct signal_struct___315 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___442 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___230 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___230 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___289 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___121 *splice_pipe;
	struct page_frag___441 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___173 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___442 *oom_reaper_list;
	struct vm_struct___344 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___156 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___441 *pgtable_t___441;

struct address_space___440;

struct dev_pagemap___428;

struct page___441 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___440 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___441 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___441 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___441 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___428 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___173 *mem_cgroup;
};

struct pglist_data___441;

struct lruvec___441 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___441 *pgdat;
};

struct zone___441 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___441 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___441 {
	struct zone___441 *zone;
	int zone_idx;
};

struct zonelist___441 {
	struct zoneref___441 _zonerefs[25];
};

struct pglist_data___441 {
	struct zone___441 node_zones[3];
	struct zonelist___441 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___442 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___442 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___441 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___442 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___442 *owner;
};

struct secondary_data___442 {
	void *stack;
	struct task_struct___442 *task;
	long int status;
};

struct blocking_notifier_head___441 {
	struct rw_semaphore___442 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___428;

struct vm_area_struct___441 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___441 *vm_next;
	struct vm_area_struct___441 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___441 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___428 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___440 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___441;

struct user_namespace___305;

struct mm_struct___441 {
	struct {
		struct vm_area_struct___441 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___440 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___442 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___441 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___442 *owner;
		struct user_namespace___305 *user_ns;
		struct file___440 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___441 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___440;

struct address_space___440 {
	struct inode___440 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___442 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___440 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___428)(struct vm_area_struct___441 *, long unsigned int, const struct page___441 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___428)(struct page___441 *, void *);

struct device___408;

struct dev_pagemap___428 {
	dev_page_fault_t___428 page_fault;
	dev_page_free_t___428 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___408 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct cgroup___289;

struct cgroup_subsys___289;

struct cgroup_subsys_state___289 {
	struct cgroup___289 *cgroup;
	struct cgroup_subsys___289 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___289 *parent;
};

struct kernfs_node___435;

struct cgroup_file___289 {
	struct kernfs_node___435 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___173;

struct mem_cgroup___173 {
	struct cgroup_subsys_state___289 css;
	struct mem_cgroup_id___16 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___289 events_file;
	struct cgroup_file___289 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___442 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___173 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry___440;

struct path___441 {
	struct vfsmount *mnt;
	struct dentry___440 *dentry;
};

struct fown_struct___244 {
	rwlock_t lock;
	struct pid___244 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___440 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___441 f_path;
	struct inode___440 *f_inode;
	const struct file_operations___440 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___244 f_owner;
	const struct cred___408 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___440 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___428;

struct vm_operations_struct___428 {
	void (*open)(struct vm_area_struct___441 *);
	void (*close)(struct vm_area_struct___441 *);
	int (*split)(struct vm_area_struct___441 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___441 *);
	vm_fault_t (*fault)(struct vm_fault___428 *);
	vm_fault_t (*huge_fault)(struct vm_fault___428 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___428 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___441 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___428 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___428 *);
	int (*access)(struct vm_area_struct___441 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___441 *);
	int (*set_policy)(struct vm_area_struct___441 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___441 *, long unsigned int);
	struct page___441 * (*find_special_page)(struct vm_area_struct___441 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___441 {
	struct task_struct___442 *task;
	struct core_thread___441 *next;
};

struct core_state___441 {
	atomic_t nr_threads;
	struct core_thread___441 dumper;
	struct completion startup;
};

struct key___408;

struct ucounts___305;

struct user_namespace___305 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___305 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___29 ns;
	long unsigned int flags;
	struct key___408 *persistent_keyring_register;
	struct rw_semaphore___442 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___305 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___428 {
	struct vm_area_struct___441 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___441 *cow_page;
	struct mem_cgroup___173 *memcg;
	struct page___441 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___441 prealloc_pte;
};

struct shrink_control___173 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___173 *memcg;
};

struct shrinker___173 {
	long unsigned int (*count_objects)(struct shrinker___173 *, struct shrink_control___173 *);
	long unsigned int (*scan_objects)(struct shrinker___173 *, struct shrink_control___173 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct pid_namespace___244;

struct upid___244 {
	int nr;
	struct pid_namespace___244 *ns;
};

struct pid_namespace___244 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___442 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___244 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___440 *proc_self;
	struct dentry___440 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___305 *user_ns;
	struct ucounts___305 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___29 ns;
};

struct pid___244 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___244 numbers[1];
};

struct user_struct___408 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___408 *uid_keyring;
	struct key___408 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___408 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___408 *session_keyring;
	struct key___408 *process_keyring;
	struct key___408 *thread_keyring;
	struct key___408 *request_key_auth;
	void *security;
	struct user_struct___408 *user;
	struct user_namespace___305 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___96;

struct cgroup_namespace___289;

struct nsproxy___335 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___244 *pid_ns_for_children;
	struct net___96 *net_ns;
	struct cgroup_namespace___289 *cgroup_ns;
};

struct signal_struct___315 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___442 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___442 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___244 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___244 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___441 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___244 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___230;

struct bio_list___230 {
	struct bio___230 *head;
	struct bio___230 *tail;
};

struct bdi_writeback_congested___230;

struct bdi_writeback___230 {
	struct backing_dev_info___230 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___230 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___289 *memcg_css;
	struct cgroup_subsys_state___289 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___230 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___230 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___408 *dev;
	struct device___408 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___440 *debug_dir;
	struct dentry___440 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___289 {
	struct cgroup_subsys_state___289 *subsys[13];
	refcount_t refcount;
	struct css_set___289 *dom_cset;
	struct cgroup___289 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___289 *mg_src_cgrp;
	struct cgroup___289 *mg_dst_cgrp;
	struct css_set___289 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___440;

struct pipe_buffer___121;

struct pipe_inode_info___121 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___441 *tmp_page;
	struct fasync_struct___440 *fasync_readers;
	struct fasync_struct___440 *fasync_writers;
	struct pipe_buffer___121 *bufs;
	struct user_struct___408 *user;
};

struct vm_struct___344 {
	struct vm_struct___344 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___441 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___327 {
	struct task_struct___442 task;
	long unsigned int stack[8192];
};

struct kset___427;

struct kobj_type___427;

struct kobject___428 {
	const char *name;
	struct list_head entry;
	struct kobject___428 *parent;
	struct kset___427 *kset;
	struct kobj_type___427 *ktype;
	struct kernfs_node___435 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___408 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___408 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___408;

struct bus_type___408;

struct device_driver___408;

struct dev_pm_domain___408;

struct dma_map_ops___180;

struct fwnode_handle___328;

struct class___408;

struct attribute_group___405;

struct device___408 {
	struct device___408 *parent;
	struct device_private *p;
	struct kobject___428 kobj;
	const char *init_name;
	const struct device_type___408 *type;
	struct mutex mutex;
	struct bus_type___408 *bus;
	struct device_driver___408 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___408 power;
	struct dev_pm_domain___408 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___180 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___328 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___408 *class;
	const struct attribute_group___405 **groups;
	void (*release)(struct device___408 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___440;

struct super_block___440;

struct dentry___440 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___440 *d_parent;
	struct qstr d_name;
	struct inode___440 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___440 *d_op;
	struct super_block___440 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___440;

struct block_device___440;

struct inode___440 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___440 *i_op;
	struct super_block___440 *i_sb;
	struct address_space___440 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___442 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___230 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___440 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___440 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___121 *i_pipe;
		struct block_device___440 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___440 {
	int (*d_revalidate)(struct dentry___440 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___440 *, unsigned int);
	int (*d_hash)(const struct dentry___440 *, struct qstr *);
	int (*d_compare)(const struct dentry___440 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___440 *);
	int (*d_init)(struct dentry___440 *);
	void (*d_release)(struct dentry___440 *);
	void (*d_prune)(struct dentry___440 *);
	void (*d_iput)(struct dentry___440 *, struct inode___440 *);
	char * (*d_dname)(struct dentry___440 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___441 *);
	int (*d_manage)(const struct path___441 *, bool);
	struct dentry___440 * (*d_real)(struct dentry___440 *, const struct inode___440 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___440;

struct mem_dqinfo___440 {
	struct quota_format_type___440 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___440;

struct quota_info___440 {
	unsigned int flags;
	struct rw_semaphore___442 dqio_sem;
	struct inode___440 *files[3];
	struct mem_dqinfo___440 info[3];
	const struct quota_format_ops___440 *ops[3];
};

struct rcuwait___440 {
	struct task_struct___442 *task;
};

struct percpu_rw_semaphore___440 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___442 rw_sem;
	struct rcuwait___440 writer;
	int readers_block;
};

struct sb_writers___440 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___440 rw_sem[3];
};

struct file_system_type___440;

struct super_operations___440;

struct dquot_operations___440;

struct quotactl_ops___440;

struct super_block___440 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___440 *s_type;
	const struct super_operations___440 *s_op;
	const struct dquot_operations___440 *dq_op;
	const struct quotactl_ops___440 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___440 *s_root;
	struct rw_semaphore___442 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___440 *s_bdev;
	struct backing_dev_info___230 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___440 s_dquot;
	struct sb_writers___440 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___440 *s_d_op;
	int cleancache_poolid;
	struct shrinker___173 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___305 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___440 {
	struct file___440 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___440 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___440 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___440 *ia_file;
};

struct dquot___440 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___440 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___440 {
	int qf_fmt_id;
	const struct quota_format_ops___440 *qf_ops;
	struct module___367 *qf_owner;
	struct quota_format_type___440 *qf_next;
};

struct quota_format_ops___440 {
	int (*check_quota_file)(struct super_block___440 *, int);
	int (*read_file_info)(struct super_block___440 *, int);
	int (*write_file_info)(struct super_block___440 *, int);
	int (*free_file_info)(struct super_block___440 *, int);
	int (*read_dqblk)(struct dquot___440 *);
	int (*commit_dqblk)(struct dquot___440 *);
	int (*release_dqblk)(struct dquot___440 *);
	int (*get_next_id)(struct super_block___440 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___440 {
	int (*write_dquot)(struct dquot___440 *);
	struct dquot___440 * (*alloc_dquot)(struct super_block___440 *, int);
	void (*destroy_dquot)(struct dquot___440 *);
	int (*acquire_dquot)(struct dquot___440 *);
	int (*release_dquot)(struct dquot___440 *);
	int (*mark_dirty)(struct dquot___440 *);
	int (*write_info)(struct super_block___440 *, int);
	qsize_t * (*get_reserved_space)(struct inode___440 *);
	int (*get_projid)(struct inode___440 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___440 *, qsize_t *);
	int (*get_next_id)(struct super_block___440 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___440 {
	int (*quota_on)(struct super_block___440 *, int, int, const struct path___441 *);
	int (*quota_off)(struct super_block___440 *, int);
	int (*quota_enable)(struct super_block___440 *, unsigned int);
	int (*quota_disable)(struct super_block___440 *, unsigned int);
	int (*quota_sync)(struct super_block___440 *, int);
	int (*set_info)(struct super_block___440 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___440 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___440 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___440 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___440 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___440 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___366 {
	struct kobject___428 kobj;
	struct module___367 *mod;
	struct kobject___428 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___366 {
	struct module___367 *mod;
	struct latch_tree_node node;
};

struct module_layout___366 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___366 mtn;
};

struct module_attribute___366;

struct kernel_param___366;

struct module___367 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___366 mkobj;
	struct module_attribute___366 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___428 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___366 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___366 core_layout;
	struct module_layout___366 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide53;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide54;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___193;

struct address_space_operations___440 {
	int (*writepage)(struct page___441 *, struct writeback_control___193 *);
	int (*readpage)(struct file___440 *, struct page___441 *);
	int (*writepages)(struct address_space___440 *, struct writeback_control___193 *);
	int (*set_page_dirty)(struct page___441 *);
	int (*readpages)(struct file___440 *, struct address_space___440 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___440 *, struct address_space___440 *, loff_t, unsigned int, unsigned int, struct page___441 **, void **);
	int (*write_end)(struct file___440 *, struct address_space___440 *, loff_t, unsigned int, unsigned int, struct page___441 *, void *);
	sector_t (*bmap)(struct address_space___440 *, sector_t);
	void (*invalidatepage)(struct page___441 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___441 *, gfp_t);
	void (*freepage)(struct page___441 *);
	ssize_t (*direct_IO)(struct kiocb___440 *, struct iov_iter___207 *);
	int (*migratepage)(struct address_space___440 *, struct page___441 *, struct page___441 *, enum migrate_mode);
	bool (*isolate_page)(struct page___441 *, isolate_mode_t);
	void (*putback_page)(struct page___441 *);
	int (*launder_page)(struct page___441 *);
	int (*is_partially_uptodate)(struct page___441 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___441 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___440 *, struct page___441 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___440 *, sector_t *);
	void (*swap_deactivate)(struct file___440 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___193 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___230 *wb;
	struct inode___440 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___232;

struct iov_iter___207 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___232 *bvec;
		struct pipe_inode_info___121 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___440 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___440 *bd_inode;
	struct super_block___440 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___440 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___230 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___440 {
	struct dentry___440 * (*lookup)(struct inode___440 *, struct dentry___440 *, unsigned int);
	const char * (*get_link)(struct dentry___440 *, struct inode___440 *, struct delayed_call *);
	int (*permission)(struct inode___440 *, int);
	struct posix_acl * (*get_acl)(struct inode___440 *, int);
	int (*readlink)(struct dentry___440 *, char *, int);
	int (*create)(struct inode___440 *, struct dentry___440 *, umode_t, bool);
	int (*link)(struct dentry___440 *, struct inode___440 *, struct dentry___440 *);
	int (*unlink)(struct inode___440 *, struct dentry___440 *);
	int (*symlink)(struct inode___440 *, struct dentry___440 *, const char *);
	int (*mkdir)(struct inode___440 *, struct dentry___440 *, umode_t);
	int (*rmdir)(struct inode___440 *, struct dentry___440 *);
	int (*mknod)(struct inode___440 *, struct dentry___440 *, umode_t, dev_t);
	int (*rename)(struct inode___440 *, struct dentry___440 *, struct inode___440 *, struct dentry___440 *, unsigned int);
	int (*setattr)(struct dentry___440 *, struct iattr___440 *);
	int (*getattr)(const struct path___441 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___440 *, char *, size_t);
	int (*fiemap)(struct inode___440 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___440 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___440 *, struct dentry___440 *, struct file___440 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___440 *, struct dentry___440 *, umode_t);
	int (*set_acl)(struct inode___440 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___440 {
	void (*fl_copy_lock)(struct file_lock___440 *, struct file_lock___440 *);
	void (*fl_release_private)(struct file_lock___440 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___440;

struct file_lock___440 {
	struct file_lock___440 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___440 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___440 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___440 *fl_ops;
	const struct lock_manager_operations___440 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___440 {
	int (*lm_compare_owner)(struct file_lock___440 *, struct file_lock___440 *);
	long unsigned int (*lm_owner_key)(struct file_lock___440 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___440 *);
	int (*lm_grant)(struct file_lock___440 *, int);
	bool (*lm_break)(struct file_lock___440 *);
	int (*lm_change)(struct file_lock___440 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___440 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___440 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___440 *fa_next;
	struct file___440 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___440 {
	const char *name;
	int fs_flags;
	struct dentry___440 * (*mount)(struct file_system_type___440 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___440 *);
	struct module___367 *owner;
	struct file_system_type___440 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___440 {
	struct inode___440 * (*alloc_inode)(struct super_block___440 *);
	void (*destroy_inode)(struct inode___440 *);
	void (*dirty_inode)(struct inode___440 *, int);
	int (*write_inode)(struct inode___440 *, struct writeback_control___193 *);
	int (*drop_inode)(struct inode___440 *);
	void (*evict_inode)(struct inode___440 *);
	void (*put_super)(struct super_block___440 *);
	int (*sync_fs)(struct super_block___440 *, int);
	int (*freeze_super)(struct super_block___440 *);
	int (*freeze_fs)(struct super_block___440 *);
	int (*thaw_super)(struct super_block___440 *);
	int (*unfreeze_fs)(struct super_block___440 *);
	int (*statfs)(struct dentry___440 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___440 *, int *, char *);
	void (*umount_begin)(struct super_block___440 *);
	int (*show_options)(struct seq_file___379 *, struct dentry___440 *);
	int (*show_devname)(struct seq_file___379 *, struct dentry___440 *);
	int (*show_path)(struct seq_file___379 *, struct dentry___440 *);
	int (*show_stats)(struct seq_file___379 *, struct dentry___440 *);
	ssize_t (*quota_read)(struct super_block___440 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___440 *, int, const char *, size_t, loff_t);
	struct dquot___440 ** (*get_dquots)(struct inode___440 *);
	int (*bdev_try_to_free_page)(struct super_block___440 *, struct page___441 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___440 *, struct shrink_control___173 *);
	long int (*free_cached_objects)(struct super_block___440 *, struct shrink_control___173 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___289)(struct file___440 *, wait_queue_head_t *, struct poll_table_struct___279 *);

struct poll_table_struct___279 {
	poll_queue_proc___289 _qproc;
	__poll_t _key;
};

struct seq_operations___379;

struct seq_file___379 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___379 *op;
	int poll_event;
	const struct file___440 *file;
	void *private;
};

typedef void bio_end_io_t___230(struct bio___230 *);

struct bio_vec___232 {
	struct page___441 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___230;

struct bio_set___230;

struct bio___230 {
	struct bio___230 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___230 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___230 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___232 *bi_io_vec;
	struct bio_set___230 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___232 bi_inline_vecs[0];
};

struct kobj_attribute___418 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___428 *, struct kobj_attribute___418 *, char *);
	ssize_t (*store)(struct kobject___428 *, struct kobj_attribute___418 *, const char *, size_t);
};

typedef void compound_page_dtor___428(struct page___441 *);

struct crypto_async_request___31;

typedef void (*crypto_completion_t___31)(struct crypto_async_request___31 *, int);

struct crypto_tfm___31;

struct crypto_async_request___31 {
	struct list_head list;
	crypto_completion_t___31 complete;
	void *data;
	struct crypto_tfm___31 *tfm;
	u32 flags;
};

struct crypto_ablkcipher___31;

struct ablkcipher_request___31;

struct ablkcipher_tfm___31 {
	int (*setkey)(struct crypto_ablkcipher___31 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___31 *);
	int (*decrypt)(struct ablkcipher_request___31 *);
	struct crypto_ablkcipher___31 *base;
	unsigned int ivsize;
	unsigned int reqsize;
};

struct blkcipher_desc___31;

struct blkcipher_tfm___31 {
	void *iv;
	int (*setkey)(struct crypto_tfm___31 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___31 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___31 *, struct scatterlist *, struct scatterlist *, unsigned int);
};

struct cipher_tfm___31 {
	int (*cit_setkey)(struct crypto_tfm___31 *, const u8 *, unsigned int);
	void (*cit_encrypt_one)(struct crypto_tfm___31 *, u8 *, const u8 *);
	void (*cit_decrypt_one)(struct crypto_tfm___31 *, u8 *, const u8 *);
};

struct compress_tfm___31 {
	int (*cot_compress)(struct crypto_tfm___31 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*cot_decompress)(struct crypto_tfm___31 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___31;

struct crypto_tfm___31 {
	u32 crt_flags;
	union {
		struct ablkcipher_tfm___31 ablkcipher;
		struct blkcipher_tfm___31 blkcipher;
		struct cipher_tfm___31 cipher;
		struct compress_tfm___31 compress;
	} crt_u;
	void (*exit)(struct crypto_tfm___31 *);
	struct crypto_alg___31 *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct ablkcipher_request___31 {
	struct crypto_async_request___31 base;
	unsigned int nbytes;
	void *info;
	struct scatterlist *src;
	struct scatterlist *dst;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_blkcipher___31;

struct blkcipher_desc___31 {
	struct crypto_blkcipher___31 *tfm;
	void *info;
	u32 flags;
};

struct crypto_blkcipher___31 {
	struct crypto_tfm___31 base;
};

struct ablkcipher_alg___31 {
	int (*setkey)(struct crypto_ablkcipher___31 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___31 *);
	int (*decrypt)(struct ablkcipher_request___31 *);
	int (*givencrypt)(struct skcipher_givcrypt_request *);
	int (*givdecrypt)(struct skcipher_givcrypt_request *);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct crypto_ablkcipher___31 {
	struct crypto_tfm___31 base;
};

struct blkcipher_alg___31 {
	int (*setkey)(struct crypto_tfm___31 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___31 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___31 *, struct scatterlist *, struct scatterlist *, unsigned int);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct cipher_alg___31 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___31 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___31 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___31 *, u8 *, const u8 *);
};

struct compress_alg___31 {
	int (*coa_compress)(struct crypto_tfm___31 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___31 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___31 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type *cra_type;
	union {
		struct ablkcipher_alg___31 ablkcipher;
		struct blkcipher_alg___31 blkcipher;
		struct cipher_alg___31 cipher;
		struct compress_alg___31 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___31 *);
	void (*cra_exit)(struct crypto_tfm___31 *);
	void (*cra_destroy)(struct crypto_alg___31 *);
	struct module___367 *cra_module;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct crypto_cipher___15 {
	struct crypto_tfm___31 base;
};

struct msghdr___68 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___207 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___440 *msg_iocb;
};

struct socket_wq___66 {
	wait_queue_head_t wait;
	struct fasync_struct___440 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct sock___66;

struct proto_ops___66;

struct socket___67 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___66 *wq;
	struct file___440 *file;
	struct sock___66 *sk;
	const struct proto_ops___66 *ops;
};

typedef struct {
	struct net___96 *net;
} possible_net_t___87;

struct proto___65;

struct sock_common___65 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___65 *skc_prot;
	possible_net_t___87 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___66 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___86;

struct sk_buff_head___85 {
	struct sk_buff___86 *next;
	struct sk_buff___86 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___65;

struct xfrm_policy___9;

struct dst_entry___65;

struct net_device___85;

struct sock___66 {
	struct sock_common___65 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___85 sk_error_queue;
	struct sk_buff_head___85 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___86 *head;
		struct sk_buff___86 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___65 *sk_filter;
	union {
		struct socket_wq___66 *sk_wq;
		struct socket_wq___66 *sk_wq_raw;
	};
	struct xfrm_policy___9 *sk_policy[2];
	struct dst_entry___65 *sk_rx_dst;
	struct dst_entry___65 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___86 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___85 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___441 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___65 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___244 *sk_peer_pid;
	const struct cred___408 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___67 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___173 *sk_memcg;
	void (*sk_state_change)(struct sock___66 *);
	void (*sk_data_ready)(struct sock___66 *);
	void (*sk_write_space)(struct sock___66 *);
	void (*sk_error_report)(struct sock___66 *);
	int (*sk_backlog_rcv)(struct sock___66 *, struct sk_buff___86 *);
	struct sk_buff___86 * (*sk_validate_xmit_skb)(struct sock___66 *, struct net_device___85 *, struct sk_buff___86 *);
	void (*sk_destruct)(struct sock___66 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

typedef int (*sk_read_actor_t___65)(read_descriptor_t *, struct sk_buff___86 *, unsigned int, size_t);

struct proto_ops___66 {
	int family;
	struct module___367 *owner;
	int (*release)(struct socket___67 *);
	int (*bind)(struct socket___67 *, struct sockaddr *, int);
	int (*connect)(struct socket___67 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___67 *, struct socket___67 *);
	int (*accept)(struct socket___67 *, struct socket___67 *, int, bool);
	int (*getname)(struct socket___67 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___440 *, struct socket___67 *, struct poll_table_struct___279 *);
	int (*ioctl)(struct socket___67 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___67 *, int);
	int (*shutdown)(struct socket___67 *, int);
	int (*setsockopt)(struct socket___67 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___67 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___67 *, struct msghdr___68 *, size_t);
	int (*recvmsg)(struct socket___67 *, struct msghdr___68 *, size_t, int);
	int (*mmap)(struct file___440 *, struct socket___67 *, struct vm_area_struct___441 *);
	ssize_t (*sendpage)(struct socket___67 *, struct page___441 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___67 *, loff_t *, struct pipe_inode_info___121 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___66 *, int);
	int (*peek_len)(struct socket___67 *);
	int (*read_sock)(struct sock___66 *, read_descriptor_t *, sk_read_actor_t___65);
	int (*sendpage_locked)(struct sock___66 *, struct page___441 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___66 *, struct msghdr___68 *, size_t);
	int (*set_rcvlowat)(struct sock___66 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct sec_path___9;

struct nf_bridge_info___85;

struct sk_buff___86 {
	union {
		struct {
			struct sk_buff___86 *next;
			struct sk_buff___86 *prev;
			union {
				struct net_device___85 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___66 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___86 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path___9 *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___85 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___85;

struct netns_frags___85 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___85 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ip_ra_chain___31;

struct fib_rules_ops___65;

struct tcp_congestion_ops___12;

struct tcp_fastopen_context___12;

struct fib_notifier_ops___66;

struct netns_ipv4___85 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___31 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___65 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___66 *fibnl;
	struct sock___66 **icmp_sk;
	struct sock___66 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___66 **tcp_sk;
	struct netns_frags___85 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops___12 *tcp_congestion_control;
	struct tcp_fastopen_context___12 *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___65 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___66 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___66 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___65;

struct dst_ops___96 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___96 *);
	struct dst_entry___65 * (*check)(struct dst_entry___65 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___65 *);
	unsigned int (*mtu)(const struct dst_entry___65 *);
	u32 * (*cow_metrics)(struct dst_entry___65 *, long unsigned int);
	void (*destroy)(struct dst_entry___65 *);
	void (*ifdown)(struct dst_entry___65 *, struct net_device___85 *, int);
	struct dst_entry___65 * (*negative_advice)(struct dst_entry___65 *);
	void (*link_failure)(struct sk_buff___86 *);
	void (*update_pmtu)(struct dst_entry___65 *, struct sock___66 *, struct sk_buff___86 *, u32);
	void (*redirect)(struct dst_entry___65 *, struct sock___66 *, struct sk_buff___86 *);
	int (*local_out)(struct net___96 *, struct sock___66 *, struct sk_buff___86 *);
	struct neighbour___65 * (*neigh_lookup)(const struct dst_entry___65 *, struct sk_buff___86 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___65 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_info___13;

struct rt6_info___13;

struct fib6_table___13;

struct netns_ipv6___96 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___85 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info___13 *fib6_null_entry;
	struct rt6_info___13 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___13 *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___96 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info___13 *ip6_prohibit_entry;
	struct rt6_info___13 *ip6_blk_hole_entry;
	struct fib6_table___13 *fib6_local_tbl;
	struct fib_rules_ops___65 *fib6_rules_ops;
	struct sock___66 **icmp_sk;
	struct sock___66 *ndisc_sk;
	struct sock___66 *tcp_sk;
	struct sock___66 *igmp_sk;
	struct sock___66 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___65 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___66 *notifier_ops;
	struct fib_notifier_ops___66 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___66 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___66 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct nf_hook_entries___10;

struct netns_nf___11 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_queue_handler *queue_handler;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header *nf_log_dir_header;
	struct nf_hook_entries___10 *hooks_ipv4[5];
	struct nf_hook_entries___10 *hooks_ipv6[5];
	struct nf_hook_entries___10 *hooks_arp[3];
	struct nf_hook_entries___10 *hooks_bridge[5];
	bool defrag_ipv4;
	bool defrag_ipv6;
};

struct netns_nf_frag___85 {
	struct netns_frags___85 frags;
};

struct netns_xfrm___96 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___66 *nlsk;
	struct sock___66 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___96 xfrm4_dst_ops;
	struct dst_ops___96 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___75;

struct net___96 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___305 *user_ns;
	struct ucounts___305 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___29 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___66 *rtnl;
	struct sock___66 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___85 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___85 ipv4;
	struct netns_ipv6___96 ipv6;
	struct netns_sctp___66 sctp;
	struct netns_nf___11 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___85 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___66 *nfnl;
	struct sock___66 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___96 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___66 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___75 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kernfs_root___434;

struct kernfs_elem_dir___434 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___434 *root;
};

struct kernfs_syscall_ops___434;

struct kernfs_root___434 {
	struct kernfs_node___435 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___434 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___434 {
	struct kernfs_node___435 *target_kn;
};

struct kernfs_ops___434;

struct kernfs_elem_attr___434 {
	const struct kernfs_ops___434 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___435 *notify_next;
};

struct kernfs_node___435 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___435 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___434 dir;
		struct kernfs_elem_symlink___434 symlink;
		struct kernfs_elem_attr___434 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___434;

struct kernfs_ops___434 {
	int (*open)(struct kernfs_open_file___434 *);
	void (*release)(struct kernfs_open_file___434 *);
	int (*seq_show)(struct seq_file___379 *, void *);
	void * (*seq_start)(struct seq_file___379 *, loff_t *);
	void * (*seq_next)(struct seq_file___379 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___379 *, void *);
	ssize_t (*read)(struct kernfs_open_file___434 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___434 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___434 *, struct vm_area_struct___441 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___434 *, struct poll_table_struct___279 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___434 {
	int (*remount_fs)(struct kernfs_root___434 *, int *, char *);
	int (*show_options)(struct seq_file___379 *, struct kernfs_root___434 *);
	int (*mkdir)(struct kernfs_node___435 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___435 *);
	int (*rename)(struct kernfs_node___435 *, struct kernfs_node___435 *, const char *);
	int (*show_path)(struct seq_file___379 *, struct kernfs_node___435 *, struct kernfs_root___434 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___434 {
	struct kernfs_node___435 *kn;
	struct file___440 *file;
	struct seq_file___379 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___428 *vm_ops;
};

struct kobj_ns_type_operations___65 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___66 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___404;

struct attribute_group___405 {
	const char *name;
	umode_t (*is_visible)(struct kobject___428 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___428 *, struct bin_attribute___404 *, int);
	struct attribute **attrs;
	struct bin_attribute___404 **bin_attrs;
};

struct bin_attribute___404 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___440 *, struct kobject___428 *, struct bin_attribute___404 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___440 *, struct kobject___428 *, struct bin_attribute___404 *, char *, loff_t, size_t);
	int (*mmap)(struct file___440 *, struct kobject___428 *, struct bin_attribute___404 *, struct vm_area_struct___441 *);
};

struct sysfs_ops___427 {
	ssize_t (*show)(struct kobject___428 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___428 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___427;

struct kset___427 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___428 kobj;
	const struct kset_uevent_ops___427 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___427 {
	void (*release)(struct kobject___428 *);
	const struct sysfs_ops___427 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___65 * (*child_ns_type)(struct kobject___428 *);
	const void * (*namespace)(struct kobject___428 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___427 {
	int (* const filter)(struct kset___427 *, struct kobject___428 *);
	const char * (* const name)(struct kset___427 *, struct kobject___428 *);
	int (* const uevent)(struct kset___427 *, struct kobject___428 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___408 {
	int (*prepare)(struct device___408 *);
	void (*complete)(struct device___408 *);
	int (*suspend)(struct device___408 *);
	int (*resume)(struct device___408 *);
	int (*freeze)(struct device___408 *);
	int (*thaw)(struct device___408 *);
	int (*poweroff)(struct device___408 *);
	int (*restore)(struct device___408 *);
	int (*suspend_late)(struct device___408 *);
	int (*resume_early)(struct device___408 *);
	int (*freeze_late)(struct device___408 *);
	int (*thaw_early)(struct device___408 *);
	int (*poweroff_late)(struct device___408 *);
	int (*restore_early)(struct device___408 *);
	int (*suspend_noirq)(struct device___408 *);
	int (*resume_noirq)(struct device___408 *);
	int (*freeze_noirq)(struct device___408 *);
	int (*thaw_noirq)(struct device___408 *);
	int (*poweroff_noirq)(struct device___408 *);
	int (*restore_noirq)(struct device___408 *);
	int (*runtime_suspend)(struct device___408 *);
	int (*runtime_resume)(struct device___408 *);
	int (*runtime_idle)(struct device___408 *);
};

struct dev_pm_domain___408 {
	struct dev_pm_ops___408 ops;
	void (*detach)(struct device___408 *, bool);
	int (*activate)(struct device___408 *);
	void (*sync)(struct device___408 *);
	void (*dismiss)(struct device___408 *);
};

struct bus_type___408 {
	const char *name;
	const char *dev_name;
	struct device___408 *dev_root;
	const struct attribute_group___405 **bus_groups;
	const struct attribute_group___405 **dev_groups;
	const struct attribute_group___405 **drv_groups;
	int (*match)(struct device___408 *, struct device_driver___408 *);
	int (*uevent)(struct device___408 *, struct kobj_uevent_env *);
	int (*probe)(struct device___408 *);
	int (*remove)(struct device___408 *);
	void (*shutdown)(struct device___408 *);
	int (*online)(struct device___408 *);
	int (*offline)(struct device___408 *);
	int (*suspend)(struct device___408 *, pm_message_t);
	int (*resume)(struct device___408 *);
	int (*num_vf)(struct device___408 *);
	int (*dma_configure)(struct device___408 *);
	const struct dev_pm_ops___408 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___408 {
	const char *name;
	struct bus_type___408 *bus;
	struct module___367 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___408 *);
	int (*remove)(struct device___408 *);
	void (*shutdown)(struct device___408 *);
	int (*suspend)(struct device___408 *, pm_message_t);
	int (*resume)(struct device___408 *);
	const struct attribute_group___405 **groups;
	const struct dev_pm_ops___408 *pm;
	void (*coredump)(struct device___408 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___408 {
	const char *name;
	const struct attribute_group___405 **groups;
	int (*uevent)(struct device___408 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___408 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___408 *);
	const struct dev_pm_ops___408 *pm;
};

struct class___408 {
	const char *name;
	struct module___367 *owner;
	const struct attribute_group___405 **class_groups;
	const struct attribute_group___405 **dev_groups;
	struct kobject___428 *dev_kobj;
	int (*dev_uevent)(struct device___408 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___408 *, umode_t *);
	void (*class_release)(struct class___408 *);
	void (*dev_release)(struct device___408 *);
	int (*shutdown_pre)(struct device___408 *);
	const struct kobj_ns_type_operations___65 *ns_type;
	const void * (*namespace)(struct device___408 *);
	const struct dev_pm_ops___408 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___180 {
	void * (*alloc)(struct device___408 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___408 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___408 *, struct vm_area_struct___441 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___408 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___408 *, struct page___441 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___408 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___408 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___408 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___408 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___408 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___408 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___408 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___408 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___408 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___408 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___408 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___408 *, u64);
	u64 (*get_required_mask)(struct device___408 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___328;

struct fwnode_handle___328 {
	struct fwnode_handle___328 *secondary;
	const struct fwnode_operations___328 *ops;
};

struct fwnode_reference_args___328;

struct fwnode_endpoint___328;

struct fwnode_operations___328 {
	struct fwnode_handle___328 * (*get)(struct fwnode_handle___328 *);
	void (*put)(struct fwnode_handle___328 *);
	bool (*device_is_available)(const struct fwnode_handle___328 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___328 *, const struct device___408 *);
	bool (*property_present)(const struct fwnode_handle___328 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___328 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___328 *, const char *, const char **, size_t);
	struct fwnode_handle___328 * (*get_parent)(const struct fwnode_handle___328 *);
	struct fwnode_handle___328 * (*get_next_child_node)(const struct fwnode_handle___328 *, struct fwnode_handle___328 *);
	struct fwnode_handle___328 * (*get_named_child_node)(const struct fwnode_handle___328 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___328 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___328 *);
	struct fwnode_handle___328 * (*graph_get_next_endpoint)(const struct fwnode_handle___328 *, struct fwnode_handle___328 *);
	struct fwnode_handle___328 * (*graph_get_remote_endpoint)(const struct fwnode_handle___328 *);
	struct fwnode_handle___328 * (*graph_get_port_parent)(struct fwnode_handle___328 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___328 *, struct fwnode_endpoint___328 *);
};

struct fwnode_endpoint___328 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___328 *local_fwnode;
};

struct fwnode_reference_args___328 {
	struct fwnode_handle___328 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___121;

struct pipe_buffer___121 {
	struct page___441 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___121 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___121 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___121 *, struct pipe_buffer___121 *);
	void (*release)(struct pipe_inode_info___121 *, struct pipe_buffer___121 *);
	int (*steal)(struct pipe_inode_info___121 *, struct pipe_buffer___121 *);
	union {
		bool (*get)(struct pipe_inode_info___121 *, struct pipe_buffer___121 *);
		struct {
			void (*get)(struct pipe_inode_info___121 *, struct pipe_buffer___121 *);
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
};

struct nf_bridge_info___85 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___85 = 0,
		BRNF_PROTO_8021Q___85 = 1,
		BRNF_PROTO_PPPOE___85 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___85 *physindev;
	struct net_device___85 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___85(struct sk_buff___86 **);

struct net_device_ops___85;

struct ethtool_ops___85;

struct l3mdev_ops___65;

struct ndisc_ops___36;

struct xfrmdev_ops___85;

struct tlsdev_ops___85;

struct header_ops___85;

struct inet6_dev___36;

struct netdev_rx_queue___85;

struct mini_Qdisc___77;

struct netdev_queue___85;

struct Qdisc___77;

struct rtnl_link_ops___77;

struct dcbnl_rtnl_ops___85;

struct net_device___85 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___85 *netdev_ops;
	const struct ethtool_ops___85 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___65 *l3mdev_ops;
	const struct ndisc_ops___36 *ndisc_ops;
	const struct xfrmdev_ops___85 *xfrmdev_ops;
	const struct tlsdev_ops___85 *tlsdev_ops;
	const struct header_ops___85 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___427 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___36 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___85 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___75 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___85 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___77 *miniq_ingress;
	struct netdev_queue___85 *ingress_queue;
	struct nf_hook_entries___10 *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___85 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___77 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___77 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___85 = 0,
		NETREG_REGISTERED___85 = 1,
		NETREG_UNREGISTERING___85 = 2,
		NETREG_UNREGISTERED___85 = 3,
		NETREG_RELEASED___85 = 4,
		NETREG_DUMMY___85 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___85 = 0,
		RTNL_LINK_INITIALIZING___85 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___85 *);
	struct netpoll_info *npinfo;
	possible_net_t___87 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___408 dev;
	const struct attribute_group___405 *sysfs_groups[4];
	const struct attribute_group___405 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___77 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___85 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct skb_frag_struct___17 {
	struct {
		struct page___441 *p;
	} page;
	__u32 page_offset;
	__u32 size;
};

typedef struct skb_frag_struct___17 skb_frag_t___17;

struct skb_shared_info___17 {
	__u8 __unused;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___86 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___17 frags[16];
};

struct xfrm_state___9;

struct sec_path___9 {
	refcount_t refcnt;
	int len;
	int olen;
	struct xfrm_state___9 *xvec[6];
	struct xfrm_offload ovec[1];
};

struct ethtool_ops___85 {
	int (*get_settings)(struct net_device___85 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___85 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___85 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___85 *);
	void (*get_regs)(struct net_device___85 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___85 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___85 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___85 *);
	void (*set_msglevel)(struct net_device___85 *, u32);
	int (*nway_reset)(struct net_device___85 *);
	u32 (*get_link)(struct net_device___85 *);
	int (*get_eeprom_len)(struct net_device___85 *);
	int (*get_eeprom)(struct net_device___85 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___85 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___85 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___85 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___85 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___85 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___85 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___85 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___85 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___85 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___85 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___85 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___85 *);
	void (*complete)(struct net_device___85 *);
	u32 (*get_priv_flags)(struct net_device___85 *);
	int (*set_priv_flags)(struct net_device___85 *, u32);
	int (*get_sset_count)(struct net_device___85 *, int);
	int (*get_rxnfc)(struct net_device___85 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___85 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___85 *, struct ethtool_flash *);
	int (*reset)(struct net_device___85 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___85 *);
	u32 (*get_rxfh_indir_size)(struct net_device___85 *);
	int (*get_rxfh)(struct net_device___85 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___85 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___85 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___85 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___85 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___85 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___85 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___85 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___85 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___85 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___85 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___85 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___85 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___85 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___85 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___85 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___85 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___85 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___85 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___85 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___85 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___85 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	int (*get_fecparam)(struct net_device___85 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___85 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___85 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___85 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___85 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___85;

struct inet_frags___85 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___85 *, const void *);
	void (*destructor)(struct inet_frag_queue___85 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___85 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___86 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___86 *fragments_tail;
	struct sk_buff___86 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___85 *net;
	struct callback_head rcu;
};

struct ip_ra_chain___31 {
	struct ip_ra_chain___31 *next;
	struct sock___66 *sk;
	union {
		void (*destructor)(struct sock___66 *);
		struct sock___66 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___65;

struct fib_lookup_arg___65;

struct fib_rules_ops___65 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___65 *, struct flowi *, int, struct fib_lookup_arg___65 *);
	bool (*suppress)(struct fib_rule___65 *, struct fib_lookup_arg___65 *);
	int (*match)(struct fib_rule___65 *, struct flowi *, int);
	int (*configure)(struct fib_rule___65 *, struct sk_buff___86 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___65 *);
	int (*compare)(struct fib_rule___65 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___65 *, struct sk_buff___86 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___65 *);
	void (*flush_cache)(struct fib_rules_ops___65 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___367 *owner;
	struct net___96 *fro_net;
	struct callback_head rcu;
};

struct tcp_congestion_ops___12 {
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___66 *);
	void (*release)(struct sock___66 *);
	u32 (*ssthresh)(struct sock___66 *);
	void (*cong_avoid)(struct sock___66 *, u32, u32);
	void (*set_state)(struct sock___66 *, u8);
	void (*cwnd_event)(struct sock___66 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___66 *, u32);
	u32 (*undo_cwnd)(struct sock___66 *);
	void (*pkts_acked)(struct sock___66 *, const struct ack_sample *);
	u32 (*min_tso_segs)(struct sock___66 *);
	u32 (*sndbuf_expand)(struct sock___66 *);
	void (*cong_control)(struct sock___66 *, const struct rate_sample *);
	size_t (*get_info)(struct sock___66 *, u32, int *, union tcp_cc_info *);
	char name[16];
	struct module___367 *owner;
};

struct tcp_fastopen_context___12 {
	struct crypto_cipher___15 *tfm;
	__u8 key[16];
	struct callback_head rcu;
};

struct fib_notifier_ops___66 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___96 *);
	int (*fib_dump)(struct net___96 *, struct notifier_block *);
	struct module___367 *owner;
	struct callback_head rcu;
};

struct dst_entry___65 {
	struct net_device___85 *dev;
	struct dst_ops___96 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state___9 *xfrm;
	int (*input)(struct sk_buff___86 *);
	int (*output)(struct net___96 *, struct sock___66 *, struct sk_buff___86 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___65;

struct neigh_parms___65;

struct neigh_ops___65;

struct neighbour___65 {
	struct neighbour___65 *next;
	struct neigh_table___65 *tbl;
	struct neigh_parms___65 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___85 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___65 *, struct sk_buff___86 *);
	const struct neigh_ops___65 *ops;
	struct callback_head rcu;
	struct net_device___85 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct fib6_nh___13 {
	struct in6_addr nh_gw;
	struct net_device___85 *nh_dev;
	struct lwtunnel_state *nh_lwtstate;
	unsigned int nh_flags;
	atomic_t nh_upper_bound;
	int nh_weight;
};

struct fib6_node___13;

struct fib6_info___13 {
	struct fib6_table___13 *fib6_table;
	struct fib6_info___13 *fib6_next;
	struct fib6_node___13 *fib6_node;
	struct list_head fib6_siblings;
	unsigned int fib6_nsiblings;
	atomic_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	struct rt6_info___13 **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
	long unsigned int last_probe;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 exception_bucket_flushed: 1;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 dst_host: 1;
	u8 fib6_destroying: 1;
	u8 unused: 2;
	struct fib6_nh___13 fib6_nh;
	struct callback_head rcu;
};

struct rt6_info___13 {
	struct dst_entry___65 dst;
	struct fib6_info___13 *from;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___36 *rt6i_idev;
	u32 rt6i_flags;
	struct rt6key rt6i_prefsrc;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct fib6_node___13 {
	struct fib6_node___13 *parent;
	struct fib6_node___13 *left;
	struct fib6_node___13 *right;
	struct fib6_info___13 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info___13 *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table___13 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node___13 tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

struct nf_hook_state___10;

typedef unsigned int nf_hookfn___10(void *, struct sk_buff___86 *, const struct nf_hook_state___10 *);

struct nf_hook_entry___10 {
	nf_hookfn___10 *hook;
	void *priv;
};

struct nf_hook_entries___10 {
	u16 num_hook_entries;
	struct nf_hook_entry___10 hooks[0];
};

struct ucounts___305 {
	struct hlist_node node;
	struct user_namespace___305 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_prog_aux___78;

struct bpf_prog___75 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___78 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

typedef int (*key_restrict_link_func_t___409)(struct key___408 *, const struct key_type *, const union key_payload *, struct key___408 *);

struct key_restriction___408;

struct key___408 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___442 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___408 *restrict_link;
};

struct key_restriction___408 {
	key_restrict_link_func_t___409 check;
	struct key___408 *key;
	struct key_type *keytype;
};

struct seq_operations___379 {
	void * (*start)(struct seq_file___379 *, loff_t *);
	void (*stop)(struct seq_file___379 *, void *);
	void * (*next)(struct seq_file___379 *, void *, loff_t *);
	int (*show)(struct seq_file___379 *, void *);
};

struct pernet_operations___86 {
	struct list_head list;
	int (*init)(struct net___96 *);
	void (*exit)(struct net___96 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___85 {
	int (*ieee_getets)(struct net_device___85 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___85 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___85 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___85 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___85 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___85 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___85 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___85 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___85 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___85 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___85 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___85 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___85 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___85 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___85 *);
	u8 (*setstate)(struct net_device___85 *, u8);
	void (*getpermhwaddr)(struct net_device___85 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___85 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___85 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___85 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___85 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___85 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___85 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___85 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___85 *, int, u8 *);
	void (*setpfccfg)(struct net_device___85 *, int, u8);
	void (*getpfccfg)(struct net_device___85 *, int, u8 *);
	u8 (*setall)(struct net_device___85 *);
	u8 (*getcap)(struct net_device___85 *, int, u8 *);
	int (*getnumtcs)(struct net_device___85 *, int, u8 *);
	int (*setnumtcs)(struct net_device___85 *, int, u8);
	u8 (*getpfcstate)(struct net_device___85 *);
	void (*setpfcstate)(struct net_device___85 *, u8);
	void (*getbcncfg)(struct net_device___85 *, int, u32 *);
	void (*setbcncfg)(struct net_device___85 *, int, u32);
	void (*getbcnrp)(struct net_device___85 *, int, u8 *);
	void (*setbcnrp)(struct net_device___85 *, int, u8);
	int (*setapp)(struct net_device___85 *, u8, u16, u8);
	int (*getapp)(struct net_device___85 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___85 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___85 *, int, u8);
	u8 (*getdcbx)(struct net_device___85 *);
	u8 (*setdcbx)(struct net_device___85 *, u8);
	int (*peer_getappinfo)(struct net_device___85 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___85 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___85 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___85 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___85 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___85 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___289 {
	refcount_t count;
	struct ns_common___29 ns;
	struct user_namespace___305 *user_ns;
	struct ucounts___305 *ucounts;
	struct css_set___289 *root_cset;
};

struct bpf_map___290;

struct bpf_map_ops___289 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___290 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___290 *, struct file___440 *);
	void (*map_free)(struct bpf_map___290 *);
	int (*map_get_next_key)(struct bpf_map___290 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___290 *);
	void * (*map_lookup_elem)(struct bpf_map___290 *, void *);
	int (*map_update_elem)(struct bpf_map___290 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___290 *, void *);
	int (*map_push_elem)(struct bpf_map___290 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___290 *, void *);
	int (*map_peek_elem)(struct bpf_map___290 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___290 *, struct file___440 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___290 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___290 *, void *, struct seq_file___379 *);
	int (*map_check_btf)(const struct bpf_map___290 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___290 {
	const struct bpf_map_ops___289 *ops;
	struct bpf_map___290 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___408 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___85;

struct bpf_map_dev_ops___85 {
	int (*map_get_next_key)(struct bpf_offloaded_map___85 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___85 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___85 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___85 *, void *);
};

struct bpf_offloaded_map___85 {
	struct bpf_map___290 map;
	struct net_device___85 *netdev;
	const struct bpf_map_dev_ops___85 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___75 {
	int (*test_run)(struct bpf_prog___75 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___75 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___75 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___75 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___75 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___75 *, u32 *);
};

struct bpf_prog_offload_ops___75 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___75 *);
	int (*translate)(struct bpf_prog___75 *);
	void (*destroy)(struct bpf_prog___75 *);
};

struct bpf_prog_offload___75 {
	struct bpf_prog___75 *prog;
	struct net_device___85 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___75 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___78 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___75 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___75 *ops;
	struct bpf_map___290 **used_maps;
	struct bpf_prog___75 *prog;
	struct user_struct___408 *user;
	u64 load_time;
	struct bpf_map___290 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___75 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___75 {
	struct bpf_prog___75 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___75 {
	struct callback_head rcu;
	struct bpf_prog_array_item___75 items[0];
};

struct cgroup_bpf___75 {
	struct bpf_prog_array___75 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___75 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___290;

typedef void (*kthread_work_func_t___290)(struct kthread_work___290 *);

struct kthread_worker___290;

struct kthread_work___290 {
	struct list_head node;
	kthread_work_func_t___290 func;
	struct kthread_worker___290 *worker;
	int canceling;
};

struct kthread_worker___290 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___442 *task;
	struct kthread_work___290 *current_work;
};

struct kthread_delayed_work___289 {
	struct kthread_work___290 work;
	struct timer_list timer;
};

struct psi_group___289 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___290 *poll_kworker;
	struct kthread_delayed_work___289 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___289;

struct cgroup_rstat_cpu___289;

struct cgroup___289 {
	struct cgroup_subsys_state___289 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___435 *kn;
	struct cgroup_file___289 procs_file;
	struct cgroup_file___289 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___289 *subsys[13];
	struct cgroup_root___289 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___289 *dom_cgrp;
	struct cgroup_rstat_cpu___289 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___75 bpf;
	atomic_t congestion_count;
	struct cgroup___289 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___289 psi;
	int ancestor_ids[0];
};

struct cftype___289;

struct cgroup_subsys___289 {
	struct cgroup_subsys_state___289 * (*css_alloc)(struct cgroup_subsys_state___289 *);
	int (*css_online)(struct cgroup_subsys_state___289 *);
	void (*css_offline)(struct cgroup_subsys_state___289 *);
	void (*css_released)(struct cgroup_subsys_state___289 *);
	void (*css_free)(struct cgroup_subsys_state___289 *);
	void (*css_reset)(struct cgroup_subsys_state___289 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___289 *, int);
	int (*css_extra_stat_show)(struct seq_file___379 *, struct cgroup_subsys_state___289 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___442 *);
	void (*cancel_fork)(struct task_struct___442 *);
	void (*fork)(struct task_struct___442 *);
	void (*exit)(struct task_struct___442 *);
	void (*free)(struct task_struct___442 *);
	void (*bind)(struct cgroup_subsys_state___289 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___289 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___289 *dfl_cftypes;
	struct cftype___289 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___289 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___289 *updated_children;
	struct cgroup___289 *updated_next;
};

struct cgroup_root___289 {
	struct kernfs_root___434 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___289 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___289 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___289 *ss;
	struct list_head node;
	struct kernfs_ops___434 *kf_ops;
	int (*open)(struct kernfs_open_file___434 *);
	void (*release)(struct kernfs_open_file___434 *);
	u64 (*read_u64)(struct cgroup_subsys_state___289 *, struct cftype___289 *);
	s64 (*read_s64)(struct cgroup_subsys_state___289 *, struct cftype___289 *);
	int (*seq_show)(struct seq_file___379 *, void *);
	void * (*seq_start)(struct seq_file___379 *, loff_t *);
	void * (*seq_next)(struct seq_file___379 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___379 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___289 *, struct cftype___289 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___289 *, struct cftype___289 *, s64);
	ssize_t (*write)(struct kernfs_open_file___434 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___434 *, struct poll_table_struct___279 *);
};

struct xdp_rxq_info___85 {
	struct net_device___85 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___85 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___85 *dev_rx;
};

struct netlink_callback___87 {
	struct sk_buff___86 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___87 *);
	int (*dump)(struct sk_buff___86 *, struct netlink_callback___87 *);
	int (*done)(struct netlink_callback___87 *);
	void *data;
	struct module___367 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___85 {
	int (*create)(struct sk_buff___86 *, struct net_device___85 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___86 *, unsigned char *);
	int (*cache)(const struct neighbour___65 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___85 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___85 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___85 *, int);
	int poll_owner;
	struct net_device___85 *dev;
	struct sk_buff___86 *gro_list;
	struct sk_buff___86 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___85 {
	struct net_device___85 *dev;
	struct Qdisc___77 *qdisc;
	struct Qdisc___77 *qdisc_sleeping;
	struct kobject___428 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___85 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___77 {
	struct sk_buff___86 *head;
	struct sk_buff___86 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___77;

struct Qdisc___77 {
	int (*enqueue)(struct sk_buff___86 *, struct Qdisc___77 *, struct sk_buff___86 **);
	struct sk_buff___86 * (*dequeue)(struct Qdisc___77 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___77 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___85 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___85 gso_skb;
	struct qdisc_skb_head___77 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___77 *next_sched;
	struct sk_buff_head___85 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___85 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___428 kobj;
	struct net_device___85 *dev;
	long: 64;
	struct xdp_rxq_info___85 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___85)(struct net_device___85 *, struct sk_buff___86 *, struct net_device___85 *);

struct netdev_bpf___85 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___75 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___75 *prog;
			const struct bpf_prog_offload_ops___75 *ops;
		} verifier;
		struct {
			struct bpf_prog___75 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___85 *offmap;
		};
		struct {
			struct xdp_umem___3 *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___85 {
	int (*xdo_dev_state_add)(struct xfrm_state___9 *);
	void (*xdo_dev_state_delete)(struct xfrm_state___9 *);
	void (*xdo_dev_state_free)(struct xfrm_state___9 *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___86 *, struct xfrm_state___9 *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state___9 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct xfrm_state_offload___9 {
	struct net_device___85 *dev;
	long unsigned int offload_handle;
	unsigned int num_exthdrs;
	u8 flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct xfrm_replay___9;

struct xfrm_type___9;

struct xfrm_mode___9;

struct xfrm_type_offload___9;

struct xfrm_state___9 {
	possible_net_t___87 xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	refcount_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
		u32 output_mark;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	const char *geniv;
	struct xfrm_encap_tmpl *encap;
	xfrm_address_t *coaddr;
	struct xfrm_state___9 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	const struct xfrm_replay___9 *repl;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct tasklet_hrtimer mtimer;
	struct xfrm_state_offload___9 xso;
	long int saved_tmo;
	long unsigned int lastused;
	struct page_frag___441 xfrag;
	const struct xfrm_type___9 *type;
	struct xfrm_mode___9 *inner_mode;
	struct xfrm_mode___9 *inner_mode_iaf;
	struct xfrm_mode___9 *outer_mode;
	const struct xfrm_type_offload___9 *type_offload;
	struct xfrm_sec_ctx___2 *security;
	void *data;
	u32 output_mark_mask;
	u32 if_id;
};

struct tlsdev_ops___85 {
	int (*tls_dev_add)(struct net_device___85 *, struct sock___66 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___85 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___85 *, struct sock___66 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___85 {
	int (*ndo_init)(struct net_device___85 *);
	void (*ndo_uninit)(struct net_device___85 *);
	int (*ndo_open)(struct net_device___85 *);
	int (*ndo_stop)(struct net_device___85 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___86 *, struct net_device___85 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___86 *, struct net_device___85 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___85 *, struct sk_buff___86 *, struct net_device___85 *, select_queue_fallback_t___85);
	void (*ndo_change_rx_flags)(struct net_device___85 *, int);
	void (*ndo_set_rx_mode)(struct net_device___85 *);
	int (*ndo_set_mac_address)(struct net_device___85 *, void *);
	int (*ndo_validate_addr)(struct net_device___85 *);
	int (*ndo_do_ioctl)(struct net_device___85 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___85 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___85 *, int);
	int (*ndo_neigh_setup)(struct net_device___85 *, struct neigh_parms___65 *);
	void (*ndo_tx_timeout)(struct net_device___85 *);
	void (*ndo_get_stats64)(struct net_device___85 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___85 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___85 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___85 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___85 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___85 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___85 *);
	int (*ndo_netpoll_setup)(struct net_device___85 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___85 *);
	int (*ndo_set_vf_mac)(struct net_device___85 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___85 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___85 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___85 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___85 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___85 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___85 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___85 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___85 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___85 *, int, struct sk_buff___86 *);
	int (*ndo_set_vf_guid)(struct net_device___85 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___85 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___85 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___85 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___85 *, const struct sk_buff___86 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___85 *, struct net_device___85 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___85 *, struct net_device___85 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___85 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___85 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___85 *, struct neighbour___65 *);
	void (*ndo_neigh_destroy)(struct net_device___85 *, struct neighbour___65 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___85 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___85 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___85 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___86 *, struct netlink_callback___87 *, struct net_device___85 *, struct net_device___85 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___85 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___85 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___86 *, u32, u32, struct net_device___85 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___85 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___85 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___85 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___85 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___85 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___85 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___85 *, struct net_device___85 *);
	void (*ndo_dfwd_del_station)(struct net_device___85 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___85 *);
	int (*ndo_set_tx_maxrate)(struct net_device___85 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___85 *);
	int (*ndo_change_proto_down)(struct net_device___85 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___85 *, struct sk_buff___86 *);
	void (*ndo_set_rx_headroom)(struct net_device___85 *, int);
	int (*ndo_bpf)(struct net_device___85 *, struct netdev_bpf___85 *);
	int (*ndo_xdp_xmit)(struct net_device___85 *, int, struct xdp_frame___85 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___85 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___85 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___65 {
	possible_net_t___87 net;
	struct net_device___85 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___65 *);
	void (*neigh_cleanup)(struct neighbour___65 *);
	struct neigh_table___65 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___65 {
	u32 (*l3mdev_fib_table)(const struct net_device___85 *);
	struct sk_buff___86 * (*l3mdev_l3_rcv)(struct net_device___85 *, struct sk_buff___86 *, u16);
	struct sk_buff___86 * (*l3mdev_l3_out)(struct net_device___85 *, struct sock___66 *, struct sk_buff___86 *, u16);
	struct dst_entry___65 * (*l3mdev_link_scope_lookup)(const struct net_device___85 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct ndisc_ops___36 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___85 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___85 *, struct neighbour___65 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___85 *, u8, struct neighbour___65 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___85 *, struct sk_buff___86 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___96 *, struct net_device___85 *, const struct prefix_info *, struct inet6_dev___36 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___36;

struct ifacaddr6___13;

struct inet6_dev___36 {
	struct net_device___85 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___36 *mc_list;
	struct ifmcaddr6___36 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___13 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	u8 rndid[8];
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___65 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
};

struct tcf_proto___77;

struct mini_Qdisc___77 {
	struct tcf_proto___77 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___77 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___85 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___96 *, struct net_device___85 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___85 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___85 *, struct list_head *);
	size_t (*get_size)(const struct net_device___85 *);
	int (*fill_info)(struct sk_buff___86 *, const struct net_device___85 *);
	size_t (*get_xstats_size)(const struct net_device___85 *);
	int (*fill_xstats)(struct sk_buff___86 *, const struct net_device___85 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___85 *, struct net_device___85 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___85 *, const struct net_device___85 *);
	int (*fill_slave_info)(struct sk_buff___86 *, const struct net_device___85 *, const struct net_device___85 *);
	struct net___96 * (*get_link_net)(const struct net_device___85 *);
	size_t (*get_linkxstats_size)(const struct net_device___85 *, int);
	int (*fill_linkxstats)(struct sk_buff___86 *, const struct net_device___85 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___85 {
	struct list_head poll_list;
	struct sk_buff_head___85 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___85 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___77 *output_queue;
	struct Qdisc___77 **output_queue_tailp;
	struct sk_buff___86 *completion_queue;
	struct sk_buff_head___85 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___85 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___85 input_pkt_queue;
	struct napi_struct___85 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bdi_writeback_congested___230 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___230 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___230 {
	struct bio___230 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___232 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___232 bip_inline_vecs[0];
};

struct bio_set___230 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___230 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___173 {
	struct mem_cgroup___173 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___173 {
	struct lruvec___441 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___173 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___173 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct kernel_param_ops___366 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___366 *);
	int (*get)(char *, const struct kernel_param___366 *);
	void (*free)(void *);
};

struct kparam_array___366;

struct kernel_param___366 {
	const char *name;
	struct module___367 *mod;
	const struct kernel_param_ops___366 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___366 *arr;
	};
};

struct kparam_array___366 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___366 *ops;
	void *elem;
};

struct module_attribute___366 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___366 *, struct module_kobject___366 *, char *);
	ssize_t (*store)(struct module_attribute___366 *, struct module_kobject___366 *, const char *, size_t);
	void (*setup)(struct module___367 *, const char *);
	int (*test)(struct module___367 *);
	void (*free)(struct module___367 *);
};

struct gnet_dump___77 {
	spinlock_t *lock;
	struct sk_buff___86 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___77;

struct Qdisc_ops___77 {
	struct Qdisc_ops___77 *next;
	const struct Qdisc_class_ops___77 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___86 *, struct Qdisc___77 *, struct sk_buff___86 **);
	struct sk_buff___86 * (*dequeue)(struct Qdisc___77 *);
	struct sk_buff___86 * (*peek)(struct Qdisc___77 *);
	int (*init)(struct Qdisc___77 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___77 *);
	void (*destroy)(struct Qdisc___77 *);
	int (*change)(struct Qdisc___77 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___77 *);
	int (*change_tx_queue_len)(struct Qdisc___77 *, unsigned int);
	int (*dump)(struct Qdisc___77 *, struct sk_buff___86 *);
	int (*dump_stats)(struct Qdisc___77 *, struct gnet_dump___77 *);
	void (*ingress_block_set)(struct Qdisc___77 *, u32);
	void (*egress_block_set)(struct Qdisc___77 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___77 *);
	u32 (*egress_block_get)(struct Qdisc___77 *);
	struct module___367 *owner;
};

struct tcf_block___77;

struct Qdisc_class_ops___77 {
	unsigned int flags;
	struct netdev_queue___85 * (*select_queue)(struct Qdisc___77 *, struct tcmsg *);
	int (*graft)(struct Qdisc___77 *, long unsigned int, struct Qdisc___77 *, struct Qdisc___77 **, struct netlink_ext_ack *);
	struct Qdisc___77 * (*leaf)(struct Qdisc___77 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___77 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___77 *, u32);
	int (*change)(struct Qdisc___77 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___77 *, long unsigned int);
	void (*walk)(struct Qdisc___77 *, struct qdisc_walker *);
	struct tcf_block___77 * (*tcf_block)(struct Qdisc___77 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___77 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___77 *, long unsigned int);
	int (*dump)(struct Qdisc___77 *, long unsigned int, struct sk_buff___86 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___77 *, long unsigned int, struct gnet_dump___77 *);
};

struct tcf_chain___77;

struct tcf_block___77 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___96 *net;
	struct Qdisc___77 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___77 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___77;

struct tcf_proto_ops___77;

struct tcf_proto___77 {
	struct tcf_proto___77 *next;
	void *root;
	int (*classify)(struct sk_buff___86 *, const struct tcf_proto___77 *, struct tcf_result___77 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___77 *ops;
	struct tcf_chain___77 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___77 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___77 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___77 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___86 *, const struct tcf_proto___77 *, struct tcf_result___77 *);
	int (*init)(struct tcf_proto___77 *);
	void (*destroy)(struct tcf_proto___77 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___77 *, u32);
	void (*put)(struct tcf_proto___77 *, void *);
	int (*change)(struct net___96 *, struct sk_buff___86 *, struct tcf_proto___77 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___77 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___77 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___77 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___96 *, struct tcf_chain___77 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___96 *, struct tcf_proto___77 *, void *, struct sk_buff___86 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___86 *, struct net___96 *, void *);
	struct module___367 *owner;
	int flags;
};

struct tcf_chain___77 {
	struct mutex filter_chain_lock;
	struct tcf_proto___77 *filter_chain;
	struct list_head list;
	struct tcf_block___77 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___77 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___65 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___75 *prog;
};

struct bpf_redirect_info___75 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___290 *map;
	struct bpf_map___290 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___65;

struct neigh_hash_table___65;

struct neigh_table___65 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___85 *, __u32 *);
	bool (*key_eq)(const struct neighbour___65 *, const void *);
	int (*constructor)(struct neighbour___65 *);
	int (*pconstructor)(struct pneigh_entry___65 *);
	void (*pdestructor)(struct pneigh_entry___65 *);
	void (*proxy_redo)(struct sk_buff___86 *);
	char *id;
	struct neigh_parms___65 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___85 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___65 *nht;
	struct pneigh_entry___65 **phash_buckets;
};

struct neigh_ops___65 {
	int family;
	void (*solicit)(struct neighbour___65 *, struct sk_buff___86 *);
	void (*error_report)(struct neighbour___65 *, struct sk_buff___86 *);
	int (*output)(struct neighbour___65 *, struct sk_buff___86 *);
	int (*connected_output)(struct neighbour___65 *, struct sk_buff___86 *);
};

struct pneigh_entry___65 {
	struct pneigh_entry___65 *next;
	possible_net_t___87 net;
	struct net_device___85 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___65 {
	struct neighbour___65 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___65 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___65 *ctarget;
	struct net___96 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___65 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___65 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___48;

struct timewait_sock_ops___44;

struct proto___65 {
	void (*close)(struct sock___66 *, long int);
	int (*pre_connect)(struct sock___66 *, struct sockaddr *, int);
	int (*connect)(struct sock___66 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___66 *, int);
	struct sock___66 * (*accept)(struct sock___66 *, int, int *, bool);
	int (*ioctl)(struct sock___66 *, int, long unsigned int);
	int (*init)(struct sock___66 *);
	void (*destroy)(struct sock___66 *);
	void (*shutdown)(struct sock___66 *, int);
	int (*setsockopt)(struct sock___66 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___66 *, int, int, char *, int *);
	void (*keepalive)(struct sock___66 *, int);
	int (*sendmsg)(struct sock___66 *, struct msghdr___68 *, size_t);
	int (*recvmsg)(struct sock___66 *, struct msghdr___68 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___66 *, struct page___441 *, int, size_t, int);
	int (*bind)(struct sock___66 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___66 *, struct sk_buff___86 *);
	void (*release_cb)(struct sock___66 *);
	int (*hash)(struct sock___66 *);
	void (*unhash)(struct sock___66 *);
	void (*rehash)(struct sock___66 *);
	int (*get_port)(struct sock___66 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___66 *);
	bool (*stream_memory_read)(const struct sock___66 *);
	void (*enter_memory_pressure)(struct sock___66 *);
	void (*leave_memory_pressure)(struct sock___66 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___48 *rsk_prot;
	struct timewait_sock_ops___44 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___367 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___66 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct xfrm_policy_queue___9 {
	struct sk_buff_head___85 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___9 {
	possible_net_t___87 xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	refcount_t refcnt;
	struct timer_list timer;
	atomic_t genid;
	u32 priority;
	u32 index;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___9 polq;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx___2 *security;
	struct xfrm_tmpl xfrm_vec[6];
	struct callback_head rcu;
	u32 if_id;
};

struct request_sock___49;

struct request_sock_ops___48 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___66 *, struct request_sock___49 *);
	void (*send_ack)(const struct sock___66 *, struct sk_buff___86 *, struct request_sock___49 *);
	void (*send_reset)(const struct sock___66 *, struct sk_buff___86 *);
	void (*destructor)(struct request_sock___49 *);
	void (*syn_ack_timeout)(const struct request_sock___49 *);
};

struct timewait_sock_ops___44 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___66 *, struct sock___66 *, void *);
	void (*twsk_destructor)(struct sock___66 *);
};

struct request_sock___49 {
	struct sock_common___65 __req_common;
	struct request_sock___49 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___48 *rsk_ops;
	struct sock___66 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___36 {
	struct in6_addr mca_addr;
	struct inet6_dev___36 *idev;
	struct ifmcaddr6___36 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___13 {
	struct in6_addr aca_addr;
	struct fib6_info___13 *aca_rt;
	struct ifacaddr6___13 *aca_next;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct ip6_ra_chain___36 {
	struct ip6_ra_chain___36 *next;
	struct sock___66 *sk;
	int sel;
	void (*destructor)(struct sock___66 *);
};

struct rtable___7 {
	struct dst_entry___65 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	__be32 rt_gateway;
	u32 rt_mtu_locked: 1;
	u32 rt_pmtu: 31;
	struct list_head rt_uncached;
	struct uncached_list *rt_uncached_list;
};

struct nf_hook_state___10 {
	unsigned int hook;
	u_int8_t pf;
	struct net_device___85 *in;
	struct net_device___85 *out;
	struct sock___66 *sk;
	struct net___96 *net;
	int (*okfn)(struct net___96 *, struct sock___66 *, struct sk_buff___86 *);
};

struct nf_nat_hook___10 {
	int (*parse_nat_setup)(struct nf_conn *, enum nf_nat_manip_type, const struct nlattr *);
	void (*decode_session)(struct sk_buff___86 *, struct flowi *);
	unsigned int (*manip_pkt)(struct sk_buff___86 *, struct nf_conn *, enum nf_nat_manip_type, enum ip_conntrack_dir);
};

struct nf_ct_hook___10 {
	int (*update)(struct net___96 *, struct sk_buff___86 *);
	void (*destroy)(struct nf_conntrack *);
	bool (*get_tuple_skb)(struct nf_conntrack_tuple *, const struct sk_buff___86 *);
};

struct nfnl_ct_hook___10 {
	struct nf_conn * (*get_ct)(const struct sk_buff___86 *, enum ip_conntrack_info *);
	size_t (*build_size)(const struct nf_conn *);
	int (*build)(struct sk_buff___86 *, struct nf_conn *, enum ip_conntrack_info, u_int16_t, u_int16_t);
	int (*parse)(const struct nlattr *, struct nf_conn *);
	int (*attach_expect)(const struct nlattr *, struct nf_conn *, u32, u32);
	void (*seq_adjust)(struct sk_buff___86 *, struct nf_conn *, enum ip_conntrack_info, s32);
};

struct xfrm_replay___9 {
	void (*advance)(struct xfrm_state___9 *, __be32);
	int (*check)(struct xfrm_state___9 *, struct sk_buff___86 *, __be32);
	int (*recheck)(struct xfrm_state___9 *, struct sk_buff___86 *, __be32);
	void (*notify)(struct xfrm_state___9 *, int);
	int (*overflow)(struct xfrm_state___9 *, struct sk_buff___86 *);
};

struct xfrm_type___9 {
	char *description;
	struct module___367 *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___9 *);
	void (*destructor)(struct xfrm_state___9 *);
	int (*input)(struct xfrm_state___9 *, struct sk_buff___86 *);
	int (*output)(struct xfrm_state___9 *, struct sk_buff___86 *);
	int (*reject)(struct xfrm_state___9 *, struct sk_buff___86 *, const struct flowi *);
	int (*hdr_offset)(struct xfrm_state___9 *, struct sk_buff___86 *, u8 **);
	u32 (*get_mtu)(struct xfrm_state___9 *, int);
};

struct xfrm_state_afinfo___9;

struct xfrm_mode___9 {
	int (*input2)(struct xfrm_state___9 *, struct sk_buff___86 *);
	int (*input)(struct xfrm_state___9 *, struct sk_buff___86 *);
	int (*output2)(struct xfrm_state___9 *, struct sk_buff___86 *);
	int (*output)(struct xfrm_state___9 *, struct sk_buff___86 *);
	struct sk_buff___86 * (*gso_segment)(struct xfrm_state___9 *, struct sk_buff___86 *, netdev_features_t);
	void (*xmit)(struct xfrm_state___9 *, struct sk_buff___86 *);
	struct xfrm_state_afinfo___9 *afinfo;
	struct module___367 *owner;
	unsigned int encap;
	int flags;
};

struct xfrm_type_offload___9 {
	char *description;
	struct module___367 *owner;
	u8 proto;
	void (*encap)(struct xfrm_state___9 *, struct sk_buff___86 *);
	int (*input_tail)(struct xfrm_state___9 *, struct sk_buff___86 *);
	int (*xmit)(struct xfrm_state___9 *, struct sk_buff___86 *, netdev_features_t);
};

struct xfrm_state_afinfo___9 {
	unsigned int family;
	unsigned int proto;
	__be16 eth_proto;
	struct module___367 *owner;
	const struct xfrm_type___9 *type_map[256];
	const struct xfrm_type_offload___9 *type_offload_map[256];
	struct xfrm_mode___9 *mode_map[5];
	int (*init_flags)(struct xfrm_state___9 *);
	void (*init_tempsel)(struct xfrm_selector *, const struct flowi *);
	void (*init_temprop)(struct xfrm_state___9 *, const struct xfrm_tmpl *, const xfrm_address_t *, const xfrm_address_t *);
	int (*tmpl_sort)(struct xfrm_tmpl **, struct xfrm_tmpl **, int);
	int (*state_sort)(struct xfrm_state___9 **, struct xfrm_state___9 **, int);
	int (*output)(struct net___96 *, struct sock___66 *, struct sk_buff___86 *);
	int (*output_finish)(struct sock___66 *, struct sk_buff___86 *);
	int (*extract_input)(struct xfrm_state___9 *, struct sk_buff___86 *);
	int (*extract_output)(struct xfrm_state___9 *, struct sk_buff___86 *);
	int (*transport_finish)(struct sk_buff___86 *, int);
	void (*local_error)(struct sk_buff___86 *, u32);
};

struct module___368;

struct file___441;

struct kiocb___441;

struct iov_iter___208;

struct poll_table_struct___280;

struct vm_area_struct___442;

struct inode___441;

struct file_lock___441;

struct page___442;

struct pipe_inode_info___122;

struct seq_file___380;

struct file_operations___441 {
	struct module___368 *owner;
	loff_t (*llseek)(struct file___441 *, loff_t, int);
	ssize_t (*read)(struct file___441 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___441 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___441 *, struct iov_iter___208 *);
	ssize_t (*write_iter)(struct kiocb___441 *, struct iov_iter___208 *);
	int (*iopoll)(struct kiocb___441 *, bool);
	int (*iterate)(struct file___441 *, struct dir_context *);
	int (*iterate_shared)(struct file___441 *, struct dir_context *);
	__poll_t (*poll)(struct file___441 *, struct poll_table_struct___280 *);
	long int (*unlocked_ioctl)(struct file___441 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___441 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___441 *, struct vm_area_struct___442 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___441 *, struct file___441 *);
	int (*flush)(struct file___441 *, fl_owner_t);
	int (*release)(struct inode___441 *, struct file___441 *);
	int (*fsync)(struct file___441 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___441 *, int);
	int (*lock)(struct file___441 *, int, struct file_lock___441 *);
	ssize_t (*sendpage)(struct file___441 *, struct page___442 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___441 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___441 *, int, struct file_lock___441 *);
	ssize_t (*splice_write)(struct pipe_inode_info___122 *, struct file___441 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___441 *, loff_t *, struct pipe_inode_info___122 *, size_t, unsigned int);
	int (*setlease)(struct file___441 *, long int, struct file_lock___441 **, void **);
	long int (*fallocate)(struct file___441 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___380 *, struct file___441 *);
	ssize_t (*copy_file_range)(struct file___441 *, loff_t, struct file___441 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___441 *, loff_t, struct file___441 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___441 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___442 {
	u64 seqnum;
	struct vm_area_struct___442 *vmas[4];
};

struct page_frag___442 {
	struct page___442 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___442;

struct mem_cgroup___174;

struct pid___245;

struct cred___409;

struct nsproxy___336;

struct signal_struct___316;

struct bio_list___231;

struct backing_dev_info___231;

struct css_set___290;

struct vm_struct___345;

struct task_struct___443 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___443 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___442 *mm;
	struct mm_struct___442 *active_mm;
	struct vmacache___442 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___443 *real_parent;
	struct task_struct___443 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___443 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___174 *active_memcg;
	long int rh_reserved2;
	struct pid___245 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___245 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___245 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___409 *ptracer_cred;
	const struct cred___409 *real_cred;
	const struct cred___409 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___336 *nsproxy;
	struct signal_struct___316 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___443 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___231 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___231 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___290 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___122 *splice_pipe;
	struct page_frag___442 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___174 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___443 *oom_reaper_list;
	struct vm_struct___345 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___156 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___245;

struct upid___245 {
	int nr;
	struct pid_namespace___245 *ns;
};

struct dentry___441;

struct user_namespace___306;

struct ucounts___306;

struct pid_namespace___245 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___443 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___245 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___441 *proc_self;
	struct dentry___441 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___306 *user_ns;
	struct ucounts___306 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___29 ns;
};

struct pid___245 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___245 numbers[1];
};

struct rw_semaphore___443 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___443 *owner;
};

struct key___409;

struct user_namespace___306 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___306 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___29 ns;
	long unsigned int flags;
	struct key___409 *persistent_keyring_register;
	struct rw_semaphore___443 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___306 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct secondary_data___443 {
	void *stack;
	struct task_struct___443 *task;
	long int status;
};

typedef struct page___442 *pgtable_t___442;

struct address_space___441;

struct dev_pagemap___429;

struct page___442 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___441 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___442 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___442 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___442 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___429 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___174 *mem_cgroup;
};

struct user_struct___409 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___409 *uid_keyring;
	struct key___409 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___429;

struct vm_area_struct___442 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___442 *vm_next;
	struct vm_area_struct___442 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___442 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___429 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___441 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___442;

struct mm_struct___442 {
	struct {
		struct vm_area_struct___442 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___441 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___443 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___442 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___443 *owner;
		struct user_namespace___306 *user_ns;
		struct file___441 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___442 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup___290;

struct cgroup_subsys___290;

struct cgroup_subsys_state___290 {
	struct cgroup___290 *cgroup;
	struct cgroup_subsys___290 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___290 *parent;
};

struct kernfs_node___436;

struct cgroup_file___290 {
	struct kernfs_node___436 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___174;

struct mem_cgroup___174 {
	struct cgroup_subsys_state___290 css;
	struct mem_cgroup_id___13 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___290 events_file;
	struct cgroup_file___290 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___443 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___174 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cred___409 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___409 *session_keyring;
	struct key___409 *process_keyring;
	struct key___409 *thread_keyring;
	struct key___409 *request_key_auth;
	void *security;
	struct user_struct___409 *user;
	struct user_namespace___306 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___97;

struct cgroup_namespace___290;

struct nsproxy___336 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___245 *pid_ns_for_children;
	struct net___97 *net_ns;
	struct cgroup_namespace___290 *cgroup_ns;
};

struct signal_struct___316 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___443 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___443 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___245 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___245 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___442 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___245 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___231;

struct bio_list___231 {
	struct bio___231 *head;
	struct bio___231 *tail;
};

struct bdi_writeback_congested___231;

struct bdi_writeback___231 {
	struct backing_dev_info___231 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___231 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___290 *memcg_css;
	struct cgroup_subsys_state___290 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___409;

struct backing_dev_info___231 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___231 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___409 *dev;
	struct device___409 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___441 *debug_dir;
	struct dentry___441 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___290 {
	struct cgroup_subsys_state___290 *subsys[13];
	refcount_t refcount;
	struct css_set___290 *dom_cset;
	struct cgroup___290 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___290 *mg_src_cgrp;
	struct cgroup___290 *mg_dst_cgrp;
	struct css_set___290 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___441;

struct pipe_buffer___122;

struct pipe_inode_info___122 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___442 *tmp_page;
	struct fasync_struct___441 *fasync_readers;
	struct fasync_struct___441 *fasync_writers;
	struct pipe_buffer___122 *bufs;
	struct user_struct___409 *user;
};

struct vm_struct___345 {
	struct vm_struct___345 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___442 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___328 {
	struct task_struct___443 task;
	long unsigned int stack[8192];
};

struct address_space_operations___441;

struct address_space___441 {
	struct inode___441 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___443 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___441 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___429)(struct vm_area_struct___442 *, long unsigned int, const struct page___442 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___429)(struct page___442 *, void *);

struct dev_pagemap___429 {
	dev_page_fault_t___429 page_fault;
	dev_page_free_t___429 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___409 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___442 {
	struct vfsmount *mnt;
	struct dentry___441 *dentry;
};

struct fown_struct___245 {
	rwlock_t lock;
	struct pid___245 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___441 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___442 f_path;
	struct inode___441 *f_inode;
	const struct file_operations___441 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___245 f_owner;
	const struct cred___409 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___441 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___429;

struct vm_operations_struct___429 {
	void (*open)(struct vm_area_struct___442 *);
	void (*close)(struct vm_area_struct___442 *);
	int (*split)(struct vm_area_struct___442 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___442 *);
	vm_fault_t (*fault)(struct vm_fault___429 *);
	vm_fault_t (*huge_fault)(struct vm_fault___429 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___429 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___442 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___429 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___429 *);
	int (*access)(struct vm_area_struct___442 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___442 *);
	int (*set_policy)(struct vm_area_struct___442 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___442 *, long unsigned int);
	struct page___442 * (*find_special_page)(struct vm_area_struct___442 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___442 {
	struct task_struct___443 *task;
	struct core_thread___442 *next;
};

struct core_state___442 {
	atomic_t nr_threads;
	struct core_thread___442 dumper;
	struct completion startup;
};

struct vm_fault___429 {
	struct vm_area_struct___442 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___442 *cow_page;
	struct mem_cgroup___174 *memcg;
	struct page___442 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___442 prealloc_pte;
};

struct pglist_data___442;

struct lruvec___442 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___442 *pgdat;
};

struct zone___442 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___442 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___442 {
	struct zone___442 *zone;
	int zone_idx;
};

struct zonelist___442 {
	struct zoneref___442 _zonerefs[25];
};

struct pglist_data___442 {
	struct zone___442 node_zones[3];
	struct zonelist___442 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___443 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___443 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___442 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___442 {
	struct rw_semaphore___443 rwsem;
	struct notifier_block *head;
};

struct kernfs_root___435;

struct kernfs_elem_dir___435 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___435 *root;
};

struct kernfs_syscall_ops___435;

struct kernfs_root___435 {
	struct kernfs_node___436 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___435 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___435 {
	struct kernfs_node___436 *target_kn;
};

struct kernfs_ops___435;

struct kernfs_elem_attr___435 {
	const struct kernfs_ops___435 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___436 *notify_next;
};

struct kernfs_node___436 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___436 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___435 dir;
		struct kernfs_elem_symlink___435 symlink;
		struct kernfs_elem_attr___435 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___435;

struct kernfs_ops___435 {
	int (*open)(struct kernfs_open_file___435 *);
	void (*release)(struct kernfs_open_file___435 *);
	int (*seq_show)(struct seq_file___380 *, void *);
	void * (*seq_start)(struct seq_file___380 *, loff_t *);
	void * (*seq_next)(struct seq_file___380 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___380 *, void *);
	ssize_t (*read)(struct kernfs_open_file___435 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___435 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___435 *, struct vm_area_struct___442 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___435 *, struct poll_table_struct___280 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___435 {
	int (*remount_fs)(struct kernfs_root___435 *, int *, char *);
	int (*show_options)(struct seq_file___380 *, struct kernfs_root___435 *);
	int (*mkdir)(struct kernfs_node___436 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___436 *);
	int (*rename)(struct kernfs_node___436 *, struct kernfs_node___436 *, const char *);
	int (*show_path)(struct seq_file___380 *, struct kernfs_node___436 *, struct kernfs_root___435 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___380;

struct seq_file___380 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___380 *op;
	int poll_event;
	const struct file___441 *file;
	void *private;
};

struct kernfs_open_file___435 {
	struct kernfs_node___436 *kn;
	struct file___441 *file;
	struct seq_file___380 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___429 *vm_ops;
};

typedef void (*poll_queue_proc___290)(struct file___441 *, wait_queue_head_t *, struct poll_table_struct___280 *);

struct poll_table_struct___280 {
	poll_queue_proc___290 _qproc;
	__poll_t _key;
};

struct sock___67;

struct kobj_ns_type_operations___66 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___67 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___97 *net;
} possible_net_t___88;

struct proto___66;

struct sock_common___66 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___66 *skc_prot;
	possible_net_t___88 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___67 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___87;

struct sk_buff_head___86 {
	struct sk_buff___87 *next;
	struct sk_buff___87 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___66;

struct socket_wq___67;

struct xfrm_policy___10;

struct dst_entry___66;

struct socket___68;

struct net_device___86;

struct sock___67 {
	struct sock_common___66 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___86 sk_error_queue;
	struct sk_buff_head___86 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___87 *head;
		struct sk_buff___87 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___66 *sk_filter;
	union {
		struct socket_wq___67 *sk_wq;
		struct socket_wq___67 *sk_wq_raw;
	};
	struct xfrm_policy___10 *sk_policy[2];
	struct dst_entry___66 *sk_rx_dst;
	struct dst_entry___66 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___87 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___86 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___442 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___66 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___245 *sk_peer_pid;
	const struct cred___409 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___68 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___174 *sk_memcg;
	void (*sk_state_change)(struct sock___67 *);
	void (*sk_data_ready)(struct sock___67 *);
	void (*sk_write_space)(struct sock___67 *);
	void (*sk_error_report)(struct sock___67 *);
	int (*sk_backlog_rcv)(struct sock___67 *, struct sk_buff___87 *);
	struct sk_buff___87 * (*sk_validate_xmit_skb)(struct sock___67 *, struct net_device___86 *, struct sk_buff___87 *);
	void (*sk_destruct)(struct sock___67 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kobject___429;

struct bin_attribute___405;

struct attribute_group___406 {
	const char *name;
	umode_t (*is_visible)(struct kobject___429 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___429 *, struct bin_attribute___405 *, int);
	struct attribute **attrs;
	struct bin_attribute___405 **bin_attrs;
};

struct kset___428;

struct kobj_type___428;

struct kobject___429 {
	const char *name;
	struct list_head entry;
	struct kobject___429 *parent;
	struct kset___428 *kset;
	struct kobj_type___428 *ktype;
	struct kernfs_node___436 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___405 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___441 *, struct kobject___429 *, struct bin_attribute___405 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___441 *, struct kobject___429 *, struct bin_attribute___405 *, char *, loff_t, size_t);
	int (*mmap)(struct file___441 *, struct kobject___429 *, struct bin_attribute___405 *, struct vm_area_struct___442 *);
};

struct sysfs_ops___428 {
	ssize_t (*show)(struct kobject___429 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___429 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___428;

struct kset___428 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___429 kobj;
	const struct kset_uevent_ops___428 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___428 {
	void (*release)(struct kobject___429 *);
	const struct sysfs_ops___428 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___66 * (*child_ns_type)(struct kobject___429 *);
	const void * (*namespace)(struct kobject___429 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___428 {
	int (* const filter)(struct kset___428 *, struct kobject___429 *);
	const char * (* const name)(struct kset___428 *, struct kobject___429 *);
	int (* const uevent)(struct kset___428 *, struct kobject___429 *, struct kobj_uevent_env *);
};

struct kobj_attribute___419 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___429 *, struct kobj_attribute___419 *, char *);
	ssize_t (*store)(struct kobject___429 *, struct kobj_attribute___419 *, const char *, size_t);
};

struct kernel_param___367;

struct kernel_param_ops___367 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___367 *);
	int (*get)(char *, const struct kernel_param___367 *);
	void (*free)(void *);
};

struct kparam_array___367;

struct kernel_param___367 {
	const char *name;
	struct module___368 *mod;
	const struct kernel_param_ops___367 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___367 *arr;
	};
};

struct kparam_array___367 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___367 *ops;
	void *elem;
};

struct module_kobject___367 {
	struct kobject___429 kobj;
	struct module___368 *mod;
	struct kobject___429 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___367 {
	struct module___368 *mod;
	struct latch_tree_node node;
};

struct module_layout___367 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___367 mtn;
};

struct module_attribute___367;

struct module___368 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___367 mkobj;
	struct module_attribute___367 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___429 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___367 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___367 core_layout;
	struct module_layout___367 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___367 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___367 *, struct module_kobject___367 *, char *);
	ssize_t (*store)(struct module_attribute___367 *, struct module_kobject___367 *, const char *, size_t);
	void (*setup)(struct module___368 *, const char *);
	int (*test)(struct module___368 *);
	void (*free)(struct module___368 *);
};

struct shrink_control___174 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___174 *memcg;
};

struct shrinker___174 {
	long unsigned int (*count_objects)(struct shrinker___174 *, struct shrink_control___174 *);
	long unsigned int (*scan_objects)(struct shrinker___174 *, struct shrink_control___174 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct dev_pm_info___409 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___409 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___409;

struct bus_type___409;

struct device_driver___409;

struct dev_pm_domain___409;

struct dma_map_ops___181;

struct fwnode_handle___329;

struct class___409;

struct device___409 {
	struct device___409 *parent;
	struct device_private *p;
	struct kobject___429 kobj;
	const char *init_name;
	const struct device_type___409 *type;
	struct mutex mutex;
	struct bus_type___409 *bus;
	struct device_driver___409 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___409 power;
	struct dev_pm_domain___409 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___181 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___329 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___409 *class;
	const struct attribute_group___406 **groups;
	void (*release)(struct device___409 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___441;

struct super_block___441;

struct dentry___441 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___441 *d_parent;
	struct qstr d_name;
	struct inode___441 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___441 *d_op;
	struct super_block___441 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___441;

struct block_device___441;

struct inode___441 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___441 *i_op;
	struct super_block___441 *i_sb;
	struct address_space___441 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___443 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___231 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___441 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___441 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___122 *i_pipe;
		struct block_device___441 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___441 {
	int (*d_revalidate)(struct dentry___441 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___441 *, unsigned int);
	int (*d_hash)(const struct dentry___441 *, struct qstr *);
	int (*d_compare)(const struct dentry___441 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___441 *);
	int (*d_init)(struct dentry___441 *);
	void (*d_release)(struct dentry___441 *);
	void (*d_prune)(struct dentry___441 *);
	void (*d_iput)(struct dentry___441 *, struct inode___441 *);
	char * (*d_dname)(struct dentry___441 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___442 *);
	int (*d_manage)(const struct path___442 *, bool);
	struct dentry___441 * (*d_real)(struct dentry___441 *, const struct inode___441 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___441;

struct mem_dqinfo___441 {
	struct quota_format_type___441 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___441;

struct quota_info___441 {
	unsigned int flags;
	struct rw_semaphore___443 dqio_sem;
	struct inode___441 *files[3];
	struct mem_dqinfo___441 info[3];
	const struct quota_format_ops___441 *ops[3];
};

struct rcuwait___441 {
	struct task_struct___443 *task;
};

struct percpu_rw_semaphore___441 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___443 rw_sem;
	struct rcuwait___441 writer;
	int readers_block;
};

struct sb_writers___441 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___441 rw_sem[3];
};

struct file_system_type___441;

struct super_operations___441;

struct dquot_operations___441;

struct quotactl_ops___441;

struct super_block___441 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___441 *s_type;
	const struct super_operations___441 *s_op;
	const struct dquot_operations___441 *dq_op;
	const struct quotactl_ops___441 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___441 *s_root;
	struct rw_semaphore___443 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___441 *s_bdev;
	struct backing_dev_info___231 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___441 s_dquot;
	struct sb_writers___441 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___441 *s_d_op;
	int cleancache_poolid;
	struct shrinker___174 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___306 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___441 {
	struct file___441 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___441 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___441 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___441 *ia_file;
};

struct dquot___441 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___441 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___441 {
	int qf_fmt_id;
	const struct quota_format_ops___441 *qf_ops;
	struct module___368 *qf_owner;
	struct quota_format_type___441 *qf_next;
};

struct quota_format_ops___441 {
	int (*check_quota_file)(struct super_block___441 *, int);
	int (*read_file_info)(struct super_block___441 *, int);
	int (*write_file_info)(struct super_block___441 *, int);
	int (*free_file_info)(struct super_block___441 *, int);
	int (*read_dqblk)(struct dquot___441 *);
	int (*commit_dqblk)(struct dquot___441 *);
	int (*release_dqblk)(struct dquot___441 *);
	int (*get_next_id)(struct super_block___441 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___441 {
	int (*write_dquot)(struct dquot___441 *);
	struct dquot___441 * (*alloc_dquot)(struct super_block___441 *, int);
	void (*destroy_dquot)(struct dquot___441 *);
	int (*acquire_dquot)(struct dquot___441 *);
	int (*release_dquot)(struct dquot___441 *);
	int (*mark_dirty)(struct dquot___441 *);
	int (*write_info)(struct super_block___441 *, int);
	qsize_t * (*get_reserved_space)(struct inode___441 *);
	int (*get_projid)(struct inode___441 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___441 *, qsize_t *);
	int (*get_next_id)(struct super_block___441 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___441 {
	int (*quota_on)(struct super_block___441 *, int, int, const struct path___442 *);
	int (*quota_off)(struct super_block___441 *, int);
	int (*quota_enable)(struct super_block___441 *, unsigned int);
	int (*quota_disable)(struct super_block___441 *, unsigned int);
	int (*quota_sync)(struct super_block___441 *, int);
	int (*set_info)(struct super_block___441 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___441 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___441 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___441 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___441 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___441 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___194;

struct address_space_operations___441 {
	int (*writepage)(struct page___442 *, struct writeback_control___194 *);
	int (*readpage)(struct file___441 *, struct page___442 *);
	int (*writepages)(struct address_space___441 *, struct writeback_control___194 *);
	int (*set_page_dirty)(struct page___442 *);
	int (*readpages)(struct file___441 *, struct address_space___441 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___441 *, struct address_space___441 *, loff_t, unsigned int, unsigned int, struct page___442 **, void **);
	int (*write_end)(struct file___441 *, struct address_space___441 *, loff_t, unsigned int, unsigned int, struct page___442 *, void *);
	sector_t (*bmap)(struct address_space___441 *, sector_t);
	void (*invalidatepage)(struct page___442 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___442 *, gfp_t);
	void (*freepage)(struct page___442 *);
	ssize_t (*direct_IO)(struct kiocb___441 *, struct iov_iter___208 *);
	int (*migratepage)(struct address_space___441 *, struct page___442 *, struct page___442 *, enum migrate_mode);
	bool (*isolate_page)(struct page___442 *, isolate_mode_t);
	void (*putback_page)(struct page___442 *);
	int (*launder_page)(struct page___442 *);
	int (*is_partially_uptodate)(struct page___442 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___442 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___441 *, struct page___442 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___441 *, sector_t *);
	void (*swap_deactivate)(struct file___441 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___194 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___231 *wb;
	struct inode___441 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___233;

struct iov_iter___208 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___233 *bvec;
		struct pipe_inode_info___122 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___441 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___441 *bd_inode;
	struct super_block___441 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___441 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___231 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___441 {
	struct dentry___441 * (*lookup)(struct inode___441 *, struct dentry___441 *, unsigned int);
	const char * (*get_link)(struct dentry___441 *, struct inode___441 *, struct delayed_call *);
	int (*permission)(struct inode___441 *, int);
	struct posix_acl * (*get_acl)(struct inode___441 *, int);
	int (*readlink)(struct dentry___441 *, char *, int);
	int (*create)(struct inode___441 *, struct dentry___441 *, umode_t, bool);
	int (*link)(struct dentry___441 *, struct inode___441 *, struct dentry___441 *);
	int (*unlink)(struct inode___441 *, struct dentry___441 *);
	int (*symlink)(struct inode___441 *, struct dentry___441 *, const char *);
	int (*mkdir)(struct inode___441 *, struct dentry___441 *, umode_t);
	int (*rmdir)(struct inode___441 *, struct dentry___441 *);
	int (*mknod)(struct inode___441 *, struct dentry___441 *, umode_t, dev_t);
	int (*rename)(struct inode___441 *, struct dentry___441 *, struct inode___441 *, struct dentry___441 *, unsigned int);
	int (*setattr)(struct dentry___441 *, struct iattr___441 *);
	int (*getattr)(const struct path___442 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___441 *, char *, size_t);
	int (*fiemap)(struct inode___441 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___441 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___441 *, struct dentry___441 *, struct file___441 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___441 *, struct dentry___441 *, umode_t);
	int (*set_acl)(struct inode___441 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___441 {
	void (*fl_copy_lock)(struct file_lock___441 *, struct file_lock___441 *);
	void (*fl_release_private)(struct file_lock___441 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___441;

struct file_lock___441 {
	struct file_lock___441 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___441 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___441 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___441 *fl_ops;
	const struct lock_manager_operations___441 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___441 {
	int (*lm_compare_owner)(struct file_lock___441 *, struct file_lock___441 *);
	long unsigned int (*lm_owner_key)(struct file_lock___441 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___441 *);
	int (*lm_grant)(struct file_lock___441 *, int);
	bool (*lm_break)(struct file_lock___441 *);
	int (*lm_change)(struct file_lock___441 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___441 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___441 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___441 *fa_next;
	struct file___441 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___441 {
	const char *name;
	int fs_flags;
	struct dentry___441 * (*mount)(struct file_system_type___441 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___441 *);
	struct module___368 *owner;
	struct file_system_type___441 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___441 {
	struct inode___441 * (*alloc_inode)(struct super_block___441 *);
	void (*destroy_inode)(struct inode___441 *);
	void (*dirty_inode)(struct inode___441 *, int);
	int (*write_inode)(struct inode___441 *, struct writeback_control___194 *);
	int (*drop_inode)(struct inode___441 *);
	void (*evict_inode)(struct inode___441 *);
	void (*put_super)(struct super_block___441 *);
	int (*sync_fs)(struct super_block___441 *, int);
	int (*freeze_super)(struct super_block___441 *);
	int (*freeze_fs)(struct super_block___441 *);
	int (*thaw_super)(struct super_block___441 *);
	int (*unfreeze_fs)(struct super_block___441 *);
	int (*statfs)(struct dentry___441 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___441 *, int *, char *);
	void (*umount_begin)(struct super_block___441 *);
	int (*show_options)(struct seq_file___380 *, struct dentry___441 *);
	int (*show_devname)(struct seq_file___380 *, struct dentry___441 *);
	int (*show_path)(struct seq_file___380 *, struct dentry___441 *);
	int (*show_stats)(struct seq_file___380 *, struct dentry___441 *);
	ssize_t (*quota_read)(struct super_block___441 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___441 *, int, const char *, size_t, loff_t);
	struct dquot___441 ** (*get_dquots)(struct inode___441 *);
	int (*bdev_try_to_free_page)(struct super_block___441 *, struct page___442 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___441 *, struct shrink_control___174 *);
	long int (*free_cached_objects)(struct super_block___441 *, struct shrink_control___174 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___231(struct bio___231 *);

struct bio_vec___233 {
	struct page___442 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___231;

struct bio_set___231;

struct bio___231 {
	struct bio___231 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___231 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___231 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___233 *bi_io_vec;
	struct bio_set___231 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___233 bi_inline_vecs[0];
};

typedef void compound_page_dtor___429(struct page___442 *);

struct msghdr___69 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___208 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___441 *msg_iocb;
};

struct inet_frags___86;

struct netns_frags___86 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___86 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct inet_frag_queue___86;

struct inet_frags___86 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___86 *, const void *);
	void (*destructor)(struct inet_frag_queue___86 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___86 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___87 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___87 *fragments_tail;
	struct sk_buff___87 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___86 *net;
	struct callback_head rcu;
};

struct sec_path___10;

struct nf_bridge_info___86;

struct sk_buff___87 {
	union {
		struct {
			struct sk_buff___87 *next;
			struct sk_buff___87 *prev;
			union {
				struct net_device___86 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___67 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___87 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path___10 *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___86 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct ip_ra_chain___32;

struct fib_rules_ops___66;

struct fib_notifier_ops___67;

struct netns_ipv4___86 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___32 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___66 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___67 *fibnl;
	struct sock___67 **icmp_sk;
	struct sock___67 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___67 **tcp_sk;
	struct netns_frags___86 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___66 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___67 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___67 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct ip_ra_chain___32 {
	struct ip_ra_chain___32 *next;
	struct sock___67 *sk;
	union {
		void (*destructor)(struct sock___67 *);
		struct sock___67 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___66;

struct fib_lookup_arg___66;

struct fib_rules_ops___66 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___66 *, struct flowi *, int, struct fib_lookup_arg___66 *);
	bool (*suppress)(struct fib_rule___66 *, struct fib_lookup_arg___66 *);
	int (*match)(struct fib_rule___66 *, struct flowi *, int);
	int (*configure)(struct fib_rule___66 *, struct sk_buff___87 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___66 *);
	int (*compare)(struct fib_rule___66 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___66 *, struct sk_buff___87 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___66 *);
	void (*flush_cache)(struct fib_rules_ops___66 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___368 *owner;
	struct net___97 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___67 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___97 *);
	int (*fib_dump)(struct net___97 *, struct notifier_block *);
	struct module___368 *owner;
	struct callback_head rcu;
};

struct neighbour___66;

struct dst_ops___97 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___97 *);
	struct dst_entry___66 * (*check)(struct dst_entry___66 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___66 *);
	unsigned int (*mtu)(const struct dst_entry___66 *);
	u32 * (*cow_metrics)(struct dst_entry___66 *, long unsigned int);
	void (*destroy)(struct dst_entry___66 *);
	void (*ifdown)(struct dst_entry___66 *, struct net_device___86 *, int);
	struct dst_entry___66 * (*negative_advice)(struct dst_entry___66 *);
	void (*link_failure)(struct sk_buff___87 *);
	void (*update_pmtu)(struct dst_entry___66 *, struct sock___67 *, struct sk_buff___87 *, u32);
	void (*redirect)(struct dst_entry___66 *, struct sock___67 *, struct sk_buff___87 *);
	int (*local_out)(struct net___97 *, struct sock___67 *, struct sk_buff___87 *);
	struct neighbour___66 * (*neigh_lookup)(const struct dst_entry___66 *, struct sk_buff___87 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___66 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct xfrm_state___10;

struct lwtunnel_state___8;

struct dst_entry___66 {
	struct net_device___86 *dev;
	struct dst_ops___97 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state___10 *xfrm;
	int (*input)(struct sk_buff___87 *);
	int (*output)(struct net___97 *, struct sock___67 *, struct sk_buff___87 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___8 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

typedef rx_handler_result_t rx_handler_func_t___86(struct sk_buff___87 **);

struct net_device_ops___86;

struct ethtool_ops___86;

struct l3mdev_ops___66;

struct ndisc_ops___37;

struct xfrmdev_ops___86;

struct tlsdev_ops___86;

struct header_ops___86;

struct inet6_dev___37;

struct netdev_rx_queue___86;

struct bpf_prog___76;

struct mini_Qdisc___78;

struct netdev_queue___86;

struct nf_hook_entries___11;

struct Qdisc___78;

struct rtnl_link_ops___78;

struct dcbnl_rtnl_ops___86;

struct net_device___86 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___86 *netdev_ops;
	const struct ethtool_ops___86 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___66 *l3mdev_ops;
	const struct ndisc_ops___37 *ndisc_ops;
	const struct xfrmdev_ops___86 *xfrmdev_ops;
	const struct tlsdev_ops___86 *tlsdev_ops;
	const struct header_ops___86 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___428 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___37 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___86 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___76 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___86 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___78 *miniq_ingress;
	struct netdev_queue___86 *ingress_queue;
	struct nf_hook_entries___11 *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___86 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___78 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___78 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___86 = 0,
		NETREG_REGISTERED___86 = 1,
		NETREG_UNREGISTERING___86 = 2,
		NETREG_UNREGISTERED___86 = 3,
		NETREG_RELEASED___86 = 4,
		NETREG_DUMMY___86 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___86 = 0,
		RTNL_LINK_INITIALIZING___86 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___86 *);
	struct netpoll_info *npinfo;
	possible_net_t___88 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___409 dev;
	const struct attribute_group___406 *sysfs_groups[4];
	const struct attribute_group___406 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___78 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___86 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide35;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct fib6_info___14;

struct rt6_info___14;

struct fib6_table___14;

struct netns_ipv6___97 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___86 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info___14 *fib6_null_entry;
	struct rt6_info___14 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___14 *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___97 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info___14 *ip6_prohibit_entry;
	struct rt6_info___14 *ip6_blk_hole_entry;
	struct fib6_table___14 *fib6_local_tbl;
	struct fib_rules_ops___66 *fib6_rules_ops;
	struct sock___67 **icmp_sk;
	struct sock___67 *ndisc_sk;
	struct sock___67 *tcp_sk;
	struct sock___67 *igmp_sk;
	struct sock___67 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___66 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___67 *notifier_ops;
	struct fib_notifier_ops___67 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___67 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___67 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf___12 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_queue_handler *queue_handler;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header *nf_log_dir_header;
	struct nf_hook_entries___11 *hooks_ipv4[5];
	struct nf_hook_entries___11 *hooks_ipv6[5];
	struct nf_hook_entries___11 *hooks_arp[3];
	struct nf_hook_entries___11 *hooks_bridge[5];
	bool defrag_ipv4;
	bool defrag_ipv6;
};

struct netns_nf_frag___86 {
	struct netns_frags___86 frags;
};

struct netns_xfrm___97 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___67 *nlsk;
	struct sock___67 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___97 xfrm4_dst_ops;
	struct dst_ops___97 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct net___97 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___306 *user_ns;
	struct ucounts___306 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___29 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___67 *rtnl;
	struct sock___67 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___86 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___86 ipv4;
	struct netns_ipv6___97 ipv6;
	struct netns_sctp___67 sctp;
	struct netns_nf___12 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___86 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___67 *nfnl;
	struct sock___67 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___97 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___67 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___76 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neigh_table___66;

struct neigh_parms___66;

struct neigh_ops___66;

struct neighbour___66 {
	struct neighbour___66 *next;
	struct neigh_table___66 *tbl;
	struct neigh_parms___66 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___86 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___66 *, struct sk_buff___87 *);
	const struct neigh_ops___66 *ops;
	struct callback_head rcu;
	struct net_device___86 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct fib6_nh___14 {
	struct in6_addr nh_gw;
	struct net_device___86 *nh_dev;
	struct lwtunnel_state___8 *nh_lwtstate;
	unsigned int nh_flags;
	atomic_t nh_upper_bound;
	int nh_weight;
};

struct fib6_node___14;

struct fib6_info___14 {
	struct fib6_table___14 *fib6_table;
	struct fib6_info___14 *fib6_next;
	struct fib6_node___14 *fib6_node;
	struct list_head fib6_siblings;
	unsigned int fib6_nsiblings;
	atomic_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	struct rt6_info___14 **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
	long unsigned int last_probe;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 exception_bucket_flushed: 1;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 dst_host: 1;
	u8 fib6_destroying: 1;
	u8 unused: 2;
	struct fib6_nh___14 fib6_nh;
	struct callback_head rcu;
};

struct rt6_info___14 {
	struct dst_entry___66 dst;
	struct fib6_info___14 *from;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___37 *rt6i_idev;
	u32 rt6i_flags;
	struct rt6key rt6i_prefsrc;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct fib6_node___14 {
	struct fib6_node___14 *parent;
	struct fib6_node___14 *left;
	struct fib6_node___14 *right;
	struct fib6_info___14 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info___14 *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table___14 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node___14 tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

struct nf_hook_state___11;

typedef unsigned int nf_hookfn___11(void *, struct sk_buff___87 *, const struct nf_hook_state___11 *);

struct nf_hook_entry___11 {
	nf_hookfn___11 *hook;
	void *priv;
};

struct nf_hook_entries___11 {
	u16 num_hook_entries;
	struct nf_hook_entry___11 hooks[0];
};

struct socket_wq___67 {
	wait_queue_head_t wait;
	struct fasync_struct___441 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___67;

struct socket___68 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___67 *wq;
	struct file___441 *file;
	struct sock___67 *sk;
	const struct proto_ops___67 *ops;
};

typedef int (*sk_read_actor_t___66)(read_descriptor_t *, struct sk_buff___87 *, unsigned int, size_t);

struct proto_ops___67 {
	int family;
	struct module___368 *owner;
	int (*release)(struct socket___68 *);
	int (*bind)(struct socket___68 *, struct sockaddr *, int);
	int (*connect)(struct socket___68 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___68 *, struct socket___68 *);
	int (*accept)(struct socket___68 *, struct socket___68 *, int, bool);
	int (*getname)(struct socket___68 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___441 *, struct socket___68 *, struct poll_table_struct___280 *);
	int (*ioctl)(struct socket___68 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___68 *, int);
	int (*shutdown)(struct socket___68 *, int);
	int (*setsockopt)(struct socket___68 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___68 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___68 *, struct msghdr___69 *, size_t);
	int (*recvmsg)(struct socket___68 *, struct msghdr___69 *, size_t, int);
	int (*mmap)(struct file___441 *, struct socket___68 *, struct vm_area_struct___442 *);
	ssize_t (*sendpage)(struct socket___68 *, struct page___442 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___68 *, loff_t *, struct pipe_inode_info___122 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___67 *, int);
	int (*peek_len)(struct socket___68 *);
	int (*read_sock)(struct sock___67 *, read_descriptor_t *, sk_read_actor_t___66);
	int (*sendpage_locked)(struct sock___67 *, struct page___442 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___67 *, struct msghdr___69 *, size_t);
	int (*set_rcvlowat)(struct sock___67 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct dev_pm_ops___409 {
	int (*prepare)(struct device___409 *);
	void (*complete)(struct device___409 *);
	int (*suspend)(struct device___409 *);
	int (*resume)(struct device___409 *);
	int (*freeze)(struct device___409 *);
	int (*thaw)(struct device___409 *);
	int (*poweroff)(struct device___409 *);
	int (*restore)(struct device___409 *);
	int (*suspend_late)(struct device___409 *);
	int (*resume_early)(struct device___409 *);
	int (*freeze_late)(struct device___409 *);
	int (*thaw_early)(struct device___409 *);
	int (*poweroff_late)(struct device___409 *);
	int (*restore_early)(struct device___409 *);
	int (*suspend_noirq)(struct device___409 *);
	int (*resume_noirq)(struct device___409 *);
	int (*freeze_noirq)(struct device___409 *);
	int (*thaw_noirq)(struct device___409 *);
	int (*poweroff_noirq)(struct device___409 *);
	int (*restore_noirq)(struct device___409 *);
	int (*runtime_suspend)(struct device___409 *);
	int (*runtime_resume)(struct device___409 *);
	int (*runtime_idle)(struct device___409 *);
};

struct dev_pm_domain___409 {
	struct dev_pm_ops___409 ops;
	void (*detach)(struct device___409 *, bool);
	int (*activate)(struct device___409 *);
	void (*sync)(struct device___409 *);
	void (*dismiss)(struct device___409 *);
};

struct bus_type___409 {
	const char *name;
	const char *dev_name;
	struct device___409 *dev_root;
	const struct attribute_group___406 **bus_groups;
	const struct attribute_group___406 **dev_groups;
	const struct attribute_group___406 **drv_groups;
	int (*match)(struct device___409 *, struct device_driver___409 *);
	int (*uevent)(struct device___409 *, struct kobj_uevent_env *);
	int (*probe)(struct device___409 *);
	int (*remove)(struct device___409 *);
	void (*shutdown)(struct device___409 *);
	int (*online)(struct device___409 *);
	int (*offline)(struct device___409 *);
	int (*suspend)(struct device___409 *, pm_message_t);
	int (*resume)(struct device___409 *);
	int (*num_vf)(struct device___409 *);
	int (*dma_configure)(struct device___409 *);
	const struct dev_pm_ops___409 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___409 {
	const char *name;
	struct bus_type___409 *bus;
	struct module___368 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___409 *);
	int (*remove)(struct device___409 *);
	void (*shutdown)(struct device___409 *);
	int (*suspend)(struct device___409 *, pm_message_t);
	int (*resume)(struct device___409 *);
	const struct attribute_group___406 **groups;
	const struct dev_pm_ops___409 *pm;
	void (*coredump)(struct device___409 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___409 {
	const char *name;
	const struct attribute_group___406 **groups;
	int (*uevent)(struct device___409 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___409 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___409 *);
	const struct dev_pm_ops___409 *pm;
};

struct class___409 {
	const char *name;
	struct module___368 *owner;
	const struct attribute_group___406 **class_groups;
	const struct attribute_group___406 **dev_groups;
	struct kobject___429 *dev_kobj;
	int (*dev_uevent)(struct device___409 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___409 *, umode_t *);
	void (*class_release)(struct class___409 *);
	void (*dev_release)(struct device___409 *);
	int (*shutdown_pre)(struct device___409 *);
	const struct kobj_ns_type_operations___66 *ns_type;
	const void * (*namespace)(struct device___409 *);
	const struct dev_pm_ops___409 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___181 {
	void * (*alloc)(struct device___409 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___409 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___409 *, struct vm_area_struct___442 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___409 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___409 *, struct page___442 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___409 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___409 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___409 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___409 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___409 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___409 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___409 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___409 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___409 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___409 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___409 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___409 *, u64);
	u64 (*get_required_mask)(struct device___409 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___329;

struct fwnode_handle___329 {
	struct fwnode_handle___329 *secondary;
	const struct fwnode_operations___329 *ops;
};

struct fwnode_reference_args___329;

struct fwnode_endpoint___329;

struct fwnode_operations___329 {
	struct fwnode_handle___329 * (*get)(struct fwnode_handle___329 *);
	void (*put)(struct fwnode_handle___329 *);
	bool (*device_is_available)(const struct fwnode_handle___329 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___329 *, const struct device___409 *);
	bool (*property_present)(const struct fwnode_handle___329 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___329 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___329 *, const char *, const char **, size_t);
	struct fwnode_handle___329 * (*get_parent)(const struct fwnode_handle___329 *);
	struct fwnode_handle___329 * (*get_next_child_node)(const struct fwnode_handle___329 *, struct fwnode_handle___329 *);
	struct fwnode_handle___329 * (*get_named_child_node)(const struct fwnode_handle___329 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___329 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___329 *);
	struct fwnode_handle___329 * (*graph_get_next_endpoint)(const struct fwnode_handle___329 *, struct fwnode_handle___329 *);
	struct fwnode_handle___329 * (*graph_get_remote_endpoint)(const struct fwnode_handle___329 *);
	struct fwnode_handle___329 * (*graph_get_port_parent)(struct fwnode_handle___329 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___329 *, struct fwnode_endpoint___329 *);
};

struct fwnode_endpoint___329 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___329 *local_fwnode;
};

struct fwnode_reference_args___329 {
	struct fwnode_handle___329 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___122;

struct pipe_buffer___122 {
	struct page___442 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___122 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___122 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___122 *, struct pipe_buffer___122 *);
	void (*release)(struct pipe_inode_info___122 *, struct pipe_buffer___122 *);
	int (*steal)(struct pipe_inode_info___122 *, struct pipe_buffer___122 *);
	union {
		bool (*get)(struct pipe_inode_info___122 *, struct pipe_buffer___122 *);
		struct {
			void (*get)(struct pipe_inode_info___122 *, struct pipe_buffer___122 *);
		} __UNIQUE_ID_rh_kabi_hide21;
		union {		};
	};
};

struct nf_bridge_info___86 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___86 = 0,
		BRNF_PROTO_8021Q___86 = 1,
		BRNF_PROTO_PPPOE___86 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___86 *physindev;
	struct net_device___86 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

struct skb_frag_struct___18 {
	struct {
		struct page___442 *p;
	} page;
	__u32 page_offset;
	__u32 size;
};

typedef struct skb_frag_struct___18 skb_frag_t___18;

struct mmpin___4 {
	struct user_struct___409 *user;
	unsigned int num_pg;
};

struct ubuf_info___4 {
	void (*callback)(struct ubuf_info___4 *, bool);
	union {
		struct {
			long unsigned int desc;
			void *ctx;
		};
		struct {
			u32 id;
			u16 len;
			u16 zerocopy: 1;
			u32 bytelen;
		};
	};
	refcount_t refcnt;
	struct mmpin___4 mmp;
};

struct skb_shared_info___18 {
	__u8 __unused;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___87 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___18 frags[16];
};

struct sec_path___10 {
	refcount_t refcnt;
	int len;
	int olen;
	struct xfrm_state___10 *xvec[6];
	struct xfrm_offload ovec[1];
};

struct ucounts___306 {
	struct hlist_node node;
	struct user_namespace___306 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_prog_aux___79;

struct bpf_prog___76 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___79 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

typedef int (*key_restrict_link_func_t___410)(struct key___409 *, const struct key_type *, const union key_payload *, struct key___409 *);

struct key_restriction___409;

struct key___409 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___443 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___409 *restrict_link;
};

struct key_restriction___409 {
	key_restrict_link_func_t___410 check;
	struct key___409 *key;
	struct key_type *keytype;
};

struct seq_operations___380 {
	void * (*start)(struct seq_file___380 *, loff_t *);
	void (*stop)(struct seq_file___380 *, void *);
	void * (*next)(struct seq_file___380 *, void *, loff_t *);
	int (*show)(struct seq_file___380 *, void *);
};

struct pernet_operations___87 {
	struct list_head list;
	int (*init)(struct net___97 *);
	void (*exit)(struct net___97 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct ethtool_ops___86 {
	int (*get_settings)(struct net_device___86 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___86 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___86 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___86 *);
	void (*get_regs)(struct net_device___86 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___86 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___86 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___86 *);
	void (*set_msglevel)(struct net_device___86 *, u32);
	int (*nway_reset)(struct net_device___86 *);
	u32 (*get_link)(struct net_device___86 *);
	int (*get_eeprom_len)(struct net_device___86 *);
	int (*get_eeprom)(struct net_device___86 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___86 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___86 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___86 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___86 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___86 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___86 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___86 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___86 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___86 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___86 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___86 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___86 *);
	void (*complete)(struct net_device___86 *);
	u32 (*get_priv_flags)(struct net_device___86 *);
	int (*set_priv_flags)(struct net_device___86 *, u32);
	int (*get_sset_count)(struct net_device___86 *, int);
	int (*get_rxnfc)(struct net_device___86 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___86 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___86 *, struct ethtool_flash *);
	int (*reset)(struct net_device___86 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___86 *);
	u32 (*get_rxfh_indir_size)(struct net_device___86 *);
	int (*get_rxfh)(struct net_device___86 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___86 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___86 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___86 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___86 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___86 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___86 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___86 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___86 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___86 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___86 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___86 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___86 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___86 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___86 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___86 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___86 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___86 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___86 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___86 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___86 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___86 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	int (*get_fecparam)(struct net_device___86 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___86 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___86 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___86 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___86 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct dcbnl_rtnl_ops___86 {
	int (*ieee_getets)(struct net_device___86 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___86 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___86 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___86 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___86 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___86 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___86 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___86 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___86 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___86 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___86 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___86 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___86 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___86 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___86 *);
	u8 (*setstate)(struct net_device___86 *, u8);
	void (*getpermhwaddr)(struct net_device___86 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___86 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___86 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___86 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___86 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___86 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___86 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___86 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___86 *, int, u8 *);
	void (*setpfccfg)(struct net_device___86 *, int, u8);
	void (*getpfccfg)(struct net_device___86 *, int, u8 *);
	u8 (*setall)(struct net_device___86 *);
	u8 (*getcap)(struct net_device___86 *, int, u8 *);
	int (*getnumtcs)(struct net_device___86 *, int, u8 *);
	int (*setnumtcs)(struct net_device___86 *, int, u8);
	u8 (*getpfcstate)(struct net_device___86 *);
	void (*setpfcstate)(struct net_device___86 *, u8);
	void (*getbcncfg)(struct net_device___86 *, int, u32 *);
	void (*setbcncfg)(struct net_device___86 *, int, u32);
	void (*getbcnrp)(struct net_device___86 *, int, u8 *);
	void (*setbcnrp)(struct net_device___86 *, int, u8);
	int (*setapp)(struct net_device___86 *, u8, u16, u8);
	int (*getapp)(struct net_device___86 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___86 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___86 *, int, u8);
	u8 (*getdcbx)(struct net_device___86 *);
	u8 (*setdcbx)(struct net_device___86 *, u8);
	int (*peer_getappinfo)(struct net_device___86 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___86 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___86 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___86 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___86 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___86 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___290 {
	refcount_t count;
	struct ns_common___29 ns;
	struct user_namespace___306 *user_ns;
	struct ucounts___306 *ucounts;
	struct css_set___290 *root_cset;
};

struct bpf_map___291;

struct bpf_map_ops___290 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___291 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___291 *, struct file___441 *);
	void (*map_free)(struct bpf_map___291 *);
	int (*map_get_next_key)(struct bpf_map___291 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___291 *);
	void * (*map_lookup_elem)(struct bpf_map___291 *, void *);
	int (*map_update_elem)(struct bpf_map___291 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___291 *, void *);
	int (*map_push_elem)(struct bpf_map___291 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___291 *, void *);
	int (*map_peek_elem)(struct bpf_map___291 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___291 *, struct file___441 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___291 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___291 *, void *, struct seq_file___380 *);
	int (*map_check_btf)(const struct bpf_map___291 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___291 {
	const struct bpf_map_ops___290 *ops;
	struct bpf_map___291 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___409 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___86;

struct bpf_map_dev_ops___86 {
	int (*map_get_next_key)(struct bpf_offloaded_map___86 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___86 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___86 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___86 *, void *);
};

struct bpf_offloaded_map___86 {
	struct bpf_map___291 map;
	struct net_device___86 *netdev;
	const struct bpf_map_dev_ops___86 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___76 {
	int (*test_run)(struct bpf_prog___76 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___76 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___76 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___76 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___76 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___76 *, u32 *);
};

struct bpf_prog_offload_ops___76 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___76 *);
	int (*translate)(struct bpf_prog___76 *);
	void (*destroy)(struct bpf_prog___76 *);
};

struct bpf_prog_offload___76 {
	struct bpf_prog___76 *prog;
	struct net_device___86 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___76 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___79 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___76 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___76 *ops;
	struct bpf_map___291 **used_maps;
	struct bpf_prog___76 *prog;
	struct user_struct___409 *user;
	u64 load_time;
	struct bpf_map___291 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___76 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___76 {
	struct bpf_prog___76 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___76 {
	struct callback_head rcu;
	struct bpf_prog_array_item___76 items[0];
};

struct cgroup_bpf___76 {
	struct bpf_prog_array___76 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___76 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___291;

typedef void (*kthread_work_func_t___291)(struct kthread_work___291 *);

struct kthread_worker___291;

struct kthread_work___291 {
	struct list_head node;
	kthread_work_func_t___291 func;
	struct kthread_worker___291 *worker;
	int canceling;
};

struct kthread_worker___291 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___443 *task;
	struct kthread_work___291 *current_work;
};

struct kthread_delayed_work___290 {
	struct kthread_work___291 work;
	struct timer_list timer;
};

struct psi_group___290 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___291 *poll_kworker;
	struct kthread_delayed_work___290 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___290;

struct cgroup_rstat_cpu___290;

struct cgroup___290 {
	struct cgroup_subsys_state___290 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___436 *kn;
	struct cgroup_file___290 procs_file;
	struct cgroup_file___290 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___290 *subsys[13];
	struct cgroup_root___290 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___290 *dom_cgrp;
	struct cgroup_rstat_cpu___290 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___76 bpf;
	atomic_t congestion_count;
	struct cgroup___290 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___290 psi;
	int ancestor_ids[0];
};

struct cftype___290;

struct cgroup_subsys___290 {
	struct cgroup_subsys_state___290 * (*css_alloc)(struct cgroup_subsys_state___290 *);
	int (*css_online)(struct cgroup_subsys_state___290 *);
	void (*css_offline)(struct cgroup_subsys_state___290 *);
	void (*css_released)(struct cgroup_subsys_state___290 *);
	void (*css_free)(struct cgroup_subsys_state___290 *);
	void (*css_reset)(struct cgroup_subsys_state___290 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___290 *, int);
	int (*css_extra_stat_show)(struct seq_file___380 *, struct cgroup_subsys_state___290 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___443 *);
	void (*cancel_fork)(struct task_struct___443 *);
	void (*fork)(struct task_struct___443 *);
	void (*exit)(struct task_struct___443 *);
	void (*free)(struct task_struct___443 *);
	void (*bind)(struct cgroup_subsys_state___290 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___290 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___290 *dfl_cftypes;
	struct cftype___290 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___290 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___290 *updated_children;
	struct cgroup___290 *updated_next;
};

struct cgroup_root___290 {
	struct kernfs_root___435 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___290 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___290 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___290 *ss;
	struct list_head node;
	struct kernfs_ops___435 *kf_ops;
	int (*open)(struct kernfs_open_file___435 *);
	void (*release)(struct kernfs_open_file___435 *);
	u64 (*read_u64)(struct cgroup_subsys_state___290 *, struct cftype___290 *);
	s64 (*read_s64)(struct cgroup_subsys_state___290 *, struct cftype___290 *);
	int (*seq_show)(struct seq_file___380 *, void *);
	void * (*seq_start)(struct seq_file___380 *, loff_t *);
	void * (*seq_next)(struct seq_file___380 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___380 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___290 *, struct cftype___290 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___290 *, struct cftype___290 *, s64);
	ssize_t (*write)(struct kernfs_open_file___435 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___435 *, struct poll_table_struct___280 *);
};

struct xdp_rxq_info___86 {
	struct net_device___86 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___86 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___86 *dev_rx;
};

struct netlink_callback___88 {
	struct sk_buff___87 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___88 *);
	int (*dump)(struct sk_buff___87 *, struct netlink_callback___88 *);
	int (*done)(struct netlink_callback___88 *);
	void *data;
	struct module___368 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___86 {
	int (*create)(struct sk_buff___87 *, struct net_device___86 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___87 *, unsigned char *);
	int (*cache)(const struct neighbour___66 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___86 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___86 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___86 *, int);
	int poll_owner;
	struct net_device___86 *dev;
	struct sk_buff___87 *gro_list;
	struct sk_buff___87 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___86 {
	struct net_device___86 *dev;
	struct Qdisc___78 *qdisc;
	struct Qdisc___78 *qdisc_sleeping;
	struct kobject___429 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___86 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem___3 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___78 {
	struct sk_buff___87 *head;
	struct sk_buff___87 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___78;

struct Qdisc___78 {
	int (*enqueue)(struct sk_buff___87 *, struct Qdisc___78 *, struct sk_buff___87 **);
	struct sk_buff___87 * (*dequeue)(struct Qdisc___78 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___78 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___86 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___86 gso_skb;
	struct qdisc_skb_head___78 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___78 *next_sched;
	struct sk_buff_head___86 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___86 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___429 kobj;
	struct net_device___86 *dev;
	long: 64;
	struct xdp_rxq_info___86 xdp_rxq;
	union {
		struct xdp_umem___3 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___86)(struct net_device___86 *, struct sk_buff___87 *, struct net_device___86 *);

struct netdev_bpf___86 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___76 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___76 *prog;
			const struct bpf_prog_offload_ops___76 *ops;
		} verifier;
		struct {
			struct bpf_prog___76 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___86 *offmap;
		};
		struct {
			struct xdp_umem___3 *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___86 {
	int (*xdo_dev_state_add)(struct xfrm_state___10 *);
	void (*xdo_dev_state_delete)(struct xfrm_state___10 *);
	void (*xdo_dev_state_free)(struct xfrm_state___10 *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___87 *, struct xfrm_state___10 *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state___10 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct xfrm_state_offload___10 {
	struct net_device___86 *dev;
	long unsigned int offload_handle;
	unsigned int num_exthdrs;
	u8 flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct xfrm_replay___10;

struct xfrm_type___10;

struct xfrm_mode___10;

struct xfrm_type_offload___10;

struct xfrm_state___10 {
	possible_net_t___88 xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	refcount_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
		u32 output_mark;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	const char *geniv;
	struct xfrm_encap_tmpl *encap;
	xfrm_address_t *coaddr;
	struct xfrm_state___10 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	const struct xfrm_replay___10 *repl;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct tasklet_hrtimer mtimer;
	struct xfrm_state_offload___10 xso;
	long int saved_tmo;
	long unsigned int lastused;
	struct page_frag___442 xfrag;
	const struct xfrm_type___10 *type;
	struct xfrm_mode___10 *inner_mode;
	struct xfrm_mode___10 *inner_mode_iaf;
	struct xfrm_mode___10 *outer_mode;
	const struct xfrm_type_offload___10 *type_offload;
	struct xfrm_sec_ctx___2 *security;
	void *data;
	u32 output_mark_mask;
	u32 if_id;
};

struct tlsdev_ops___86 {
	int (*tls_dev_add)(struct net_device___86 *, struct sock___67 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___86 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___86 *, struct sock___67 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___86 {
	int (*ndo_init)(struct net_device___86 *);
	void (*ndo_uninit)(struct net_device___86 *);
	int (*ndo_open)(struct net_device___86 *);
	int (*ndo_stop)(struct net_device___86 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___87 *, struct net_device___86 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___87 *, struct net_device___86 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___86 *, struct sk_buff___87 *, struct net_device___86 *, select_queue_fallback_t___86);
	void (*ndo_change_rx_flags)(struct net_device___86 *, int);
	void (*ndo_set_rx_mode)(struct net_device___86 *);
	int (*ndo_set_mac_address)(struct net_device___86 *, void *);
	int (*ndo_validate_addr)(struct net_device___86 *);
	int (*ndo_do_ioctl)(struct net_device___86 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___86 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___86 *, int);
	int (*ndo_neigh_setup)(struct net_device___86 *, struct neigh_parms___66 *);
	void (*ndo_tx_timeout)(struct net_device___86 *);
	void (*ndo_get_stats64)(struct net_device___86 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___86 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___86 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___86 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___86 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___86 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___86 *);
	int (*ndo_netpoll_setup)(struct net_device___86 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___86 *);
	int (*ndo_set_vf_mac)(struct net_device___86 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___86 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___86 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___86 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___86 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___86 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___86 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___86 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___86 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___86 *, int, struct sk_buff___87 *);
	int (*ndo_set_vf_guid)(struct net_device___86 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___86 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___86 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___86 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___86 *, const struct sk_buff___87 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___86 *, struct net_device___86 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___86 *, struct net_device___86 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___86 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___86 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___86 *, struct neighbour___66 *);
	void (*ndo_neigh_destroy)(struct net_device___86 *, struct neighbour___66 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___86 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___86 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___86 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___87 *, struct netlink_callback___88 *, struct net_device___86 *, struct net_device___86 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___86 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___86 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___87 *, u32, u32, struct net_device___86 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___86 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___86 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___86 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___86 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___86 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___86 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___86 *, struct net_device___86 *);
	void (*ndo_dfwd_del_station)(struct net_device___86 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___86 *);
	int (*ndo_set_tx_maxrate)(struct net_device___86 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___86 *);
	int (*ndo_change_proto_down)(struct net_device___86 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___86 *, struct sk_buff___87 *);
	void (*ndo_set_rx_headroom)(struct net_device___86 *, int);
	int (*ndo_bpf)(struct net_device___86 *, struct netdev_bpf___86 *);
	int (*ndo_xdp_xmit)(struct net_device___86 *, int, struct xdp_frame___86 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___86 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___86 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___66 {
	possible_net_t___88 net;
	struct net_device___86 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___66 *);
	void (*neigh_cleanup)(struct neighbour___66 *);
	struct neigh_table___66 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___66 {
	u32 (*l3mdev_fib_table)(const struct net_device___86 *);
	struct sk_buff___87 * (*l3mdev_l3_rcv)(struct net_device___86 *, struct sk_buff___87 *, u16);
	struct sk_buff___87 * (*l3mdev_l3_out)(struct net_device___86 *, struct sock___67 *, struct sk_buff___87 *, u16);
	struct dst_entry___66 * (*l3mdev_link_scope_lookup)(const struct net_device___86 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct ndisc_ops___37 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___86 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___86 *, struct neighbour___66 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___86 *, u8, struct neighbour___66 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___86 *, struct sk_buff___87 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___97 *, struct net_device___86 *, const struct prefix_info *, struct inet6_dev___37 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___37;

struct ifacaddr6___14;

struct inet6_dev___37 {
	struct net_device___86 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___37 *mc_list;
	struct ifmcaddr6___37 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___14 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	u8 rndid[8];
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___66 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
};

struct tcf_proto___78;

struct mini_Qdisc___78 {
	struct tcf_proto___78 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___78 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___86 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___97 *, struct net_device___86 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___86 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___86 *, struct list_head *);
	size_t (*get_size)(const struct net_device___86 *);
	int (*fill_info)(struct sk_buff___87 *, const struct net_device___86 *);
	size_t (*get_xstats_size)(const struct net_device___86 *);
	int (*fill_xstats)(struct sk_buff___87 *, const struct net_device___86 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___86 *, struct net_device___86 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___86 *, const struct net_device___86 *);
	int (*fill_slave_info)(struct sk_buff___87 *, const struct net_device___86 *, const struct net_device___86 *);
	struct net___97 * (*get_link_net)(const struct net_device___86 *);
	size_t (*get_linkxstats_size)(const struct net_device___86 *, int);
	int (*fill_linkxstats)(struct sk_buff___87 *, const struct net_device___86 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct offload_callbacks___10 {
	struct sk_buff___87 * (*gso_segment)(struct sk_buff___87 *, netdev_features_t);
	struct sk_buff___87 ** (*gro_receive)(struct sk_buff___87 **, struct sk_buff___87 *);
	int (*gro_complete)(struct sk_buff___87 *, int);
};

struct softnet_data___86 {
	struct list_head poll_list;
	struct sk_buff_head___86 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___86 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___78 *output_queue;
	struct Qdisc___78 **output_queue_tailp;
	struct sk_buff___87 *completion_queue;
	struct sk_buff_head___86 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___86 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___86 input_pkt_queue;
	struct napi_struct___86 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bdi_writeback_congested___231 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___231 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___231 {
	struct bio___231 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___233 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___233 bip_inline_vecs[0];
};

struct bio_set___231 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___231 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___174 {
	struct mem_cgroup___174 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___174 {
	struct lruvec___442 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___174 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___174 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct gnet_dump___78 {
	spinlock_t *lock;
	struct sk_buff___87 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___78;

struct Qdisc_ops___78 {
	struct Qdisc_ops___78 *next;
	const struct Qdisc_class_ops___78 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___87 *, struct Qdisc___78 *, struct sk_buff___87 **);
	struct sk_buff___87 * (*dequeue)(struct Qdisc___78 *);
	struct sk_buff___87 * (*peek)(struct Qdisc___78 *);
	int (*init)(struct Qdisc___78 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___78 *);
	void (*destroy)(struct Qdisc___78 *);
	int (*change)(struct Qdisc___78 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___78 *);
	int (*change_tx_queue_len)(struct Qdisc___78 *, unsigned int);
	int (*dump)(struct Qdisc___78 *, struct sk_buff___87 *);
	int (*dump_stats)(struct Qdisc___78 *, struct gnet_dump___78 *);
	void (*ingress_block_set)(struct Qdisc___78 *, u32);
	void (*egress_block_set)(struct Qdisc___78 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___78 *);
	u32 (*egress_block_get)(struct Qdisc___78 *);
	struct module___368 *owner;
};

struct tcf_block___78;

struct Qdisc_class_ops___78 {
	unsigned int flags;
	struct netdev_queue___86 * (*select_queue)(struct Qdisc___78 *, struct tcmsg *);
	int (*graft)(struct Qdisc___78 *, long unsigned int, struct Qdisc___78 *, struct Qdisc___78 **, struct netlink_ext_ack *);
	struct Qdisc___78 * (*leaf)(struct Qdisc___78 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___78 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___78 *, u32);
	int (*change)(struct Qdisc___78 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___78 *, long unsigned int);
	void (*walk)(struct Qdisc___78 *, struct qdisc_walker *);
	struct tcf_block___78 * (*tcf_block)(struct Qdisc___78 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___78 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___78 *, long unsigned int);
	int (*dump)(struct Qdisc___78 *, long unsigned int, struct sk_buff___87 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___78 *, long unsigned int, struct gnet_dump___78 *);
};

struct tcf_chain___78;

struct tcf_block___78 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___97 *net;
	struct Qdisc___78 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___78 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___78;

struct tcf_proto_ops___78;

struct tcf_proto___78 {
	struct tcf_proto___78 *next;
	void *root;
	int (*classify)(struct sk_buff___87 *, const struct tcf_proto___78 *, struct tcf_result___78 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___78 *ops;
	struct tcf_chain___78 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___78 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___78 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___78 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___87 *, const struct tcf_proto___78 *, struct tcf_result___78 *);
	int (*init)(struct tcf_proto___78 *);
	void (*destroy)(struct tcf_proto___78 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___78 *, u32);
	void (*put)(struct tcf_proto___78 *, void *);
	int (*change)(struct net___97 *, struct sk_buff___87 *, struct tcf_proto___78 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___78 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___78 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___78 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___97 *, struct tcf_chain___78 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___97 *, struct tcf_proto___78 *, void *, struct sk_buff___87 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___87 *, struct net___97 *, void *);
	struct module___368 *owner;
	int flags;
};

struct tcf_chain___78 {
	struct mutex filter_chain_lock;
	struct tcf_proto___78 *filter_chain;
	struct list_head list;
	struct tcf_block___78 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___78 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___66 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___76 *prog;
};

struct bpf_redirect_info___76 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___291 *map;
	struct bpf_map___291 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___66;

struct neigh_hash_table___66;

struct neigh_table___66 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___86 *, __u32 *);
	bool (*key_eq)(const struct neighbour___66 *, const void *);
	int (*constructor)(struct neighbour___66 *);
	int (*pconstructor)(struct pneigh_entry___66 *);
	void (*pdestructor)(struct pneigh_entry___66 *);
	void (*proxy_redo)(struct sk_buff___87 *);
	char *id;
	struct neigh_parms___66 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___86 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___66 *nht;
	struct pneigh_entry___66 **phash_buckets;
};

struct neigh_ops___66 {
	int family;
	void (*solicit)(struct neighbour___66 *, struct sk_buff___87 *);
	void (*error_report)(struct neighbour___66 *, struct sk_buff___87 *);
	int (*output)(struct neighbour___66 *, struct sk_buff___87 *);
	int (*connected_output)(struct neighbour___66 *, struct sk_buff___87 *);
};

struct pneigh_entry___66 {
	struct pneigh_entry___66 *next;
	possible_net_t___88 net;
	struct net_device___86 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___66 {
	struct neighbour___66 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___8 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___97 *, struct sock___67 *, struct sk_buff___87 *);
	int (*orig_input)(struct sk_buff___87 *);
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	__u8 data[0];
};

struct fib_rule___66 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___66 *ctarget;
	struct net___97 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___66 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___66 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___49;

struct timewait_sock_ops___45;

struct proto___66 {
	void (*close)(struct sock___67 *, long int);
	int (*pre_connect)(struct sock___67 *, struct sockaddr *, int);
	int (*connect)(struct sock___67 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___67 *, int);
	struct sock___67 * (*accept)(struct sock___67 *, int, int *, bool);
	int (*ioctl)(struct sock___67 *, int, long unsigned int);
	int (*init)(struct sock___67 *);
	void (*destroy)(struct sock___67 *);
	void (*shutdown)(struct sock___67 *, int);
	int (*setsockopt)(struct sock___67 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___67 *, int, int, char *, int *);
	void (*keepalive)(struct sock___67 *, int);
	int (*sendmsg)(struct sock___67 *, struct msghdr___69 *, size_t);
	int (*recvmsg)(struct sock___67 *, struct msghdr___69 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___67 *, struct page___442 *, int, size_t, int);
	int (*bind)(struct sock___67 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___67 *, struct sk_buff___87 *);
	void (*release_cb)(struct sock___67 *);
	int (*hash)(struct sock___67 *);
	void (*unhash)(struct sock___67 *);
	void (*rehash)(struct sock___67 *);
	int (*get_port)(struct sock___67 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___67 *);
	bool (*stream_memory_read)(const struct sock___67 *);
	void (*enter_memory_pressure)(struct sock___67 *);
	void (*leave_memory_pressure)(struct sock___67 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___49 *rsk_prot;
	struct timewait_sock_ops___45 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___368 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___67 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct xfrm_policy_queue___10 {
	struct sk_buff_head___86 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___10 {
	possible_net_t___88 xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	refcount_t refcnt;
	struct timer_list timer;
	atomic_t genid;
	u32 priority;
	u32 index;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___10 polq;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx___2 *security;
	struct xfrm_tmpl xfrm_vec[6];
	struct callback_head rcu;
	u32 if_id;
};

struct request_sock___50;

struct request_sock_ops___49 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___67 *, struct request_sock___50 *);
	void (*send_ack)(const struct sock___67 *, struct sk_buff___87 *, struct request_sock___50 *);
	void (*send_reset)(const struct sock___67 *, struct sk_buff___87 *);
	void (*destructor)(struct request_sock___50 *);
	void (*syn_ack_timeout)(const struct request_sock___50 *);
};

struct timewait_sock_ops___45 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___67 *, struct sock___67 *, void *);
	void (*twsk_destructor)(struct sock___67 *);
};

struct request_sock___50 {
	struct sock_common___66 __req_common;
	struct request_sock___50 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___49 *rsk_ops;
	struct sock___67 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ip_options_data {
	struct ip_options_rcu opt;
	char data[40];
};

struct inet_cork___9 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___66 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
	__u16 gso_size;
	u64 transmit_time;
};

struct inet_cork_full___9 {
	struct inet_cork___9 base;
	struct flowi fl;
};

struct ipv6_pinfo___9;

struct inet_sock___9 {
	struct sock___67 sk;
	struct ipv6_pinfo___9 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	__be16 inet_sport;
	__u16 inet_id;
	struct ip_options_rcu *inet_opt;
	int rx_dst_ifindex;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 bind_address_no_port: 1;
	__u8 defer_connect: 1;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___9 cork;
};

struct ipv6_fl_socklist___8;

struct ipv6_pinfo___9 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
			__u16 recvfragsize: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 repflow: 1;
	__u16 pmtudisc: 3;
	__u16 padding: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u16 autoflowlabel: 1;
	__u16 autoflowlabel_set: 1;
	__u8 min_hopcount;
	__u8 tclass;
	__be32 rcv_flowinfo;
	__u32 dst_cookie;
	__u32 rx_dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___8 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___87 *pktoptions;
	struct sk_buff___87 *rxpmtu;
	struct inet6_cork cork;
};

struct ip6_flowlabel___8;

struct ipv6_fl_socklist___8 {
	struct ipv6_fl_socklist___8 *next;
	struct ip6_flowlabel___8 *fl;
	struct callback_head rcu;
};

struct ifmcaddr6___37 {
	struct in6_addr mca_addr;
	struct inet6_dev___37 *idev;
	struct ifmcaddr6___37 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___14 {
	struct in6_addr aca_addr;
	struct fib6_info___14 *aca_rt;
	struct ifacaddr6___14 *aca_next;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct ip6_ra_chain___37 {
	struct ip6_ra_chain___37 *next;
	struct sock___67 *sk;
	int sel;
	void (*destructor)(struct sock___67 *);
};

struct ip6_flowlabel___8 {
	struct ip6_flowlabel___8 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___245 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___97 *fl_net;
};

struct rtable___8 {
	struct dst_entry___66 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	__be32 rt_gateway;
	u32 rt_mtu_locked: 1;
	u32 rt_pmtu: 31;
	struct list_head rt_uncached;
	struct uncached_list *rt_uncached_list;
};

struct ipcm_cookie {
	struct sockcm_cookie sockc;
	__be32 addr;
	int oif;
	struct ip_options_rcu *opt;
	__u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
	__u16 gso_size;
};

struct ip_reply_arg {
	struct kvec iov[1];
	int flags;
	__wsum csum;
	int csumoffset;
	int bound_dev_if;
	u8 tos;
	kuid_t uid;
};

struct net_protocol___8 {
	int (*early_demux)(struct sk_buff___87 *);
	int (*early_demux_handler)(struct sk_buff___87 *);
	int (*handler)(struct sk_buff___87 *);
	void (*err_handler)(struct sk_buff___87 *, u32);
	unsigned int no_policy: 1;
	unsigned int netns_ok: 1;
	unsigned int icmp_strict_tag_validation: 1;
};

struct inet6_protocol___8 {
	void (*early_demux)(struct sk_buff___87 *);
	void (*early_demux_handler)(struct sk_buff___87 *);
	int (*handler)(struct sk_buff___87 *);
	void (*err_handler)(struct sk_buff___87 *, struct inet6_skb_parm *, u8, u8, int, __be32);
	unsigned int flags;
};

struct net_offload___8 {
	struct offload_callbacks___10 callbacks;
	unsigned int flags;
};

struct xfrm_replay___10 {
	void (*advance)(struct xfrm_state___10 *, __be32);
	int (*check)(struct xfrm_state___10 *, struct sk_buff___87 *, __be32);
	int (*recheck)(struct xfrm_state___10 *, struct sk_buff___87 *, __be32);
	void (*notify)(struct xfrm_state___10 *, int);
	int (*overflow)(struct xfrm_state___10 *, struct sk_buff___87 *);
};

struct xfrm_type___10 {
	char *description;
	struct module___368 *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___10 *);
	void (*destructor)(struct xfrm_state___10 *);
	int (*input)(struct xfrm_state___10 *, struct sk_buff___87 *);
	int (*output)(struct xfrm_state___10 *, struct sk_buff___87 *);
	int (*reject)(struct xfrm_state___10 *, struct sk_buff___87 *, const struct flowi *);
	int (*hdr_offset)(struct xfrm_state___10 *, struct sk_buff___87 *, u8 **);
	u32 (*get_mtu)(struct xfrm_state___10 *, int);
};

struct xfrm_state_afinfo___10;

struct xfrm_mode___10 {
	int (*input2)(struct xfrm_state___10 *, struct sk_buff___87 *);
	int (*input)(struct xfrm_state___10 *, struct sk_buff___87 *);
	int (*output2)(struct xfrm_state___10 *, struct sk_buff___87 *);
	int (*output)(struct xfrm_state___10 *, struct sk_buff___87 *);
	struct sk_buff___87 * (*gso_segment)(struct xfrm_state___10 *, struct sk_buff___87 *, netdev_features_t);
	void (*xmit)(struct xfrm_state___10 *, struct sk_buff___87 *);
	struct xfrm_state_afinfo___10 *afinfo;
	struct module___368 *owner;
	unsigned int encap;
	int flags;
};

struct xfrm_type_offload___10 {
	char *description;
	struct module___368 *owner;
	u8 proto;
	void (*encap)(struct xfrm_state___10 *, struct sk_buff___87 *);
	int (*input_tail)(struct xfrm_state___10 *, struct sk_buff___87 *);
	int (*xmit)(struct xfrm_state___10 *, struct sk_buff___87 *, netdev_features_t);
};

struct xfrm_state_afinfo___10 {
	unsigned int family;
	unsigned int proto;
	__be16 eth_proto;
	struct module___368 *owner;
	const struct xfrm_type___10 *type_map[256];
	const struct xfrm_type_offload___10 *type_offload_map[256];
	struct xfrm_mode___10 *mode_map[5];
	int (*init_flags)(struct xfrm_state___10 *);
	void (*init_tempsel)(struct xfrm_selector *, const struct flowi *);
	void (*init_temprop)(struct xfrm_state___10 *, const struct xfrm_tmpl *, const xfrm_address_t *, const xfrm_address_t *);
	int (*tmpl_sort)(struct xfrm_tmpl **, struct xfrm_tmpl **, int);
	int (*state_sort)(struct xfrm_state___10 **, struct xfrm_state___10 **, int);
	int (*output)(struct net___97 *, struct sock___67 *, struct sk_buff___87 *);
	int (*output_finish)(struct sock___67 *, struct sk_buff___87 *);
	int (*extract_input)(struct xfrm_state___10 *, struct sk_buff___87 *);
	int (*extract_output)(struct xfrm_state___10 *, struct sk_buff___87 *);
	int (*transport_finish)(struct sk_buff___87 *, int);
	void (*local_error)(struct sk_buff___87 *, u32);
};

struct nf_hook_state___11 {
	unsigned int hook;
	u_int8_t pf;
	struct net_device___86 *in;
	struct net_device___86 *out;
	struct sock___67 *sk;
	struct net___97 *net;
	int (*okfn)(struct net___97 *, struct sock___67 *, struct sk_buff___87 *);
};

struct nf_nat_hook___11 {
	int (*parse_nat_setup)(struct nf_conn *, enum nf_nat_manip_type, const struct nlattr *);
	void (*decode_session)(struct sk_buff___87 *, struct flowi *);
	unsigned int (*manip_pkt)(struct sk_buff___87 *, struct nf_conn *, enum nf_nat_manip_type, enum ip_conntrack_dir);
};

struct nf_ct_hook___11 {
	int (*update)(struct net___97 *, struct sk_buff___87 *);
	void (*destroy)(struct nf_conntrack *);
	bool (*get_tuple_skb)(struct nf_conntrack_tuple *, const struct sk_buff___87 *);
};

struct nfnl_ct_hook___11 {
	struct nf_conn * (*get_ct)(const struct sk_buff___87 *, enum ip_conntrack_info *);
	size_t (*build_size)(const struct nf_conn *);
	int (*build)(struct sk_buff___87 *, struct nf_conn *, enum ip_conntrack_info, u_int16_t, u_int16_t);
	int (*parse)(const struct nlattr *, struct nf_conn *);
	int (*attach_expect)(const struct nlattr *, struct nf_conn *, u32, u32);
	void (*seq_adjust)(struct sk_buff___87 *, struct nf_conn *, enum ip_conntrack_info, s32);
};

struct umh_info___2 {
	const char *cmdline;
	struct file___439 *pipe_to_umh;
	struct file___439 *pipe_from_umh;
	struct list_head list;
	void (*cleanup)(struct umh_info___2 *);
	pid_t pid;
};

struct ip_mreq_source {
	__be32 imr_multiaddr;
	__be32 imr_interface;
	__be32 imr_sourceaddr;
};

struct ip_msfilter {
	__be32 imsf_multiaddr;
	__be32 imsf_interface;
	__u32 imsf_fmode;
	__u32 imsf_numsrc;
	__be32 imsf_slist[1];
};

struct group_req {
	__u32 gr_interface;
	int: 32;
	struct __kernel_sockaddr_storage gr_group;
};

struct group_source_req {
	__u32 gsr_interface;
	int: 32;
	struct __kernel_sockaddr_storage gsr_group;
	struct __kernel_sockaddr_storage gsr_source;
};

struct group_filter {
	__u32 gf_interface;
	int: 32;
	struct __kernel_sockaddr_storage gf_group;
	__u32 gf_fmode;
	__u32 gf_numsrc;
	struct __kernel_sockaddr_storage gf_slist[1];
};

struct in_pktinfo {
	int ipi_ifindex;
	struct in_addr ipi_spec_dst;
	struct in_addr ipi_addr;
};

struct fastopen_queue___5 {
	struct request_sock___48 *rskq_rst_head;
	struct request_sock___48 *rskq_rst_tail;
	spinlock_t lock;
	int qlen;
	int max_qlen;
	struct tcp_fastopen_context *ctx;
};

struct request_sock_queue___5 {
	spinlock_t rskq_lock;
	u8 rskq_defer_accept;
	u32 synflood_warned;
	atomic_t qlen;
	atomic_t young;
	struct request_sock___48 *rskq_accept_head;
	struct request_sock___48 *rskq_accept_tail;
	struct fastopen_queue___5 fastopenq;
};

struct inet_connection_sock_af_ops___5 {
	int (*queue_xmit)(struct sock___65 *, struct sk_buff___85 *, struct flowi *);
	void (*send_check)(struct sock___65 *, struct sk_buff___85 *);
	int (*rebuild_header)(struct sock___65 *);
	void (*sk_rx_dst_set)(struct sock___65 *, const struct sk_buff___85 *);
	int (*conn_request)(struct sock___65 *, struct sk_buff___85 *);
	struct sock___65 * (*syn_recv_sock)(const struct sock___65 *, struct sk_buff___85 *, struct request_sock___48 *, struct dst_entry___64 *, struct request_sock___48 *, bool *);
	u16 net_header_len;
	u16 net_frag_header_len;
	u16 sockaddr_len;
	int (*setsockopt)(struct sock___65 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___65 *, int, int, char *, int *);
	void (*addr2sockaddr)(struct sock___65 *, struct sockaddr *);
	void (*mtu_reduced)(struct sock___65 *);
};

struct inet_connection_sock___5 {
	struct inet_sock___8 icsk_inet;
	struct request_sock_queue___5 icsk_accept_queue;
	struct inet_bind_bucket___2 *icsk_bind_hash;
	long unsigned int icsk_timeout;
	struct timer_list icsk_retransmit_timer;
	struct timer_list icsk_delack_timer;
	__u32 icsk_rto;
	__u32 icsk_pmtu_cookie;
	const struct tcp_congestion_ops *icsk_ca_ops;
	const struct inet_connection_sock_af_ops___5 *icsk_af_ops;
	const struct tcp_ulp_ops___2 *icsk_ulp_ops;
	void *icsk_ulp_data;
	void (*icsk_clean_acked)(struct sock___65 *, u32);
	struct hlist_node icsk_listen_portaddr_node;
	unsigned int (*icsk_sync_mss)(struct sock___65 *, u32);
	__u8 icsk_ca_state: 6;
	__u8 icsk_ca_setsockopt: 1;
	__u8 icsk_ca_dst_locked: 1;
	__u8 icsk_retransmits;
	__u8 icsk_pending;
	__u8 icsk_backoff;
	__u8 icsk_syn_retries;
	__u8 icsk_probes_out;
	__u16 icsk_ext_hdr_len;
	struct {
		__u8 pending;
		__u8 quick;
		__u8 pingpong;
		__u8 blocked;
		__u32 ato;
		long unsigned int timeout;
		__u32 lrcvtime;
		__u16 last_seg_size;
		__u16 rcv_mss;
	} icsk_ack;
	struct {
		int enabled;
		int search_high;
		int search_low;
		int probe_size;
		u32 probe_timestamp;
	} icsk_mtup;
	u32 icsk_user_timeout;
	u64 icsk_ca_priv[11];
};

struct bpfilter_umh_ops {
	struct umh_info___2 info;
	struct mutex lock;
	int (*sockopt)(struct sock___65 *, int, char *, unsigned int, bool);
	int (*start)();
	bool stop;
};

struct file___442;

struct kiocb___442;

struct iov_iter___209;

struct poll_table_struct___281;

struct vm_area_struct___443;

struct inode___442;

struct file_lock___442;

struct page___443;

struct pipe_inode_info___123;

struct seq_file___381;

struct file_operations___442 {
	struct module___333 *owner;
	loff_t (*llseek)(struct file___442 *, loff_t, int);
	ssize_t (*read)(struct file___442 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___442 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___442 *, struct iov_iter___209 *);
	ssize_t (*write_iter)(struct kiocb___442 *, struct iov_iter___209 *);
	int (*iopoll)(struct kiocb___442 *, bool);
	int (*iterate)(struct file___442 *, struct dir_context *);
	int (*iterate_shared)(struct file___442 *, struct dir_context *);
	__poll_t (*poll)(struct file___442 *, struct poll_table_struct___281 *);
	long int (*unlocked_ioctl)(struct file___442 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___442 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___442 *, struct vm_area_struct___443 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___442 *, struct file___442 *);
	int (*flush)(struct file___442 *, fl_owner_t);
	int (*release)(struct inode___442 *, struct file___442 *);
	int (*fsync)(struct file___442 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___442 *, int);
	int (*lock)(struct file___442 *, int, struct file_lock___442 *);
	ssize_t (*sendpage)(struct file___442 *, struct page___443 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___442 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___442 *, int, struct file_lock___442 *);
	ssize_t (*splice_write)(struct pipe_inode_info___123 *, struct file___442 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___442 *, loff_t *, struct pipe_inode_info___123 *, size_t, unsigned int);
	int (*setlease)(struct file___442 *, long int, struct file_lock___442 **, void **);
	long int (*fallocate)(struct file___442 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___381 *, struct file___442 *);
	ssize_t (*copy_file_range)(struct file___442 *, loff_t, struct file___442 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___442 *, loff_t, struct file___442 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___442 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___443 {
	u64 seqnum;
	struct vm_area_struct___443 *vmas[4];
};

struct page_frag___443 {
	struct page___443 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___443;

struct mem_cgroup___175;

struct cred___410;

struct nsproxy___337;

struct signal_struct___317;

struct bio_list___232;

struct backing_dev_info___232;

struct css_set___291;

struct vm_struct___346;

struct task_struct___444 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___444 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___443 *mm;
	struct mm_struct___443 *active_mm;
	struct vmacache___443 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___444 *real_parent;
	struct task_struct___444 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___444 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___175 *active_memcg;
	long int rh_reserved2;
	struct pid___245 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___245 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___245 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___410 *ptracer_cred;
	const struct cred___410 *real_cred;
	const struct cred___410 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___337 *nsproxy;
	struct signal_struct___317 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___444 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___232 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___232 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___291 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___123 *splice_pipe;
	struct page_frag___443 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___175 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___444 *oom_reaper_list;
	struct vm_struct___346 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___156 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rw_semaphore___444 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___444 *owner;
};

struct key___410;

struct ucounts___307;

struct user_namespace___307 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___307 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___29 ns;
	long unsigned int flags;
	struct key___410 *persistent_keyring_register;
	struct rw_semaphore___444 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___307 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___443 *pgtable_t___443;

struct address_space___442;

struct dev_pagemap___430;

struct page___443 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___442 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___443 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___443 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___443 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___430 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___175 *mem_cgroup;
};

struct pglist_data___443;

struct lruvec___443 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___443 *pgdat;
};

struct zone___443 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___443 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___443 {
	struct zone___443 *zone;
	int zone_idx;
};

struct zonelist___443 {
	struct zoneref___443 _zonerefs[25];
};

struct pglist_data___443 {
	struct zone___443 node_zones[3];
	struct zonelist___443 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___444 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___444 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___443 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___444 {
	void *stack;
	struct task_struct___444 *task;
	long int status;
};

struct blocking_notifier_head___443 {
	struct rw_semaphore___444 rwsem;
	struct notifier_block *head;
};

struct dentry___442;

struct path___443 {
	struct vfsmount *mnt;
	struct dentry___442 *dentry;
};

struct file___442 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___443 f_path;
	struct inode___442 *f_inode;
	const struct file_operations___442 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___245 f_owner;
	const struct cred___410 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___442 *f_mapping;
	errseq_t f_wb_err;
};

struct user_struct___410;

struct cred___410 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___410 *session_keyring;
	struct key___410 *process_keyring;
	struct key___410 *thread_keyring;
	struct key___410 *request_key_auth;
	void *security;
	struct user_struct___410 *user;
	struct user_namespace___307 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___436;

struct kernfs_elem_dir___436 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___436 *root;
};

struct kernfs_node___437;

struct kernfs_syscall_ops___436;

struct kernfs_root___436 {
	struct kernfs_node___437 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___436 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___436 {
	struct kernfs_node___437 *target_kn;
};

struct kernfs_ops___436;

struct kernfs_elem_attr___436 {
	const struct kernfs_ops___436 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___437 *notify_next;
};

struct kernfs_node___437 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___437 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___436 dir;
		struct kernfs_elem_symlink___436 symlink;
		struct kernfs_elem_attr___436 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___436;

struct kernfs_ops___436 {
	int (*open)(struct kernfs_open_file___436 *);
	void (*release)(struct kernfs_open_file___436 *);
	int (*seq_show)(struct seq_file___381 *, void *);
	void * (*seq_start)(struct seq_file___381 *, loff_t *);
	void * (*seq_next)(struct seq_file___381 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___381 *, void *);
	ssize_t (*read)(struct kernfs_open_file___436 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___436 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___436 *, struct vm_area_struct___443 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___436 *, struct poll_table_struct___281 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___436 {
	int (*remount_fs)(struct kernfs_root___436 *, int *, char *);
	int (*show_options)(struct seq_file___381 *, struct kernfs_root___436 *);
	int (*mkdir)(struct kernfs_node___437 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___437 *);
	int (*rename)(struct kernfs_node___437 *, struct kernfs_node___437 *, const char *);
	int (*show_path)(struct seq_file___381 *, struct kernfs_node___437 *, struct kernfs_root___436 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___381;

struct seq_file___381 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___381 *op;
	int poll_event;
	const struct file___442 *file;
	void *private;
};

struct vm_operations_struct___430;

struct kernfs_open_file___436 {
	struct kernfs_node___437 *kn;
	struct file___442 *file;
	struct seq_file___381 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___430 *vm_ops;
};

struct vm_fault___430;

struct vm_operations_struct___430 {
	void (*open)(struct vm_area_struct___443 *);
	void (*close)(struct vm_area_struct___443 *);
	int (*split)(struct vm_area_struct___443 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___443 *);
	vm_fault_t (*fault)(struct vm_fault___430 *);
	vm_fault_t (*huge_fault)(struct vm_fault___430 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___430 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___443 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___430 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___430 *);
	int (*access)(struct vm_area_struct___443 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___443 *);
	int (*set_policy)(struct vm_area_struct___443 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___443 *, long unsigned int);
	struct page___443 * (*find_special_page)(struct vm_area_struct___443 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___291)(struct file___442 *, wait_queue_head_t *, struct poll_table_struct___281 *);

struct poll_table_struct___281 {
	poll_queue_proc___291 _qproc;
	__poll_t _key;
};

struct vm_area_struct___443 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___443 *vm_next;
	struct vm_area_struct___443 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___443 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___430 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___442 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_ns_type_operations___67 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___33 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct net___98;

typedef struct {
	struct net___98 *net;
} possible_net_t___89;

struct proto___67;

struct sock_common___67 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___67 *skc_prot;
	possible_net_t___89 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___33 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___88;

struct sk_buff_head___87 {
	struct sk_buff___88 *next;
	struct sk_buff___88 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___67;

struct socket_wq___68;

struct dst_entry___67;

struct socket___69;

struct net_device___87;

struct sock_reuseport___5;

struct sock___33 {
	struct sock_common___67 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___87 sk_error_queue;
	struct sk_buff_head___87 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___88 *head;
		struct sk_buff___88 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___67 *sk_filter;
	union {
		struct socket_wq___68 *sk_wq;
		struct socket_wq___68 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___67 *sk_rx_dst;
	struct dst_entry___67 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___88 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___87 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___443 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___67 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___245 *sk_peer_pid;
	const struct cred___410 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___69 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___175 *sk_memcg;
	void (*sk_state_change)(struct sock___33 *);
	void (*sk_data_ready)(struct sock___33 *);
	void (*sk_write_space)(struct sock___33 *);
	void (*sk_error_report)(struct sock___33 *);
	int (*sk_backlog_rcv)(struct sock___33 *, struct sk_buff___88 *);
	struct sk_buff___88 * (*sk_validate_xmit_skb)(struct sock___33 *, struct net_device___87 *, struct sk_buff___88 *);
	void (*sk_destruct)(struct sock___33 *);
	struct sock_reuseport___5 *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kobject___430;

struct bin_attribute___406;

struct attribute_group___407 {
	const char *name;
	umode_t (*is_visible)(struct kobject___430 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___430 *, struct bin_attribute___406 *, int);
	struct attribute **attrs;
	struct bin_attribute___406 **bin_attrs;
};

struct kset___429;

struct kobj_type___429;

struct kobject___430 {
	const char *name;
	struct list_head entry;
	struct kobject___430 *parent;
	struct kset___429 *kset;
	struct kobj_type___429 *ktype;
	struct kernfs_node___437 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___406 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___442 *, struct kobject___430 *, struct bin_attribute___406 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___442 *, struct kobject___430 *, struct bin_attribute___406 *, char *, loff_t, size_t);
	int (*mmap)(struct file___442 *, struct kobject___430 *, struct bin_attribute___406 *, struct vm_area_struct___443 *);
};

struct sysfs_ops___429 {
	ssize_t (*show)(struct kobject___430 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___430 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___429;

struct kset___429 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___430 kobj;
	const struct kset_uevent_ops___429 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___429 {
	void (*release)(struct kobject___430 *);
	const struct sysfs_ops___429 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___67 * (*child_ns_type)(struct kobject___430 *);
	const void * (*namespace)(struct kobject___430 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___429 {
	int (* const filter)(struct kset___429 *, struct kobject___430 *);
	const char * (* const name)(struct kset___429 *, struct kobject___430 *);
	int (* const uevent)(struct kset___429 *, struct kobject___430 *, struct kobj_uevent_env *);
};

struct kobj_attribute___420 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___430 *, struct kobj_attribute___420 *, char *);
	ssize_t (*store)(struct kobject___430 *, struct kobj_attribute___420 *, const char *, size_t);
};

struct kernel_param___368;

struct kernel_param_ops___368 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___368 *);
	int (*get)(char *, const struct kernel_param___368 *);
	void (*free)(void *);
};

struct kparam_array___368;

struct kernel_param___368 {
	const char *name;
	struct module___333 *mod;
	const struct kernel_param_ops___368 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___368 *arr;
	};
};

struct kparam_array___368 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___368 *ops;
	void *elem;
};

struct module_kobject___368 {
	struct kobject___430 kobj;
	struct module___333 *mod;
	struct kobject___430 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___368 {
	struct module___333 *mod;
	struct latch_tree_node node;
};

struct module_layout___368 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___368 mtn;
};

struct module_attribute___368;

struct module___333 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___368 mkobj;
	struct module_attribute___368 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___430 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___368 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___368 core_layout;
	struct module_layout___368 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___368 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___368 *, struct module_kobject___368 *, char *);
	ssize_t (*store)(struct module_attribute___368 *, struct module_kobject___368 *, const char *, size_t);
	void (*setup)(struct module___333 *, const char *);
	int (*test)(struct module___333 *);
	void (*free)(struct module___333 *);
};

struct user_struct___410 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___410 *uid_keyring;
	struct key___410 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___443;

struct mm_struct___443 {
	struct {
		struct vm_area_struct___443 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___442 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___444 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___443 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___444 *owner;
		struct user_namespace___307 *user_ns;
		struct file___442 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___443 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup___291;

struct cgroup_subsys___291;

struct cgroup_subsys_state___291 {
	struct cgroup___291 *cgroup;
	struct cgroup_subsys___291 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___291 *parent;
};

struct cgroup_file___291 {
	struct kernfs_node___437 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___175;

struct mem_cgroup___175 {
	struct cgroup_subsys_state___291 css;
	struct mem_cgroup_id___13 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___291 events_file;
	struct cgroup_file___291 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___444 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___175 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cgroup_namespace___291;

struct nsproxy___337 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net___98 *net_ns;
	struct cgroup_namespace___291 *cgroup_ns;
};

struct signal_struct___317 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___444 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___444 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___245 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___245 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___443 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___245 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___232;

struct bio_list___232 {
	struct bio___232 *head;
	struct bio___232 *tail;
};

struct bdi_writeback_congested___232;

struct bdi_writeback___232 {
	struct backing_dev_info___232 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___232 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___291 *memcg_css;
	struct cgroup_subsys_state___291 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___410;

struct backing_dev_info___232 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___232 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___410 *dev;
	struct device___410 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___442 *debug_dir;
	struct dentry___442 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___291 {
	struct cgroup_subsys_state___291 *subsys[13];
	refcount_t refcount;
	struct css_set___291 *dom_cset;
	struct cgroup___291 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___291 *mg_src_cgrp;
	struct cgroup___291 *mg_dst_cgrp;
	struct css_set___291 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___442;

struct pipe_buffer___123;

struct pipe_inode_info___123 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___443 *tmp_page;
	struct fasync_struct___442 *fasync_readers;
	struct fasync_struct___442 *fasync_writers;
	struct pipe_buffer___123 *bufs;
	struct user_struct___410 *user;
};

struct vm_struct___346 {
	struct vm_struct___346 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___443 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___329 {
	struct task_struct___444 task;
	long unsigned int stack[8192];
};

struct address_space_operations___442;

struct address_space___442 {
	struct inode___442 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___444 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___442 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___430)(struct vm_area_struct___443 *, long unsigned int, const struct page___443 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___430)(struct page___443 *, void *);

struct dev_pagemap___430 {
	dev_page_fault_t___430 page_fault;
	dev_page_free_t___430 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___410 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___443 {
	struct task_struct___444 *task;
	struct core_thread___443 *next;
};

struct core_state___443 {
	atomic_t nr_threads;
	struct core_thread___443 dumper;
	struct completion startup;
};

struct vm_fault___430 {
	struct vm_area_struct___443 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___443 *cow_page;
	struct mem_cgroup___175 *memcg;
	struct page___443 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___443 prealloc_pte;
};

struct crypto_async_request___32;

typedef void (*crypto_completion_t___32)(struct crypto_async_request___32 *, int);

struct crypto_tfm___32;

struct crypto_async_request___32 {
	struct list_head list;
	crypto_completion_t___32 complete;
	void *data;
	struct crypto_tfm___32 *tfm;
	u32 flags;
};

struct crypto_ablkcipher___32;

struct ablkcipher_request___32;

struct ablkcipher_tfm___32 {
	int (*setkey)(struct crypto_ablkcipher___32 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___32 *);
	int (*decrypt)(struct ablkcipher_request___32 *);
	struct crypto_ablkcipher___32 *base;
	unsigned int ivsize;
	unsigned int reqsize;
};

struct blkcipher_desc___32;

struct blkcipher_tfm___32 {
	void *iv;
	int (*setkey)(struct crypto_tfm___32 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___32 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___32 *, struct scatterlist *, struct scatterlist *, unsigned int);
};

struct cipher_tfm___32 {
	int (*cit_setkey)(struct crypto_tfm___32 *, const u8 *, unsigned int);
	void (*cit_encrypt_one)(struct crypto_tfm___32 *, u8 *, const u8 *);
	void (*cit_decrypt_one)(struct crypto_tfm___32 *, u8 *, const u8 *);
};

struct compress_tfm___32 {
	int (*cot_compress)(struct crypto_tfm___32 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*cot_decompress)(struct crypto_tfm___32 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___32;

struct crypto_tfm___32 {
	u32 crt_flags;
	union {
		struct ablkcipher_tfm___32 ablkcipher;
		struct blkcipher_tfm___32 blkcipher;
		struct cipher_tfm___32 cipher;
		struct compress_tfm___32 compress;
	} crt_u;
	void (*exit)(struct crypto_tfm___32 *);
	struct crypto_alg___32 *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct ablkcipher_request___32 {
	struct crypto_async_request___32 base;
	unsigned int nbytes;
	void *info;
	struct scatterlist *src;
	struct scatterlist *dst;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_blkcipher___32;

struct blkcipher_desc___32 {
	struct crypto_blkcipher___32 *tfm;
	void *info;
	u32 flags;
};

struct crypto_blkcipher___32 {
	struct crypto_tfm___32 base;
};

struct ablkcipher_alg___32 {
	int (*setkey)(struct crypto_ablkcipher___32 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___32 *);
	int (*decrypt)(struct ablkcipher_request___32 *);
	int (*givencrypt)(struct skcipher_givcrypt_request *);
	int (*givdecrypt)(struct skcipher_givcrypt_request *);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct crypto_ablkcipher___32 {
	struct crypto_tfm___32 base;
};

struct blkcipher_alg___32 {
	int (*setkey)(struct crypto_tfm___32 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___32 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___32 *, struct scatterlist *, struct scatterlist *, unsigned int);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct cipher_alg___32 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___32 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___32 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___32 *, u8 *, const u8 *);
};

struct compress_alg___32 {
	int (*coa_compress)(struct crypto_tfm___32 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___32 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___32 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type *cra_type;
	union {
		struct ablkcipher_alg___32 ablkcipher;
		struct blkcipher_alg___32 blkcipher;
		struct cipher_alg___32 cipher;
		struct compress_alg___32 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___32 *);
	void (*cra_exit)(struct crypto_tfm___32 *);
	void (*cra_destroy)(struct crypto_alg___32 *);
	struct module___333 *cra_module;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct crypto_cipher___16 {
	struct crypto_tfm___32 base;
};

struct bio_vec___234 {
	struct page___443 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___209 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___234 *bvec;
		struct pipe_inode_info___123 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct msghdr___70 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___209 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___442 *msg_iocb;
};

struct kiocb___442 {
	struct file___442 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___442 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dentry_operations___442;

struct super_block___442;

struct dentry___442 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___442 *d_parent;
	struct qstr d_name;
	struct inode___442 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___442 *d_op;
	struct super_block___442 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___442;

struct block_device___442;

struct inode___442 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___442 *i_op;
	struct super_block___442 *i_sb;
	struct address_space___442 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___444 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___232 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___442 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___442 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___123 *i_pipe;
		struct block_device___442 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___442 {
	int (*d_revalidate)(struct dentry___442 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___442 *, unsigned int);
	int (*d_hash)(const struct dentry___442 *, struct qstr *);
	int (*d_compare)(const struct dentry___442 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___442 *);
	int (*d_init)(struct dentry___442 *);
	void (*d_release)(struct dentry___442 *);
	void (*d_prune)(struct dentry___442 *);
	void (*d_iput)(struct dentry___442 *, struct inode___442 *);
	char * (*d_dname)(struct dentry___442 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___443 *);
	int (*d_manage)(const struct path___443 *, bool);
	struct dentry___442 * (*d_real)(struct dentry___442 *, const struct inode___442 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___442;

struct mem_dqinfo___442 {
	struct quota_format_type___442 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___442;

struct quota_info___442 {
	unsigned int flags;
	struct rw_semaphore___444 dqio_sem;
	struct inode___442 *files[3];
	struct mem_dqinfo___442 info[3];
	const struct quota_format_ops___442 *ops[3];
};

struct rcuwait___442 {
	struct task_struct___444 *task;
};

struct percpu_rw_semaphore___442 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___444 rw_sem;
	struct rcuwait___442 writer;
	int readers_block;
};

struct sb_writers___442 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___442 rw_sem[3];
};

struct shrink_control___175;

struct shrinker___175 {
	long unsigned int (*count_objects)(struct shrinker___175 *, struct shrink_control___175 *);
	long unsigned int (*scan_objects)(struct shrinker___175 *, struct shrink_control___175 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___442;

struct super_operations___442;

struct dquot_operations___442;

struct quotactl_ops___442;

struct super_block___442 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___442 *s_type;
	const struct super_operations___442 *s_op;
	const struct dquot_operations___442 *dq_op;
	const struct quotactl_ops___442 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___442 *s_root;
	struct rw_semaphore___444 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___442 *s_bdev;
	struct backing_dev_info___232 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___442 s_dquot;
	struct sb_writers___442 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___442 *s_d_op;
	int cleancache_poolid;
	struct shrinker___175 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___307 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___175 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___175 *memcg;
};

struct iattr___442 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___442 *ia_file;
};

struct dquot___442 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___442 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___442 {
	int qf_fmt_id;
	const struct quota_format_ops___442 *qf_ops;
	struct module___333 *qf_owner;
	struct quota_format_type___442 *qf_next;
};

struct quota_format_ops___442 {
	int (*check_quota_file)(struct super_block___442 *, int);
	int (*read_file_info)(struct super_block___442 *, int);
	int (*write_file_info)(struct super_block___442 *, int);
	int (*free_file_info)(struct super_block___442 *, int);
	int (*read_dqblk)(struct dquot___442 *);
	int (*commit_dqblk)(struct dquot___442 *);
	int (*release_dqblk)(struct dquot___442 *);
	int (*get_next_id)(struct super_block___442 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___442 {
	int (*write_dquot)(struct dquot___442 *);
	struct dquot___442 * (*alloc_dquot)(struct super_block___442 *, int);
	void (*destroy_dquot)(struct dquot___442 *);
	int (*acquire_dquot)(struct dquot___442 *);
	int (*release_dquot)(struct dquot___442 *);
	int (*mark_dirty)(struct dquot___442 *);
	int (*write_info)(struct super_block___442 *, int);
	qsize_t * (*get_reserved_space)(struct inode___442 *);
	int (*get_projid)(struct inode___442 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___442 *, qsize_t *);
	int (*get_next_id)(struct super_block___442 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___442 {
	int (*quota_on)(struct super_block___442 *, int, int, const struct path___443 *);
	int (*quota_off)(struct super_block___442 *, int);
	int (*quota_enable)(struct super_block___442 *, unsigned int);
	int (*quota_disable)(struct super_block___442 *, unsigned int);
	int (*quota_sync)(struct super_block___442 *, int);
	int (*set_info)(struct super_block___442 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___442 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___442 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___442 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___442 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___442 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___195;

struct address_space_operations___442 {
	int (*writepage)(struct page___443 *, struct writeback_control___195 *);
	int (*readpage)(struct file___442 *, struct page___443 *);
	int (*writepages)(struct address_space___442 *, struct writeback_control___195 *);
	int (*set_page_dirty)(struct page___443 *);
	int (*readpages)(struct file___442 *, struct address_space___442 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___442 *, struct address_space___442 *, loff_t, unsigned int, unsigned int, struct page___443 **, void **);
	int (*write_end)(struct file___442 *, struct address_space___442 *, loff_t, unsigned int, unsigned int, struct page___443 *, void *);
	sector_t (*bmap)(struct address_space___442 *, sector_t);
	void (*invalidatepage)(struct page___443 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___443 *, gfp_t);
	void (*freepage)(struct page___443 *);
	ssize_t (*direct_IO)(struct kiocb___442 *, struct iov_iter___209 *);
	int (*migratepage)(struct address_space___442 *, struct page___443 *, struct page___443 *, enum migrate_mode);
	bool (*isolate_page)(struct page___443 *, isolate_mode_t);
	void (*putback_page)(struct page___443 *);
	int (*launder_page)(struct page___443 *);
	int (*is_partially_uptodate)(struct page___443 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___443 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___442 *, struct page___443 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___442 *, sector_t *);
	void (*swap_deactivate)(struct file___442 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___195 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___232 *wb;
	struct inode___442 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___442 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___442 *bd_inode;
	struct super_block___442 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___442 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___232 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___442 {
	struct dentry___442 * (*lookup)(struct inode___442 *, struct dentry___442 *, unsigned int);
	const char * (*get_link)(struct dentry___442 *, struct inode___442 *, struct delayed_call *);
	int (*permission)(struct inode___442 *, int);
	struct posix_acl * (*get_acl)(struct inode___442 *, int);
	int (*readlink)(struct dentry___442 *, char *, int);
	int (*create)(struct inode___442 *, struct dentry___442 *, umode_t, bool);
	int (*link)(struct dentry___442 *, struct inode___442 *, struct dentry___442 *);
	int (*unlink)(struct inode___442 *, struct dentry___442 *);
	int (*symlink)(struct inode___442 *, struct dentry___442 *, const char *);
	int (*mkdir)(struct inode___442 *, struct dentry___442 *, umode_t);
	int (*rmdir)(struct inode___442 *, struct dentry___442 *);
	int (*mknod)(struct inode___442 *, struct dentry___442 *, umode_t, dev_t);
	int (*rename)(struct inode___442 *, struct dentry___442 *, struct inode___442 *, struct dentry___442 *, unsigned int);
	int (*setattr)(struct dentry___442 *, struct iattr___442 *);
	int (*getattr)(const struct path___443 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___442 *, char *, size_t);
	int (*fiemap)(struct inode___442 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___442 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___442 *, struct dentry___442 *, struct file___442 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___442 *, struct dentry___442 *, umode_t);
	int (*set_acl)(struct inode___442 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___442 {
	void (*fl_copy_lock)(struct file_lock___442 *, struct file_lock___442 *);
	void (*fl_release_private)(struct file_lock___442 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___442;

struct file_lock___442 {
	struct file_lock___442 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___442 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___442 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___442 *fl_ops;
	const struct lock_manager_operations___442 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___442 {
	int (*lm_compare_owner)(struct file_lock___442 *, struct file_lock___442 *);
	long unsigned int (*lm_owner_key)(struct file_lock___442 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___442 *);
	int (*lm_grant)(struct file_lock___442 *, int);
	bool (*lm_break)(struct file_lock___442 *);
	int (*lm_change)(struct file_lock___442 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___442 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___442 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___442 *fa_next;
	struct file___442 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___442 {
	const char *name;
	int fs_flags;
	struct dentry___442 * (*mount)(struct file_system_type___442 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___442 *);
	struct module___333 *owner;
	struct file_system_type___442 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___442 {
	struct inode___442 * (*alloc_inode)(struct super_block___442 *);
	void (*destroy_inode)(struct inode___442 *);
	void (*dirty_inode)(struct inode___442 *, int);
	int (*write_inode)(struct inode___442 *, struct writeback_control___195 *);
	int (*drop_inode)(struct inode___442 *);
	void (*evict_inode)(struct inode___442 *);
	void (*put_super)(struct super_block___442 *);
	int (*sync_fs)(struct super_block___442 *, int);
	int (*freeze_super)(struct super_block___442 *);
	int (*freeze_fs)(struct super_block___442 *);
	int (*thaw_super)(struct super_block___442 *);
	int (*unfreeze_fs)(struct super_block___442 *);
	int (*statfs)(struct dentry___442 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___442 *, int *, char *);
	void (*umount_begin)(struct super_block___442 *);
	int (*show_options)(struct seq_file___381 *, struct dentry___442 *);
	int (*show_devname)(struct seq_file___381 *, struct dentry___442 *);
	int (*show_path)(struct seq_file___381 *, struct dentry___442 *);
	int (*show_stats)(struct seq_file___381 *, struct dentry___442 *);
	ssize_t (*quota_read)(struct super_block___442 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___442 *, int, const char *, size_t, loff_t);
	struct dquot___442 ** (*get_dquots)(struct inode___442 *);
	int (*bdev_try_to_free_page)(struct super_block___442 *, struct page___443 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___442 *, struct shrink_control___175 *);
	long int (*free_cached_objects)(struct super_block___442 *, struct shrink_control___175 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___232(struct bio___232 *);

struct bio_integrity_payload___232;

struct bio_set___232;

struct bio___232 {
	struct bio___232 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___232 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___232 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___234 *bi_io_vec;
	struct bio_set___232 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___234 bi_inline_vecs[0];
};

struct socket_wq___68 {
	wait_queue_head_t wait;
	struct fasync_struct___442 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___68;

struct socket___69 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___68 *wq;
	struct file___442 *file;
	struct sock___33 *sk;
	const struct proto_ops___68 *ops;
};

typedef int (*sk_read_actor_t___67)(read_descriptor_t *, struct sk_buff___88 *, unsigned int, size_t);

struct proto_ops___68 {
	int family;
	struct module___333 *owner;
	int (*release)(struct socket___69 *);
	int (*bind)(struct socket___69 *, struct sockaddr *, int);
	int (*connect)(struct socket___69 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___69 *, struct socket___69 *);
	int (*accept)(struct socket___69 *, struct socket___69 *, int, bool);
	int (*getname)(struct socket___69 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___442 *, struct socket___69 *, struct poll_table_struct___281 *);
	int (*ioctl)(struct socket___69 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___69 *, int);
	int (*shutdown)(struct socket___69 *, int);
	int (*setsockopt)(struct socket___69 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___69 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___69 *, struct msghdr___70 *, size_t);
	int (*recvmsg)(struct socket___69 *, struct msghdr___70 *, size_t, int);
	int (*mmap)(struct file___442 *, struct socket___69 *, struct vm_area_struct___443 *);
	ssize_t (*sendpage)(struct socket___69 *, struct page___443 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___69 *, loff_t *, struct pipe_inode_info___123 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___33 *, int);
	int (*peek_len)(struct socket___69 *);
	int (*read_sock)(struct sock___33 *, read_descriptor_t *, sk_read_actor_t___67);
	int (*sendpage_locked)(struct sock___33 *, struct page___443 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___33 *, struct msghdr___70 *, size_t);
	int (*set_rcvlowat)(struct sock___33 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct nf_bridge_info___87;

struct sk_buff___88 {
	union {
		struct {
			struct sk_buff___88 *next;
			struct sk_buff___88 *prev;
			union {
				struct net_device___87 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___33 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___88 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___87 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___87;

struct netns_frags___87 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___87 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ip_ra_chain___33;

struct fib_rules_ops___67;

struct tcp_congestion_ops___13;

struct tcp_fastopen_context___13;

struct fib_notifier_ops___68;

struct netns_ipv4___87 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___33 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___67 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___33 *fibnl;
	struct sock___33 **icmp_sk;
	struct sock___33 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___33 **tcp_sk;
	struct netns_frags___87 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops___13 *tcp_congestion_control;
	struct tcp_fastopen_context___13 *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___67 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___68 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___68 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___67;

struct dst_ops___98 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___98 *);
	struct dst_entry___67 * (*check)(struct dst_entry___67 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___67 *);
	unsigned int (*mtu)(const struct dst_entry___67 *);
	u32 * (*cow_metrics)(struct dst_entry___67 *, long unsigned int);
	void (*destroy)(struct dst_entry___67 *);
	void (*ifdown)(struct dst_entry___67 *, struct net_device___87 *, int);
	struct dst_entry___67 * (*negative_advice)(struct dst_entry___67 *);
	void (*link_failure)(struct sk_buff___88 *);
	void (*update_pmtu)(struct dst_entry___67 *, struct sock___33 *, struct sk_buff___88 *, u32);
	void (*redirect)(struct dst_entry___67 *, struct sock___33 *, struct sk_buff___88 *);
	int (*local_out)(struct net___98 *, struct sock___33 *, struct sk_buff___88 *);
	struct neighbour___67 * (*neigh_lookup)(const struct dst_entry___67 *, struct sk_buff___88 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___67 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___98 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___87 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___98 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___67 *fib6_rules_ops;
	struct sock___33 **icmp_sk;
	struct sock___33 *ndisc_sk;
	struct sock___33 *tcp_sk;
	struct sock___33 *igmp_sk;
	struct sock___33 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___67 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___68 *notifier_ops;
	struct fib_notifier_ops___68 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___68 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___33 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___87 {
	struct netns_frags___87 frags;
};

struct netns_xfrm___98 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___33 *nlsk;
	struct sock___33 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___98 xfrm4_dst_ops;
	struct dst_ops___98 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___77;

struct net___98 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___307 *user_ns;
	struct ucounts___307 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___29 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___33 *rtnl;
	struct sock___33 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___87 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___87 ipv4;
	struct netns_ipv6___98 ipv6;
	struct netns_sctp___68 sctp;
	struct netns_nf___12 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___87 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___33 *nfnl;
	struct sock___33 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___98 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___33 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___77 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___410 {
	int (*prepare)(struct device___410 *);
	void (*complete)(struct device___410 *);
	int (*suspend)(struct device___410 *);
	int (*resume)(struct device___410 *);
	int (*freeze)(struct device___410 *);
	int (*thaw)(struct device___410 *);
	int (*poweroff)(struct device___410 *);
	int (*restore)(struct device___410 *);
	int (*suspend_late)(struct device___410 *);
	int (*resume_early)(struct device___410 *);
	int (*freeze_late)(struct device___410 *);
	int (*thaw_early)(struct device___410 *);
	int (*poweroff_late)(struct device___410 *);
	int (*restore_early)(struct device___410 *);
	int (*suspend_noirq)(struct device___410 *);
	int (*resume_noirq)(struct device___410 *);
	int (*freeze_noirq)(struct device___410 *);
	int (*thaw_noirq)(struct device___410 *);
	int (*poweroff_noirq)(struct device___410 *);
	int (*restore_noirq)(struct device___410 *);
	int (*runtime_suspend)(struct device___410 *);
	int (*runtime_resume)(struct device___410 *);
	int (*runtime_idle)(struct device___410 *);
};

struct dev_pm_info___410 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___410 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___410;

struct bus_type___410;

struct device_driver___410;

struct dev_pm_domain___410;

struct dma_map_ops___182;

struct fwnode_handle___330;

struct class___410;

struct device___410 {
	struct device___410 *parent;
	struct device_private *p;
	struct kobject___430 kobj;
	const char *init_name;
	const struct device_type___410 *type;
	struct mutex mutex;
	struct bus_type___410 *bus;
	struct device_driver___410 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___410 power;
	struct dev_pm_domain___410 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___182 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___330 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___410 *class;
	const struct attribute_group___407 **groups;
	void (*release)(struct device___410 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___410 {
	struct dev_pm_ops___410 ops;
	void (*detach)(struct device___410 *, bool);
	int (*activate)(struct device___410 *);
	void (*sync)(struct device___410 *);
	void (*dismiss)(struct device___410 *);
};

struct bus_type___410 {
	const char *name;
	const char *dev_name;
	struct device___410 *dev_root;
	const struct attribute_group___407 **bus_groups;
	const struct attribute_group___407 **dev_groups;
	const struct attribute_group___407 **drv_groups;
	int (*match)(struct device___410 *, struct device_driver___410 *);
	int (*uevent)(struct device___410 *, struct kobj_uevent_env *);
	int (*probe)(struct device___410 *);
	int (*remove)(struct device___410 *);
	void (*shutdown)(struct device___410 *);
	int (*online)(struct device___410 *);
	int (*offline)(struct device___410 *);
	int (*suspend)(struct device___410 *, pm_message_t);
	int (*resume)(struct device___410 *);
	int (*num_vf)(struct device___410 *);
	int (*dma_configure)(struct device___410 *);
	const struct dev_pm_ops___410 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___410 {
	const char *name;
	struct bus_type___410 *bus;
	struct module___333 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___410 *);
	int (*remove)(struct device___410 *);
	void (*shutdown)(struct device___410 *);
	int (*suspend)(struct device___410 *, pm_message_t);
	int (*resume)(struct device___410 *);
	const struct attribute_group___407 **groups;
	const struct dev_pm_ops___410 *pm;
	void (*coredump)(struct device___410 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___410 {
	const char *name;
	const struct attribute_group___407 **groups;
	int (*uevent)(struct device___410 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___410 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___410 *);
	const struct dev_pm_ops___410 *pm;
};

struct class___410 {
	const char *name;
	struct module___333 *owner;
	const struct attribute_group___407 **class_groups;
	const struct attribute_group___407 **dev_groups;
	struct kobject___430 *dev_kobj;
	int (*dev_uevent)(struct device___410 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___410 *, umode_t *);
	void (*class_release)(struct class___410 *);
	void (*dev_release)(struct device___410 *);
	int (*shutdown_pre)(struct device___410 *);
	const struct kobj_ns_type_operations___67 *ns_type;
	const void * (*namespace)(struct device___410 *);
	const struct dev_pm_ops___410 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___182 {
	void * (*alloc)(struct device___410 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___410 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___410 *, struct vm_area_struct___443 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___410 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___410 *, struct page___443 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___410 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___410 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___410 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___410 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___410 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___410 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___410 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___410 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___410 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___410 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___410 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___410 *, u64);
	u64 (*get_required_mask)(struct device___410 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___330;

struct fwnode_handle___330 {
	struct fwnode_handle___330 *secondary;
	const struct fwnode_operations___330 *ops;
};

typedef void compound_page_dtor___430(struct page___443 *);

struct fwnode_reference_args___330;

struct fwnode_endpoint___330;

struct fwnode_operations___330 {
	struct fwnode_handle___330 * (*get)(struct fwnode_handle___330 *);
	void (*put)(struct fwnode_handle___330 *);
	bool (*device_is_available)(const struct fwnode_handle___330 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___330 *, const struct device___410 *);
	bool (*property_present)(const struct fwnode_handle___330 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___330 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___330 *, const char *, const char **, size_t);
	struct fwnode_handle___330 * (*get_parent)(const struct fwnode_handle___330 *);
	struct fwnode_handle___330 * (*get_next_child_node)(const struct fwnode_handle___330 *, struct fwnode_handle___330 *);
	struct fwnode_handle___330 * (*get_named_child_node)(const struct fwnode_handle___330 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___330 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___330 *);
	struct fwnode_handle___330 * (*graph_get_next_endpoint)(const struct fwnode_handle___330 *, struct fwnode_handle___330 *);
	struct fwnode_handle___330 * (*graph_get_remote_endpoint)(const struct fwnode_handle___330 *);
	struct fwnode_handle___330 * (*graph_get_port_parent)(struct fwnode_handle___330 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___330 *, struct fwnode_endpoint___330 *);
};

struct fwnode_endpoint___330 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___330 *local_fwnode;
};

struct fwnode_reference_args___330 {
	struct fwnode_handle___330 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___123;

struct pipe_buffer___123 {
	struct page___443 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___123 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___123 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___123 *, struct pipe_buffer___123 *);
	void (*release)(struct pipe_inode_info___123 *, struct pipe_buffer___123 *);
	int (*steal)(struct pipe_inode_info___123 *, struct pipe_buffer___123 *);
	union {
		bool (*get)(struct pipe_inode_info___123 *, struct pipe_buffer___123 *);
		struct {
			void (*get)(struct pipe_inode_info___123 *, struct pipe_buffer___123 *);
		} __UNIQUE_ID_rh_kabi_hide21;
		union {		};
	};
};

struct nf_bridge_info___87 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___87 = 0,
		BRNF_PROTO_8021Q___87 = 1,
		BRNF_PROTO_PPPOE___87 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___87 *physindev;
	struct net_device___87 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___87(struct sk_buff___88 **);

struct net_device_ops___87;

struct ethtool_ops___87;

struct l3mdev_ops___67;

struct ndisc_ops___38;

struct xfrmdev_ops___87;

struct tlsdev_ops___87;

struct header_ops___87;

struct inet6_dev___38;

struct netdev_rx_queue___87;

struct mini_Qdisc___79;

struct netdev_queue___87;

struct Qdisc___79;

struct rtnl_link_ops___79;

struct dcbnl_rtnl_ops___87;

struct net_device___87 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___87 *netdev_ops;
	const struct ethtool_ops___87 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___67 *l3mdev_ops;
	const struct ndisc_ops___38 *ndisc_ops;
	const struct xfrmdev_ops___87 *xfrmdev_ops;
	const struct tlsdev_ops___87 *tlsdev_ops;
	const struct header_ops___87 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___429 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___38 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___87 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___77 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___87 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___79 *miniq_ingress;
	struct netdev_queue___87 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___87 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___79 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___79 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___87 = 0,
		NETREG_REGISTERED___87 = 1,
		NETREG_UNREGISTERING___87 = 2,
		NETREG_UNREGISTERED___87 = 3,
		NETREG_RELEASED___87 = 4,
		NETREG_DUMMY___87 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___87 = 0,
		RTNL_LINK_INITIALIZING___87 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___87 *);
	struct netpoll_info *npinfo;
	possible_net_t___89 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___410 dev;
	const struct attribute_group___407 *sysfs_groups[4];
	const struct attribute_group___407 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___79 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___87 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide35;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct ethtool_ops___87 {
	int (*get_settings)(struct net_device___87 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___87 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___87 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___87 *);
	void (*get_regs)(struct net_device___87 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___87 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___87 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___87 *);
	void (*set_msglevel)(struct net_device___87 *, u32);
	int (*nway_reset)(struct net_device___87 *);
	u32 (*get_link)(struct net_device___87 *);
	int (*get_eeprom_len)(struct net_device___87 *);
	int (*get_eeprom)(struct net_device___87 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___87 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___87 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___87 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___87 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___87 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___87 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___87 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___87 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___87 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___87 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___87 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___87 *);
	void (*complete)(struct net_device___87 *);
	u32 (*get_priv_flags)(struct net_device___87 *);
	int (*set_priv_flags)(struct net_device___87 *, u32);
	int (*get_sset_count)(struct net_device___87 *, int);
	int (*get_rxnfc)(struct net_device___87 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___87 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___87 *, struct ethtool_flash *);
	int (*reset)(struct net_device___87 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___87 *);
	u32 (*get_rxfh_indir_size)(struct net_device___87 *);
	int (*get_rxfh)(struct net_device___87 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___87 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___87 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___87 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___87 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___87 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___87 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___87 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___87 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___87 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___87 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___87 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___87 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___87 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___87 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___87 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___87 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___87 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___87 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___87 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___87 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___87 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	int (*get_fecparam)(struct net_device___87 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___87 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___87 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___87 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___87 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___87;

struct inet_frags___87 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___87 *, const void *);
	void (*destructor)(struct inet_frag_queue___87 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___87 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___88 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___88 *fragments_tail;
	struct sk_buff___88 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___87 *net;
	struct callback_head rcu;
};

struct ip_ra_chain___33 {
	struct ip_ra_chain___33 *next;
	struct sock___33 *sk;
	union {
		void (*destructor)(struct sock___33 *);
		struct sock___33 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___67;

struct fib_lookup_arg___67;

struct fib_rules_ops___67 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___67 *, struct flowi *, int, struct fib_lookup_arg___67 *);
	bool (*suppress)(struct fib_rule___67 *, struct fib_lookup_arg___67 *);
	int (*match)(struct fib_rule___67 *, struct flowi *, int);
	int (*configure)(struct fib_rule___67 *, struct sk_buff___88 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___67 *);
	int (*compare)(struct fib_rule___67 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___67 *, struct sk_buff___88 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___67 *);
	void (*flush_cache)(struct fib_rules_ops___67 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___333 *owner;
	struct net___98 *fro_net;
	struct callback_head rcu;
};

struct tcp_congestion_ops___13 {
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___33 *);
	void (*release)(struct sock___33 *);
	u32 (*ssthresh)(struct sock___33 *);
	void (*cong_avoid)(struct sock___33 *, u32, u32);
	void (*set_state)(struct sock___33 *, u8);
	void (*cwnd_event)(struct sock___33 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___33 *, u32);
	u32 (*undo_cwnd)(struct sock___33 *);
	void (*pkts_acked)(struct sock___33 *, const struct ack_sample *);
	u32 (*min_tso_segs)(struct sock___33 *);
	u32 (*sndbuf_expand)(struct sock___33 *);
	void (*cong_control)(struct sock___33 *, const struct rate_sample *);
	size_t (*get_info)(struct sock___33 *, u32, int *, union tcp_cc_info *);
	char name[16];
	struct module___333 *owner;
};

struct tcp_fastopen_context___13 {
	struct crypto_cipher___16 *tfm;
	__u8 key[16];
	struct callback_head rcu;
};

struct fib_notifier_ops___68 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___98 *);
	int (*fib_dump)(struct net___98 *, struct notifier_block *);
	struct module___333 *owner;
	struct callback_head rcu;
};

struct dst_entry___67 {
	struct net_device___87 *dev;
	struct dst_ops___98 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___88 *);
	int (*output)(struct net___98 *, struct sock___33 *, struct sk_buff___88 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___67;

struct neigh_parms___67;

struct neigh_ops___67;

struct neighbour___67 {
	struct neighbour___67 *next;
	struct neigh_table___67 *tbl;
	struct neigh_parms___67 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___87 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___67 *, struct sk_buff___88 *);
	const struct neigh_ops___67 *ops;
	struct callback_head rcu;
	struct net_device___87 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct ucounts___307 {
	struct hlist_node node;
	struct user_namespace___307 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_prog_aux___80;

struct bpf_prog___77 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___80 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

typedef int (*key_restrict_link_func_t___411)(struct key___410 *, const struct key_type *, const union key_payload *, struct key___410 *);

struct key_restriction___410;

struct key___410 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___444 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___410 *restrict_link;
};

struct key_restriction___410 {
	key_restrict_link_func_t___411 check;
	struct key___410 *key;
	struct key_type *keytype;
};

struct seq_operations___381 {
	void * (*start)(struct seq_file___381 *, loff_t *);
	void (*stop)(struct seq_file___381 *, void *);
	void * (*next)(struct seq_file___381 *, void *, loff_t *);
	int (*show)(struct seq_file___381 *, void *);
};

struct pernet_operations___88 {
	struct list_head list;
	int (*init)(struct net___98 *);
	void (*exit)(struct net___98 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___87 {
	int (*ieee_getets)(struct net_device___87 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___87 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___87 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___87 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___87 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___87 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___87 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___87 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___87 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___87 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___87 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___87 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___87 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___87 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___87 *);
	u8 (*setstate)(struct net_device___87 *, u8);
	void (*getpermhwaddr)(struct net_device___87 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___87 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___87 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___87 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___87 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___87 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___87 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___87 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___87 *, int, u8 *);
	void (*setpfccfg)(struct net_device___87 *, int, u8);
	void (*getpfccfg)(struct net_device___87 *, int, u8 *);
	u8 (*setall)(struct net_device___87 *);
	u8 (*getcap)(struct net_device___87 *, int, u8 *);
	int (*getnumtcs)(struct net_device___87 *, int, u8 *);
	int (*setnumtcs)(struct net_device___87 *, int, u8);
	u8 (*getpfcstate)(struct net_device___87 *);
	void (*setpfcstate)(struct net_device___87 *, u8);
	void (*getbcncfg)(struct net_device___87 *, int, u32 *);
	void (*setbcncfg)(struct net_device___87 *, int, u32);
	void (*getbcnrp)(struct net_device___87 *, int, u8 *);
	void (*setbcnrp)(struct net_device___87 *, int, u8);
	int (*setapp)(struct net_device___87 *, u8, u16, u8);
	int (*getapp)(struct net_device___87 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___87 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___87 *, int, u8);
	u8 (*getdcbx)(struct net_device___87 *);
	u8 (*setdcbx)(struct net_device___87 *, u8);
	int (*peer_getappinfo)(struct net_device___87 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___87 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___87 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___87 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___87 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___87 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___291 {
	refcount_t count;
	struct ns_common___29 ns;
	struct user_namespace___307 *user_ns;
	struct ucounts___307 *ucounts;
	struct css_set___291 *root_cset;
};

struct bpf_map___292;

struct bpf_map_ops___291 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___292 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___292 *, struct file___442 *);
	void (*map_free)(struct bpf_map___292 *);
	int (*map_get_next_key)(struct bpf_map___292 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___292 *);
	void * (*map_lookup_elem)(struct bpf_map___292 *, void *);
	int (*map_update_elem)(struct bpf_map___292 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___292 *, void *);
	int (*map_push_elem)(struct bpf_map___292 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___292 *, void *);
	int (*map_peek_elem)(struct bpf_map___292 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___292 *, struct file___442 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___292 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___292 *, void *, struct seq_file___381 *);
	int (*map_check_btf)(const struct bpf_map___292 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___292 {
	const struct bpf_map_ops___291 *ops;
	struct bpf_map___292 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___410 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___87;

struct bpf_map_dev_ops___87 {
	int (*map_get_next_key)(struct bpf_offloaded_map___87 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___87 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___87 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___87 *, void *);
};

struct bpf_offloaded_map___87 {
	struct bpf_map___292 map;
	struct net_device___87 *netdev;
	const struct bpf_map_dev_ops___87 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___77 {
	int (*test_run)(struct bpf_prog___77 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___77 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___77 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___77 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___77 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___77 *, u32 *);
};

struct bpf_prog_offload_ops___77 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___77 *);
	int (*translate)(struct bpf_prog___77 *);
	void (*destroy)(struct bpf_prog___77 *);
};

struct bpf_prog_offload___77 {
	struct bpf_prog___77 *prog;
	struct net_device___87 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___77 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___80 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___77 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___77 *ops;
	struct bpf_map___292 **used_maps;
	struct bpf_prog___77 *prog;
	struct user_struct___410 *user;
	u64 load_time;
	struct bpf_map___292 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___77 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___77 {
	struct bpf_prog___77 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___77 {
	struct callback_head rcu;
	struct bpf_prog_array_item___77 items[0];
};

struct cgroup_bpf___77 {
	struct bpf_prog_array___77 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___77 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___292;

typedef void (*kthread_work_func_t___292)(struct kthread_work___292 *);

struct kthread_worker___292;

struct kthread_work___292 {
	struct list_head node;
	kthread_work_func_t___292 func;
	struct kthread_worker___292 *worker;
	int canceling;
};

struct kthread_worker___292 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___444 *task;
	struct kthread_work___292 *current_work;
};

struct kthread_delayed_work___291 {
	struct kthread_work___292 work;
	struct timer_list timer;
};

struct psi_group___291 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___292 *poll_kworker;
	struct kthread_delayed_work___291 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___291;

struct cgroup_rstat_cpu___291;

struct cgroup___291 {
	struct cgroup_subsys_state___291 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___437 *kn;
	struct cgroup_file___291 procs_file;
	struct cgroup_file___291 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___291 *subsys[13];
	struct cgroup_root___291 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___291 *dom_cgrp;
	struct cgroup_rstat_cpu___291 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___77 bpf;
	atomic_t congestion_count;
	struct cgroup___291 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___291 psi;
	int ancestor_ids[0];
};

struct cftype___291;

struct cgroup_subsys___291 {
	struct cgroup_subsys_state___291 * (*css_alloc)(struct cgroup_subsys_state___291 *);
	int (*css_online)(struct cgroup_subsys_state___291 *);
	void (*css_offline)(struct cgroup_subsys_state___291 *);
	void (*css_released)(struct cgroup_subsys_state___291 *);
	void (*css_free)(struct cgroup_subsys_state___291 *);
	void (*css_reset)(struct cgroup_subsys_state___291 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___291 *, int);
	int (*css_extra_stat_show)(struct seq_file___381 *, struct cgroup_subsys_state___291 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___444 *);
	void (*cancel_fork)(struct task_struct___444 *);
	void (*fork)(struct task_struct___444 *);
	void (*exit)(struct task_struct___444 *);
	void (*free)(struct task_struct___444 *);
	void (*bind)(struct cgroup_subsys_state___291 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___291 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___291 *dfl_cftypes;
	struct cftype___291 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___291 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___291 *updated_children;
	struct cgroup___291 *updated_next;
};

struct cgroup_root___291 {
	struct kernfs_root___436 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___291 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___291 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___291 *ss;
	struct list_head node;
	struct kernfs_ops___436 *kf_ops;
	int (*open)(struct kernfs_open_file___436 *);
	void (*release)(struct kernfs_open_file___436 *);
	u64 (*read_u64)(struct cgroup_subsys_state___291 *, struct cftype___291 *);
	s64 (*read_s64)(struct cgroup_subsys_state___291 *, struct cftype___291 *);
	int (*seq_show)(struct seq_file___381 *, void *);
	void * (*seq_start)(struct seq_file___381 *, loff_t *);
	void * (*seq_next)(struct seq_file___381 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___381 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___291 *, struct cftype___291 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___291 *, struct cftype___291 *, s64);
	ssize_t (*write)(struct kernfs_open_file___436 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___436 *, struct poll_table_struct___281 *);
};

struct xdp_rxq_info___87 {
	struct net_device___87 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___87 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___87 *dev_rx;
};

struct netlink_callback___89 {
	struct sk_buff___88 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___89 *);
	int (*dump)(struct sk_buff___88 *, struct netlink_callback___89 *);
	int (*done)(struct netlink_callback___89 *);
	void *data;
	struct module___333 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___87 {
	int (*create)(struct sk_buff___88 *, struct net_device___87 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___88 *, unsigned char *);
	int (*cache)(const struct neighbour___67 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___87 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___87 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___87 *, int);
	int poll_owner;
	struct net_device___87 *dev;
	struct sk_buff___88 *gro_list;
	struct sk_buff___88 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___87 {
	struct net_device___87 *dev;
	struct Qdisc___79 *qdisc;
	struct Qdisc___79 *qdisc_sleeping;
	struct kobject___430 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___87 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem___3 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___79 {
	struct sk_buff___88 *head;
	struct sk_buff___88 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___79;

struct Qdisc___79 {
	int (*enqueue)(struct sk_buff___88 *, struct Qdisc___79 *, struct sk_buff___88 **);
	struct sk_buff___88 * (*dequeue)(struct Qdisc___79 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___79 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___87 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___87 gso_skb;
	struct qdisc_skb_head___79 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___79 *next_sched;
	struct sk_buff_head___87 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___87 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___430 kobj;
	struct net_device___87 *dev;
	long: 64;
	struct xdp_rxq_info___87 xdp_rxq;
	union {
		struct xdp_umem___3 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___87)(struct net_device___87 *, struct sk_buff___88 *, struct net_device___87 *);

struct netdev_bpf___87 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___77 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___77 *prog;
			const struct bpf_prog_offload_ops___77 *ops;
		} verifier;
		struct {
			struct bpf_prog___77 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___87 *offmap;
		};
		struct {
			struct xdp_umem___3 *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___87 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___88 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___87 {
	int (*tls_dev_add)(struct net_device___87 *, struct sock___33 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___87 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___87 *, struct sock___33 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___87 {
	int (*ndo_init)(struct net_device___87 *);
	void (*ndo_uninit)(struct net_device___87 *);
	int (*ndo_open)(struct net_device___87 *);
	int (*ndo_stop)(struct net_device___87 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___88 *, struct net_device___87 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___88 *, struct net_device___87 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___87 *, struct sk_buff___88 *, struct net_device___87 *, select_queue_fallback_t___87);
	void (*ndo_change_rx_flags)(struct net_device___87 *, int);
	void (*ndo_set_rx_mode)(struct net_device___87 *);
	int (*ndo_set_mac_address)(struct net_device___87 *, void *);
	int (*ndo_validate_addr)(struct net_device___87 *);
	int (*ndo_do_ioctl)(struct net_device___87 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___87 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___87 *, int);
	int (*ndo_neigh_setup)(struct net_device___87 *, struct neigh_parms___67 *);
	void (*ndo_tx_timeout)(struct net_device___87 *);
	void (*ndo_get_stats64)(struct net_device___87 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___87 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___87 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___87 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___87 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___87 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___87 *);
	int (*ndo_netpoll_setup)(struct net_device___87 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___87 *);
	int (*ndo_set_vf_mac)(struct net_device___87 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___87 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___87 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___87 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___87 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___87 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___87 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___87 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___87 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___87 *, int, struct sk_buff___88 *);
	int (*ndo_set_vf_guid)(struct net_device___87 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___87 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___87 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___87 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___87 *, const struct sk_buff___88 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___87 *, struct net_device___87 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___87 *, struct net_device___87 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___87 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___87 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___87 *, struct neighbour___67 *);
	void (*ndo_neigh_destroy)(struct net_device___87 *, struct neighbour___67 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___87 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___87 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___87 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___88 *, struct netlink_callback___89 *, struct net_device___87 *, struct net_device___87 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___87 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___87 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___88 *, u32, u32, struct net_device___87 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___87 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___87 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___87 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___87 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___87 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___87 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___87 *, struct net_device___87 *);
	void (*ndo_dfwd_del_station)(struct net_device___87 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___87 *);
	int (*ndo_set_tx_maxrate)(struct net_device___87 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___87 *);
	int (*ndo_change_proto_down)(struct net_device___87 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___87 *, struct sk_buff___88 *);
	void (*ndo_set_rx_headroom)(struct net_device___87 *, int);
	int (*ndo_bpf)(struct net_device___87 *, struct netdev_bpf___87 *);
	int (*ndo_xdp_xmit)(struct net_device___87 *, int, struct xdp_frame___87 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___87 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___87 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___67 {
	possible_net_t___89 net;
	struct net_device___87 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___67 *);
	void (*neigh_cleanup)(struct neighbour___67 *);
	struct neigh_table___67 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___67 {
	u32 (*l3mdev_fib_table)(const struct net_device___87 *);
	struct sk_buff___88 * (*l3mdev_l3_rcv)(struct net_device___87 *, struct sk_buff___88 *, u16);
	struct sk_buff___88 * (*l3mdev_l3_out)(struct net_device___87 *, struct sock___33 *, struct sk_buff___88 *, u16);
	struct dst_entry___67 * (*l3mdev_link_scope_lookup)(const struct net_device___87 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct ndisc_ops___38 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___87 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___87 *, struct neighbour___67 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___87 *, u8, struct neighbour___67 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___87 *, struct sk_buff___88 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___98 *, struct net_device___87 *, const struct prefix_info *, struct inet6_dev___38 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___38;

struct inet6_dev___38 {
	struct net_device___87 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___38 *mc_list;
	struct ifmcaddr6___38 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___14 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	u8 rndid[8];
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___67 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
};

struct tcf_proto___79;

struct mini_Qdisc___79 {
	struct tcf_proto___79 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___79 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___87 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___98 *, struct net_device___87 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___87 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___87 *, struct list_head *);
	size_t (*get_size)(const struct net_device___87 *);
	int (*fill_info)(struct sk_buff___88 *, const struct net_device___87 *);
	size_t (*get_xstats_size)(const struct net_device___87 *);
	int (*fill_xstats)(struct sk_buff___88 *, const struct net_device___87 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___87 *, struct net_device___87 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___87 *, const struct net_device___87 *);
	int (*fill_slave_info)(struct sk_buff___88 *, const struct net_device___87 *, const struct net_device___87 *);
	struct net___98 * (*get_link_net)(const struct net_device___87 *);
	size_t (*get_linkxstats_size)(const struct net_device___87 *, int);
	int (*fill_linkxstats)(struct sk_buff___88 *, const struct net_device___87 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___87 {
	struct list_head poll_list;
	struct sk_buff_head___87 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___87 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___79 *output_queue;
	struct Qdisc___79 **output_queue_tailp;
	struct sk_buff___88 *completion_queue;
	struct sk_buff_head___87 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___87 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___87 input_pkt_queue;
	struct napi_struct___87 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bdi_writeback_congested___232 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___232 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___232 {
	struct bio___232 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___234 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___234 bip_inline_vecs[0];
};

struct bio_set___232 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___232 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___175 {
	struct mem_cgroup___175 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___175 {
	struct lruvec___443 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___175 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___175 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct gnet_dump___79 {
	spinlock_t *lock;
	struct sk_buff___88 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___79;

struct Qdisc_ops___79 {
	struct Qdisc_ops___79 *next;
	const struct Qdisc_class_ops___79 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___88 *, struct Qdisc___79 *, struct sk_buff___88 **);
	struct sk_buff___88 * (*dequeue)(struct Qdisc___79 *);
	struct sk_buff___88 * (*peek)(struct Qdisc___79 *);
	int (*init)(struct Qdisc___79 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___79 *);
	void (*destroy)(struct Qdisc___79 *);
	int (*change)(struct Qdisc___79 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___79 *);
	int (*change_tx_queue_len)(struct Qdisc___79 *, unsigned int);
	int (*dump)(struct Qdisc___79 *, struct sk_buff___88 *);
	int (*dump_stats)(struct Qdisc___79 *, struct gnet_dump___79 *);
	void (*ingress_block_set)(struct Qdisc___79 *, u32);
	void (*egress_block_set)(struct Qdisc___79 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___79 *);
	u32 (*egress_block_get)(struct Qdisc___79 *);
	struct module___333 *owner;
};

struct tcf_block___79;

struct Qdisc_class_ops___79 {
	unsigned int flags;
	struct netdev_queue___87 * (*select_queue)(struct Qdisc___79 *, struct tcmsg *);
	int (*graft)(struct Qdisc___79 *, long unsigned int, struct Qdisc___79 *, struct Qdisc___79 **, struct netlink_ext_ack *);
	struct Qdisc___79 * (*leaf)(struct Qdisc___79 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___79 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___79 *, u32);
	int (*change)(struct Qdisc___79 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___79 *, long unsigned int);
	void (*walk)(struct Qdisc___79 *, struct qdisc_walker *);
	struct tcf_block___79 * (*tcf_block)(struct Qdisc___79 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___79 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___79 *, long unsigned int);
	int (*dump)(struct Qdisc___79 *, long unsigned int, struct sk_buff___88 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___79 *, long unsigned int, struct gnet_dump___79 *);
};

struct tcf_chain___79;

struct tcf_block___79 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___98 *net;
	struct Qdisc___79 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___79 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___79;

struct tcf_proto_ops___79;

struct tcf_proto___79 {
	struct tcf_proto___79 *next;
	void *root;
	int (*classify)(struct sk_buff___88 *, const struct tcf_proto___79 *, struct tcf_result___79 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___79 *ops;
	struct tcf_chain___79 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___79 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___79 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___79 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___88 *, const struct tcf_proto___79 *, struct tcf_result___79 *);
	int (*init)(struct tcf_proto___79 *);
	void (*destroy)(struct tcf_proto___79 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___79 *, u32);
	void (*put)(struct tcf_proto___79 *, void *);
	int (*change)(struct net___98 *, struct sk_buff___88 *, struct tcf_proto___79 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___79 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___79 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___79 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___98 *, struct tcf_chain___79 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___98 *, struct tcf_proto___79 *, void *, struct sk_buff___88 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___88 *, struct net___98 *, void *);
	struct module___333 *owner;
	int flags;
};

struct tcf_chain___79 {
	struct mutex filter_chain_lock;
	struct tcf_proto___79 *filter_chain;
	struct list_head list;
	struct tcf_block___79 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___79 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___67 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___77 *prog;
};

struct bpf_redirect_info___77 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___292 *map;
	struct bpf_map___292 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___67;

struct neigh_hash_table___67;

struct neigh_table___67 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___87 *, __u32 *);
	bool (*key_eq)(const struct neighbour___67 *, const void *);
	int (*constructor)(struct neighbour___67 *);
	int (*pconstructor)(struct pneigh_entry___67 *);
	void (*pdestructor)(struct pneigh_entry___67 *);
	void (*proxy_redo)(struct sk_buff___88 *);
	char *id;
	struct neigh_parms___67 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___87 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___67 *nht;
	struct pneigh_entry___67 **phash_buckets;
};

struct neigh_ops___67 {
	int family;
	void (*solicit)(struct neighbour___67 *, struct sk_buff___88 *);
	void (*error_report)(struct neighbour___67 *, struct sk_buff___88 *);
	int (*output)(struct neighbour___67 *, struct sk_buff___88 *);
	int (*connected_output)(struct neighbour___67 *, struct sk_buff___88 *);
};

struct pneigh_entry___67 {
	struct pneigh_entry___67 *next;
	possible_net_t___89 net;
	struct net_device___87 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___67 {
	struct neighbour___67 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___67 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___67 *ctarget;
	struct net___98 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___67 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___67 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___50;

struct timewait_sock_ops___46;

struct proto___67 {
	void (*close)(struct sock___33 *, long int);
	int (*pre_connect)(struct sock___33 *, struct sockaddr *, int);
	int (*connect)(struct sock___33 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___33 *, int);
	struct sock___33 * (*accept)(struct sock___33 *, int, int *, bool);
	int (*ioctl)(struct sock___33 *, int, long unsigned int);
	int (*init)(struct sock___33 *);
	void (*destroy)(struct sock___33 *);
	void (*shutdown)(struct sock___33 *, int);
	int (*setsockopt)(struct sock___33 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___33 *, int, int, char *, int *);
	void (*keepalive)(struct sock___33 *, int);
	int (*sendmsg)(struct sock___33 *, struct msghdr___70 *, size_t);
	int (*recvmsg)(struct sock___33 *, struct msghdr___70 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___33 *, struct page___443 *, int, size_t, int);
	int (*bind)(struct sock___33 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___33 *, struct sk_buff___88 *);
	void (*release_cb)(struct sock___33 *);
	int (*hash)(struct sock___33 *);
	void (*unhash)(struct sock___33 *);
	void (*rehash)(struct sock___33 *);
	int (*get_port)(struct sock___33 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___33 *);
	bool (*stream_memory_read)(const struct sock___33 *);
	void (*enter_memory_pressure)(struct sock___33 *);
	void (*leave_memory_pressure)(struct sock___33 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___50 *rsk_prot;
	struct timewait_sock_ops___46 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___333 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___33 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct sock_reuseport___5 {
	struct callback_head rcu;
	u16 max_socks;
	u16 num_socks;
	unsigned int reuseport_id;
	bool bind_inany;
	struct bpf_prog___77 *prog;
	struct sock___33 *socks[0];
};

struct request_sock___51;

struct request_sock_ops___50 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___33 *, struct request_sock___51 *);
	void (*send_ack)(const struct sock___33 *, struct sk_buff___88 *, struct request_sock___51 *);
	void (*send_reset)(const struct sock___33 *, struct sk_buff___88 *);
	void (*destructor)(struct request_sock___51 *);
	void (*syn_ack_timeout)(const struct request_sock___51 *);
};

struct timewait_sock_ops___46 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___33 *, struct sock___33 *, void *);
	void (*twsk_destructor)(struct sock___33 *);
};

struct request_sock___51 {
	struct sock_common___67 __req_common;
	struct request_sock___51 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___50 *rsk_ops;
	struct sock___33 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct fastopen_queue___6 {
	struct request_sock___51 *rskq_rst_head;
	struct request_sock___51 *rskq_rst_tail;
	spinlock_t lock;
	int qlen;
	int max_qlen;
	struct tcp_fastopen_context___13 *ctx;
};

struct request_sock_queue___6 {
	spinlock_t rskq_lock;
	u8 rskq_defer_accept;
	u32 synflood_warned;
	atomic_t qlen;
	atomic_t young;
	struct request_sock___51 *rskq_accept_head;
	struct request_sock___51 *rskq_accept_tail;
	struct fastopen_queue___6 fastopenq;
};

struct inet_cork___10 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___67 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
	__u16 gso_size;
	u64 transmit_time;
};

struct inet_cork_full___10 {
	struct inet_cork___10 base;
	struct flowi fl;
};

struct ipv6_pinfo___10;

struct inet_sock___10 {
	struct sock___33 sk;
	struct ipv6_pinfo___10 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	__be16 inet_sport;
	__u16 inet_id;
	struct ip_options_rcu *inet_opt;
	int rx_dst_ifindex;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 bind_address_no_port: 1;
	__u8 defer_connect: 1;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___10 cork;
};

struct ipv6_fl_socklist___9;

struct ipv6_pinfo___10 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
			__u16 recvfragsize: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 repflow: 1;
	__u16 pmtudisc: 3;
	__u16 padding: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u16 autoflowlabel: 1;
	__u16 autoflowlabel_set: 1;
	__u8 min_hopcount;
	__u8 tclass;
	__be32 rcv_flowinfo;
	__u32 dst_cookie;
	__u32 rx_dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___9 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___88 *pktoptions;
	struct sk_buff___88 *rxpmtu;
	struct inet6_cork cork;
};

struct inet_connection_sock_af_ops___6 {
	int (*queue_xmit)(struct sock___33 *, struct sk_buff___88 *, struct flowi *);
	void (*send_check)(struct sock___33 *, struct sk_buff___88 *);
	int (*rebuild_header)(struct sock___33 *);
	void (*sk_rx_dst_set)(struct sock___33 *, const struct sk_buff___88 *);
	int (*conn_request)(struct sock___33 *, struct sk_buff___88 *);
	struct sock___33 * (*syn_recv_sock)(const struct sock___33 *, struct sk_buff___88 *, struct request_sock___51 *, struct dst_entry___67 *, struct request_sock___51 *, bool *);
	u16 net_header_len;
	u16 net_frag_header_len;
	u16 sockaddr_len;
	int (*setsockopt)(struct sock___33 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___33 *, int, int, char *, int *);
	void (*addr2sockaddr)(struct sock___33 *, struct sockaddr *);
	void (*mtu_reduced)(struct sock___33 *);
};

struct inet_bind_bucket___5;

struct inet_connection_sock___6 {
	struct inet_sock___10 icsk_inet;
	struct request_sock_queue___6 icsk_accept_queue;
	struct inet_bind_bucket___5 *icsk_bind_hash;
	long unsigned int icsk_timeout;
	struct timer_list icsk_retransmit_timer;
	struct timer_list icsk_delack_timer;
	__u32 icsk_rto;
	__u32 icsk_pmtu_cookie;
	const struct tcp_congestion_ops___13 *icsk_ca_ops;
	const struct inet_connection_sock_af_ops___6 *icsk_af_ops;
	const struct tcp_ulp_ops___2 *icsk_ulp_ops;
	void *icsk_ulp_data;
	void (*icsk_clean_acked)(struct sock___33 *, u32);
	struct hlist_node icsk_listen_portaddr_node;
	unsigned int (*icsk_sync_mss)(struct sock___33 *, u32);
	__u8 icsk_ca_state: 6;
	__u8 icsk_ca_setsockopt: 1;
	__u8 icsk_ca_dst_locked: 1;
	__u8 icsk_retransmits;
	__u8 icsk_pending;
	__u8 icsk_backoff;
	__u8 icsk_syn_retries;
	__u8 icsk_probes_out;
	__u16 icsk_ext_hdr_len;
	struct {
		__u8 pending;
		__u8 quick;
		__u8 pingpong;
		__u8 blocked;
		__u32 ato;
		long unsigned int timeout;
		__u32 lrcvtime;
		__u16 last_seg_size;
		__u16 rcv_mss;
	} icsk_ack;
	struct {
		int enabled;
		int search_high;
		int search_low;
		int probe_size;
		u32 probe_timestamp;
	} icsk_mtup;
	u32 icsk_user_timeout;
	u64 icsk_ca_priv[11];
};

struct inet_bind_bucket___5 {
	possible_net_t___89 ib_net;
	short unsigned int port;
	signed char fastreuse;
	signed char fastreuseport;
	kuid_t fastuid;
	struct in6_addr fast_v6_rcv_saddr;
	__be32 fast_rcv_saddr;
	short unsigned int fast_sk_family;
	bool fast_ipv6_only;
	struct hlist_node node;
	struct hlist_head owners;
};

struct inet_timewait_sock {
	struct sock_common___67 __tw_common;
	__u32 tw_mark;
	volatile unsigned char tw_substate;
	unsigned char tw_rcv_wscale;
	__be16 tw_sport;
	unsigned int tw_kill: 1;
	unsigned int tw_transparent: 1;
	unsigned int tw_flowlabel: 20;
	unsigned int tw_pad: 2;
	unsigned int tw_tos: 8;
	struct timer_list tw_timer;
	struct inet_bind_bucket___5 *tw_tb;
};

struct ip6_flowlabel___9;

struct ipv6_fl_socklist___9 {
	struct ipv6_fl_socklist___9 *next;
	struct ip6_flowlabel___9 *fl;
	struct callback_head rcu;
};

struct ifmcaddr6___38 {
	struct in6_addr mca_addr;
	struct inet6_dev___38 *idev;
	struct ifmcaddr6___38 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ip6_ra_chain___38 {
	struct ip6_ra_chain___38 *next;
	struct sock___33 *sk;
	int sel;
	void (*destructor)(struct sock___33 *);
};

struct ip6_flowlabel___9 {
	struct ip6_flowlabel___9 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___245 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___98 *fl_net;
};

struct ipv6_stub___10 {
	int (*ipv6_sock_mc_join)(struct sock___33 *, int, const struct in6_addr *);
	int (*ipv6_sock_mc_drop)(struct sock___33 *, int, const struct in6_addr *);
	int (*ipv6_dst_lookup)(struct net___98 *, struct sock___33 *, struct dst_entry___67 **, struct flowi6 *);
	struct fib6_table * (*fib6_get_table)(struct net___98 *, u32);
	struct fib6_info * (*fib6_lookup)(struct net___98 *, int, struct flowi6 *, int);
	struct fib6_info * (*fib6_table_lookup)(struct net___98 *, struct fib6_table *, int, struct flowi6 *, int);
	struct fib6_info * (*fib6_multipath_select)(const struct net___98 *, struct fib6_info *, struct flowi6 *, int, const struct sk_buff___88 *, int);
	u32 (*ip6_mtu_from_fib6)(struct fib6_info *, struct in6_addr *, struct in6_addr *);
	void (*udpv6_encap_enable)();
	void (*ndisc_send_na)(struct net_device___87 *, const struct in6_addr *, const struct in6_addr *, bool, bool, bool, bool);
	struct neigh_table___67 *nd_tbl;
};

struct ipv6_bpf_stub___10 {
	int (*inet6_bind)(struct sock___33 *, struct sockaddr *, int, bool, bool);
	struct sock___33 * (*udp6_lib_lookup)(struct net___98 *, const struct in6_addr *, __be16, const struct in6_addr *, __be16, int, int, struct udp_table *, struct sk_buff___88 *);
};

struct module___369;

struct file___443;

struct kiocb___443;

struct iov_iter___210;

struct poll_table_struct___282;

struct vm_area_struct___444;

struct inode___443;

struct file_lock___443;

struct page___444;

struct pipe_inode_info___124;

struct seq_file___382;

struct file_operations___443 {
	struct module___369 *owner;
	loff_t (*llseek)(struct file___443 *, loff_t, int);
	ssize_t (*read)(struct file___443 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___443 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___443 *, struct iov_iter___210 *);
	ssize_t (*write_iter)(struct kiocb___443 *, struct iov_iter___210 *);
	int (*iopoll)(struct kiocb___443 *, bool);
	int (*iterate)(struct file___443 *, struct dir_context *);
	int (*iterate_shared)(struct file___443 *, struct dir_context *);
	__poll_t (*poll)(struct file___443 *, struct poll_table_struct___282 *);
	long int (*unlocked_ioctl)(struct file___443 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___443 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___443 *, struct vm_area_struct___444 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___443 *, struct file___443 *);
	int (*flush)(struct file___443 *, fl_owner_t);
	int (*release)(struct inode___443 *, struct file___443 *);
	int (*fsync)(struct file___443 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___443 *, int);
	int (*lock)(struct file___443 *, int, struct file_lock___443 *);
	ssize_t (*sendpage)(struct file___443 *, struct page___444 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___443 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___443 *, int, struct file_lock___443 *);
	ssize_t (*splice_write)(struct pipe_inode_info___124 *, struct file___443 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___443 *, loff_t *, struct pipe_inode_info___124 *, size_t, unsigned int);
	int (*setlease)(struct file___443 *, long int, struct file_lock___443 **, void **);
	long int (*fallocate)(struct file___443 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___382 *, struct file___443 *);
	ssize_t (*copy_file_range)(struct file___443 *, loff_t, struct file___443 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___443 *, loff_t, struct file___443 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___443 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___444 {
	u64 seqnum;
	struct vm_area_struct___444 *vmas[4];
};

struct page_frag___444 {
	struct page___444 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___444;

struct mem_cgroup___176;

struct pid___246;

struct cred___411;

struct nsproxy___338;

struct signal_struct___318;

struct bio_list___233;

struct backing_dev_info___233;

struct css_set___292;

struct vm_struct___347;

struct task_struct___445 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___445 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___444 *mm;
	struct mm_struct___444 *active_mm;
	struct vmacache___444 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___445 *real_parent;
	struct task_struct___445 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___445 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___176 *active_memcg;
	long int rh_reserved2;
	struct pid___246 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___246 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___246 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___411 *ptracer_cred;
	const struct cred___411 *real_cred;
	const struct cred___411 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___338 *nsproxy;
	struct signal_struct___318 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___445 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___233 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___233 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___292 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___124 *splice_pipe;
	struct page_frag___444 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___176 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___445 *oom_reaper_list;
	struct vm_struct___347 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___156 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rw_semaphore___445 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___445 *owner;
};

struct key___411;

struct ucounts___308;

struct user_namespace___308 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___308 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___29 ns;
	long unsigned int flags;
	struct key___411 *persistent_keyring_register;
	struct rw_semaphore___445 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___308 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___444 *pgtable_t___444;

struct address_space___443;

struct dev_pagemap___431;

struct page___444 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___443 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___444 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___444 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___444 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___431 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___176 *mem_cgroup;
};

struct pglist_data___444;

struct lruvec___444 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___444 *pgdat;
};

struct zone___444 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___444 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___444 {
	struct zone___444 *zone;
	int zone_idx;
};

struct zonelist___444 {
	struct zoneref___444 _zonerefs[25];
};

struct pglist_data___444 {
	struct zone___444 node_zones[3];
	struct zonelist___444 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___445 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___445 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___444 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___445 {
	void *stack;
	struct task_struct___445 *task;
	long int status;
};

struct blocking_notifier_head___444 {
	struct rw_semaphore___445 rwsem;
	struct notifier_block *head;
};

struct dentry___443;

struct path___444 {
	struct vfsmount *mnt;
	struct dentry___443 *dentry;
};

struct fown_struct___246 {
	rwlock_t lock;
	struct pid___246 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___443 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___444 f_path;
	struct inode___443 *f_inode;
	const struct file_operations___443 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___246 f_owner;
	const struct cred___411 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___443 *f_mapping;
	errseq_t f_wb_err;
};

struct user_struct___411;

struct cred___411 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___411 *session_keyring;
	struct key___411 *process_keyring;
	struct key___411 *thread_keyring;
	struct key___411 *request_key_auth;
	void *security;
	struct user_struct___411 *user;
	struct user_namespace___308 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___437;

struct kernfs_elem_dir___437 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___437 *root;
};

struct kernfs_node___438;

struct kernfs_syscall_ops___437;

struct kernfs_root___437 {
	struct kernfs_node___438 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___437 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___437 {
	struct kernfs_node___438 *target_kn;
};

struct kernfs_ops___437;

struct kernfs_elem_attr___437 {
	const struct kernfs_ops___437 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___438 *notify_next;
};

struct kernfs_node___438 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___438 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___437 dir;
		struct kernfs_elem_symlink___437 symlink;
		struct kernfs_elem_attr___437 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___437;

struct kernfs_ops___437 {
	int (*open)(struct kernfs_open_file___437 *);
	void (*release)(struct kernfs_open_file___437 *);
	int (*seq_show)(struct seq_file___382 *, void *);
	void * (*seq_start)(struct seq_file___382 *, loff_t *);
	void * (*seq_next)(struct seq_file___382 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___382 *, void *);
	ssize_t (*read)(struct kernfs_open_file___437 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___437 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___437 *, struct vm_area_struct___444 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___437 *, struct poll_table_struct___282 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___437 {
	int (*remount_fs)(struct kernfs_root___437 *, int *, char *);
	int (*show_options)(struct seq_file___382 *, struct kernfs_root___437 *);
	int (*mkdir)(struct kernfs_node___438 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___438 *);
	int (*rename)(struct kernfs_node___438 *, struct kernfs_node___438 *, const char *);
	int (*show_path)(struct seq_file___382 *, struct kernfs_node___438 *, struct kernfs_root___437 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___382;

struct seq_file___382 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___382 *op;
	int poll_event;
	const struct file___443 *file;
	void *private;
};

struct vm_operations_struct___431;

struct kernfs_open_file___437 {
	struct kernfs_node___438 *kn;
	struct file___443 *file;
	struct seq_file___382 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___431 *vm_ops;
};

struct vm_fault___431;

struct vm_operations_struct___431 {
	void (*open)(struct vm_area_struct___444 *);
	void (*close)(struct vm_area_struct___444 *);
	int (*split)(struct vm_area_struct___444 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___444 *);
	vm_fault_t (*fault)(struct vm_fault___431 *);
	vm_fault_t (*huge_fault)(struct vm_fault___431 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___431 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___444 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___431 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___431 *);
	int (*access)(struct vm_area_struct___444 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___444 *);
	int (*set_policy)(struct vm_area_struct___444 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___444 *, long unsigned int);
	struct page___444 * (*find_special_page)(struct vm_area_struct___444 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___292)(struct file___443 *, wait_queue_head_t *, struct poll_table_struct___282 *);

struct poll_table_struct___282 {
	poll_queue_proc___292 _qproc;
	__poll_t _key;
};

struct vm_area_struct___444 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___444 *vm_next;
	struct vm_area_struct___444 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___444 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___431 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___443 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sock___68;

struct kobj_ns_type_operations___68 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___68 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct net___99;

typedef struct {
	struct net___99 *net;
} possible_net_t___90;

struct proto___68;

struct sock_common___68 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___68 *skc_prot;
	possible_net_t___90 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___68 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___89;

struct sk_buff_head___88 {
	struct sk_buff___89 *next;
	struct sk_buff___89 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___68;

struct socket_wq___69;

struct xfrm_policy___11;

struct dst_entry___68;

struct socket___70;

struct net_device___88;

struct sock_reuseport___6;

struct sock___68 {
	struct sock_common___68 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___88 sk_error_queue;
	struct sk_buff_head___88 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___89 *head;
		struct sk_buff___89 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___68 *sk_filter;
	union {
		struct socket_wq___69 *sk_wq;
		struct socket_wq___69 *sk_wq_raw;
	};
	struct xfrm_policy___11 *sk_policy[2];
	struct dst_entry___68 *sk_rx_dst;
	struct dst_entry___68 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___89 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___88 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___444 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___68 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___246 *sk_peer_pid;
	const struct cred___411 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___70 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___176 *sk_memcg;
	void (*sk_state_change)(struct sock___68 *);
	void (*sk_data_ready)(struct sock___68 *);
	void (*sk_write_space)(struct sock___68 *);
	void (*sk_error_report)(struct sock___68 *);
	int (*sk_backlog_rcv)(struct sock___68 *, struct sk_buff___89 *);
	struct sk_buff___89 * (*sk_validate_xmit_skb)(struct sock___68 *, struct net_device___88 *, struct sk_buff___89 *);
	void (*sk_destruct)(struct sock___68 *);
	struct sock_reuseport___6 *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kobject___431;

struct bin_attribute___407;

struct attribute_group___408 {
	const char *name;
	umode_t (*is_visible)(struct kobject___431 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___431 *, struct bin_attribute___407 *, int);
	struct attribute **attrs;
	struct bin_attribute___407 **bin_attrs;
};

struct kset___430;

struct kobj_type___430;

struct kobject___431 {
	const char *name;
	struct list_head entry;
	struct kobject___431 *parent;
	struct kset___430 *kset;
	struct kobj_type___430 *ktype;
	struct kernfs_node___438 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___407 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___443 *, struct kobject___431 *, struct bin_attribute___407 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___443 *, struct kobject___431 *, struct bin_attribute___407 *, char *, loff_t, size_t);
	int (*mmap)(struct file___443 *, struct kobject___431 *, struct bin_attribute___407 *, struct vm_area_struct___444 *);
};

struct sysfs_ops___430 {
	ssize_t (*show)(struct kobject___431 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___431 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___430;

struct kset___430 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___431 kobj;
	const struct kset_uevent_ops___430 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___430 {
	void (*release)(struct kobject___431 *);
	const struct sysfs_ops___430 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___68 * (*child_ns_type)(struct kobject___431 *);
	const void * (*namespace)(struct kobject___431 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___430 {
	int (* const filter)(struct kset___430 *, struct kobject___431 *);
	const char * (* const name)(struct kset___430 *, struct kobject___431 *);
	int (* const uevent)(struct kset___430 *, struct kobject___431 *, struct kobj_uevent_env *);
};

struct kobj_attribute___421 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___431 *, struct kobj_attribute___421 *, char *);
	ssize_t (*store)(struct kobject___431 *, struct kobj_attribute___421 *, const char *, size_t);
};

struct kernel_param___369;

struct kernel_param_ops___369 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___369 *);
	int (*get)(char *, const struct kernel_param___369 *);
	void (*free)(void *);
};

struct kparam_array___369;

struct kernel_param___369 {
	const char *name;
	struct module___369 *mod;
	const struct kernel_param_ops___369 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___369 *arr;
	};
};

struct kparam_array___369 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___369 *ops;
	void *elem;
};

struct module_kobject___369 {
	struct kobject___431 kobj;
	struct module___369 *mod;
	struct kobject___431 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___369 {
	struct module___369 *mod;
	struct latch_tree_node node;
};

struct module_layout___369 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___369 mtn;
};

struct module_attribute___369;

struct module___369 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___369 mkobj;
	struct module_attribute___369 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___431 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___369 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___369 core_layout;
	struct module_layout___369 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___369 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___369 *, struct module_kobject___369 *, char *);
	ssize_t (*store)(struct module_attribute___369 *, struct module_kobject___369 *, const char *, size_t);
	void (*setup)(struct module___369 *, const char *);
	int (*test)(struct module___369 *);
	void (*free)(struct module___369 *);
};

struct dentry_operations___443;

struct super_block___443;

struct dentry___443 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___443 *d_parent;
	struct qstr d_name;
	struct inode___443 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___443 *d_op;
	struct super_block___443 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___443;

struct address_space___443 {
	struct inode___443 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___445 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___443 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___443;

struct bdi_writeback___233;

struct block_device___443;

struct inode___443 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___443 *i_op;
	struct super_block___443 *i_sb;
	struct address_space___443 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___445 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___233 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___443 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___443 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___124 *i_pipe;
		struct block_device___443 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___443 {
	int (*d_revalidate)(struct dentry___443 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___443 *, unsigned int);
	int (*d_hash)(const struct dentry___443 *, struct qstr *);
	int (*d_compare)(const struct dentry___443 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___443 *);
	int (*d_init)(struct dentry___443 *);
	void (*d_release)(struct dentry___443 *);
	void (*d_prune)(struct dentry___443 *);
	void (*d_iput)(struct dentry___443 *, struct inode___443 *);
	char * (*d_dname)(struct dentry___443 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___444 *);
	int (*d_manage)(const struct path___444 *, bool);
	struct dentry___443 * (*d_real)(struct dentry___443 *, const struct inode___443 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___443;

struct mem_dqinfo___443 {
	struct quota_format_type___443 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___443;

struct quota_info___443 {
	unsigned int flags;
	struct rw_semaphore___445 dqio_sem;
	struct inode___443 *files[3];
	struct mem_dqinfo___443 info[3];
	const struct quota_format_ops___443 *ops[3];
};

struct rcuwait___443 {
	struct task_struct___445 *task;
};

struct percpu_rw_semaphore___443 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___445 rw_sem;
	struct rcuwait___443 writer;
	int readers_block;
};

struct sb_writers___443 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___443 rw_sem[3];
};

struct shrink_control___176;

struct shrinker___176 {
	long unsigned int (*count_objects)(struct shrinker___176 *, struct shrink_control___176 *);
	long unsigned int (*scan_objects)(struct shrinker___176 *, struct shrink_control___176 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___443;

struct super_operations___443;

struct dquot_operations___443;

struct quotactl_ops___443;

struct super_block___443 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___443 *s_type;
	const struct super_operations___443 *s_op;
	const struct dquot_operations___443 *dq_op;
	const struct quotactl_ops___443 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___443 *s_root;
	struct rw_semaphore___445 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___443 *s_bdev;
	struct backing_dev_info___233 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___443 s_dquot;
	struct sb_writers___443 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___443 *s_d_op;
	int cleancache_poolid;
	struct shrinker___176 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___308 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___176 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___176 *memcg;
};

struct cgroup___292;

struct cgroup_subsys___292;

struct cgroup_subsys_state___292 {
	struct cgroup___292 *cgroup;
	struct cgroup_subsys___292 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___292 *parent;
};

struct cgroup_file___292 {
	struct kernfs_node___438 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___176;

struct mem_cgroup___176 {
	struct cgroup_subsys_state___292 css;
	struct mem_cgroup_id___13 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___292 events_file;
	struct cgroup_file___292 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___445 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___176 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___246;

struct upid___246 {
	int nr;
	struct pid_namespace___246 *ns;
};

struct pid_namespace___246 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___445 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___246 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___443 *proc_self;
	struct dentry___443 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___308 *user_ns;
	struct ucounts___308 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___29 ns;
};

struct pid___246 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___246 numbers[1];
};

struct core_state___444;

struct mm_struct___444 {
	struct {
		struct vm_area_struct___444 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___443 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___445 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___444 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___445 *owner;
		struct user_namespace___308 *user_ns;
		struct file___443 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___444 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

typedef int (*dev_page_fault_t___431)(struct vm_area_struct___444 *, long unsigned int, const struct page___444 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___431)(struct page___444 *, void *);

struct device___411;

struct dev_pagemap___431 {
	dev_page_fault_t___431 page_fault;
	dev_page_free_t___431 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___411 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___444 {
	struct task_struct___445 *task;
	struct core_thread___444 *next;
};

struct core_state___444 {
	atomic_t nr_threads;
	struct core_thread___444 dumper;
	struct completion startup;
};

struct vm_fault___431 {
	struct vm_area_struct___444 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___444 *cow_page;
	struct mem_cgroup___176 *memcg;
	struct page___444 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___444 prealloc_pte;
};

struct user_struct___411 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___411 *uid_keyring;
	struct key___411 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cgroup_namespace___292;

struct nsproxy___338 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___246 *pid_ns_for_children;
	struct net___99 *net_ns;
	struct cgroup_namespace___292 *cgroup_ns;
};

struct signal_struct___318 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___445 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___445 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___246 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___246 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___444 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___246 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___233;

struct bio_list___233 {
	struct bio___233 *head;
	struct bio___233 *tail;
};

struct bdi_writeback_congested___233;

struct bdi_writeback___233 {
	struct backing_dev_info___233 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___233 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___292 *memcg_css;
	struct cgroup_subsys_state___292 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___233 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___233 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___411 *dev;
	struct device___411 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___443 *debug_dir;
	struct dentry___443 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___292 {
	struct cgroup_subsys_state___292 *subsys[13];
	refcount_t refcount;
	struct css_set___292 *dom_cset;
	struct cgroup___292 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___292 *mg_src_cgrp;
	struct cgroup___292 *mg_dst_cgrp;
	struct css_set___292 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___443;

struct pipe_buffer___124;

struct pipe_inode_info___124 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___444 *tmp_page;
	struct fasync_struct___443 *fasync_readers;
	struct fasync_struct___443 *fasync_writers;
	struct pipe_buffer___124 *bufs;
	struct user_struct___411 *user;
};

struct vm_struct___347 {
	struct vm_struct___347 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___444 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___330 {
	struct task_struct___445 task;
	long unsigned int stack[8192];
};

struct kiocb___443 {
	struct file___443 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___443 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___443 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___443 *ia_file;
};

struct dquot___443 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___443 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___443 {
	int qf_fmt_id;
	const struct quota_format_ops___443 *qf_ops;
	struct module___369 *qf_owner;
	struct quota_format_type___443 *qf_next;
};

struct quota_format_ops___443 {
	int (*check_quota_file)(struct super_block___443 *, int);
	int (*read_file_info)(struct super_block___443 *, int);
	int (*write_file_info)(struct super_block___443 *, int);
	int (*free_file_info)(struct super_block___443 *, int);
	int (*read_dqblk)(struct dquot___443 *);
	int (*commit_dqblk)(struct dquot___443 *);
	int (*release_dqblk)(struct dquot___443 *);
	int (*get_next_id)(struct super_block___443 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___443 {
	int (*write_dquot)(struct dquot___443 *);
	struct dquot___443 * (*alloc_dquot)(struct super_block___443 *, int);
	void (*destroy_dquot)(struct dquot___443 *);
	int (*acquire_dquot)(struct dquot___443 *);
	int (*release_dquot)(struct dquot___443 *);
	int (*mark_dirty)(struct dquot___443 *);
	int (*write_info)(struct super_block___443 *, int);
	qsize_t * (*get_reserved_space)(struct inode___443 *);
	int (*get_projid)(struct inode___443 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___443 *, qsize_t *);
	int (*get_next_id)(struct super_block___443 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___443 {
	int (*quota_on)(struct super_block___443 *, int, int, const struct path___444 *);
	int (*quota_off)(struct super_block___443 *, int);
	int (*quota_enable)(struct super_block___443 *, unsigned int);
	int (*quota_disable)(struct super_block___443 *, unsigned int);
	int (*quota_sync)(struct super_block___443 *, int);
	int (*set_info)(struct super_block___443 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___443 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___443 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___443 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___443 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___443 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___196;

struct address_space_operations___443 {
	int (*writepage)(struct page___444 *, struct writeback_control___196 *);
	int (*readpage)(struct file___443 *, struct page___444 *);
	int (*writepages)(struct address_space___443 *, struct writeback_control___196 *);
	int (*set_page_dirty)(struct page___444 *);
	int (*readpages)(struct file___443 *, struct address_space___443 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___443 *, struct address_space___443 *, loff_t, unsigned int, unsigned int, struct page___444 **, void **);
	int (*write_end)(struct file___443 *, struct address_space___443 *, loff_t, unsigned int, unsigned int, struct page___444 *, void *);
	sector_t (*bmap)(struct address_space___443 *, sector_t);
	void (*invalidatepage)(struct page___444 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___444 *, gfp_t);
	void (*freepage)(struct page___444 *);
	ssize_t (*direct_IO)(struct kiocb___443 *, struct iov_iter___210 *);
	int (*migratepage)(struct address_space___443 *, struct page___444 *, struct page___444 *, enum migrate_mode);
	bool (*isolate_page)(struct page___444 *, isolate_mode_t);
	void (*putback_page)(struct page___444 *);
	int (*launder_page)(struct page___444 *);
	int (*is_partially_uptodate)(struct page___444 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___444 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___443 *, struct page___444 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___443 *, sector_t *);
	void (*swap_deactivate)(struct file___443 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___196 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___233 *wb;
	struct inode___443 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___235;

struct iov_iter___210 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___235 *bvec;
		struct pipe_inode_info___124 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___443 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___443 *bd_inode;
	struct super_block___443 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___443 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___233 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___443 {
	struct dentry___443 * (*lookup)(struct inode___443 *, struct dentry___443 *, unsigned int);
	const char * (*get_link)(struct dentry___443 *, struct inode___443 *, struct delayed_call *);
	int (*permission)(struct inode___443 *, int);
	struct posix_acl * (*get_acl)(struct inode___443 *, int);
	int (*readlink)(struct dentry___443 *, char *, int);
	int (*create)(struct inode___443 *, struct dentry___443 *, umode_t, bool);
	int (*link)(struct dentry___443 *, struct inode___443 *, struct dentry___443 *);
	int (*unlink)(struct inode___443 *, struct dentry___443 *);
	int (*symlink)(struct inode___443 *, struct dentry___443 *, const char *);
	int (*mkdir)(struct inode___443 *, struct dentry___443 *, umode_t);
	int (*rmdir)(struct inode___443 *, struct dentry___443 *);
	int (*mknod)(struct inode___443 *, struct dentry___443 *, umode_t, dev_t);
	int (*rename)(struct inode___443 *, struct dentry___443 *, struct inode___443 *, struct dentry___443 *, unsigned int);
	int (*setattr)(struct dentry___443 *, struct iattr___443 *);
	int (*getattr)(const struct path___444 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___443 *, char *, size_t);
	int (*fiemap)(struct inode___443 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___443 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___443 *, struct dentry___443 *, struct file___443 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___443 *, struct dentry___443 *, umode_t);
	int (*set_acl)(struct inode___443 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___443 {
	void (*fl_copy_lock)(struct file_lock___443 *, struct file_lock___443 *);
	void (*fl_release_private)(struct file_lock___443 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___443;

struct file_lock___443 {
	struct file_lock___443 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___443 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___443 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___443 *fl_ops;
	const struct lock_manager_operations___443 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___443 {
	int (*lm_compare_owner)(struct file_lock___443 *, struct file_lock___443 *);
	long unsigned int (*lm_owner_key)(struct file_lock___443 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___443 *);
	int (*lm_grant)(struct file_lock___443 *, int);
	bool (*lm_break)(struct file_lock___443 *);
	int (*lm_change)(struct file_lock___443 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___443 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___443 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___443 *fa_next;
	struct file___443 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___443 {
	const char *name;
	int fs_flags;
	struct dentry___443 * (*mount)(struct file_system_type___443 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___443 *);
	struct module___369 *owner;
	struct file_system_type___443 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___443 {
	struct inode___443 * (*alloc_inode)(struct super_block___443 *);
	void (*destroy_inode)(struct inode___443 *);
	void (*dirty_inode)(struct inode___443 *, int);
	int (*write_inode)(struct inode___443 *, struct writeback_control___196 *);
	int (*drop_inode)(struct inode___443 *);
	void (*evict_inode)(struct inode___443 *);
	void (*put_super)(struct super_block___443 *);
	int (*sync_fs)(struct super_block___443 *, int);
	int (*freeze_super)(struct super_block___443 *);
	int (*freeze_fs)(struct super_block___443 *);
	int (*thaw_super)(struct super_block___443 *);
	int (*unfreeze_fs)(struct super_block___443 *);
	int (*statfs)(struct dentry___443 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___443 *, int *, char *);
	void (*umount_begin)(struct super_block___443 *);
	int (*show_options)(struct seq_file___382 *, struct dentry___443 *);
	int (*show_devname)(struct seq_file___382 *, struct dentry___443 *);
	int (*show_path)(struct seq_file___382 *, struct dentry___443 *);
	int (*show_stats)(struct seq_file___382 *, struct dentry___443 *);
	ssize_t (*quota_read)(struct super_block___443 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___443 *, int, const char *, size_t, loff_t);
	struct dquot___443 ** (*get_dquots)(struct inode___443 *);
	int (*bdev_try_to_free_page)(struct super_block___443 *, struct page___444 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___443 *, struct shrink_control___176 *);
	long int (*free_cached_objects)(struct super_block___443 *, struct shrink_control___176 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___233(struct bio___233 *);

struct bio_vec___235 {
	struct page___444 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___233;

struct bio_set___233;

struct bio___233 {
	struct bio___233 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___233 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___233 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___235 *bi_io_vec;
	struct bio_set___233 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___235 bi_inline_vecs[0];
};

struct crypto_async_request___33;

typedef void (*crypto_completion_t___33)(struct crypto_async_request___33 *, int);

struct crypto_tfm___33;

struct crypto_async_request___33 {
	struct list_head list;
	crypto_completion_t___33 complete;
	void *data;
	struct crypto_tfm___33 *tfm;
	u32 flags;
};

struct crypto_ablkcipher___33;

struct ablkcipher_request___33;

struct ablkcipher_tfm___33 {
	int (*setkey)(struct crypto_ablkcipher___33 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___33 *);
	int (*decrypt)(struct ablkcipher_request___33 *);
	struct crypto_ablkcipher___33 *base;
	unsigned int ivsize;
	unsigned int reqsize;
};

struct blkcipher_desc___33;

struct blkcipher_tfm___33 {
	void *iv;
	int (*setkey)(struct crypto_tfm___33 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___33 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___33 *, struct scatterlist *, struct scatterlist *, unsigned int);
};

struct cipher_tfm___33 {
	int (*cit_setkey)(struct crypto_tfm___33 *, const u8 *, unsigned int);
	void (*cit_encrypt_one)(struct crypto_tfm___33 *, u8 *, const u8 *);
	void (*cit_decrypt_one)(struct crypto_tfm___33 *, u8 *, const u8 *);
};

struct compress_tfm___33 {
	int (*cot_compress)(struct crypto_tfm___33 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*cot_decompress)(struct crypto_tfm___33 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___33;

struct crypto_tfm___33 {
	u32 crt_flags;
	union {
		struct ablkcipher_tfm___33 ablkcipher;
		struct blkcipher_tfm___33 blkcipher;
		struct cipher_tfm___33 cipher;
		struct compress_tfm___33 compress;
	} crt_u;
	void (*exit)(struct crypto_tfm___33 *);
	struct crypto_alg___33 *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct ablkcipher_request___33 {
	struct crypto_async_request___33 base;
	unsigned int nbytes;
	void *info;
	struct scatterlist *src;
	struct scatterlist *dst;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_blkcipher___33;

struct blkcipher_desc___33 {
	struct crypto_blkcipher___33 *tfm;
	void *info;
	u32 flags;
};

struct crypto_blkcipher___33 {
	struct crypto_tfm___33 base;
};

struct ablkcipher_alg___33 {
	int (*setkey)(struct crypto_ablkcipher___33 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___33 *);
	int (*decrypt)(struct ablkcipher_request___33 *);
	int (*givencrypt)(struct skcipher_givcrypt_request *);
	int (*givdecrypt)(struct skcipher_givcrypt_request *);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct crypto_ablkcipher___33 {
	struct crypto_tfm___33 base;
};

struct blkcipher_alg___33 {
	int (*setkey)(struct crypto_tfm___33 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___33 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___33 *, struct scatterlist *, struct scatterlist *, unsigned int);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct cipher_alg___33 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___33 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___33 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___33 *, u8 *, const u8 *);
};

struct compress_alg___33 {
	int (*coa_compress)(struct crypto_tfm___33 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___33 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___33 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type *cra_type;
	union {
		struct ablkcipher_alg___33 ablkcipher;
		struct blkcipher_alg___33 blkcipher;
		struct cipher_alg___33 cipher;
		struct compress_alg___33 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___33 *);
	void (*cra_exit)(struct crypto_tfm___33 *);
	void (*cra_destroy)(struct crypto_alg___33 *);
	struct module___369 *cra_module;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct crypto_cipher___17 {
	struct crypto_tfm___33 base;
};

struct msghdr___71 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___210 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___443 *msg_iocb;
};

struct socket_wq___69 {
	wait_queue_head_t wait;
	struct fasync_struct___443 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___69;

struct socket___70 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___69 *wq;
	struct file___443 *file;
	struct sock___68 *sk;
	const struct proto_ops___69 *ops;
};

typedef int (*sk_read_actor_t___68)(read_descriptor_t *, struct sk_buff___89 *, unsigned int, size_t);

struct proto_ops___69 {
	int family;
	struct module___369 *owner;
	int (*release)(struct socket___70 *);
	int (*bind)(struct socket___70 *, struct sockaddr *, int);
	int (*connect)(struct socket___70 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___70 *, struct socket___70 *);
	int (*accept)(struct socket___70 *, struct socket___70 *, int, bool);
	int (*getname)(struct socket___70 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___443 *, struct socket___70 *, struct poll_table_struct___282 *);
	int (*ioctl)(struct socket___70 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___70 *, int);
	int (*shutdown)(struct socket___70 *, int);
	int (*setsockopt)(struct socket___70 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___70 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___70 *, struct msghdr___71 *, size_t);
	int (*recvmsg)(struct socket___70 *, struct msghdr___71 *, size_t, int);
	int (*mmap)(struct file___443 *, struct socket___70 *, struct vm_area_struct___444 *);
	ssize_t (*sendpage)(struct socket___70 *, struct page___444 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___70 *, loff_t *, struct pipe_inode_info___124 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___68 *, int);
	int (*peek_len)(struct socket___70 *);
	int (*read_sock)(struct sock___68 *, read_descriptor_t *, sk_read_actor_t___68);
	int (*sendpage_locked)(struct sock___68 *, struct page___444 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___68 *, struct msghdr___71 *, size_t);
	int (*set_rcvlowat)(struct sock___68 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct sec_path___11;

struct nf_bridge_info___88;

struct sk_buff___89 {
	union {
		struct {
			struct sk_buff___89 *next;
			struct sk_buff___89 *prev;
			union {
				struct net_device___88 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___68 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___89 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path___11 *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___88 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___88;

struct netns_frags___88 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___88 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ip_ra_chain___34;

struct fib_rules_ops___68;

struct tcp_congestion_ops___14;

struct tcp_fastopen_context___14;

struct fib_notifier_ops___69;

struct netns_ipv4___88 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___34 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___68 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___68 *fibnl;
	struct sock___68 **icmp_sk;
	struct sock___68 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___68 **tcp_sk;
	struct netns_frags___88 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops___14 *tcp_congestion_control;
	struct tcp_fastopen_context___14 *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___68 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___69 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___69 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___68;

struct dst_ops___99 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___99 *);
	struct dst_entry___68 * (*check)(struct dst_entry___68 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___68 *);
	unsigned int (*mtu)(const struct dst_entry___68 *);
	u32 * (*cow_metrics)(struct dst_entry___68 *, long unsigned int);
	void (*destroy)(struct dst_entry___68 *);
	void (*ifdown)(struct dst_entry___68 *, struct net_device___88 *, int);
	struct dst_entry___68 * (*negative_advice)(struct dst_entry___68 *);
	void (*link_failure)(struct sk_buff___89 *);
	void (*update_pmtu)(struct dst_entry___68 *, struct sock___68 *, struct sk_buff___89 *, u32);
	void (*redirect)(struct dst_entry___68 *, struct sock___68 *, struct sk_buff___89 *);
	int (*local_out)(struct net___99 *, struct sock___68 *, struct sk_buff___89 *);
	struct neighbour___68 * (*neigh_lookup)(const struct dst_entry___68 *, struct sk_buff___89 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___68 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_info___15;

struct rt6_info___15;

struct fib6_table___15;

struct netns_ipv6___99 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___88 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info___15 *fib6_null_entry;
	struct rt6_info___15 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___15 *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___99 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info___15 *ip6_prohibit_entry;
	struct rt6_info___15 *ip6_blk_hole_entry;
	struct fib6_table___15 *fib6_local_tbl;
	struct fib_rules_ops___68 *fib6_rules_ops;
	struct sock___68 **icmp_sk;
	struct sock___68 *ndisc_sk;
	struct sock___68 *tcp_sk;
	struct sock___68 *igmp_sk;
	struct sock___68 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___68 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___69 *notifier_ops;
	struct fib_notifier_ops___69 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___69 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___68 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___88 {
	struct netns_frags___88 frags;
};

struct netns_xfrm___99 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___68 *nlsk;
	struct sock___68 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___99 xfrm4_dst_ops;
	struct dst_ops___99 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___78;

struct net___99 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___308 *user_ns;
	struct ucounts___308 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___29 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___68 *rtnl;
	struct sock___68 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___88 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___88 ipv4;
	struct netns_ipv6___99 ipv6;
	struct netns_sctp___69 sctp;
	struct netns_nf___12 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___88 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___68 *nfnl;
	struct sock___68 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___99 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___68 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___78 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___411 {
	int (*prepare)(struct device___411 *);
	void (*complete)(struct device___411 *);
	int (*suspend)(struct device___411 *);
	int (*resume)(struct device___411 *);
	int (*freeze)(struct device___411 *);
	int (*thaw)(struct device___411 *);
	int (*poweroff)(struct device___411 *);
	int (*restore)(struct device___411 *);
	int (*suspend_late)(struct device___411 *);
	int (*resume_early)(struct device___411 *);
	int (*freeze_late)(struct device___411 *);
	int (*thaw_early)(struct device___411 *);
	int (*poweroff_late)(struct device___411 *);
	int (*restore_early)(struct device___411 *);
	int (*suspend_noirq)(struct device___411 *);
	int (*resume_noirq)(struct device___411 *);
	int (*freeze_noirq)(struct device___411 *);
	int (*thaw_noirq)(struct device___411 *);
	int (*poweroff_noirq)(struct device___411 *);
	int (*restore_noirq)(struct device___411 *);
	int (*runtime_suspend)(struct device___411 *);
	int (*runtime_resume)(struct device___411 *);
	int (*runtime_idle)(struct device___411 *);
};

struct dev_pm_info___411 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___411 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___411;

struct bus_type___411;

struct device_driver___411;

struct dev_pm_domain___411;

struct dma_map_ops___183;

struct fwnode_handle___331;

struct class___411;

struct device___411 {
	struct device___411 *parent;
	struct device_private *p;
	struct kobject___431 kobj;
	const char *init_name;
	const struct device_type___411 *type;
	struct mutex mutex;
	struct bus_type___411 *bus;
	struct device_driver___411 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___411 power;
	struct dev_pm_domain___411 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___183 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___331 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___411 *class;
	const struct attribute_group___408 **groups;
	void (*release)(struct device___411 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___411 {
	struct dev_pm_ops___411 ops;
	void (*detach)(struct device___411 *, bool);
	int (*activate)(struct device___411 *);
	void (*sync)(struct device___411 *);
	void (*dismiss)(struct device___411 *);
};

struct bus_type___411 {
	const char *name;
	const char *dev_name;
	struct device___411 *dev_root;
	const struct attribute_group___408 **bus_groups;
	const struct attribute_group___408 **dev_groups;
	const struct attribute_group___408 **drv_groups;
	int (*match)(struct device___411 *, struct device_driver___411 *);
	int (*uevent)(struct device___411 *, struct kobj_uevent_env *);
	int (*probe)(struct device___411 *);
	int (*remove)(struct device___411 *);
	void (*shutdown)(struct device___411 *);
	int (*online)(struct device___411 *);
	int (*offline)(struct device___411 *);
	int (*suspend)(struct device___411 *, pm_message_t);
	int (*resume)(struct device___411 *);
	int (*num_vf)(struct device___411 *);
	int (*dma_configure)(struct device___411 *);
	const struct dev_pm_ops___411 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___411 {
	const char *name;
	struct bus_type___411 *bus;
	struct module___369 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___411 *);
	int (*remove)(struct device___411 *);
	void (*shutdown)(struct device___411 *);
	int (*suspend)(struct device___411 *, pm_message_t);
	int (*resume)(struct device___411 *);
	const struct attribute_group___408 **groups;
	const struct dev_pm_ops___411 *pm;
	void (*coredump)(struct device___411 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___411 {
	const char *name;
	const struct attribute_group___408 **groups;
	int (*uevent)(struct device___411 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___411 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___411 *);
	const struct dev_pm_ops___411 *pm;
};

struct class___411 {
	const char *name;
	struct module___369 *owner;
	const struct attribute_group___408 **class_groups;
	const struct attribute_group___408 **dev_groups;
	struct kobject___431 *dev_kobj;
	int (*dev_uevent)(struct device___411 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___411 *, umode_t *);
	void (*class_release)(struct class___411 *);
	void (*dev_release)(struct device___411 *);
	int (*shutdown_pre)(struct device___411 *);
	const struct kobj_ns_type_operations___68 *ns_type;
	const void * (*namespace)(struct device___411 *);
	const struct dev_pm_ops___411 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___183 {
	void * (*alloc)(struct device___411 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___411 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___411 *, struct vm_area_struct___444 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___411 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___411 *, struct page___444 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___411 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___411 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___411 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___411 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___411 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___411 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___411 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___411 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___411 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___411 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___411 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___411 *, u64);
	u64 (*get_required_mask)(struct device___411 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___331;

struct fwnode_handle___331 {
	struct fwnode_handle___331 *secondary;
	const struct fwnode_operations___331 *ops;
};

typedef void compound_page_dtor___431(struct page___444 *);

struct fwnode_reference_args___331;

struct fwnode_endpoint___331;

struct fwnode_operations___331 {
	struct fwnode_handle___331 * (*get)(struct fwnode_handle___331 *);
	void (*put)(struct fwnode_handle___331 *);
	bool (*device_is_available)(const struct fwnode_handle___331 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___331 *, const struct device___411 *);
	bool (*property_present)(const struct fwnode_handle___331 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___331 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___331 *, const char *, const char **, size_t);
	struct fwnode_handle___331 * (*get_parent)(const struct fwnode_handle___331 *);
	struct fwnode_handle___331 * (*get_next_child_node)(const struct fwnode_handle___331 *, struct fwnode_handle___331 *);
	struct fwnode_handle___331 * (*get_named_child_node)(const struct fwnode_handle___331 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___331 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___331 *);
	struct fwnode_handle___331 * (*graph_get_next_endpoint)(const struct fwnode_handle___331 *, struct fwnode_handle___331 *);
	struct fwnode_handle___331 * (*graph_get_remote_endpoint)(const struct fwnode_handle___331 *);
	struct fwnode_handle___331 * (*graph_get_port_parent)(struct fwnode_handle___331 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___331 *, struct fwnode_endpoint___331 *);
};

struct fwnode_endpoint___331 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___331 *local_fwnode;
};

struct fwnode_reference_args___331 {
	struct fwnode_handle___331 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___124;

struct pipe_buffer___124 {
	struct page___444 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___124 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___124 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___124 *, struct pipe_buffer___124 *);
	void (*release)(struct pipe_inode_info___124 *, struct pipe_buffer___124 *);
	int (*steal)(struct pipe_inode_info___124 *, struct pipe_buffer___124 *);
	union {
		bool (*get)(struct pipe_inode_info___124 *, struct pipe_buffer___124 *);
		struct {
			void (*get)(struct pipe_inode_info___124 *, struct pipe_buffer___124 *);
		} __UNIQUE_ID_rh_kabi_hide21;
		union {		};
	};
};

struct nf_bridge_info___88 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___88 = 0,
		BRNF_PROTO_8021Q___88 = 1,
		BRNF_PROTO_PPPOE___88 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___88 *physindev;
	struct net_device___88 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___88(struct sk_buff___89 **);

struct net_device_ops___88;

struct ethtool_ops___88;

struct l3mdev_ops___68;

struct ndisc_ops___39;

struct xfrmdev_ops___88;

struct tlsdev_ops___88;

struct header_ops___88;

struct inet6_dev___39;

struct netdev_rx_queue___88;

struct mini_Qdisc___80;

struct netdev_queue___88;

struct Qdisc___80;

struct rtnl_link_ops___80;

struct dcbnl_rtnl_ops___88;

struct net_device___88 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___88 *netdev_ops;
	const struct ethtool_ops___88 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___68 *l3mdev_ops;
	const struct ndisc_ops___39 *ndisc_ops;
	const struct xfrmdev_ops___88 *xfrmdev_ops;
	const struct tlsdev_ops___88 *tlsdev_ops;
	const struct header_ops___88 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___430 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___39 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___88 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___78 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___88 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___80 *miniq_ingress;
	struct netdev_queue___88 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___88 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___80 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___80 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___88 = 0,
		NETREG_REGISTERED___88 = 1,
		NETREG_UNREGISTERING___88 = 2,
		NETREG_UNREGISTERED___88 = 3,
		NETREG_RELEASED___88 = 4,
		NETREG_DUMMY___88 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___88 = 0,
		RTNL_LINK_INITIALIZING___88 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___88 *);
	struct netpoll_info *npinfo;
	possible_net_t___90 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___411 dev;
	const struct attribute_group___408 *sysfs_groups[4];
	const struct attribute_group___408 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___80 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___88 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide35;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct xfrm_state___11;

struct sec_path___11 {
	refcount_t refcnt;
	int len;
	int olen;
	struct xfrm_state___11 *xvec[6];
	struct xfrm_offload ovec[1];
};

struct ethtool_ops___88 {
	int (*get_settings)(struct net_device___88 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___88 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___88 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___88 *);
	void (*get_regs)(struct net_device___88 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___88 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___88 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___88 *);
	void (*set_msglevel)(struct net_device___88 *, u32);
	int (*nway_reset)(struct net_device___88 *);
	u32 (*get_link)(struct net_device___88 *);
	int (*get_eeprom_len)(struct net_device___88 *);
	int (*get_eeprom)(struct net_device___88 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___88 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___88 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___88 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___88 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___88 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___88 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___88 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___88 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___88 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___88 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___88 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___88 *);
	void (*complete)(struct net_device___88 *);
	u32 (*get_priv_flags)(struct net_device___88 *);
	int (*set_priv_flags)(struct net_device___88 *, u32);
	int (*get_sset_count)(struct net_device___88 *, int);
	int (*get_rxnfc)(struct net_device___88 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___88 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___88 *, struct ethtool_flash *);
	int (*reset)(struct net_device___88 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___88 *);
	u32 (*get_rxfh_indir_size)(struct net_device___88 *);
	int (*get_rxfh)(struct net_device___88 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___88 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___88 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___88 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___88 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___88 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___88 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___88 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___88 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___88 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___88 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___88 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___88 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___88 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___88 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___88 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___88 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___88 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___88 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___88 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___88 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___88 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	int (*get_fecparam)(struct net_device___88 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___88 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___88 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___88 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___88 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___88;

struct inet_frags___88 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___88 *, const void *);
	void (*destructor)(struct inet_frag_queue___88 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___88 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___89 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___89 *fragments_tail;
	struct sk_buff___89 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___88 *net;
	struct callback_head rcu;
};

struct ip_ra_chain___34 {
	struct ip_ra_chain___34 *next;
	struct sock___68 *sk;
	union {
		void (*destructor)(struct sock___68 *);
		struct sock___68 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___68;

struct fib_lookup_arg___68;

struct fib_rules_ops___68 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___68 *, struct flowi *, int, struct fib_lookup_arg___68 *);
	bool (*suppress)(struct fib_rule___68 *, struct fib_lookup_arg___68 *);
	int (*match)(struct fib_rule___68 *, struct flowi *, int);
	int (*configure)(struct fib_rule___68 *, struct sk_buff___89 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___68 *);
	int (*compare)(struct fib_rule___68 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___68 *, struct sk_buff___89 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___68 *);
	void (*flush_cache)(struct fib_rules_ops___68 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___369 *owner;
	struct net___99 *fro_net;
	struct callback_head rcu;
};

struct tcp_congestion_ops___14 {
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___68 *);
	void (*release)(struct sock___68 *);
	u32 (*ssthresh)(struct sock___68 *);
	void (*cong_avoid)(struct sock___68 *, u32, u32);
	void (*set_state)(struct sock___68 *, u8);
	void (*cwnd_event)(struct sock___68 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___68 *, u32);
	u32 (*undo_cwnd)(struct sock___68 *);
	void (*pkts_acked)(struct sock___68 *, const struct ack_sample *);
	u32 (*min_tso_segs)(struct sock___68 *);
	u32 (*sndbuf_expand)(struct sock___68 *);
	void (*cong_control)(struct sock___68 *, const struct rate_sample *);
	size_t (*get_info)(struct sock___68 *, u32, int *, union tcp_cc_info *);
	char name[16];
	struct module___369 *owner;
};

struct tcp_fastopen_context___14 {
	struct crypto_cipher___17 *tfm;
	__u8 key[16];
	struct callback_head rcu;
};

struct fib_notifier_ops___69 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___99 *);
	int (*fib_dump)(struct net___99 *, struct notifier_block *);
	struct module___369 *owner;
	struct callback_head rcu;
};

struct dst_entry___68 {
	struct net_device___88 *dev;
	struct dst_ops___99 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state___11 *xfrm;
	int (*input)(struct sk_buff___89 *);
	int (*output)(struct net___99 *, struct sock___68 *, struct sk_buff___89 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___68;

struct neigh_parms___68;

struct neigh_ops___68;

struct neighbour___68 {
	struct neighbour___68 *next;
	struct neigh_table___68 *tbl;
	struct neigh_parms___68 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___88 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___68 *, struct sk_buff___89 *);
	const struct neigh_ops___68 *ops;
	struct callback_head rcu;
	struct net_device___88 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct fib6_nh___15 {
	struct in6_addr nh_gw;
	struct net_device___88 *nh_dev;
	struct lwtunnel_state *nh_lwtstate;
	unsigned int nh_flags;
	atomic_t nh_upper_bound;
	int nh_weight;
};

struct fib6_node___15;

struct fib6_info___15 {
	struct fib6_table___15 *fib6_table;
	struct fib6_info___15 *fib6_next;
	struct fib6_node___15 *fib6_node;
	struct list_head fib6_siblings;
	unsigned int fib6_nsiblings;
	atomic_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	struct rt6_info___15 **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
	long unsigned int last_probe;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 exception_bucket_flushed: 1;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 dst_host: 1;
	u8 fib6_destroying: 1;
	u8 unused: 2;
	struct fib6_nh___15 fib6_nh;
	struct callback_head rcu;
};

struct rt6_info___15 {
	struct dst_entry___68 dst;
	struct fib6_info___15 *from;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___39 *rt6i_idev;
	u32 rt6i_flags;
	struct rt6key rt6i_prefsrc;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct fib6_node___15 {
	struct fib6_node___15 *parent;
	struct fib6_node___15 *left;
	struct fib6_node___15 *right;
	struct fib6_info___15 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info___15 *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table___15 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node___15 tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

struct ucounts___308 {
	struct hlist_node node;
	struct user_namespace___308 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_prog_aux___81;

struct bpf_prog___78 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___81 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

typedef int (*key_restrict_link_func_t___412)(struct key___411 *, const struct key_type *, const union key_payload *, struct key___411 *);

struct key_restriction___411;

struct key___411 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___445 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___411 *restrict_link;
};

struct key_restriction___411 {
	key_restrict_link_func_t___412 check;
	struct key___411 *key;
	struct key_type *keytype;
};

struct seq_operations___382 {
	void * (*start)(struct seq_file___382 *, loff_t *);
	void (*stop)(struct seq_file___382 *, void *);
	void * (*next)(struct seq_file___382 *, void *, loff_t *);
	int (*show)(struct seq_file___382 *, void *);
};

struct pernet_operations___89 {
	struct list_head list;
	int (*init)(struct net___99 *);
	void (*exit)(struct net___99 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___88 {
	int (*ieee_getets)(struct net_device___88 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___88 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___88 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___88 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___88 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___88 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___88 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___88 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___88 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___88 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___88 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___88 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___88 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___88 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___88 *);
	u8 (*setstate)(struct net_device___88 *, u8);
	void (*getpermhwaddr)(struct net_device___88 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___88 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___88 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___88 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___88 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___88 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___88 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___88 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___88 *, int, u8 *);
	void (*setpfccfg)(struct net_device___88 *, int, u8);
	void (*getpfccfg)(struct net_device___88 *, int, u8 *);
	u8 (*setall)(struct net_device___88 *);
	u8 (*getcap)(struct net_device___88 *, int, u8 *);
	int (*getnumtcs)(struct net_device___88 *, int, u8 *);
	int (*setnumtcs)(struct net_device___88 *, int, u8);
	u8 (*getpfcstate)(struct net_device___88 *);
	void (*setpfcstate)(struct net_device___88 *, u8);
	void (*getbcncfg)(struct net_device___88 *, int, u32 *);
	void (*setbcncfg)(struct net_device___88 *, int, u32);
	void (*getbcnrp)(struct net_device___88 *, int, u8 *);
	void (*setbcnrp)(struct net_device___88 *, int, u8);
	int (*setapp)(struct net_device___88 *, u8, u16, u8);
	int (*getapp)(struct net_device___88 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___88 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___88 *, int, u8);
	u8 (*getdcbx)(struct net_device___88 *);
	u8 (*setdcbx)(struct net_device___88 *, u8);
	int (*peer_getappinfo)(struct net_device___88 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___88 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___88 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___88 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___88 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___88 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___292 {
	refcount_t count;
	struct ns_common___29 ns;
	struct user_namespace___308 *user_ns;
	struct ucounts___308 *ucounts;
	struct css_set___292 *root_cset;
};

struct bpf_map___293;

struct bpf_map_ops___292 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___293 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___293 *, struct file___443 *);
	void (*map_free)(struct bpf_map___293 *);
	int (*map_get_next_key)(struct bpf_map___293 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___293 *);
	void * (*map_lookup_elem)(struct bpf_map___293 *, void *);
	int (*map_update_elem)(struct bpf_map___293 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___293 *, void *);
	int (*map_push_elem)(struct bpf_map___293 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___293 *, void *);
	int (*map_peek_elem)(struct bpf_map___293 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___293 *, struct file___443 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___293 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___293 *, void *, struct seq_file___382 *);
	int (*map_check_btf)(const struct bpf_map___293 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___293 {
	const struct bpf_map_ops___292 *ops;
	struct bpf_map___293 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___411 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___88;

struct bpf_map_dev_ops___88 {
	int (*map_get_next_key)(struct bpf_offloaded_map___88 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___88 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___88 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___88 *, void *);
};

struct bpf_offloaded_map___88 {
	struct bpf_map___293 map;
	struct net_device___88 *netdev;
	const struct bpf_map_dev_ops___88 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___78 {
	int (*test_run)(struct bpf_prog___78 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___78 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___78 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___78 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___78 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___78 *, u32 *);
};

struct bpf_prog_offload_ops___78 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___78 *);
	int (*translate)(struct bpf_prog___78 *);
	void (*destroy)(struct bpf_prog___78 *);
};

struct bpf_prog_offload___78 {
	struct bpf_prog___78 *prog;
	struct net_device___88 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___78 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___81 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___78 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___78 *ops;
	struct bpf_map___293 **used_maps;
	struct bpf_prog___78 *prog;
	struct user_struct___411 *user;
	u64 load_time;
	struct bpf_map___293 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___78 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___78 {
	struct bpf_prog___78 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___78 {
	struct callback_head rcu;
	struct bpf_prog_array_item___78 items[0];
};

struct cgroup_bpf___78 {
	struct bpf_prog_array___78 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___78 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___293;

typedef void (*kthread_work_func_t___293)(struct kthread_work___293 *);

struct kthread_worker___293;

struct kthread_work___293 {
	struct list_head node;
	kthread_work_func_t___293 func;
	struct kthread_worker___293 *worker;
	int canceling;
};

struct kthread_worker___293 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___445 *task;
	struct kthread_work___293 *current_work;
};

struct kthread_delayed_work___292 {
	struct kthread_work___293 work;
	struct timer_list timer;
};

struct psi_group___292 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___293 *poll_kworker;
	struct kthread_delayed_work___292 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___292;

struct cgroup_rstat_cpu___292;

struct cgroup___292 {
	struct cgroup_subsys_state___292 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___438 *kn;
	struct cgroup_file___292 procs_file;
	struct cgroup_file___292 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___292 *subsys[13];
	struct cgroup_root___292 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___292 *dom_cgrp;
	struct cgroup_rstat_cpu___292 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___78 bpf;
	atomic_t congestion_count;
	struct cgroup___292 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___292 psi;
	int ancestor_ids[0];
};

struct cftype___292;

struct cgroup_subsys___292 {
	struct cgroup_subsys_state___292 * (*css_alloc)(struct cgroup_subsys_state___292 *);
	int (*css_online)(struct cgroup_subsys_state___292 *);
	void (*css_offline)(struct cgroup_subsys_state___292 *);
	void (*css_released)(struct cgroup_subsys_state___292 *);
	void (*css_free)(struct cgroup_subsys_state___292 *);
	void (*css_reset)(struct cgroup_subsys_state___292 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___292 *, int);
	int (*css_extra_stat_show)(struct seq_file___382 *, struct cgroup_subsys_state___292 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___445 *);
	void (*cancel_fork)(struct task_struct___445 *);
	void (*fork)(struct task_struct___445 *);
	void (*exit)(struct task_struct___445 *);
	void (*free)(struct task_struct___445 *);
	void (*bind)(struct cgroup_subsys_state___292 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___292 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___292 *dfl_cftypes;
	struct cftype___292 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___292 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___292 *updated_children;
	struct cgroup___292 *updated_next;
};

struct cgroup_root___292 {
	struct kernfs_root___437 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___292 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___292 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___292 *ss;
	struct list_head node;
	struct kernfs_ops___437 *kf_ops;
	int (*open)(struct kernfs_open_file___437 *);
	void (*release)(struct kernfs_open_file___437 *);
	u64 (*read_u64)(struct cgroup_subsys_state___292 *, struct cftype___292 *);
	s64 (*read_s64)(struct cgroup_subsys_state___292 *, struct cftype___292 *);
	int (*seq_show)(struct seq_file___382 *, void *);
	void * (*seq_start)(struct seq_file___382 *, loff_t *);
	void * (*seq_next)(struct seq_file___382 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___382 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___292 *, struct cftype___292 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___292 *, struct cftype___292 *, s64);
	ssize_t (*write)(struct kernfs_open_file___437 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___437 *, struct poll_table_struct___282 *);
};

struct xdp_rxq_info___88 {
	struct net_device___88 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___88 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___88 *dev_rx;
};

struct netlink_callback___90 {
	struct sk_buff___89 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___90 *);
	int (*dump)(struct sk_buff___89 *, struct netlink_callback___90 *);
	int (*done)(struct netlink_callback___90 *);
	void *data;
	struct module___369 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___88 {
	int (*create)(struct sk_buff___89 *, struct net_device___88 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___89 *, unsigned char *);
	int (*cache)(const struct neighbour___68 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___88 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___88 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___88 *, int);
	int poll_owner;
	struct net_device___88 *dev;
	struct sk_buff___89 *gro_list;
	struct sk_buff___89 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___88 {
	struct net_device___88 *dev;
	struct Qdisc___80 *qdisc;
	struct Qdisc___80 *qdisc_sleeping;
	struct kobject___431 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___88 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem___3 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___80 {
	struct sk_buff___89 *head;
	struct sk_buff___89 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___80;

struct Qdisc___80 {
	int (*enqueue)(struct sk_buff___89 *, struct Qdisc___80 *, struct sk_buff___89 **);
	struct sk_buff___89 * (*dequeue)(struct Qdisc___80 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___80 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___88 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___88 gso_skb;
	struct qdisc_skb_head___80 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___80 *next_sched;
	struct sk_buff_head___88 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___88 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___431 kobj;
	struct net_device___88 *dev;
	long: 64;
	struct xdp_rxq_info___88 xdp_rxq;
	union {
		struct xdp_umem___3 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___88)(struct net_device___88 *, struct sk_buff___89 *, struct net_device___88 *);

struct netdev_bpf___88 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___78 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___78 *prog;
			const struct bpf_prog_offload_ops___78 *ops;
		} verifier;
		struct {
			struct bpf_prog___78 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___88 *offmap;
		};
		struct {
			struct xdp_umem___3 *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___88 {
	int (*xdo_dev_state_add)(struct xfrm_state___11 *);
	void (*xdo_dev_state_delete)(struct xfrm_state___11 *);
	void (*xdo_dev_state_free)(struct xfrm_state___11 *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___89 *, struct xfrm_state___11 *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state___11 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct xfrm_state_offload___11 {
	struct net_device___88 *dev;
	long unsigned int offload_handle;
	unsigned int num_exthdrs;
	u8 flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct xfrm_replay___11;

struct xfrm_type___11;

struct xfrm_mode___11;

struct xfrm_type_offload___11;

struct xfrm_state___11 {
	possible_net_t___90 xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	refcount_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
		u32 output_mark;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	const char *geniv;
	struct xfrm_encap_tmpl *encap;
	xfrm_address_t *coaddr;
	struct xfrm_state___11 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	const struct xfrm_replay___11 *repl;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct tasklet_hrtimer mtimer;
	struct xfrm_state_offload___11 xso;
	long int saved_tmo;
	long unsigned int lastused;
	struct page_frag___444 xfrag;
	const struct xfrm_type___11 *type;
	struct xfrm_mode___11 *inner_mode;
	struct xfrm_mode___11 *inner_mode_iaf;
	struct xfrm_mode___11 *outer_mode;
	const struct xfrm_type_offload___11 *type_offload;
	struct xfrm_sec_ctx___2 *security;
	void *data;
	u32 output_mark_mask;
	u32 if_id;
};

struct tlsdev_ops___88 {
	int (*tls_dev_add)(struct net_device___88 *, struct sock___68 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___88 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___88 *, struct sock___68 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___88 {
	int (*ndo_init)(struct net_device___88 *);
	void (*ndo_uninit)(struct net_device___88 *);
	int (*ndo_open)(struct net_device___88 *);
	int (*ndo_stop)(struct net_device___88 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___89 *, struct net_device___88 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___89 *, struct net_device___88 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___88 *, struct sk_buff___89 *, struct net_device___88 *, select_queue_fallback_t___88);
	void (*ndo_change_rx_flags)(struct net_device___88 *, int);
	void (*ndo_set_rx_mode)(struct net_device___88 *);
	int (*ndo_set_mac_address)(struct net_device___88 *, void *);
	int (*ndo_validate_addr)(struct net_device___88 *);
	int (*ndo_do_ioctl)(struct net_device___88 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___88 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___88 *, int);
	int (*ndo_neigh_setup)(struct net_device___88 *, struct neigh_parms___68 *);
	void (*ndo_tx_timeout)(struct net_device___88 *);
	void (*ndo_get_stats64)(struct net_device___88 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___88 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___88 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___88 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___88 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___88 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___88 *);
	int (*ndo_netpoll_setup)(struct net_device___88 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___88 *);
	int (*ndo_set_vf_mac)(struct net_device___88 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___88 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___88 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___88 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___88 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___88 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___88 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___88 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___88 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___88 *, int, struct sk_buff___89 *);
	int (*ndo_set_vf_guid)(struct net_device___88 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___88 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___88 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___88 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___88 *, const struct sk_buff___89 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___88 *, struct net_device___88 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___88 *, struct net_device___88 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___88 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___88 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___88 *, struct neighbour___68 *);
	void (*ndo_neigh_destroy)(struct net_device___88 *, struct neighbour___68 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___88 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___88 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___88 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___89 *, struct netlink_callback___90 *, struct net_device___88 *, struct net_device___88 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___88 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___88 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___89 *, u32, u32, struct net_device___88 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___88 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___88 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___88 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___88 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___88 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___88 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___88 *, struct net_device___88 *);
	void (*ndo_dfwd_del_station)(struct net_device___88 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___88 *);
	int (*ndo_set_tx_maxrate)(struct net_device___88 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___88 *);
	int (*ndo_change_proto_down)(struct net_device___88 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___88 *, struct sk_buff___89 *);
	void (*ndo_set_rx_headroom)(struct net_device___88 *, int);
	int (*ndo_bpf)(struct net_device___88 *, struct netdev_bpf___88 *);
	int (*ndo_xdp_xmit)(struct net_device___88 *, int, struct xdp_frame___88 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___88 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___88 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___68 {
	possible_net_t___90 net;
	struct net_device___88 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___68 *);
	void (*neigh_cleanup)(struct neighbour___68 *);
	struct neigh_table___68 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___68 {
	u32 (*l3mdev_fib_table)(const struct net_device___88 *);
	struct sk_buff___89 * (*l3mdev_l3_rcv)(struct net_device___88 *, struct sk_buff___89 *, u16);
	struct sk_buff___89 * (*l3mdev_l3_out)(struct net_device___88 *, struct sock___68 *, struct sk_buff___89 *, u16);
	struct dst_entry___68 * (*l3mdev_link_scope_lookup)(const struct net_device___88 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct ndisc_ops___39 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___88 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___88 *, struct neighbour___68 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___88 *, u8, struct neighbour___68 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___88 *, struct sk_buff___89 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___99 *, struct net_device___88 *, const struct prefix_info *, struct inet6_dev___39 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___39;

struct ifacaddr6___15;

struct inet6_dev___39 {
	struct net_device___88 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___39 *mc_list;
	struct ifmcaddr6___39 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___15 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	u8 rndid[8];
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___68 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
};

struct tcf_proto___80;

struct mini_Qdisc___80 {
	struct tcf_proto___80 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___80 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___88 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___99 *, struct net_device___88 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___88 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___88 *, struct list_head *);
	size_t (*get_size)(const struct net_device___88 *);
	int (*fill_info)(struct sk_buff___89 *, const struct net_device___88 *);
	size_t (*get_xstats_size)(const struct net_device___88 *);
	int (*fill_xstats)(struct sk_buff___89 *, const struct net_device___88 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___88 *, struct net_device___88 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___88 *, const struct net_device___88 *);
	int (*fill_slave_info)(struct sk_buff___89 *, const struct net_device___88 *, const struct net_device___88 *);
	struct net___99 * (*get_link_net)(const struct net_device___88 *);
	size_t (*get_linkxstats_size)(const struct net_device___88 *, int);
	int (*fill_linkxstats)(struct sk_buff___89 *, const struct net_device___88 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___88 {
	struct list_head poll_list;
	struct sk_buff_head___88 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___88 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___80 *output_queue;
	struct Qdisc___80 **output_queue_tailp;
	struct sk_buff___89 *completion_queue;
	struct sk_buff_head___88 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___88 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___88 input_pkt_queue;
	struct napi_struct___88 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bdi_writeback_congested___233 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___233 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___233 {
	struct bio___233 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___235 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___235 bip_inline_vecs[0];
};

struct bio_set___233 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___233 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___176 {
	struct mem_cgroup___176 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___176 {
	struct lruvec___444 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___176 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___176 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct gnet_dump___80 {
	spinlock_t *lock;
	struct sk_buff___89 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___80;

struct Qdisc_ops___80 {
	struct Qdisc_ops___80 *next;
	const struct Qdisc_class_ops___80 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___89 *, struct Qdisc___80 *, struct sk_buff___89 **);
	struct sk_buff___89 * (*dequeue)(struct Qdisc___80 *);
	struct sk_buff___89 * (*peek)(struct Qdisc___80 *);
	int (*init)(struct Qdisc___80 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___80 *);
	void (*destroy)(struct Qdisc___80 *);
	int (*change)(struct Qdisc___80 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___80 *);
	int (*change_tx_queue_len)(struct Qdisc___80 *, unsigned int);
	int (*dump)(struct Qdisc___80 *, struct sk_buff___89 *);
	int (*dump_stats)(struct Qdisc___80 *, struct gnet_dump___80 *);
	void (*ingress_block_set)(struct Qdisc___80 *, u32);
	void (*egress_block_set)(struct Qdisc___80 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___80 *);
	u32 (*egress_block_get)(struct Qdisc___80 *);
	struct module___369 *owner;
};

struct tcf_block___80;

struct Qdisc_class_ops___80 {
	unsigned int flags;
	struct netdev_queue___88 * (*select_queue)(struct Qdisc___80 *, struct tcmsg *);
	int (*graft)(struct Qdisc___80 *, long unsigned int, struct Qdisc___80 *, struct Qdisc___80 **, struct netlink_ext_ack *);
	struct Qdisc___80 * (*leaf)(struct Qdisc___80 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___80 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___80 *, u32);
	int (*change)(struct Qdisc___80 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___80 *, long unsigned int);
	void (*walk)(struct Qdisc___80 *, struct qdisc_walker *);
	struct tcf_block___80 * (*tcf_block)(struct Qdisc___80 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___80 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___80 *, long unsigned int);
	int (*dump)(struct Qdisc___80 *, long unsigned int, struct sk_buff___89 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___80 *, long unsigned int, struct gnet_dump___80 *);
};

struct tcf_chain___80;

struct tcf_block___80 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___99 *net;
	struct Qdisc___80 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___80 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___80;

struct tcf_proto_ops___80;

struct tcf_proto___80 {
	struct tcf_proto___80 *next;
	void *root;
	int (*classify)(struct sk_buff___89 *, const struct tcf_proto___80 *, struct tcf_result___80 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___80 *ops;
	struct tcf_chain___80 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___80 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___80 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___80 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___89 *, const struct tcf_proto___80 *, struct tcf_result___80 *);
	int (*init)(struct tcf_proto___80 *);
	void (*destroy)(struct tcf_proto___80 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___80 *, u32);
	void (*put)(struct tcf_proto___80 *, void *);
	int (*change)(struct net___99 *, struct sk_buff___89 *, struct tcf_proto___80 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___80 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___80 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___80 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___99 *, struct tcf_chain___80 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___99 *, struct tcf_proto___80 *, void *, struct sk_buff___89 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___89 *, struct net___99 *, void *);
	struct module___369 *owner;
	int flags;
};

struct tcf_chain___80 {
	struct mutex filter_chain_lock;
	struct tcf_proto___80 *filter_chain;
	struct list_head list;
	struct tcf_block___80 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___80 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___68 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___78 *prog;
};

struct bpf_redirect_info___78 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___293 *map;
	struct bpf_map___293 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___68;

struct neigh_hash_table___68;

struct neigh_table___68 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___88 *, __u32 *);
	bool (*key_eq)(const struct neighbour___68 *, const void *);
	int (*constructor)(struct neighbour___68 *);
	int (*pconstructor)(struct pneigh_entry___68 *);
	void (*pdestructor)(struct pneigh_entry___68 *);
	void (*proxy_redo)(struct sk_buff___89 *);
	char *id;
	struct neigh_parms___68 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___88 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___68 *nht;
	struct pneigh_entry___68 **phash_buckets;
};

struct neigh_ops___68 {
	int family;
	void (*solicit)(struct neighbour___68 *, struct sk_buff___89 *);
	void (*error_report)(struct neighbour___68 *, struct sk_buff___89 *);
	int (*output)(struct neighbour___68 *, struct sk_buff___89 *);
	int (*connected_output)(struct neighbour___68 *, struct sk_buff___89 *);
};

struct pneigh_entry___68 {
	struct pneigh_entry___68 *next;
	possible_net_t___90 net;
	struct net_device___88 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___68 {
	struct neighbour___68 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___68 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___68 *ctarget;
	struct net___99 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___68 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___68 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___51;

struct timewait_sock_ops___47;

struct proto___68 {
	void (*close)(struct sock___68 *, long int);
	int (*pre_connect)(struct sock___68 *, struct sockaddr *, int);
	int (*connect)(struct sock___68 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___68 *, int);
	struct sock___68 * (*accept)(struct sock___68 *, int, int *, bool);
	int (*ioctl)(struct sock___68 *, int, long unsigned int);
	int (*init)(struct sock___68 *);
	void (*destroy)(struct sock___68 *);
	void (*shutdown)(struct sock___68 *, int);
	int (*setsockopt)(struct sock___68 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___68 *, int, int, char *, int *);
	void (*keepalive)(struct sock___68 *, int);
	int (*sendmsg)(struct sock___68 *, struct msghdr___71 *, size_t);
	int (*recvmsg)(struct sock___68 *, struct msghdr___71 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___68 *, struct page___444 *, int, size_t, int);
	int (*bind)(struct sock___68 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___68 *, struct sk_buff___89 *);
	void (*release_cb)(struct sock___68 *);
	int (*hash)(struct sock___68 *);
	void (*unhash)(struct sock___68 *);
	void (*rehash)(struct sock___68 *);
	int (*get_port)(struct sock___68 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___68 *);
	bool (*stream_memory_read)(const struct sock___68 *);
	void (*enter_memory_pressure)(struct sock___68 *);
	void (*leave_memory_pressure)(struct sock___68 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___51 *rsk_prot;
	struct timewait_sock_ops___47 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___369 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___68 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct xfrm_policy_queue___11 {
	struct sk_buff_head___88 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___11 {
	possible_net_t___90 xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	refcount_t refcnt;
	struct timer_list timer;
	atomic_t genid;
	u32 priority;
	u32 index;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___11 polq;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx___2 *security;
	struct xfrm_tmpl xfrm_vec[6];
	struct callback_head rcu;
	u32 if_id;
};

struct sock_reuseport___6 {
	struct callback_head rcu;
	u16 max_socks;
	u16 num_socks;
	unsigned int reuseport_id;
	bool bind_inany;
	struct bpf_prog___78 *prog;
	struct sock___68 *socks[0];
};

struct request_sock___52;

struct request_sock_ops___51 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___68 *, struct request_sock___52 *);
	void (*send_ack)(const struct sock___68 *, struct sk_buff___89 *, struct request_sock___52 *);
	void (*send_reset)(const struct sock___68 *, struct sk_buff___89 *);
	void (*destructor)(struct request_sock___52 *);
	void (*syn_ack_timeout)(const struct request_sock___52 *);
};

struct timewait_sock_ops___47 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___68 *, struct sock___68 *, void *);
	void (*twsk_destructor)(struct sock___68 *);
};

struct request_sock___52 {
	struct sock_common___68 __req_common;
	struct request_sock___52 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___51 *rsk_ops;
	struct sock___68 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct fastopen_queue___7 {
	struct request_sock___52 *rskq_rst_head;
	struct request_sock___52 *rskq_rst_tail;
	spinlock_t lock;
	int qlen;
	int max_qlen;
	struct tcp_fastopen_context___14 *ctx;
};

struct request_sock_queue___7 {
	spinlock_t rskq_lock;
	u8 rskq_defer_accept;
	u32 synflood_warned;
	atomic_t qlen;
	atomic_t young;
	struct request_sock___52 *rskq_accept_head;
	struct request_sock___52 *rskq_accept_tail;
	struct fastopen_queue___7 fastopenq;
};

struct inet_request_sock___3 {
	struct request_sock___52 req;
	u16 snd_wscale: 4;
	u16 rcv_wscale: 4;
	u16 tstamp_ok: 1;
	u16 sack_ok: 1;
	u16 wscale_ok: 1;
	u16 ecn_ok: 1;
	u16 acked: 1;
	u16 no_srccheck: 1;
	u16 smc_ok: 1;
	u32 ir_mark;
	union {
		struct ip_options_rcu *ireq_opt;
		struct {
			struct ipv6_txoptions *ipv6_opt;
			struct sk_buff___89 *pktopts;
		};
	};
};

struct inet_cork___11 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___68 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
	__u16 gso_size;
	u64 transmit_time;
};

struct inet_cork_full___11 {
	struct inet_cork___11 base;
	struct flowi fl;
};

struct ipv6_pinfo___11;

struct inet_sock___11 {
	struct sock___68 sk;
	struct ipv6_pinfo___11 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	__be16 inet_sport;
	__u16 inet_id;
	struct ip_options_rcu *inet_opt;
	int rx_dst_ifindex;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 bind_address_no_port: 1;
	__u8 defer_connect: 1;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___11 cork;
};

struct ipv6_fl_socklist___10;

struct ipv6_pinfo___11 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
			__u16 recvfragsize: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 repflow: 1;
	__u16 pmtudisc: 3;
	__u16 padding: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u16 autoflowlabel: 1;
	__u16 autoflowlabel_set: 1;
	__u8 min_hopcount;
	__u8 tclass;
	__be32 rcv_flowinfo;
	__u32 dst_cookie;
	__u32 rx_dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___10 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___89 *pktoptions;
	struct sk_buff___89 *rxpmtu;
	struct inet6_cork cork;
};

struct inet_connection_sock_af_ops___7 {
	int (*queue_xmit)(struct sock___68 *, struct sk_buff___89 *, struct flowi *);
	void (*send_check)(struct sock___68 *, struct sk_buff___89 *);
	int (*rebuild_header)(struct sock___68 *);
	void (*sk_rx_dst_set)(struct sock___68 *, const struct sk_buff___89 *);
	int (*conn_request)(struct sock___68 *, struct sk_buff___89 *);
	struct sock___68 * (*syn_recv_sock)(const struct sock___68 *, struct sk_buff___89 *, struct request_sock___52 *, struct dst_entry___68 *, struct request_sock___52 *, bool *);
	u16 net_header_len;
	u16 net_frag_header_len;
	u16 sockaddr_len;
	int (*setsockopt)(struct sock___68 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___68 *, int, int, char *, int *);
	void (*addr2sockaddr)(struct sock___68 *, struct sockaddr *);
	void (*mtu_reduced)(struct sock___68 *);
};

struct inet_bind_bucket___6;

struct tcp_ulp_ops___5;

struct inet_connection_sock___7 {
	struct inet_sock___11 icsk_inet;
	struct request_sock_queue___7 icsk_accept_queue;
	struct inet_bind_bucket___6 *icsk_bind_hash;
	long unsigned int icsk_timeout;
	struct timer_list icsk_retransmit_timer;
	struct timer_list icsk_delack_timer;
	__u32 icsk_rto;
	__u32 icsk_pmtu_cookie;
	const struct tcp_congestion_ops___14 *icsk_ca_ops;
	const struct inet_connection_sock_af_ops___7 *icsk_af_ops;
	const struct tcp_ulp_ops___5 *icsk_ulp_ops;
	void *icsk_ulp_data;
	void (*icsk_clean_acked)(struct sock___68 *, u32);
	struct hlist_node icsk_listen_portaddr_node;
	unsigned int (*icsk_sync_mss)(struct sock___68 *, u32);
	__u8 icsk_ca_state: 6;
	__u8 icsk_ca_setsockopt: 1;
	__u8 icsk_ca_dst_locked: 1;
	__u8 icsk_retransmits;
	__u8 icsk_pending;
	__u8 icsk_backoff;
	__u8 icsk_syn_retries;
	__u8 icsk_probes_out;
	__u16 icsk_ext_hdr_len;
	struct {
		__u8 pending;
		__u8 quick;
		__u8 pingpong;
		__u8 blocked;
		__u32 ato;
		long unsigned int timeout;
		__u32 lrcvtime;
		__u16 last_seg_size;
		__u16 rcv_mss;
	} icsk_ack;
	struct {
		int enabled;
		int search_high;
		int search_low;
		int probe_size;
		u32 probe_timestamp;
	} icsk_mtup;
	u32 icsk_user_timeout;
	u64 icsk_ca_priv[11];
};

struct inet_bind_bucket___6 {
	possible_net_t___90 ib_net;
	short unsigned int port;
	signed char fastreuse;
	signed char fastreuseport;
	kuid_t fastuid;
	struct in6_addr fast_v6_rcv_saddr;
	__be32 fast_rcv_saddr;
	short unsigned int fast_sk_family;
	bool fast_ipv6_only;
	struct hlist_node node;
	struct hlist_head owners;
};

struct tcp_ulp_ops___5 {
	struct list_head list;
	int (*init)(struct sock___68 *);
	void (*release)(struct sock___68 *);
	char name[16];
	struct module___369 *owner;
};

struct tcp_request_sock_ops___2;

struct tcp_request_sock___2 {
	struct inet_request_sock___3 req;
	const struct tcp_request_sock_ops___2 *af_specific;
	u64 snt_synack;
	bool tfo_listener;
	u32 txhash;
	u32 rcv_isn;
	u32 snt_isn;
	u32 ts_off;
	u32 last_oow_ack_time;
	u32 rcv_nxt;
};

enum tcp_synack_type {
	TCP_SYNACK_NORMAL = 0,
	TCP_SYNACK_FASTOPEN = 1,
	TCP_SYNACK_COOKIE = 2,
};

struct tcp_request_sock_ops___2 {
	u16 mss_clamp;
	struct tcp_md5sig_key * (*req_md5_lookup)(const struct sock___68 *, const struct sock___68 *);
	int (*calc_md5_hash)(char *, const struct tcp_md5sig_key *, const struct sock___68 *, const struct sk_buff___89 *);
	void (*init_req)(struct request_sock___52 *, const struct sock___68 *, struct sk_buff___89 *);
	__u32 (*cookie_init_seq)(const struct sk_buff___89 *, __u16 *);
	struct dst_entry___68 * (*route_req)(const struct sock___68 *, struct flowi *, const struct request_sock___52 *);
	u32 (*init_seq)(const struct sk_buff___89 *);
	u32 (*init_ts_off)(const struct net___99 *, const struct sk_buff___89 *);
	int (*send_synack)(const struct sock___68 *, struct dst_entry___68 *, struct flowi *, struct request_sock___52 *, struct tcp_fastopen_cookie *, enum tcp_synack_type);
};

struct tcp_sock_af_ops___5;

struct tcp_fastopen_request___5;

struct tcp_sock___5 {
	struct inet_connection_sock___7 inet_conn;
	u16 tcp_header_len;
	u16 gso_segs;
	__be32 pred_flags;
	u64 bytes_received;
	u32 segs_in;
	u32 data_segs_in;
	u32 rcv_nxt;
	u32 copied_seq;
	u32 rcv_wup;
	u32 snd_nxt;
	u32 segs_out;
	u32 data_segs_out;
	u64 bytes_acked;
	u32 snd_una;
	u32 snd_sml;
	u32 rcv_tstamp;
	u32 lsndtime;
	u32 last_oow_ack_time;
	u32 compressed_ack_rcv_nxt;
	u32 tsoffset;
	struct list_head tsq_node;
	struct list_head tsorted_sent_queue;
	u32 snd_wl1;
	u32 snd_wnd;
	u32 max_window;
	u32 mss_cache;
	u32 window_clamp;
	u32 rcv_ssthresh;
	struct tcp_rack rack;
	u16 advmss;
	u8 compressed_ack;
	u32 chrono_start;
	u32 chrono_stat[3];
	u8 chrono_type: 2;
	u8 rate_app_limited: 1;
	u8 fastopen_connect: 1;
	u8 fastopen_no_cookie: 1;
	u8 is_sack_reneg: 1;
	u8 unused: 2;
	u8 nonagle: 4;
	u8 thin_lto: 1;
	u8 recvmsg_inq: 1;
	u8 repair: 1;
	u8 frto: 1;
	u8 repair_queue;
	u8 syn_data: 1;
	u8 syn_fastopen: 1;
	u8 syn_fastopen_exp: 1;
	u8 syn_fastopen_ch: 1;
	u8 syn_data_acked: 1;
	u8 save_syn: 1;
	u8 is_cwnd_limited: 1;
	u8 syn_smc: 1;
	u32 tlp_high_seq;
	u64 tcp_mstamp;
	u32 srtt_us;
	u32 mdev_us;
	u32 mdev_max_us;
	u32 rttvar_us;
	u32 rtt_seq;
	struct minmax rtt_min;
	u32 packets_out;
	u32 retrans_out;
	u32 max_packets_out;
	u32 max_packets_seq;
	u16 urg_data;
	u8 ecn_flags;
	u8 keepalive_probes;
	u32 reordering;
	u32 snd_up;
	struct tcp_options_received rx_opt;
	u32 snd_ssthresh;
	u32 snd_cwnd;
	u32 snd_cwnd_cnt;
	u32 snd_cwnd_clamp;
	u32 snd_cwnd_used;
	u32 snd_cwnd_stamp;
	u32 prior_cwnd;
	u32 prr_delivered;
	u32 prr_out;
	u32 delivered;
	u32 delivered_ce;
	u32 lost;
	u32 app_limited;
	u64 first_tx_mstamp;
	u64 delivered_mstamp;
	u32 rate_delivered;
	u32 rate_interval_us;
	u32 rcv_wnd;
	u32 write_seq;
	u32 notsent_lowat;
	u32 pushed_seq;
	u32 lost_out;
	u32 sacked_out;
	struct hrtimer pacing_timer;
	struct hrtimer compressed_ack_timer;
	struct sk_buff___89 *lost_skb_hint;
	struct sk_buff___89 *retransmit_skb_hint;
	struct rb_root out_of_order_queue;
	struct sk_buff___89 *ooo_last_skb;
	struct tcp_sack_block duplicate_sack[1];
	struct tcp_sack_block selective_acks[4];
	struct tcp_sack_block recv_sack_cache[4];
	struct sk_buff___89 *highest_sack;
	int lost_cnt_hint;
	u32 prior_ssthresh;
	u32 high_seq;
	u32 retrans_stamp;
	u32 undo_marker;
	int undo_retrans;
	u32 total_retrans;
	u32 urg_seq;
	unsigned int keepalive_time;
	unsigned int keepalive_intvl;
	int linger2;
	u8 bpf_sock_ops_cb_flags;
	struct {
		u32 rtt_us;
		u32 seq;
		u64 time;
	} rcv_rtt_est;
	struct {
		u32 space;
		u32 seq;
		u64 time;
	} rcvq_space;
	struct {
		u32 probe_seq_start;
		u32 probe_seq_end;
	} mtu_probe;
	u32 mtu_info;
	const struct tcp_sock_af_ops___5 *af_specific;
	struct tcp_md5sig_info *md5sig_info;
	struct tcp_fastopen_request___5 *fastopen_req;
	struct request_sock___52 *fastopen_rsk;
	u32 *saved_syn;
};

struct tcp_sock_af_ops___5 {
	struct tcp_md5sig_key * (*md5_lookup)(const struct sock___68 *, const struct sock___68 *);
	int (*calc_md5_hash)(char *, const struct tcp_md5sig_key *, const struct sock___68 *, const struct sk_buff___89 *);
	int (*md5_parse)(struct sock___68 *, int, char *, int);
};

struct tcp_fastopen_request___5 {
	struct tcp_fastopen_cookie cookie;
	struct msghdr___71 *data;
	size_t size;
	int copied;
};

struct ip6_flowlabel___10;

struct ipv6_fl_socklist___10 {
	struct ipv6_fl_socklist___10 *next;
	struct ip6_flowlabel___10 *fl;
	struct callback_head rcu;
};

struct ifmcaddr6___39 {
	struct in6_addr mca_addr;
	struct inet6_dev___39 *idev;
	struct ifmcaddr6___39 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___15 {
	struct in6_addr aca_addr;
	struct fib6_info___15 *aca_rt;
	struct ifacaddr6___15 *aca_next;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct ip6_ra_chain___39 {
	struct ip6_ra_chain___39 *next;
	struct sock___68 *sk;
	int sel;
	void (*destructor)(struct sock___68 *);
};

struct ip6_flowlabel___10 {
	struct ip6_flowlabel___10 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___246 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___99 *fl_net;
};

struct rtable___9 {
	struct dst_entry___68 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	__be32 rt_gateway;
	u32 rt_mtu_locked: 1;
	u32 rt_pmtu: 31;
	struct list_head rt_uncached;
	struct uncached_list *rt_uncached_list;
};

struct xfrm_replay___11 {
	void (*advance)(struct xfrm_state___11 *, __be32);
	int (*check)(struct xfrm_state___11 *, struct sk_buff___89 *, __be32);
	int (*recheck)(struct xfrm_state___11 *, struct sk_buff___89 *, __be32);
	void (*notify)(struct xfrm_state___11 *, int);
	int (*overflow)(struct xfrm_state___11 *, struct sk_buff___89 *);
};

struct xfrm_type___11 {
	char *description;
	struct module___369 *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___11 *);
	void (*destructor)(struct xfrm_state___11 *);
	int (*input)(struct xfrm_state___11 *, struct sk_buff___89 *);
	int (*output)(struct xfrm_state___11 *, struct sk_buff___89 *);
	int (*reject)(struct xfrm_state___11 *, struct sk_buff___89 *, const struct flowi *);
	int (*hdr_offset)(struct xfrm_state___11 *, struct sk_buff___89 *, u8 **);
	u32 (*get_mtu)(struct xfrm_state___11 *, int);
};

struct xfrm_state_afinfo___11;

struct xfrm_mode___11 {
	int (*input2)(struct xfrm_state___11 *, struct sk_buff___89 *);
	int (*input)(struct xfrm_state___11 *, struct sk_buff___89 *);
	int (*output2)(struct xfrm_state___11 *, struct sk_buff___89 *);
	int (*output)(struct xfrm_state___11 *, struct sk_buff___89 *);
	struct sk_buff___89 * (*gso_segment)(struct xfrm_state___11 *, struct sk_buff___89 *, netdev_features_t);
	void (*xmit)(struct xfrm_state___11 *, struct sk_buff___89 *);
	struct xfrm_state_afinfo___11 *afinfo;
	struct module___369 *owner;
	unsigned int encap;
	int flags;
};

struct xfrm_type_offload___11 {
	char *description;
	struct module___369 *owner;
	u8 proto;
	void (*encap)(struct xfrm_state___11 *, struct sk_buff___89 *);
	int (*input_tail)(struct xfrm_state___11 *, struct sk_buff___89 *);
	int (*xmit)(struct xfrm_state___11 *, struct sk_buff___89 *, netdev_features_t);
};

struct xfrm_state_afinfo___11 {
	unsigned int family;
	unsigned int proto;
	__be16 eth_proto;
	struct module___369 *owner;
	const struct xfrm_type___11 *type_map[256];
	const struct xfrm_type_offload___11 *type_offload_map[256];
	struct xfrm_mode___11 *mode_map[5];
	int (*init_flags)(struct xfrm_state___11 *);
	void (*init_tempsel)(struct xfrm_selector *, const struct flowi *);
	void (*init_temprop)(struct xfrm_state___11 *, const struct xfrm_tmpl *, const xfrm_address_t *, const xfrm_address_t *);
	int (*tmpl_sort)(struct xfrm_tmpl **, struct xfrm_tmpl **, int);
	int (*state_sort)(struct xfrm_state___11 **, struct xfrm_state___11 **, int);
	int (*output)(struct net___99 *, struct sock___68 *, struct sk_buff___89 *);
	int (*output_finish)(struct sock___68 *, struct sk_buff___89 *);
	int (*extract_input)(struct xfrm_state___11 *, struct sk_buff___89 *);
	int (*extract_output)(struct xfrm_state___11 *, struct sk_buff___89 *);
	int (*transport_finish)(struct sk_buff___89 *, int);
	void (*local_error)(struct sk_buff___89 *, u32);
};

struct ipv6_stub___11 {
	int (*ipv6_sock_mc_join)(struct sock___68 *, int, const struct in6_addr *);
	int (*ipv6_sock_mc_drop)(struct sock___68 *, int, const struct in6_addr *);
	int (*ipv6_dst_lookup)(struct net___99 *, struct sock___68 *, struct dst_entry___68 **, struct flowi6 *);
	struct fib6_table___15 * (*fib6_get_table)(struct net___99 *, u32);
	struct fib6_info___15 * (*fib6_lookup)(struct net___99 *, int, struct flowi6 *, int);
	struct fib6_info___15 * (*fib6_table_lookup)(struct net___99 *, struct fib6_table___15 *, int, struct flowi6 *, int);
	struct fib6_info___15 * (*fib6_multipath_select)(const struct net___99 *, struct fib6_info___15 *, struct flowi6 *, int, const struct sk_buff___89 *, int);
	u32 (*ip6_mtu_from_fib6)(struct fib6_info___15 *, struct in6_addr *, struct in6_addr *);
	void (*udpv6_encap_enable)();
	void (*ndisc_send_na)(struct net_device___88 *, const struct in6_addr *, const struct in6_addr *, bool, bool, bool, bool);
	struct neigh_table___68 *nd_tbl;
};

struct ipv6_bpf_stub___11 {
	int (*inet6_bind)(struct sock___68 *, struct sockaddr *, int, bool, bool);
	struct sock___68 * (*udp6_lib_lookup)(struct net___99 *, const struct in6_addr *, __be16, const struct in6_addr *, __be16, int, int, struct udp_table *, struct sk_buff___89 *);
};

struct module___370;

struct file___444;

struct kiocb___444;

struct iov_iter___211;

struct poll_table_struct___283;

struct vm_area_struct___445;

struct inode___444;

struct file_lock___444;

struct page___445;

struct pipe_inode_info___125;

struct seq_file___383;

struct file_operations___444 {
	struct module___370 *owner;
	loff_t (*llseek)(struct file___444 *, loff_t, int);
	ssize_t (*read)(struct file___444 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___444 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___444 *, struct iov_iter___211 *);
	ssize_t (*write_iter)(struct kiocb___444 *, struct iov_iter___211 *);
	int (*iopoll)(struct kiocb___444 *, bool);
	int (*iterate)(struct file___444 *, struct dir_context *);
	int (*iterate_shared)(struct file___444 *, struct dir_context *);
	__poll_t (*poll)(struct file___444 *, struct poll_table_struct___283 *);
	long int (*unlocked_ioctl)(struct file___444 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___444 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___444 *, struct vm_area_struct___445 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___444 *, struct file___444 *);
	int (*flush)(struct file___444 *, fl_owner_t);
	int (*release)(struct inode___444 *, struct file___444 *);
	int (*fsync)(struct file___444 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___444 *, int);
	int (*lock)(struct file___444 *, int, struct file_lock___444 *);
	ssize_t (*sendpage)(struct file___444 *, struct page___445 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___444 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___444 *, int, struct file_lock___444 *);
	ssize_t (*splice_write)(struct pipe_inode_info___125 *, struct file___444 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___444 *, loff_t *, struct pipe_inode_info___125 *, size_t, unsigned int);
	int (*setlease)(struct file___444 *, long int, struct file_lock___444 **, void **);
	long int (*fallocate)(struct file___444 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___383 *, struct file___444 *);
	ssize_t (*copy_file_range)(struct file___444 *, loff_t, struct file___444 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___444 *, loff_t, struct file___444 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___444 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___445 {
	u64 seqnum;
	struct vm_area_struct___445 *vmas[4];
};

struct page_frag___445 {
	struct page___445 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___445;

struct mem_cgroup___177;

struct pid___247;

struct cred___412;

struct nsproxy___339;

struct signal_struct___319;

struct bio_list___234;

struct backing_dev_info___234;

struct css_set___293;

struct vm_struct___348;

struct task_struct___446 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___446 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___445 *mm;
	struct mm_struct___445 *active_mm;
	struct vmacache___445 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___446 *real_parent;
	struct task_struct___446 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___446 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___177 *active_memcg;
	long int rh_reserved2;
	struct pid___247 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___247 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___247 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___412 *ptracer_cred;
	const struct cred___412 *real_cred;
	const struct cred___412 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___339 *nsproxy;
	struct signal_struct___319 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___446 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___234 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___234 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___293 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___125 *splice_pipe;
	struct page_frag___445 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___177 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___446 *oom_reaper_list;
	struct vm_struct___348 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___156 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___445 *pgtable_t___445;

struct address_space___444;

struct dev_pagemap___432;

struct page___445 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___444 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___445 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___445 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___445 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___432 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___177 *mem_cgroup;
};

struct pglist_data___445;

struct lruvec___445 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___445 *pgdat;
};

struct zone___445 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___445 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___445 {
	struct zone___445 *zone;
	int zone_idx;
};

struct zonelist___445 {
	struct zoneref___445 _zonerefs[25];
};

struct pglist_data___445 {
	struct zone___445 node_zones[3];
	struct zonelist___445 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___446 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___446 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___445 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___446 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___446 *owner;
};

struct secondary_data___446 {
	void *stack;
	struct task_struct___446 *task;
	long int status;
};

struct blocking_notifier_head___445 {
	struct rw_semaphore___446 rwsem;
	struct notifier_block *head;
};

struct cgroup___293;

struct cgroup_subsys___293;

struct cgroup_subsys_state___293 {
	struct cgroup___293 *cgroup;
	struct cgroup_subsys___293 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___293 *parent;
};

struct kernfs_node___439;

struct cgroup_file___293 {
	struct kernfs_node___439 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___177;

struct mem_cgroup___177 {
	struct cgroup_subsys_state___293 css;
	struct mem_cgroup_id___26 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___293 events_file;
	struct cgroup_file___293 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___446 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___177 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___247;

struct upid___247 {
	int nr;
	struct pid_namespace___247 *ns;
};

struct dentry___444;

struct user_namespace___309;

struct ucounts___309;

struct pid_namespace___247 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___446 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___247 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___444 *proc_self;
	struct dentry___444 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___309 *user_ns;
	struct ucounts___309 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___29 ns;
};

struct pid___247 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___247 numbers[1];
};

struct key___412;

struct user_namespace___309 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___309 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___29 ns;
	long unsigned int flags;
	struct key___412 *persistent_keyring_register;
	struct rw_semaphore___446 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___309 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct user_struct___412 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___412 *uid_keyring;
	struct key___412 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___432;

struct vm_area_struct___445 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___445 *vm_next;
	struct vm_area_struct___445 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___445 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___432 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___444 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___445;

struct mm_struct___445 {
	struct {
		struct vm_area_struct___445 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___444 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___446 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___445 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___446 *owner;
		struct user_namespace___309 *user_ns;
		struct file___444 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___445 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___412 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___412 *session_keyring;
	struct key___412 *process_keyring;
	struct key___412 *thread_keyring;
	struct key___412 *request_key_auth;
	void *security;
	struct user_struct___412 *user;
	struct user_namespace___309 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___100;

struct cgroup_namespace___293;

struct nsproxy___339 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___247 *pid_ns_for_children;
	struct net___100 *net_ns;
	struct cgroup_namespace___293 *cgroup_ns;
};

struct signal_struct___319 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___446 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___446 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___247 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___247 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___445 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___247 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide43;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___234;

struct bio_list___234 {
	struct bio___234 *head;
	struct bio___234 *tail;
};

struct bdi_writeback_congested___234;

struct bdi_writeback___234 {
	struct backing_dev_info___234 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___234 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___293 *memcg_css;
	struct cgroup_subsys_state___293 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___412;

struct backing_dev_info___234 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___234 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___412 *dev;
	struct device___412 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___444 *debug_dir;
	struct dentry___444 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___293 {
	struct cgroup_subsys_state___293 *subsys[13];
	refcount_t refcount;
	struct css_set___293 *dom_cset;
	struct cgroup___293 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___293 *mg_src_cgrp;
	struct cgroup___293 *mg_dst_cgrp;
	struct css_set___293 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___444;

struct pipe_buffer___125;

struct pipe_inode_info___125 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___445 *tmp_page;
	struct fasync_struct___444 *fasync_readers;
	struct fasync_struct___444 *fasync_writers;
	struct pipe_buffer___125 *bufs;
	struct user_struct___412 *user;
};

struct vm_struct___348 {
	struct vm_struct___348 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___445 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___331 {
	struct task_struct___446 task;
	long unsigned int stack[8192];
};

struct address_space_operations___444;

struct address_space___444 {
	struct inode___444 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___446 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___444 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___432)(struct vm_area_struct___445 *, long unsigned int, const struct page___445 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___432)(struct page___445 *, void *);

struct dev_pagemap___432 {
	dev_page_fault_t___432 page_fault;
	dev_page_free_t___432 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___412 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___445 {
	struct vfsmount *mnt;
	struct dentry___444 *dentry;
};

struct fown_struct___247 {
	rwlock_t lock;
	struct pid___247 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___444 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___445 f_path;
	struct inode___444 *f_inode;
	const struct file_operations___444 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___247 f_owner;
	const struct cred___412 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___444 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___432;

struct vm_operations_struct___432 {
	void (*open)(struct vm_area_struct___445 *);
	void (*close)(struct vm_area_struct___445 *);
	int (*split)(struct vm_area_struct___445 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___445 *);
	vm_fault_t (*fault)(struct vm_fault___432 *);
	vm_fault_t (*huge_fault)(struct vm_fault___432 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___432 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___445 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___432 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___432 *);
	int (*access)(struct vm_area_struct___445 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___445 *);
	int (*set_policy)(struct vm_area_struct___445 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___445 *, long unsigned int);
	struct page___445 * (*find_special_page)(struct vm_area_struct___445 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___445 {
	struct task_struct___446 *task;
	struct core_thread___445 *next;
};

struct core_state___445 {
	atomic_t nr_threads;
	struct core_thread___445 dumper;
	struct completion startup;
};

struct vm_fault___432 {
	struct vm_area_struct___445 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___445 *cow_page;
	struct mem_cgroup___177 *memcg;
	struct page___445 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___445 prealloc_pte;
};

struct crypto_async_request___34;

typedef void (*crypto_completion_t___34)(struct crypto_async_request___34 *, int);

struct crypto_tfm___34;

struct crypto_async_request___34 {
	struct list_head list;
	crypto_completion_t___34 complete;
	void *data;
	struct crypto_tfm___34 *tfm;
	u32 flags;
};

struct crypto_ablkcipher___34;

struct ablkcipher_request___34;

struct ablkcipher_tfm___34 {
	int (*setkey)(struct crypto_ablkcipher___34 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___34 *);
	int (*decrypt)(struct ablkcipher_request___34 *);
	struct crypto_ablkcipher___34 *base;
	unsigned int ivsize;
	unsigned int reqsize;
};

struct blkcipher_desc___34;

struct blkcipher_tfm___34 {
	void *iv;
	int (*setkey)(struct crypto_tfm___34 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___34 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___34 *, struct scatterlist *, struct scatterlist *, unsigned int);
};

struct cipher_tfm___34 {
	int (*cit_setkey)(struct crypto_tfm___34 *, const u8 *, unsigned int);
	void (*cit_encrypt_one)(struct crypto_tfm___34 *, u8 *, const u8 *);
	void (*cit_decrypt_one)(struct crypto_tfm___34 *, u8 *, const u8 *);
};

struct compress_tfm___34 {
	int (*cot_compress)(struct crypto_tfm___34 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*cot_decompress)(struct crypto_tfm___34 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___34;

struct crypto_tfm___34 {
	u32 crt_flags;
	union {
		struct ablkcipher_tfm___34 ablkcipher;
		struct blkcipher_tfm___34 blkcipher;
		struct cipher_tfm___34 cipher;
		struct compress_tfm___34 compress;
	} crt_u;
	void (*exit)(struct crypto_tfm___34 *);
	struct crypto_alg___34 *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct ablkcipher_request___34 {
	struct crypto_async_request___34 base;
	unsigned int nbytes;
	void *info;
	struct scatterlist *src;
	struct scatterlist *dst;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_blkcipher___34;

struct blkcipher_desc___34 {
	struct crypto_blkcipher___34 *tfm;
	void *info;
	u32 flags;
};

struct crypto_blkcipher___34 {
	struct crypto_tfm___34 base;
};

struct ablkcipher_alg___34 {
	int (*setkey)(struct crypto_ablkcipher___34 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___34 *);
	int (*decrypt)(struct ablkcipher_request___34 *);
	int (*givencrypt)(struct skcipher_givcrypt_request *);
	int (*givdecrypt)(struct skcipher_givcrypt_request *);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct crypto_ablkcipher___34 {
	struct crypto_tfm___34 base;
};

struct blkcipher_alg___34 {
	int (*setkey)(struct crypto_tfm___34 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___34 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___34 *, struct scatterlist *, struct scatterlist *, unsigned int);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct cipher_alg___34 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___34 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___34 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___34 *, u8 *, const u8 *);
};

struct compress_alg___34 {
	int (*coa_compress)(struct crypto_tfm___34 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___34 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___34 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type *cra_type;
	union {
		struct ablkcipher_alg___34 ablkcipher;
		struct blkcipher_alg___34 blkcipher;
		struct cipher_alg___34 cipher;
		struct compress_alg___34 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___34 *);
	void (*cra_exit)(struct crypto_tfm___34 *);
	void (*cra_destroy)(struct crypto_alg___34 *);
	struct module___370 *cra_module;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___431;

struct kobj_type___431;

struct kobject___432 {
	const char *name;
	struct list_head entry;
	struct kobject___432 *parent;
	struct kset___431 *kset;
	struct kobj_type___431 *ktype;
	struct kernfs_node___439 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___370 {
	struct kobject___432 kobj;
	struct module___370 *mod;
	struct kobject___432 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___370 {
	struct module___370 *mod;
	struct latch_tree_node node;
};

struct module_layout___370 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___370 mtn;
};

struct module_attribute___370;

struct kernel_param___370;

struct module___370 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___370 mkobj;
	struct module_attribute___370 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___432 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___370 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___370 core_layout;
	struct module_layout___370 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct crypto_cipher___18 {
	struct crypto_tfm___34 base;
};

struct ahash_request___5 {
	struct crypto_async_request___34 base;
	unsigned int nbytes;
	struct scatterlist *src;
	u8 *result;
	void *priv;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_ahash___4 {
	int (*init)(struct ahash_request___5 *);
	int (*update)(struct ahash_request___5 *);
	int (*final)(struct ahash_request___5 *);
	int (*finup)(struct ahash_request___5 *);
	int (*digest)(struct ahash_request___5 *);
	int (*export)(struct ahash_request___5 *, void *);
	int (*import)(struct ahash_request___5 *, const void *);
	int (*setkey)(struct crypto_ahash___4 *, const u8 *, unsigned int);
	unsigned int reqsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_tfm___34 base;
};

struct kernfs_root___438;

struct kernfs_elem_dir___438 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___438 *root;
};

struct kernfs_syscall_ops___438;

struct kernfs_root___438 {
	struct kernfs_node___439 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___438 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___438 {
	struct kernfs_node___439 *target_kn;
};

struct kernfs_ops___438;

struct kernfs_elem_attr___438 {
	const struct kernfs_ops___438 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___439 *notify_next;
};

struct kernfs_node___439 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___439 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___438 dir;
		struct kernfs_elem_symlink___438 symlink;
		struct kernfs_elem_attr___438 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___438;

struct kernfs_ops___438 {
	int (*open)(struct kernfs_open_file___438 *);
	void (*release)(struct kernfs_open_file___438 *);
	int (*seq_show)(struct seq_file___383 *, void *);
	void * (*seq_start)(struct seq_file___383 *, loff_t *);
	void * (*seq_next)(struct seq_file___383 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___383 *, void *);
	ssize_t (*read)(struct kernfs_open_file___438 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___438 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___438 *, struct vm_area_struct___445 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___438 *, struct poll_table_struct___283 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___438 {
	int (*remount_fs)(struct kernfs_root___438 *, int *, char *);
	int (*show_options)(struct seq_file___383 *, struct kernfs_root___438 *);
	int (*mkdir)(struct kernfs_node___439 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___439 *);
	int (*rename)(struct kernfs_node___439 *, struct kernfs_node___439 *, const char *);
	int (*show_path)(struct seq_file___383 *, struct kernfs_node___439 *, struct kernfs_root___438 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___383;

struct seq_file___383 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___383 *op;
	int poll_event;
	const struct file___444 *file;
	void *private;
};

struct kernfs_open_file___438 {
	struct kernfs_node___439 *kn;
	struct file___444 *file;
	struct seq_file___383 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___432 *vm_ops;
};

typedef void (*poll_queue_proc___293)(struct file___444 *, wait_queue_head_t *, struct poll_table_struct___283 *);

struct poll_table_struct___283 {
	poll_queue_proc___293 _qproc;
	__poll_t _key;
};

struct sock___69;

struct kobj_ns_type_operations___69 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___69 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___100 *net;
} possible_net_t___91;

struct proto___69;

struct sock_common___69 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___69 *skc_prot;
	possible_net_t___91 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___69 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___90;

struct sk_buff_head___89 {
	struct sk_buff___90 *next;
	struct sk_buff___90 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___69;

struct socket_wq___70;

struct xfrm_policy___12;

struct dst_entry___69;

struct socket___71;

struct net_device___89;

struct sock___69 {
	struct sock_common___69 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___89 sk_error_queue;
	struct sk_buff_head___89 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___90 *head;
		struct sk_buff___90 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___69 *sk_filter;
	union {
		struct socket_wq___70 *sk_wq;
		struct socket_wq___70 *sk_wq_raw;
	};
	struct xfrm_policy___12 *sk_policy[2];
	struct dst_entry___69 *sk_rx_dst;
	struct dst_entry___69 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___90 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___89 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___445 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___69 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___247 *sk_peer_pid;
	const struct cred___412 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___71 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___177 *sk_memcg;
	void (*sk_state_change)(struct sock___69 *);
	void (*sk_data_ready)(struct sock___69 *);
	void (*sk_write_space)(struct sock___69 *);
	void (*sk_error_report)(struct sock___69 *);
	int (*sk_backlog_rcv)(struct sock___69 *, struct sk_buff___90 *);
	struct sk_buff___90 * (*sk_validate_xmit_skb)(struct sock___69 *, struct net_device___89 *, struct sk_buff___90 *);
	void (*sk_destruct)(struct sock___69 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct bin_attribute___408;

struct attribute_group___409 {
	const char *name;
	umode_t (*is_visible)(struct kobject___432 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___432 *, struct bin_attribute___408 *, int);
	struct attribute **attrs;
	struct bin_attribute___408 **bin_attrs;
};

struct bin_attribute___408 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___444 *, struct kobject___432 *, struct bin_attribute___408 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___444 *, struct kobject___432 *, struct bin_attribute___408 *, char *, loff_t, size_t);
	int (*mmap)(struct file___444 *, struct kobject___432 *, struct bin_attribute___408 *, struct vm_area_struct___445 *);
};

struct sysfs_ops___431 {
	ssize_t (*show)(struct kobject___432 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___432 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___431;

struct kset___431 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___432 kobj;
	const struct kset_uevent_ops___431 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___431 {
	void (*release)(struct kobject___432 *);
	const struct sysfs_ops___431 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___69 * (*child_ns_type)(struct kobject___432 *);
	const void * (*namespace)(struct kobject___432 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___431 {
	int (* const filter)(struct kset___431 *, struct kobject___432 *);
	const char * (* const name)(struct kset___431 *, struct kobject___432 *);
	int (* const uevent)(struct kset___431 *, struct kobject___432 *, struct kobj_uevent_env *);
};

struct kobj_attribute___422 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___432 *, struct kobj_attribute___422 *, char *);
	ssize_t (*store)(struct kobject___432 *, struct kobj_attribute___422 *, const char *, size_t);
};

struct kernel_param_ops___370 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___370 *);
	int (*get)(char *, const struct kernel_param___370 *);
	void (*free)(void *);
};

struct kparam_array___370;

struct kernel_param___370 {
	const char *name;
	struct module___370 *mod;
	const struct kernel_param_ops___370 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___370 *arr;
	};
};

struct kparam_array___370 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___370 *ops;
	void *elem;
};

struct module_attribute___370 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___370 *, struct module_kobject___370 *, char *);
	ssize_t (*store)(struct module_attribute___370 *, struct module_kobject___370 *, const char *, size_t);
	void (*setup)(struct module___370 *, const char *);
	int (*test)(struct module___370 *);
	void (*free)(struct module___370 *);
};

struct dentry_operations___444;

struct super_block___444;

struct dentry___444 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___444 *d_parent;
	struct qstr d_name;
	struct inode___444 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___444 *d_op;
	struct super_block___444 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___444;

struct block_device___444;

struct inode___444 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___444 *i_op;
	struct super_block___444 *i_sb;
	struct address_space___444 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___446 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___234 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___444 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___444 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___125 *i_pipe;
		struct block_device___444 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___444 {
	int (*d_revalidate)(struct dentry___444 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___444 *, unsigned int);
	int (*d_hash)(const struct dentry___444 *, struct qstr *);
	int (*d_compare)(const struct dentry___444 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___444 *);
	int (*d_init)(struct dentry___444 *);
	void (*d_release)(struct dentry___444 *);
	void (*d_prune)(struct dentry___444 *);
	void (*d_iput)(struct dentry___444 *, struct inode___444 *);
	char * (*d_dname)(struct dentry___444 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___445 *);
	int (*d_manage)(const struct path___445 *, bool);
	struct dentry___444 * (*d_real)(struct dentry___444 *, const struct inode___444 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___444;

struct mem_dqinfo___444 {
	struct quota_format_type___444 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___444;

struct quota_info___444 {
	unsigned int flags;
	struct rw_semaphore___446 dqio_sem;
	struct inode___444 *files[3];
	struct mem_dqinfo___444 info[3];
	const struct quota_format_ops___444 *ops[3];
};

struct rcuwait___444 {
	struct task_struct___446 *task;
};

struct percpu_rw_semaphore___444 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___446 rw_sem;
	struct rcuwait___444 writer;
	int readers_block;
};

struct sb_writers___444 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___444 rw_sem[3];
};

struct shrink_control___177;

struct shrinker___177 {
	long unsigned int (*count_objects)(struct shrinker___177 *, struct shrink_control___177 *);
	long unsigned int (*scan_objects)(struct shrinker___177 *, struct shrink_control___177 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___444;

struct super_operations___444;

struct dquot_operations___444;

struct quotactl_ops___444;

struct super_block___444 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___444 *s_type;
	const struct super_operations___444 *s_op;
	const struct dquot_operations___444 *dq_op;
	const struct quotactl_ops___444 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___444 *s_root;
	struct rw_semaphore___446 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___444 *s_bdev;
	struct backing_dev_info___234 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___444 s_dquot;
	struct sb_writers___444 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___444 *s_d_op;
	int cleancache_poolid;
	struct shrinker___177 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___309 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___177 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___177 *memcg;
};

struct kiocb___444 {
	struct file___444 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___444 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___444 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___444 *ia_file;
};

struct dquot___444 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___444 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___444 {
	int qf_fmt_id;
	const struct quota_format_ops___444 *qf_ops;
	struct module___370 *qf_owner;
	struct quota_format_type___444 *qf_next;
};

struct quota_format_ops___444 {
	int (*check_quota_file)(struct super_block___444 *, int);
	int (*read_file_info)(struct super_block___444 *, int);
	int (*write_file_info)(struct super_block___444 *, int);
	int (*free_file_info)(struct super_block___444 *, int);
	int (*read_dqblk)(struct dquot___444 *);
	int (*commit_dqblk)(struct dquot___444 *);
	int (*release_dqblk)(struct dquot___444 *);
	int (*get_next_id)(struct super_block___444 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___444 {
	int (*write_dquot)(struct dquot___444 *);
	struct dquot___444 * (*alloc_dquot)(struct super_block___444 *, int);
	void (*destroy_dquot)(struct dquot___444 *);
	int (*acquire_dquot)(struct dquot___444 *);
	int (*release_dquot)(struct dquot___444 *);
	int (*mark_dirty)(struct dquot___444 *);
	int (*write_info)(struct super_block___444 *, int);
	qsize_t * (*get_reserved_space)(struct inode___444 *);
	int (*get_projid)(struct inode___444 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___444 *, qsize_t *);
	int (*get_next_id)(struct super_block___444 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___444 {
	int (*quota_on)(struct super_block___444 *, int, int, const struct path___445 *);
	int (*quota_off)(struct super_block___444 *, int);
	int (*quota_enable)(struct super_block___444 *, unsigned int);
	int (*quota_disable)(struct super_block___444 *, unsigned int);
	int (*quota_sync)(struct super_block___444 *, int);
	int (*set_info)(struct super_block___444 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___444 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___444 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___444 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___444 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___444 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___197;

struct swap_info_struct___93;

struct address_space_operations___444 {
	int (*writepage)(struct page___445 *, struct writeback_control___197 *);
	int (*readpage)(struct file___444 *, struct page___445 *);
	int (*writepages)(struct address_space___444 *, struct writeback_control___197 *);
	int (*set_page_dirty)(struct page___445 *);
	int (*readpages)(struct file___444 *, struct address_space___444 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___444 *, struct address_space___444 *, loff_t, unsigned int, unsigned int, struct page___445 **, void **);
	int (*write_end)(struct file___444 *, struct address_space___444 *, loff_t, unsigned int, unsigned int, struct page___445 *, void *);
	sector_t (*bmap)(struct address_space___444 *, sector_t);
	void (*invalidatepage)(struct page___445 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___445 *, gfp_t);
	void (*freepage)(struct page___445 *);
	ssize_t (*direct_IO)(struct kiocb___444 *, struct iov_iter___211 *);
	int (*migratepage)(struct address_space___444 *, struct page___445 *, struct page___445 *, enum migrate_mode);
	bool (*isolate_page)(struct page___445 *, isolate_mode_t);
	void (*putback_page)(struct page___445 *);
	int (*launder_page)(struct page___445 *);
	int (*is_partially_uptodate)(struct page___445 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___445 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___444 *, struct page___445 *);
	int (*swap_activate)(struct swap_info_struct___93 *, struct file___444 *, sector_t *);
	void (*swap_deactivate)(struct file___444 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___197 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___234 *wb;
	struct inode___444 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___236;

struct iov_iter___211 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___236 *bvec;
		struct pipe_inode_info___125 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct swap_info_struct___93 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___444 *bdev;
	struct file___444 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___444 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___444 *bd_inode;
	struct super_block___444 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___444 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___234 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___444 {
	struct dentry___444 * (*lookup)(struct inode___444 *, struct dentry___444 *, unsigned int);
	const char * (*get_link)(struct dentry___444 *, struct inode___444 *, struct delayed_call *);
	int (*permission)(struct inode___444 *, int);
	struct posix_acl * (*get_acl)(struct inode___444 *, int);
	int (*readlink)(struct dentry___444 *, char *, int);
	int (*create)(struct inode___444 *, struct dentry___444 *, umode_t, bool);
	int (*link)(struct dentry___444 *, struct inode___444 *, struct dentry___444 *);
	int (*unlink)(struct inode___444 *, struct dentry___444 *);
	int (*symlink)(struct inode___444 *, struct dentry___444 *, const char *);
	int (*mkdir)(struct inode___444 *, struct dentry___444 *, umode_t);
	int (*rmdir)(struct inode___444 *, struct dentry___444 *);
	int (*mknod)(struct inode___444 *, struct dentry___444 *, umode_t, dev_t);
	int (*rename)(struct inode___444 *, struct dentry___444 *, struct inode___444 *, struct dentry___444 *, unsigned int);
	int (*setattr)(struct dentry___444 *, struct iattr___444 *);
	int (*getattr)(const struct path___445 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___444 *, char *, size_t);
	int (*fiemap)(struct inode___444 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___444 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___444 *, struct dentry___444 *, struct file___444 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___444 *, struct dentry___444 *, umode_t);
	int (*set_acl)(struct inode___444 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___444 {
	void (*fl_copy_lock)(struct file_lock___444 *, struct file_lock___444 *);
	void (*fl_release_private)(struct file_lock___444 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___444;

struct file_lock___444 {
	struct file_lock___444 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___444 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___444 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___444 *fl_ops;
	const struct lock_manager_operations___444 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___444 {
	int (*lm_compare_owner)(struct file_lock___444 *, struct file_lock___444 *);
	long unsigned int (*lm_owner_key)(struct file_lock___444 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___444 *);
	int (*lm_grant)(struct file_lock___444 *, int);
	bool (*lm_break)(struct file_lock___444 *);
	int (*lm_change)(struct file_lock___444 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___444 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___444 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___444 *fa_next;
	struct file___444 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___444 {
	const char *name;
	int fs_flags;
	struct dentry___444 * (*mount)(struct file_system_type___444 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___444 *);
	struct module___370 *owner;
	struct file_system_type___444 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___444 {
	struct inode___444 * (*alloc_inode)(struct super_block___444 *);
	void (*destroy_inode)(struct inode___444 *);
	void (*dirty_inode)(struct inode___444 *, int);
	int (*write_inode)(struct inode___444 *, struct writeback_control___197 *);
	int (*drop_inode)(struct inode___444 *);
	void (*evict_inode)(struct inode___444 *);
	void (*put_super)(struct super_block___444 *);
	int (*sync_fs)(struct super_block___444 *, int);
	int (*freeze_super)(struct super_block___444 *);
	int (*freeze_fs)(struct super_block___444 *);
	int (*thaw_super)(struct super_block___444 *);
	int (*unfreeze_fs)(struct super_block___444 *);
	int (*statfs)(struct dentry___444 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___444 *, int *, char *);
	void (*umount_begin)(struct super_block___444 *);
	int (*show_options)(struct seq_file___383 *, struct dentry___444 *);
	int (*show_devname)(struct seq_file___383 *, struct dentry___444 *);
	int (*show_path)(struct seq_file___383 *, struct dentry___444 *);
	int (*show_stats)(struct seq_file___383 *, struct dentry___444 *);
	ssize_t (*quota_read)(struct super_block___444 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___444 *, int, const char *, size_t, loff_t);
	struct dquot___444 ** (*get_dquots)(struct inode___444 *);
	int (*bdev_try_to_free_page)(struct super_block___444 *, struct page___445 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___444 *, struct shrink_control___177 *);
	long int (*free_cached_objects)(struct super_block___444 *, struct shrink_control___177 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___234(struct bio___234 *);

struct bio_vec___236 {
	struct page___445 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___234;

struct bio_set___234;

struct bio___234 {
	struct bio___234 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___234 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___234 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___236 *bi_io_vec;
	struct bio_set___234 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___236 bi_inline_vecs[0];
};

typedef struct poll_table_struct___283 poll_table___43;

struct tcpvegas_info {
	__u32 tcpv_enabled;
	__u32 tcpv_rttcnt;
	__u32 tcpv_rtt;
	__u32 tcpv_minrtt;
};

struct tcp_dctcp_info {
	__u16 dctcp_enabled;
	__u16 dctcp_ce_state;
	__u32 dctcp_alpha;
	__u32 dctcp_ab_ecn;
	__u32 dctcp_ab_tot;
};

struct tcp_bbr_info {
	__u32 bbr_bw_lo;
	__u32 bbr_bw_hi;
	__u32 bbr_min_rtt;
	__u32 bbr_pacing_gain;
	__u32 bbr_cwnd_gain;
};

union tcp_cc_info___2 {
	struct tcpvegas_info vegas;
	struct tcp_dctcp_info dctcp;
	struct tcp_bbr_info bbr;
};

struct sec_path___12;

struct nf_bridge_info___89;

struct sk_buff___90 {
	union {
		struct {
			struct sk_buff___90 *next;
			struct sk_buff___90 *prev;
			union {
				struct net_device___89 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___69 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___90 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path___12 *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___89 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct netlink_callback___91 {
	struct sk_buff___90 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___91 *);
	int (*dump)(struct sk_buff___90 *, struct netlink_callback___91 *);
	int (*done)(struct netlink_callback___91 *);
	void *data;
	struct module___370 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct msghdr___72 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___211 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___444 *msg_iocb;
};

struct socket_wq___70 {
	wait_queue_head_t wait;
	struct fasync_struct___444 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___70;

struct socket___71 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___70 *wq;
	struct file___444 *file;
	struct sock___69 *sk;
	const struct proto_ops___70 *ops;
};

typedef int (*sk_read_actor_t___69)(read_descriptor_t *, struct sk_buff___90 *, unsigned int, size_t);

struct proto_ops___70 {
	int family;
	struct module___370 *owner;
	int (*release)(struct socket___71 *);
	int (*bind)(struct socket___71 *, struct sockaddr *, int);
	int (*connect)(struct socket___71 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___71 *, struct socket___71 *);
	int (*accept)(struct socket___71 *, struct socket___71 *, int, bool);
	int (*getname)(struct socket___71 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___444 *, struct socket___71 *, struct poll_table_struct___283 *);
	int (*ioctl)(struct socket___71 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___71 *, int);
	int (*shutdown)(struct socket___71 *, int);
	int (*setsockopt)(struct socket___71 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___71 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___71 *, struct msghdr___72 *, size_t);
	int (*recvmsg)(struct socket___71 *, struct msghdr___72 *, size_t, int);
	int (*mmap)(struct file___444 *, struct socket___71 *, struct vm_area_struct___445 *);
	ssize_t (*sendpage)(struct socket___71 *, struct page___445 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___71 *, loff_t *, struct pipe_inode_info___125 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___69 *, int);
	int (*peek_len)(struct socket___71 *);
	int (*read_sock)(struct sock___69 *, read_descriptor_t *, sk_read_actor_t___69);
	int (*sendpage_locked)(struct sock___69 *, struct page___445 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___69 *, struct msghdr___72 *, size_t);
	int (*set_rcvlowat)(struct sock___69 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct inet_frags___89;

struct netns_frags___89 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___89 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ip_ra_chain___35;

struct fib_rules_ops___69;

struct tcp_congestion_ops___15;

struct tcp_fastopen_context___15;

struct fib_notifier_ops___70;

struct netns_ipv4___89 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___35 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___69 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___69 *fibnl;
	struct sock___69 **icmp_sk;
	struct sock___69 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___69 **tcp_sk;
	struct netns_frags___89 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops___15 *tcp_congestion_control;
	struct tcp_fastopen_context___15 *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___69 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___70 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___70 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___69;

struct dst_ops___100 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___100 *);
	struct dst_entry___69 * (*check)(struct dst_entry___69 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___69 *);
	unsigned int (*mtu)(const struct dst_entry___69 *);
	u32 * (*cow_metrics)(struct dst_entry___69 *, long unsigned int);
	void (*destroy)(struct dst_entry___69 *);
	void (*ifdown)(struct dst_entry___69 *, struct net_device___89 *, int);
	struct dst_entry___69 * (*negative_advice)(struct dst_entry___69 *);
	void (*link_failure)(struct sk_buff___90 *);
	void (*update_pmtu)(struct dst_entry___69 *, struct sock___69 *, struct sk_buff___90 *, u32);
	void (*redirect)(struct dst_entry___69 *, struct sock___69 *, struct sk_buff___90 *);
	int (*local_out)(struct net___100 *, struct sock___69 *, struct sk_buff___90 *);
	struct neighbour___69 * (*neigh_lookup)(const struct dst_entry___69 *, struct sk_buff___90 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___69 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_info___16;

struct rt6_info___16;

struct fib6_table___16;

struct netns_ipv6___100 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___89 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info___16 *fib6_null_entry;
	struct rt6_info___16 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___16 *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___100 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info___16 *ip6_prohibit_entry;
	struct rt6_info___16 *ip6_blk_hole_entry;
	struct fib6_table___16 *fib6_local_tbl;
	struct fib_rules_ops___69 *fib6_rules_ops;
	struct sock___69 **icmp_sk;
	struct sock___69 *ndisc_sk;
	struct sock___69 *tcp_sk;
	struct sock___69 *igmp_sk;
	struct sock___69 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___69 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___70 *notifier_ops;
	struct fib_notifier_ops___70 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___70 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___69 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___89 {
	struct netns_frags___89 frags;
};

struct netns_xfrm___100 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___69 *nlsk;
	struct sock___69 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___100 xfrm4_dst_ops;
	struct dst_ops___100 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___79;

struct net___100 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___309 *user_ns;
	struct ucounts___309 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___29 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___69 *rtnl;
	struct sock___69 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___89 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___89 ipv4;
	struct netns_ipv6___100 ipv6;
	struct netns_sctp___70 sctp;
	struct netns_nf___12 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___89 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___69 *nfnl;
	struct sock___69 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___100 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___69 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___79 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___412 {
	int (*prepare)(struct device___412 *);
	void (*complete)(struct device___412 *);
	int (*suspend)(struct device___412 *);
	int (*resume)(struct device___412 *);
	int (*freeze)(struct device___412 *);
	int (*thaw)(struct device___412 *);
	int (*poweroff)(struct device___412 *);
	int (*restore)(struct device___412 *);
	int (*suspend_late)(struct device___412 *);
	int (*resume_early)(struct device___412 *);
	int (*freeze_late)(struct device___412 *);
	int (*thaw_early)(struct device___412 *);
	int (*poweroff_late)(struct device___412 *);
	int (*restore_early)(struct device___412 *);
	int (*suspend_noirq)(struct device___412 *);
	int (*resume_noirq)(struct device___412 *);
	int (*freeze_noirq)(struct device___412 *);
	int (*thaw_noirq)(struct device___412 *);
	int (*poweroff_noirq)(struct device___412 *);
	int (*restore_noirq)(struct device___412 *);
	int (*runtime_suspend)(struct device___412 *);
	int (*runtime_resume)(struct device___412 *);
	int (*runtime_idle)(struct device___412 *);
};

struct dev_pm_info___412 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___412 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___412;

struct bus_type___412;

struct device_driver___412;

struct dev_pm_domain___412;

struct dma_map_ops___184;

struct fwnode_handle___332;

struct class___412;

struct device___412 {
	struct device___412 *parent;
	struct device_private *p;
	struct kobject___432 kobj;
	const char *init_name;
	const struct device_type___412 *type;
	struct mutex mutex;
	struct bus_type___412 *bus;
	struct device_driver___412 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___412 power;
	struct dev_pm_domain___412 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___184 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___332 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___412 *class;
	const struct attribute_group___409 **groups;
	void (*release)(struct device___412 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___412 {
	struct dev_pm_ops___412 ops;
	void (*detach)(struct device___412 *, bool);
	int (*activate)(struct device___412 *);
	void (*sync)(struct device___412 *);
	void (*dismiss)(struct device___412 *);
};

struct bus_type___412 {
	const char *name;
	const char *dev_name;
	struct device___412 *dev_root;
	const struct attribute_group___409 **bus_groups;
	const struct attribute_group___409 **dev_groups;
	const struct attribute_group___409 **drv_groups;
	int (*match)(struct device___412 *, struct device_driver___412 *);
	int (*uevent)(struct device___412 *, struct kobj_uevent_env *);
	int (*probe)(struct device___412 *);
	int (*remove)(struct device___412 *);
	void (*shutdown)(struct device___412 *);
	int (*online)(struct device___412 *);
	int (*offline)(struct device___412 *);
	int (*suspend)(struct device___412 *, pm_message_t);
	int (*resume)(struct device___412 *);
	int (*num_vf)(struct device___412 *);
	int (*dma_configure)(struct device___412 *);
	const struct dev_pm_ops___412 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___412 {
	const char *name;
	struct bus_type___412 *bus;
	struct module___370 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___412 *);
	int (*remove)(struct device___412 *);
	void (*shutdown)(struct device___412 *);
	int (*suspend)(struct device___412 *, pm_message_t);
	int (*resume)(struct device___412 *);
	const struct attribute_group___409 **groups;
	const struct dev_pm_ops___412 *pm;
	void (*coredump)(struct device___412 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___412 {
	const char *name;
	const struct attribute_group___409 **groups;
	int (*uevent)(struct device___412 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___412 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___412 *);
	const struct dev_pm_ops___412 *pm;
};

struct class___412 {
	const char *name;
	struct module___370 *owner;
	const struct attribute_group___409 **class_groups;
	const struct attribute_group___409 **dev_groups;
	struct kobject___432 *dev_kobj;
	int (*dev_uevent)(struct device___412 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___412 *, umode_t *);
	void (*class_release)(struct class___412 *);
	void (*dev_release)(struct device___412 *);
	int (*shutdown_pre)(struct device___412 *);
	const struct kobj_ns_type_operations___69 *ns_type;
	const void * (*namespace)(struct device___412 *);
	const struct dev_pm_ops___412 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___184 {
	void * (*alloc)(struct device___412 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___412 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___412 *, struct vm_area_struct___445 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___412 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___412 *, struct page___445 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___412 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___412 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___412 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___412 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___412 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___412 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___412 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___412 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___412 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___412 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___412 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___412 *, u64);
	u64 (*get_required_mask)(struct device___412 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___332;

struct fwnode_handle___332 {
	struct fwnode_handle___332 *secondary;
	const struct fwnode_operations___332 *ops;
};

typedef void compound_page_dtor___432(struct page___445 *);

struct fwnode_reference_args___332;

struct fwnode_endpoint___332;

struct fwnode_operations___332 {
	struct fwnode_handle___332 * (*get)(struct fwnode_handle___332 *);
	void (*put)(struct fwnode_handle___332 *);
	bool (*device_is_available)(const struct fwnode_handle___332 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___332 *, const struct device___412 *);
	bool (*property_present)(const struct fwnode_handle___332 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___332 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___332 *, const char *, const char **, size_t);
	struct fwnode_handle___332 * (*get_parent)(const struct fwnode_handle___332 *);
	struct fwnode_handle___332 * (*get_next_child_node)(const struct fwnode_handle___332 *, struct fwnode_handle___332 *);
	struct fwnode_handle___332 * (*get_named_child_node)(const struct fwnode_handle___332 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___332 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___332 *);
	struct fwnode_handle___332 * (*graph_get_next_endpoint)(const struct fwnode_handle___332 *, struct fwnode_handle___332 *);
	struct fwnode_handle___332 * (*graph_get_remote_endpoint)(const struct fwnode_handle___332 *);
	struct fwnode_handle___332 * (*graph_get_port_parent)(struct fwnode_handle___332 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___332 *, struct fwnode_endpoint___332 *);
};

struct fwnode_endpoint___332 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___332 *local_fwnode;
};

struct fwnode_reference_args___332 {
	struct fwnode_handle___332 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___125;

struct pipe_buffer___125 {
	struct page___445 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___125 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___125 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___125 *, struct pipe_buffer___125 *);
	void (*release)(struct pipe_inode_info___125 *, struct pipe_buffer___125 *);
	int (*steal)(struct pipe_inode_info___125 *, struct pipe_buffer___125 *);
	union {
		bool (*get)(struct pipe_inode_info___125 *, struct pipe_buffer___125 *);
		struct {
			void (*get)(struct pipe_inode_info___125 *, struct pipe_buffer___125 *);
		} __UNIQUE_ID_rh_kabi_hide21;
		union {		};
	};
};

struct nf_bridge_info___89 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___89 = 0,
		BRNF_PROTO_8021Q___89 = 1,
		BRNF_PROTO_PPPOE___89 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___89 *physindev;
	struct net_device___89 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___89(struct sk_buff___90 **);

struct net_device_ops___89;

struct ethtool_ops___89;

struct l3mdev_ops___69;

struct ndisc_ops___40;

struct xfrmdev_ops___89;

struct tlsdev_ops___89;

struct header_ops___89;

struct inet6_dev___40;

struct netdev_rx_queue___89;

struct mini_Qdisc___81;

struct netdev_queue___89;

struct Qdisc___81;

struct rtnl_link_ops___81;

struct dcbnl_rtnl_ops___89;

struct net_device___89 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___89 *netdev_ops;
	const struct ethtool_ops___89 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___69 *l3mdev_ops;
	const struct ndisc_ops___40 *ndisc_ops;
	const struct xfrmdev_ops___89 *xfrmdev_ops;
	const struct tlsdev_ops___89 *tlsdev_ops;
	const struct header_ops___89 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___431 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___40 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___89 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___79 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___89 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___81 *miniq_ingress;
	struct netdev_queue___89 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___89 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___81 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___81 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___89 = 0,
		NETREG_REGISTERED___89 = 1,
		NETREG_UNREGISTERING___89 = 2,
		NETREG_UNREGISTERED___89 = 3,
		NETREG_RELEASED___89 = 4,
		NETREG_DUMMY___89 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___89 = 0,
		RTNL_LINK_INITIALIZING___89 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___89 *);
	struct netpoll_info *npinfo;
	possible_net_t___91 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___412 dev;
	const struct attribute_group___409 *sysfs_groups[4];
	const struct attribute_group___409 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___81 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___89 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide50;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct skb_frag_struct___19 {
	struct {
		struct page___445 *p;
	} page;
	__u32 page_offset;
	__u32 size;
};

typedef struct skb_frag_struct___19 skb_frag_t___19;

struct mmpin___5 {
	struct user_struct___412 *user;
	unsigned int num_pg;
};

struct ubuf_info___5 {
	void (*callback)(struct ubuf_info___5 *, bool);
	union {
		struct {
			long unsigned int desc;
			void *ctx;
		};
		struct {
			u32 id;
			u16 len;
			u16 zerocopy: 1;
			u32 bytelen;
		};
	};
	refcount_t refcnt;
	struct mmpin___5 mmp;
};

struct skb_shared_info___19 {
	__u8 __unused;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___90 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___19 frags[16];
};

struct xfrm_state___12;

struct sec_path___12 {
	refcount_t refcnt;
	int len;
	int olen;
	struct xfrm_state___12 *xvec[6];
	struct xfrm_offload ovec[1];
};

typedef int (*key_restrict_link_func_t___413)(struct key___412 *, const struct key_type *, const union key_payload *, struct key___412 *);

struct key_restriction___412;

struct key___412 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___446 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___412 *restrict_link;
};

struct key_restriction___412 {
	key_restrict_link_func_t___413 check;
	struct key___412 *key;
	struct key_type *keytype;
};

struct seq_operations___383 {
	void * (*start)(struct seq_file___383 *, loff_t *);
	void (*stop)(struct seq_file___383 *, void *);
	void * (*next)(struct seq_file___383 *, void *, loff_t *);
	int (*show)(struct seq_file___383 *, void *);
};

struct cgroup_namespace___293 {
	refcount_t count;
	struct ns_common___29 ns;
	struct user_namespace___309 *user_ns;
	struct ucounts___309 *ucounts;
	struct css_set___293 *root_cset;
};

struct ucounts___309 {
	struct hlist_node node;
	struct user_namespace___309 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

enum {
	BPF_TCP_ESTABLISHED = 1,
	BPF_TCP_SYN_SENT = 2,
	BPF_TCP_SYN_RECV = 3,
	BPF_TCP_FIN_WAIT1 = 4,
	BPF_TCP_FIN_WAIT2 = 5,
	BPF_TCP_TIME_WAIT = 6,
	BPF_TCP_CLOSE = 7,
	BPF_TCP_CLOSE_WAIT = 8,
	BPF_TCP_LAST_ACK = 9,
	BPF_TCP_LISTEN = 10,
	BPF_TCP_CLOSING = 11,
	BPF_TCP_NEW_SYN_RECV = 12,
	BPF_TCP_MAX_STATES = 13,
};

struct bpf_map___294;

struct bpf_map_ops___293 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___294 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___294 *, struct file___444 *);
	void (*map_free)(struct bpf_map___294 *);
	int (*map_get_next_key)(struct bpf_map___294 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___294 *);
	void * (*map_lookup_elem)(struct bpf_map___294 *, void *);
	int (*map_update_elem)(struct bpf_map___294 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___294 *, void *);
	int (*map_push_elem)(struct bpf_map___294 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___294 *, void *);
	int (*map_peek_elem)(struct bpf_map___294 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___294 *, struct file___444 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___294 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___294 *, void *, struct seq_file___383 *);
	int (*map_check_btf)(const struct bpf_map___294 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___294 {
	const struct bpf_map_ops___293 *ops;
	struct bpf_map___294 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___412 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___89;

struct bpf_map_dev_ops___89 {
	int (*map_get_next_key)(struct bpf_offloaded_map___89 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___89 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___89 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___89 *, void *);
};

struct bpf_offloaded_map___89 {
	struct bpf_map___294 map;
	struct net_device___89 *netdev;
	const struct bpf_map_dev_ops___89 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___79 {
	int (*test_run)(struct bpf_prog___79 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_aux___82;

struct bpf_prog___79 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___82 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

struct bpf_verifier_ops___79 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___79 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___79 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___79 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___79 *, u32 *);
};

struct bpf_prog_offload_ops___79 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___79 *);
	int (*translate)(struct bpf_prog___79 *);
	void (*destroy)(struct bpf_prog___79 *);
};

struct bpf_prog_offload___79 {
	struct bpf_prog___79 *prog;
	struct net_device___89 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___79 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___82 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___79 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___79 *ops;
	struct bpf_map___294 **used_maps;
	struct bpf_prog___79 *prog;
	struct user_struct___412 *user;
	u64 load_time;
	struct bpf_map___294 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___79 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___79 {
	struct bpf_prog___79 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___79 {
	struct callback_head rcu;
	struct bpf_prog_array_item___79 items[0];
};

struct cgroup_bpf___79 {
	struct bpf_prog_array___79 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___79 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___294;

typedef void (*kthread_work_func_t___294)(struct kthread_work___294 *);

struct kthread_worker___294;

struct kthread_work___294 {
	struct list_head node;
	kthread_work_func_t___294 func;
	struct kthread_worker___294 *worker;
	int canceling;
};

struct kthread_worker___294 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___446 *task;
	struct kthread_work___294 *current_work;
};

struct kthread_delayed_work___293 {
	struct kthread_work___294 work;
	struct timer_list timer;
};

struct psi_group___293 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___294 *poll_kworker;
	struct kthread_delayed_work___293 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___293;

struct cgroup_rstat_cpu___293;

struct cgroup___293 {
	struct cgroup_subsys_state___293 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___439 *kn;
	struct cgroup_file___293 procs_file;
	struct cgroup_file___293 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___293 *subsys[13];
	struct cgroup_root___293 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___293 *dom_cgrp;
	struct cgroup_rstat_cpu___293 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___79 bpf;
	atomic_t congestion_count;
	struct cgroup___293 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___293 psi;
	int ancestor_ids[0];
};

struct cftype___293;

struct cgroup_subsys___293 {
	struct cgroup_subsys_state___293 * (*css_alloc)(struct cgroup_subsys_state___293 *);
	int (*css_online)(struct cgroup_subsys_state___293 *);
	void (*css_offline)(struct cgroup_subsys_state___293 *);
	void (*css_released)(struct cgroup_subsys_state___293 *);
	void (*css_free)(struct cgroup_subsys_state___293 *);
	void (*css_reset)(struct cgroup_subsys_state___293 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___293 *, int);
	int (*css_extra_stat_show)(struct seq_file___383 *, struct cgroup_subsys_state___293 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___446 *);
	void (*cancel_fork)(struct task_struct___446 *);
	void (*fork)(struct task_struct___446 *);
	void (*exit)(struct task_struct___446 *);
	void (*free)(struct task_struct___446 *);
	void (*bind)(struct cgroup_subsys_state___293 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___293 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___293 *dfl_cftypes;
	struct cftype___293 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___293 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___293 *updated_children;
	struct cgroup___293 *updated_next;
};

struct cgroup_root___293 {
	struct kernfs_root___438 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___293 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___293 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___293 *ss;
	struct list_head node;
	struct kernfs_ops___438 *kf_ops;
	int (*open)(struct kernfs_open_file___438 *);
	void (*release)(struct kernfs_open_file___438 *);
	u64 (*read_u64)(struct cgroup_subsys_state___293 *, struct cftype___293 *);
	s64 (*read_s64)(struct cgroup_subsys_state___293 *, struct cftype___293 *);
	int (*seq_show)(struct seq_file___383 *, void *);
	void * (*seq_start)(struct seq_file___383 *, loff_t *);
	void * (*seq_next)(struct seq_file___383 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___383 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___293 *, struct cftype___293 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___293 *, struct cftype___293 *, s64);
	ssize_t (*write)(struct kernfs_open_file___438 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___438 *, struct poll_table_struct___283 *);
};

struct bdi_writeback_congested___234 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___234 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___234 {
	struct bio___234 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___236 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___236 bip_inline_vecs[0];
};

struct bio_set___234 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___234 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___177 {
	struct mem_cgroup___177 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___177 {
	struct lruvec___445 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___177 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___177 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct node___227 {
	struct device___412 dev;
};

struct ethtool_ops___89 {
	int (*get_settings)(struct net_device___89 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___89 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___89 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___89 *);
	void (*get_regs)(struct net_device___89 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___89 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___89 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___89 *);
	void (*set_msglevel)(struct net_device___89 *, u32);
	int (*nway_reset)(struct net_device___89 *);
	u32 (*get_link)(struct net_device___89 *);
	int (*get_eeprom_len)(struct net_device___89 *);
	int (*get_eeprom)(struct net_device___89 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___89 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___89 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___89 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___89 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___89 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___89 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___89 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___89 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___89 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___89 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___89 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___89 *);
	void (*complete)(struct net_device___89 *);
	u32 (*get_priv_flags)(struct net_device___89 *);
	int (*set_priv_flags)(struct net_device___89 *, u32);
	int (*get_sset_count)(struct net_device___89 *, int);
	int (*get_rxnfc)(struct net_device___89 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___89 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___89 *, struct ethtool_flash *);
	int (*reset)(struct net_device___89 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___89 *);
	u32 (*get_rxfh_indir_size)(struct net_device___89 *);
	int (*get_rxfh)(struct net_device___89 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___89 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___89 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___89 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___89 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___89 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___89 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___89 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___89 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___89 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___89 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___89 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___89 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___89 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___89 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___89 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___89 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___89 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___89 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___89 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide39;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___89 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___89 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide40;
		union {		};
	};
	int (*get_fecparam)(struct net_device___89 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___89 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___89 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___89 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide41;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___89 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide42;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___89;

struct inet_frags___89 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___89 *, const void *);
	void (*destructor)(struct inet_frag_queue___89 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___89 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___90 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___90 *fragments_tail;
	struct sk_buff___90 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___89 *net;
	struct callback_head rcu;
};

struct ip_ra_chain___35 {
	struct ip_ra_chain___35 *next;
	struct sock___69 *sk;
	union {
		void (*destructor)(struct sock___69 *);
		struct sock___69 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___69;

struct fib_lookup_arg___69;

struct fib_rules_ops___69 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___69 *, struct flowi *, int, struct fib_lookup_arg___69 *);
	bool (*suppress)(struct fib_rule___69 *, struct fib_lookup_arg___69 *);
	int (*match)(struct fib_rule___69 *, struct flowi *, int);
	int (*configure)(struct fib_rule___69 *, struct sk_buff___90 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___69 *);
	int (*compare)(struct fib_rule___69 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___69 *, struct sk_buff___90 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___69 *);
	void (*flush_cache)(struct fib_rules_ops___69 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___370 *owner;
	struct net___100 *fro_net;
	struct callback_head rcu;
};

struct tcp_congestion_ops___15 {
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___69 *);
	void (*release)(struct sock___69 *);
	u32 (*ssthresh)(struct sock___69 *);
	void (*cong_avoid)(struct sock___69 *, u32, u32);
	void (*set_state)(struct sock___69 *, u8);
	void (*cwnd_event)(struct sock___69 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___69 *, u32);
	u32 (*undo_cwnd)(struct sock___69 *);
	void (*pkts_acked)(struct sock___69 *, const struct ack_sample *);
	u32 (*min_tso_segs)(struct sock___69 *);
	u32 (*sndbuf_expand)(struct sock___69 *);
	void (*cong_control)(struct sock___69 *, const struct rate_sample *);
	size_t (*get_info)(struct sock___69 *, u32, int *, union tcp_cc_info___2 *);
	char name[16];
	struct module___370 *owner;
};

struct tcp_fastopen_context___15 {
	struct crypto_cipher___18 *tfm;
	__u8 key[16];
	struct callback_head rcu;
};

struct fib_notifier_ops___70 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___100 *);
	int (*fib_dump)(struct net___100 *, struct notifier_block *);
	struct module___370 *owner;
	struct callback_head rcu;
};

struct dst_entry___69 {
	struct net_device___89 *dev;
	struct dst_ops___100 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state___12 *xfrm;
	int (*input)(struct sk_buff___90 *);
	int (*output)(struct net___100 *, struct sock___69 *, struct sk_buff___90 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___69;

struct neigh_parms___69;

struct neigh_ops___69;

struct neighbour___69 {
	struct neighbour___69 *next;
	struct neigh_table___69 *tbl;
	struct neigh_parms___69 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___89 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___69 *, struct sk_buff___90 *);
	const struct neigh_ops___69 *ops;
	struct callback_head rcu;
	struct net_device___89 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct fib6_nh___16 {
	struct in6_addr nh_gw;
	struct net_device___89 *nh_dev;
	struct lwtunnel_state *nh_lwtstate;
	unsigned int nh_flags;
	atomic_t nh_upper_bound;
	int nh_weight;
};

struct fib6_node___16;

struct fib6_info___16 {
	struct fib6_table___16 *fib6_table;
	struct fib6_info___16 *fib6_next;
	struct fib6_node___16 *fib6_node;
	struct list_head fib6_siblings;
	unsigned int fib6_nsiblings;
	atomic_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	struct rt6_info___16 **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
	long unsigned int last_probe;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 exception_bucket_flushed: 1;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 dst_host: 1;
	u8 fib6_destroying: 1;
	u8 unused: 2;
	struct fib6_nh___16 fib6_nh;
	struct callback_head rcu;
};

struct rt6_info___16 {
	struct dst_entry___69 dst;
	struct fib6_info___16 *from;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___40 *rt6i_idev;
	u32 rt6i_flags;
	struct rt6key rt6i_prefsrc;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct fib6_node___16 {
	struct fib6_node___16 *parent;
	struct fib6_node___16 *left;
	struct fib6_node___16 *right;
	struct fib6_info___16 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info___16 *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table___16 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node___16 tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

struct pernet_operations___90 {
	struct list_head list;
	int (*init)(struct net___100 *);
	void (*exit)(struct net___100 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___89 {
	int (*ieee_getets)(struct net_device___89 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___89 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___89 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___89 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___89 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___89 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___89 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___89 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___89 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___89 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___89 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___89 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___89 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___89 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___89 *);
	u8 (*setstate)(struct net_device___89 *, u8);
	void (*getpermhwaddr)(struct net_device___89 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___89 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___89 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___89 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___89 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___89 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___89 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___89 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___89 *, int, u8 *);
	void (*setpfccfg)(struct net_device___89 *, int, u8);
	void (*getpfccfg)(struct net_device___89 *, int, u8 *);
	u8 (*setall)(struct net_device___89 *);
	u8 (*getcap)(struct net_device___89 *, int, u8 *);
	int (*getnumtcs)(struct net_device___89 *, int, u8 *);
	int (*setnumtcs)(struct net_device___89 *, int, u8);
	u8 (*getpfcstate)(struct net_device___89 *);
	void (*setpfcstate)(struct net_device___89 *, u8);
	void (*getbcncfg)(struct net_device___89 *, int, u32 *);
	void (*setbcncfg)(struct net_device___89 *, int, u32);
	void (*getbcnrp)(struct net_device___89 *, int, u8 *);
	void (*setbcnrp)(struct net_device___89 *, int, u8);
	int (*setapp)(struct net_device___89 *, u8, u16, u8);
	int (*getapp)(struct net_device___89 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___89 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___89 *, int, u8);
	u8 (*getdcbx)(struct net_device___89 *);
	u8 (*setdcbx)(struct net_device___89 *, u8);
	int (*peer_getappinfo)(struct net_device___89 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___89 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___89 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___89 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___89 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___89 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct xdp_rxq_info___89 {
	struct net_device___89 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___89 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___89 *dev_rx;
};

struct header_ops___89 {
	int (*create)(struct sk_buff___90 *, struct net_device___89 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___90 *, unsigned char *);
	int (*cache)(const struct neighbour___69 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___89 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___89 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___89 *, int);
	int poll_owner;
	struct net_device___89 *dev;
	struct sk_buff___90 *gro_list;
	struct sk_buff___90 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___89 {
	struct net_device___89 *dev;
	struct Qdisc___81 *qdisc;
	struct Qdisc___81 *qdisc_sleeping;
	struct kobject___432 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___89 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide44;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___81 {
	struct sk_buff___90 *head;
	struct sk_buff___90 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___81;

struct Qdisc___81 {
	int (*enqueue)(struct sk_buff___90 *, struct Qdisc___81 *, struct sk_buff___90 **);
	struct sk_buff___90 * (*dequeue)(struct Qdisc___81 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___81 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___89 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___89 gso_skb;
	struct qdisc_skb_head___81 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___81 *next_sched;
	struct sk_buff_head___89 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___89 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___432 kobj;
	struct net_device___89 *dev;
	long: 64;
	struct xdp_rxq_info___89 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide45;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___89)(struct net_device___89 *, struct sk_buff___90 *, struct net_device___89 *);

struct netdev_bpf___89 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___79 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___79 *prog;
			const struct bpf_prog_offload_ops___79 *ops;
		} verifier;
		struct {
			struct bpf_prog___79 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___89 *offmap;
		};
		struct {
			struct xdp_umem___3 *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___89 {
	int (*xdo_dev_state_add)(struct xfrm_state___12 *);
	void (*xdo_dev_state_delete)(struct xfrm_state___12 *);
	void (*xdo_dev_state_free)(struct xfrm_state___12 *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___90 *, struct xfrm_state___12 *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state___12 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct xfrm_state_offload___12 {
	struct net_device___89 *dev;
	long unsigned int offload_handle;
	unsigned int num_exthdrs;
	u8 flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct xfrm_replay___12;

struct xfrm_type___12;

struct xfrm_mode___12;

struct xfrm_type_offload___12;

struct xfrm_state___12 {
	possible_net_t___91 xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	refcount_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
		u32 output_mark;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	const char *geniv;
	struct xfrm_encap_tmpl *encap;
	xfrm_address_t *coaddr;
	struct xfrm_state___12 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	const struct xfrm_replay___12 *repl;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct tasklet_hrtimer mtimer;
	struct xfrm_state_offload___12 xso;
	long int saved_tmo;
	long unsigned int lastused;
	struct page_frag___445 xfrag;
	const struct xfrm_type___12 *type;
	struct xfrm_mode___12 *inner_mode;
	struct xfrm_mode___12 *inner_mode_iaf;
	struct xfrm_mode___12 *outer_mode;
	const struct xfrm_type_offload___12 *type_offload;
	struct xfrm_sec_ctx___2 *security;
	void *data;
	u32 output_mark_mask;
	u32 if_id;
};

struct tlsdev_ops___89 {
	int (*tls_dev_add)(struct net_device___89 *, struct sock___69 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___89 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___89 *, struct sock___69 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide46;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___89 {
	int (*ndo_init)(struct net_device___89 *);
	void (*ndo_uninit)(struct net_device___89 *);
	int (*ndo_open)(struct net_device___89 *);
	int (*ndo_stop)(struct net_device___89 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___90 *, struct net_device___89 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___90 *, struct net_device___89 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___89 *, struct sk_buff___90 *, struct net_device___89 *, select_queue_fallback_t___89);
	void (*ndo_change_rx_flags)(struct net_device___89 *, int);
	void (*ndo_set_rx_mode)(struct net_device___89 *);
	int (*ndo_set_mac_address)(struct net_device___89 *, void *);
	int (*ndo_validate_addr)(struct net_device___89 *);
	int (*ndo_do_ioctl)(struct net_device___89 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___89 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___89 *, int);
	int (*ndo_neigh_setup)(struct net_device___89 *, struct neigh_parms___69 *);
	void (*ndo_tx_timeout)(struct net_device___89 *);
	void (*ndo_get_stats64)(struct net_device___89 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___89 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___89 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___89 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___89 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___89 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___89 *);
	int (*ndo_netpoll_setup)(struct net_device___89 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___89 *);
	int (*ndo_set_vf_mac)(struct net_device___89 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___89 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___89 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___89 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___89 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___89 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___89 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___89 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___89 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___89 *, int, struct sk_buff___90 *);
	int (*ndo_set_vf_guid)(struct net_device___89 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___89 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___89 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___89 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___89 *, const struct sk_buff___90 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___89 *, struct net_device___89 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___89 *, struct net_device___89 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___89 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___89 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___89 *, struct neighbour___69 *);
	void (*ndo_neigh_destroy)(struct net_device___89 *, struct neighbour___69 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___89 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___89 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide47;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___89 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___90 *, struct netlink_callback___91 *, struct net_device___89 *, struct net_device___89 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___89 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___89 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide48;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___90 *, u32, u32, struct net_device___89 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___89 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___89 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___89 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___89 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___89 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___89 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___89 *, struct net_device___89 *);
	void (*ndo_dfwd_del_station)(struct net_device___89 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___89 *);
	int (*ndo_set_tx_maxrate)(struct net_device___89 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___89 *);
	int (*ndo_change_proto_down)(struct net_device___89 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___89 *, struct sk_buff___90 *);
	void (*ndo_set_rx_headroom)(struct net_device___89 *, int);
	int (*ndo_bpf)(struct net_device___89 *, struct netdev_bpf___89 *);
	int (*ndo_xdp_xmit)(struct net_device___89 *, int, struct xdp_frame___89 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___89 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___89 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide49;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___69 {
	possible_net_t___91 net;
	struct net_device___89 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___69 *);
	void (*neigh_cleanup)(struct neighbour___69 *);
	struct neigh_table___69 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___69 {
	u32 (*l3mdev_fib_table)(const struct net_device___89 *);
	struct sk_buff___90 * (*l3mdev_l3_rcv)(struct net_device___89 *, struct sk_buff___90 *, u16);
	struct sk_buff___90 * (*l3mdev_l3_out)(struct net_device___89 *, struct sock___69 *, struct sk_buff___90 *, u16);
	struct dst_entry___69 * (*l3mdev_link_scope_lookup)(const struct net_device___89 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct ndisc_ops___40 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___89 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___89 *, struct neighbour___69 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___89 *, u8, struct neighbour___69 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___89 *, struct sk_buff___90 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___100 *, struct net_device___89 *, const struct prefix_info *, struct inet6_dev___40 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___40;

struct ifacaddr6___16;

struct inet6_dev___40 {
	struct net_device___89 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___40 *mc_list;
	struct ifmcaddr6___40 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___16 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	u8 rndid[8];
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___69 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
};

struct tcf_proto___81;

struct mini_Qdisc___81 {
	struct tcf_proto___81 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___81 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___89 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___100 *, struct net_device___89 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___89 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___89 *, struct list_head *);
	size_t (*get_size)(const struct net_device___89 *);
	int (*fill_info)(struct sk_buff___90 *, const struct net_device___89 *);
	size_t (*get_xstats_size)(const struct net_device___89 *);
	int (*fill_xstats)(struct sk_buff___90 *, const struct net_device___89 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___89 *, struct net_device___89 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___89 *, const struct net_device___89 *);
	int (*fill_slave_info)(struct sk_buff___90 *, const struct net_device___89 *, const struct net_device___89 *);
	struct net___100 * (*get_link_net)(const struct net_device___89 *);
	size_t (*get_linkxstats_size)(const struct net_device___89 *, int);
	int (*fill_linkxstats)(struct sk_buff___90 *, const struct net_device___89 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___89 {
	struct list_head poll_list;
	struct sk_buff_head___89 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___89 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___81 *output_queue;
	struct Qdisc___81 **output_queue_tailp;
	struct sk_buff___90 *completion_queue;
	struct sk_buff_head___89 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___89 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___89 input_pkt_queue;
	struct napi_struct___89 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct gnet_dump___81 {
	spinlock_t *lock;
	struct sk_buff___90 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___81;

struct Qdisc_ops___81 {
	struct Qdisc_ops___81 *next;
	const struct Qdisc_class_ops___81 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___90 *, struct Qdisc___81 *, struct sk_buff___90 **);
	struct sk_buff___90 * (*dequeue)(struct Qdisc___81 *);
	struct sk_buff___90 * (*peek)(struct Qdisc___81 *);
	int (*init)(struct Qdisc___81 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___81 *);
	void (*destroy)(struct Qdisc___81 *);
	int (*change)(struct Qdisc___81 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___81 *);
	int (*change_tx_queue_len)(struct Qdisc___81 *, unsigned int);
	int (*dump)(struct Qdisc___81 *, struct sk_buff___90 *);
	int (*dump_stats)(struct Qdisc___81 *, struct gnet_dump___81 *);
	void (*ingress_block_set)(struct Qdisc___81 *, u32);
	void (*egress_block_set)(struct Qdisc___81 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___81 *);
	u32 (*egress_block_get)(struct Qdisc___81 *);
	struct module___370 *owner;
};

struct tcf_block___81;

struct Qdisc_class_ops___81 {
	unsigned int flags;
	struct netdev_queue___89 * (*select_queue)(struct Qdisc___81 *, struct tcmsg *);
	int (*graft)(struct Qdisc___81 *, long unsigned int, struct Qdisc___81 *, struct Qdisc___81 **, struct netlink_ext_ack *);
	struct Qdisc___81 * (*leaf)(struct Qdisc___81 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___81 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___81 *, u32);
	int (*change)(struct Qdisc___81 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___81 *, long unsigned int);
	void (*walk)(struct Qdisc___81 *, struct qdisc_walker *);
	struct tcf_block___81 * (*tcf_block)(struct Qdisc___81 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___81 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___81 *, long unsigned int);
	int (*dump)(struct Qdisc___81 *, long unsigned int, struct sk_buff___90 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___81 *, long unsigned int, struct gnet_dump___81 *);
};

struct tcf_chain___81;

struct tcf_block___81 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___100 *net;
	struct Qdisc___81 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___81 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___81;

struct tcf_proto_ops___81;

struct tcf_proto___81 {
	struct tcf_proto___81 *next;
	void *root;
	int (*classify)(struct sk_buff___90 *, const struct tcf_proto___81 *, struct tcf_result___81 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___81 *ops;
	struct tcf_chain___81 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___81 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___81 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___81 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___90 *, const struct tcf_proto___81 *, struct tcf_result___81 *);
	int (*init)(struct tcf_proto___81 *);
	void (*destroy)(struct tcf_proto___81 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___81 *, u32);
	void (*put)(struct tcf_proto___81 *, void *);
	int (*change)(struct net___100 *, struct sk_buff___90 *, struct tcf_proto___81 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___81 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___81 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___81 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___100 *, struct tcf_chain___81 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___100 *, struct tcf_proto___81 *, void *, struct sk_buff___90 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___90 *, struct net___100 *, void *);
	struct module___370 *owner;
	int flags;
};

struct tcf_chain___81 {
	struct mutex filter_chain_lock;
	struct tcf_proto___81 *filter_chain;
	struct list_head list;
	struct tcf_block___81 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___81 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___69 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___79 *prog;
};

struct bpf_redirect_info___79 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___294 *map;
	struct bpf_map___294 *map_to_flush;
	u32 kern_flags;
};

struct bpf_sock_ops_kern___4 {
	struct sock___69 *sk;
	u32 op;
	union {
		u32 args[4];
		u32 reply;
		u32 replylong[4];
	};
	u32 is_fullsock;
	u64 temp;
};

struct pneigh_entry___69;

struct neigh_hash_table___69;

struct neigh_table___69 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___89 *, __u32 *);
	bool (*key_eq)(const struct neighbour___69 *, const void *);
	int (*constructor)(struct neighbour___69 *);
	int (*pconstructor)(struct pneigh_entry___69 *);
	void (*pdestructor)(struct pneigh_entry___69 *);
	void (*proxy_redo)(struct sk_buff___90 *);
	char *id;
	struct neigh_parms___69 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___89 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___69 *nht;
	struct pneigh_entry___69 **phash_buckets;
};

struct neigh_ops___69 {
	int family;
	void (*solicit)(struct neighbour___69 *, struct sk_buff___90 *);
	void (*error_report)(struct neighbour___69 *, struct sk_buff___90 *);
	int (*output)(struct neighbour___69 *, struct sk_buff___90 *);
	int (*connected_output)(struct neighbour___69 *, struct sk_buff___90 *);
};

struct pneigh_entry___69 {
	struct pneigh_entry___69 *next;
	possible_net_t___91 net;
	struct net_device___89 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___69 {
	struct neighbour___69 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___69 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___69 *ctarget;
	struct net___100 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___69 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___69 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___52;

struct timewait_sock_ops___48;

struct proto___69 {
	void (*close)(struct sock___69 *, long int);
	int (*pre_connect)(struct sock___69 *, struct sockaddr *, int);
	int (*connect)(struct sock___69 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___69 *, int);
	struct sock___69 * (*accept)(struct sock___69 *, int, int *, bool);
	int (*ioctl)(struct sock___69 *, int, long unsigned int);
	int (*init)(struct sock___69 *);
	void (*destroy)(struct sock___69 *);
	void (*shutdown)(struct sock___69 *, int);
	int (*setsockopt)(struct sock___69 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___69 *, int, int, char *, int *);
	void (*keepalive)(struct sock___69 *, int);
	int (*sendmsg)(struct sock___69 *, struct msghdr___72 *, size_t);
	int (*recvmsg)(struct sock___69 *, struct msghdr___72 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___69 *, struct page___445 *, int, size_t, int);
	int (*bind)(struct sock___69 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___69 *, struct sk_buff___90 *);
	void (*release_cb)(struct sock___69 *);
	int (*hash)(struct sock___69 *);
	void (*unhash)(struct sock___69 *);
	void (*rehash)(struct sock___69 *);
	int (*get_port)(struct sock___69 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___69 *);
	bool (*stream_memory_read)(const struct sock___69 *);
	void (*enter_memory_pressure)(struct sock___69 *);
	void (*leave_memory_pressure)(struct sock___69 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___52 *rsk_prot;
	struct timewait_sock_ops___48 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___370 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___69 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct xfrm_policy_queue___12 {
	struct sk_buff_head___89 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___12 {
	possible_net_t___91 xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	refcount_t refcnt;
	struct timer_list timer;
	atomic_t genid;
	u32 priority;
	u32 index;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___12 polq;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx___2 *security;
	struct xfrm_tmpl xfrm_vec[6];
	struct callback_head rcu;
	u32 if_id;
};

struct request_sock___53;

struct request_sock_ops___52 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___69 *, struct request_sock___53 *);
	void (*send_ack)(const struct sock___69 *, struct sk_buff___90 *, struct request_sock___53 *);
	void (*send_reset)(const struct sock___69 *, struct sk_buff___90 *);
	void (*destructor)(struct request_sock___53 *);
	void (*syn_ack_timeout)(const struct request_sock___53 *);
};

struct timewait_sock_ops___48 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___69 *, struct sock___69 *, void *);
	void (*twsk_destructor)(struct sock___69 *);
};

struct request_sock___53 {
	struct sock_common___69 __req_common;
	struct request_sock___53 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___52 *rsk_ops;
	struct sock___69 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct fastopen_queue___8 {
	struct request_sock___53 *rskq_rst_head;
	struct request_sock___53 *rskq_rst_tail;
	spinlock_t lock;
	int qlen;
	int max_qlen;
	struct tcp_fastopen_context___15 *ctx;
};

struct request_sock_queue___8 {
	spinlock_t rskq_lock;
	u8 rskq_defer_accept;
	u32 synflood_warned;
	atomic_t qlen;
	atomic_t young;
	struct request_sock___53 *rskq_accept_head;
	struct request_sock___53 *rskq_accept_tail;
	struct fastopen_queue___8 fastopenq;
};

struct inet_cork___12 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___69 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
	__u16 gso_size;
	u64 transmit_time;
};

struct inet_cork_full___12 {
	struct inet_cork___12 base;
	struct flowi fl;
};

struct ipv6_pinfo___12;

struct inet_sock___12 {
	struct sock___69 sk;
	struct ipv6_pinfo___12 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	__be16 inet_sport;
	__u16 inet_id;
	struct ip_options_rcu *inet_opt;
	int rx_dst_ifindex;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 bind_address_no_port: 1;
	__u8 defer_connect: 1;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___12 cork;
};

struct ipv6_fl_socklist___11;

struct ipv6_pinfo___12 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
			__u16 recvfragsize: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 repflow: 1;
	__u16 pmtudisc: 3;
	__u16 padding: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u16 autoflowlabel: 1;
	__u16 autoflowlabel_set: 1;
	__u8 min_hopcount;
	__u8 tclass;
	__be32 rcv_flowinfo;
	__u32 dst_cookie;
	__u32 rx_dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___11 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___90 *pktoptions;
	struct sk_buff___90 *rxpmtu;
	struct inet6_cork cork;
};

struct inet_connection_sock_af_ops___8 {
	int (*queue_xmit)(struct sock___69 *, struct sk_buff___90 *, struct flowi *);
	void (*send_check)(struct sock___69 *, struct sk_buff___90 *);
	int (*rebuild_header)(struct sock___69 *);
	void (*sk_rx_dst_set)(struct sock___69 *, const struct sk_buff___90 *);
	int (*conn_request)(struct sock___69 *, struct sk_buff___90 *);
	struct sock___69 * (*syn_recv_sock)(const struct sock___69 *, struct sk_buff___90 *, struct request_sock___53 *, struct dst_entry___69 *, struct request_sock___53 *, bool *);
	u16 net_header_len;
	u16 net_frag_header_len;
	u16 sockaddr_len;
	int (*setsockopt)(struct sock___69 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___69 *, int, int, char *, int *);
	void (*addr2sockaddr)(struct sock___69 *, struct sockaddr *);
	void (*mtu_reduced)(struct sock___69 *);
};

struct inet_bind_bucket___7;

struct tcp_ulp_ops___6;

struct inet_connection_sock___8 {
	struct inet_sock___12 icsk_inet;
	struct request_sock_queue___8 icsk_accept_queue;
	struct inet_bind_bucket___7 *icsk_bind_hash;
	long unsigned int icsk_timeout;
	struct timer_list icsk_retransmit_timer;
	struct timer_list icsk_delack_timer;
	__u32 icsk_rto;
	__u32 icsk_pmtu_cookie;
	const struct tcp_congestion_ops___15 *icsk_ca_ops;
	const struct inet_connection_sock_af_ops___8 *icsk_af_ops;
	const struct tcp_ulp_ops___6 *icsk_ulp_ops;
	void *icsk_ulp_data;
	void (*icsk_clean_acked)(struct sock___69 *, u32);
	struct hlist_node icsk_listen_portaddr_node;
	unsigned int (*icsk_sync_mss)(struct sock___69 *, u32);
	__u8 icsk_ca_state: 6;
	__u8 icsk_ca_setsockopt: 1;
	__u8 icsk_ca_dst_locked: 1;
	__u8 icsk_retransmits;
	__u8 icsk_pending;
	__u8 icsk_backoff;
	__u8 icsk_syn_retries;
	__u8 icsk_probes_out;
	__u16 icsk_ext_hdr_len;
	struct {
		__u8 pending;
		__u8 quick;
		__u8 pingpong;
		__u8 blocked;
		__u32 ato;
		long unsigned int timeout;
		__u32 lrcvtime;
		__u16 last_seg_size;
		__u16 rcv_mss;
	} icsk_ack;
	struct {
		int enabled;
		int search_high;
		int search_low;
		int probe_size;
		u32 probe_timestamp;
	} icsk_mtup;
	u32 icsk_user_timeout;
	u64 icsk_ca_priv[11];
};

struct inet_bind_bucket___7 {
	possible_net_t___91 ib_net;
	short unsigned int port;
	signed char fastreuse;
	signed char fastreuseport;
	kuid_t fastuid;
	struct in6_addr fast_v6_rcv_saddr;
	__be32 fast_rcv_saddr;
	short unsigned int fast_sk_family;
	bool fast_ipv6_only;
	struct hlist_node node;
	struct hlist_head owners;
};

struct tcp_ulp_ops___6 {
	struct list_head list;
	int (*init)(struct sock___69 *);
	void (*release)(struct sock___69 *);
	char name[16];
	struct module___370 *owner;
};

enum inet_csk_ack_state_t {
	ICSK_ACK_SCHED = 1,
	ICSK_ACK_TIMER = 2,
	ICSK_ACK_PUSHED = 4,
	ICSK_ACK_PUSHED2 = 8,
	ICSK_ACK_NOW = 16,
};

enum {
	TCP_FLAG_CWR = 32768,
	TCP_FLAG_ECE = 16384,
	TCP_FLAG_URG = 8192,
	TCP_FLAG_ACK = 4096,
	TCP_FLAG_PSH = 2048,
	TCP_FLAG_RST = 1024,
	TCP_FLAG_SYN = 512,
	TCP_FLAG_FIN = 256,
	TCP_RESERVED_BITS = 15,
	TCP_DATA_OFFSET = 240,
};

struct tcp_repair_opt {
	__u32 opt_code;
	__u32 opt_val;
};

struct tcp_repair_window {
	__u32 snd_wl1;
	__u32 snd_wnd;
	__u32 max_window;
	__u32 rcv_wnd;
	__u32 rcv_wup;
};

enum {
	TCP_NO_QUEUE = 0,
	TCP_RECV_QUEUE = 1,
	TCP_SEND_QUEUE = 2,
	TCP_QUEUES_NR = 3,
};

struct tcp_info {
	__u8 tcpi_state;
	__u8 tcpi_ca_state;
	__u8 tcpi_retransmits;
	__u8 tcpi_probes;
	__u8 tcpi_backoff;
	__u8 tcpi_options;
	__u8 tcpi_snd_wscale: 4;
	__u8 tcpi_rcv_wscale: 4;
	__u8 tcpi_delivery_rate_app_limited: 1;
	__u32 tcpi_rto;
	__u32 tcpi_ato;
	__u32 tcpi_snd_mss;
	__u32 tcpi_rcv_mss;
	__u32 tcpi_unacked;
	__u32 tcpi_sacked;
	__u32 tcpi_lost;
	__u32 tcpi_retrans;
	__u32 tcpi_fackets;
	__u32 tcpi_last_data_sent;
	__u32 tcpi_last_ack_sent;
	__u32 tcpi_last_data_recv;
	__u32 tcpi_last_ack_recv;
	__u32 tcpi_pmtu;
	__u32 tcpi_rcv_ssthresh;
	__u32 tcpi_rtt;
	__u32 tcpi_rttvar;
	__u32 tcpi_snd_ssthresh;
	__u32 tcpi_snd_cwnd;
	__u32 tcpi_advmss;
	__u32 tcpi_reordering;
	__u32 tcpi_rcv_rtt;
	__u32 tcpi_rcv_space;
	__u32 tcpi_total_retrans;
	__u64 tcpi_pacing_rate;
	__u64 tcpi_max_pacing_rate;
	__u64 tcpi_bytes_acked;
	__u64 tcpi_bytes_received;
	__u32 tcpi_segs_out;
	__u32 tcpi_segs_in;
	__u32 tcpi_notsent_bytes;
	__u32 tcpi_min_rtt;
	__u32 tcpi_data_segs_in;
	__u32 tcpi_data_segs_out;
	__u64 tcpi_delivery_rate;
	__u64 tcpi_busy_time;
	__u64 tcpi_rwnd_limited;
	__u64 tcpi_sndbuf_limited;
	__u32 tcpi_delivered;
	__u32 tcpi_delivered_ce;
};

enum {
	TCP_NLA_PAD = 0,
	TCP_NLA_BUSY = 1,
	TCP_NLA_RWND_LIMITED = 2,
	TCP_NLA_SNDBUF_LIMITED = 3,
	TCP_NLA_DATA_SEGS_OUT = 4,
	TCP_NLA_TOTAL_RETRANS = 5,
	TCP_NLA_PACING_RATE = 6,
	TCP_NLA_DELIVERY_RATE = 7,
	TCP_NLA_SND_CWND = 8,
	TCP_NLA_REORDERING = 9,
	TCP_NLA_MIN_RTT = 10,
	TCP_NLA_RECUR_RETRANS = 11,
	TCP_NLA_DELIVERY_RATE_APP_LMT = 12,
	TCP_NLA_SNDQ_SIZE = 13,
	TCP_NLA_CA_STATE = 14,
	TCP_NLA_SND_SSTHRESH = 15,
	TCP_NLA_DELIVERED = 16,
	TCP_NLA_DELIVERED_CE = 17,
};

struct tcp_zerocopy_receive {
	__u64 address;
	__u32 length;
	__u32 recv_skip_hint;
};

struct tcp_sock_af_ops___6;

struct tcp_fastopen_request___6;

struct tcp_sock___6 {
	struct inet_connection_sock___8 inet_conn;
	u16 tcp_header_len;
	u16 gso_segs;
	__be32 pred_flags;
	u64 bytes_received;
	u32 segs_in;
	u32 data_segs_in;
	u32 rcv_nxt;
	u32 copied_seq;
	u32 rcv_wup;
	u32 snd_nxt;
	u32 segs_out;
	u32 data_segs_out;
	u64 bytes_acked;
	u32 snd_una;
	u32 snd_sml;
	u32 rcv_tstamp;
	u32 lsndtime;
	u32 last_oow_ack_time;
	u32 compressed_ack_rcv_nxt;
	u32 tsoffset;
	struct list_head tsq_node;
	struct list_head tsorted_sent_queue;
	u32 snd_wl1;
	u32 snd_wnd;
	u32 max_window;
	u32 mss_cache;
	u32 window_clamp;
	u32 rcv_ssthresh;
	struct tcp_rack rack;
	u16 advmss;
	u8 compressed_ack;
	u32 chrono_start;
	u32 chrono_stat[3];
	u8 chrono_type: 2;
	u8 rate_app_limited: 1;
	u8 fastopen_connect: 1;
	u8 fastopen_no_cookie: 1;
	u8 is_sack_reneg: 1;
	u8 unused: 2;
	u8 nonagle: 4;
	u8 thin_lto: 1;
	u8 recvmsg_inq: 1;
	u8 repair: 1;
	u8 frto: 1;
	u8 repair_queue;
	u8 syn_data: 1;
	u8 syn_fastopen: 1;
	u8 syn_fastopen_exp: 1;
	u8 syn_fastopen_ch: 1;
	u8 syn_data_acked: 1;
	u8 save_syn: 1;
	u8 is_cwnd_limited: 1;
	u8 syn_smc: 1;
	u32 tlp_high_seq;
	u64 tcp_mstamp;
	u32 srtt_us;
	u32 mdev_us;
	u32 mdev_max_us;
	u32 rttvar_us;
	u32 rtt_seq;
	struct minmax rtt_min;
	u32 packets_out;
	u32 retrans_out;
	u32 max_packets_out;
	u32 max_packets_seq;
	u16 urg_data;
	u8 ecn_flags;
	u8 keepalive_probes;
	u32 reordering;
	u32 snd_up;
	struct tcp_options_received rx_opt;
	u32 snd_ssthresh;
	u32 snd_cwnd;
	u32 snd_cwnd_cnt;
	u32 snd_cwnd_clamp;
	u32 snd_cwnd_used;
	u32 snd_cwnd_stamp;
	u32 prior_cwnd;
	u32 prr_delivered;
	u32 prr_out;
	u32 delivered;
	u32 delivered_ce;
	u32 lost;
	u32 app_limited;
	u64 first_tx_mstamp;
	u64 delivered_mstamp;
	u32 rate_delivered;
	u32 rate_interval_us;
	u32 rcv_wnd;
	u32 write_seq;
	u32 notsent_lowat;
	u32 pushed_seq;
	u32 lost_out;
	u32 sacked_out;
	struct hrtimer pacing_timer;
	struct hrtimer compressed_ack_timer;
	struct sk_buff___90 *lost_skb_hint;
	struct sk_buff___90 *retransmit_skb_hint;
	struct rb_root out_of_order_queue;
	struct sk_buff___90 *ooo_last_skb;
	struct tcp_sack_block duplicate_sack[1];
	struct tcp_sack_block selective_acks[4];
	struct tcp_sack_block recv_sack_cache[4];
	struct sk_buff___90 *highest_sack;
	int lost_cnt_hint;
	u32 prior_ssthresh;
	u32 high_seq;
	u32 retrans_stamp;
	u32 undo_marker;
	int undo_retrans;
	u32 total_retrans;
	u32 urg_seq;
	unsigned int keepalive_time;
	unsigned int keepalive_intvl;
	int linger2;
	u8 bpf_sock_ops_cb_flags;
	struct {
		u32 rtt_us;
		u32 seq;
		u64 time;
	} rcv_rtt_est;
	struct {
		u32 space;
		u32 seq;
		u64 time;
	} rcvq_space;
	struct {
		u32 probe_seq_start;
		u32 probe_seq_end;
	} mtu_probe;
	u32 mtu_info;
	const struct tcp_sock_af_ops___6 *af_specific;
	struct tcp_md5sig_info *md5sig_info;
	struct tcp_fastopen_request___6 *fastopen_req;
	struct request_sock___53 *fastopen_rsk;
	u32 *saved_syn;
};

struct tcp_sock_af_ops___6 {
	struct tcp_md5sig_key * (*md5_lookup)(const struct sock___69 *, const struct sock___69 *);
	int (*calc_md5_hash)(char *, const struct tcp_md5sig_key *, const struct sock___69 *, const struct sk_buff___90 *);
	int (*md5_parse)(struct sock___69 *, int, char *, int);
};

struct tcp_fastopen_request___6 {
	struct tcp_fastopen_cookie cookie;
	struct msghdr___72 *data;
	size_t size;
	int copied;
};

struct ip6_flowlabel___11;

struct ipv6_fl_socklist___11 {
	struct ipv6_fl_socklist___11 *next;
	struct ip6_flowlabel___11 *fl;
	struct callback_head rcu;
};

struct ifmcaddr6___40 {
	struct in6_addr mca_addr;
	struct inet6_dev___40 *idev;
	struct ifmcaddr6___40 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___16 {
	struct in6_addr aca_addr;
	struct fib6_info___16 *aca_rt;
	struct ifacaddr6___16 *aca_next;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct ip6_ra_chain___40 {
	struct ip6_ra_chain___40 *next;
	struct sock___69 *sk;
	int sel;
	void (*destructor)(struct sock___69 *);
};

struct ip6_flowlabel___11 {
	struct ip6_flowlabel___11 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___247 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___100 *fl_net;
};

struct tcp_skb_cb___3 {
	__u32 seq;
	__u32 end_seq;
	union {
		__u32 tcp_tw_isn;
		struct {
			u16 tcp_gso_segs;
			u16 tcp_gso_size;
		};
	};
	__u8 tcp_flags;
	__u8 sacked;
	__u8 ip_dsfield;
	__u8 txstamp_ack: 1;
	__u8 eor: 1;
	__u8 has_rxtstamp: 1;
	__u8 unused: 5;
	__u32 ack_seq;
	union {
		struct {
			__u32 in_flight: 30;
			__u32 is_app_limited: 1;
			__u32 unused: 1;
			__u32 delivered;
			u64 first_tx_mstamp;
			u64 delivered_mstamp;
		} tx;
		union {
			struct inet_skb_parm h4;
			struct inet6_skb_parm h6;
		} header;
		struct {
			__u32 flags;
			struct sock___69 *sk_redir;
			void *data_end;
		} bpf;
	};
};

struct tcp_md5sig_pool {
	struct ahash_request___5 *md5_req;
	void *scratch;
};

enum tcp_chrono {
	TCP_CHRONO_UNSPEC = 0,
	TCP_CHRONO_BUSY = 1,
	TCP_CHRONO_RWND_LIMITED = 2,
	TCP_CHRONO_SNDBUF_LIMITED = 3,
	__TCP_CHRONO_MAX = 4,
};

struct xfrm_replay___12 {
	void (*advance)(struct xfrm_state___12 *, __be32);
	int (*check)(struct xfrm_state___12 *, struct sk_buff___90 *, __be32);
	int (*recheck)(struct xfrm_state___12 *, struct sk_buff___90 *, __be32);
	void (*notify)(struct xfrm_state___12 *, int);
	int (*overflow)(struct xfrm_state___12 *, struct sk_buff___90 *);
};

struct xfrm_type___12 {
	char *description;
	struct module___370 *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___12 *);
	void (*destructor)(struct xfrm_state___12 *);
	int (*input)(struct xfrm_state___12 *, struct sk_buff___90 *);
	int (*output)(struct xfrm_state___12 *, struct sk_buff___90 *);
	int (*reject)(struct xfrm_state___12 *, struct sk_buff___90 *, const struct flowi *);
	int (*hdr_offset)(struct xfrm_state___12 *, struct sk_buff___90 *, u8 **);
	u32 (*get_mtu)(struct xfrm_state___12 *, int);
};

struct xfrm_state_afinfo___12;

struct xfrm_mode___12 {
	int (*input2)(struct xfrm_state___12 *, struct sk_buff___90 *);
	int (*input)(struct xfrm_state___12 *, struct sk_buff___90 *);
	int (*output2)(struct xfrm_state___12 *, struct sk_buff___90 *);
	int (*output)(struct xfrm_state___12 *, struct sk_buff___90 *);
	struct sk_buff___90 * (*gso_segment)(struct xfrm_state___12 *, struct sk_buff___90 *, netdev_features_t);
	void (*xmit)(struct xfrm_state___12 *, struct sk_buff___90 *);
	struct xfrm_state_afinfo___12 *afinfo;
	struct module___370 *owner;
	unsigned int encap;
	int flags;
};

struct xfrm_type_offload___12 {
	char *description;
	struct module___370 *owner;
	u8 proto;
	void (*encap)(struct xfrm_state___12 *, struct sk_buff___90 *);
	int (*input_tail)(struct xfrm_state___12 *, struct sk_buff___90 *);
	int (*xmit)(struct xfrm_state___12 *, struct sk_buff___90 *, netdev_features_t);
};

struct xfrm_state_afinfo___12 {
	unsigned int family;
	unsigned int proto;
	__be16 eth_proto;
	struct module___370 *owner;
	const struct xfrm_type___12 *type_map[256];
	const struct xfrm_type_offload___12 *type_offload_map[256];
	struct xfrm_mode___12 *mode_map[5];
	int (*init_flags)(struct xfrm_state___12 *);
	void (*init_tempsel)(struct xfrm_selector *, const struct flowi *);
	void (*init_temprop)(struct xfrm_state___12 *, const struct xfrm_tmpl *, const xfrm_address_t *, const xfrm_address_t *);
	int (*tmpl_sort)(struct xfrm_tmpl **, struct xfrm_tmpl **, int);
	int (*state_sort)(struct xfrm_state___12 **, struct xfrm_state___12 **, int);
	int (*output)(struct net___100 *, struct sock___69 *, struct sk_buff___90 *);
	int (*output_finish)(struct sock___69 *, struct sk_buff___90 *);
	int (*extract_input)(struct xfrm_state___12 *, struct sk_buff___90 *);
	int (*extract_output)(struct xfrm_state___12 *, struct sk_buff___90 *);
	int (*transport_finish)(struct sk_buff___90 *, int);
	void (*local_error)(struct sk_buff___90 *, u32);
};

struct tcp_splice_state {
	struct pipe_inode_info___125 *pipe;
	size_t len;
	unsigned int flags;
};

struct module___371;

struct file___445;

struct kiocb___445;

struct iov_iter___212;

struct poll_table_struct___284;

struct vm_area_struct___446;

struct inode___445;

struct file_lock___445;

struct page___446;

struct pipe_inode_info___126;

struct seq_file___384;

struct file_operations___445 {
	struct module___371 *owner;
	loff_t (*llseek)(struct file___445 *, loff_t, int);
	ssize_t (*read)(struct file___445 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___445 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___445 *, struct iov_iter___212 *);
	ssize_t (*write_iter)(struct kiocb___445 *, struct iov_iter___212 *);
	int (*iopoll)(struct kiocb___445 *, bool);
	int (*iterate)(struct file___445 *, struct dir_context *);
	int (*iterate_shared)(struct file___445 *, struct dir_context *);
	__poll_t (*poll)(struct file___445 *, struct poll_table_struct___284 *);
	long int (*unlocked_ioctl)(struct file___445 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___445 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___445 *, struct vm_area_struct___446 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___445 *, struct file___445 *);
	int (*flush)(struct file___445 *, fl_owner_t);
	int (*release)(struct inode___445 *, struct file___445 *);
	int (*fsync)(struct file___445 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___445 *, int);
	int (*lock)(struct file___445 *, int, struct file_lock___445 *);
	ssize_t (*sendpage)(struct file___445 *, struct page___446 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___445 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___445 *, int, struct file_lock___445 *);
	ssize_t (*splice_write)(struct pipe_inode_info___126 *, struct file___445 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___445 *, loff_t *, struct pipe_inode_info___126 *, size_t, unsigned int);
	int (*setlease)(struct file___445 *, long int, struct file_lock___445 **, void **);
	long int (*fallocate)(struct file___445 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___384 *, struct file___445 *);
	ssize_t (*copy_file_range)(struct file___445 *, loff_t, struct file___445 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___445 *, loff_t, struct file___445 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___445 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___446 {
	u64 seqnum;
	struct vm_area_struct___446 *vmas[4];
};

struct page_frag___446 {
	struct page___446 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___446;

struct mem_cgroup___178;

struct cred___413;

struct nsproxy___340;

struct signal_struct___320;

struct bio_list___235;

struct backing_dev_info___235;

struct css_set___294;

struct vm_struct___349;

struct task_struct___447 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___447 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___446 *mm;
	struct mm_struct___446 *active_mm;
	struct vmacache___446 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___447 *real_parent;
	struct task_struct___447 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___447 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___178 *active_memcg;
	long int rh_reserved2;
	struct pid___247 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___247 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___247 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___413 *ptracer_cred;
	const struct cred___413 *real_cred;
	const struct cred___413 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___340 *nsproxy;
	struct signal_struct___320 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___447 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___235 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___235 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___294 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___126 *splice_pipe;
	struct page_frag___446 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___178 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___447 *oom_reaper_list;
	struct vm_struct___349 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___156 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___446 *pgtable_t___446;

struct address_space___445;

struct dev_pagemap___433;

struct page___446 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___445 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___446 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___446 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___446 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___433 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___178 *mem_cgroup;
};

struct pglist_data___446;

struct lruvec___446 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___446 *pgdat;
};

struct zone___446 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___446 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___446 {
	struct zone___446 *zone;
	int zone_idx;
};

struct zonelist___446 {
	struct zoneref___446 _zonerefs[25];
};

struct pglist_data___446 {
	struct zone___446 node_zones[3];
	struct zonelist___446 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___447 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___447 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___446 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___447 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___447 *owner;
};

struct secondary_data___447 {
	void *stack;
	struct task_struct___447 *task;
	long int status;
};

struct blocking_notifier_head___446 {
	struct rw_semaphore___447 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___433;

struct vm_area_struct___446 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___446 *vm_next;
	struct vm_area_struct___446 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___446 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___433 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___445 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___446;

struct user_namespace___310;

struct mm_struct___446 {
	struct {
		struct vm_area_struct___446 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___445 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___447 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___446 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___447 *owner;
		struct user_namespace___310 *user_ns;
		struct file___445 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___446 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___445;

struct address_space___445 {
	struct inode___445 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___447 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___445 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___433)(struct vm_area_struct___446 *, long unsigned int, const struct page___446 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___433)(struct page___446 *, void *);

struct device___413;

struct dev_pagemap___433 {
	dev_page_fault_t___433 page_fault;
	dev_page_free_t___433 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___413 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct cgroup___294;

struct cgroup_subsys___294;

struct cgroup_subsys_state___294 {
	struct cgroup___294 *cgroup;
	struct cgroup_subsys___294 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___294 *parent;
};

struct kernfs_node___440;

struct cgroup_file___294 {
	struct kernfs_node___440 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___178;

struct mem_cgroup___178 {
	struct cgroup_subsys_state___294 css;
	struct mem_cgroup_id___13 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___294 events_file;
	struct cgroup_file___294 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___447 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___178 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry___445;

struct path___446 {
	struct vfsmount *mnt;
	struct dentry___445 *dentry;
};

struct file___445 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___446 f_path;
	struct inode___445 *f_inode;
	const struct file_operations___445 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___247 f_owner;
	const struct cred___413 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___445 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___433;

struct vm_operations_struct___433 {
	void (*open)(struct vm_area_struct___446 *);
	void (*close)(struct vm_area_struct___446 *);
	int (*split)(struct vm_area_struct___446 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___446 *);
	vm_fault_t (*fault)(struct vm_fault___433 *);
	vm_fault_t (*huge_fault)(struct vm_fault___433 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___433 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___446 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___433 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___433 *);
	int (*access)(struct vm_area_struct___446 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___446 *);
	int (*set_policy)(struct vm_area_struct___446 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___446 *, long unsigned int);
	struct page___446 * (*find_special_page)(struct vm_area_struct___446 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___446 {
	struct task_struct___447 *task;
	struct core_thread___446 *next;
};

struct core_state___446 {
	atomic_t nr_threads;
	struct core_thread___446 dumper;
	struct completion startup;
};

struct key___413;

struct ucounts___310;

struct user_namespace___310 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___310 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___29 ns;
	long unsigned int flags;
	struct key___413 *persistent_keyring_register;
	struct rw_semaphore___447 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___310 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___433 {
	struct vm_area_struct___446 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___446 *cow_page;
	struct mem_cgroup___178 *memcg;
	struct page___446 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___446 prealloc_pte;
};

struct shrink_control___178 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___178 *memcg;
};

struct shrinker___178 {
	long unsigned int (*count_objects)(struct shrinker___178 *, struct shrink_control___178 *);
	long unsigned int (*scan_objects)(struct shrinker___178 *, struct shrink_control___178 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct user_struct___413 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___413 *uid_keyring;
	struct key___413 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___413 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___413 *session_keyring;
	struct key___413 *process_keyring;
	struct key___413 *thread_keyring;
	struct key___413 *request_key_auth;
	void *security;
	struct user_struct___413 *user;
	struct user_namespace___310 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___101;

struct cgroup_namespace___294;

struct nsproxy___340 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net___101 *net_ns;
	struct cgroup_namespace___294 *cgroup_ns;
};

struct signal_struct___320 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___447 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___447 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___247 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___247 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___446 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___247 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___235;

struct bio_list___235 {
	struct bio___235 *head;
	struct bio___235 *tail;
};

struct bdi_writeback_congested___235;

struct bdi_writeback___235 {
	struct backing_dev_info___235 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___235 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___294 *memcg_css;
	struct cgroup_subsys_state___294 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___235 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___235 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___413 *dev;
	struct device___413 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___445 *debug_dir;
	struct dentry___445 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___294 {
	struct cgroup_subsys_state___294 *subsys[13];
	refcount_t refcount;
	struct css_set___294 *dom_cset;
	struct cgroup___294 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___294 *mg_src_cgrp;
	struct cgroup___294 *mg_dst_cgrp;
	struct css_set___294 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___445;

struct pipe_buffer___126;

struct pipe_inode_info___126 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___446 *tmp_page;
	struct fasync_struct___445 *fasync_readers;
	struct fasync_struct___445 *fasync_writers;
	struct pipe_buffer___126 *bufs;
	struct user_struct___413 *user;
};

struct vm_struct___349 {
	struct vm_struct___349 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___446 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___332 {
	struct task_struct___447 task;
	long unsigned int stack[8192];
};

struct kset___432;

struct kobj_type___432;

struct kobject___433 {
	const char *name;
	struct list_head entry;
	struct kobject___433 *parent;
	struct kset___432 *kset;
	struct kobj_type___432 *ktype;
	struct kernfs_node___440 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___413 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___413 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___413;

struct bus_type___413;

struct device_driver___413;

struct dev_pm_domain___413;

struct dma_map_ops___185;

struct fwnode_handle___333;

struct class___413;

struct attribute_group___410;

struct device___413 {
	struct device___413 *parent;
	struct device_private *p;
	struct kobject___433 kobj;
	const char *init_name;
	const struct device_type___413 *type;
	struct mutex mutex;
	struct bus_type___413 *bus;
	struct device_driver___413 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___413 power;
	struct dev_pm_domain___413 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___185 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___333 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___413 *class;
	const struct attribute_group___410 **groups;
	void (*release)(struct device___413 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___445;

struct super_block___445;

struct dentry___445 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___445 *d_parent;
	struct qstr d_name;
	struct inode___445 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___445 *d_op;
	struct super_block___445 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___445;

struct block_device___445;

struct inode___445 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___445 *i_op;
	struct super_block___445 *i_sb;
	struct address_space___445 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___447 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___235 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___445 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___445 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___126 *i_pipe;
		struct block_device___445 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___445 {
	int (*d_revalidate)(struct dentry___445 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___445 *, unsigned int);
	int (*d_hash)(const struct dentry___445 *, struct qstr *);
	int (*d_compare)(const struct dentry___445 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___445 *);
	int (*d_init)(struct dentry___445 *);
	void (*d_release)(struct dentry___445 *);
	void (*d_prune)(struct dentry___445 *);
	void (*d_iput)(struct dentry___445 *, struct inode___445 *);
	char * (*d_dname)(struct dentry___445 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___446 *);
	int (*d_manage)(const struct path___446 *, bool);
	struct dentry___445 * (*d_real)(struct dentry___445 *, const struct inode___445 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___445;

struct mem_dqinfo___445 {
	struct quota_format_type___445 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___445;

struct quota_info___445 {
	unsigned int flags;
	struct rw_semaphore___447 dqio_sem;
	struct inode___445 *files[3];
	struct mem_dqinfo___445 info[3];
	const struct quota_format_ops___445 *ops[3];
};

struct rcuwait___445 {
	struct task_struct___447 *task;
};

struct percpu_rw_semaphore___445 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___447 rw_sem;
	struct rcuwait___445 writer;
	int readers_block;
};

struct sb_writers___445 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___445 rw_sem[3];
};

struct file_system_type___445;

struct super_operations___445;

struct dquot_operations___445;

struct quotactl_ops___445;

struct super_block___445 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___445 *s_type;
	const struct super_operations___445 *s_op;
	const struct dquot_operations___445 *dq_op;
	const struct quotactl_ops___445 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___445 *s_root;
	struct rw_semaphore___447 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___445 *s_bdev;
	struct backing_dev_info___235 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___445 s_dquot;
	struct sb_writers___445 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___445 *s_d_op;
	int cleancache_poolid;
	struct shrinker___178 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___310 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___445 {
	struct file___445 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___445 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___445 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___445 *ia_file;
};

struct dquot___445 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___445 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___445 {
	int qf_fmt_id;
	const struct quota_format_ops___445 *qf_ops;
	struct module___371 *qf_owner;
	struct quota_format_type___445 *qf_next;
};

struct quota_format_ops___445 {
	int (*check_quota_file)(struct super_block___445 *, int);
	int (*read_file_info)(struct super_block___445 *, int);
	int (*write_file_info)(struct super_block___445 *, int);
	int (*free_file_info)(struct super_block___445 *, int);
	int (*read_dqblk)(struct dquot___445 *);
	int (*commit_dqblk)(struct dquot___445 *);
	int (*release_dqblk)(struct dquot___445 *);
	int (*get_next_id)(struct super_block___445 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___445 {
	int (*write_dquot)(struct dquot___445 *);
	struct dquot___445 * (*alloc_dquot)(struct super_block___445 *, int);
	void (*destroy_dquot)(struct dquot___445 *);
	int (*acquire_dquot)(struct dquot___445 *);
	int (*release_dquot)(struct dquot___445 *);
	int (*mark_dirty)(struct dquot___445 *);
	int (*write_info)(struct super_block___445 *, int);
	qsize_t * (*get_reserved_space)(struct inode___445 *);
	int (*get_projid)(struct inode___445 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___445 *, qsize_t *);
	int (*get_next_id)(struct super_block___445 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___445 {
	int (*quota_on)(struct super_block___445 *, int, int, const struct path___446 *);
	int (*quota_off)(struct super_block___445 *, int);
	int (*quota_enable)(struct super_block___445 *, unsigned int);
	int (*quota_disable)(struct super_block___445 *, unsigned int);
	int (*quota_sync)(struct super_block___445 *, int);
	int (*set_info)(struct super_block___445 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___445 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___445 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___445 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___445 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___445 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___371 {
	struct kobject___433 kobj;
	struct module___371 *mod;
	struct kobject___433 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___371 {
	struct module___371 *mod;
	struct latch_tree_node node;
};

struct module_layout___371 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___371 mtn;
};

struct module_attribute___371;

struct kernel_param___371;

struct module___371 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___371 mkobj;
	struct module_attribute___371 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___433 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___371 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___371 core_layout;
	struct module_layout___371 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___198;

struct address_space_operations___445 {
	int (*writepage)(struct page___446 *, struct writeback_control___198 *);
	int (*readpage)(struct file___445 *, struct page___446 *);
	int (*writepages)(struct address_space___445 *, struct writeback_control___198 *);
	int (*set_page_dirty)(struct page___446 *);
	int (*readpages)(struct file___445 *, struct address_space___445 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___445 *, struct address_space___445 *, loff_t, unsigned int, unsigned int, struct page___446 **, void **);
	int (*write_end)(struct file___445 *, struct address_space___445 *, loff_t, unsigned int, unsigned int, struct page___446 *, void *);
	sector_t (*bmap)(struct address_space___445 *, sector_t);
	void (*invalidatepage)(struct page___446 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___446 *, gfp_t);
	void (*freepage)(struct page___446 *);
	ssize_t (*direct_IO)(struct kiocb___445 *, struct iov_iter___212 *);
	int (*migratepage)(struct address_space___445 *, struct page___446 *, struct page___446 *, enum migrate_mode);
	bool (*isolate_page)(struct page___446 *, isolate_mode_t);
	void (*putback_page)(struct page___446 *);
	int (*launder_page)(struct page___446 *);
	int (*is_partially_uptodate)(struct page___446 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___446 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___445 *, struct page___446 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___445 *, sector_t *);
	void (*swap_deactivate)(struct file___445 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___198 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___235 *wb;
	struct inode___445 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___237;

struct iov_iter___212 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___237 *bvec;
		struct pipe_inode_info___126 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___445 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___445 *bd_inode;
	struct super_block___445 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___445 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___235 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___445 {
	struct dentry___445 * (*lookup)(struct inode___445 *, struct dentry___445 *, unsigned int);
	const char * (*get_link)(struct dentry___445 *, struct inode___445 *, struct delayed_call *);
	int (*permission)(struct inode___445 *, int);
	struct posix_acl * (*get_acl)(struct inode___445 *, int);
	int (*readlink)(struct dentry___445 *, char *, int);
	int (*create)(struct inode___445 *, struct dentry___445 *, umode_t, bool);
	int (*link)(struct dentry___445 *, struct inode___445 *, struct dentry___445 *);
	int (*unlink)(struct inode___445 *, struct dentry___445 *);
	int (*symlink)(struct inode___445 *, struct dentry___445 *, const char *);
	int (*mkdir)(struct inode___445 *, struct dentry___445 *, umode_t);
	int (*rmdir)(struct inode___445 *, struct dentry___445 *);
	int (*mknod)(struct inode___445 *, struct dentry___445 *, umode_t, dev_t);
	int (*rename)(struct inode___445 *, struct dentry___445 *, struct inode___445 *, struct dentry___445 *, unsigned int);
	int (*setattr)(struct dentry___445 *, struct iattr___445 *);
	int (*getattr)(const struct path___446 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___445 *, char *, size_t);
	int (*fiemap)(struct inode___445 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___445 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___445 *, struct dentry___445 *, struct file___445 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___445 *, struct dentry___445 *, umode_t);
	int (*set_acl)(struct inode___445 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___445 {
	void (*fl_copy_lock)(struct file_lock___445 *, struct file_lock___445 *);
	void (*fl_release_private)(struct file_lock___445 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___445;

struct file_lock___445 {
	struct file_lock___445 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___445 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___445 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___445 *fl_ops;
	const struct lock_manager_operations___445 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___445 {
	int (*lm_compare_owner)(struct file_lock___445 *, struct file_lock___445 *);
	long unsigned int (*lm_owner_key)(struct file_lock___445 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___445 *);
	int (*lm_grant)(struct file_lock___445 *, int);
	bool (*lm_break)(struct file_lock___445 *);
	int (*lm_change)(struct file_lock___445 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___445 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___445 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___445 *fa_next;
	struct file___445 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___445 {
	const char *name;
	int fs_flags;
	struct dentry___445 * (*mount)(struct file_system_type___445 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___445 *);
	struct module___371 *owner;
	struct file_system_type___445 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___445 {
	struct inode___445 * (*alloc_inode)(struct super_block___445 *);
	void (*destroy_inode)(struct inode___445 *);
	void (*dirty_inode)(struct inode___445 *, int);
	int (*write_inode)(struct inode___445 *, struct writeback_control___198 *);
	int (*drop_inode)(struct inode___445 *);
	void (*evict_inode)(struct inode___445 *);
	void (*put_super)(struct super_block___445 *);
	int (*sync_fs)(struct super_block___445 *, int);
	int (*freeze_super)(struct super_block___445 *);
	int (*freeze_fs)(struct super_block___445 *);
	int (*thaw_super)(struct super_block___445 *);
	int (*unfreeze_fs)(struct super_block___445 *);
	int (*statfs)(struct dentry___445 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___445 *, int *, char *);
	void (*umount_begin)(struct super_block___445 *);
	int (*show_options)(struct seq_file___384 *, struct dentry___445 *);
	int (*show_devname)(struct seq_file___384 *, struct dentry___445 *);
	int (*show_path)(struct seq_file___384 *, struct dentry___445 *);
	int (*show_stats)(struct seq_file___384 *, struct dentry___445 *);
	ssize_t (*quota_read)(struct super_block___445 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___445 *, int, const char *, size_t, loff_t);
	struct dquot___445 ** (*get_dquots)(struct inode___445 *);
	int (*bdev_try_to_free_page)(struct super_block___445 *, struct page___446 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___445 *, struct shrink_control___178 *);
	long int (*free_cached_objects)(struct super_block___445 *, struct shrink_control___178 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___294)(struct file___445 *, wait_queue_head_t *, struct poll_table_struct___284 *);

struct poll_table_struct___284 {
	poll_queue_proc___294 _qproc;
	__poll_t _key;
};

struct seq_operations___384;

struct seq_file___384 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___384 *op;
	int poll_event;
	const struct file___445 *file;
	void *private;
};

typedef void bio_end_io_t___235(struct bio___235 *);

struct bio_vec___237 {
	struct page___446 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___235;

struct bio_set___235;

struct bio___235 {
	struct bio___235 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___235 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___235 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___237 *bi_io_vec;
	struct bio_set___235 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___237 bi_inline_vecs[0];
};

struct kobj_attribute___423 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___433 *, struct kobj_attribute___423 *, char *);
	ssize_t (*store)(struct kobject___433 *, struct kobj_attribute___423 *, const char *, size_t);
};

typedef void compound_page_dtor___433(struct page___446 *);

struct kernfs_root___439;

struct kernfs_elem_dir___439 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___439 *root;
};

struct kernfs_syscall_ops___439;

struct kernfs_root___439 {
	struct kernfs_node___440 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___439 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___439 {
	struct kernfs_node___440 *target_kn;
};

struct kernfs_ops___439;

struct kernfs_elem_attr___439 {
	const struct kernfs_ops___439 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___440 *notify_next;
};

struct kernfs_node___440 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___440 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___439 dir;
		struct kernfs_elem_symlink___439 symlink;
		struct kernfs_elem_attr___439 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___439;

struct kernfs_ops___439 {
	int (*open)(struct kernfs_open_file___439 *);
	void (*release)(struct kernfs_open_file___439 *);
	int (*seq_show)(struct seq_file___384 *, void *);
	void * (*seq_start)(struct seq_file___384 *, loff_t *);
	void * (*seq_next)(struct seq_file___384 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___384 *, void *);
	ssize_t (*read)(struct kernfs_open_file___439 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___439 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___439 *, struct vm_area_struct___446 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___439 *, struct poll_table_struct___284 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___439 {
	int (*remount_fs)(struct kernfs_root___439 *, int *, char *);
	int (*show_options)(struct seq_file___384 *, struct kernfs_root___439 *);
	int (*mkdir)(struct kernfs_node___440 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___440 *);
	int (*rename)(struct kernfs_node___440 *, struct kernfs_node___440 *, const char *);
	int (*show_path)(struct seq_file___384 *, struct kernfs_node___440 *, struct kernfs_root___439 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___439 {
	struct kernfs_node___440 *kn;
	struct file___445 *file;
	struct seq_file___384 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___433 *vm_ops;
};

struct sock___70;

struct kobj_ns_type_operations___70 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___70 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___101 *net;
} possible_net_t___92;

struct proto___70;

struct sock_common___70 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___70 *skc_prot;
	possible_net_t___92 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___70 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___91;

struct sk_buff_head___90 {
	struct sk_buff___91 *next;
	struct sk_buff___91 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___70;

struct socket_wq___71;

struct dst_entry___70;

struct socket___72;

struct net_device___90;

struct sock___70 {
	struct sock_common___70 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___90 sk_error_queue;
	struct sk_buff_head___90 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___91 *head;
		struct sk_buff___91 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___70 *sk_filter;
	union {
		struct socket_wq___71 *sk_wq;
		struct socket_wq___71 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___70 *sk_rx_dst;
	struct dst_entry___70 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___91 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___90 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___446 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___70 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___247 *sk_peer_pid;
	const struct cred___413 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___72 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___178 *sk_memcg;
	void (*sk_state_change)(struct sock___70 *);
	void (*sk_data_ready)(struct sock___70 *);
	void (*sk_write_space)(struct sock___70 *);
	void (*sk_error_report)(struct sock___70 *);
	int (*sk_backlog_rcv)(struct sock___70 *, struct sk_buff___91 *);
	struct sk_buff___91 * (*sk_validate_xmit_skb)(struct sock___70 *, struct net_device___90 *, struct sk_buff___91 *);
	void (*sk_destruct)(struct sock___70 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct bin_attribute___409;

struct attribute_group___410 {
	const char *name;
	umode_t (*is_visible)(struct kobject___433 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___433 *, struct bin_attribute___409 *, int);
	struct attribute **attrs;
	struct bin_attribute___409 **bin_attrs;
};

struct bin_attribute___409 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___445 *, struct kobject___433 *, struct bin_attribute___409 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___445 *, struct kobject___433 *, struct bin_attribute___409 *, char *, loff_t, size_t);
	int (*mmap)(struct file___445 *, struct kobject___433 *, struct bin_attribute___409 *, struct vm_area_struct___446 *);
};

struct sysfs_ops___432 {
	ssize_t (*show)(struct kobject___433 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___433 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___432;

struct kset___432 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___433 kobj;
	const struct kset_uevent_ops___432 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___432 {
	void (*release)(struct kobject___433 *);
	const struct sysfs_ops___432 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___70 * (*child_ns_type)(struct kobject___433 *);
	const void * (*namespace)(struct kobject___433 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___432 {
	int (* const filter)(struct kset___432 *, struct kobject___433 *);
	const char * (* const name)(struct kset___432 *, struct kobject___433 *);
	int (* const uevent)(struct kset___432 *, struct kobject___433 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___371 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___371 *);
	int (*get)(char *, const struct kernel_param___371 *);
	void (*free)(void *);
};

struct kparam_array___371;

struct kernel_param___371 {
	const char *name;
	struct module___371 *mod;
	const struct kernel_param_ops___371 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___371 *arr;
	};
};

struct kparam_array___371 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___371 *ops;
	void *elem;
};

struct module_attribute___371 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___371 *, struct module_kobject___371 *, char *);
	ssize_t (*store)(struct module_attribute___371 *, struct module_kobject___371 *, const char *, size_t);
	void (*setup)(struct module___371 *, const char *);
	int (*test)(struct module___371 *);
	void (*free)(struct module___371 *);
};

struct neighbour___70;

struct dst_ops___101 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___101 *);
	struct dst_entry___70 * (*check)(struct dst_entry___70 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___70 *);
	unsigned int (*mtu)(const struct dst_entry___70 *);
	u32 * (*cow_metrics)(struct dst_entry___70 *, long unsigned int);
	void (*destroy)(struct dst_entry___70 *);
	void (*ifdown)(struct dst_entry___70 *, struct net_device___90 *, int);
	struct dst_entry___70 * (*negative_advice)(struct dst_entry___70 *);
	void (*link_failure)(struct sk_buff___91 *);
	void (*update_pmtu)(struct dst_entry___70 *, struct sock___70 *, struct sk_buff___91 *, u32);
	void (*redirect)(struct dst_entry___70 *, struct sock___70 *, struct sk_buff___91 *);
	int (*local_out)(struct net___101 *, struct sock___70 *, struct sk_buff___91 *);
	struct neighbour___70 * (*neigh_lookup)(const struct dst_entry___70 *, struct sk_buff___91 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___70 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct dst_entry___70 {
	struct net_device___90 *dev;
	struct dst_ops___101 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___91 *);
	int (*output)(struct net___101 *, struct sock___70 *, struct sk_buff___91 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

typedef rx_handler_result_t rx_handler_func_t___90(struct sk_buff___91 **);

struct net_device_ops___90;

struct ethtool_ops___90;

struct l3mdev_ops___70;

struct ndisc_ops___41;

struct xfrmdev_ops___90;

struct tlsdev_ops___90;

struct header_ops___90;

struct inet6_dev___41;

struct netdev_rx_queue___90;

struct bpf_prog___80;

struct mini_Qdisc___82;

struct netdev_queue___90;

struct Qdisc___82;

struct rtnl_link_ops___82;

struct dcbnl_rtnl_ops___90;

struct net_device___90 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___90 *netdev_ops;
	const struct ethtool_ops___90 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___70 *l3mdev_ops;
	const struct ndisc_ops___41 *ndisc_ops;
	const struct xfrmdev_ops___90 *xfrmdev_ops;
	const struct tlsdev_ops___90 *tlsdev_ops;
	const struct header_ops___90 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___432 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___41 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___90 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___80 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___90 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___82 *miniq_ingress;
	struct netdev_queue___90 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___90 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___82 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___82 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___90 = 0,
		NETREG_REGISTERED___90 = 1,
		NETREG_UNREGISTERING___90 = 2,
		NETREG_UNREGISTERED___90 = 3,
		NETREG_RELEASED___90 = 4,
		NETREG_DUMMY___90 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___90 = 0,
		RTNL_LINK_INITIALIZING___90 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___90 *);
	struct netpoll_info *npinfo;
	possible_net_t___92 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___413 dev;
	const struct attribute_group___410 *sysfs_groups[4];
	const struct attribute_group___410 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___82 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___90 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide35;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct nf_bridge_info___90;

struct sk_buff___91 {
	union {
		struct {
			struct sk_buff___91 *next;
			struct sk_buff___91 *prev;
			union {
				struct net_device___90 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___70 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___91 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___90 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___90;

struct netns_frags___90 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___90 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ip_ra_chain___36;

struct fib_rules_ops___70;

struct tcp_congestion_ops___16;

struct tcp_fastopen_context___16;

struct fib_notifier_ops___71;

struct netns_ipv4___90 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___36 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___70 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___70 *fibnl;
	struct sock___70 **icmp_sk;
	struct sock___70 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___70 **tcp_sk;
	struct netns_frags___90 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops___16 *tcp_congestion_control;
	struct tcp_fastopen_context___16 *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___70 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___71 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___71 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct netns_ipv6___101 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___90 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___101 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___70 *fib6_rules_ops;
	struct sock___70 **icmp_sk;
	struct sock___70 *ndisc_sk;
	struct sock___70 *tcp_sk;
	struct sock___70 *igmp_sk;
	struct sock___70 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___70 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___71 *notifier_ops;
	struct fib_notifier_ops___71 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___71 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___70 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___90 {
	struct netns_frags___90 frags;
};

struct netns_xfrm___101 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___70 *nlsk;
	struct sock___70 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___101 xfrm4_dst_ops;
	struct dst_ops___101 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct net___101 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___310 *user_ns;
	struct ucounts___310 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___29 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___70 *rtnl;
	struct sock___70 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___90 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___90 ipv4;
	struct netns_ipv6___101 ipv6;
	struct netns_sctp___71 sctp;
	struct netns_nf___12 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___90 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___70 *nfnl;
	struct sock___70 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___101 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___70 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___80 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neigh_table___70;

struct neigh_parms___70;

struct neigh_ops___70;

struct neighbour___70 {
	struct neighbour___70 *next;
	struct neigh_table___70 *tbl;
	struct neigh_parms___70 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___90 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___70 *, struct sk_buff___91 *);
	const struct neigh_ops___70 *ops;
	struct callback_head rcu;
	struct net_device___90 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct crypto_async_request___35;

typedef void (*crypto_completion_t___35)(struct crypto_async_request___35 *, int);

struct crypto_tfm___35;

struct crypto_async_request___35 {
	struct list_head list;
	crypto_completion_t___35 complete;
	void *data;
	struct crypto_tfm___35 *tfm;
	u32 flags;
};

struct crypto_ablkcipher___35;

struct ablkcipher_request___35;

struct ablkcipher_tfm___35 {
	int (*setkey)(struct crypto_ablkcipher___35 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___35 *);
	int (*decrypt)(struct ablkcipher_request___35 *);
	struct crypto_ablkcipher___35 *base;
	unsigned int ivsize;
	unsigned int reqsize;
};

struct blkcipher_desc___35;

struct blkcipher_tfm___35 {
	void *iv;
	int (*setkey)(struct crypto_tfm___35 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___35 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___35 *, struct scatterlist *, struct scatterlist *, unsigned int);
};

struct cipher_tfm___35 {
	int (*cit_setkey)(struct crypto_tfm___35 *, const u8 *, unsigned int);
	void (*cit_encrypt_one)(struct crypto_tfm___35 *, u8 *, const u8 *);
	void (*cit_decrypt_one)(struct crypto_tfm___35 *, u8 *, const u8 *);
};

struct compress_tfm___35 {
	int (*cot_compress)(struct crypto_tfm___35 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*cot_decompress)(struct crypto_tfm___35 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___35;

struct crypto_tfm___35 {
	u32 crt_flags;
	union {
		struct ablkcipher_tfm___35 ablkcipher;
		struct blkcipher_tfm___35 blkcipher;
		struct cipher_tfm___35 cipher;
		struct compress_tfm___35 compress;
	} crt_u;
	void (*exit)(struct crypto_tfm___35 *);
	struct crypto_alg___35 *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct ablkcipher_request___35 {
	struct crypto_async_request___35 base;
	unsigned int nbytes;
	void *info;
	struct scatterlist *src;
	struct scatterlist *dst;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_blkcipher___35;

struct blkcipher_desc___35 {
	struct crypto_blkcipher___35 *tfm;
	void *info;
	u32 flags;
};

struct crypto_blkcipher___35 {
	struct crypto_tfm___35 base;
};

struct ablkcipher_alg___35 {
	int (*setkey)(struct crypto_ablkcipher___35 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___35 *);
	int (*decrypt)(struct ablkcipher_request___35 *);
	int (*givencrypt)(struct skcipher_givcrypt_request *);
	int (*givdecrypt)(struct skcipher_givcrypt_request *);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct crypto_ablkcipher___35 {
	struct crypto_tfm___35 base;
};

struct blkcipher_alg___35 {
	int (*setkey)(struct crypto_tfm___35 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___35 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___35 *, struct scatterlist *, struct scatterlist *, unsigned int);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct cipher_alg___35 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___35 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___35 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___35 *, u8 *, const u8 *);
};

struct compress_alg___35 {
	int (*coa_compress)(struct crypto_tfm___35 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___35 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___35 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type *cra_type;
	union {
		struct ablkcipher_alg___35 ablkcipher;
		struct blkcipher_alg___35 blkcipher;
		struct cipher_alg___35 cipher;
		struct compress_alg___35 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___35 *);
	void (*cra_exit)(struct crypto_tfm___35 *);
	void (*cra_destroy)(struct crypto_alg___35 *);
	struct module___371 *cra_module;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct crypto_cipher___19 {
	struct crypto_tfm___35 base;
};

struct msghdr___73 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___212 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___445 *msg_iocb;
};

struct socket_wq___71 {
	wait_queue_head_t wait;
	struct fasync_struct___445 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___71;

struct socket___72 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___71 *wq;
	struct file___445 *file;
	struct sock___70 *sk;
	const struct proto_ops___71 *ops;
};

typedef int (*sk_read_actor_t___70)(read_descriptor_t *, struct sk_buff___91 *, unsigned int, size_t);

struct proto_ops___71 {
	int family;
	struct module___371 *owner;
	int (*release)(struct socket___72 *);
	int (*bind)(struct socket___72 *, struct sockaddr *, int);
	int (*connect)(struct socket___72 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___72 *, struct socket___72 *);
	int (*accept)(struct socket___72 *, struct socket___72 *, int, bool);
	int (*getname)(struct socket___72 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___445 *, struct socket___72 *, struct poll_table_struct___284 *);
	int (*ioctl)(struct socket___72 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___72 *, int);
	int (*shutdown)(struct socket___72 *, int);
	int (*setsockopt)(struct socket___72 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___72 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___72 *, struct msghdr___73 *, size_t);
	int (*recvmsg)(struct socket___72 *, struct msghdr___73 *, size_t, int);
	int (*mmap)(struct file___445 *, struct socket___72 *, struct vm_area_struct___446 *);
	ssize_t (*sendpage)(struct socket___72 *, struct page___446 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___72 *, loff_t *, struct pipe_inode_info___126 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___70 *, int);
	int (*peek_len)(struct socket___72 *);
	int (*read_sock)(struct sock___70 *, read_descriptor_t *, sk_read_actor_t___70);
	int (*sendpage_locked)(struct sock___70 *, struct page___446 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___70 *, struct msghdr___73 *, size_t);
	int (*set_rcvlowat)(struct sock___70 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct dev_pm_ops___413 {
	int (*prepare)(struct device___413 *);
	void (*complete)(struct device___413 *);
	int (*suspend)(struct device___413 *);
	int (*resume)(struct device___413 *);
	int (*freeze)(struct device___413 *);
	int (*thaw)(struct device___413 *);
	int (*poweroff)(struct device___413 *);
	int (*restore)(struct device___413 *);
	int (*suspend_late)(struct device___413 *);
	int (*resume_early)(struct device___413 *);
	int (*freeze_late)(struct device___413 *);
	int (*thaw_early)(struct device___413 *);
	int (*poweroff_late)(struct device___413 *);
	int (*restore_early)(struct device___413 *);
	int (*suspend_noirq)(struct device___413 *);
	int (*resume_noirq)(struct device___413 *);
	int (*freeze_noirq)(struct device___413 *);
	int (*thaw_noirq)(struct device___413 *);
	int (*poweroff_noirq)(struct device___413 *);
	int (*restore_noirq)(struct device___413 *);
	int (*runtime_suspend)(struct device___413 *);
	int (*runtime_resume)(struct device___413 *);
	int (*runtime_idle)(struct device___413 *);
};

struct dev_pm_domain___413 {
	struct dev_pm_ops___413 ops;
	void (*detach)(struct device___413 *, bool);
	int (*activate)(struct device___413 *);
	void (*sync)(struct device___413 *);
	void (*dismiss)(struct device___413 *);
};

struct bus_type___413 {
	const char *name;
	const char *dev_name;
	struct device___413 *dev_root;
	const struct attribute_group___410 **bus_groups;
	const struct attribute_group___410 **dev_groups;
	const struct attribute_group___410 **drv_groups;
	int (*match)(struct device___413 *, struct device_driver___413 *);
	int (*uevent)(struct device___413 *, struct kobj_uevent_env *);
	int (*probe)(struct device___413 *);
	int (*remove)(struct device___413 *);
	void (*shutdown)(struct device___413 *);
	int (*online)(struct device___413 *);
	int (*offline)(struct device___413 *);
	int (*suspend)(struct device___413 *, pm_message_t);
	int (*resume)(struct device___413 *);
	int (*num_vf)(struct device___413 *);
	int (*dma_configure)(struct device___413 *);
	const struct dev_pm_ops___413 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___413 {
	const char *name;
	struct bus_type___413 *bus;
	struct module___371 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___413 *);
	int (*remove)(struct device___413 *);
	void (*shutdown)(struct device___413 *);
	int (*suspend)(struct device___413 *, pm_message_t);
	int (*resume)(struct device___413 *);
	const struct attribute_group___410 **groups;
	const struct dev_pm_ops___413 *pm;
	void (*coredump)(struct device___413 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___413 {
	const char *name;
	const struct attribute_group___410 **groups;
	int (*uevent)(struct device___413 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___413 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___413 *);
	const struct dev_pm_ops___413 *pm;
};

struct class___413 {
	const char *name;
	struct module___371 *owner;
	const struct attribute_group___410 **class_groups;
	const struct attribute_group___410 **dev_groups;
	struct kobject___433 *dev_kobj;
	int (*dev_uevent)(struct device___413 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___413 *, umode_t *);
	void (*class_release)(struct class___413 *);
	void (*dev_release)(struct device___413 *);
	int (*shutdown_pre)(struct device___413 *);
	const struct kobj_ns_type_operations___70 *ns_type;
	const void * (*namespace)(struct device___413 *);
	const struct dev_pm_ops___413 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___185 {
	void * (*alloc)(struct device___413 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___413 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___413 *, struct vm_area_struct___446 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___413 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___413 *, struct page___446 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___413 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___413 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___413 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___413 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___413 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___413 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___413 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___413 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___413 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___413 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___413 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___413 *, u64);
	u64 (*get_required_mask)(struct device___413 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___333;

struct fwnode_handle___333 {
	struct fwnode_handle___333 *secondary;
	const struct fwnode_operations___333 *ops;
};

struct fwnode_reference_args___333;

struct fwnode_endpoint___333;

struct fwnode_operations___333 {
	struct fwnode_handle___333 * (*get)(struct fwnode_handle___333 *);
	void (*put)(struct fwnode_handle___333 *);
	bool (*device_is_available)(const struct fwnode_handle___333 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___333 *, const struct device___413 *);
	bool (*property_present)(const struct fwnode_handle___333 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___333 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___333 *, const char *, const char **, size_t);
	struct fwnode_handle___333 * (*get_parent)(const struct fwnode_handle___333 *);
	struct fwnode_handle___333 * (*get_next_child_node)(const struct fwnode_handle___333 *, struct fwnode_handle___333 *);
	struct fwnode_handle___333 * (*get_named_child_node)(const struct fwnode_handle___333 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___333 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___333 *);
	struct fwnode_handle___333 * (*graph_get_next_endpoint)(const struct fwnode_handle___333 *, struct fwnode_handle___333 *);
	struct fwnode_handle___333 * (*graph_get_remote_endpoint)(const struct fwnode_handle___333 *);
	struct fwnode_handle___333 * (*graph_get_port_parent)(struct fwnode_handle___333 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___333 *, struct fwnode_endpoint___333 *);
};

struct fwnode_endpoint___333 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___333 *local_fwnode;
};

struct fwnode_reference_args___333 {
	struct fwnode_handle___333 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___126;

struct pipe_buffer___126 {
	struct page___446 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___126 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___126 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___126 *, struct pipe_buffer___126 *);
	void (*release)(struct pipe_inode_info___126 *, struct pipe_buffer___126 *);
	int (*steal)(struct pipe_inode_info___126 *, struct pipe_buffer___126 *);
	union {
		bool (*get)(struct pipe_inode_info___126 *, struct pipe_buffer___126 *);
		struct {
			void (*get)(struct pipe_inode_info___126 *, struct pipe_buffer___126 *);
		} __UNIQUE_ID_rh_kabi_hide21;
		union {		};
	};
};

struct nf_bridge_info___90 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___90 = 0,
		BRNF_PROTO_8021Q___90 = 1,
		BRNF_PROTO_PPPOE___90 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___90 *physindev;
	struct net_device___90 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

struct skb_frag_struct___20 {
	struct {
		struct page___446 *p;
	} page;
	__u32 page_offset;
	__u32 size;
};

typedef struct skb_frag_struct___20 skb_frag_t___20;

struct skb_shared_info___20 {
	__u8 __unused;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___91 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___20 frags[16];
};

struct ethtool_ops___90 {
	int (*get_settings)(struct net_device___90 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___90 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___90 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___90 *);
	void (*get_regs)(struct net_device___90 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___90 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___90 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___90 *);
	void (*set_msglevel)(struct net_device___90 *, u32);
	int (*nway_reset)(struct net_device___90 *);
	u32 (*get_link)(struct net_device___90 *);
	int (*get_eeprom_len)(struct net_device___90 *);
	int (*get_eeprom)(struct net_device___90 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___90 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___90 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___90 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___90 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___90 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___90 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___90 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___90 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___90 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___90 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___90 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___90 *);
	void (*complete)(struct net_device___90 *);
	u32 (*get_priv_flags)(struct net_device___90 *);
	int (*set_priv_flags)(struct net_device___90 *, u32);
	int (*get_sset_count)(struct net_device___90 *, int);
	int (*get_rxnfc)(struct net_device___90 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___90 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___90 *, struct ethtool_flash *);
	int (*reset)(struct net_device___90 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___90 *);
	u32 (*get_rxfh_indir_size)(struct net_device___90 *);
	int (*get_rxfh)(struct net_device___90 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___90 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___90 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___90 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___90 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___90 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___90 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___90 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___90 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___90 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___90 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___90 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___90 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___90 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___90 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___90 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___90 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___90 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___90 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___90 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___90 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___90 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	int (*get_fecparam)(struct net_device___90 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___90 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___90 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___90 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___90 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___90;

struct inet_frags___90 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___90 *, const void *);
	void (*destructor)(struct inet_frag_queue___90 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___90 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___91 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___91 *fragments_tail;
	struct sk_buff___91 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___90 *net;
	struct callback_head rcu;
};

struct ip_ra_chain___36 {
	struct ip_ra_chain___36 *next;
	struct sock___70 *sk;
	union {
		void (*destructor)(struct sock___70 *);
		struct sock___70 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___70;

struct fib_lookup_arg___70;

struct fib_rules_ops___70 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___70 *, struct flowi *, int, struct fib_lookup_arg___70 *);
	bool (*suppress)(struct fib_rule___70 *, struct fib_lookup_arg___70 *);
	int (*match)(struct fib_rule___70 *, struct flowi *, int);
	int (*configure)(struct fib_rule___70 *, struct sk_buff___91 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___70 *);
	int (*compare)(struct fib_rule___70 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___70 *, struct sk_buff___91 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___70 *);
	void (*flush_cache)(struct fib_rules_ops___70 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___371 *owner;
	struct net___101 *fro_net;
	struct callback_head rcu;
};

struct tcp_congestion_ops___16 {
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___70 *);
	void (*release)(struct sock___70 *);
	u32 (*ssthresh)(struct sock___70 *);
	void (*cong_avoid)(struct sock___70 *, u32, u32);
	void (*set_state)(struct sock___70 *, u8);
	void (*cwnd_event)(struct sock___70 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___70 *, u32);
	u32 (*undo_cwnd)(struct sock___70 *);
	void (*pkts_acked)(struct sock___70 *, const struct ack_sample *);
	u32 (*min_tso_segs)(struct sock___70 *);
	u32 (*sndbuf_expand)(struct sock___70 *);
	void (*cong_control)(struct sock___70 *, const struct rate_sample *);
	size_t (*get_info)(struct sock___70 *, u32, int *, union tcp_cc_info *);
	char name[16];
	struct module___371 *owner;
};

struct tcp_fastopen_context___16 {
	struct crypto_cipher___19 *tfm;
	__u8 key[16];
	struct callback_head rcu;
};

struct fib_notifier_ops___71 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___101 *);
	int (*fib_dump)(struct net___101 *, struct notifier_block *);
	struct module___371 *owner;
	struct callback_head rcu;
};

struct ucounts___310 {
	struct hlist_node node;
	struct user_namespace___310 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_prog_aux___83;

struct bpf_prog___80 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___83 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

typedef int (*key_restrict_link_func_t___414)(struct key___413 *, const struct key_type *, const union key_payload *, struct key___413 *);

struct key_restriction___413;

struct key___413 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___447 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___413 *restrict_link;
};

struct key_restriction___413 {
	key_restrict_link_func_t___414 check;
	struct key___413 *key;
	struct key_type *keytype;
};

struct seq_operations___384 {
	void * (*start)(struct seq_file___384 *, loff_t *);
	void (*stop)(struct seq_file___384 *, void *);
	void * (*next)(struct seq_file___384 *, void *, loff_t *);
	int (*show)(struct seq_file___384 *, void *);
};

struct pernet_operations___91 {
	struct list_head list;
	int (*init)(struct net___101 *);
	void (*exit)(struct net___101 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___90 {
	int (*ieee_getets)(struct net_device___90 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___90 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___90 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___90 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___90 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___90 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___90 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___90 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___90 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___90 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___90 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___90 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___90 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___90 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___90 *);
	u8 (*setstate)(struct net_device___90 *, u8);
	void (*getpermhwaddr)(struct net_device___90 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___90 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___90 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___90 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___90 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___90 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___90 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___90 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___90 *, int, u8 *);
	void (*setpfccfg)(struct net_device___90 *, int, u8);
	void (*getpfccfg)(struct net_device___90 *, int, u8 *);
	u8 (*setall)(struct net_device___90 *);
	u8 (*getcap)(struct net_device___90 *, int, u8 *);
	int (*getnumtcs)(struct net_device___90 *, int, u8 *);
	int (*setnumtcs)(struct net_device___90 *, int, u8);
	u8 (*getpfcstate)(struct net_device___90 *);
	void (*setpfcstate)(struct net_device___90 *, u8);
	void (*getbcncfg)(struct net_device___90 *, int, u32 *);
	void (*setbcncfg)(struct net_device___90 *, int, u32);
	void (*getbcnrp)(struct net_device___90 *, int, u8 *);
	void (*setbcnrp)(struct net_device___90 *, int, u8);
	int (*setapp)(struct net_device___90 *, u8, u16, u8);
	int (*getapp)(struct net_device___90 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___90 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___90 *, int, u8);
	u8 (*getdcbx)(struct net_device___90 *);
	u8 (*setdcbx)(struct net_device___90 *, u8);
	int (*peer_getappinfo)(struct net_device___90 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___90 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___90 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___90 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___90 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___90 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___294 {
	refcount_t count;
	struct ns_common___29 ns;
	struct user_namespace___310 *user_ns;
	struct ucounts___310 *ucounts;
	struct css_set___294 *root_cset;
};

struct bpf_map___295;

struct bpf_map_ops___294 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___295 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___295 *, struct file___445 *);
	void (*map_free)(struct bpf_map___295 *);
	int (*map_get_next_key)(struct bpf_map___295 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___295 *);
	void * (*map_lookup_elem)(struct bpf_map___295 *, void *);
	int (*map_update_elem)(struct bpf_map___295 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___295 *, void *);
	int (*map_push_elem)(struct bpf_map___295 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___295 *, void *);
	int (*map_peek_elem)(struct bpf_map___295 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___295 *, struct file___445 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___295 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___295 *, void *, struct seq_file___384 *);
	int (*map_check_btf)(const struct bpf_map___295 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___295 {
	const struct bpf_map_ops___294 *ops;
	struct bpf_map___295 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___413 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___90;

struct bpf_map_dev_ops___90 {
	int (*map_get_next_key)(struct bpf_offloaded_map___90 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___90 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___90 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___90 *, void *);
};

struct bpf_offloaded_map___90 {
	struct bpf_map___295 map;
	struct net_device___90 *netdev;
	const struct bpf_map_dev_ops___90 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___80 {
	int (*test_run)(struct bpf_prog___80 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___80 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___80 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___80 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___80 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___80 *, u32 *);
};

struct bpf_prog_offload_ops___80 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___80 *);
	int (*translate)(struct bpf_prog___80 *);
	void (*destroy)(struct bpf_prog___80 *);
};

struct bpf_prog_offload___80 {
	struct bpf_prog___80 *prog;
	struct net_device___90 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___80 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___83 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___80 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___80 *ops;
	struct bpf_map___295 **used_maps;
	struct bpf_prog___80 *prog;
	struct user_struct___413 *user;
	u64 load_time;
	struct bpf_map___295 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___80 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___80 {
	struct bpf_prog___80 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___80 {
	struct callback_head rcu;
	struct bpf_prog_array_item___80 items[0];
};

struct cgroup_bpf___80 {
	struct bpf_prog_array___80 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___80 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___295;

typedef void (*kthread_work_func_t___295)(struct kthread_work___295 *);

struct kthread_worker___295;

struct kthread_work___295 {
	struct list_head node;
	kthread_work_func_t___295 func;
	struct kthread_worker___295 *worker;
	int canceling;
};

struct kthread_worker___295 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___447 *task;
	struct kthread_work___295 *current_work;
};

struct kthread_delayed_work___294 {
	struct kthread_work___295 work;
	struct timer_list timer;
};

struct psi_group___294 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___295 *poll_kworker;
	struct kthread_delayed_work___294 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___294;

struct cgroup_rstat_cpu___294;

struct cgroup___294 {
	struct cgroup_subsys_state___294 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___440 *kn;
	struct cgroup_file___294 procs_file;
	struct cgroup_file___294 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___294 *subsys[13];
	struct cgroup_root___294 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___294 *dom_cgrp;
	struct cgroup_rstat_cpu___294 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___80 bpf;
	atomic_t congestion_count;
	struct cgroup___294 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___294 psi;
	int ancestor_ids[0];
};

struct cftype___294;

struct cgroup_subsys___294 {
	struct cgroup_subsys_state___294 * (*css_alloc)(struct cgroup_subsys_state___294 *);
	int (*css_online)(struct cgroup_subsys_state___294 *);
	void (*css_offline)(struct cgroup_subsys_state___294 *);
	void (*css_released)(struct cgroup_subsys_state___294 *);
	void (*css_free)(struct cgroup_subsys_state___294 *);
	void (*css_reset)(struct cgroup_subsys_state___294 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___294 *, int);
	int (*css_extra_stat_show)(struct seq_file___384 *, struct cgroup_subsys_state___294 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___447 *);
	void (*cancel_fork)(struct task_struct___447 *);
	void (*fork)(struct task_struct___447 *);
	void (*exit)(struct task_struct___447 *);
	void (*free)(struct task_struct___447 *);
	void (*bind)(struct cgroup_subsys_state___294 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___294 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___294 *dfl_cftypes;
	struct cftype___294 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___294 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___294 *updated_children;
	struct cgroup___294 *updated_next;
};

struct cgroup_root___294 {
	struct kernfs_root___439 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___294 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___294 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___294 *ss;
	struct list_head node;
	struct kernfs_ops___439 *kf_ops;
	int (*open)(struct kernfs_open_file___439 *);
	void (*release)(struct kernfs_open_file___439 *);
	u64 (*read_u64)(struct cgroup_subsys_state___294 *, struct cftype___294 *);
	s64 (*read_s64)(struct cgroup_subsys_state___294 *, struct cftype___294 *);
	int (*seq_show)(struct seq_file___384 *, void *);
	void * (*seq_start)(struct seq_file___384 *, loff_t *);
	void * (*seq_next)(struct seq_file___384 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___384 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___294 *, struct cftype___294 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___294 *, struct cftype___294 *, s64);
	ssize_t (*write)(struct kernfs_open_file___439 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___439 *, struct poll_table_struct___284 *);
};

struct xdp_rxq_info___90 {
	struct net_device___90 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___90 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___90 *dev_rx;
};

struct netlink_callback___92 {
	struct sk_buff___91 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___92 *);
	int (*dump)(struct sk_buff___91 *, struct netlink_callback___92 *);
	int (*done)(struct netlink_callback___92 *);
	void *data;
	struct module___371 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___90 {
	int (*create)(struct sk_buff___91 *, struct net_device___90 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___91 *, unsigned char *);
	int (*cache)(const struct neighbour___70 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___90 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___90 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___90 *, int);
	int poll_owner;
	struct net_device___90 *dev;
	struct sk_buff___91 *gro_list;
	struct sk_buff___91 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___90 {
	struct net_device___90 *dev;
	struct Qdisc___82 *qdisc;
	struct Qdisc___82 *qdisc_sleeping;
	struct kobject___433 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___90 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem___3 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___82 {
	struct sk_buff___91 *head;
	struct sk_buff___91 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___82;

struct Qdisc___82 {
	int (*enqueue)(struct sk_buff___91 *, struct Qdisc___82 *, struct sk_buff___91 **);
	struct sk_buff___91 * (*dequeue)(struct Qdisc___82 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___82 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___90 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___90 gso_skb;
	struct qdisc_skb_head___82 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___82 *next_sched;
	struct sk_buff_head___90 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___90 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___433 kobj;
	struct net_device___90 *dev;
	long: 64;
	struct xdp_rxq_info___90 xdp_rxq;
	union {
		struct xdp_umem___3 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___90)(struct net_device___90 *, struct sk_buff___91 *, struct net_device___90 *);

struct netdev_bpf___90 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___80 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___80 *prog;
			const struct bpf_prog_offload_ops___80 *ops;
		} verifier;
		struct {
			struct bpf_prog___80 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___90 *offmap;
		};
		struct {
			struct xdp_umem___3 *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___90 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___91 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___90 {
	int (*tls_dev_add)(struct net_device___90 *, struct sock___70 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___90 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___90 *, struct sock___70 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___90 {
	int (*ndo_init)(struct net_device___90 *);
	void (*ndo_uninit)(struct net_device___90 *);
	int (*ndo_open)(struct net_device___90 *);
	int (*ndo_stop)(struct net_device___90 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___91 *, struct net_device___90 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___91 *, struct net_device___90 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___90 *, struct sk_buff___91 *, struct net_device___90 *, select_queue_fallback_t___90);
	void (*ndo_change_rx_flags)(struct net_device___90 *, int);
	void (*ndo_set_rx_mode)(struct net_device___90 *);
	int (*ndo_set_mac_address)(struct net_device___90 *, void *);
	int (*ndo_validate_addr)(struct net_device___90 *);
	int (*ndo_do_ioctl)(struct net_device___90 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___90 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___90 *, int);
	int (*ndo_neigh_setup)(struct net_device___90 *, struct neigh_parms___70 *);
	void (*ndo_tx_timeout)(struct net_device___90 *);
	void (*ndo_get_stats64)(struct net_device___90 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___90 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___90 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___90 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___90 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___90 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___90 *);
	int (*ndo_netpoll_setup)(struct net_device___90 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___90 *);
	int (*ndo_set_vf_mac)(struct net_device___90 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___90 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___90 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___90 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___90 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___90 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___90 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___90 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___90 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___90 *, int, struct sk_buff___91 *);
	int (*ndo_set_vf_guid)(struct net_device___90 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___90 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___90 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___90 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___90 *, const struct sk_buff___91 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___90 *, struct net_device___90 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___90 *, struct net_device___90 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___90 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___90 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___90 *, struct neighbour___70 *);
	void (*ndo_neigh_destroy)(struct net_device___90 *, struct neighbour___70 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___90 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___90 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___90 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___91 *, struct netlink_callback___92 *, struct net_device___90 *, struct net_device___90 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___90 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___90 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___91 *, u32, u32, struct net_device___90 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___90 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___90 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___90 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___90 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___90 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___90 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___90 *, struct net_device___90 *);
	void (*ndo_dfwd_del_station)(struct net_device___90 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___90 *);
	int (*ndo_set_tx_maxrate)(struct net_device___90 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___90 *);
	int (*ndo_change_proto_down)(struct net_device___90 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___90 *, struct sk_buff___91 *);
	void (*ndo_set_rx_headroom)(struct net_device___90 *, int);
	int (*ndo_bpf)(struct net_device___90 *, struct netdev_bpf___90 *);
	int (*ndo_xdp_xmit)(struct net_device___90 *, int, struct xdp_frame___90 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___90 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___90 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___70 {
	possible_net_t___92 net;
	struct net_device___90 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___70 *);
	void (*neigh_cleanup)(struct neighbour___70 *);
	struct neigh_table___70 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___70 {
	u32 (*l3mdev_fib_table)(const struct net_device___90 *);
	struct sk_buff___91 * (*l3mdev_l3_rcv)(struct net_device___90 *, struct sk_buff___91 *, u16);
	struct sk_buff___91 * (*l3mdev_l3_out)(struct net_device___90 *, struct sock___70 *, struct sk_buff___91 *, u16);
	struct dst_entry___70 * (*l3mdev_link_scope_lookup)(const struct net_device___90 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct ndisc_ops___41 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___90 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___90 *, struct neighbour___70 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___90 *, u8, struct neighbour___70 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___90 *, struct sk_buff___91 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___101 *, struct net_device___90 *, const struct prefix_info *, struct inet6_dev___41 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___41;

struct inet6_dev___41 {
	struct net_device___90 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___41 *mc_list;
	struct ifmcaddr6___41 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___16 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	u8 rndid[8];
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___70 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
};

struct tcf_proto___82;

struct mini_Qdisc___82 {
	struct tcf_proto___82 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___82 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___90 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___101 *, struct net_device___90 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___90 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___90 *, struct list_head *);
	size_t (*get_size)(const struct net_device___90 *);
	int (*fill_info)(struct sk_buff___91 *, const struct net_device___90 *);
	size_t (*get_xstats_size)(const struct net_device___90 *);
	int (*fill_xstats)(struct sk_buff___91 *, const struct net_device___90 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___90 *, struct net_device___90 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___90 *, const struct net_device___90 *);
	int (*fill_slave_info)(struct sk_buff___91 *, const struct net_device___90 *, const struct net_device___90 *);
	struct net___101 * (*get_link_net)(const struct net_device___90 *);
	size_t (*get_linkxstats_size)(const struct net_device___90 *, int);
	int (*fill_linkxstats)(struct sk_buff___91 *, const struct net_device___90 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___90 {
	struct list_head poll_list;
	struct sk_buff_head___90 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___90 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___82 *output_queue;
	struct Qdisc___82 **output_queue_tailp;
	struct sk_buff___91 *completion_queue;
	struct sk_buff_head___90 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___90 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___90 input_pkt_queue;
	struct napi_struct___90 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pneigh_entry___70;

struct neigh_hash_table___70;

struct neigh_table___70 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___90 *, __u32 *);
	bool (*key_eq)(const struct neighbour___70 *, const void *);
	int (*constructor)(struct neighbour___70 *);
	int (*pconstructor)(struct pneigh_entry___70 *);
	void (*pdestructor)(struct pneigh_entry___70 *);
	void (*proxy_redo)(struct sk_buff___91 *);
	char *id;
	struct neigh_parms___70 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___90 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___70 *nht;
	struct pneigh_entry___70 **phash_buckets;
};

struct neigh_ops___70 {
	int family;
	void (*solicit)(struct neighbour___70 *, struct sk_buff___91 *);
	void (*error_report)(struct neighbour___70 *, struct sk_buff___91 *);
	int (*output)(struct neighbour___70 *, struct sk_buff___91 *);
	int (*connected_output)(struct neighbour___70 *, struct sk_buff___91 *);
};

struct pneigh_entry___70 {
	struct pneigh_entry___70 *next;
	possible_net_t___92 net;
	struct net_device___90 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___70 {
	struct neighbour___70 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct bdi_writeback_congested___235 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___235 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___235 {
	struct bio___235 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___237 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___237 bip_inline_vecs[0];
};

struct bio_set___235 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___235 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___178 {
	struct mem_cgroup___178 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___178 {
	struct lruvec___446 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___178 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___178 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct gnet_dump___82 {
	spinlock_t *lock;
	struct sk_buff___91 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___82;

struct Qdisc_ops___82 {
	struct Qdisc_ops___82 *next;
	const struct Qdisc_class_ops___82 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___91 *, struct Qdisc___82 *, struct sk_buff___91 **);
	struct sk_buff___91 * (*dequeue)(struct Qdisc___82 *);
	struct sk_buff___91 * (*peek)(struct Qdisc___82 *);
	int (*init)(struct Qdisc___82 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___82 *);
	void (*destroy)(struct Qdisc___82 *);
	int (*change)(struct Qdisc___82 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___82 *);
	int (*change_tx_queue_len)(struct Qdisc___82 *, unsigned int);
	int (*dump)(struct Qdisc___82 *, struct sk_buff___91 *);
	int (*dump_stats)(struct Qdisc___82 *, struct gnet_dump___82 *);
	void (*ingress_block_set)(struct Qdisc___82 *, u32);
	void (*egress_block_set)(struct Qdisc___82 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___82 *);
	u32 (*egress_block_get)(struct Qdisc___82 *);
	struct module___371 *owner;
};

struct tcf_block___82;

struct Qdisc_class_ops___82 {
	unsigned int flags;
	struct netdev_queue___90 * (*select_queue)(struct Qdisc___82 *, struct tcmsg *);
	int (*graft)(struct Qdisc___82 *, long unsigned int, struct Qdisc___82 *, struct Qdisc___82 **, struct netlink_ext_ack *);
	struct Qdisc___82 * (*leaf)(struct Qdisc___82 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___82 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___82 *, u32);
	int (*change)(struct Qdisc___82 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___82 *, long unsigned int);
	void (*walk)(struct Qdisc___82 *, struct qdisc_walker *);
	struct tcf_block___82 * (*tcf_block)(struct Qdisc___82 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___82 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___82 *, long unsigned int);
	int (*dump)(struct Qdisc___82 *, long unsigned int, struct sk_buff___91 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___82 *, long unsigned int, struct gnet_dump___82 *);
};

struct tcf_chain___82;

struct tcf_block___82 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___101 *net;
	struct Qdisc___82 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___82 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___82;

struct tcf_proto_ops___82;

struct tcf_proto___82 {
	struct tcf_proto___82 *next;
	void *root;
	int (*classify)(struct sk_buff___91 *, const struct tcf_proto___82 *, struct tcf_result___82 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___82 *ops;
	struct tcf_chain___82 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___82 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___82 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___82 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___91 *, const struct tcf_proto___82 *, struct tcf_result___82 *);
	int (*init)(struct tcf_proto___82 *);
	void (*destroy)(struct tcf_proto___82 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___82 *, u32);
	void (*put)(struct tcf_proto___82 *, void *);
	int (*change)(struct net___101 *, struct sk_buff___91 *, struct tcf_proto___82 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___82 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___82 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___82 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___101 *, struct tcf_chain___82 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___101 *, struct tcf_proto___82 *, void *, struct sk_buff___91 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___91 *, struct net___101 *, void *);
	struct module___371 *owner;
	int flags;
};

struct tcf_chain___82 {
	struct mutex filter_chain_lock;
	struct tcf_proto___82 *filter_chain;
	struct list_head list;
	struct tcf_block___82 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___82 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___70 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___80 *prog;
};

struct bpf_redirect_info___80 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___295 *map;
	struct bpf_map___295 *map_to_flush;
	u32 kern_flags;
};

struct bpf_sock_ops_kern___5 {
	struct sock___70 *sk;
	u32 op;
	union {
		u32 args[4];
		u32 reply;
		u32 replylong[4];
	};
	u32 is_fullsock;
	u64 temp;
};

struct fib_rule___70 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___70 *ctarget;
	struct net___101 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___70 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___70 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___53;

struct timewait_sock_ops___49;

struct proto___70 {
	void (*close)(struct sock___70 *, long int);
	int (*pre_connect)(struct sock___70 *, struct sockaddr *, int);
	int (*connect)(struct sock___70 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___70 *, int);
	struct sock___70 * (*accept)(struct sock___70 *, int, int *, bool);
	int (*ioctl)(struct sock___70 *, int, long unsigned int);
	int (*init)(struct sock___70 *);
	void (*destroy)(struct sock___70 *);
	void (*shutdown)(struct sock___70 *, int);
	int (*setsockopt)(struct sock___70 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___70 *, int, int, char *, int *);
	void (*keepalive)(struct sock___70 *, int);
	int (*sendmsg)(struct sock___70 *, struct msghdr___73 *, size_t);
	int (*recvmsg)(struct sock___70 *, struct msghdr___73 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___70 *, struct page___446 *, int, size_t, int);
	int (*bind)(struct sock___70 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___70 *, struct sk_buff___91 *);
	void (*release_cb)(struct sock___70 *);
	int (*hash)(struct sock___70 *);
	void (*unhash)(struct sock___70 *);
	void (*rehash)(struct sock___70 *);
	int (*get_port)(struct sock___70 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___70 *);
	bool (*stream_memory_read)(const struct sock___70 *);
	void (*enter_memory_pressure)(struct sock___70 *);
	void (*leave_memory_pressure)(struct sock___70 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___53 *rsk_prot;
	struct timewait_sock_ops___49 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___371 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___70 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct request_sock___54;

struct request_sock_ops___53 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___70 *, struct request_sock___54 *);
	void (*send_ack)(const struct sock___70 *, struct sk_buff___91 *, struct request_sock___54 *);
	void (*send_reset)(const struct sock___70 *, struct sk_buff___91 *);
	void (*destructor)(struct request_sock___54 *);
	void (*syn_ack_timeout)(const struct request_sock___54 *);
};

struct timewait_sock_ops___49 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___70 *, struct sock___70 *, void *);
	void (*twsk_destructor)(struct sock___70 *);
};

struct request_sock___54 {
	struct sock_common___70 __req_common;
	struct request_sock___54 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___53 *rsk_ops;
	struct sock___70 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct fastopen_queue___9 {
	struct request_sock___54 *rskq_rst_head;
	struct request_sock___54 *rskq_rst_tail;
	spinlock_t lock;
	int qlen;
	int max_qlen;
	struct tcp_fastopen_context___16 *ctx;
};

struct request_sock_queue___9 {
	spinlock_t rskq_lock;
	u8 rskq_defer_accept;
	u32 synflood_warned;
	atomic_t qlen;
	atomic_t young;
	struct request_sock___54 *rskq_accept_head;
	struct request_sock___54 *rskq_accept_tail;
	struct fastopen_queue___9 fastopenq;
};

struct inet_request_sock___4 {
	struct request_sock___54 req;
	u16 snd_wscale: 4;
	u16 rcv_wscale: 4;
	u16 tstamp_ok: 1;
	u16 sack_ok: 1;
	u16 wscale_ok: 1;
	u16 ecn_ok: 1;
	u16 acked: 1;
	u16 no_srccheck: 1;
	u16 smc_ok: 1;
	u32 ir_mark;
	union {
		struct ip_options_rcu *ireq_opt;
		struct {
			struct ipv6_txoptions *ipv6_opt;
			struct sk_buff___91 *pktopts;
		};
	};
};

struct inet_cork___13 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___70 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
	__u16 gso_size;
	u64 transmit_time;
};

struct inet_cork_full___13 {
	struct inet_cork___13 base;
	struct flowi fl;
};

struct ipv6_pinfo___13;

struct inet_sock___13 {
	struct sock___70 sk;
	struct ipv6_pinfo___13 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	__be16 inet_sport;
	__u16 inet_id;
	struct ip_options_rcu *inet_opt;
	int rx_dst_ifindex;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 bind_address_no_port: 1;
	__u8 defer_connect: 1;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___13 cork;
};

struct ipv6_fl_socklist___12;

struct ipv6_pinfo___13 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
			__u16 recvfragsize: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 repflow: 1;
	__u16 pmtudisc: 3;
	__u16 padding: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u16 autoflowlabel: 1;
	__u16 autoflowlabel_set: 1;
	__u8 min_hopcount;
	__u8 tclass;
	__be32 rcv_flowinfo;
	__u32 dst_cookie;
	__u32 rx_dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___12 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___91 *pktoptions;
	struct sk_buff___91 *rxpmtu;
	struct inet6_cork cork;
};

struct inet_connection_sock_af_ops___9 {
	int (*queue_xmit)(struct sock___70 *, struct sk_buff___91 *, struct flowi *);
	void (*send_check)(struct sock___70 *, struct sk_buff___91 *);
	int (*rebuild_header)(struct sock___70 *);
	void (*sk_rx_dst_set)(struct sock___70 *, const struct sk_buff___91 *);
	int (*conn_request)(struct sock___70 *, struct sk_buff___91 *);
	struct sock___70 * (*syn_recv_sock)(const struct sock___70 *, struct sk_buff___91 *, struct request_sock___54 *, struct dst_entry___70 *, struct request_sock___54 *, bool *);
	u16 net_header_len;
	u16 net_frag_header_len;
	u16 sockaddr_len;
	int (*setsockopt)(struct sock___70 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___70 *, int, int, char *, int *);
	void (*addr2sockaddr)(struct sock___70 *, struct sockaddr *);
	void (*mtu_reduced)(struct sock___70 *);
};

struct inet_bind_bucket___8;

struct tcp_ulp_ops___7;

struct inet_connection_sock___9 {
	struct inet_sock___13 icsk_inet;
	struct request_sock_queue___9 icsk_accept_queue;
	struct inet_bind_bucket___8 *icsk_bind_hash;
	long unsigned int icsk_timeout;
	struct timer_list icsk_retransmit_timer;
	struct timer_list icsk_delack_timer;
	__u32 icsk_rto;
	__u32 icsk_pmtu_cookie;
	const struct tcp_congestion_ops___16 *icsk_ca_ops;
	const struct inet_connection_sock_af_ops___9 *icsk_af_ops;
	const struct tcp_ulp_ops___7 *icsk_ulp_ops;
	void *icsk_ulp_data;
	void (*icsk_clean_acked)(struct sock___70 *, u32);
	struct hlist_node icsk_listen_portaddr_node;
	unsigned int (*icsk_sync_mss)(struct sock___70 *, u32);
	__u8 icsk_ca_state: 6;
	__u8 icsk_ca_setsockopt: 1;
	__u8 icsk_ca_dst_locked: 1;
	__u8 icsk_retransmits;
	__u8 icsk_pending;
	__u8 icsk_backoff;
	__u8 icsk_syn_retries;
	__u8 icsk_probes_out;
	__u16 icsk_ext_hdr_len;
	struct {
		__u8 pending;
		__u8 quick;
		__u8 pingpong;
		__u8 blocked;
		__u32 ato;
		long unsigned int timeout;
		__u32 lrcvtime;
		__u16 last_seg_size;
		__u16 rcv_mss;
	} icsk_ack;
	struct {
		int enabled;
		int search_high;
		int search_low;
		int probe_size;
		u32 probe_timestamp;
	} icsk_mtup;
	u32 icsk_user_timeout;
	u64 icsk_ca_priv[11];
};

struct inet_bind_bucket___8 {
	possible_net_t___92 ib_net;
	short unsigned int port;
	signed char fastreuse;
	signed char fastreuseport;
	kuid_t fastuid;
	struct in6_addr fast_v6_rcv_saddr;
	__be32 fast_rcv_saddr;
	short unsigned int fast_sk_family;
	bool fast_ipv6_only;
	struct hlist_node node;
	struct hlist_head owners;
};

struct tcp_ulp_ops___7 {
	struct list_head list;
	int (*init)(struct sock___70 *);
	void (*release)(struct sock___70 *);
	char name[16];
	struct module___371 *owner;
};

struct tcp_sack_block_wire {
	__be32 start_seq;
	__be32 end_seq;
};

struct tcp_request_sock_ops___3;

struct tcp_request_sock___3 {
	struct inet_request_sock___4 req;
	const struct tcp_request_sock_ops___3 *af_specific;
	u64 snt_synack;
	bool tfo_listener;
	u32 txhash;
	u32 rcv_isn;
	u32 snt_isn;
	u32 ts_off;
	u32 last_oow_ack_time;
	u32 rcv_nxt;
};

struct tcp_request_sock_ops___3 {
	u16 mss_clamp;
	struct tcp_md5sig_key * (*req_md5_lookup)(const struct sock___70 *, const struct sock___70 *);
	int (*calc_md5_hash)(char *, const struct tcp_md5sig_key *, const struct sock___70 *, const struct sk_buff___91 *);
	void (*init_req)(struct request_sock___54 *, const struct sock___70 *, struct sk_buff___91 *);
	__u32 (*cookie_init_seq)(const struct sk_buff___91 *, __u16 *);
	struct dst_entry___70 * (*route_req)(const struct sock___70 *, struct flowi *, const struct request_sock___54 *);
	u32 (*init_seq)(const struct sk_buff___91 *);
	u32 (*init_ts_off)(const struct net___101 *, const struct sk_buff___91 *);
	int (*send_synack)(const struct sock___70 *, struct dst_entry___70 *, struct flowi *, struct request_sock___54 *, struct tcp_fastopen_cookie *, enum tcp_synack_type);
};

struct tcp_sock_af_ops___7;

struct tcp_fastopen_request___7;

struct tcp_sock___7 {
	struct inet_connection_sock___9 inet_conn;
	u16 tcp_header_len;
	u16 gso_segs;
	__be32 pred_flags;
	u64 bytes_received;
	u32 segs_in;
	u32 data_segs_in;
	u32 rcv_nxt;
	u32 copied_seq;
	u32 rcv_wup;
	u32 snd_nxt;
	u32 segs_out;
	u32 data_segs_out;
	u64 bytes_acked;
	u32 snd_una;
	u32 snd_sml;
	u32 rcv_tstamp;
	u32 lsndtime;
	u32 last_oow_ack_time;
	u32 compressed_ack_rcv_nxt;
	u32 tsoffset;
	struct list_head tsq_node;
	struct list_head tsorted_sent_queue;
	u32 snd_wl1;
	u32 snd_wnd;
	u32 max_window;
	u32 mss_cache;
	u32 window_clamp;
	u32 rcv_ssthresh;
	struct tcp_rack rack;
	u16 advmss;
	u8 compressed_ack;
	u32 chrono_start;
	u32 chrono_stat[3];
	u8 chrono_type: 2;
	u8 rate_app_limited: 1;
	u8 fastopen_connect: 1;
	u8 fastopen_no_cookie: 1;
	u8 is_sack_reneg: 1;
	u8 unused: 2;
	u8 nonagle: 4;
	u8 thin_lto: 1;
	u8 recvmsg_inq: 1;
	u8 repair: 1;
	u8 frto: 1;
	u8 repair_queue;
	u8 syn_data: 1;
	u8 syn_fastopen: 1;
	u8 syn_fastopen_exp: 1;
	u8 syn_fastopen_ch: 1;
	u8 syn_data_acked: 1;
	u8 save_syn: 1;
	u8 is_cwnd_limited: 1;
	u8 syn_smc: 1;
	u32 tlp_high_seq;
	u64 tcp_mstamp;
	u32 srtt_us;
	u32 mdev_us;
	u32 mdev_max_us;
	u32 rttvar_us;
	u32 rtt_seq;
	struct minmax rtt_min;
	u32 packets_out;
	u32 retrans_out;
	u32 max_packets_out;
	u32 max_packets_seq;
	u16 urg_data;
	u8 ecn_flags;
	u8 keepalive_probes;
	u32 reordering;
	u32 snd_up;
	struct tcp_options_received rx_opt;
	u32 snd_ssthresh;
	u32 snd_cwnd;
	u32 snd_cwnd_cnt;
	u32 snd_cwnd_clamp;
	u32 snd_cwnd_used;
	u32 snd_cwnd_stamp;
	u32 prior_cwnd;
	u32 prr_delivered;
	u32 prr_out;
	u32 delivered;
	u32 delivered_ce;
	u32 lost;
	u32 app_limited;
	u64 first_tx_mstamp;
	u64 delivered_mstamp;
	u32 rate_delivered;
	u32 rate_interval_us;
	u32 rcv_wnd;
	u32 write_seq;
	u32 notsent_lowat;
	u32 pushed_seq;
	u32 lost_out;
	u32 sacked_out;
	struct hrtimer pacing_timer;
	struct hrtimer compressed_ack_timer;
	struct sk_buff___91 *lost_skb_hint;
	struct sk_buff___91 *retransmit_skb_hint;
	struct rb_root out_of_order_queue;
	struct sk_buff___91 *ooo_last_skb;
	struct tcp_sack_block duplicate_sack[1];
	struct tcp_sack_block selective_acks[4];
	struct tcp_sack_block recv_sack_cache[4];
	struct sk_buff___91 *highest_sack;
	int lost_cnt_hint;
	u32 prior_ssthresh;
	u32 high_seq;
	u32 retrans_stamp;
	u32 undo_marker;
	int undo_retrans;
	u32 total_retrans;
	u32 urg_seq;
	unsigned int keepalive_time;
	unsigned int keepalive_intvl;
	int linger2;
	u8 bpf_sock_ops_cb_flags;
	struct {
		u32 rtt_us;
		u32 seq;
		u64 time;
	} rcv_rtt_est;
	struct {
		u32 space;
		u32 seq;
		u64 time;
	} rcvq_space;
	struct {
		u32 probe_seq_start;
		u32 probe_seq_end;
	} mtu_probe;
	u32 mtu_info;
	const struct tcp_sock_af_ops___7 *af_specific;
	struct tcp_md5sig_info *md5sig_info;
	struct tcp_fastopen_request___7 *fastopen_req;
	struct request_sock___54 *fastopen_rsk;
	u32 *saved_syn;
};

struct tcp_sock_af_ops___7 {
	struct tcp_md5sig_key * (*md5_lookup)(const struct sock___70 *, const struct sock___70 *);
	int (*calc_md5_hash)(char *, const struct tcp_md5sig_key *, const struct sock___70 *, const struct sk_buff___91 *);
	int (*md5_parse)(struct sock___70 *, int, char *, int);
};

struct tcp_fastopen_request___7 {
	struct tcp_fastopen_cookie cookie;
	struct msghdr___73 *data;
	size_t size;
	int copied;
};

struct ip6_flowlabel___12;

struct ipv6_fl_socklist___12 {
	struct ipv6_fl_socklist___12 *next;
	struct ip6_flowlabel___12 *fl;
	struct callback_head rcu;
};

struct ifmcaddr6___41 {
	struct in6_addr mca_addr;
	struct inet6_dev___41 *idev;
	struct ifmcaddr6___41 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ip6_ra_chain___41 {
	struct ip6_ra_chain___41 *next;
	struct sock___70 *sk;
	int sel;
	void (*destructor)(struct sock___70 *);
};

struct ip6_flowlabel___12 {
	struct ip6_flowlabel___12 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___247 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___101 *fl_net;
};

enum tcp_queue {
	TCP_FRAG_IN_WRITE_QUEUE = 0,
	TCP_FRAG_IN_RTX_QUEUE = 1,
};

struct tcp_skb_cb___4 {
	__u32 seq;
	__u32 end_seq;
	union {
		__u32 tcp_tw_isn;
		struct {
			u16 tcp_gso_segs;
			u16 tcp_gso_size;
		};
	};
	__u8 tcp_flags;
	__u8 sacked;
	__u8 ip_dsfield;
	__u8 txstamp_ack: 1;
	__u8 eor: 1;
	__u8 has_rxtstamp: 1;
	__u8 unused: 5;
	__u32 ack_seq;
	union {
		struct {
			__u32 in_flight: 30;
			__u32 is_app_limited: 1;
			__u32 unused: 1;
			__u32 delivered;
			u64 first_tx_mstamp;
			u64 delivered_mstamp;
		} tx;
		union {
			struct inet_skb_parm h4;
			struct inet6_skb_parm h6;
		} header;
		struct {
			__u32 flags;
			struct sock___70 *sk_redir;
			void *data_end;
		} bpf;
	};
};

enum tcp_ca_ack_event_flags {
	CA_ACK_SLOWPATH = 1,
	CA_ACK_WIN_UPDATE = 2,
	CA_ACK_ECE = 4,
};

struct tcp_sacktag_state {
	u32 reord;
	u64 first_sackt;
	u64 last_sackt;
	struct rate_sample *rate;
	int flag;
	unsigned int mss_now;
};

struct sk_buff_fclones___2 {
	struct sk_buff___65 skb1;
	struct sk_buff___65 skb2;
	refcount_t fclone_ref;
};

enum pkt_hash_types {
	PKT_HASH_TYPE_NONE = 0,
	PKT_HASH_TYPE_L2 = 1,
	PKT_HASH_TYPE_L3 = 2,
	PKT_HASH_TYPE_L4 = 3,
};

struct bpf_sock_ops_kern___6 {
	struct sock___47 *sk;
	u32 op;
	union {
		u32 args[4];
		u32 reply;
		u32 replylong[4];
	};
	u32 is_fullsock;
	u64 temp;
};

struct inet_request_sock___5 {
	struct request_sock___32 req;
	u16 snd_wscale: 4;
	u16 rcv_wscale: 4;
	u16 tstamp_ok: 1;
	u16 sack_ok: 1;
	u16 wscale_ok: 1;
	u16 ecn_ok: 1;
	u16 acked: 1;
	u16 no_srccheck: 1;
	u16 smc_ok: 1;
	u32 ir_mark;
	union {
		struct ip_options_rcu *ireq_opt;
		struct {
			struct ipv6_txoptions *ipv6_opt;
			struct sk_buff___65 *pktopts;
		};
	};
};

struct tcp_request_sock_ops___4;

struct tcp_request_sock___4 {
	struct inet_request_sock___5 req;
	const struct tcp_request_sock_ops___4 *af_specific;
	u64 snt_synack;
	bool tfo_listener;
	u32 txhash;
	u32 rcv_isn;
	u32 snt_isn;
	u32 ts_off;
	u32 last_oow_ack_time;
	u32 rcv_nxt;
};

struct tcp_request_sock_ops___4 {
	u16 mss_clamp;
	struct tcp_md5sig_key * (*req_md5_lookup)(const struct sock___47 *, const struct sock___47 *);
	int (*calc_md5_hash)(char *, const struct tcp_md5sig_key *, const struct sock___47 *, const struct sk_buff___65 *);
	void (*init_req)(struct request_sock___32 *, const struct sock___47 *, struct sk_buff___65 *);
	__u32 (*cookie_init_seq)(const struct sk_buff___65 *, __u16 *);
	struct dst_entry___46 * (*route_req)(const struct sock___47 *, struct flowi *, const struct request_sock___32 *);
	u32 (*init_seq)(const struct sk_buff___65 *);
	u32 (*init_ts_off)(const struct net___75 *, const struct sk_buff___65 *);
	int (*send_synack)(const struct sock___47 *, struct dst_entry___46 *, struct flowi *, struct request_sock___32 *, struct tcp_fastopen_cookie *, enum tcp_synack_type);
};

enum tsq_flags {
	TSQF_THROTTLED = 1,
	TSQF_QUEUED = 2,
	TCPF_TSQ_DEFERRED = 4,
	TCPF_WRITE_TIMER_DEFERRED = 8,
	TCPF_DELACK_TIMER_DEFERRED = 16,
	TCPF_MTU_REDUCED_DEFERRED = 32,
};

struct tcp_skb_cb___5 {
	__u32 seq;
	__u32 end_seq;
	union {
		__u32 tcp_tw_isn;
		struct {
			u16 tcp_gso_segs;
			u16 tcp_gso_size;
		};
	};
	__u8 tcp_flags;
	__u8 sacked;
	__u8 ip_dsfield;
	__u8 txstamp_ack: 1;
	__u8 eor: 1;
	__u8 has_rxtstamp: 1;
	__u8 unused: 5;
	__u32 ack_seq;
	union {
		struct {
			__u32 in_flight: 30;
			__u32 is_app_limited: 1;
			__u32 unused: 1;
			__u32 delivered;
			u64 first_tx_mstamp;
			u64 delivered_mstamp;
		} tx;
		union {
			struct inet_skb_parm h4;
			struct inet6_skb_parm h6;
		} header;
		struct {
			__u32 flags;
			struct sock___47 *sk_redir;
			void *data_end;
		} bpf;
	};
};

struct tcp_out_options {
	u16 options;
	u16 mss;
	u8 ws;
	u8 num_sack_blocks;
	u8 hash_size;
	__u8 *hash_location;
	__u32 tsval;
	__u32 tsecr;
	struct tcp_fastopen_cookie *fastopen_cookie;
};

struct tsq_tasklet {
	struct tasklet_struct tasklet;
	struct list_head head;
};

struct bpf_sock_ops_kern___7 {
	struct sock___68 *sk;
	u32 op;
	union {
		u32 args[4];
		u32 reply;
		u32 replylong[4];
	};
	u32 is_fullsock;
	u64 temp;
};

struct ahash_request___6 {
	struct crypto_async_request___30 base;
	unsigned int nbytes;
	struct scatterlist *src;
	u8 *result;
	void *priv;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_ahash___5 {
	int (*init)(struct ahash_request___6 *);
	int (*update)(struct ahash_request___6 *);
	int (*final)(struct ahash_request___6 *);
	int (*finup)(struct ahash_request___6 *);
	int (*digest)(struct ahash_request___6 *);
	int (*export)(struct ahash_request___6 *, void *);
	int (*import)(struct ahash_request___6 *, const void *);
	int (*setkey)(struct crypto_ahash___5 *, const u8 *, unsigned int);
	unsigned int reqsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_tfm___30 base;
};

struct seq_net_private___7 {
	struct net___95 *net;
};

struct fastopen_queue___10 {
	struct request_sock___48 *rskq_rst_head;
	struct request_sock___48 *rskq_rst_tail;
	spinlock_t lock;
	int qlen;
	int max_qlen;
	struct tcp_fastopen_context___11 *ctx;
};

struct request_sock_queue___10 {
	spinlock_t rskq_lock;
	u8 rskq_defer_accept;
	u32 synflood_warned;
	atomic_t qlen;
	atomic_t young;
	struct request_sock___48 *rskq_accept_head;
	struct request_sock___48 *rskq_accept_tail;
	struct fastopen_queue___10 fastopenq;
};

struct inet_request_sock___6 {
	struct request_sock___48 req;
	u16 snd_wscale: 4;
	u16 rcv_wscale: 4;
	u16 tstamp_ok: 1;
	u16 sack_ok: 1;
	u16 wscale_ok: 1;
	u16 ecn_ok: 1;
	u16 acked: 1;
	u16 no_srccheck: 1;
	u16 smc_ok: 1;
	u32 ir_mark;
	union {
		struct ip_options_rcu *ireq_opt;
		struct {
			struct ipv6_txoptions *ipv6_opt;
			struct sk_buff___85 *pktopts;
		};
	};
};

struct inet_bind_bucket___9;

struct tcp_ulp_ops___8;

struct inet_connection_sock___10 {
	struct inet_sock___8 icsk_inet;
	struct request_sock_queue___10 icsk_accept_queue;
	struct inet_bind_bucket___9 *icsk_bind_hash;
	long unsigned int icsk_timeout;
	struct timer_list icsk_retransmit_timer;
	struct timer_list icsk_delack_timer;
	__u32 icsk_rto;
	__u32 icsk_pmtu_cookie;
	const struct tcp_congestion_ops___11 *icsk_ca_ops;
	const struct inet_connection_sock_af_ops___5 *icsk_af_ops;
	const struct tcp_ulp_ops___8 *icsk_ulp_ops;
	void *icsk_ulp_data;
	void (*icsk_clean_acked)(struct sock___65 *, u32);
	struct hlist_node icsk_listen_portaddr_node;
	unsigned int (*icsk_sync_mss)(struct sock___65 *, u32);
	__u8 icsk_ca_state: 6;
	__u8 icsk_ca_setsockopt: 1;
	__u8 icsk_ca_dst_locked: 1;
	__u8 icsk_retransmits;
	__u8 icsk_pending;
	__u8 icsk_backoff;
	__u8 icsk_syn_retries;
	__u8 icsk_probes_out;
	__u16 icsk_ext_hdr_len;
	struct {
		__u8 pending;
		__u8 quick;
		__u8 pingpong;
		__u8 blocked;
		__u32 ato;
		long unsigned int timeout;
		__u32 lrcvtime;
		__u16 last_seg_size;
		__u16 rcv_mss;
	} icsk_ack;
	struct {
		int enabled;
		int search_high;
		int search_low;
		int probe_size;
		u32 probe_timestamp;
	} icsk_mtup;
	u32 icsk_user_timeout;
	u64 icsk_ca_priv[11];
};

struct inet_bind_bucket___9 {
	possible_net_t___86 ib_net;
	short unsigned int port;
	signed char fastreuse;
	signed char fastreuseport;
	kuid_t fastuid;
	struct in6_addr fast_v6_rcv_saddr;
	__be32 fast_rcv_saddr;
	short unsigned int fast_sk_family;
	bool fast_ipv6_only;
	struct hlist_node node;
	struct hlist_head owners;
};

struct tcp_ulp_ops___8 {
	struct list_head list;
	int (*init)(struct sock___65 *);
	void (*release)(struct sock___65 *);
	char name[16];
	struct module___366 *owner;
};

struct inet_timewait_sock___2 {
	struct sock_common___64 __tw_common;
	__u32 tw_mark;
	volatile unsigned char tw_substate;
	unsigned char tw_rcv_wscale;
	__be16 tw_sport;
	unsigned int tw_kill: 1;
	unsigned int tw_transparent: 1;
	unsigned int tw_flowlabel: 20;
	unsigned int tw_pad: 2;
	unsigned int tw_tos: 8;
	struct timer_list tw_timer;
	struct inet_bind_bucket___9 *tw_tb;
};

struct tcp_md5sig {
	struct __kernel_sockaddr_storage tcpm_addr;
	__u8 tcpm_flags;
	__u8 tcpm_prefixlen;
	__u16 tcpm_keylen;
	__u32 __tcpm_pad;
	__u8 tcpm_key[80];
};

struct tcp_request_sock_ops___5;

struct tcp_request_sock___5 {
	struct inet_request_sock___6 req;
	const struct tcp_request_sock_ops___5 *af_specific;
	u64 snt_synack;
	bool tfo_listener;
	u32 txhash;
	u32 rcv_isn;
	u32 snt_isn;
	u32 ts_off;
	u32 last_oow_ack_time;
	u32 rcv_nxt;
};

struct tcp_request_sock_ops___5 {
	u16 mss_clamp;
	struct tcp_md5sig_key * (*req_md5_lookup)(const struct sock___65 *, const struct sock___65 *);
	int (*calc_md5_hash)(char *, const struct tcp_md5sig_key *, const struct sock___65 *, const struct sk_buff___85 *);
	void (*init_req)(struct request_sock___48 *, const struct sock___65 *, struct sk_buff___85 *);
	__u32 (*cookie_init_seq)(const struct sk_buff___85 *, __u16 *);
	struct dst_entry___64 * (*route_req)(const struct sock___65 *, struct flowi *, const struct request_sock___48 *);
	u32 (*init_seq)(const struct sk_buff___85 *);
	u32 (*init_ts_off)(const struct net___95 *, const struct sk_buff___85 *);
	int (*send_synack)(const struct sock___65 *, struct dst_entry___64 *, struct flowi *, struct request_sock___48 *, struct tcp_fastopen_cookie *, enum tcp_synack_type);
};

struct tcp_sock_af_ops___8;

struct tcp_fastopen_request___8;

struct tcp_sock___8 {
	struct inet_connection_sock___10 inet_conn;
	u16 tcp_header_len;
	u16 gso_segs;
	__be32 pred_flags;
	u64 bytes_received;
	u32 segs_in;
	u32 data_segs_in;
	u32 rcv_nxt;
	u32 copied_seq;
	u32 rcv_wup;
	u32 snd_nxt;
	u32 segs_out;
	u32 data_segs_out;
	u64 bytes_acked;
	u32 snd_una;
	u32 snd_sml;
	u32 rcv_tstamp;
	u32 lsndtime;
	u32 last_oow_ack_time;
	u32 compressed_ack_rcv_nxt;
	u32 tsoffset;
	struct list_head tsq_node;
	struct list_head tsorted_sent_queue;
	u32 snd_wl1;
	u32 snd_wnd;
	u32 max_window;
	u32 mss_cache;
	u32 window_clamp;
	u32 rcv_ssthresh;
	struct tcp_rack rack;
	u16 advmss;
	u8 compressed_ack;
	u32 chrono_start;
	u32 chrono_stat[3];
	u8 chrono_type: 2;
	u8 rate_app_limited: 1;
	u8 fastopen_connect: 1;
	u8 fastopen_no_cookie: 1;
	u8 is_sack_reneg: 1;
	u8 unused: 2;
	u8 nonagle: 4;
	u8 thin_lto: 1;
	u8 recvmsg_inq: 1;
	u8 repair: 1;
	u8 frto: 1;
	u8 repair_queue;
	u8 syn_data: 1;
	u8 syn_fastopen: 1;
	u8 syn_fastopen_exp: 1;
	u8 syn_fastopen_ch: 1;
	u8 syn_data_acked: 1;
	u8 save_syn: 1;
	u8 is_cwnd_limited: 1;
	u8 syn_smc: 1;
	u32 tlp_high_seq;
	u64 tcp_mstamp;
	u32 srtt_us;
	u32 mdev_us;
	u32 mdev_max_us;
	u32 rttvar_us;
	u32 rtt_seq;
	struct minmax rtt_min;
	u32 packets_out;
	u32 retrans_out;
	u32 max_packets_out;
	u32 max_packets_seq;
	u16 urg_data;
	u8 ecn_flags;
	u8 keepalive_probes;
	u32 reordering;
	u32 snd_up;
	struct tcp_options_received rx_opt;
	u32 snd_ssthresh;
	u32 snd_cwnd;
	u32 snd_cwnd_cnt;
	u32 snd_cwnd_clamp;
	u32 snd_cwnd_used;
	u32 snd_cwnd_stamp;
	u32 prior_cwnd;
	u32 prr_delivered;
	u32 prr_out;
	u32 delivered;
	u32 delivered_ce;
	u32 lost;
	u32 app_limited;
	u64 first_tx_mstamp;
	u64 delivered_mstamp;
	u32 rate_delivered;
	u32 rate_interval_us;
	u32 rcv_wnd;
	u32 write_seq;
	u32 notsent_lowat;
	u32 pushed_seq;
	u32 lost_out;
	u32 sacked_out;
	struct hrtimer pacing_timer;
	struct hrtimer compressed_ack_timer;
	struct sk_buff___85 *lost_skb_hint;
	struct sk_buff___85 *retransmit_skb_hint;
	struct rb_root out_of_order_queue;
	struct sk_buff___85 *ooo_last_skb;
	struct tcp_sack_block duplicate_sack[1];
	struct tcp_sack_block selective_acks[4];
	struct tcp_sack_block recv_sack_cache[4];
	struct sk_buff___85 *highest_sack;
	int lost_cnt_hint;
	u32 prior_ssthresh;
	u32 high_seq;
	u32 retrans_stamp;
	u32 undo_marker;
	int undo_retrans;
	u32 total_retrans;
	u32 urg_seq;
	unsigned int keepalive_time;
	unsigned int keepalive_intvl;
	int linger2;
	u8 bpf_sock_ops_cb_flags;
	struct {
		u32 rtt_us;
		u32 seq;
		u64 time;
	} rcv_rtt_est;
	struct {
		u32 space;
		u32 seq;
		u64 time;
	} rcvq_space;
	struct {
		u32 probe_seq_start;
		u32 probe_seq_end;
	} mtu_probe;
	u32 mtu_info;
	const struct tcp_sock_af_ops___8 *af_specific;
	struct tcp_md5sig_info *md5sig_info;
	struct tcp_fastopen_request___8 *fastopen_req;
	struct request_sock___48 *fastopen_rsk;
	u32 *saved_syn;
};

struct tcp_sock_af_ops___8 {
	struct tcp_md5sig_key * (*md5_lookup)(const struct sock___65 *, const struct sock___65 *);
	int (*calc_md5_hash)(char *, const struct tcp_md5sig_key *, const struct sock___65 *, const struct sk_buff___85 *);
	int (*md5_parse)(struct sock___65 *, int, char *, int);
};

struct tcp_fastopen_request___8 {
	struct tcp_fastopen_cookie cookie;
	struct msghdr___67 *data;
	size_t size;
	int copied;
};

struct tcp_timewait_sock {
	struct inet_timewait_sock___2 tw_sk;
	u32 tw_rcv_wnd;
	u32 tw_ts_offset;
	u32 tw_ts_recent;
	u32 tw_last_oow_ack_time;
	long int tw_ts_recent_stamp;
	struct tcp_md5sig_key *tw_md5_key;
};

enum tcp_tw_status {
	TCP_TW_SUCCESS = 0,
	TCP_TW_RST = 1,
	TCP_TW_ACK = 2,
	TCP_TW_SYN = 3,
};

struct tcp_skb_cb___6 {
	__u32 seq;
	__u32 end_seq;
	union {
		__u32 tcp_tw_isn;
		struct {
			u16 tcp_gso_segs;
			u16 tcp_gso_size;
		};
	};
	__u8 tcp_flags;
	__u8 sacked;
	__u8 ip_dsfield;
	__u8 txstamp_ack: 1;
	__u8 eor: 1;
	__u8 has_rxtstamp: 1;
	__u8 unused: 5;
	__u32 ack_seq;
	union {
		struct {
			__u32 in_flight: 30;
			__u32 is_app_limited: 1;
			__u32 unused: 1;
			__u32 delivered;
			u64 first_tx_mstamp;
			u64 delivered_mstamp;
		} tx;
		union {
			struct inet_skb_parm h4;
			struct inet6_skb_parm h6;
		} header;
		struct {
			__u32 flags;
			struct sock___65 *sk_redir;
			void *data_end;
		} bpf;
	};
};

struct tcp4_pseudohdr {
	__be32 saddr;
	__be32 daddr;
	__u8 pad;
	__u8 protocol;
	__be16 len;
};

struct tcp_md5sig_pool___2 {
	struct ahash_request___6 *md5_req;
	void *scratch;
};

enum tcp_seq_states {
	TCP_SEQ_STATE_LISTENING = 0,
	TCP_SEQ_STATE_ESTABLISHED = 1,
};

struct tcp_seq_afinfo {
	sa_family_t family;
};

struct tcp_iter_state {
	struct seq_net_private___7 p;
	enum tcp_seq_states state;
	struct sock___65 *syn_wait_sk;
	int bucket;
	int offset;
	int sbucket;
	int num;
	loff_t last_pos;
};

struct module___372;

struct file___446;

struct kiocb___446;

struct iov_iter___213;

struct poll_table_struct___285;

struct vm_area_struct___447;

struct inode___446;

struct file_lock___446;

struct page___447;

struct pipe_inode_info___127;

struct seq_file___385;

struct file_operations___446 {
	struct module___372 *owner;
	loff_t (*llseek)(struct file___446 *, loff_t, int);
	ssize_t (*read)(struct file___446 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___446 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___446 *, struct iov_iter___213 *);
	ssize_t (*write_iter)(struct kiocb___446 *, struct iov_iter___213 *);
	int (*iopoll)(struct kiocb___446 *, bool);
	int (*iterate)(struct file___446 *, struct dir_context *);
	int (*iterate_shared)(struct file___446 *, struct dir_context *);
	__poll_t (*poll)(struct file___446 *, struct poll_table_struct___285 *);
	long int (*unlocked_ioctl)(struct file___446 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___446 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___446 *, struct vm_area_struct___447 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___446 *, struct file___446 *);
	int (*flush)(struct file___446 *, fl_owner_t);
	int (*release)(struct inode___446 *, struct file___446 *);
	int (*fsync)(struct file___446 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___446 *, int);
	int (*lock)(struct file___446 *, int, struct file_lock___446 *);
	ssize_t (*sendpage)(struct file___446 *, struct page___447 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___446 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___446 *, int, struct file_lock___446 *);
	ssize_t (*splice_write)(struct pipe_inode_info___127 *, struct file___446 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___446 *, loff_t *, struct pipe_inode_info___127 *, size_t, unsigned int);
	int (*setlease)(struct file___446 *, long int, struct file_lock___446 **, void **);
	long int (*fallocate)(struct file___446 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___385 *, struct file___446 *);
	ssize_t (*copy_file_range)(struct file___446 *, loff_t, struct file___446 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___446 *, loff_t, struct file___446 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___446 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___447 {
	u64 seqnum;
	struct vm_area_struct___447 *vmas[4];
};

struct page_frag___447 {
	struct page___447 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___447;

struct mem_cgroup___179;

struct pid___248;

struct cred___414;

struct nsproxy___341;

struct signal_struct___321;

struct bio_list___236;

struct backing_dev_info___236;

struct css_set___295;

struct vm_struct___350;

struct task_struct___448 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___448 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___447 *mm;
	struct mm_struct___447 *active_mm;
	struct vmacache___447 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___448 *real_parent;
	struct task_struct___448 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___448 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___179 *active_memcg;
	long int rh_reserved2;
	struct pid___248 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___248 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___248 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___414 *ptracer_cred;
	const struct cred___414 *real_cred;
	const struct cred___414 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___341 *nsproxy;
	struct signal_struct___321 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___448 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___236 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___236 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___295 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___127 *splice_pipe;
	struct page_frag___447 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___179 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___448 *oom_reaper_list;
	struct vm_struct___350 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___156 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___447 *pgtable_t___447;

struct address_space___446;

struct dev_pagemap___434;

struct page___447 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___446 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___447 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___447 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___447 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___434 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___179 *mem_cgroup;
};

struct pglist_data___447;

struct lruvec___447 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___447 *pgdat;
};

struct zone___447 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___447 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___447 {
	struct zone___447 *zone;
	int zone_idx;
};

struct zonelist___447 {
	struct zoneref___447 _zonerefs[25];
};

struct pglist_data___447 {
	struct zone___447 node_zones[3];
	struct zonelist___447 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___448 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___448 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___447 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___448 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___448 *owner;
};

struct secondary_data___448 {
	void *stack;
	struct task_struct___448 *task;
	long int status;
};

struct blocking_notifier_head___447 {
	struct rw_semaphore___448 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___434;

struct vm_area_struct___447 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___447 *vm_next;
	struct vm_area_struct___447 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___447 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___434 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___446 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___447;

struct user_namespace___311;

struct mm_struct___447 {
	struct {
		struct vm_area_struct___447 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___446 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___448 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___447 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___448 *owner;
		struct user_namespace___311 *user_ns;
		struct file___446 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___447 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___446;

struct address_space___446 {
	struct inode___446 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___448 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___446 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___434)(struct vm_area_struct___447 *, long unsigned int, const struct page___447 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___434)(struct page___447 *, void *);

struct device___414;

struct dev_pagemap___434 {
	dev_page_fault_t___434 page_fault;
	dev_page_free_t___434 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___414 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct cgroup___295;

struct cgroup_subsys___295;

struct cgroup_subsys_state___295 {
	struct cgroup___295 *cgroup;
	struct cgroup_subsys___295 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___295 *parent;
};

struct kernfs_node___441;

struct cgroup_file___295 {
	struct kernfs_node___441 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___179;

struct mem_cgroup___179 {
	struct cgroup_subsys_state___295 css;
	struct mem_cgroup_id___13 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___295 events_file;
	struct cgroup_file___295 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___448 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___179 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry___446;

struct path___447 {
	struct vfsmount *mnt;
	struct dentry___446 *dentry;
};

struct fown_struct___248 {
	rwlock_t lock;
	struct pid___248 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___446 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___447 f_path;
	struct inode___446 *f_inode;
	const struct file_operations___446 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___248 f_owner;
	const struct cred___414 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___446 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___434;

struct vm_operations_struct___434 {
	void (*open)(struct vm_area_struct___447 *);
	void (*close)(struct vm_area_struct___447 *);
	int (*split)(struct vm_area_struct___447 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___447 *);
	vm_fault_t (*fault)(struct vm_fault___434 *);
	vm_fault_t (*huge_fault)(struct vm_fault___434 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___434 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___447 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___434 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___434 *);
	int (*access)(struct vm_area_struct___447 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___447 *);
	int (*set_policy)(struct vm_area_struct___447 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___447 *, long unsigned int);
	struct page___447 * (*find_special_page)(struct vm_area_struct___447 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___447 {
	struct task_struct___448 *task;
	struct core_thread___447 *next;
};

struct core_state___447 {
	atomic_t nr_threads;
	struct core_thread___447 dumper;
	struct completion startup;
};

struct key___414;

struct ucounts___311;

struct user_namespace___311 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___311 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___29 ns;
	long unsigned int flags;
	struct key___414 *persistent_keyring_register;
	struct rw_semaphore___448 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___311 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___434 {
	struct vm_area_struct___447 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___447 *cow_page;
	struct mem_cgroup___179 *memcg;
	struct page___447 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___447 prealloc_pte;
};

struct shrink_control___179 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___179 *memcg;
};

struct shrinker___179 {
	long unsigned int (*count_objects)(struct shrinker___179 *, struct shrink_control___179 *);
	long unsigned int (*scan_objects)(struct shrinker___179 *, struct shrink_control___179 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct pid_namespace___248;

struct upid___248 {
	int nr;
	struct pid_namespace___248 *ns;
};

struct pid_namespace___248 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___448 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___248 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___446 *proc_self;
	struct dentry___446 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___311 *user_ns;
	struct ucounts___311 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___29 ns;
};

struct pid___248 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___248 numbers[1];
};

struct user_struct___414 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___414 *uid_keyring;
	struct key___414 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___414 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___414 *session_keyring;
	struct key___414 *process_keyring;
	struct key___414 *thread_keyring;
	struct key___414 *request_key_auth;
	void *security;
	struct user_struct___414 *user;
	struct user_namespace___311 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___102;

struct cgroup_namespace___295;

struct nsproxy___341 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___248 *pid_ns_for_children;
	struct net___102 *net_ns;
	struct cgroup_namespace___295 *cgroup_ns;
};

struct signal_struct___321 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___448 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___448 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___248 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___248 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___447 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___248 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___236;

struct bio_list___236 {
	struct bio___236 *head;
	struct bio___236 *tail;
};

struct bdi_writeback_congested___236;

struct bdi_writeback___236 {
	struct backing_dev_info___236 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___236 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___295 *memcg_css;
	struct cgroup_subsys_state___295 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___236 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___236 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___414 *dev;
	struct device___414 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___446 *debug_dir;
	struct dentry___446 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___295 {
	struct cgroup_subsys_state___295 *subsys[13];
	refcount_t refcount;
	struct css_set___295 *dom_cset;
	struct cgroup___295 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___295 *mg_src_cgrp;
	struct cgroup___295 *mg_dst_cgrp;
	struct css_set___295 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___446;

struct pipe_buffer___127;

struct pipe_inode_info___127 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___447 *tmp_page;
	struct fasync_struct___446 *fasync_readers;
	struct fasync_struct___446 *fasync_writers;
	struct pipe_buffer___127 *bufs;
	struct user_struct___414 *user;
};

struct vm_struct___350 {
	struct vm_struct___350 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___447 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___333 {
	struct task_struct___448 task;
	long unsigned int stack[8192];
};

struct kset___433;

struct kobj_type___433;

struct kobject___434 {
	const char *name;
	struct list_head entry;
	struct kobject___434 *parent;
	struct kset___433 *kset;
	struct kobj_type___433 *ktype;
	struct kernfs_node___441 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___414 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___414 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___414;

struct bus_type___414;

struct device_driver___414;

struct dev_pm_domain___414;

struct dma_map_ops___186;

struct fwnode_handle___334;

struct class___414;

struct attribute_group___411;

struct device___414 {
	struct device___414 *parent;
	struct device_private *p;
	struct kobject___434 kobj;
	const char *init_name;
	const struct device_type___414 *type;
	struct mutex mutex;
	struct bus_type___414 *bus;
	struct device_driver___414 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___414 power;
	struct dev_pm_domain___414 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___186 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___334 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___414 *class;
	const struct attribute_group___411 **groups;
	void (*release)(struct device___414 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___446;

struct super_block___446;

struct dentry___446 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___446 *d_parent;
	struct qstr d_name;
	struct inode___446 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___446 *d_op;
	struct super_block___446 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___446;

struct block_device___446;

struct inode___446 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___446 *i_op;
	struct super_block___446 *i_sb;
	struct address_space___446 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___448 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___236 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___446 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___446 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___127 *i_pipe;
		struct block_device___446 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___446 {
	int (*d_revalidate)(struct dentry___446 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___446 *, unsigned int);
	int (*d_hash)(const struct dentry___446 *, struct qstr *);
	int (*d_compare)(const struct dentry___446 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___446 *);
	int (*d_init)(struct dentry___446 *);
	void (*d_release)(struct dentry___446 *);
	void (*d_prune)(struct dentry___446 *);
	void (*d_iput)(struct dentry___446 *, struct inode___446 *);
	char * (*d_dname)(struct dentry___446 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___447 *);
	int (*d_manage)(const struct path___447 *, bool);
	struct dentry___446 * (*d_real)(struct dentry___446 *, const struct inode___446 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___446;

struct mem_dqinfo___446 {
	struct quota_format_type___446 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___446;

struct quota_info___446 {
	unsigned int flags;
	struct rw_semaphore___448 dqio_sem;
	struct inode___446 *files[3];
	struct mem_dqinfo___446 info[3];
	const struct quota_format_ops___446 *ops[3];
};

struct rcuwait___446 {
	struct task_struct___448 *task;
};

struct percpu_rw_semaphore___446 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___448 rw_sem;
	struct rcuwait___446 writer;
	int readers_block;
};

struct sb_writers___446 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___446 rw_sem[3];
};

struct file_system_type___446;

struct super_operations___446;

struct dquot_operations___446;

struct quotactl_ops___446;

struct super_block___446 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___446 *s_type;
	const struct super_operations___446 *s_op;
	const struct dquot_operations___446 *dq_op;
	const struct quotactl_ops___446 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___446 *s_root;
	struct rw_semaphore___448 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___446 *s_bdev;
	struct backing_dev_info___236 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___446 s_dquot;
	struct sb_writers___446 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___446 *s_d_op;
	int cleancache_poolid;
	struct shrinker___179 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___311 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___446 {
	struct file___446 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___446 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___446 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___446 *ia_file;
};

struct dquot___446 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___446 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___446 {
	int qf_fmt_id;
	const struct quota_format_ops___446 *qf_ops;
	struct module___372 *qf_owner;
	struct quota_format_type___446 *qf_next;
};

struct quota_format_ops___446 {
	int (*check_quota_file)(struct super_block___446 *, int);
	int (*read_file_info)(struct super_block___446 *, int);
	int (*write_file_info)(struct super_block___446 *, int);
	int (*free_file_info)(struct super_block___446 *, int);
	int (*read_dqblk)(struct dquot___446 *);
	int (*commit_dqblk)(struct dquot___446 *);
	int (*release_dqblk)(struct dquot___446 *);
	int (*get_next_id)(struct super_block___446 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___446 {
	int (*write_dquot)(struct dquot___446 *);
	struct dquot___446 * (*alloc_dquot)(struct super_block___446 *, int);
	void (*destroy_dquot)(struct dquot___446 *);
	int (*acquire_dquot)(struct dquot___446 *);
	int (*release_dquot)(struct dquot___446 *);
	int (*mark_dirty)(struct dquot___446 *);
	int (*write_info)(struct super_block___446 *, int);
	qsize_t * (*get_reserved_space)(struct inode___446 *);
	int (*get_projid)(struct inode___446 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___446 *, qsize_t *);
	int (*get_next_id)(struct super_block___446 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___446 {
	int (*quota_on)(struct super_block___446 *, int, int, const struct path___447 *);
	int (*quota_off)(struct super_block___446 *, int);
	int (*quota_enable)(struct super_block___446 *, unsigned int);
	int (*quota_disable)(struct super_block___446 *, unsigned int);
	int (*quota_sync)(struct super_block___446 *, int);
	int (*set_info)(struct super_block___446 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___446 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___446 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___446 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___446 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___446 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___372 {
	struct kobject___434 kobj;
	struct module___372 *mod;
	struct kobject___434 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___372 {
	struct module___372 *mod;
	struct latch_tree_node node;
};

struct module_layout___372 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___372 mtn;
};

struct module_attribute___372;

struct kernel_param___372;

struct module___372 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___372 mkobj;
	struct module_attribute___372 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___434 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___372 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___372 core_layout;
	struct module_layout___372 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___199;

struct address_space_operations___446 {
	int (*writepage)(struct page___447 *, struct writeback_control___199 *);
	int (*readpage)(struct file___446 *, struct page___447 *);
	int (*writepages)(struct address_space___446 *, struct writeback_control___199 *);
	int (*set_page_dirty)(struct page___447 *);
	int (*readpages)(struct file___446 *, struct address_space___446 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___446 *, struct address_space___446 *, loff_t, unsigned int, unsigned int, struct page___447 **, void **);
	int (*write_end)(struct file___446 *, struct address_space___446 *, loff_t, unsigned int, unsigned int, struct page___447 *, void *);
	sector_t (*bmap)(struct address_space___446 *, sector_t);
	void (*invalidatepage)(struct page___447 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___447 *, gfp_t);
	void (*freepage)(struct page___447 *);
	ssize_t (*direct_IO)(struct kiocb___446 *, struct iov_iter___213 *);
	int (*migratepage)(struct address_space___446 *, struct page___447 *, struct page___447 *, enum migrate_mode);
	bool (*isolate_page)(struct page___447 *, isolate_mode_t);
	void (*putback_page)(struct page___447 *);
	int (*launder_page)(struct page___447 *);
	int (*is_partially_uptodate)(struct page___447 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___447 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___446 *, struct page___447 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___446 *, sector_t *);
	void (*swap_deactivate)(struct file___446 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___199 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___236 *wb;
	struct inode___446 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___238;

struct iov_iter___213 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___238 *bvec;
		struct pipe_inode_info___127 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___446 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___446 *bd_inode;
	struct super_block___446 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___446 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___236 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___446 {
	struct dentry___446 * (*lookup)(struct inode___446 *, struct dentry___446 *, unsigned int);
	const char * (*get_link)(struct dentry___446 *, struct inode___446 *, struct delayed_call *);
	int (*permission)(struct inode___446 *, int);
	struct posix_acl * (*get_acl)(struct inode___446 *, int);
	int (*readlink)(struct dentry___446 *, char *, int);
	int (*create)(struct inode___446 *, struct dentry___446 *, umode_t, bool);
	int (*link)(struct dentry___446 *, struct inode___446 *, struct dentry___446 *);
	int (*unlink)(struct inode___446 *, struct dentry___446 *);
	int (*symlink)(struct inode___446 *, struct dentry___446 *, const char *);
	int (*mkdir)(struct inode___446 *, struct dentry___446 *, umode_t);
	int (*rmdir)(struct inode___446 *, struct dentry___446 *);
	int (*mknod)(struct inode___446 *, struct dentry___446 *, umode_t, dev_t);
	int (*rename)(struct inode___446 *, struct dentry___446 *, struct inode___446 *, struct dentry___446 *, unsigned int);
	int (*setattr)(struct dentry___446 *, struct iattr___446 *);
	int (*getattr)(const struct path___447 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___446 *, char *, size_t);
	int (*fiemap)(struct inode___446 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___446 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___446 *, struct dentry___446 *, struct file___446 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___446 *, struct dentry___446 *, umode_t);
	int (*set_acl)(struct inode___446 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___446 {
	void (*fl_copy_lock)(struct file_lock___446 *, struct file_lock___446 *);
	void (*fl_release_private)(struct file_lock___446 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___446;

struct file_lock___446 {
	struct file_lock___446 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___446 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___446 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___446 *fl_ops;
	const struct lock_manager_operations___446 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___446 {
	int (*lm_compare_owner)(struct file_lock___446 *, struct file_lock___446 *);
	long unsigned int (*lm_owner_key)(struct file_lock___446 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___446 *);
	int (*lm_grant)(struct file_lock___446 *, int);
	bool (*lm_break)(struct file_lock___446 *);
	int (*lm_change)(struct file_lock___446 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___446 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___446 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___446 *fa_next;
	struct file___446 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___446 {
	const char *name;
	int fs_flags;
	struct dentry___446 * (*mount)(struct file_system_type___446 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___446 *);
	struct module___372 *owner;
	struct file_system_type___446 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___446 {
	struct inode___446 * (*alloc_inode)(struct super_block___446 *);
	void (*destroy_inode)(struct inode___446 *);
	void (*dirty_inode)(struct inode___446 *, int);
	int (*write_inode)(struct inode___446 *, struct writeback_control___199 *);
	int (*drop_inode)(struct inode___446 *);
	void (*evict_inode)(struct inode___446 *);
	void (*put_super)(struct super_block___446 *);
	int (*sync_fs)(struct super_block___446 *, int);
	int (*freeze_super)(struct super_block___446 *);
	int (*freeze_fs)(struct super_block___446 *);
	int (*thaw_super)(struct super_block___446 *);
	int (*unfreeze_fs)(struct super_block___446 *);
	int (*statfs)(struct dentry___446 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___446 *, int *, char *);
	void (*umount_begin)(struct super_block___446 *);
	int (*show_options)(struct seq_file___385 *, struct dentry___446 *);
	int (*show_devname)(struct seq_file___385 *, struct dentry___446 *);
	int (*show_path)(struct seq_file___385 *, struct dentry___446 *);
	int (*show_stats)(struct seq_file___385 *, struct dentry___446 *);
	ssize_t (*quota_read)(struct super_block___446 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___446 *, int, const char *, size_t, loff_t);
	struct dquot___446 ** (*get_dquots)(struct inode___446 *);
	int (*bdev_try_to_free_page)(struct super_block___446 *, struct page___447 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___446 *, struct shrink_control___179 *);
	long int (*free_cached_objects)(struct super_block___446 *, struct shrink_control___179 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___295)(struct file___446 *, wait_queue_head_t *, struct poll_table_struct___285 *);

struct poll_table_struct___285 {
	poll_queue_proc___295 _qproc;
	__poll_t _key;
};

struct seq_operations___385;

struct seq_file___385 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___385 *op;
	int poll_event;
	const struct file___446 *file;
	void *private;
};

typedef void bio_end_io_t___236(struct bio___236 *);

struct bio_vec___238 {
	struct page___447 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___236;

struct bio_set___236;

struct bio___236 {
	struct bio___236 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___236 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___236 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___238 *bi_io_vec;
	struct bio_set___236 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___238 bi_inline_vecs[0];
};

struct kobj_attribute___424 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___434 *, struct kobj_attribute___424 *, char *);
	ssize_t (*store)(struct kobject___434 *, struct kobj_attribute___424 *, const char *, size_t);
};

typedef void compound_page_dtor___434(struct page___447 *);

struct kernfs_root___440;

struct kernfs_elem_dir___440 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___440 *root;
};

struct kernfs_syscall_ops___440;

struct kernfs_root___440 {
	struct kernfs_node___441 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___440 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___440 {
	struct kernfs_node___441 *target_kn;
};

struct kernfs_ops___440;

struct kernfs_elem_attr___440 {
	const struct kernfs_ops___440 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___441 *notify_next;
};

struct kernfs_node___441 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___441 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___440 dir;
		struct kernfs_elem_symlink___440 symlink;
		struct kernfs_elem_attr___440 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___440;

struct kernfs_ops___440 {
	int (*open)(struct kernfs_open_file___440 *);
	void (*release)(struct kernfs_open_file___440 *);
	int (*seq_show)(struct seq_file___385 *, void *);
	void * (*seq_start)(struct seq_file___385 *, loff_t *);
	void * (*seq_next)(struct seq_file___385 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___385 *, void *);
	ssize_t (*read)(struct kernfs_open_file___440 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___440 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___440 *, struct vm_area_struct___447 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___440 *, struct poll_table_struct___285 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___440 {
	int (*remount_fs)(struct kernfs_root___440 *, int *, char *);
	int (*show_options)(struct seq_file___385 *, struct kernfs_root___440 *);
	int (*mkdir)(struct kernfs_node___441 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___441 *);
	int (*rename)(struct kernfs_node___441 *, struct kernfs_node___441 *, const char *);
	int (*show_path)(struct seq_file___385 *, struct kernfs_node___441 *, struct kernfs_root___440 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___440 {
	struct kernfs_node___441 *kn;
	struct file___446 *file;
	struct seq_file___385 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___434 *vm_ops;
};

struct sock___71;

struct kobj_ns_type_operations___71 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___71 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___102 *net;
} possible_net_t___93;

struct proto___71;

struct sock_common___71 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___71 *skc_prot;
	possible_net_t___93 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___71 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___92;

struct sk_buff_head___91 {
	struct sk_buff___92 *next;
	struct sk_buff___92 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___71;

struct socket_wq___72;

struct xfrm_policy___13;

struct dst_entry___71;

struct socket___73;

struct net_device___91;

struct sock___71 {
	struct sock_common___71 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___91 sk_error_queue;
	struct sk_buff_head___91 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___92 *head;
		struct sk_buff___92 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___71 *sk_filter;
	union {
		struct socket_wq___72 *sk_wq;
		struct socket_wq___72 *sk_wq_raw;
	};
	struct xfrm_policy___13 *sk_policy[2];
	struct dst_entry___71 *sk_rx_dst;
	struct dst_entry___71 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___92 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___91 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___447 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___71 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___248 *sk_peer_pid;
	const struct cred___414 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___73 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___179 *sk_memcg;
	void (*sk_state_change)(struct sock___71 *);
	void (*sk_data_ready)(struct sock___71 *);
	void (*sk_write_space)(struct sock___71 *);
	void (*sk_error_report)(struct sock___71 *);
	int (*sk_backlog_rcv)(struct sock___71 *, struct sk_buff___92 *);
	struct sk_buff___92 * (*sk_validate_xmit_skb)(struct sock___71 *, struct net_device___91 *, struct sk_buff___92 *);
	void (*sk_destruct)(struct sock___71 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct bin_attribute___410;

struct attribute_group___411 {
	const char *name;
	umode_t (*is_visible)(struct kobject___434 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___434 *, struct bin_attribute___410 *, int);
	struct attribute **attrs;
	struct bin_attribute___410 **bin_attrs;
};

struct bin_attribute___410 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___446 *, struct kobject___434 *, struct bin_attribute___410 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___446 *, struct kobject___434 *, struct bin_attribute___410 *, char *, loff_t, size_t);
	int (*mmap)(struct file___446 *, struct kobject___434 *, struct bin_attribute___410 *, struct vm_area_struct___447 *);
};

struct sysfs_ops___433 {
	ssize_t (*show)(struct kobject___434 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___434 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___433;

struct kset___433 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___434 kobj;
	const struct kset_uevent_ops___433 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___433 {
	void (*release)(struct kobject___434 *);
	const struct sysfs_ops___433 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___71 * (*child_ns_type)(struct kobject___434 *);
	const void * (*namespace)(struct kobject___434 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___433 {
	int (* const filter)(struct kset___433 *, struct kobject___434 *);
	const char * (* const name)(struct kset___433 *, struct kobject___434 *);
	int (* const uevent)(struct kset___433 *, struct kobject___434 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___372 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___372 *);
	int (*get)(char *, const struct kernel_param___372 *);
	void (*free)(void *);
};

struct kparam_array___372;

struct kernel_param___372 {
	const char *name;
	struct module___372 *mod;
	const struct kernel_param_ops___372 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___372 *arr;
	};
};

struct kparam_array___372 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___372 *ops;
	void *elem;
};

struct module_attribute___372 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___372 *, struct module_kobject___372 *, char *);
	ssize_t (*store)(struct module_attribute___372 *, struct module_kobject___372 *, const char *, size_t);
	void (*setup)(struct module___372 *, const char *);
	int (*test)(struct module___372 *);
	void (*free)(struct module___372 *);
};

struct crypto_async_request___36;

typedef void (*crypto_completion_t___36)(struct crypto_async_request___36 *, int);

struct crypto_tfm___36;

struct crypto_async_request___36 {
	struct list_head list;
	crypto_completion_t___36 complete;
	void *data;
	struct crypto_tfm___36 *tfm;
	u32 flags;
};

struct crypto_ablkcipher___36;

struct ablkcipher_request___36;

struct ablkcipher_tfm___36 {
	int (*setkey)(struct crypto_ablkcipher___36 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___36 *);
	int (*decrypt)(struct ablkcipher_request___36 *);
	struct crypto_ablkcipher___36 *base;
	unsigned int ivsize;
	unsigned int reqsize;
};

struct blkcipher_desc___36;

struct blkcipher_tfm___36 {
	void *iv;
	int (*setkey)(struct crypto_tfm___36 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___36 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___36 *, struct scatterlist *, struct scatterlist *, unsigned int);
};

struct cipher_tfm___36 {
	int (*cit_setkey)(struct crypto_tfm___36 *, const u8 *, unsigned int);
	void (*cit_encrypt_one)(struct crypto_tfm___36 *, u8 *, const u8 *);
	void (*cit_decrypt_one)(struct crypto_tfm___36 *, u8 *, const u8 *);
};

struct compress_tfm___36 {
	int (*cot_compress)(struct crypto_tfm___36 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*cot_decompress)(struct crypto_tfm___36 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___36;

struct crypto_tfm___36 {
	u32 crt_flags;
	union {
		struct ablkcipher_tfm___36 ablkcipher;
		struct blkcipher_tfm___36 blkcipher;
		struct cipher_tfm___36 cipher;
		struct compress_tfm___36 compress;
	} crt_u;
	void (*exit)(struct crypto_tfm___36 *);
	struct crypto_alg___36 *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct ablkcipher_request___36 {
	struct crypto_async_request___36 base;
	unsigned int nbytes;
	void *info;
	struct scatterlist *src;
	struct scatterlist *dst;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_blkcipher___36;

struct blkcipher_desc___36 {
	struct crypto_blkcipher___36 *tfm;
	void *info;
	u32 flags;
};

struct crypto_blkcipher___36 {
	struct crypto_tfm___36 base;
};

struct ablkcipher_alg___36 {
	int (*setkey)(struct crypto_ablkcipher___36 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___36 *);
	int (*decrypt)(struct ablkcipher_request___36 *);
	int (*givencrypt)(struct skcipher_givcrypt_request *);
	int (*givdecrypt)(struct skcipher_givcrypt_request *);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct crypto_ablkcipher___36 {
	struct crypto_tfm___36 base;
};

struct blkcipher_alg___36 {
	int (*setkey)(struct crypto_tfm___36 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___36 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___36 *, struct scatterlist *, struct scatterlist *, unsigned int);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct cipher_alg___36 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___36 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___36 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___36 *, u8 *, const u8 *);
};

struct compress_alg___36 {
	int (*coa_compress)(struct crypto_tfm___36 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___36 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___36 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type *cra_type;
	union {
		struct ablkcipher_alg___36 ablkcipher;
		struct blkcipher_alg___36 blkcipher;
		struct cipher_alg___36 cipher;
		struct compress_alg___36 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___36 *);
	void (*cra_exit)(struct crypto_tfm___36 *);
	void (*cra_destroy)(struct crypto_alg___36 *);
	struct module___372 *cra_module;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct crypto_cipher___20 {
	struct crypto_tfm___36 base;
};

struct msghdr___74 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___213 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___446 *msg_iocb;
};

struct socket_wq___72 {
	wait_queue_head_t wait;
	struct fasync_struct___446 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___72;

struct socket___73 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___72 *wq;
	struct file___446 *file;
	struct sock___71 *sk;
	const struct proto_ops___72 *ops;
};

typedef int (*sk_read_actor_t___71)(read_descriptor_t *, struct sk_buff___92 *, unsigned int, size_t);

struct proto_ops___72 {
	int family;
	struct module___372 *owner;
	int (*release)(struct socket___73 *);
	int (*bind)(struct socket___73 *, struct sockaddr *, int);
	int (*connect)(struct socket___73 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___73 *, struct socket___73 *);
	int (*accept)(struct socket___73 *, struct socket___73 *, int, bool);
	int (*getname)(struct socket___73 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___446 *, struct socket___73 *, struct poll_table_struct___285 *);
	int (*ioctl)(struct socket___73 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___73 *, int);
	int (*shutdown)(struct socket___73 *, int);
	int (*setsockopt)(struct socket___73 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___73 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___73 *, struct msghdr___74 *, size_t);
	int (*recvmsg)(struct socket___73 *, struct msghdr___74 *, size_t, int);
	int (*mmap)(struct file___446 *, struct socket___73 *, struct vm_area_struct___447 *);
	ssize_t (*sendpage)(struct socket___73 *, struct page___447 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___73 *, loff_t *, struct pipe_inode_info___127 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___71 *, int);
	int (*peek_len)(struct socket___73 *);
	int (*read_sock)(struct sock___71 *, read_descriptor_t *, sk_read_actor_t___71);
	int (*sendpage_locked)(struct sock___71 *, struct page___447 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___71 *, struct msghdr___74 *, size_t);
	int (*set_rcvlowat)(struct sock___71 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct sec_path___13;

struct nf_bridge_info___91;

struct sk_buff___92 {
	union {
		struct {
			struct sk_buff___92 *next;
			struct sk_buff___92 *prev;
			union {
				struct net_device___91 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___71 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___92 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path___13 *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___91 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___91;

struct netns_frags___91 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___91 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ip_ra_chain___37;

struct fib_rules_ops___71;

struct tcp_congestion_ops___17;

struct tcp_fastopen_context___17;

struct fib_notifier_ops___72;

struct netns_ipv4___91 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___37 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___71 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___71 *fibnl;
	struct sock___71 **icmp_sk;
	struct sock___71 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___71 **tcp_sk;
	struct netns_frags___91 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops___17 *tcp_congestion_control;
	struct tcp_fastopen_context___17 *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___71 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___72 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___72 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___71;

struct dst_ops___102 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___102 *);
	struct dst_entry___71 * (*check)(struct dst_entry___71 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___71 *);
	unsigned int (*mtu)(const struct dst_entry___71 *);
	u32 * (*cow_metrics)(struct dst_entry___71 *, long unsigned int);
	void (*destroy)(struct dst_entry___71 *);
	void (*ifdown)(struct dst_entry___71 *, struct net_device___91 *, int);
	struct dst_entry___71 * (*negative_advice)(struct dst_entry___71 *);
	void (*link_failure)(struct sk_buff___92 *);
	void (*update_pmtu)(struct dst_entry___71 *, struct sock___71 *, struct sk_buff___92 *, u32);
	void (*redirect)(struct dst_entry___71 *, struct sock___71 *, struct sk_buff___92 *);
	int (*local_out)(struct net___102 *, struct sock___71 *, struct sk_buff___92 *);
	struct neighbour___71 * (*neigh_lookup)(const struct dst_entry___71 *, struct sk_buff___92 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___71 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_info___17;

struct rt6_info___17;

struct fib6_table___17;

struct netns_ipv6___102 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___91 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info___17 *fib6_null_entry;
	struct rt6_info___17 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___17 *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___102 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info___17 *ip6_prohibit_entry;
	struct rt6_info___17 *ip6_blk_hole_entry;
	struct fib6_table___17 *fib6_local_tbl;
	struct fib_rules_ops___71 *fib6_rules_ops;
	struct sock___71 **icmp_sk;
	struct sock___71 *ndisc_sk;
	struct sock___71 *tcp_sk;
	struct sock___71 *igmp_sk;
	struct sock___71 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___71 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___72 *notifier_ops;
	struct fib_notifier_ops___72 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___72 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___71 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___91 {
	struct netns_frags___91 frags;
};

struct netns_xfrm___102 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___71 *nlsk;
	struct sock___71 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___102 xfrm4_dst_ops;
	struct dst_ops___102 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___81;

struct net___102 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___311 *user_ns;
	struct ucounts___311 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___29 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___71 *rtnl;
	struct sock___71 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___91 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___91 ipv4;
	struct netns_ipv6___102 ipv6;
	struct netns_sctp___72 sctp;
	struct netns_nf___12 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___91 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___71 *nfnl;
	struct sock___71 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___102 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___71 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___81 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___414 {
	int (*prepare)(struct device___414 *);
	void (*complete)(struct device___414 *);
	int (*suspend)(struct device___414 *);
	int (*resume)(struct device___414 *);
	int (*freeze)(struct device___414 *);
	int (*thaw)(struct device___414 *);
	int (*poweroff)(struct device___414 *);
	int (*restore)(struct device___414 *);
	int (*suspend_late)(struct device___414 *);
	int (*resume_early)(struct device___414 *);
	int (*freeze_late)(struct device___414 *);
	int (*thaw_early)(struct device___414 *);
	int (*poweroff_late)(struct device___414 *);
	int (*restore_early)(struct device___414 *);
	int (*suspend_noirq)(struct device___414 *);
	int (*resume_noirq)(struct device___414 *);
	int (*freeze_noirq)(struct device___414 *);
	int (*thaw_noirq)(struct device___414 *);
	int (*poweroff_noirq)(struct device___414 *);
	int (*restore_noirq)(struct device___414 *);
	int (*runtime_suspend)(struct device___414 *);
	int (*runtime_resume)(struct device___414 *);
	int (*runtime_idle)(struct device___414 *);
};

struct dev_pm_domain___414 {
	struct dev_pm_ops___414 ops;
	void (*detach)(struct device___414 *, bool);
	int (*activate)(struct device___414 *);
	void (*sync)(struct device___414 *);
	void (*dismiss)(struct device___414 *);
};

struct bus_type___414 {
	const char *name;
	const char *dev_name;
	struct device___414 *dev_root;
	const struct attribute_group___411 **bus_groups;
	const struct attribute_group___411 **dev_groups;
	const struct attribute_group___411 **drv_groups;
	int (*match)(struct device___414 *, struct device_driver___414 *);
	int (*uevent)(struct device___414 *, struct kobj_uevent_env *);
	int (*probe)(struct device___414 *);
	int (*remove)(struct device___414 *);
	void (*shutdown)(struct device___414 *);
	int (*online)(struct device___414 *);
	int (*offline)(struct device___414 *);
	int (*suspend)(struct device___414 *, pm_message_t);
	int (*resume)(struct device___414 *);
	int (*num_vf)(struct device___414 *);
	int (*dma_configure)(struct device___414 *);
	const struct dev_pm_ops___414 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___414 {
	const char *name;
	struct bus_type___414 *bus;
	struct module___372 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___414 *);
	int (*remove)(struct device___414 *);
	void (*shutdown)(struct device___414 *);
	int (*suspend)(struct device___414 *, pm_message_t);
	int (*resume)(struct device___414 *);
	const struct attribute_group___411 **groups;
	const struct dev_pm_ops___414 *pm;
	void (*coredump)(struct device___414 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___414 {
	const char *name;
	const struct attribute_group___411 **groups;
	int (*uevent)(struct device___414 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___414 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___414 *);
	const struct dev_pm_ops___414 *pm;
};

struct class___414 {
	const char *name;
	struct module___372 *owner;
	const struct attribute_group___411 **class_groups;
	const struct attribute_group___411 **dev_groups;
	struct kobject___434 *dev_kobj;
	int (*dev_uevent)(struct device___414 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___414 *, umode_t *);
	void (*class_release)(struct class___414 *);
	void (*dev_release)(struct device___414 *);
	int (*shutdown_pre)(struct device___414 *);
	const struct kobj_ns_type_operations___71 *ns_type;
	const void * (*namespace)(struct device___414 *);
	const struct dev_pm_ops___414 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___186 {
	void * (*alloc)(struct device___414 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___414 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___414 *, struct vm_area_struct___447 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___414 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___414 *, struct page___447 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___414 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___414 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___414 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___414 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___414 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___414 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___414 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___414 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___414 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___414 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___414 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___414 *, u64);
	u64 (*get_required_mask)(struct device___414 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___334;

struct fwnode_handle___334 {
	struct fwnode_handle___334 *secondary;
	const struct fwnode_operations___334 *ops;
};

struct fwnode_reference_args___334;

struct fwnode_endpoint___334;

struct fwnode_operations___334 {
	struct fwnode_handle___334 * (*get)(struct fwnode_handle___334 *);
	void (*put)(struct fwnode_handle___334 *);
	bool (*device_is_available)(const struct fwnode_handle___334 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___334 *, const struct device___414 *);
	bool (*property_present)(const struct fwnode_handle___334 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___334 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___334 *, const char *, const char **, size_t);
	struct fwnode_handle___334 * (*get_parent)(const struct fwnode_handle___334 *);
	struct fwnode_handle___334 * (*get_next_child_node)(const struct fwnode_handle___334 *, struct fwnode_handle___334 *);
	struct fwnode_handle___334 * (*get_named_child_node)(const struct fwnode_handle___334 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___334 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___334 *);
	struct fwnode_handle___334 * (*graph_get_next_endpoint)(const struct fwnode_handle___334 *, struct fwnode_handle___334 *);
	struct fwnode_handle___334 * (*graph_get_remote_endpoint)(const struct fwnode_handle___334 *);
	struct fwnode_handle___334 * (*graph_get_port_parent)(struct fwnode_handle___334 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___334 *, struct fwnode_endpoint___334 *);
};

struct fwnode_endpoint___334 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___334 *local_fwnode;
};

struct fwnode_reference_args___334 {
	struct fwnode_handle___334 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___127;

struct pipe_buffer___127 {
	struct page___447 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___127 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___127 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___127 *, struct pipe_buffer___127 *);
	void (*release)(struct pipe_inode_info___127 *, struct pipe_buffer___127 *);
	int (*steal)(struct pipe_inode_info___127 *, struct pipe_buffer___127 *);
	union {
		bool (*get)(struct pipe_inode_info___127 *, struct pipe_buffer___127 *);
		struct {
			void (*get)(struct pipe_inode_info___127 *, struct pipe_buffer___127 *);
		} __UNIQUE_ID_rh_kabi_hide21;
		union {		};
	};
};

struct nf_bridge_info___91 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___91 = 0,
		BRNF_PROTO_8021Q___91 = 1,
		BRNF_PROTO_PPPOE___91 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___91 *physindev;
	struct net_device___91 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___91(struct sk_buff___92 **);

struct net_device_ops___91;

struct ethtool_ops___91;

struct l3mdev_ops___71;

struct ndisc_ops___42;

struct xfrmdev_ops___91;

struct tlsdev_ops___91;

struct header_ops___91;

struct inet6_dev___42;

struct netdev_rx_queue___91;

struct mini_Qdisc___83;

struct netdev_queue___91;

struct Qdisc___83;

struct rtnl_link_ops___83;

struct dcbnl_rtnl_ops___91;

struct net_device___91 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___91 *netdev_ops;
	const struct ethtool_ops___91 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___71 *l3mdev_ops;
	const struct ndisc_ops___42 *ndisc_ops;
	const struct xfrmdev_ops___91 *xfrmdev_ops;
	const struct tlsdev_ops___91 *tlsdev_ops;
	const struct header_ops___91 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___433 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___42 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___91 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___81 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___91 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___83 *miniq_ingress;
	struct netdev_queue___91 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___91 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___83 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___83 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___91 = 0,
		NETREG_REGISTERED___91 = 1,
		NETREG_UNREGISTERING___91 = 2,
		NETREG_UNREGISTERED___91 = 3,
		NETREG_RELEASED___91 = 4,
		NETREG_DUMMY___91 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___91 = 0,
		RTNL_LINK_INITIALIZING___91 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___91 *);
	struct netpoll_info *npinfo;
	possible_net_t___93 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___414 dev;
	const struct attribute_group___411 *sysfs_groups[4];
	const struct attribute_group___411 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___83 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___91 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide35;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct skb_frag_struct___21 {
	struct {
		struct page___447 *p;
	} page;
	__u32 page_offset;
	__u32 size;
};

typedef struct skb_frag_struct___21 skb_frag_t___21;

struct skb_shared_info___21 {
	__u8 __unused;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___92 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___21 frags[16];
};

struct xfrm_state___13;

struct sec_path___13 {
	refcount_t refcnt;
	int len;
	int olen;
	struct xfrm_state___13 *xvec[6];
	struct xfrm_offload ovec[1];
};

struct ethtool_ops___91 {
	int (*get_settings)(struct net_device___91 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___91 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___91 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___91 *);
	void (*get_regs)(struct net_device___91 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___91 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___91 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___91 *);
	void (*set_msglevel)(struct net_device___91 *, u32);
	int (*nway_reset)(struct net_device___91 *);
	u32 (*get_link)(struct net_device___91 *);
	int (*get_eeprom_len)(struct net_device___91 *);
	int (*get_eeprom)(struct net_device___91 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___91 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___91 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___91 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___91 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___91 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___91 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___91 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___91 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___91 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___91 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___91 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___91 *);
	void (*complete)(struct net_device___91 *);
	u32 (*get_priv_flags)(struct net_device___91 *);
	int (*set_priv_flags)(struct net_device___91 *, u32);
	int (*get_sset_count)(struct net_device___91 *, int);
	int (*get_rxnfc)(struct net_device___91 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___91 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___91 *, struct ethtool_flash *);
	int (*reset)(struct net_device___91 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___91 *);
	u32 (*get_rxfh_indir_size)(struct net_device___91 *);
	int (*get_rxfh)(struct net_device___91 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___91 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___91 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___91 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___91 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___91 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___91 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___91 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___91 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___91 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___91 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___91 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___91 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___91 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___91 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___91 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___91 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___91 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___91 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___91 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___91 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___91 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	int (*get_fecparam)(struct net_device___91 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___91 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___91 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___91 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___91 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___91;

struct inet_frags___91 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___91 *, const void *);
	void (*destructor)(struct inet_frag_queue___91 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___91 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___92 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___92 *fragments_tail;
	struct sk_buff___92 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___91 *net;
	struct callback_head rcu;
};

struct ip_ra_chain___37 {
	struct ip_ra_chain___37 *next;
	struct sock___71 *sk;
	union {
		void (*destructor)(struct sock___71 *);
		struct sock___71 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___71;

struct fib_lookup_arg___71;

struct fib_rules_ops___71 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___71 *, struct flowi *, int, struct fib_lookup_arg___71 *);
	bool (*suppress)(struct fib_rule___71 *, struct fib_lookup_arg___71 *);
	int (*match)(struct fib_rule___71 *, struct flowi *, int);
	int (*configure)(struct fib_rule___71 *, struct sk_buff___92 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___71 *);
	int (*compare)(struct fib_rule___71 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___71 *, struct sk_buff___92 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___71 *);
	void (*flush_cache)(struct fib_rules_ops___71 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___372 *owner;
	struct net___102 *fro_net;
	struct callback_head rcu;
};

struct tcp_congestion_ops___17 {
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___71 *);
	void (*release)(struct sock___71 *);
	u32 (*ssthresh)(struct sock___71 *);
	void (*cong_avoid)(struct sock___71 *, u32, u32);
	void (*set_state)(struct sock___71 *, u8);
	void (*cwnd_event)(struct sock___71 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___71 *, u32);
	u32 (*undo_cwnd)(struct sock___71 *);
	void (*pkts_acked)(struct sock___71 *, const struct ack_sample *);
	u32 (*min_tso_segs)(struct sock___71 *);
	u32 (*sndbuf_expand)(struct sock___71 *);
	void (*cong_control)(struct sock___71 *, const struct rate_sample *);
	size_t (*get_info)(struct sock___71 *, u32, int *, union tcp_cc_info *);
	char name[16];
	struct module___372 *owner;
};

struct tcp_fastopen_context___17 {
	struct crypto_cipher___20 *tfm;
	__u8 key[16];
	struct callback_head rcu;
};

struct fib_notifier_ops___72 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___102 *);
	int (*fib_dump)(struct net___102 *, struct notifier_block *);
	struct module___372 *owner;
	struct callback_head rcu;
};

struct dst_entry___71 {
	struct net_device___91 *dev;
	struct dst_ops___102 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state___13 *xfrm;
	int (*input)(struct sk_buff___92 *);
	int (*output)(struct net___102 *, struct sock___71 *, struct sk_buff___92 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___71;

struct neigh_parms___71;

struct neigh_ops___71;

struct neighbour___71 {
	struct neighbour___71 *next;
	struct neigh_table___71 *tbl;
	struct neigh_parms___71 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___91 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___71 *, struct sk_buff___92 *);
	const struct neigh_ops___71 *ops;
	struct callback_head rcu;
	struct net_device___91 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct fib6_nh___17 {
	struct in6_addr nh_gw;
	struct net_device___91 *nh_dev;
	struct lwtunnel_state *nh_lwtstate;
	unsigned int nh_flags;
	atomic_t nh_upper_bound;
	int nh_weight;
};

struct fib6_node___17;

struct fib6_info___17 {
	struct fib6_table___17 *fib6_table;
	struct fib6_info___17 *fib6_next;
	struct fib6_node___17 *fib6_node;
	struct list_head fib6_siblings;
	unsigned int fib6_nsiblings;
	atomic_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	struct rt6_info___17 **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
	long unsigned int last_probe;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 exception_bucket_flushed: 1;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 dst_host: 1;
	u8 fib6_destroying: 1;
	u8 unused: 2;
	struct fib6_nh___17 fib6_nh;
	struct callback_head rcu;
};

struct rt6_info___17 {
	struct dst_entry___71 dst;
	struct fib6_info___17 *from;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___42 *rt6i_idev;
	u32 rt6i_flags;
	struct rt6key rt6i_prefsrc;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct fib6_node___17 {
	struct fib6_node___17 *parent;
	struct fib6_node___17 *left;
	struct fib6_node___17 *right;
	struct fib6_info___17 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info___17 *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table___17 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node___17 tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

struct ucounts___311 {
	struct hlist_node node;
	struct user_namespace___311 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_prog_aux___84;

struct bpf_prog___81 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___84 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

typedef int (*key_restrict_link_func_t___415)(struct key___414 *, const struct key_type *, const union key_payload *, struct key___414 *);

struct key_restriction___414;

struct key___414 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___448 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___414 *restrict_link;
};

struct key_restriction___414 {
	key_restrict_link_func_t___415 check;
	struct key___414 *key;
	struct key_type *keytype;
};

struct seq_operations___385 {
	void * (*start)(struct seq_file___385 *, loff_t *);
	void (*stop)(struct seq_file___385 *, void *);
	void * (*next)(struct seq_file___385 *, void *, loff_t *);
	int (*show)(struct seq_file___385 *, void *);
};

struct pernet_operations___92 {
	struct list_head list;
	int (*init)(struct net___102 *);
	void (*exit)(struct net___102 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___91 {
	int (*ieee_getets)(struct net_device___91 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___91 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___91 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___91 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___91 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___91 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___91 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___91 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___91 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___91 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___91 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___91 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___91 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___91 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___91 *);
	u8 (*setstate)(struct net_device___91 *, u8);
	void (*getpermhwaddr)(struct net_device___91 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___91 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___91 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___91 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___91 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___91 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___91 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___91 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___91 *, int, u8 *);
	void (*setpfccfg)(struct net_device___91 *, int, u8);
	void (*getpfccfg)(struct net_device___91 *, int, u8 *);
	u8 (*setall)(struct net_device___91 *);
	u8 (*getcap)(struct net_device___91 *, int, u8 *);
	int (*getnumtcs)(struct net_device___91 *, int, u8 *);
	int (*setnumtcs)(struct net_device___91 *, int, u8);
	u8 (*getpfcstate)(struct net_device___91 *);
	void (*setpfcstate)(struct net_device___91 *, u8);
	void (*getbcncfg)(struct net_device___91 *, int, u32 *);
	void (*setbcncfg)(struct net_device___91 *, int, u32);
	void (*getbcnrp)(struct net_device___91 *, int, u8 *);
	void (*setbcnrp)(struct net_device___91 *, int, u8);
	int (*setapp)(struct net_device___91 *, u8, u16, u8);
	int (*getapp)(struct net_device___91 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___91 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___91 *, int, u8);
	u8 (*getdcbx)(struct net_device___91 *);
	u8 (*setdcbx)(struct net_device___91 *, u8);
	int (*peer_getappinfo)(struct net_device___91 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___91 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___91 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___91 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___91 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___91 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___295 {
	refcount_t count;
	struct ns_common___29 ns;
	struct user_namespace___311 *user_ns;
	struct ucounts___311 *ucounts;
	struct css_set___295 *root_cset;
};

struct bpf_map___296;

struct bpf_map_ops___295 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___296 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___296 *, struct file___446 *);
	void (*map_free)(struct bpf_map___296 *);
	int (*map_get_next_key)(struct bpf_map___296 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___296 *);
	void * (*map_lookup_elem)(struct bpf_map___296 *, void *);
	int (*map_update_elem)(struct bpf_map___296 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___296 *, void *);
	int (*map_push_elem)(struct bpf_map___296 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___296 *, void *);
	int (*map_peek_elem)(struct bpf_map___296 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___296 *, struct file___446 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___296 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___296 *, void *, struct seq_file___385 *);
	int (*map_check_btf)(const struct bpf_map___296 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___296 {
	const struct bpf_map_ops___295 *ops;
	struct bpf_map___296 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___414 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___91;

struct bpf_map_dev_ops___91 {
	int (*map_get_next_key)(struct bpf_offloaded_map___91 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___91 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___91 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___91 *, void *);
};

struct bpf_offloaded_map___91 {
	struct bpf_map___296 map;
	struct net_device___91 *netdev;
	const struct bpf_map_dev_ops___91 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___81 {
	int (*test_run)(struct bpf_prog___81 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___81 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___81 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___81 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___81 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___81 *, u32 *);
};

struct bpf_prog_offload_ops___81 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___81 *);
	int (*translate)(struct bpf_prog___81 *);
	void (*destroy)(struct bpf_prog___81 *);
};

struct bpf_prog_offload___81 {
	struct bpf_prog___81 *prog;
	struct net_device___91 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___81 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___84 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___81 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___81 *ops;
	struct bpf_map___296 **used_maps;
	struct bpf_prog___81 *prog;
	struct user_struct___414 *user;
	u64 load_time;
	struct bpf_map___296 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___81 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___81 {
	struct bpf_prog___81 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___81 {
	struct callback_head rcu;
	struct bpf_prog_array_item___81 items[0];
};

struct cgroup_bpf___81 {
	struct bpf_prog_array___81 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___81 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___296;

typedef void (*kthread_work_func_t___296)(struct kthread_work___296 *);

struct kthread_worker___296;

struct kthread_work___296 {
	struct list_head node;
	kthread_work_func_t___296 func;
	struct kthread_worker___296 *worker;
	int canceling;
};

struct kthread_worker___296 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___448 *task;
	struct kthread_work___296 *current_work;
};

struct kthread_delayed_work___295 {
	struct kthread_work___296 work;
	struct timer_list timer;
};

struct psi_group___295 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___296 *poll_kworker;
	struct kthread_delayed_work___295 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___295;

struct cgroup_rstat_cpu___295;

struct cgroup___295 {
	struct cgroup_subsys_state___295 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___441 *kn;
	struct cgroup_file___295 procs_file;
	struct cgroup_file___295 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___295 *subsys[13];
	struct cgroup_root___295 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___295 *dom_cgrp;
	struct cgroup_rstat_cpu___295 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___81 bpf;
	atomic_t congestion_count;
	struct cgroup___295 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___295 psi;
	int ancestor_ids[0];
};

struct cftype___295;

struct cgroup_subsys___295 {
	struct cgroup_subsys_state___295 * (*css_alloc)(struct cgroup_subsys_state___295 *);
	int (*css_online)(struct cgroup_subsys_state___295 *);
	void (*css_offline)(struct cgroup_subsys_state___295 *);
	void (*css_released)(struct cgroup_subsys_state___295 *);
	void (*css_free)(struct cgroup_subsys_state___295 *);
	void (*css_reset)(struct cgroup_subsys_state___295 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___295 *, int);
	int (*css_extra_stat_show)(struct seq_file___385 *, struct cgroup_subsys_state___295 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___448 *);
	void (*cancel_fork)(struct task_struct___448 *);
	void (*fork)(struct task_struct___448 *);
	void (*exit)(struct task_struct___448 *);
	void (*free)(struct task_struct___448 *);
	void (*bind)(struct cgroup_subsys_state___295 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___295 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___295 *dfl_cftypes;
	struct cftype___295 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___295 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___295 *updated_children;
	struct cgroup___295 *updated_next;
};

struct cgroup_root___295 {
	struct kernfs_root___440 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___295 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___295 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___295 *ss;
	struct list_head node;
	struct kernfs_ops___440 *kf_ops;
	int (*open)(struct kernfs_open_file___440 *);
	void (*release)(struct kernfs_open_file___440 *);
	u64 (*read_u64)(struct cgroup_subsys_state___295 *, struct cftype___295 *);
	s64 (*read_s64)(struct cgroup_subsys_state___295 *, struct cftype___295 *);
	int (*seq_show)(struct seq_file___385 *, void *);
	void * (*seq_start)(struct seq_file___385 *, loff_t *);
	void * (*seq_next)(struct seq_file___385 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___385 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___295 *, struct cftype___295 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___295 *, struct cftype___295 *, s64);
	ssize_t (*write)(struct kernfs_open_file___440 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___440 *, struct poll_table_struct___285 *);
};

struct xdp_rxq_info___91 {
	struct net_device___91 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___91 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___91 *dev_rx;
};

struct netlink_callback___93 {
	struct sk_buff___92 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___93 *);
	int (*dump)(struct sk_buff___92 *, struct netlink_callback___93 *);
	int (*done)(struct netlink_callback___93 *);
	void *data;
	struct module___372 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___91 {
	int (*create)(struct sk_buff___92 *, struct net_device___91 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___92 *, unsigned char *);
	int (*cache)(const struct neighbour___71 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___91 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___91 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___91 *, int);
	int poll_owner;
	struct net_device___91 *dev;
	struct sk_buff___92 *gro_list;
	struct sk_buff___92 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___91 {
	struct net_device___91 *dev;
	struct Qdisc___83 *qdisc;
	struct Qdisc___83 *qdisc_sleeping;
	struct kobject___434 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___91 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem___3 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___83 {
	struct sk_buff___92 *head;
	struct sk_buff___92 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___83;

struct Qdisc___83 {
	int (*enqueue)(struct sk_buff___92 *, struct Qdisc___83 *, struct sk_buff___92 **);
	struct sk_buff___92 * (*dequeue)(struct Qdisc___83 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___83 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___91 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___91 gso_skb;
	struct qdisc_skb_head___83 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___83 *next_sched;
	struct sk_buff_head___91 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___91 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___434 kobj;
	struct net_device___91 *dev;
	long: 64;
	struct xdp_rxq_info___91 xdp_rxq;
	union {
		struct xdp_umem___3 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___91)(struct net_device___91 *, struct sk_buff___92 *, struct net_device___91 *);

struct netdev_bpf___91 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___81 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___81 *prog;
			const struct bpf_prog_offload_ops___81 *ops;
		} verifier;
		struct {
			struct bpf_prog___81 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___91 *offmap;
		};
		struct {
			struct xdp_umem___3 *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___91 {
	int (*xdo_dev_state_add)(struct xfrm_state___13 *);
	void (*xdo_dev_state_delete)(struct xfrm_state___13 *);
	void (*xdo_dev_state_free)(struct xfrm_state___13 *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___92 *, struct xfrm_state___13 *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state___13 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct xfrm_state_offload___13 {
	struct net_device___91 *dev;
	long unsigned int offload_handle;
	unsigned int num_exthdrs;
	u8 flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct xfrm_replay___13;

struct xfrm_type___13;

struct xfrm_mode___13;

struct xfrm_type_offload___13;

struct xfrm_state___13 {
	possible_net_t___93 xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	refcount_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
		u32 output_mark;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	const char *geniv;
	struct xfrm_encap_tmpl *encap;
	xfrm_address_t *coaddr;
	struct xfrm_state___13 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	const struct xfrm_replay___13 *repl;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct tasklet_hrtimer mtimer;
	struct xfrm_state_offload___13 xso;
	long int saved_tmo;
	long unsigned int lastused;
	struct page_frag___447 xfrag;
	const struct xfrm_type___13 *type;
	struct xfrm_mode___13 *inner_mode;
	struct xfrm_mode___13 *inner_mode_iaf;
	struct xfrm_mode___13 *outer_mode;
	const struct xfrm_type_offload___13 *type_offload;
	struct xfrm_sec_ctx___2 *security;
	void *data;
	u32 output_mark_mask;
	u32 if_id;
};

struct tlsdev_ops___91 {
	int (*tls_dev_add)(struct net_device___91 *, struct sock___71 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___91 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___91 *, struct sock___71 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___91 {
	int (*ndo_init)(struct net_device___91 *);
	void (*ndo_uninit)(struct net_device___91 *);
	int (*ndo_open)(struct net_device___91 *);
	int (*ndo_stop)(struct net_device___91 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___92 *, struct net_device___91 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___92 *, struct net_device___91 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___91 *, struct sk_buff___92 *, struct net_device___91 *, select_queue_fallback_t___91);
	void (*ndo_change_rx_flags)(struct net_device___91 *, int);
	void (*ndo_set_rx_mode)(struct net_device___91 *);
	int (*ndo_set_mac_address)(struct net_device___91 *, void *);
	int (*ndo_validate_addr)(struct net_device___91 *);
	int (*ndo_do_ioctl)(struct net_device___91 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___91 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___91 *, int);
	int (*ndo_neigh_setup)(struct net_device___91 *, struct neigh_parms___71 *);
	void (*ndo_tx_timeout)(struct net_device___91 *);
	void (*ndo_get_stats64)(struct net_device___91 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___91 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___91 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___91 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___91 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___91 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___91 *);
	int (*ndo_netpoll_setup)(struct net_device___91 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___91 *);
	int (*ndo_set_vf_mac)(struct net_device___91 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___91 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___91 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___91 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___91 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___91 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___91 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___91 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___91 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___91 *, int, struct sk_buff___92 *);
	int (*ndo_set_vf_guid)(struct net_device___91 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___91 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___91 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___91 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___91 *, const struct sk_buff___92 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___91 *, struct net_device___91 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___91 *, struct net_device___91 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___91 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___91 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___91 *, struct neighbour___71 *);
	void (*ndo_neigh_destroy)(struct net_device___91 *, struct neighbour___71 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___91 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___91 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___91 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___92 *, struct netlink_callback___93 *, struct net_device___91 *, struct net_device___91 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___91 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___91 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___92 *, u32, u32, struct net_device___91 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___91 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___91 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___91 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___91 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___91 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___91 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___91 *, struct net_device___91 *);
	void (*ndo_dfwd_del_station)(struct net_device___91 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___91 *);
	int (*ndo_set_tx_maxrate)(struct net_device___91 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___91 *);
	int (*ndo_change_proto_down)(struct net_device___91 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___91 *, struct sk_buff___92 *);
	void (*ndo_set_rx_headroom)(struct net_device___91 *, int);
	int (*ndo_bpf)(struct net_device___91 *, struct netdev_bpf___91 *);
	int (*ndo_xdp_xmit)(struct net_device___91 *, int, struct xdp_frame___91 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___91 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___91 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___71 {
	possible_net_t___93 net;
	struct net_device___91 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___71 *);
	void (*neigh_cleanup)(struct neighbour___71 *);
	struct neigh_table___71 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___71 {
	u32 (*l3mdev_fib_table)(const struct net_device___91 *);
	struct sk_buff___92 * (*l3mdev_l3_rcv)(struct net_device___91 *, struct sk_buff___92 *, u16);
	struct sk_buff___92 * (*l3mdev_l3_out)(struct net_device___91 *, struct sock___71 *, struct sk_buff___92 *, u16);
	struct dst_entry___71 * (*l3mdev_link_scope_lookup)(const struct net_device___91 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct ndisc_ops___42 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___91 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___91 *, struct neighbour___71 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___91 *, u8, struct neighbour___71 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___91 *, struct sk_buff___92 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___102 *, struct net_device___91 *, const struct prefix_info *, struct inet6_dev___42 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___42;

struct ifacaddr6___17;

struct inet6_dev___42 {
	struct net_device___91 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___42 *mc_list;
	struct ifmcaddr6___42 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___17 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	u8 rndid[8];
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___71 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
};

struct tcf_proto___83;

struct mini_Qdisc___83 {
	struct tcf_proto___83 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___83 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___91 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___102 *, struct net_device___91 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___91 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___91 *, struct list_head *);
	size_t (*get_size)(const struct net_device___91 *);
	int (*fill_info)(struct sk_buff___92 *, const struct net_device___91 *);
	size_t (*get_xstats_size)(const struct net_device___91 *);
	int (*fill_xstats)(struct sk_buff___92 *, const struct net_device___91 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___91 *, struct net_device___91 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___91 *, const struct net_device___91 *);
	int (*fill_slave_info)(struct sk_buff___92 *, const struct net_device___91 *, const struct net_device___91 *);
	struct net___102 * (*get_link_net)(const struct net_device___91 *);
	size_t (*get_linkxstats_size)(const struct net_device___91 *, int);
	int (*fill_linkxstats)(struct sk_buff___92 *, const struct net_device___91 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___91 {
	struct list_head poll_list;
	struct sk_buff_head___91 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___91 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___83 *output_queue;
	struct Qdisc___83 **output_queue_tailp;
	struct sk_buff___92 *completion_queue;
	struct sk_buff_head___91 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___91 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___91 input_pkt_queue;
	struct napi_struct___91 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bdi_writeback_congested___236 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___236 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___236 {
	struct bio___236 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___238 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___238 bip_inline_vecs[0];
};

struct bio_set___236 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___236 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___179 {
	struct mem_cgroup___179 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___179 {
	struct lruvec___447 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___179 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___179 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct gnet_dump___83 {
	spinlock_t *lock;
	struct sk_buff___92 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___83;

struct Qdisc_ops___83 {
	struct Qdisc_ops___83 *next;
	const struct Qdisc_class_ops___83 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___92 *, struct Qdisc___83 *, struct sk_buff___92 **);
	struct sk_buff___92 * (*dequeue)(struct Qdisc___83 *);
	struct sk_buff___92 * (*peek)(struct Qdisc___83 *);
	int (*init)(struct Qdisc___83 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___83 *);
	void (*destroy)(struct Qdisc___83 *);
	int (*change)(struct Qdisc___83 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___83 *);
	int (*change_tx_queue_len)(struct Qdisc___83 *, unsigned int);
	int (*dump)(struct Qdisc___83 *, struct sk_buff___92 *);
	int (*dump_stats)(struct Qdisc___83 *, struct gnet_dump___83 *);
	void (*ingress_block_set)(struct Qdisc___83 *, u32);
	void (*egress_block_set)(struct Qdisc___83 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___83 *);
	u32 (*egress_block_get)(struct Qdisc___83 *);
	struct module___372 *owner;
};

struct tcf_block___83;

struct Qdisc_class_ops___83 {
	unsigned int flags;
	struct netdev_queue___91 * (*select_queue)(struct Qdisc___83 *, struct tcmsg *);
	int (*graft)(struct Qdisc___83 *, long unsigned int, struct Qdisc___83 *, struct Qdisc___83 **, struct netlink_ext_ack *);
	struct Qdisc___83 * (*leaf)(struct Qdisc___83 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___83 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___83 *, u32);
	int (*change)(struct Qdisc___83 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___83 *, long unsigned int);
	void (*walk)(struct Qdisc___83 *, struct qdisc_walker *);
	struct tcf_block___83 * (*tcf_block)(struct Qdisc___83 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___83 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___83 *, long unsigned int);
	int (*dump)(struct Qdisc___83 *, long unsigned int, struct sk_buff___92 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___83 *, long unsigned int, struct gnet_dump___83 *);
};

struct tcf_chain___83;

struct tcf_block___83 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___102 *net;
	struct Qdisc___83 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___83 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___83;

struct tcf_proto_ops___83;

struct tcf_proto___83 {
	struct tcf_proto___83 *next;
	void *root;
	int (*classify)(struct sk_buff___92 *, const struct tcf_proto___83 *, struct tcf_result___83 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___83 *ops;
	struct tcf_chain___83 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___83 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___83 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___83 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___92 *, const struct tcf_proto___83 *, struct tcf_result___83 *);
	int (*init)(struct tcf_proto___83 *);
	void (*destroy)(struct tcf_proto___83 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___83 *, u32);
	void (*put)(struct tcf_proto___83 *, void *);
	int (*change)(struct net___102 *, struct sk_buff___92 *, struct tcf_proto___83 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___83 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___83 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___83 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___102 *, struct tcf_chain___83 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___102 *, struct tcf_proto___83 *, void *, struct sk_buff___92 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___92 *, struct net___102 *, void *);
	struct module___372 *owner;
	int flags;
};

struct tcf_chain___83 {
	struct mutex filter_chain_lock;
	struct tcf_proto___83 *filter_chain;
	struct list_head list;
	struct tcf_block___83 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___83 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___71 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___81 *prog;
};

struct bpf_redirect_info___81 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___296 *map;
	struct bpf_map___296 *map_to_flush;
	u32 kern_flags;
};

struct bpf_sock_ops_kern___8 {
	struct sock___71 *sk;
	u32 op;
	union {
		u32 args[4];
		u32 reply;
		u32 replylong[4];
	};
	u32 is_fullsock;
	u64 temp;
};

struct pneigh_entry___71;

struct neigh_hash_table___71;

struct neigh_table___71 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___91 *, __u32 *);
	bool (*key_eq)(const struct neighbour___71 *, const void *);
	int (*constructor)(struct neighbour___71 *);
	int (*pconstructor)(struct pneigh_entry___71 *);
	void (*pdestructor)(struct pneigh_entry___71 *);
	void (*proxy_redo)(struct sk_buff___92 *);
	char *id;
	struct neigh_parms___71 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___91 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___71 *nht;
	struct pneigh_entry___71 **phash_buckets;
};

struct neigh_ops___71 {
	int family;
	void (*solicit)(struct neighbour___71 *, struct sk_buff___92 *);
	void (*error_report)(struct neighbour___71 *, struct sk_buff___92 *);
	int (*output)(struct neighbour___71 *, struct sk_buff___92 *);
	int (*connected_output)(struct neighbour___71 *, struct sk_buff___92 *);
};

struct pneigh_entry___71 {
	struct pneigh_entry___71 *next;
	possible_net_t___93 net;
	struct net_device___91 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___71 {
	struct neighbour___71 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___71 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___71 *ctarget;
	struct net___102 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___71 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___71 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___54;

struct timewait_sock_ops___50;

struct proto___71 {
	void (*close)(struct sock___71 *, long int);
	int (*pre_connect)(struct sock___71 *, struct sockaddr *, int);
	int (*connect)(struct sock___71 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___71 *, int);
	struct sock___71 * (*accept)(struct sock___71 *, int, int *, bool);
	int (*ioctl)(struct sock___71 *, int, long unsigned int);
	int (*init)(struct sock___71 *);
	void (*destroy)(struct sock___71 *);
	void (*shutdown)(struct sock___71 *, int);
	int (*setsockopt)(struct sock___71 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___71 *, int, int, char *, int *);
	void (*keepalive)(struct sock___71 *, int);
	int (*sendmsg)(struct sock___71 *, struct msghdr___74 *, size_t);
	int (*recvmsg)(struct sock___71 *, struct msghdr___74 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___71 *, struct page___447 *, int, size_t, int);
	int (*bind)(struct sock___71 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___71 *, struct sk_buff___92 *);
	void (*release_cb)(struct sock___71 *);
	int (*hash)(struct sock___71 *);
	void (*unhash)(struct sock___71 *);
	void (*rehash)(struct sock___71 *);
	int (*get_port)(struct sock___71 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___71 *);
	bool (*stream_memory_read)(const struct sock___71 *);
	void (*enter_memory_pressure)(struct sock___71 *);
	void (*leave_memory_pressure)(struct sock___71 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___54 *rsk_prot;
	struct timewait_sock_ops___50 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___372 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___71 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct xfrm_policy_queue___13 {
	struct sk_buff_head___91 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___13 {
	possible_net_t___93 xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	refcount_t refcnt;
	struct timer_list timer;
	atomic_t genid;
	u32 priority;
	u32 index;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___13 polq;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx___2 *security;
	struct xfrm_tmpl xfrm_vec[6];
	struct callback_head rcu;
	u32 if_id;
};

struct request_sock___55;

struct request_sock_ops___54 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___71 *, struct request_sock___55 *);
	void (*send_ack)(const struct sock___71 *, struct sk_buff___92 *, struct request_sock___55 *);
	void (*send_reset)(const struct sock___71 *, struct sk_buff___92 *);
	void (*destructor)(struct request_sock___55 *);
	void (*syn_ack_timeout)(const struct request_sock___55 *);
};

struct timewait_sock_ops___50 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___71 *, struct sock___71 *, void *);
	void (*twsk_destructor)(struct sock___71 *);
};

struct request_sock___55 {
	struct sock_common___71 __req_common;
	struct request_sock___55 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___54 *rsk_ops;
	struct sock___71 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct fastopen_queue___11 {
	struct request_sock___55 *rskq_rst_head;
	struct request_sock___55 *rskq_rst_tail;
	spinlock_t lock;
	int qlen;
	int max_qlen;
	struct tcp_fastopen_context___17 *ctx;
};

struct request_sock_queue___11 {
	spinlock_t rskq_lock;
	u8 rskq_defer_accept;
	u32 synflood_warned;
	atomic_t qlen;
	atomic_t young;
	struct request_sock___55 *rskq_accept_head;
	struct request_sock___55 *rskq_accept_tail;
	struct fastopen_queue___11 fastopenq;
};

struct inet_request_sock___7 {
	struct request_sock___55 req;
	u16 snd_wscale: 4;
	u16 rcv_wscale: 4;
	u16 tstamp_ok: 1;
	u16 sack_ok: 1;
	u16 wscale_ok: 1;
	u16 ecn_ok: 1;
	u16 acked: 1;
	u16 no_srccheck: 1;
	u16 smc_ok: 1;
	u32 ir_mark;
	union {
		struct ip_options_rcu *ireq_opt;
		struct {
			struct ipv6_txoptions *ipv6_opt;
			struct sk_buff___92 *pktopts;
		};
	};
};

struct inet_cork___14 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___71 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
	__u16 gso_size;
	u64 transmit_time;
};

struct inet_cork_full___14 {
	struct inet_cork___14 base;
	struct flowi fl;
};

struct ipv6_pinfo___14;

struct inet_sock___14 {
	struct sock___71 sk;
	struct ipv6_pinfo___14 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	__be16 inet_sport;
	__u16 inet_id;
	struct ip_options_rcu *inet_opt;
	int rx_dst_ifindex;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 bind_address_no_port: 1;
	__u8 defer_connect: 1;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___14 cork;
};

struct ipv6_fl_socklist___13;

struct ipv6_pinfo___14 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
			__u16 recvfragsize: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 repflow: 1;
	__u16 pmtudisc: 3;
	__u16 padding: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u16 autoflowlabel: 1;
	__u16 autoflowlabel_set: 1;
	__u8 min_hopcount;
	__u8 tclass;
	__be32 rcv_flowinfo;
	__u32 dst_cookie;
	__u32 rx_dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___13 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___92 *pktoptions;
	struct sk_buff___92 *rxpmtu;
	struct inet6_cork cork;
};

struct inet_connection_sock_af_ops___10 {
	int (*queue_xmit)(struct sock___71 *, struct sk_buff___92 *, struct flowi *);
	void (*send_check)(struct sock___71 *, struct sk_buff___92 *);
	int (*rebuild_header)(struct sock___71 *);
	void (*sk_rx_dst_set)(struct sock___71 *, const struct sk_buff___92 *);
	int (*conn_request)(struct sock___71 *, struct sk_buff___92 *);
	struct sock___71 * (*syn_recv_sock)(const struct sock___71 *, struct sk_buff___92 *, struct request_sock___55 *, struct dst_entry___71 *, struct request_sock___55 *, bool *);
	u16 net_header_len;
	u16 net_frag_header_len;
	u16 sockaddr_len;
	int (*setsockopt)(struct sock___71 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___71 *, int, int, char *, int *);
	void (*addr2sockaddr)(struct sock___71 *, struct sockaddr *);
	void (*mtu_reduced)(struct sock___71 *);
};

struct inet_bind_bucket___10;

struct tcp_ulp_ops___9;

struct inet_connection_sock___11 {
	struct inet_sock___14 icsk_inet;
	struct request_sock_queue___11 icsk_accept_queue;
	struct inet_bind_bucket___10 *icsk_bind_hash;
	long unsigned int icsk_timeout;
	struct timer_list icsk_retransmit_timer;
	struct timer_list icsk_delack_timer;
	__u32 icsk_rto;
	__u32 icsk_pmtu_cookie;
	const struct tcp_congestion_ops___17 *icsk_ca_ops;
	const struct inet_connection_sock_af_ops___10 *icsk_af_ops;
	const struct tcp_ulp_ops___9 *icsk_ulp_ops;
	void *icsk_ulp_data;
	void (*icsk_clean_acked)(struct sock___71 *, u32);
	struct hlist_node icsk_listen_portaddr_node;
	unsigned int (*icsk_sync_mss)(struct sock___71 *, u32);
	__u8 icsk_ca_state: 6;
	__u8 icsk_ca_setsockopt: 1;
	__u8 icsk_ca_dst_locked: 1;
	__u8 icsk_retransmits;
	__u8 icsk_pending;
	__u8 icsk_backoff;
	__u8 icsk_syn_retries;
	__u8 icsk_probes_out;
	__u16 icsk_ext_hdr_len;
	struct {
		__u8 pending;
		__u8 quick;
		__u8 pingpong;
		__u8 blocked;
		__u32 ato;
		long unsigned int timeout;
		__u32 lrcvtime;
		__u16 last_seg_size;
		__u16 rcv_mss;
	} icsk_ack;
	struct {
		int enabled;
		int search_high;
		int search_low;
		int probe_size;
		u32 probe_timestamp;
	} icsk_mtup;
	u32 icsk_user_timeout;
	u64 icsk_ca_priv[11];
};

struct inet_bind_bucket___10 {
	possible_net_t___93 ib_net;
	short unsigned int port;
	signed char fastreuse;
	signed char fastreuseport;
	kuid_t fastuid;
	struct in6_addr fast_v6_rcv_saddr;
	__be32 fast_rcv_saddr;
	short unsigned int fast_sk_family;
	bool fast_ipv6_only;
	struct hlist_node node;
	struct hlist_head owners;
};

struct tcp_ulp_ops___9 {
	struct list_head list;
	int (*init)(struct sock___71 *);
	void (*release)(struct sock___71 *);
	char name[16];
	struct module___372 *owner;
};

struct inet_timewait_sock___3 {
	struct sock_common___71 __tw_common;
	__u32 tw_mark;
	volatile unsigned char tw_substate;
	unsigned char tw_rcv_wscale;
	__be16 tw_sport;
	unsigned int tw_kill: 1;
	unsigned int tw_transparent: 1;
	unsigned int tw_flowlabel: 20;
	unsigned int tw_pad: 2;
	unsigned int tw_tos: 8;
	struct timer_list tw_timer;
	struct inet_bind_bucket___10 *tw_tb;
};

struct tcp_request_sock_ops___6;

struct tcp_request_sock___6 {
	struct inet_request_sock___7 req;
	const struct tcp_request_sock_ops___6 *af_specific;
	u64 snt_synack;
	bool tfo_listener;
	u32 txhash;
	u32 rcv_isn;
	u32 snt_isn;
	u32 ts_off;
	u32 last_oow_ack_time;
	u32 rcv_nxt;
};

struct tcp_request_sock_ops___6 {
	u16 mss_clamp;
	struct tcp_md5sig_key * (*req_md5_lookup)(const struct sock___71 *, const struct sock___71 *);
	int (*calc_md5_hash)(char *, const struct tcp_md5sig_key *, const struct sock___71 *, const struct sk_buff___92 *);
	void (*init_req)(struct request_sock___55 *, const struct sock___71 *, struct sk_buff___92 *);
	__u32 (*cookie_init_seq)(const struct sk_buff___92 *, __u16 *);
	struct dst_entry___71 * (*route_req)(const struct sock___71 *, struct flowi *, const struct request_sock___55 *);
	u32 (*init_seq)(const struct sk_buff___92 *);
	u32 (*init_ts_off)(const struct net___102 *, const struct sk_buff___92 *);
	int (*send_synack)(const struct sock___71 *, struct dst_entry___71 *, struct flowi *, struct request_sock___55 *, struct tcp_fastopen_cookie *, enum tcp_synack_type);
};

struct tcp_sock_af_ops___9;

struct tcp_fastopen_request___9;

struct tcp_sock___9 {
	struct inet_connection_sock___11 inet_conn;
	u16 tcp_header_len;
	u16 gso_segs;
	__be32 pred_flags;
	u64 bytes_received;
	u32 segs_in;
	u32 data_segs_in;
	u32 rcv_nxt;
	u32 copied_seq;
	u32 rcv_wup;
	u32 snd_nxt;
	u32 segs_out;
	u32 data_segs_out;
	u64 bytes_acked;
	u32 snd_una;
	u32 snd_sml;
	u32 rcv_tstamp;
	u32 lsndtime;
	u32 last_oow_ack_time;
	u32 compressed_ack_rcv_nxt;
	u32 tsoffset;
	struct list_head tsq_node;
	struct list_head tsorted_sent_queue;
	u32 snd_wl1;
	u32 snd_wnd;
	u32 max_window;
	u32 mss_cache;
	u32 window_clamp;
	u32 rcv_ssthresh;
	struct tcp_rack rack;
	u16 advmss;
	u8 compressed_ack;
	u32 chrono_start;
	u32 chrono_stat[3];
	u8 chrono_type: 2;
	u8 rate_app_limited: 1;
	u8 fastopen_connect: 1;
	u8 fastopen_no_cookie: 1;
	u8 is_sack_reneg: 1;
	u8 unused: 2;
	u8 nonagle: 4;
	u8 thin_lto: 1;
	u8 recvmsg_inq: 1;
	u8 repair: 1;
	u8 frto: 1;
	u8 repair_queue;
	u8 syn_data: 1;
	u8 syn_fastopen: 1;
	u8 syn_fastopen_exp: 1;
	u8 syn_fastopen_ch: 1;
	u8 syn_data_acked: 1;
	u8 save_syn: 1;
	u8 is_cwnd_limited: 1;
	u8 syn_smc: 1;
	u32 tlp_high_seq;
	u64 tcp_mstamp;
	u32 srtt_us;
	u32 mdev_us;
	u32 mdev_max_us;
	u32 rttvar_us;
	u32 rtt_seq;
	struct minmax rtt_min;
	u32 packets_out;
	u32 retrans_out;
	u32 max_packets_out;
	u32 max_packets_seq;
	u16 urg_data;
	u8 ecn_flags;
	u8 keepalive_probes;
	u32 reordering;
	u32 snd_up;
	struct tcp_options_received rx_opt;
	u32 snd_ssthresh;
	u32 snd_cwnd;
	u32 snd_cwnd_cnt;
	u32 snd_cwnd_clamp;
	u32 snd_cwnd_used;
	u32 snd_cwnd_stamp;
	u32 prior_cwnd;
	u32 prr_delivered;
	u32 prr_out;
	u32 delivered;
	u32 delivered_ce;
	u32 lost;
	u32 app_limited;
	u64 first_tx_mstamp;
	u64 delivered_mstamp;
	u32 rate_delivered;
	u32 rate_interval_us;
	u32 rcv_wnd;
	u32 write_seq;
	u32 notsent_lowat;
	u32 pushed_seq;
	u32 lost_out;
	u32 sacked_out;
	struct hrtimer pacing_timer;
	struct hrtimer compressed_ack_timer;
	struct sk_buff___92 *lost_skb_hint;
	struct sk_buff___92 *retransmit_skb_hint;
	struct rb_root out_of_order_queue;
	struct sk_buff___92 *ooo_last_skb;
	struct tcp_sack_block duplicate_sack[1];
	struct tcp_sack_block selective_acks[4];
	struct tcp_sack_block recv_sack_cache[4];
	struct sk_buff___92 *highest_sack;
	int lost_cnt_hint;
	u32 prior_ssthresh;
	u32 high_seq;
	u32 retrans_stamp;
	u32 undo_marker;
	int undo_retrans;
	u32 total_retrans;
	u32 urg_seq;
	unsigned int keepalive_time;
	unsigned int keepalive_intvl;
	int linger2;
	u8 bpf_sock_ops_cb_flags;
	struct {
		u32 rtt_us;
		u32 seq;
		u64 time;
	} rcv_rtt_est;
	struct {
		u32 space;
		u32 seq;
		u64 time;
	} rcvq_space;
	struct {
		u32 probe_seq_start;
		u32 probe_seq_end;
	} mtu_probe;
	u32 mtu_info;
	const struct tcp_sock_af_ops___9 *af_specific;
	struct tcp_md5sig_info *md5sig_info;
	struct tcp_fastopen_request___9 *fastopen_req;
	struct request_sock___55 *fastopen_rsk;
	u32 *saved_syn;
};

struct tcp_sock_af_ops___9 {
	struct tcp_md5sig_key * (*md5_lookup)(const struct sock___71 *, const struct sock___71 *);
	int (*calc_md5_hash)(char *, const struct tcp_md5sig_key *, const struct sock___71 *, const struct sk_buff___92 *);
	int (*md5_parse)(struct sock___71 *, int, char *, int);
};

struct tcp_fastopen_request___9 {
	struct tcp_fastopen_cookie cookie;
	struct msghdr___74 *data;
	size_t size;
	int copied;
};

struct tcp_timewait_sock___2 {
	struct inet_timewait_sock___3 tw_sk;
	u32 tw_rcv_wnd;
	u32 tw_ts_offset;
	u32 tw_ts_recent;
	u32 tw_last_oow_ack_time;
	long int tw_ts_recent_stamp;
	struct tcp_md5sig_key *tw_md5_key;
};

struct ip6_flowlabel___13;

struct ipv6_fl_socklist___13 {
	struct ipv6_fl_socklist___13 *next;
	struct ip6_flowlabel___13 *fl;
	struct callback_head rcu;
};

struct ifmcaddr6___42 {
	struct in6_addr mca_addr;
	struct inet6_dev___42 *idev;
	struct ifmcaddr6___42 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___17 {
	struct in6_addr aca_addr;
	struct fib6_info___17 *aca_rt;
	struct ifacaddr6___17 *aca_next;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct ip6_ra_chain___42 {
	struct ip6_ra_chain___42 *next;
	struct sock___71 *sk;
	int sel;
	void (*destructor)(struct sock___71 *);
};

struct ip6_flowlabel___13 {
	struct ip6_flowlabel___13 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___248 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___102 *fl_net;
};

struct tcp_skb_cb___7 {
	__u32 seq;
	__u32 end_seq;
	union {
		__u32 tcp_tw_isn;
		struct {
			u16 tcp_gso_segs;
			u16 tcp_gso_size;
		};
	};
	__u8 tcp_flags;
	__u8 sacked;
	__u8 ip_dsfield;
	__u8 txstamp_ack: 1;
	__u8 eor: 1;
	__u8 has_rxtstamp: 1;
	__u8 unused: 5;
	__u32 ack_seq;
	union {
		struct {
			__u32 in_flight: 30;
			__u32 is_app_limited: 1;
			__u32 unused: 1;
			__u32 delivered;
			u64 first_tx_mstamp;
			u64 delivered_mstamp;
		} tx;
		union {
			struct inet_skb_parm h4;
			struct inet6_skb_parm h6;
		} header;
		struct {
			__u32 flags;
			struct sock___71 *sk_redir;
			void *data_end;
		} bpf;
	};
};

struct xfrm_replay___13 {
	void (*advance)(struct xfrm_state___13 *, __be32);
	int (*check)(struct xfrm_state___13 *, struct sk_buff___92 *, __be32);
	int (*recheck)(struct xfrm_state___13 *, struct sk_buff___92 *, __be32);
	void (*notify)(struct xfrm_state___13 *, int);
	int (*overflow)(struct xfrm_state___13 *, struct sk_buff___92 *);
};

struct xfrm_type___13 {
	char *description;
	struct module___372 *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___13 *);
	void (*destructor)(struct xfrm_state___13 *);
	int (*input)(struct xfrm_state___13 *, struct sk_buff___92 *);
	int (*output)(struct xfrm_state___13 *, struct sk_buff___92 *);
	int (*reject)(struct xfrm_state___13 *, struct sk_buff___92 *, const struct flowi *);
	int (*hdr_offset)(struct xfrm_state___13 *, struct sk_buff___92 *, u8 **);
	u32 (*get_mtu)(struct xfrm_state___13 *, int);
};

struct xfrm_state_afinfo___13;

struct xfrm_mode___13 {
	int (*input2)(struct xfrm_state___13 *, struct sk_buff___92 *);
	int (*input)(struct xfrm_state___13 *, struct sk_buff___92 *);
	int (*output2)(struct xfrm_state___13 *, struct sk_buff___92 *);
	int (*output)(struct xfrm_state___13 *, struct sk_buff___92 *);
	struct sk_buff___92 * (*gso_segment)(struct xfrm_state___13 *, struct sk_buff___92 *, netdev_features_t);
	void (*xmit)(struct xfrm_state___13 *, struct sk_buff___92 *);
	struct xfrm_state_afinfo___13 *afinfo;
	struct module___372 *owner;
	unsigned int encap;
	int flags;
};

struct xfrm_type_offload___13 {
	char *description;
	struct module___372 *owner;
	u8 proto;
	void (*encap)(struct xfrm_state___13 *, struct sk_buff___92 *);
	int (*input_tail)(struct xfrm_state___13 *, struct sk_buff___92 *);
	int (*xmit)(struct xfrm_state___13 *, struct sk_buff___92 *, netdev_features_t);
};

struct xfrm_state_afinfo___13 {
	unsigned int family;
	unsigned int proto;
	__be16 eth_proto;
	struct module___372 *owner;
	const struct xfrm_type___13 *type_map[256];
	const struct xfrm_type_offload___13 *type_offload_map[256];
	struct xfrm_mode___13 *mode_map[5];
	int (*init_flags)(struct xfrm_state___13 *);
	void (*init_tempsel)(struct xfrm_selector *, const struct flowi *);
	void (*init_temprop)(struct xfrm_state___13 *, const struct xfrm_tmpl *, const xfrm_address_t *, const xfrm_address_t *);
	int (*tmpl_sort)(struct xfrm_tmpl **, struct xfrm_tmpl **, int);
	int (*state_sort)(struct xfrm_state___13 **, struct xfrm_state___13 **, int);
	int (*output)(struct net___102 *, struct sock___71 *, struct sk_buff___92 *);
	int (*output_finish)(struct sock___71 *, struct sk_buff___92 *);
	int (*extract_input)(struct xfrm_state___13 *, struct sk_buff___92 *);
	int (*extract_output)(struct xfrm_state___13 *, struct sk_buff___92 *);
	int (*transport_finish)(struct sk_buff___92 *, int);
	void (*local_error)(struct sk_buff___92 *, u32);
};

enum tcp_metric_index {
	TCP_METRIC_RTT = 0,
	TCP_METRIC_RTTVAR = 1,
	TCP_METRIC_SSTHRESH = 2,
	TCP_METRIC_CWND = 3,
	TCP_METRIC_REORDERING = 4,
	TCP_METRIC_RTT_US = 5,
	TCP_METRIC_RTTVAR_US = 6,
	__TCP_METRIC_MAX = 7,
};

enum {
	TCP_METRICS_ATTR_UNSPEC = 0,
	TCP_METRICS_ATTR_ADDR_IPV4 = 1,
	TCP_METRICS_ATTR_ADDR_IPV6 = 2,
	TCP_METRICS_ATTR_AGE = 3,
	TCP_METRICS_ATTR_TW_TSVAL = 4,
	TCP_METRICS_ATTR_TW_TS_STAMP = 5,
	TCP_METRICS_ATTR_VALS = 6,
	TCP_METRICS_ATTR_FOPEN_MSS = 7,
	TCP_METRICS_ATTR_FOPEN_SYN_DROPS = 8,
	TCP_METRICS_ATTR_FOPEN_SYN_DROP_TS = 9,
	TCP_METRICS_ATTR_FOPEN_COOKIE = 10,
	TCP_METRICS_ATTR_SADDR_IPV4 = 11,
	TCP_METRICS_ATTR_SADDR_IPV6 = 12,
	TCP_METRICS_ATTR_PAD = 13,
	__TCP_METRICS_ATTR_MAX = 14,
};

enum {
	TCP_METRICS_CMD_UNSPEC = 0,
	TCP_METRICS_CMD_GET = 1,
	TCP_METRICS_CMD_DEL = 2,
	__TCP_METRICS_CMD_MAX = 3,
};

struct tcp_fastopen_metrics {
	u16 mss;
	u16 syn_loss: 10;
	u16 try_exp: 2;
	long unsigned int last_syn_loss;
	struct tcp_fastopen_cookie cookie;
};

struct tcp_metrics_block {
	struct tcp_metrics_block *tcpm_next;
	possible_net_t___90 tcpm_net;
	struct inetpeer_addr tcpm_saddr;
	struct inetpeer_addr tcpm_daddr;
	long unsigned int tcpm_stamp;
	u32 tcpm_lock;
	u32 tcpm_vals[5];
	struct tcp_fastopen_metrics tcpm_fastopen;
	struct callback_head callback_head;
};

struct tcpm_hash_bucket {
	struct tcp_metrics_block *chain;
};

struct napi_gro_cb___4 {
	void *frag0;
	unsigned int frag0_len;
	int data_offset;
	u16 flush;
	u16 flush_id;
	u16 count;
	u16 gro_remcsum_start;
	long unsigned int age;
	u16 proto;
	u8 same_flow: 1;
	u8 encap_mark: 1;
	u8 csum_valid: 1;
	u8 csum_cnt: 3;
	u8 free: 2;
	u8 is_ipv6: 1;
	u8 is_fou: 1;
	u8 is_atomic: 1;
	u8 recursion_counter: 4;
	__wsum csum;
	struct sk_buff___65 *last;
};

struct module___373;

struct file___447;

struct kiocb___447;

struct iov_iter___214;

struct poll_table_struct___286;

struct vm_area_struct___448;

struct inode___447;

struct file_lock___447;

struct page___448;

struct pipe_inode_info___128;

struct seq_file___386;

struct file_operations___447 {
	struct module___373 *owner;
	loff_t (*llseek)(struct file___447 *, loff_t, int);
	ssize_t (*read)(struct file___447 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___447 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___447 *, struct iov_iter___214 *);
	ssize_t (*write_iter)(struct kiocb___447 *, struct iov_iter___214 *);
	int (*iopoll)(struct kiocb___447 *, bool);
	int (*iterate)(struct file___447 *, struct dir_context *);
	int (*iterate_shared)(struct file___447 *, struct dir_context *);
	__poll_t (*poll)(struct file___447 *, struct poll_table_struct___286 *);
	long int (*unlocked_ioctl)(struct file___447 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___447 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___447 *, struct vm_area_struct___448 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___447 *, struct file___447 *);
	int (*flush)(struct file___447 *, fl_owner_t);
	int (*release)(struct inode___447 *, struct file___447 *);
	int (*fsync)(struct file___447 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___447 *, int);
	int (*lock)(struct file___447 *, int, struct file_lock___447 *);
	ssize_t (*sendpage)(struct file___447 *, struct page___448 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___447 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___447 *, int, struct file_lock___447 *);
	ssize_t (*splice_write)(struct pipe_inode_info___128 *, struct file___447 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___447 *, loff_t *, struct pipe_inode_info___128 *, size_t, unsigned int);
	int (*setlease)(struct file___447 *, long int, struct file_lock___447 **, void **);
	long int (*fallocate)(struct file___447 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___386 *, struct file___447 *);
	ssize_t (*copy_file_range)(struct file___447 *, loff_t, struct file___447 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___447 *, loff_t, struct file___447 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___447 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___448 {
	u64 seqnum;
	struct vm_area_struct___448 *vmas[4];
};

struct page_frag___448 {
	struct page___448 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___448;

struct mem_cgroup___180;

struct pid___249;

struct cred___415;

struct nsproxy___342;

struct signal_struct___322;

struct bio_list___237;

struct backing_dev_info___237;

struct css_set___296;

struct vm_struct___351;

struct task_struct___449 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___449 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___448 *mm;
	struct mm_struct___448 *active_mm;
	struct vmacache___448 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___449 *real_parent;
	struct task_struct___449 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___449 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___180 *active_memcg;
	long int rh_reserved2;
	struct pid___249 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___249 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___249 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___415 *ptracer_cred;
	const struct cred___415 *real_cred;
	const struct cred___415 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___342 *nsproxy;
	struct signal_struct___322 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___449 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___237 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___237 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___296 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___128 *splice_pipe;
	struct page_frag___448 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___180 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___449 *oom_reaper_list;
	struct vm_struct___351 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___156 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___249;

struct upid___249 {
	int nr;
	struct pid_namespace___249 *ns;
};

struct dentry___447;

struct user_namespace___312;

struct ucounts___312;

struct pid_namespace___249 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___449 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___249 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___447 *proc_self;
	struct dentry___447 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___312 *user_ns;
	struct ucounts___312 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___29 ns;
};

struct pid___249 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___249 numbers[1];
};

struct rw_semaphore___449 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___449 *owner;
};

struct key___415;

struct user_namespace___312 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___312 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___29 ns;
	long unsigned int flags;
	struct key___415 *persistent_keyring_register;
	struct rw_semaphore___449 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___312 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct secondary_data___449 {
	void *stack;
	struct task_struct___449 *task;
	long int status;
};

typedef struct page___448 *pgtable_t___448;

struct address_space___447;

struct dev_pagemap___435;

struct page___448 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___447 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___448 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___448 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___448 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___435 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___180 *mem_cgroup;
};

struct user_struct___415 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___415 *uid_keyring;
	struct key___415 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___435;

struct vm_area_struct___448 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___448 *vm_next;
	struct vm_area_struct___448 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___448 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___435 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___447 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___448;

struct mm_struct___448 {
	struct {
		struct vm_area_struct___448 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___447 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___449 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___448 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___449 *owner;
		struct user_namespace___312 *user_ns;
		struct file___447 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___448 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup___296;

struct cgroup_subsys___296;

struct cgroup_subsys_state___296 {
	struct cgroup___296 *cgroup;
	struct cgroup_subsys___296 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___296 *parent;
};

struct kernfs_node___442;

struct cgroup_file___296 {
	struct kernfs_node___442 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___180;

struct mem_cgroup___180 {
	struct cgroup_subsys_state___296 css;
	struct mem_cgroup_id___16 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___296 events_file;
	struct cgroup_file___296 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___449 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___180 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cred___415 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___415 *session_keyring;
	struct key___415 *process_keyring;
	struct key___415 *thread_keyring;
	struct key___415 *request_key_auth;
	void *security;
	struct user_struct___415 *user;
	struct user_namespace___312 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___103;

struct cgroup_namespace___296;

struct nsproxy___342 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___249 *pid_ns_for_children;
	struct net___103 *net_ns;
	struct cgroup_namespace___296 *cgroup_ns;
};

struct signal_struct___322 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___449 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___449 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___249 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___249 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___448 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___249 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___237;

struct bio_list___237 {
	struct bio___237 *head;
	struct bio___237 *tail;
};

struct bdi_writeback_congested___237;

struct bdi_writeback___237 {
	struct backing_dev_info___237 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___237 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___296 *memcg_css;
	struct cgroup_subsys_state___296 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___415;

struct backing_dev_info___237 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___237 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___415 *dev;
	struct device___415 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___447 *debug_dir;
	struct dentry___447 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___296 {
	struct cgroup_subsys_state___296 *subsys[13];
	refcount_t refcount;
	struct css_set___296 *dom_cset;
	struct cgroup___296 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___296 *mg_src_cgrp;
	struct cgroup___296 *mg_dst_cgrp;
	struct css_set___296 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___447;

struct pipe_buffer___128;

struct pipe_inode_info___128 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___448 *tmp_page;
	struct fasync_struct___447 *fasync_readers;
	struct fasync_struct___447 *fasync_writers;
	struct pipe_buffer___128 *bufs;
	struct user_struct___415 *user;
};

struct vm_struct___351 {
	struct vm_struct___351 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___448 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___334 {
	struct task_struct___449 task;
	long unsigned int stack[8192];
};

struct address_space_operations___447;

struct address_space___447 {
	struct inode___447 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___449 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___447 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___435)(struct vm_area_struct___448 *, long unsigned int, const struct page___448 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___435)(struct page___448 *, void *);

struct dev_pagemap___435 {
	dev_page_fault_t___435 page_fault;
	dev_page_free_t___435 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___415 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___448 {
	struct vfsmount *mnt;
	struct dentry___447 *dentry;
};

struct fown_struct___249 {
	rwlock_t lock;
	struct pid___249 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___447 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___448 f_path;
	struct inode___447 *f_inode;
	const struct file_operations___447 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___249 f_owner;
	const struct cred___415 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___447 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___435;

struct vm_operations_struct___435 {
	void (*open)(struct vm_area_struct___448 *);
	void (*close)(struct vm_area_struct___448 *);
	int (*split)(struct vm_area_struct___448 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___448 *);
	vm_fault_t (*fault)(struct vm_fault___435 *);
	vm_fault_t (*huge_fault)(struct vm_fault___435 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___435 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___448 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___435 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___435 *);
	int (*access)(struct vm_area_struct___448 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___448 *);
	int (*set_policy)(struct vm_area_struct___448 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___448 *, long unsigned int);
	struct page___448 * (*find_special_page)(struct vm_area_struct___448 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___448 {
	struct task_struct___449 *task;
	struct core_thread___448 *next;
};

struct core_state___448 {
	atomic_t nr_threads;
	struct core_thread___448 dumper;
	struct completion startup;
};

struct vm_fault___435 {
	struct vm_area_struct___448 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___448 *cow_page;
	struct mem_cgroup___180 *memcg;
	struct page___448 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___448 prealloc_pte;
};

struct pglist_data___448;

struct lruvec___448 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___448 *pgdat;
};

struct zone___448 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___448 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___448 {
	struct zone___448 *zone;
	int zone_idx;
};

struct zonelist___448 {
	struct zoneref___448 _zonerefs[25];
};

struct pglist_data___448 {
	struct zone___448 node_zones[3];
	struct zonelist___448 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___449 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___449 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___448 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___448 {
	struct rw_semaphore___449 rwsem;
	struct notifier_block *head;
};

struct kset___434;

struct kobj_type___434;

struct kobject___435 {
	const char *name;
	struct list_head entry;
	struct kobject___435 *parent;
	struct kset___434 *kset;
	struct kobj_type___434 *ktype;
	struct kernfs_node___442 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___373 {
	struct kobject___435 kobj;
	struct module___373 *mod;
	struct kobject___435 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___373 {
	struct module___373 *mod;
	struct latch_tree_node node;
};

struct module_layout___373 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___373 mtn;
};

struct module_attribute___373;

struct kernel_param___373;

struct module___373 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___373 mkobj;
	struct module_attribute___373 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___435 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___373 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___373 core_layout;
	struct module_layout___373 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide53;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide54;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bio_vec___239 {
	struct page___448 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___214 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___239 *bvec;
		struct pipe_inode_info___128 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct msghdr___75 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___214 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___447 *msg_iocb;
};

struct kiocb___447 {
	struct file___447 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___447 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dentry_operations___447;

struct super_block___447;

struct dentry___447 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___447 *d_parent;
	struct qstr d_name;
	struct inode___447 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___447 *d_op;
	struct super_block___447 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___447;

struct block_device___447;

struct inode___447 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___447 *i_op;
	struct super_block___447 *i_sb;
	struct address_space___447 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___449 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___237 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___447 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___447 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___128 *i_pipe;
		struct block_device___447 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___447 {
	int (*d_revalidate)(struct dentry___447 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___447 *, unsigned int);
	int (*d_hash)(const struct dentry___447 *, struct qstr *);
	int (*d_compare)(const struct dentry___447 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___447 *);
	int (*d_init)(struct dentry___447 *);
	void (*d_release)(struct dentry___447 *);
	void (*d_prune)(struct dentry___447 *);
	void (*d_iput)(struct dentry___447 *, struct inode___447 *);
	char * (*d_dname)(struct dentry___447 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___448 *);
	int (*d_manage)(const struct path___448 *, bool);
	struct dentry___447 * (*d_real)(struct dentry___447 *, const struct inode___447 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___447;

struct mem_dqinfo___447 {
	struct quota_format_type___447 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___447;

struct quota_info___447 {
	unsigned int flags;
	struct rw_semaphore___449 dqio_sem;
	struct inode___447 *files[3];
	struct mem_dqinfo___447 info[3];
	const struct quota_format_ops___447 *ops[3];
};

struct rcuwait___447 {
	struct task_struct___449 *task;
};

struct percpu_rw_semaphore___447 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___449 rw_sem;
	struct rcuwait___447 writer;
	int readers_block;
};

struct sb_writers___447 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___447 rw_sem[3];
};

struct shrink_control___180;

struct shrinker___180 {
	long unsigned int (*count_objects)(struct shrinker___180 *, struct shrink_control___180 *);
	long unsigned int (*scan_objects)(struct shrinker___180 *, struct shrink_control___180 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___447;

struct super_operations___447;

struct dquot_operations___447;

struct quotactl_ops___447;

struct super_block___447 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___447 *s_type;
	const struct super_operations___447 *s_op;
	const struct dquot_operations___447 *dq_op;
	const struct quotactl_ops___447 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___447 *s_root;
	struct rw_semaphore___449 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___447 *s_bdev;
	struct backing_dev_info___237 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___447 s_dquot;
	struct sb_writers___447 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___447 *s_d_op;
	int cleancache_poolid;
	struct shrinker___180 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___312 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___180 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___180 *memcg;
};

struct iattr___447 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___447 *ia_file;
};

struct dquot___447 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___447 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___447 {
	int qf_fmt_id;
	const struct quota_format_ops___447 *qf_ops;
	struct module___373 *qf_owner;
	struct quota_format_type___447 *qf_next;
};

struct quota_format_ops___447 {
	int (*check_quota_file)(struct super_block___447 *, int);
	int (*read_file_info)(struct super_block___447 *, int);
	int (*write_file_info)(struct super_block___447 *, int);
	int (*free_file_info)(struct super_block___447 *, int);
	int (*read_dqblk)(struct dquot___447 *);
	int (*commit_dqblk)(struct dquot___447 *);
	int (*release_dqblk)(struct dquot___447 *);
	int (*get_next_id)(struct super_block___447 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___447 {
	int (*write_dquot)(struct dquot___447 *);
	struct dquot___447 * (*alloc_dquot)(struct super_block___447 *, int);
	void (*destroy_dquot)(struct dquot___447 *);
	int (*acquire_dquot)(struct dquot___447 *);
	int (*release_dquot)(struct dquot___447 *);
	int (*mark_dirty)(struct dquot___447 *);
	int (*write_info)(struct super_block___447 *, int);
	qsize_t * (*get_reserved_space)(struct inode___447 *);
	int (*get_projid)(struct inode___447 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___447 *, qsize_t *);
	int (*get_next_id)(struct super_block___447 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___447 {
	int (*quota_on)(struct super_block___447 *, int, int, const struct path___448 *);
	int (*quota_off)(struct super_block___447 *, int);
	int (*quota_enable)(struct super_block___447 *, unsigned int);
	int (*quota_disable)(struct super_block___447 *, unsigned int);
	int (*quota_sync)(struct super_block___447 *, int);
	int (*set_info)(struct super_block___447 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___447 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___447 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___447 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___447 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___447 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___200;

struct address_space_operations___447 {
	int (*writepage)(struct page___448 *, struct writeback_control___200 *);
	int (*readpage)(struct file___447 *, struct page___448 *);
	int (*writepages)(struct address_space___447 *, struct writeback_control___200 *);
	int (*set_page_dirty)(struct page___448 *);
	int (*readpages)(struct file___447 *, struct address_space___447 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___447 *, struct address_space___447 *, loff_t, unsigned int, unsigned int, struct page___448 **, void **);
	int (*write_end)(struct file___447 *, struct address_space___447 *, loff_t, unsigned int, unsigned int, struct page___448 *, void *);
	sector_t (*bmap)(struct address_space___447 *, sector_t);
	void (*invalidatepage)(struct page___448 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___448 *, gfp_t);
	void (*freepage)(struct page___448 *);
	ssize_t (*direct_IO)(struct kiocb___447 *, struct iov_iter___214 *);
	int (*migratepage)(struct address_space___447 *, struct page___448 *, struct page___448 *, enum migrate_mode);
	bool (*isolate_page)(struct page___448 *, isolate_mode_t);
	void (*putback_page)(struct page___448 *);
	int (*launder_page)(struct page___448 *);
	int (*is_partially_uptodate)(struct page___448 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___448 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___447 *, struct page___448 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___447 *, sector_t *);
	void (*swap_deactivate)(struct file___447 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___200 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___237 *wb;
	struct inode___447 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___447 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___447 *bd_inode;
	struct super_block___447 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___447 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___237 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___447 {
	struct dentry___447 * (*lookup)(struct inode___447 *, struct dentry___447 *, unsigned int);
	const char * (*get_link)(struct dentry___447 *, struct inode___447 *, struct delayed_call *);
	int (*permission)(struct inode___447 *, int);
	struct posix_acl * (*get_acl)(struct inode___447 *, int);
	int (*readlink)(struct dentry___447 *, char *, int);
	int (*create)(struct inode___447 *, struct dentry___447 *, umode_t, bool);
	int (*link)(struct dentry___447 *, struct inode___447 *, struct dentry___447 *);
	int (*unlink)(struct inode___447 *, struct dentry___447 *);
	int (*symlink)(struct inode___447 *, struct dentry___447 *, const char *);
	int (*mkdir)(struct inode___447 *, struct dentry___447 *, umode_t);
	int (*rmdir)(struct inode___447 *, struct dentry___447 *);
	int (*mknod)(struct inode___447 *, struct dentry___447 *, umode_t, dev_t);
	int (*rename)(struct inode___447 *, struct dentry___447 *, struct inode___447 *, struct dentry___447 *, unsigned int);
	int (*setattr)(struct dentry___447 *, struct iattr___447 *);
	int (*getattr)(const struct path___448 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___447 *, char *, size_t);
	int (*fiemap)(struct inode___447 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___447 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___447 *, struct dentry___447 *, struct file___447 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___447 *, struct dentry___447 *, umode_t);
	int (*set_acl)(struct inode___447 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___447 {
	void (*fl_copy_lock)(struct file_lock___447 *, struct file_lock___447 *);
	void (*fl_release_private)(struct file_lock___447 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___447;

struct file_lock___447 {
	struct file_lock___447 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___447 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___447 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___447 *fl_ops;
	const struct lock_manager_operations___447 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___447 {
	int (*lm_compare_owner)(struct file_lock___447 *, struct file_lock___447 *);
	long unsigned int (*lm_owner_key)(struct file_lock___447 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___447 *);
	int (*lm_grant)(struct file_lock___447 *, int);
	bool (*lm_break)(struct file_lock___447 *);
	int (*lm_change)(struct file_lock___447 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___447 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___447 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___447 *fa_next;
	struct file___447 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___447 {
	const char *name;
	int fs_flags;
	struct dentry___447 * (*mount)(struct file_system_type___447 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___447 *);
	struct module___373 *owner;
	struct file_system_type___447 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___447 {
	struct inode___447 * (*alloc_inode)(struct super_block___447 *);
	void (*destroy_inode)(struct inode___447 *);
	void (*dirty_inode)(struct inode___447 *, int);
	int (*write_inode)(struct inode___447 *, struct writeback_control___200 *);
	int (*drop_inode)(struct inode___447 *);
	void (*evict_inode)(struct inode___447 *);
	void (*put_super)(struct super_block___447 *);
	int (*sync_fs)(struct super_block___447 *, int);
	int (*freeze_super)(struct super_block___447 *);
	int (*freeze_fs)(struct super_block___447 *);
	int (*thaw_super)(struct super_block___447 *);
	int (*unfreeze_fs)(struct super_block___447 *);
	int (*statfs)(struct dentry___447 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___447 *, int *, char *);
	void (*umount_begin)(struct super_block___447 *);
	int (*show_options)(struct seq_file___386 *, struct dentry___447 *);
	int (*show_devname)(struct seq_file___386 *, struct dentry___447 *);
	int (*show_path)(struct seq_file___386 *, struct dentry___447 *);
	int (*show_stats)(struct seq_file___386 *, struct dentry___447 *);
	ssize_t (*quota_read)(struct super_block___447 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___447 *, int, const char *, size_t, loff_t);
	struct dquot___447 ** (*get_dquots)(struct inode___447 *);
	int (*bdev_try_to_free_page)(struct super_block___447 *, struct page___448 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___447 *, struct shrink_control___180 *);
	long int (*free_cached_objects)(struct super_block___447 *, struct shrink_control___180 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___296)(struct file___447 *, wait_queue_head_t *, struct poll_table_struct___286 *);

struct poll_table_struct___286 {
	poll_queue_proc___296 _qproc;
	__poll_t _key;
};

struct seq_operations___386;

struct seq_file___386 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___386 *op;
	int poll_event;
	const struct file___447 *file;
	void *private;
};

typedef void bio_end_io_t___237(struct bio___237 *);

struct bio_integrity_payload___237;

struct bio_set___237;

struct bio___237 {
	struct bio___237 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___237 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___237 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___239 *bi_io_vec;
	struct bio_set___237 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___239 bi_inline_vecs[0];
};

struct socket_wq___73 {
	wait_queue_head_t wait;
	struct fasync_struct___447 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct sock___72;

struct proto_ops___73;

struct socket___74 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___73 *wq;
	struct file___447 *file;
	struct sock___72 *sk;
	const struct proto_ops___73 *ops;
};

typedef struct {
	struct net___103 *net;
} possible_net_t___94;

struct proto___72;

struct sock_common___72 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___72 *skc_prot;
	possible_net_t___94 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___72 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___93;

struct sk_buff_head___92 {
	struct sk_buff___93 *next;
	struct sk_buff___93 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___72;

struct xfrm_policy___14;

struct dst_entry___72;

struct net_device___92;

struct sock___72 {
	struct sock_common___72 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___92 sk_error_queue;
	struct sk_buff_head___92 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___93 *head;
		struct sk_buff___93 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___72 *sk_filter;
	union {
		struct socket_wq___73 *sk_wq;
		struct socket_wq___73 *sk_wq_raw;
	};
	struct xfrm_policy___14 *sk_policy[2];
	struct dst_entry___72 *sk_rx_dst;
	struct dst_entry___72 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___93 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___92 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___448 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___72 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___249 *sk_peer_pid;
	const struct cred___415 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___74 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___180 *sk_memcg;
	void (*sk_state_change)(struct sock___72 *);
	void (*sk_data_ready)(struct sock___72 *);
	void (*sk_write_space)(struct sock___72 *);
	void (*sk_error_report)(struct sock___72 *);
	int (*sk_backlog_rcv)(struct sock___72 *, struct sk_buff___93 *);
	struct sk_buff___93 * (*sk_validate_xmit_skb)(struct sock___72 *, struct net_device___92 *, struct sk_buff___93 *);
	void (*sk_destruct)(struct sock___72 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

typedef int (*sk_read_actor_t___72)(read_descriptor_t *, struct sk_buff___93 *, unsigned int, size_t);

struct proto_ops___73 {
	int family;
	struct module___373 *owner;
	int (*release)(struct socket___74 *);
	int (*bind)(struct socket___74 *, struct sockaddr *, int);
	int (*connect)(struct socket___74 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___74 *, struct socket___74 *);
	int (*accept)(struct socket___74 *, struct socket___74 *, int, bool);
	int (*getname)(struct socket___74 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___447 *, struct socket___74 *, struct poll_table_struct___286 *);
	int (*ioctl)(struct socket___74 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___74 *, int);
	int (*shutdown)(struct socket___74 *, int);
	int (*setsockopt)(struct socket___74 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___74 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___74 *, struct msghdr___75 *, size_t);
	int (*recvmsg)(struct socket___74 *, struct msghdr___75 *, size_t, int);
	int (*mmap)(struct file___447 *, struct socket___74 *, struct vm_area_struct___448 *);
	ssize_t (*sendpage)(struct socket___74 *, struct page___448 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___74 *, loff_t *, struct pipe_inode_info___128 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___72 *, int);
	int (*peek_len)(struct socket___74 *);
	int (*read_sock)(struct sock___72 *, read_descriptor_t *, sk_read_actor_t___72);
	int (*sendpage_locked)(struct sock___72 *, struct page___448 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___72 *, struct msghdr___75 *, size_t);
	int (*set_rcvlowat)(struct sock___72 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct sec_path___14;

struct nf_bridge_info___92;

struct sk_buff___93 {
	union {
		struct {
			struct sk_buff___93 *next;
			struct sk_buff___93 *prev;
			union {
				struct net_device___92 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___72 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___93 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path___14 *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___92 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___92;

struct netns_frags___92 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___92 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ip_ra_chain___38;

struct fib_rules_ops___72;

struct fib_notifier_ops___73;

struct netns_ipv4___92 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___38 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___72 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___72 *fibnl;
	struct sock___72 **icmp_sk;
	struct sock___72 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___72 **tcp_sk;
	struct netns_frags___92 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___72 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___73 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___73 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___72;

struct dst_ops___103 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___103 *);
	struct dst_entry___72 * (*check)(struct dst_entry___72 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___72 *);
	unsigned int (*mtu)(const struct dst_entry___72 *);
	u32 * (*cow_metrics)(struct dst_entry___72 *, long unsigned int);
	void (*destroy)(struct dst_entry___72 *);
	void (*ifdown)(struct dst_entry___72 *, struct net_device___92 *, int);
	struct dst_entry___72 * (*negative_advice)(struct dst_entry___72 *);
	void (*link_failure)(struct sk_buff___93 *);
	void (*update_pmtu)(struct dst_entry___72 *, struct sock___72 *, struct sk_buff___93 *, u32);
	void (*redirect)(struct dst_entry___72 *, struct sock___72 *, struct sk_buff___93 *);
	int (*local_out)(struct net___103 *, struct sock___72 *, struct sk_buff___93 *);
	struct neighbour___72 * (*neigh_lookup)(const struct dst_entry___72 *, struct sk_buff___93 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___72 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_info___18;

struct rt6_info___18;

struct fib6_table___18;

struct netns_ipv6___103 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___92 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info___18 *fib6_null_entry;
	struct rt6_info___18 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___18 *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___103 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info___18 *ip6_prohibit_entry;
	struct rt6_info___18 *ip6_blk_hole_entry;
	struct fib6_table___18 *fib6_local_tbl;
	struct fib_rules_ops___72 *fib6_rules_ops;
	struct sock___72 **icmp_sk;
	struct sock___72 *ndisc_sk;
	struct sock___72 *tcp_sk;
	struct sock___72 *igmp_sk;
	struct sock___72 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___72 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___73 *notifier_ops;
	struct fib_notifier_ops___73 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___73 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___72 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct nf_hook_entries___12;

struct netns_nf___13 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_queue_handler *queue_handler;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header *nf_log_dir_header;
	struct nf_hook_entries___12 *hooks_ipv4[5];
	struct nf_hook_entries___12 *hooks_ipv6[5];
	struct nf_hook_entries___12 *hooks_arp[3];
	struct nf_hook_entries___12 *hooks_bridge[5];
	bool defrag_ipv4;
	bool defrag_ipv6;
};

struct netns_nf_frag___92 {
	struct netns_frags___92 frags;
};

struct netns_xfrm___103 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___72 *nlsk;
	struct sock___72 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___103 xfrm4_dst_ops;
	struct dst_ops___103 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___82;

struct net___103 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___312 *user_ns;
	struct ucounts___312 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___29 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___72 *rtnl;
	struct sock___72 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___92 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___92 ipv4;
	struct netns_ipv6___103 ipv6;
	struct netns_sctp___73 sctp;
	struct netns_nf___13 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___92 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___72 *nfnl;
	struct sock___72 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___103 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___72 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___82 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kernfs_root___441;

struct kernfs_elem_dir___441 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___441 *root;
};

struct kernfs_syscall_ops___441;

struct kernfs_root___441 {
	struct kernfs_node___442 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___441 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___441 {
	struct kernfs_node___442 *target_kn;
};

struct kernfs_ops___441;

struct kernfs_elem_attr___441 {
	const struct kernfs_ops___441 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___442 *notify_next;
};

struct kernfs_node___442 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___442 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___441 dir;
		struct kernfs_elem_symlink___441 symlink;
		struct kernfs_elem_attr___441 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___441;

struct kernfs_ops___441 {
	int (*open)(struct kernfs_open_file___441 *);
	void (*release)(struct kernfs_open_file___441 *);
	int (*seq_show)(struct seq_file___386 *, void *);
	void * (*seq_start)(struct seq_file___386 *, loff_t *);
	void * (*seq_next)(struct seq_file___386 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___386 *, void *);
	ssize_t (*read)(struct kernfs_open_file___441 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___441 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___441 *, struct vm_area_struct___448 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___441 *, struct poll_table_struct___286 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___441 {
	int (*remount_fs)(struct kernfs_root___441 *, int *, char *);
	int (*show_options)(struct seq_file___386 *, struct kernfs_root___441 *);
	int (*mkdir)(struct kernfs_node___442 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___442 *);
	int (*rename)(struct kernfs_node___442 *, struct kernfs_node___442 *, const char *);
	int (*show_path)(struct seq_file___386 *, struct kernfs_node___442 *, struct kernfs_root___441 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___441 {
	struct kernfs_node___442 *kn;
	struct file___447 *file;
	struct seq_file___386 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___435 *vm_ops;
};

struct kobj_ns_type_operations___72 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___72 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___411;

struct attribute_group___412 {
	const char *name;
	umode_t (*is_visible)(struct kobject___435 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___435 *, struct bin_attribute___411 *, int);
	struct attribute **attrs;
	struct bin_attribute___411 **bin_attrs;
};

struct bin_attribute___411 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___447 *, struct kobject___435 *, struct bin_attribute___411 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___447 *, struct kobject___435 *, struct bin_attribute___411 *, char *, loff_t, size_t);
	int (*mmap)(struct file___447 *, struct kobject___435 *, struct bin_attribute___411 *, struct vm_area_struct___448 *);
};

struct sysfs_ops___434 {
	ssize_t (*show)(struct kobject___435 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___435 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___434;

struct kset___434 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___435 kobj;
	const struct kset_uevent_ops___434 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___434 {
	void (*release)(struct kobject___435 *);
	const struct sysfs_ops___434 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___72 * (*child_ns_type)(struct kobject___435 *);
	const void * (*namespace)(struct kobject___435 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___434 {
	int (* const filter)(struct kset___434 *, struct kobject___435 *);
	const char * (* const name)(struct kset___434 *, struct kobject___435 *);
	int (* const uevent)(struct kset___434 *, struct kobject___435 *, struct kobj_uevent_env *);
};

struct kobj_attribute___425 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___435 *, struct kobj_attribute___425 *, char *);
	ssize_t (*store)(struct kobject___435 *, struct kobj_attribute___425 *, const char *, size_t);
};

struct dev_pm_ops___415 {
	int (*prepare)(struct device___415 *);
	void (*complete)(struct device___415 *);
	int (*suspend)(struct device___415 *);
	int (*resume)(struct device___415 *);
	int (*freeze)(struct device___415 *);
	int (*thaw)(struct device___415 *);
	int (*poweroff)(struct device___415 *);
	int (*restore)(struct device___415 *);
	int (*suspend_late)(struct device___415 *);
	int (*resume_early)(struct device___415 *);
	int (*freeze_late)(struct device___415 *);
	int (*thaw_early)(struct device___415 *);
	int (*poweroff_late)(struct device___415 *);
	int (*restore_early)(struct device___415 *);
	int (*suspend_noirq)(struct device___415 *);
	int (*resume_noirq)(struct device___415 *);
	int (*freeze_noirq)(struct device___415 *);
	int (*thaw_noirq)(struct device___415 *);
	int (*poweroff_noirq)(struct device___415 *);
	int (*restore_noirq)(struct device___415 *);
	int (*runtime_suspend)(struct device___415 *);
	int (*runtime_resume)(struct device___415 *);
	int (*runtime_idle)(struct device___415 *);
};

struct dev_pm_info___415 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___415 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___415;

struct bus_type___415;

struct device_driver___415;

struct dev_pm_domain___415;

struct dma_map_ops___187;

struct fwnode_handle___335;

struct class___415;

struct device___415 {
	struct device___415 *parent;
	struct device_private *p;
	struct kobject___435 kobj;
	const char *init_name;
	const struct device_type___415 *type;
	struct mutex mutex;
	struct bus_type___415 *bus;
	struct device_driver___415 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___415 power;
	struct dev_pm_domain___415 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___187 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___335 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___415 *class;
	const struct attribute_group___412 **groups;
	void (*release)(struct device___415 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___415 {
	struct dev_pm_ops___415 ops;
	void (*detach)(struct device___415 *, bool);
	int (*activate)(struct device___415 *);
	void (*sync)(struct device___415 *);
	void (*dismiss)(struct device___415 *);
};

struct bus_type___415 {
	const char *name;
	const char *dev_name;
	struct device___415 *dev_root;
	const struct attribute_group___412 **bus_groups;
	const struct attribute_group___412 **dev_groups;
	const struct attribute_group___412 **drv_groups;
	int (*match)(struct device___415 *, struct device_driver___415 *);
	int (*uevent)(struct device___415 *, struct kobj_uevent_env *);
	int (*probe)(struct device___415 *);
	int (*remove)(struct device___415 *);
	void (*shutdown)(struct device___415 *);
	int (*online)(struct device___415 *);
	int (*offline)(struct device___415 *);
	int (*suspend)(struct device___415 *, pm_message_t);
	int (*resume)(struct device___415 *);
	int (*num_vf)(struct device___415 *);
	int (*dma_configure)(struct device___415 *);
	const struct dev_pm_ops___415 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___415 {
	const char *name;
	struct bus_type___415 *bus;
	struct module___373 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___415 *);
	int (*remove)(struct device___415 *);
	void (*shutdown)(struct device___415 *);
	int (*suspend)(struct device___415 *, pm_message_t);
	int (*resume)(struct device___415 *);
	const struct attribute_group___412 **groups;
	const struct dev_pm_ops___415 *pm;
	void (*coredump)(struct device___415 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___415 {
	const char *name;
	const struct attribute_group___412 **groups;
	int (*uevent)(struct device___415 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___415 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___415 *);
	const struct dev_pm_ops___415 *pm;
};

struct class___415 {
	const char *name;
	struct module___373 *owner;
	const struct attribute_group___412 **class_groups;
	const struct attribute_group___412 **dev_groups;
	struct kobject___435 *dev_kobj;
	int (*dev_uevent)(struct device___415 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___415 *, umode_t *);
	void (*class_release)(struct class___415 *);
	void (*dev_release)(struct device___415 *);
	int (*shutdown_pre)(struct device___415 *);
	const struct kobj_ns_type_operations___72 *ns_type;
	const void * (*namespace)(struct device___415 *);
	const struct dev_pm_ops___415 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___187 {
	void * (*alloc)(struct device___415 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___415 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___415 *, struct vm_area_struct___448 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___415 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___415 *, struct page___448 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___415 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___415 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___415 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___415 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___415 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___415 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___415 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___415 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___415 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___415 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___415 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___415 *, u64);
	u64 (*get_required_mask)(struct device___415 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___335;

struct fwnode_handle___335 {
	struct fwnode_handle___335 *secondary;
	const struct fwnode_operations___335 *ops;
};

typedef void compound_page_dtor___435(struct page___448 *);

struct fwnode_reference_args___335;

struct fwnode_endpoint___335;

struct fwnode_operations___335 {
	struct fwnode_handle___335 * (*get)(struct fwnode_handle___335 *);
	void (*put)(struct fwnode_handle___335 *);
	bool (*device_is_available)(const struct fwnode_handle___335 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___335 *, const struct device___415 *);
	bool (*property_present)(const struct fwnode_handle___335 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___335 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___335 *, const char *, const char **, size_t);
	struct fwnode_handle___335 * (*get_parent)(const struct fwnode_handle___335 *);
	struct fwnode_handle___335 * (*get_next_child_node)(const struct fwnode_handle___335 *, struct fwnode_handle___335 *);
	struct fwnode_handle___335 * (*get_named_child_node)(const struct fwnode_handle___335 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___335 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___335 *);
	struct fwnode_handle___335 * (*graph_get_next_endpoint)(const struct fwnode_handle___335 *, struct fwnode_handle___335 *);
	struct fwnode_handle___335 * (*graph_get_remote_endpoint)(const struct fwnode_handle___335 *);
	struct fwnode_handle___335 * (*graph_get_port_parent)(struct fwnode_handle___335 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___335 *, struct fwnode_endpoint___335 *);
};

struct fwnode_endpoint___335 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___335 *local_fwnode;
};

struct fwnode_reference_args___335 {
	struct fwnode_handle___335 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___128;

struct pipe_buffer___128 {
	struct page___448 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___128 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___128 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___128 *, struct pipe_buffer___128 *);
	void (*release)(struct pipe_inode_info___128 *, struct pipe_buffer___128 *);
	int (*steal)(struct pipe_inode_info___128 *, struct pipe_buffer___128 *);
	union {
		bool (*get)(struct pipe_inode_info___128 *, struct pipe_buffer___128 *);
		struct {
			void (*get)(struct pipe_inode_info___128 *, struct pipe_buffer___128 *);
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
};

struct nf_bridge_info___92 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___92 = 0,
		BRNF_PROTO_8021Q___92 = 1,
		BRNF_PROTO_PPPOE___92 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___92 *physindev;
	struct net_device___92 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___92(struct sk_buff___93 **);

struct net_device_ops___92;

struct ethtool_ops___92;

struct l3mdev_ops___72;

struct ndisc_ops___43;

struct xfrmdev_ops___92;

struct tlsdev_ops___92;

struct header_ops___92;

struct inet6_dev___43;

struct netdev_rx_queue___92;

struct mini_Qdisc___84;

struct netdev_queue___92;

struct Qdisc___84;

struct rtnl_link_ops___84;

struct dcbnl_rtnl_ops___92;

struct net_device___92 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___92 *netdev_ops;
	const struct ethtool_ops___92 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___72 *l3mdev_ops;
	const struct ndisc_ops___43 *ndisc_ops;
	const struct xfrmdev_ops___92 *xfrmdev_ops;
	const struct tlsdev_ops___92 *tlsdev_ops;
	const struct header_ops___92 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___434 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___43 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___92 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___82 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___92 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___84 *miniq_ingress;
	struct netdev_queue___92 *ingress_queue;
	struct nf_hook_entries___12 *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___92 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___84 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___84 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___92 = 0,
		NETREG_REGISTERED___92 = 1,
		NETREG_UNREGISTERING___92 = 2,
		NETREG_UNREGISTERED___92 = 3,
		NETREG_RELEASED___92 = 4,
		NETREG_DUMMY___92 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___92 = 0,
		RTNL_LINK_INITIALIZING___92 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___92 *);
	struct netpoll_info *npinfo;
	possible_net_t___94 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___415 dev;
	const struct attribute_group___412 *sysfs_groups[4];
	const struct attribute_group___412 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___84 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___92 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct skb_frag_struct___22 {
	struct {
		struct page___448 *p;
	} page;
	__u32 page_offset;
	__u32 size;
};

typedef struct skb_frag_struct___22 skb_frag_t___22;

struct skb_shared_info___22 {
	__u8 __unused;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___93 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___22 frags[16];
};

struct xfrm_state___14;

struct sec_path___14 {
	refcount_t refcnt;
	int len;
	int olen;
	struct xfrm_state___14 *xvec[6];
	struct xfrm_offload ovec[1];
};

struct ethtool_ops___92 {
	int (*get_settings)(struct net_device___92 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___92 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___92 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___92 *);
	void (*get_regs)(struct net_device___92 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___92 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___92 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___92 *);
	void (*set_msglevel)(struct net_device___92 *, u32);
	int (*nway_reset)(struct net_device___92 *);
	u32 (*get_link)(struct net_device___92 *);
	int (*get_eeprom_len)(struct net_device___92 *);
	int (*get_eeprom)(struct net_device___92 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___92 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___92 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___92 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___92 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___92 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___92 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___92 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___92 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___92 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___92 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___92 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___92 *);
	void (*complete)(struct net_device___92 *);
	u32 (*get_priv_flags)(struct net_device___92 *);
	int (*set_priv_flags)(struct net_device___92 *, u32);
	int (*get_sset_count)(struct net_device___92 *, int);
	int (*get_rxnfc)(struct net_device___92 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___92 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___92 *, struct ethtool_flash *);
	int (*reset)(struct net_device___92 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___92 *);
	u32 (*get_rxfh_indir_size)(struct net_device___92 *);
	int (*get_rxfh)(struct net_device___92 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___92 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___92 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___92 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___92 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___92 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___92 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___92 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___92 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___92 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___92 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___92 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___92 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___92 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___92 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___92 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___92 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___92 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___92 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___92 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___92 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___92 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	int (*get_fecparam)(struct net_device___92 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___92 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___92 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___92 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___92 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___92;

struct inet_frags___92 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___92 *, const void *);
	void (*destructor)(struct inet_frag_queue___92 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___92 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___93 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___93 *fragments_tail;
	struct sk_buff___93 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___92 *net;
	struct callback_head rcu;
};

struct ip_ra_chain___38 {
	struct ip_ra_chain___38 *next;
	struct sock___72 *sk;
	union {
		void (*destructor)(struct sock___72 *);
		struct sock___72 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___72;

struct fib_lookup_arg___72;

struct fib_rules_ops___72 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___72 *, struct flowi *, int, struct fib_lookup_arg___72 *);
	bool (*suppress)(struct fib_rule___72 *, struct fib_lookup_arg___72 *);
	int (*match)(struct fib_rule___72 *, struct flowi *, int);
	int (*configure)(struct fib_rule___72 *, struct sk_buff___93 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___72 *);
	int (*compare)(struct fib_rule___72 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___72 *, struct sk_buff___93 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___72 *);
	void (*flush_cache)(struct fib_rules_ops___72 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___373 *owner;
	struct net___103 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___73 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___103 *);
	int (*fib_dump)(struct net___103 *, struct notifier_block *);
	struct module___373 *owner;
	struct callback_head rcu;
};

struct dst_entry___72 {
	struct net_device___92 *dev;
	struct dst_ops___103 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state___14 *xfrm;
	int (*input)(struct sk_buff___93 *);
	int (*output)(struct net___103 *, struct sock___72 *, struct sk_buff___93 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___72;

struct neigh_parms___72;

struct neigh_ops___72;

struct neighbour___72 {
	struct neighbour___72 *next;
	struct neigh_table___72 *tbl;
	struct neigh_parms___72 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___92 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___72 *, struct sk_buff___93 *);
	const struct neigh_ops___72 *ops;
	struct callback_head rcu;
	struct net_device___92 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct fib6_nh___18 {
	struct in6_addr nh_gw;
	struct net_device___92 *nh_dev;
	struct lwtunnel_state *nh_lwtstate;
	unsigned int nh_flags;
	atomic_t nh_upper_bound;
	int nh_weight;
};

struct fib6_node___18;

struct fib6_info___18 {
	struct fib6_table___18 *fib6_table;
	struct fib6_info___18 *fib6_next;
	struct fib6_node___18 *fib6_node;
	struct list_head fib6_siblings;
	unsigned int fib6_nsiblings;
	atomic_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	struct rt6_info___18 **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
	long unsigned int last_probe;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 exception_bucket_flushed: 1;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 dst_host: 1;
	u8 fib6_destroying: 1;
	u8 unused: 2;
	struct fib6_nh___18 fib6_nh;
	struct callback_head rcu;
};

struct rt6_info___18 {
	struct dst_entry___72 dst;
	struct fib6_info___18 *from;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___43 *rt6i_idev;
	u32 rt6i_flags;
	struct rt6key rt6i_prefsrc;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct fib6_node___18 {
	struct fib6_node___18 *parent;
	struct fib6_node___18 *left;
	struct fib6_node___18 *right;
	struct fib6_info___18 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info___18 *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table___18 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node___18 tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

struct nf_hook_state___12;

typedef unsigned int nf_hookfn___12(void *, struct sk_buff___93 *, const struct nf_hook_state___12 *);

struct nf_hook_entry___12 {
	nf_hookfn___12 *hook;
	void *priv;
};

struct nf_hook_entries___12 {
	u16 num_hook_entries;
	struct nf_hook_entry___12 hooks[0];
};

struct ucounts___312 {
	struct hlist_node node;
	struct user_namespace___312 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_prog_aux___85;

struct bpf_prog___82 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___85 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

typedef int (*key_restrict_link_func_t___416)(struct key___415 *, const struct key_type *, const union key_payload *, struct key___415 *);

struct key_restriction___415;

struct key___415 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___449 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___415 *restrict_link;
};

struct key_restriction___415 {
	key_restrict_link_func_t___416 check;
	struct key___415 *key;
	struct key_type *keytype;
};

struct seq_operations___386 {
	void * (*start)(struct seq_file___386 *, loff_t *);
	void (*stop)(struct seq_file___386 *, void *);
	void * (*next)(struct seq_file___386 *, void *, loff_t *);
	int (*show)(struct seq_file___386 *, void *);
};

struct seq_net_private___8 {
	struct net___103 *net;
};

struct pernet_operations___93 {
	struct list_head list;
	int (*init)(struct net___103 *);
	void (*exit)(struct net___103 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___92 {
	int (*ieee_getets)(struct net_device___92 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___92 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___92 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___92 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___92 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___92 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___92 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___92 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___92 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___92 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___92 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___92 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___92 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___92 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___92 *);
	u8 (*setstate)(struct net_device___92 *, u8);
	void (*getpermhwaddr)(struct net_device___92 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___92 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___92 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___92 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___92 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___92 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___92 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___92 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___92 *, int, u8 *);
	void (*setpfccfg)(struct net_device___92 *, int, u8);
	void (*getpfccfg)(struct net_device___92 *, int, u8 *);
	u8 (*setall)(struct net_device___92 *);
	u8 (*getcap)(struct net_device___92 *, int, u8 *);
	int (*getnumtcs)(struct net_device___92 *, int, u8 *);
	int (*setnumtcs)(struct net_device___92 *, int, u8);
	u8 (*getpfcstate)(struct net_device___92 *);
	void (*setpfcstate)(struct net_device___92 *, u8);
	void (*getbcncfg)(struct net_device___92 *, int, u32 *);
	void (*setbcncfg)(struct net_device___92 *, int, u32);
	void (*getbcnrp)(struct net_device___92 *, int, u8 *);
	void (*setbcnrp)(struct net_device___92 *, int, u8);
	int (*setapp)(struct net_device___92 *, u8, u16, u8);
	int (*getapp)(struct net_device___92 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___92 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___92 *, int, u8);
	u8 (*getdcbx)(struct net_device___92 *);
	u8 (*setdcbx)(struct net_device___92 *, u8);
	int (*peer_getappinfo)(struct net_device___92 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___92 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___92 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___92 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___92 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___92 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___296 {
	refcount_t count;
	struct ns_common___29 ns;
	struct user_namespace___312 *user_ns;
	struct ucounts___312 *ucounts;
	struct css_set___296 *root_cset;
};

struct bpf_map___297;

struct bpf_map_ops___296 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___297 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___297 *, struct file___447 *);
	void (*map_free)(struct bpf_map___297 *);
	int (*map_get_next_key)(struct bpf_map___297 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___297 *);
	void * (*map_lookup_elem)(struct bpf_map___297 *, void *);
	int (*map_update_elem)(struct bpf_map___297 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___297 *, void *);
	int (*map_push_elem)(struct bpf_map___297 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___297 *, void *);
	int (*map_peek_elem)(struct bpf_map___297 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___297 *, struct file___447 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___297 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___297 *, void *, struct seq_file___386 *);
	int (*map_check_btf)(const struct bpf_map___297 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___297 {
	const struct bpf_map_ops___296 *ops;
	struct bpf_map___297 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___415 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___92;

struct bpf_map_dev_ops___92 {
	int (*map_get_next_key)(struct bpf_offloaded_map___92 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___92 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___92 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___92 *, void *);
};

struct bpf_offloaded_map___92 {
	struct bpf_map___297 map;
	struct net_device___92 *netdev;
	const struct bpf_map_dev_ops___92 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___82 {
	int (*test_run)(struct bpf_prog___82 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___82 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___82 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___82 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___82 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___82 *, u32 *);
};

struct bpf_prog_offload_ops___82 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___82 *);
	int (*translate)(struct bpf_prog___82 *);
	void (*destroy)(struct bpf_prog___82 *);
};

struct bpf_prog_offload___82 {
	struct bpf_prog___82 *prog;
	struct net_device___92 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___82 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___85 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___82 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___82 *ops;
	struct bpf_map___297 **used_maps;
	struct bpf_prog___82 *prog;
	struct user_struct___415 *user;
	u64 load_time;
	struct bpf_map___297 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___82 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___82 {
	struct bpf_prog___82 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___82 {
	struct callback_head rcu;
	struct bpf_prog_array_item___82 items[0];
};

struct cgroup_bpf___82 {
	struct bpf_prog_array___82 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___82 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___297;

typedef void (*kthread_work_func_t___297)(struct kthread_work___297 *);

struct kthread_worker___297;

struct kthread_work___297 {
	struct list_head node;
	kthread_work_func_t___297 func;
	struct kthread_worker___297 *worker;
	int canceling;
};

struct kthread_worker___297 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___449 *task;
	struct kthread_work___297 *current_work;
};

struct kthread_delayed_work___296 {
	struct kthread_work___297 work;
	struct timer_list timer;
};

struct psi_group___296 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___297 *poll_kworker;
	struct kthread_delayed_work___296 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___296;

struct cgroup_rstat_cpu___296;

struct cgroup___296 {
	struct cgroup_subsys_state___296 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___442 *kn;
	struct cgroup_file___296 procs_file;
	struct cgroup_file___296 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___296 *subsys[13];
	struct cgroup_root___296 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___296 *dom_cgrp;
	struct cgroup_rstat_cpu___296 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___82 bpf;
	atomic_t congestion_count;
	struct cgroup___296 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___296 psi;
	int ancestor_ids[0];
};

struct cftype___296;

struct cgroup_subsys___296 {
	struct cgroup_subsys_state___296 * (*css_alloc)(struct cgroup_subsys_state___296 *);
	int (*css_online)(struct cgroup_subsys_state___296 *);
	void (*css_offline)(struct cgroup_subsys_state___296 *);
	void (*css_released)(struct cgroup_subsys_state___296 *);
	void (*css_free)(struct cgroup_subsys_state___296 *);
	void (*css_reset)(struct cgroup_subsys_state___296 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___296 *, int);
	int (*css_extra_stat_show)(struct seq_file___386 *, struct cgroup_subsys_state___296 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___449 *);
	void (*cancel_fork)(struct task_struct___449 *);
	void (*fork)(struct task_struct___449 *);
	void (*exit)(struct task_struct___449 *);
	void (*free)(struct task_struct___449 *);
	void (*bind)(struct cgroup_subsys_state___296 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___296 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___296 *dfl_cftypes;
	struct cftype___296 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___296 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___296 *updated_children;
	struct cgroup___296 *updated_next;
};

struct cgroup_root___296 {
	struct kernfs_root___441 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___296 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___296 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___296 *ss;
	struct list_head node;
	struct kernfs_ops___441 *kf_ops;
	int (*open)(struct kernfs_open_file___441 *);
	void (*release)(struct kernfs_open_file___441 *);
	u64 (*read_u64)(struct cgroup_subsys_state___296 *, struct cftype___296 *);
	s64 (*read_s64)(struct cgroup_subsys_state___296 *, struct cftype___296 *);
	int (*seq_show)(struct seq_file___386 *, void *);
	void * (*seq_start)(struct seq_file___386 *, loff_t *);
	void * (*seq_next)(struct seq_file___386 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___386 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___296 *, struct cftype___296 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___296 *, struct cftype___296 *, s64);
	ssize_t (*write)(struct kernfs_open_file___441 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___441 *, struct poll_table_struct___286 *);
};

struct xdp_rxq_info___92 {
	struct net_device___92 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___92 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___92 *dev_rx;
};

struct netlink_callback___94 {
	struct sk_buff___93 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___94 *);
	int (*dump)(struct sk_buff___93 *, struct netlink_callback___94 *);
	int (*done)(struct netlink_callback___94 *);
	void *data;
	struct module___373 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___92 {
	int (*create)(struct sk_buff___93 *, struct net_device___92 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___93 *, unsigned char *);
	int (*cache)(const struct neighbour___72 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___92 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___92 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___92 *, int);
	int poll_owner;
	struct net_device___92 *dev;
	struct sk_buff___93 *gro_list;
	struct sk_buff___93 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___92 {
	struct net_device___92 *dev;
	struct Qdisc___84 *qdisc;
	struct Qdisc___84 *qdisc_sleeping;
	struct kobject___435 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___92 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___84 {
	struct sk_buff___93 *head;
	struct sk_buff___93 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___84;

struct Qdisc___84 {
	int (*enqueue)(struct sk_buff___93 *, struct Qdisc___84 *, struct sk_buff___93 **);
	struct sk_buff___93 * (*dequeue)(struct Qdisc___84 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___84 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___92 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___92 gso_skb;
	struct qdisc_skb_head___84 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___84 *next_sched;
	struct sk_buff_head___92 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___92 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___435 kobj;
	struct net_device___92 *dev;
	long: 64;
	struct xdp_rxq_info___92 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___92)(struct net_device___92 *, struct sk_buff___93 *, struct net_device___92 *);

struct netdev_bpf___92 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___82 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___82 *prog;
			const struct bpf_prog_offload_ops___82 *ops;
		} verifier;
		struct {
			struct bpf_prog___82 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___92 *offmap;
		};
		struct {
			struct xdp_umem___3 *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___92 {
	int (*xdo_dev_state_add)(struct xfrm_state___14 *);
	void (*xdo_dev_state_delete)(struct xfrm_state___14 *);
	void (*xdo_dev_state_free)(struct xfrm_state___14 *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___93 *, struct xfrm_state___14 *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state___14 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct xfrm_state_offload___14 {
	struct net_device___92 *dev;
	long unsigned int offload_handle;
	unsigned int num_exthdrs;
	u8 flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct xfrm_replay___14;

struct xfrm_type___14;

struct xfrm_mode___14;

struct xfrm_type_offload___14;

struct xfrm_state___14 {
	possible_net_t___94 xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	refcount_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
		u32 output_mark;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	const char *geniv;
	struct xfrm_encap_tmpl *encap;
	xfrm_address_t *coaddr;
	struct xfrm_state___14 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	const struct xfrm_replay___14 *repl;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct tasklet_hrtimer mtimer;
	struct xfrm_state_offload___14 xso;
	long int saved_tmo;
	long unsigned int lastused;
	struct page_frag___448 xfrag;
	const struct xfrm_type___14 *type;
	struct xfrm_mode___14 *inner_mode;
	struct xfrm_mode___14 *inner_mode_iaf;
	struct xfrm_mode___14 *outer_mode;
	const struct xfrm_type_offload___14 *type_offload;
	struct xfrm_sec_ctx___2 *security;
	void *data;
	u32 output_mark_mask;
	u32 if_id;
};

struct tlsdev_ops___92 {
	int (*tls_dev_add)(struct net_device___92 *, struct sock___72 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___92 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___92 *, struct sock___72 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___92 {
	int (*ndo_init)(struct net_device___92 *);
	void (*ndo_uninit)(struct net_device___92 *);
	int (*ndo_open)(struct net_device___92 *);
	int (*ndo_stop)(struct net_device___92 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___93 *, struct net_device___92 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___93 *, struct net_device___92 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___92 *, struct sk_buff___93 *, struct net_device___92 *, select_queue_fallback_t___92);
	void (*ndo_change_rx_flags)(struct net_device___92 *, int);
	void (*ndo_set_rx_mode)(struct net_device___92 *);
	int (*ndo_set_mac_address)(struct net_device___92 *, void *);
	int (*ndo_validate_addr)(struct net_device___92 *);
	int (*ndo_do_ioctl)(struct net_device___92 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___92 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___92 *, int);
	int (*ndo_neigh_setup)(struct net_device___92 *, struct neigh_parms___72 *);
	void (*ndo_tx_timeout)(struct net_device___92 *);
	void (*ndo_get_stats64)(struct net_device___92 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___92 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___92 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___92 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___92 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___92 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___92 *);
	int (*ndo_netpoll_setup)(struct net_device___92 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___92 *);
	int (*ndo_set_vf_mac)(struct net_device___92 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___92 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___92 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___92 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___92 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___92 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___92 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___92 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___92 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___92 *, int, struct sk_buff___93 *);
	int (*ndo_set_vf_guid)(struct net_device___92 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___92 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___92 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___92 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___92 *, const struct sk_buff___93 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___92 *, struct net_device___92 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___92 *, struct net_device___92 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___92 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___92 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___92 *, struct neighbour___72 *);
	void (*ndo_neigh_destroy)(struct net_device___92 *, struct neighbour___72 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___92 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___92 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___92 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___93 *, struct netlink_callback___94 *, struct net_device___92 *, struct net_device___92 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___92 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___92 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___93 *, u32, u32, struct net_device___92 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___92 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___92 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___92 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___92 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___92 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___92 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___92 *, struct net_device___92 *);
	void (*ndo_dfwd_del_station)(struct net_device___92 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___92 *);
	int (*ndo_set_tx_maxrate)(struct net_device___92 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___92 *);
	int (*ndo_change_proto_down)(struct net_device___92 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___92 *, struct sk_buff___93 *);
	void (*ndo_set_rx_headroom)(struct net_device___92 *, int);
	int (*ndo_bpf)(struct net_device___92 *, struct netdev_bpf___92 *);
	int (*ndo_xdp_xmit)(struct net_device___92 *, int, struct xdp_frame___92 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___92 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___92 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___72 {
	possible_net_t___94 net;
	struct net_device___92 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___72 *);
	void (*neigh_cleanup)(struct neighbour___72 *);
	struct neigh_table___72 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___72 {
	u32 (*l3mdev_fib_table)(const struct net_device___92 *);
	struct sk_buff___93 * (*l3mdev_l3_rcv)(struct net_device___92 *, struct sk_buff___93 *, u16);
	struct sk_buff___93 * (*l3mdev_l3_out)(struct net_device___92 *, struct sock___72 *, struct sk_buff___93 *, u16);
	struct dst_entry___72 * (*l3mdev_link_scope_lookup)(const struct net_device___92 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct ndisc_ops___43 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___92 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___92 *, struct neighbour___72 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___92 *, u8, struct neighbour___72 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___92 *, struct sk_buff___93 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___103 *, struct net_device___92 *, const struct prefix_info *, struct inet6_dev___43 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___43;

struct ifacaddr6___18;

struct inet6_dev___43 {
	struct net_device___92 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___43 *mc_list;
	struct ifmcaddr6___43 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___18 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	u8 rndid[8];
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___72 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
};

struct tcf_proto___84;

struct mini_Qdisc___84 {
	struct tcf_proto___84 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___84 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___92 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___103 *, struct net_device___92 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___92 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___92 *, struct list_head *);
	size_t (*get_size)(const struct net_device___92 *);
	int (*fill_info)(struct sk_buff___93 *, const struct net_device___92 *);
	size_t (*get_xstats_size)(const struct net_device___92 *);
	int (*fill_xstats)(struct sk_buff___93 *, const struct net_device___92 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___92 *, struct net_device___92 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___92 *, const struct net_device___92 *);
	int (*fill_slave_info)(struct sk_buff___93 *, const struct net_device___92 *, const struct net_device___92 *);
	struct net___103 * (*get_link_net)(const struct net_device___92 *);
	size_t (*get_linkxstats_size)(const struct net_device___92 *, int);
	int (*fill_linkxstats)(struct sk_buff___93 *, const struct net_device___92 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct offload_callbacks___11 {
	struct sk_buff___93 * (*gso_segment)(struct sk_buff___93 *, netdev_features_t);
	struct sk_buff___93 ** (*gro_receive)(struct sk_buff___93 **, struct sk_buff___93 *);
	int (*gro_complete)(struct sk_buff___93 *, int);
};

struct softnet_data___92 {
	struct list_head poll_list;
	struct sk_buff_head___92 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___92 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___84 *output_queue;
	struct Qdisc___84 **output_queue_tailp;
	struct sk_buff___93 *completion_queue;
	struct sk_buff_head___92 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___92 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___92 input_pkt_queue;
	struct napi_struct___92 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_rule___72 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___72 *ctarget;
	struct net___103 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___72 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___72 *rule;
	u32 table;
	int flags;
};

struct bdi_writeback_congested___237 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___237 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___237 {
	struct bio___237 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___239 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___239 bip_inline_vecs[0];
};

struct bio_set___237 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___237 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___180 {
	struct mem_cgroup___180 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___180 {
	struct lruvec___448 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___180 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___180 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct kernel_param_ops___373 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___373 *);
	int (*get)(char *, const struct kernel_param___373 *);
	void (*free)(void *);
};

struct kparam_array___373;

struct kernel_param___373 {
	const char *name;
	struct module___373 *mod;
	const struct kernel_param_ops___373 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___373 *arr;
	};
};

struct kparam_array___373 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___373 *ops;
	void *elem;
};

struct module_attribute___373 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___373 *, struct module_kobject___373 *, char *);
	ssize_t (*store)(struct module_attribute___373 *, struct module_kobject___373 *, const char *, size_t);
	void (*setup)(struct module___373 *, const char *);
	int (*test)(struct module___373 *);
	void (*free)(struct module___373 *);
};

struct gnet_dump___84 {
	spinlock_t *lock;
	struct sk_buff___93 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___84;

struct Qdisc_ops___84 {
	struct Qdisc_ops___84 *next;
	const struct Qdisc_class_ops___84 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___93 *, struct Qdisc___84 *, struct sk_buff___93 **);
	struct sk_buff___93 * (*dequeue)(struct Qdisc___84 *);
	struct sk_buff___93 * (*peek)(struct Qdisc___84 *);
	int (*init)(struct Qdisc___84 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___84 *);
	void (*destroy)(struct Qdisc___84 *);
	int (*change)(struct Qdisc___84 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___84 *);
	int (*change_tx_queue_len)(struct Qdisc___84 *, unsigned int);
	int (*dump)(struct Qdisc___84 *, struct sk_buff___93 *);
	int (*dump_stats)(struct Qdisc___84 *, struct gnet_dump___84 *);
	void (*ingress_block_set)(struct Qdisc___84 *, u32);
	void (*egress_block_set)(struct Qdisc___84 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___84 *);
	u32 (*egress_block_get)(struct Qdisc___84 *);
	struct module___373 *owner;
};

struct tcf_block___84;

struct Qdisc_class_ops___84 {
	unsigned int flags;
	struct netdev_queue___92 * (*select_queue)(struct Qdisc___84 *, struct tcmsg *);
	int (*graft)(struct Qdisc___84 *, long unsigned int, struct Qdisc___84 *, struct Qdisc___84 **, struct netlink_ext_ack *);
	struct Qdisc___84 * (*leaf)(struct Qdisc___84 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___84 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___84 *, u32);
	int (*change)(struct Qdisc___84 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___84 *, long unsigned int);
	void (*walk)(struct Qdisc___84 *, struct qdisc_walker *);
	struct tcf_block___84 * (*tcf_block)(struct Qdisc___84 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___84 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___84 *, long unsigned int);
	int (*dump)(struct Qdisc___84 *, long unsigned int, struct sk_buff___93 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___84 *, long unsigned int, struct gnet_dump___84 *);
};

struct tcf_chain___84;

struct tcf_block___84 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___103 *net;
	struct Qdisc___84 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___84 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___84;

struct tcf_proto_ops___84;

struct tcf_proto___84 {
	struct tcf_proto___84 *next;
	void *root;
	int (*classify)(struct sk_buff___93 *, const struct tcf_proto___84 *, struct tcf_result___84 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___84 *ops;
	struct tcf_chain___84 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___84 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___84 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___84 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___93 *, const struct tcf_proto___84 *, struct tcf_result___84 *);
	int (*init)(struct tcf_proto___84 *);
	void (*destroy)(struct tcf_proto___84 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___84 *, u32);
	void (*put)(struct tcf_proto___84 *, void *);
	int (*change)(struct net___103 *, struct sk_buff___93 *, struct tcf_proto___84 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___84 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___84 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___84 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___103 *, struct tcf_chain___84 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___103 *, struct tcf_proto___84 *, void *, struct sk_buff___93 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___93 *, struct net___103 *, void *);
	struct module___373 *owner;
	int flags;
};

struct tcf_chain___84 {
	struct mutex filter_chain_lock;
	struct tcf_proto___84 *filter_chain;
	struct list_head list;
	struct tcf_block___84 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___84 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___72 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___82 *prog;
};

struct bpf_redirect_info___82 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___297 *map;
	struct bpf_map___297 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___72;

struct neigh_hash_table___72;

struct neigh_table___72 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___92 *, __u32 *);
	bool (*key_eq)(const struct neighbour___72 *, const void *);
	int (*constructor)(struct neighbour___72 *);
	int (*pconstructor)(struct pneigh_entry___72 *);
	void (*pdestructor)(struct pneigh_entry___72 *);
	void (*proxy_redo)(struct sk_buff___93 *);
	char *id;
	struct neigh_parms___72 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___92 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___72 *nht;
	struct pneigh_entry___72 **phash_buckets;
};

struct neigh_ops___72 {
	int family;
	void (*solicit)(struct neighbour___72 *, struct sk_buff___93 *);
	void (*error_report)(struct neighbour___72 *, struct sk_buff___93 *);
	int (*output)(struct neighbour___72 *, struct sk_buff___93 *);
	int (*connected_output)(struct neighbour___72 *, struct sk_buff___93 *);
};

struct pneigh_entry___72 {
	struct pneigh_entry___72 *next;
	possible_net_t___94 net;
	struct net_device___92 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___72 {
	struct neighbour___72 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct request_sock_ops___55;

struct timewait_sock_ops___51;

struct proto___72 {
	void (*close)(struct sock___72 *, long int);
	int (*pre_connect)(struct sock___72 *, struct sockaddr *, int);
	int (*connect)(struct sock___72 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___72 *, int);
	struct sock___72 * (*accept)(struct sock___72 *, int, int *, bool);
	int (*ioctl)(struct sock___72 *, int, long unsigned int);
	int (*init)(struct sock___72 *);
	void (*destroy)(struct sock___72 *);
	void (*shutdown)(struct sock___72 *, int);
	int (*setsockopt)(struct sock___72 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___72 *, int, int, char *, int *);
	void (*keepalive)(struct sock___72 *, int);
	int (*sendmsg)(struct sock___72 *, struct msghdr___75 *, size_t);
	int (*recvmsg)(struct sock___72 *, struct msghdr___75 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___72 *, struct page___448 *, int, size_t, int);
	int (*bind)(struct sock___72 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___72 *, struct sk_buff___93 *);
	void (*release_cb)(struct sock___72 *);
	int (*hash)(struct sock___72 *);
	void (*unhash)(struct sock___72 *);
	void (*rehash)(struct sock___72 *);
	int (*get_port)(struct sock___72 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___72 *);
	bool (*stream_memory_read)(const struct sock___72 *);
	void (*enter_memory_pressure)(struct sock___72 *);
	void (*leave_memory_pressure)(struct sock___72 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___55 *rsk_prot;
	struct timewait_sock_ops___51 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___373 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___72 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct xfrm_policy_queue___14 {
	struct sk_buff_head___92 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___14 {
	possible_net_t___94 xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	refcount_t refcnt;
	struct timer_list timer;
	atomic_t genid;
	u32 priority;
	u32 index;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___14 polq;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx___2 *security;
	struct xfrm_tmpl xfrm_vec[6];
	struct callback_head rcu;
	u32 if_id;
};

struct request_sock___56;

struct request_sock_ops___55 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___72 *, struct request_sock___56 *);
	void (*send_ack)(const struct sock___72 *, struct sk_buff___93 *, struct request_sock___56 *);
	void (*send_reset)(const struct sock___72 *, struct sk_buff___93 *);
	void (*destructor)(struct request_sock___56 *);
	void (*syn_ack_timeout)(const struct request_sock___56 *);
};

struct timewait_sock_ops___51 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___72 *, struct sock___72 *, void *);
	void (*twsk_destructor)(struct sock___72 *);
};

struct request_sock___56 {
	struct sock_common___72 __req_common;
	struct request_sock___56 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___55 *rsk_ops;
	struct sock___72 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct inet_cork___15 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___72 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
	__u16 gso_size;
	u64 transmit_time;
};

struct inet_cork_full___15 {
	struct inet_cork___15 base;
	struct flowi fl;
};

struct ipv6_pinfo___15;

struct inet_sock___15 {
	struct sock___72 sk;
	struct ipv6_pinfo___15 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	__be16 inet_sport;
	__u16 inet_id;
	struct ip_options_rcu *inet_opt;
	int rx_dst_ifindex;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 bind_address_no_port: 1;
	__u8 defer_connect: 1;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___15 cork;
};

struct ipv6_fl_socklist___14;

struct ipv6_pinfo___15 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
			__u16 recvfragsize: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 repflow: 1;
	__u16 pmtudisc: 3;
	__u16 padding: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u16 autoflowlabel: 1;
	__u16 autoflowlabel_set: 1;
	__u8 min_hopcount;
	__u8 tclass;
	__be32 rcv_flowinfo;
	__u32 dst_cookie;
	__u32 rx_dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___14 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___93 *pktoptions;
	struct sk_buff___93 *rxpmtu;
	struct inet6_cork cork;
};

struct ip6_flowlabel___14;

struct ipv6_fl_socklist___14 {
	struct ipv6_fl_socklist___14 *next;
	struct ip6_flowlabel___14 *fl;
	struct callback_head rcu;
};

struct ifmcaddr6___43 {
	struct in6_addr mca_addr;
	struct inet6_dev___43 *idev;
	struct ifmcaddr6___43 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___18 {
	struct in6_addr aca_addr;
	struct fib6_info___18 *aca_rt;
	struct ifacaddr6___18 *aca_next;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct ip6_ra_chain___43 {
	struct ip6_ra_chain___43 *next;
	struct sock___72 *sk;
	int sel;
	void (*destructor)(struct sock___72 *);
};

struct ip6_flowlabel___14 {
	struct ip6_flowlabel___14 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___249 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___103 *fl_net;
};

struct rtable___10 {
	struct dst_entry___72 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	__be32 rt_gateway;
	u32 rt_mtu_locked: 1;
	u32 rt_pmtu: 31;
	struct list_head rt_uncached;
	struct uncached_list *rt_uncached_list;
};

struct icmp_filter {
	__u32 data;
};

struct net_protocol___9 {
	int (*early_demux)(struct sk_buff___93 *);
	int (*early_demux_handler)(struct sk_buff___93 *);
	int (*handler)(struct sk_buff___93 *);
	void (*err_handler)(struct sk_buff___93 *, u32);
	unsigned int no_policy: 1;
	unsigned int netns_ok: 1;
	unsigned int icmp_strict_tag_validation: 1;
};

struct inet6_protocol___9 {
	void (*early_demux)(struct sk_buff___93 *);
	void (*early_demux_handler)(struct sk_buff___93 *);
	int (*handler)(struct sk_buff___93 *);
	void (*err_handler)(struct sk_buff___93 *, struct inet6_skb_parm *, u8, u8, int, __be32);
	unsigned int flags;
};

struct net_offload___9 {
	struct offload_callbacks___11 callbacks;
	unsigned int flags;
};

struct raw_iter_state {
	struct seq_net_private___8 p;
	int bucket;
};

struct raw_sock {
	struct inet_sock___15 inet;
	struct icmp_filter filter;
	u32 ipmr_table;
};

struct xfrm_replay___14 {
	void (*advance)(struct xfrm_state___14 *, __be32);
	int (*check)(struct xfrm_state___14 *, struct sk_buff___93 *, __be32);
	int (*recheck)(struct xfrm_state___14 *, struct sk_buff___93 *, __be32);
	void (*notify)(struct xfrm_state___14 *, int);
	int (*overflow)(struct xfrm_state___14 *, struct sk_buff___93 *);
};

struct xfrm_type___14 {
	char *description;
	struct module___373 *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___14 *);
	void (*destructor)(struct xfrm_state___14 *);
	int (*input)(struct xfrm_state___14 *, struct sk_buff___93 *);
	int (*output)(struct xfrm_state___14 *, struct sk_buff___93 *);
	int (*reject)(struct xfrm_state___14 *, struct sk_buff___93 *, const struct flowi *);
	int (*hdr_offset)(struct xfrm_state___14 *, struct sk_buff___93 *, u8 **);
	u32 (*get_mtu)(struct xfrm_state___14 *, int);
};

struct xfrm_state_afinfo___14;

struct xfrm_mode___14 {
	int (*input2)(struct xfrm_state___14 *, struct sk_buff___93 *);
	int (*input)(struct xfrm_state___14 *, struct sk_buff___93 *);
	int (*output2)(struct xfrm_state___14 *, struct sk_buff___93 *);
	int (*output)(struct xfrm_state___14 *, struct sk_buff___93 *);
	struct sk_buff___93 * (*gso_segment)(struct xfrm_state___14 *, struct sk_buff___93 *, netdev_features_t);
	void (*xmit)(struct xfrm_state___14 *, struct sk_buff___93 *);
	struct xfrm_state_afinfo___14 *afinfo;
	struct module___373 *owner;
	unsigned int encap;
	int flags;
};

struct xfrm_type_offload___14 {
	char *description;
	struct module___373 *owner;
	u8 proto;
	void (*encap)(struct xfrm_state___14 *, struct sk_buff___93 *);
	int (*input_tail)(struct xfrm_state___14 *, struct sk_buff___93 *);
	int (*xmit)(struct xfrm_state___14 *, struct sk_buff___93 *, netdev_features_t);
};

struct xfrm_state_afinfo___14 {
	unsigned int family;
	unsigned int proto;
	__be16 eth_proto;
	struct module___373 *owner;
	const struct xfrm_type___14 *type_map[256];
	const struct xfrm_type_offload___14 *type_offload_map[256];
	struct xfrm_mode___14 *mode_map[5];
	int (*init_flags)(struct xfrm_state___14 *);
	void (*init_tempsel)(struct xfrm_selector *, const struct flowi *);
	void (*init_temprop)(struct xfrm_state___14 *, const struct xfrm_tmpl *, const xfrm_address_t *, const xfrm_address_t *);
	int (*tmpl_sort)(struct xfrm_tmpl **, struct xfrm_tmpl **, int);
	int (*state_sort)(struct xfrm_state___14 **, struct xfrm_state___14 **, int);
	int (*output)(struct net___103 *, struct sock___72 *, struct sk_buff___93 *);
	int (*output_finish)(struct sock___72 *, struct sk_buff___93 *);
	int (*extract_input)(struct xfrm_state___14 *, struct sk_buff___93 *);
	int (*extract_output)(struct xfrm_state___14 *, struct sk_buff___93 *);
	int (*transport_finish)(struct sk_buff___93 *, int);
	void (*local_error)(struct sk_buff___93 *, u32);
};

struct nf_hook_state___12 {
	unsigned int hook;
	u_int8_t pf;
	struct net_device___92 *in;
	struct net_device___92 *out;
	struct sock___72 *sk;
	struct net___103 *net;
	int (*okfn)(struct net___103 *, struct sock___72 *, struct sk_buff___93 *);
};

struct nf_nat_hook___12 {
	int (*parse_nat_setup)(struct nf_conn *, enum nf_nat_manip_type, const struct nlattr *);
	void (*decode_session)(struct sk_buff___93 *, struct flowi *);
	unsigned int (*manip_pkt)(struct sk_buff___93 *, struct nf_conn *, enum nf_nat_manip_type, enum ip_conntrack_dir);
};

struct nf_ct_hook___12 {
	int (*update)(struct net___103 *, struct sk_buff___93 *);
	void (*destroy)(struct nf_conntrack *);
	bool (*get_tuple_skb)(struct nf_conntrack_tuple *, const struct sk_buff___93 *);
};

struct nfnl_ct_hook___12 {
	struct nf_conn * (*get_ct)(const struct sk_buff___93 *, enum ip_conntrack_info *);
	size_t (*build_size)(const struct nf_conn *);
	int (*build)(struct sk_buff___93 *, struct nf_conn *, enum ip_conntrack_info, u_int16_t, u_int16_t);
	int (*parse)(const struct nlattr *, struct nf_conn *);
	int (*attach_expect)(const struct nlattr *, struct nf_conn *, u32, u32);
	void (*seq_adjust)(struct sk_buff___93 *, struct nf_conn *, enum ip_conntrack_info, s32);
};

struct raw_frag_vec {
	struct msghdr___75 *msg;
	union {
		struct icmphdr icmph;
		char c[1];
	} hdr;
	int hlen;
};

struct module___374;

struct file___448;

struct kiocb___448;

struct iov_iter___215;

struct poll_table_struct___287;

struct vm_area_struct___449;

struct inode___448;

struct file_lock___448;

struct page___449;

struct pipe_inode_info___129;

struct seq_file___387;

struct file_operations___448 {
	struct module___374 *owner;
	loff_t (*llseek)(struct file___448 *, loff_t, int);
	ssize_t (*read)(struct file___448 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___448 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___448 *, struct iov_iter___215 *);
	ssize_t (*write_iter)(struct kiocb___448 *, struct iov_iter___215 *);
	int (*iopoll)(struct kiocb___448 *, bool);
	int (*iterate)(struct file___448 *, struct dir_context *);
	int (*iterate_shared)(struct file___448 *, struct dir_context *);
	__poll_t (*poll)(struct file___448 *, struct poll_table_struct___287 *);
	long int (*unlocked_ioctl)(struct file___448 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___448 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___448 *, struct vm_area_struct___449 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___448 *, struct file___448 *);
	int (*flush)(struct file___448 *, fl_owner_t);
	int (*release)(struct inode___448 *, struct file___448 *);
	int (*fsync)(struct file___448 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___448 *, int);
	int (*lock)(struct file___448 *, int, struct file_lock___448 *);
	ssize_t (*sendpage)(struct file___448 *, struct page___449 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___448 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___448 *, int, struct file_lock___448 *);
	ssize_t (*splice_write)(struct pipe_inode_info___129 *, struct file___448 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___448 *, loff_t *, struct pipe_inode_info___129 *, size_t, unsigned int);
	int (*setlease)(struct file___448 *, long int, struct file_lock___448 **, void **);
	long int (*fallocate)(struct file___448 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___387 *, struct file___448 *);
	ssize_t (*copy_file_range)(struct file___448 *, loff_t, struct file___448 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___448 *, loff_t, struct file___448 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___448 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___449 {
	u64 seqnum;
	struct vm_area_struct___449 *vmas[4];
};

struct page_frag___449 {
	struct page___449 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___449;

struct mem_cgroup___181;

struct pid___250;

struct cred___416;

struct nsproxy___343;

struct signal_struct___323;

struct bio_list___238;

struct backing_dev_info___238;

struct css_set___297;

struct vm_struct___352;

struct task_struct___450 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___450 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___449 *mm;
	struct mm_struct___449 *active_mm;
	struct vmacache___449 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___450 *real_parent;
	struct task_struct___450 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___450 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___181 *active_memcg;
	long int rh_reserved2;
	struct pid___250 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___250 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___250 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___416 *ptracer_cred;
	const struct cred___416 *real_cred;
	const struct cred___416 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___343 *nsproxy;
	struct signal_struct___323 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___450 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___238 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___238 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___297 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___129 *splice_pipe;
	struct page_frag___449 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___181 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___450 *oom_reaper_list;
	struct vm_struct___352 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___156 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___250;

struct upid___250 {
	int nr;
	struct pid_namespace___250 *ns;
};

struct dentry___448;

struct user_namespace___313;

struct ucounts___313;

struct pid_namespace___250 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___450 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___250 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___448 *proc_self;
	struct dentry___448 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___313 *user_ns;
	struct ucounts___313 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___29 ns;
};

struct pid___250 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___250 numbers[1];
};

struct rw_semaphore___450 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___450 *owner;
};

struct key___416;

struct user_namespace___313 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___313 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___29 ns;
	long unsigned int flags;
	struct key___416 *persistent_keyring_register;
	struct rw_semaphore___450 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___313 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct secondary_data___450 {
	void *stack;
	struct task_struct___450 *task;
	long int status;
};

typedef struct page___449 *pgtable_t___449;

struct address_space___448;

struct dev_pagemap___436;

struct page___449 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___448 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___449 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___449 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___449 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___436 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___181 *mem_cgroup;
};

struct user_struct___416 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___416 *uid_keyring;
	struct key___416 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___436;

struct vm_area_struct___449 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___449 *vm_next;
	struct vm_area_struct___449 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___449 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___436 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___448 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___449;

struct mm_struct___449 {
	struct {
		struct vm_area_struct___449 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___448 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___450 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___449 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___450 *owner;
		struct user_namespace___313 *user_ns;
		struct file___448 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___449 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup___297;

struct cgroup_subsys___297;

struct cgroup_subsys_state___297 {
	struct cgroup___297 *cgroup;
	struct cgroup_subsys___297 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___297 *parent;
};

struct kernfs_node___443;

struct cgroup_file___297 {
	struct kernfs_node___443 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___181;

struct mem_cgroup___181 {
	struct cgroup_subsys_state___297 css;
	struct mem_cgroup_id___6 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___297 events_file;
	struct cgroup_file___297 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___450 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___181 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cred___416 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___416 *session_keyring;
	struct key___416 *process_keyring;
	struct key___416 *thread_keyring;
	struct key___416 *request_key_auth;
	void *security;
	struct user_struct___416 *user;
	struct user_namespace___313 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___104;

struct cgroup_namespace___297;

struct nsproxy___343 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___250 *pid_ns_for_children;
	struct net___104 *net_ns;
	struct cgroup_namespace___297 *cgroup_ns;
};

struct signal_struct___323 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___450 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___450 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___250 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___250 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___449 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___250 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide43;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___238;

struct bio_list___238 {
	struct bio___238 *head;
	struct bio___238 *tail;
};

struct bdi_writeback_congested___238;

struct bdi_writeback___238 {
	struct backing_dev_info___238 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___238 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___297 *memcg_css;
	struct cgroup_subsys_state___297 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___416;

struct backing_dev_info___238 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___238 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___416 *dev;
	struct device___416 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___448 *debug_dir;
	struct dentry___448 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___297 {
	struct cgroup_subsys_state___297 *subsys[13];
	refcount_t refcount;
	struct css_set___297 *dom_cset;
	struct cgroup___297 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___297 *mg_src_cgrp;
	struct cgroup___297 *mg_dst_cgrp;
	struct css_set___297 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___448;

struct pipe_buffer___129;

struct pipe_inode_info___129 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___449 *tmp_page;
	struct fasync_struct___448 *fasync_readers;
	struct fasync_struct___448 *fasync_writers;
	struct pipe_buffer___129 *bufs;
	struct user_struct___416 *user;
};

struct vm_struct___352 {
	struct vm_struct___352 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___449 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___335 {
	struct task_struct___450 task;
	long unsigned int stack[8192];
};

struct address_space_operations___448;

struct address_space___448 {
	struct inode___448 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___450 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___448 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___436)(struct vm_area_struct___449 *, long unsigned int, const struct page___449 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___436)(struct page___449 *, void *);

struct dev_pagemap___436 {
	dev_page_fault_t___436 page_fault;
	dev_page_free_t___436 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___416 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___449 {
	struct vfsmount *mnt;
	struct dentry___448 *dentry;
};

struct fown_struct___250 {
	rwlock_t lock;
	struct pid___250 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___448 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___449 f_path;
	struct inode___448 *f_inode;
	const struct file_operations___448 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___250 f_owner;
	const struct cred___416 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___448 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___436;

struct vm_operations_struct___436 {
	void (*open)(struct vm_area_struct___449 *);
	void (*close)(struct vm_area_struct___449 *);
	int (*split)(struct vm_area_struct___449 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___449 *);
	vm_fault_t (*fault)(struct vm_fault___436 *);
	vm_fault_t (*huge_fault)(struct vm_fault___436 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___436 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___449 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___436 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___436 *);
	int (*access)(struct vm_area_struct___449 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___449 *);
	int (*set_policy)(struct vm_area_struct___449 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___449 *, long unsigned int);
	struct page___449 * (*find_special_page)(struct vm_area_struct___449 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___449 {
	struct task_struct___450 *task;
	struct core_thread___449 *next;
};

struct core_state___449 {
	atomic_t nr_threads;
	struct core_thread___449 dumper;
	struct completion startup;
};

struct vm_fault___436 {
	struct vm_area_struct___449 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___449 *cow_page;
	struct mem_cgroup___181 *memcg;
	struct page___449 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___449 prealloc_pte;
};

struct pglist_data___449;

struct lruvec___449 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___449 *pgdat;
};

struct zone___449 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___449 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___449 {
	struct zone___449 *zone;
	int zone_idx;
};

struct zonelist___449 {
	struct zoneref___449 _zonerefs[25];
};

struct pglist_data___449 {
	struct zone___449 node_zones[3];
	struct zonelist___449 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___450 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___450 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___449 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___449 {
	struct rw_semaphore___450 rwsem;
	struct notifier_block *head;
};

struct dentry_operations___448;

struct super_block___448;

struct dentry___448 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___448 *d_parent;
	struct qstr d_name;
	struct inode___448 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___448 *d_op;
	struct super_block___448 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___448;

struct block_device___448;

struct inode___448 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___448 *i_op;
	struct super_block___448 *i_sb;
	struct address_space___448 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___450 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___238 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___448 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___448 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___129 *i_pipe;
		struct block_device___448 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___448 {
	int (*d_revalidate)(struct dentry___448 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___448 *, unsigned int);
	int (*d_hash)(const struct dentry___448 *, struct qstr *);
	int (*d_compare)(const struct dentry___448 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___448 *);
	int (*d_init)(struct dentry___448 *);
	void (*d_release)(struct dentry___448 *);
	void (*d_prune)(struct dentry___448 *);
	void (*d_iput)(struct dentry___448 *, struct inode___448 *);
	char * (*d_dname)(struct dentry___448 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___449 *);
	int (*d_manage)(const struct path___449 *, bool);
	struct dentry___448 * (*d_real)(struct dentry___448 *, const struct inode___448 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___448;

struct mem_dqinfo___448 {
	struct quota_format_type___448 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___448;

struct quota_info___448 {
	unsigned int flags;
	struct rw_semaphore___450 dqio_sem;
	struct inode___448 *files[3];
	struct mem_dqinfo___448 info[3];
	const struct quota_format_ops___448 *ops[3];
};

struct rcuwait___448 {
	struct task_struct___450 *task;
};

struct percpu_rw_semaphore___448 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___450 rw_sem;
	struct rcuwait___448 writer;
	int readers_block;
};

struct sb_writers___448 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___448 rw_sem[3];
};

struct shrink_control___181;

struct shrinker___181 {
	long unsigned int (*count_objects)(struct shrinker___181 *, struct shrink_control___181 *);
	long unsigned int (*scan_objects)(struct shrinker___181 *, struct shrink_control___181 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___448;

struct super_operations___448;

struct dquot_operations___448;

struct quotactl_ops___448;

struct super_block___448 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___448 *s_type;
	const struct super_operations___448 *s_op;
	const struct dquot_operations___448 *dq_op;
	const struct quotactl_ops___448 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___448 *s_root;
	struct rw_semaphore___450 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___448 *s_bdev;
	struct backing_dev_info___238 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___448 s_dquot;
	struct sb_writers___448 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___448 *s_d_op;
	int cleancache_poolid;
	struct shrinker___181 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___313 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___181 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___181 *memcg;
};

struct kiocb___448 {
	struct file___448 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___448 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___448 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___448 *ia_file;
};

struct dquot___448 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___448 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___448 {
	int qf_fmt_id;
	const struct quota_format_ops___448 *qf_ops;
	struct module___374 *qf_owner;
	struct quota_format_type___448 *qf_next;
};

struct quota_format_ops___448 {
	int (*check_quota_file)(struct super_block___448 *, int);
	int (*read_file_info)(struct super_block___448 *, int);
	int (*write_file_info)(struct super_block___448 *, int);
	int (*free_file_info)(struct super_block___448 *, int);
	int (*read_dqblk)(struct dquot___448 *);
	int (*commit_dqblk)(struct dquot___448 *);
	int (*release_dqblk)(struct dquot___448 *);
	int (*get_next_id)(struct super_block___448 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___448 {
	int (*write_dquot)(struct dquot___448 *);
	struct dquot___448 * (*alloc_dquot)(struct super_block___448 *, int);
	void (*destroy_dquot)(struct dquot___448 *);
	int (*acquire_dquot)(struct dquot___448 *);
	int (*release_dquot)(struct dquot___448 *);
	int (*mark_dirty)(struct dquot___448 *);
	int (*write_info)(struct super_block___448 *, int);
	qsize_t * (*get_reserved_space)(struct inode___448 *);
	int (*get_projid)(struct inode___448 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___448 *, qsize_t *);
	int (*get_next_id)(struct super_block___448 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___448 {
	int (*quota_on)(struct super_block___448 *, int, int, const struct path___449 *);
	int (*quota_off)(struct super_block___448 *, int);
	int (*quota_enable)(struct super_block___448 *, unsigned int);
	int (*quota_disable)(struct super_block___448 *, unsigned int);
	int (*quota_sync)(struct super_block___448 *, int);
	int (*set_info)(struct super_block___448 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___448 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___448 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___448 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___448 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___448 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset___435;

struct kobj_type___435;

struct kobject___436 {
	const char *name;
	struct list_head entry;
	struct kobject___436 *parent;
	struct kset___435 *kset;
	struct kobj_type___435 *ktype;
	struct kernfs_node___443 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___374 {
	struct kobject___436 kobj;
	struct module___374 *mod;
	struct kobject___436 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___374 {
	struct module___374 *mod;
	struct latch_tree_node node;
};

struct module_layout___374 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___374 mtn;
};

struct module_attribute___374;

struct kernel_param___374;

struct module___374 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___374 mkobj;
	struct module_attribute___374 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___436 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___374 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___374 core_layout;
	struct module_layout___374 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___201;

struct swap_info_struct___94;

struct address_space_operations___448 {
	int (*writepage)(struct page___449 *, struct writeback_control___201 *);
	int (*readpage)(struct file___448 *, struct page___449 *);
	int (*writepages)(struct address_space___448 *, struct writeback_control___201 *);
	int (*set_page_dirty)(struct page___449 *);
	int (*readpages)(struct file___448 *, struct address_space___448 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___448 *, struct address_space___448 *, loff_t, unsigned int, unsigned int, struct page___449 **, void **);
	int (*write_end)(struct file___448 *, struct address_space___448 *, loff_t, unsigned int, unsigned int, struct page___449 *, void *);
	sector_t (*bmap)(struct address_space___448 *, sector_t);
	void (*invalidatepage)(struct page___449 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___449 *, gfp_t);
	void (*freepage)(struct page___449 *);
	ssize_t (*direct_IO)(struct kiocb___448 *, struct iov_iter___215 *);
	int (*migratepage)(struct address_space___448 *, struct page___449 *, struct page___449 *, enum migrate_mode);
	bool (*isolate_page)(struct page___449 *, isolate_mode_t);
	void (*putback_page)(struct page___449 *);
	int (*launder_page)(struct page___449 *);
	int (*is_partially_uptodate)(struct page___449 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___449 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___448 *, struct page___449 *);
	int (*swap_activate)(struct swap_info_struct___94 *, struct file___448 *, sector_t *);
	void (*swap_deactivate)(struct file___448 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___201 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___238 *wb;
	struct inode___448 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___240;

struct iov_iter___215 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___240 *bvec;
		struct pipe_inode_info___129 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct swap_info_struct___94 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___448 *bdev;
	struct file___448 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___448 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___448 *bd_inode;
	struct super_block___448 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___448 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___238 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___448 {
	struct dentry___448 * (*lookup)(struct inode___448 *, struct dentry___448 *, unsigned int);
	const char * (*get_link)(struct dentry___448 *, struct inode___448 *, struct delayed_call *);
	int (*permission)(struct inode___448 *, int);
	struct posix_acl * (*get_acl)(struct inode___448 *, int);
	int (*readlink)(struct dentry___448 *, char *, int);
	int (*create)(struct inode___448 *, struct dentry___448 *, umode_t, bool);
	int (*link)(struct dentry___448 *, struct inode___448 *, struct dentry___448 *);
	int (*unlink)(struct inode___448 *, struct dentry___448 *);
	int (*symlink)(struct inode___448 *, struct dentry___448 *, const char *);
	int (*mkdir)(struct inode___448 *, struct dentry___448 *, umode_t);
	int (*rmdir)(struct inode___448 *, struct dentry___448 *);
	int (*mknod)(struct inode___448 *, struct dentry___448 *, umode_t, dev_t);
	int (*rename)(struct inode___448 *, struct dentry___448 *, struct inode___448 *, struct dentry___448 *, unsigned int);
	int (*setattr)(struct dentry___448 *, struct iattr___448 *);
	int (*getattr)(const struct path___449 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___448 *, char *, size_t);
	int (*fiemap)(struct inode___448 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___448 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___448 *, struct dentry___448 *, struct file___448 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___448 *, struct dentry___448 *, umode_t);
	int (*set_acl)(struct inode___448 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___448 {
	void (*fl_copy_lock)(struct file_lock___448 *, struct file_lock___448 *);
	void (*fl_release_private)(struct file_lock___448 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___448;

struct file_lock___448 {
	struct file_lock___448 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___448 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___448 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___448 *fl_ops;
	const struct lock_manager_operations___448 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___448 {
	int (*lm_compare_owner)(struct file_lock___448 *, struct file_lock___448 *);
	long unsigned int (*lm_owner_key)(struct file_lock___448 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___448 *);
	int (*lm_grant)(struct file_lock___448 *, int);
	bool (*lm_break)(struct file_lock___448 *);
	int (*lm_change)(struct file_lock___448 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___448 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___448 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___448 *fa_next;
	struct file___448 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___448 {
	const char *name;
	int fs_flags;
	struct dentry___448 * (*mount)(struct file_system_type___448 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___448 *);
	struct module___374 *owner;
	struct file_system_type___448 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___448 {
	struct inode___448 * (*alloc_inode)(struct super_block___448 *);
	void (*destroy_inode)(struct inode___448 *);
	void (*dirty_inode)(struct inode___448 *, int);
	int (*write_inode)(struct inode___448 *, struct writeback_control___201 *);
	int (*drop_inode)(struct inode___448 *);
	void (*evict_inode)(struct inode___448 *);
	void (*put_super)(struct super_block___448 *);
	int (*sync_fs)(struct super_block___448 *, int);
	int (*freeze_super)(struct super_block___448 *);
	int (*freeze_fs)(struct super_block___448 *);
	int (*thaw_super)(struct super_block___448 *);
	int (*unfreeze_fs)(struct super_block___448 *);
	int (*statfs)(struct dentry___448 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___448 *, int *, char *);
	void (*umount_begin)(struct super_block___448 *);
	int (*show_options)(struct seq_file___387 *, struct dentry___448 *);
	int (*show_devname)(struct seq_file___387 *, struct dentry___448 *);
	int (*show_path)(struct seq_file___387 *, struct dentry___448 *);
	int (*show_stats)(struct seq_file___387 *, struct dentry___448 *);
	ssize_t (*quota_read)(struct super_block___448 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___448 *, int, const char *, size_t, loff_t);
	struct dquot___448 ** (*get_dquots)(struct inode___448 *);
	int (*bdev_try_to_free_page)(struct super_block___448 *, struct page___449 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___448 *, struct shrink_control___181 *);
	long int (*free_cached_objects)(struct super_block___448 *, struct shrink_control___181 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___297)(struct file___448 *, wait_queue_head_t *, struct poll_table_struct___287 *);

struct poll_table_struct___287 {
	poll_queue_proc___297 _qproc;
	__poll_t _key;
};

struct seq_operations___387;

struct seq_file___387 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___387 *op;
	int poll_event;
	const struct file___448 *file;
	void *private;
};

typedef void bio_end_io_t___238(struct bio___238 *);

struct bio_vec___240 {
	struct page___449 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___238;

struct bio_set___238;

struct bio___238 {
	struct bio___238 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___238 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___238 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___240 *bi_io_vec;
	struct bio_set___238 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___240 bi_inline_vecs[0];
};

struct dev_pm_info___416 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___416 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___416;

struct bus_type___416;

struct device_driver___416;

struct dev_pm_domain___416;

struct dma_map_ops___188;

struct fwnode_handle___336;

struct class___416;

struct attribute_group___413;

struct device___416 {
	struct device___416 *parent;
	struct device_private *p;
	struct kobject___436 kobj;
	const char *init_name;
	const struct device_type___416 *type;
	struct mutex mutex;
	struct bus_type___416 *bus;
	struct device_driver___416 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___416 power;
	struct dev_pm_domain___416 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___188 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___336 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___416 *class;
	const struct attribute_group___413 **groups;
	void (*release)(struct device___416 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct kobj_attribute___426 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___436 *, struct kobj_attribute___426 *, char *);
	ssize_t (*store)(struct kobject___436 *, struct kobj_attribute___426 *, const char *, size_t);
};

typedef void compound_page_dtor___436(struct page___449 *);

typedef int (*key_restrict_link_func_t___417)(struct key___416 *, const struct key_type *, const union key_payload *, struct key___416 *);

struct key_restriction___416;

struct key___416 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___450 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___416 *restrict_link;
};

struct key_restriction___416 {
	key_restrict_link_func_t___417 check;
	struct key___416 *key;
	struct key_type *keytype;
};

struct seq_operations___387 {
	void * (*start)(struct seq_file___387 *, loff_t *);
	void (*stop)(struct seq_file___387 *, void *);
	void * (*next)(struct seq_file___387 *, void *, loff_t *);
	int (*show)(struct seq_file___387 *, void *);
};

struct kernfs_root___442;

struct kernfs_elem_dir___442 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___442 *root;
};

struct kernfs_syscall_ops___442;

struct kernfs_root___442 {
	struct kernfs_node___443 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___442 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___442 {
	struct kernfs_node___443 *target_kn;
};

struct kernfs_ops___442;

struct kernfs_elem_attr___442 {
	const struct kernfs_ops___442 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___443 *notify_next;
};

struct kernfs_node___443 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___443 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___442 dir;
		struct kernfs_elem_symlink___442 symlink;
		struct kernfs_elem_attr___442 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___442;

struct kernfs_ops___442 {
	int (*open)(struct kernfs_open_file___442 *);
	void (*release)(struct kernfs_open_file___442 *);
	int (*seq_show)(struct seq_file___387 *, void *);
	void * (*seq_start)(struct seq_file___387 *, loff_t *);
	void * (*seq_next)(struct seq_file___387 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___387 *, void *);
	ssize_t (*read)(struct kernfs_open_file___442 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___442 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___442 *, struct vm_area_struct___449 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___442 *, struct poll_table_struct___287 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___442 {
	int (*remount_fs)(struct kernfs_root___442 *, int *, char *);
	int (*show_options)(struct seq_file___387 *, struct kernfs_root___442 *);
	int (*mkdir)(struct kernfs_node___443 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___443 *);
	int (*rename)(struct kernfs_node___443 *, struct kernfs_node___443 *, const char *);
	int (*show_path)(struct seq_file___387 *, struct kernfs_node___443 *, struct kernfs_root___442 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___442 {
	struct kernfs_node___443 *kn;
	struct file___448 *file;
	struct seq_file___387 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___436 *vm_ops;
};

struct inet_frags___93;

struct netns_frags___93 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___93 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ip_ra_chain___39;

struct fib_rules_ops___73;

struct sock___73;

struct fib_notifier_ops___74;

struct netns_ipv4___93 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___39 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___73 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___73 *fibnl;
	struct sock___73 **icmp_sk;
	struct sock___73 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___73 **tcp_sk;
	struct netns_frags___93 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___73 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___74 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___74 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct dst_entry___73;

struct net_device___93;

struct sk_buff___94;

struct neighbour___73;

struct dst_ops___104 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___104 *);
	struct dst_entry___73 * (*check)(struct dst_entry___73 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___73 *);
	unsigned int (*mtu)(const struct dst_entry___73 *);
	u32 * (*cow_metrics)(struct dst_entry___73 *, long unsigned int);
	void (*destroy)(struct dst_entry___73 *);
	void (*ifdown)(struct dst_entry___73 *, struct net_device___93 *, int);
	struct dst_entry___73 * (*negative_advice)(struct dst_entry___73 *);
	void (*link_failure)(struct sk_buff___94 *);
	void (*update_pmtu)(struct dst_entry___73 *, struct sock___73 *, struct sk_buff___94 *, u32);
	void (*redirect)(struct dst_entry___73 *, struct sock___73 *, struct sk_buff___94 *);
	int (*local_out)(struct net___104 *, struct sock___73 *, struct sk_buff___94 *);
	struct neighbour___73 * (*neigh_lookup)(const struct dst_entry___73 *, struct sk_buff___94 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___73 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_info___19;

struct rt6_info___19;

struct fib6_table___19;

struct netns_ipv6___104 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___93 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info___19 *fib6_null_entry;
	struct rt6_info___19 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___19 *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___104 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info___19 *ip6_prohibit_entry;
	struct rt6_info___19 *ip6_blk_hole_entry;
	struct fib6_table___19 *fib6_local_tbl;
	struct fib_rules_ops___73 *fib6_rules_ops;
	struct sock___73 **icmp_sk;
	struct sock___73 *ndisc_sk;
	struct sock___73 *tcp_sk;
	struct sock___73 *igmp_sk;
	struct sock___73 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___73 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___74 *notifier_ops;
	struct fib_notifier_ops___74 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___74 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___73 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___93 {
	struct netns_frags___93 frags;
};

struct netns_xfrm___104 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___73 *nlsk;
	struct sock___73 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___104 xfrm4_dst_ops;
	struct dst_ops___104 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___83;

struct net___104 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___313 *user_ns;
	struct ucounts___313 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___29 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___73 *rtnl;
	struct sock___73 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___93 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___93 ipv4;
	struct netns_ipv6___104 ipv6;
	struct netns_sctp___74 sctp;
	struct netns_nf___13 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___93 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___73 *nfnl;
	struct sock___73 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___104 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___73 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___83 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cgroup_namespace___297 {
	refcount_t count;
	struct ns_common___29 ns;
	struct user_namespace___313 *user_ns;
	struct ucounts___313 *ucounts;
	struct css_set___297 *root_cset;
};

struct ucounts___313 {
	struct hlist_node node;
	struct user_namespace___313 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_map___298;

struct bpf_map_ops___297 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___298 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___298 *, struct file___448 *);
	void (*map_free)(struct bpf_map___298 *);
	int (*map_get_next_key)(struct bpf_map___298 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___298 *);
	void * (*map_lookup_elem)(struct bpf_map___298 *, void *);
	int (*map_update_elem)(struct bpf_map___298 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___298 *, void *);
	int (*map_push_elem)(struct bpf_map___298 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___298 *, void *);
	int (*map_peek_elem)(struct bpf_map___298 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___298 *, struct file___448 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___298 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___298 *, void *, struct seq_file___387 *);
	int (*map_check_btf)(const struct bpf_map___298 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___298 {
	const struct bpf_map_ops___297 *ops;
	struct bpf_map___298 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___416 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___93;

struct bpf_map_dev_ops___93 {
	int (*map_get_next_key)(struct bpf_offloaded_map___93 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___93 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___93 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___93 *, void *);
};

struct bpf_offloaded_map___93 {
	struct bpf_map___298 map;
	struct net_device___93 *netdev;
	const struct bpf_map_dev_ops___93 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

typedef rx_handler_result_t rx_handler_func_t___93(struct sk_buff___94 **);

typedef struct {
	struct net___104 *net;
} possible_net_t___95;

struct net_device_ops___93;

struct ethtool_ops___93;

struct l3mdev_ops___73;

struct ndisc_ops___44;

struct xfrmdev_ops___93;

struct tlsdev_ops___93;

struct header_ops___93;

struct in_device___9;

struct inet6_dev___44;

struct netdev_rx_queue___93;

struct mini_Qdisc___85;

struct netdev_queue___93;

struct Qdisc___85;

struct rtnl_link_ops___85;

struct dcbnl_rtnl_ops___93;

struct net_device___93 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___93 *netdev_ops;
	const struct ethtool_ops___93 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___73 *l3mdev_ops;
	const struct ndisc_ops___44 *ndisc_ops;
	const struct xfrmdev_ops___93 *xfrmdev_ops;
	const struct tlsdev_ops___93 *tlsdev_ops;
	const struct header_ops___93 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___435 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device___9 *ip_ptr;
	struct inet6_dev___44 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___93 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___83 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___93 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___85 *miniq_ingress;
	struct netdev_queue___93 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___93 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___85 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___85 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___93 = 0,
		NETREG_REGISTERED___93 = 1,
		NETREG_UNREGISTERING___93 = 2,
		NETREG_UNREGISTERED___93 = 3,
		NETREG_RELEASED___93 = 4,
		NETREG_DUMMY___93 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___93 = 0,
		RTNL_LINK_INITIALIZING___93 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___93 *);
	struct netpoll_info *npinfo;
	possible_net_t___95 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___416 dev;
	const struct attribute_group___413 *sysfs_groups[4];
	const struct attribute_group___413 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___85 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___93 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide50;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct bpf_prog_ops___83 {
	int (*test_run)(struct bpf_prog___83 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_aux___86;

struct bpf_prog___83 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___86 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

struct bpf_verifier_ops___83 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___83 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___83 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___83 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___83 *, u32 *);
};

struct bpf_prog_offload_ops___83 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___83 *);
	int (*translate)(struct bpf_prog___83 *);
	void (*destroy)(struct bpf_prog___83 *);
};

struct bpf_prog_offload___83 {
	struct bpf_prog___83 *prog;
	struct net_device___93 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___83 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___86 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___83 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___83 *ops;
	struct bpf_map___298 **used_maps;
	struct bpf_prog___83 *prog;
	struct user_struct___416 *user;
	u64 load_time;
	struct bpf_map___298 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___83 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___83 {
	struct bpf_prog___83 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___83 {
	struct callback_head rcu;
	struct bpf_prog_array_item___83 items[0];
};

struct cgroup_bpf___83 {
	struct bpf_prog_array___83 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___83 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___298;

typedef void (*kthread_work_func_t___298)(struct kthread_work___298 *);

struct kthread_worker___298;

struct kthread_work___298 {
	struct list_head node;
	kthread_work_func_t___298 func;
	struct kthread_worker___298 *worker;
	int canceling;
};

struct kthread_worker___298 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___450 *task;
	struct kthread_work___298 *current_work;
};

struct kthread_delayed_work___297 {
	struct kthread_work___298 work;
	struct timer_list timer;
};

struct psi_group___297 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___298 *poll_kworker;
	struct kthread_delayed_work___297 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___297;

struct cgroup_rstat_cpu___297;

struct cgroup___297 {
	struct cgroup_subsys_state___297 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___443 *kn;
	struct cgroup_file___297 procs_file;
	struct cgroup_file___297 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___297 *subsys[13];
	struct cgroup_root___297 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___297 *dom_cgrp;
	struct cgroup_rstat_cpu___297 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___83 bpf;
	atomic_t congestion_count;
	struct cgroup___297 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___297 psi;
	int ancestor_ids[0];
};

struct cftype___297;

struct cgroup_subsys___297 {
	struct cgroup_subsys_state___297 * (*css_alloc)(struct cgroup_subsys_state___297 *);
	int (*css_online)(struct cgroup_subsys_state___297 *);
	void (*css_offline)(struct cgroup_subsys_state___297 *);
	void (*css_released)(struct cgroup_subsys_state___297 *);
	void (*css_free)(struct cgroup_subsys_state___297 *);
	void (*css_reset)(struct cgroup_subsys_state___297 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___297 *, int);
	int (*css_extra_stat_show)(struct seq_file___387 *, struct cgroup_subsys_state___297 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___450 *);
	void (*cancel_fork)(struct task_struct___450 *);
	void (*fork)(struct task_struct___450 *);
	void (*exit)(struct task_struct___450 *);
	void (*free)(struct task_struct___450 *);
	void (*bind)(struct cgroup_subsys_state___297 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___297 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___297 *dfl_cftypes;
	struct cftype___297 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___297 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___297 *updated_children;
	struct cgroup___297 *updated_next;
};

struct cgroup_root___297 {
	struct kernfs_root___442 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___297 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___297 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___297 *ss;
	struct list_head node;
	struct kernfs_ops___442 *kf_ops;
	int (*open)(struct kernfs_open_file___442 *);
	void (*release)(struct kernfs_open_file___442 *);
	u64 (*read_u64)(struct cgroup_subsys_state___297 *, struct cftype___297 *);
	s64 (*read_s64)(struct cgroup_subsys_state___297 *, struct cftype___297 *);
	int (*seq_show)(struct seq_file___387 *, void *);
	void * (*seq_start)(struct seq_file___387 *, loff_t *);
	void * (*seq_next)(struct seq_file___387 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___387 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___297 *, struct cftype___297 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___297 *, struct cftype___297 *, s64);
	ssize_t (*write)(struct kernfs_open_file___442 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___442 *, struct poll_table_struct___287 *);
};

struct bdi_writeback_congested___238 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___238 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___238 {
	struct bio___238 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___240 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___240 bip_inline_vecs[0];
};

struct bio_set___238 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___238 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___181 {
	struct mem_cgroup___181 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___181 {
	struct lruvec___449 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___181 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___181 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct kobj_ns_type_operations___73 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___73 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct proto___73;

struct sock_common___73 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___73 *skc_prot;
	possible_net_t___95 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___73 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff_head___93 {
	struct sk_buff___94 *next;
	struct sk_buff___94 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___73;

struct socket_wq___74;

struct xfrm_policy___15;

struct socket___75;

struct sock_reuseport___7;

struct sock___73 {
	struct sock_common___73 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___93 sk_error_queue;
	struct sk_buff_head___93 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___94 *head;
		struct sk_buff___94 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___73 *sk_filter;
	union {
		struct socket_wq___74 *sk_wq;
		struct socket_wq___74 *sk_wq_raw;
	};
	struct xfrm_policy___15 *sk_policy[2];
	struct dst_entry___73 *sk_rx_dst;
	struct dst_entry___73 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___94 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___93 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___449 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___73 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___250 *sk_peer_pid;
	const struct cred___416 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___75 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___181 *sk_memcg;
	void (*sk_state_change)(struct sock___73 *);
	void (*sk_data_ready)(struct sock___73 *);
	void (*sk_write_space)(struct sock___73 *);
	void (*sk_error_report)(struct sock___73 *);
	int (*sk_backlog_rcv)(struct sock___73 *, struct sk_buff___94 *);
	struct sk_buff___94 * (*sk_validate_xmit_skb)(struct sock___73 *, struct net_device___93 *, struct sk_buff___94 *);
	void (*sk_destruct)(struct sock___73 *);
	struct sock_reuseport___7 *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct bin_attribute___412;

struct attribute_group___413 {
	const char *name;
	umode_t (*is_visible)(struct kobject___436 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___436 *, struct bin_attribute___412 *, int);
	struct attribute **attrs;
	struct bin_attribute___412 **bin_attrs;
};

struct bin_attribute___412 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___448 *, struct kobject___436 *, struct bin_attribute___412 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___448 *, struct kobject___436 *, struct bin_attribute___412 *, char *, loff_t, size_t);
	int (*mmap)(struct file___448 *, struct kobject___436 *, struct bin_attribute___412 *, struct vm_area_struct___449 *);
};

struct sysfs_ops___435 {
	ssize_t (*show)(struct kobject___436 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___436 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___435;

struct kset___435 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___436 kobj;
	const struct kset_uevent_ops___435 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___435 {
	void (*release)(struct kobject___436 *);
	const struct sysfs_ops___435 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___73 * (*child_ns_type)(struct kobject___436 *);
	const void * (*namespace)(struct kobject___436 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___435 {
	int (* const filter)(struct kset___435 *, struct kobject___436 *);
	const char * (* const name)(struct kset___435 *, struct kobject___436 *);
	int (* const uevent)(struct kset___435 *, struct kobject___436 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___416 {
	int (*prepare)(struct device___416 *);
	void (*complete)(struct device___416 *);
	int (*suspend)(struct device___416 *);
	int (*resume)(struct device___416 *);
	int (*freeze)(struct device___416 *);
	int (*thaw)(struct device___416 *);
	int (*poweroff)(struct device___416 *);
	int (*restore)(struct device___416 *);
	int (*suspend_late)(struct device___416 *);
	int (*resume_early)(struct device___416 *);
	int (*freeze_late)(struct device___416 *);
	int (*thaw_early)(struct device___416 *);
	int (*poweroff_late)(struct device___416 *);
	int (*restore_early)(struct device___416 *);
	int (*suspend_noirq)(struct device___416 *);
	int (*resume_noirq)(struct device___416 *);
	int (*freeze_noirq)(struct device___416 *);
	int (*thaw_noirq)(struct device___416 *);
	int (*poweroff_noirq)(struct device___416 *);
	int (*restore_noirq)(struct device___416 *);
	int (*runtime_suspend)(struct device___416 *);
	int (*runtime_resume)(struct device___416 *);
	int (*runtime_idle)(struct device___416 *);
};

struct dev_pm_domain___416 {
	struct dev_pm_ops___416 ops;
	void (*detach)(struct device___416 *, bool);
	int (*activate)(struct device___416 *);
	void (*sync)(struct device___416 *);
	void (*dismiss)(struct device___416 *);
};

struct bus_type___416 {
	const char *name;
	const char *dev_name;
	struct device___416 *dev_root;
	const struct attribute_group___413 **bus_groups;
	const struct attribute_group___413 **dev_groups;
	const struct attribute_group___413 **drv_groups;
	int (*match)(struct device___416 *, struct device_driver___416 *);
	int (*uevent)(struct device___416 *, struct kobj_uevent_env *);
	int (*probe)(struct device___416 *);
	int (*remove)(struct device___416 *);
	void (*shutdown)(struct device___416 *);
	int (*online)(struct device___416 *);
	int (*offline)(struct device___416 *);
	int (*suspend)(struct device___416 *, pm_message_t);
	int (*resume)(struct device___416 *);
	int (*num_vf)(struct device___416 *);
	int (*dma_configure)(struct device___416 *);
	const struct dev_pm_ops___416 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___416 {
	const char *name;
	struct bus_type___416 *bus;
	struct module___374 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___416 *);
	int (*remove)(struct device___416 *);
	void (*shutdown)(struct device___416 *);
	int (*suspend)(struct device___416 *, pm_message_t);
	int (*resume)(struct device___416 *);
	const struct attribute_group___413 **groups;
	const struct dev_pm_ops___416 *pm;
	void (*coredump)(struct device___416 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___416 {
	const char *name;
	const struct attribute_group___413 **groups;
	int (*uevent)(struct device___416 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___416 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___416 *);
	const struct dev_pm_ops___416 *pm;
};

struct class___416 {
	const char *name;
	struct module___374 *owner;
	const struct attribute_group___413 **class_groups;
	const struct attribute_group___413 **dev_groups;
	struct kobject___436 *dev_kobj;
	int (*dev_uevent)(struct device___416 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___416 *, umode_t *);
	void (*class_release)(struct class___416 *);
	void (*dev_release)(struct device___416 *);
	int (*shutdown_pre)(struct device___416 *);
	const struct kobj_ns_type_operations___73 *ns_type;
	const void * (*namespace)(struct device___416 *);
	const struct dev_pm_ops___416 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___188 {
	void * (*alloc)(struct device___416 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___416 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___416 *, struct vm_area_struct___449 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___416 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___416 *, struct page___449 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___416 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___416 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___416 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___416 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___416 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___416 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___416 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___416 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___416 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___416 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___416 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___416 *, u64);
	u64 (*get_required_mask)(struct device___416 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___336;

struct fwnode_handle___336 {
	struct fwnode_handle___336 *secondary;
	const struct fwnode_operations___336 *ops;
};

struct node___228 {
	struct device___416 dev;
};

struct kernel_param_ops___374 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___374 *);
	int (*get)(char *, const struct kernel_param___374 *);
	void (*free)(void *);
};

struct kparam_array___374;

struct kernel_param___374 {
	const char *name;
	struct module___374 *mod;
	const struct kernel_param_ops___374 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___374 *arr;
	};
};

struct kparam_array___374 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___374 *ops;
	void *elem;
};

struct module_attribute___374 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___374 *, struct module_kobject___374 *, char *);
	ssize_t (*store)(struct module_attribute___374 *, struct module_kobject___374 *, const char *, size_t);
	void (*setup)(struct module___374 *, const char *);
	int (*test)(struct module___374 *);
	void (*free)(struct module___374 *);
};

struct msghdr___76 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___215 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___448 *msg_iocb;
};

struct socket_wq___74 {
	wait_queue_head_t wait;
	struct fasync_struct___448 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___74;

struct socket___75 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___74 *wq;
	struct file___448 *file;
	struct sock___73 *sk;
	const struct proto_ops___74 *ops;
};

typedef int (*sk_read_actor_t___73)(read_descriptor_t *, struct sk_buff___94 *, unsigned int, size_t);

struct proto_ops___74 {
	int family;
	struct module___374 *owner;
	int (*release)(struct socket___75 *);
	int (*bind)(struct socket___75 *, struct sockaddr *, int);
	int (*connect)(struct socket___75 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___75 *, struct socket___75 *);
	int (*accept)(struct socket___75 *, struct socket___75 *, int, bool);
	int (*getname)(struct socket___75 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___448 *, struct socket___75 *, struct poll_table_struct___287 *);
	int (*ioctl)(struct socket___75 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___75 *, int);
	int (*shutdown)(struct socket___75 *, int);
	int (*setsockopt)(struct socket___75 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___75 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___75 *, struct msghdr___76 *, size_t);
	int (*recvmsg)(struct socket___75 *, struct msghdr___76 *, size_t, int);
	int (*mmap)(struct file___448 *, struct socket___75 *, struct vm_area_struct___449 *);
	ssize_t (*sendpage)(struct socket___75 *, struct page___449 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___75 *, loff_t *, struct pipe_inode_info___129 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___73 *, int);
	int (*peek_len)(struct socket___75 *);
	int (*read_sock)(struct sock___73 *, read_descriptor_t *, sk_read_actor_t___73);
	int (*sendpage_locked)(struct sock___73 *, struct page___449 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___73 *, struct msghdr___76 *, size_t);
	int (*set_rcvlowat)(struct sock___73 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct sec_path___15;

struct nf_bridge_info___93;

struct sk_buff___94 {
	union {
		struct {
			struct sk_buff___94 *next;
			struct sk_buff___94 *prev;
			union {
				struct net_device___93 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___73 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___94 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path___15 *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___93 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct fwnode_reference_args___336;

struct fwnode_endpoint___336;

struct fwnode_operations___336 {
	struct fwnode_handle___336 * (*get)(struct fwnode_handle___336 *);
	void (*put)(struct fwnode_handle___336 *);
	bool (*device_is_available)(const struct fwnode_handle___336 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___336 *, const struct device___416 *);
	bool (*property_present)(const struct fwnode_handle___336 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___336 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___336 *, const char *, const char **, size_t);
	struct fwnode_handle___336 * (*get_parent)(const struct fwnode_handle___336 *);
	struct fwnode_handle___336 * (*get_next_child_node)(const struct fwnode_handle___336 *, struct fwnode_handle___336 *);
	struct fwnode_handle___336 * (*get_named_child_node)(const struct fwnode_handle___336 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___336 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___336 *);
	struct fwnode_handle___336 * (*graph_get_next_endpoint)(const struct fwnode_handle___336 *, struct fwnode_handle___336 *);
	struct fwnode_handle___336 * (*graph_get_remote_endpoint)(const struct fwnode_handle___336 *);
	struct fwnode_handle___336 * (*graph_get_port_parent)(struct fwnode_handle___336 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___336 *, struct fwnode_endpoint___336 *);
};

struct fwnode_endpoint___336 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___336 *local_fwnode;
};

struct fwnode_reference_args___336 {
	struct fwnode_handle___336 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___129;

struct pipe_buffer___129 {
	struct page___449 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___129 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___129 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___129 *, struct pipe_buffer___129 *);
	void (*release)(struct pipe_inode_info___129 *, struct pipe_buffer___129 *);
	int (*steal)(struct pipe_inode_info___129 *, struct pipe_buffer___129 *);
	union {
		bool (*get)(struct pipe_inode_info___129 *, struct pipe_buffer___129 *);
		struct {
			void (*get)(struct pipe_inode_info___129 *, struct pipe_buffer___129 *);
		} __UNIQUE_ID_rh_kabi_hide36;
		union {		};
	};
};

struct nf_bridge_info___93 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___93 = 0,
		BRNF_PROTO_8021Q___93 = 1,
		BRNF_PROTO_PPPOE___93 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___93 *physindev;
	struct net_device___93 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

struct skb_frag_struct___23 {
	struct {
		struct page___449 *p;
	} page;
	__u32 page_offset;
	__u32 size;
};

typedef struct skb_frag_struct___23 skb_frag_t___23;

struct skb_shared_info___23 {
	__u8 __unused;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___94 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___23 frags[16];
};

struct xfrm_state___15;

struct sec_path___15 {
	refcount_t refcnt;
	int len;
	int olen;
	struct xfrm_state___15 *xvec[6];
	struct xfrm_offload ovec[1];
};

struct ip_mc_list___2 {
	struct in_device___9 *interface;
	__be32 multiaddr;
	unsigned int sfmode;
	struct ip_sf_list *sources;
	struct ip_sf_list *tomb;
	long unsigned int sfcount[2];
	union {
		struct ip_mc_list___2 *next;
		struct ip_mc_list___2 *next_rcu;
	};
	struct ip_mc_list___2 *next_hash;
	struct timer_list timer;
	int users;
	refcount_t refcnt;
	spinlock_t lock;
	char tm_running;
	char reporter;
	char unsolicit_count;
	char loaded;
	unsigned char gsquery;
	unsigned char crcount;
	struct callback_head rcu;
};

struct in_ifaddr___9;

struct neigh_parms___73;

struct in_device___9 {
	struct net_device___93 *dev;
	refcount_t refcnt;
	int dead;
	struct in_ifaddr___9 *ifa_list;
	struct ip_mc_list___2 *mc_list;
	struct ip_mc_list___2 **mc_hash;
	int mc_count;
	spinlock_t mc_tomb_lock;
	struct ip_mc_list___2 *mc_tomb;
	long unsigned int mr_v1_seen;
	long unsigned int mr_v2_seen;
	long unsigned int mr_maxdelay;
	long unsigned int mr_qi;
	long unsigned int mr_qri;
	unsigned char mr_qrv;
	unsigned char mr_gq_running;
	unsigned char mr_ifc_count;
	struct timer_list mr_gq_timer;
	struct timer_list mr_ifc_timer;
	struct neigh_parms___73 *arp_parms;
	struct ipv4_devconf cnf;
	struct callback_head callback_head;
};

struct ethtool_ops___93 {
	int (*get_settings)(struct net_device___93 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___93 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___93 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___93 *);
	void (*get_regs)(struct net_device___93 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___93 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___93 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___93 *);
	void (*set_msglevel)(struct net_device___93 *, u32);
	int (*nway_reset)(struct net_device___93 *);
	u32 (*get_link)(struct net_device___93 *);
	int (*get_eeprom_len)(struct net_device___93 *);
	int (*get_eeprom)(struct net_device___93 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___93 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___93 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___93 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___93 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___93 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___93 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___93 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___93 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___93 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___93 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___93 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___93 *);
	void (*complete)(struct net_device___93 *);
	u32 (*get_priv_flags)(struct net_device___93 *);
	int (*set_priv_flags)(struct net_device___93 *, u32);
	int (*get_sset_count)(struct net_device___93 *, int);
	int (*get_rxnfc)(struct net_device___93 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___93 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___93 *, struct ethtool_flash *);
	int (*reset)(struct net_device___93 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___93 *);
	u32 (*get_rxfh_indir_size)(struct net_device___93 *);
	int (*get_rxfh)(struct net_device___93 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___93 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___93 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___93 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___93 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___93 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___93 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___93 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___93 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___93 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___93 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___93 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___93 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___93 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___93 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___93 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___93 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___93 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___93 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___93 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide39;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___93 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___93 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide40;
		union {		};
	};
	int (*get_fecparam)(struct net_device___93 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___93 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___93 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___93 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide41;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___93 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide42;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___93;

struct inet_frags___93 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___93 *, const void *);
	void (*destructor)(struct inet_frag_queue___93 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___93 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___94 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___94 *fragments_tail;
	struct sk_buff___94 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___93 *net;
	struct callback_head rcu;
};

struct ip_ra_chain___39 {
	struct ip_ra_chain___39 *next;
	struct sock___73 *sk;
	union {
		void (*destructor)(struct sock___73 *);
		struct sock___73 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___73;

struct fib_lookup_arg___73;

struct fib_rules_ops___73 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___73 *, struct flowi *, int, struct fib_lookup_arg___73 *);
	bool (*suppress)(struct fib_rule___73 *, struct fib_lookup_arg___73 *);
	int (*match)(struct fib_rule___73 *, struct flowi *, int);
	int (*configure)(struct fib_rule___73 *, struct sk_buff___94 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___73 *);
	int (*compare)(struct fib_rule___73 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___73 *, struct sk_buff___94 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___73 *);
	void (*flush_cache)(struct fib_rules_ops___73 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___374 *owner;
	struct net___104 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___74 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___104 *);
	int (*fib_dump)(struct net___104 *, struct notifier_block *);
	struct module___374 *owner;
	struct callback_head rcu;
};

struct dst_entry___73 {
	struct net_device___93 *dev;
	struct dst_ops___104 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state___15 *xfrm;
	int (*input)(struct sk_buff___94 *);
	int (*output)(struct net___104 *, struct sock___73 *, struct sk_buff___94 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___73;

struct neigh_ops___73;

struct neighbour___73 {
	struct neighbour___73 *next;
	struct neigh_table___73 *tbl;
	struct neigh_parms___73 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___93 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___73 *, struct sk_buff___94 *);
	const struct neigh_ops___73 *ops;
	struct callback_head rcu;
	struct net_device___93 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct fib6_nh___19 {
	struct in6_addr nh_gw;
	struct net_device___93 *nh_dev;
	struct lwtunnel_state *nh_lwtstate;
	unsigned int nh_flags;
	atomic_t nh_upper_bound;
	int nh_weight;
};

struct fib6_node___19;

struct fib6_info___19 {
	struct fib6_table___19 *fib6_table;
	struct fib6_info___19 *fib6_next;
	struct fib6_node___19 *fib6_node;
	struct list_head fib6_siblings;
	unsigned int fib6_nsiblings;
	atomic_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	struct rt6_info___19 **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
	long unsigned int last_probe;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 exception_bucket_flushed: 1;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 dst_host: 1;
	u8 fib6_destroying: 1;
	u8 unused: 2;
	struct fib6_nh___19 fib6_nh;
	struct callback_head rcu;
};

struct rt6_info___19 {
	struct dst_entry___73 dst;
	struct fib6_info___19 *from;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___44 *rt6i_idev;
	u32 rt6i_flags;
	struct rt6key rt6i_prefsrc;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct fib6_node___19 {
	struct fib6_node___19 *parent;
	struct fib6_node___19 *left;
	struct fib6_node___19 *right;
	struct fib6_info___19 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info___19 *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table___19 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node___19 tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

struct seq_net_private___9 {
	struct net___104 *net;
};

struct pernet_operations___94 {
	struct list_head list;
	int (*init)(struct net___104 *);
	void (*exit)(struct net___104 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___93 {
	int (*ieee_getets)(struct net_device___93 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___93 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___93 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___93 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___93 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___93 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___93 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___93 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___93 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___93 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___93 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___93 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___93 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___93 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___93 *);
	u8 (*setstate)(struct net_device___93 *, u8);
	void (*getpermhwaddr)(struct net_device___93 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___93 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___93 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___93 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___93 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___93 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___93 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___93 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___93 *, int, u8 *);
	void (*setpfccfg)(struct net_device___93 *, int, u8);
	void (*getpfccfg)(struct net_device___93 *, int, u8 *);
	u8 (*setall)(struct net_device___93 *);
	u8 (*getcap)(struct net_device___93 *, int, u8 *);
	int (*getnumtcs)(struct net_device___93 *, int, u8 *);
	int (*setnumtcs)(struct net_device___93 *, int, u8);
	u8 (*getpfcstate)(struct net_device___93 *);
	void (*setpfcstate)(struct net_device___93 *, u8);
	void (*getbcncfg)(struct net_device___93 *, int, u32 *);
	void (*setbcncfg)(struct net_device___93 *, int, u32);
	void (*getbcnrp)(struct net_device___93 *, int, u8 *);
	void (*setbcnrp)(struct net_device___93 *, int, u8);
	int (*setapp)(struct net_device___93 *, u8, u16, u8);
	int (*getapp)(struct net_device___93 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___93 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___93 *, int, u8);
	u8 (*getdcbx)(struct net_device___93 *);
	u8 (*setdcbx)(struct net_device___93 *, u8);
	int (*peer_getappinfo)(struct net_device___93 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___93 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___93 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___93 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___93 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___93 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct xdp_rxq_info___93 {
	struct net_device___93 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___93 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___93 *dev_rx;
};

struct netlink_callback___95 {
	struct sk_buff___94 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___95 *);
	int (*dump)(struct sk_buff___94 *, struct netlink_callback___95 *);
	int (*done)(struct netlink_callback___95 *);
	void *data;
	struct module___374 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___93 {
	int (*create)(struct sk_buff___94 *, struct net_device___93 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___94 *, unsigned char *);
	int (*cache)(const struct neighbour___73 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___93 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___93 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___93 *, int);
	int poll_owner;
	struct net_device___93 *dev;
	struct sk_buff___94 *gro_list;
	struct sk_buff___94 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___93 {
	struct net_device___93 *dev;
	struct Qdisc___85 *qdisc;
	struct Qdisc___85 *qdisc_sleeping;
	struct kobject___436 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___93 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide44;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___85 {
	struct sk_buff___94 *head;
	struct sk_buff___94 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___85;

struct Qdisc___85 {
	int (*enqueue)(struct sk_buff___94 *, struct Qdisc___85 *, struct sk_buff___94 **);
	struct sk_buff___94 * (*dequeue)(struct Qdisc___85 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___85 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___93 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___93 gso_skb;
	struct qdisc_skb_head___85 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___85 *next_sched;
	struct sk_buff_head___93 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___93 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___436 kobj;
	struct net_device___93 *dev;
	long: 64;
	struct xdp_rxq_info___93 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide45;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___93)(struct net_device___93 *, struct sk_buff___94 *, struct net_device___93 *);

struct netdev_bpf___93 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___83 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___83 *prog;
			const struct bpf_prog_offload_ops___83 *ops;
		} verifier;
		struct {
			struct bpf_prog___83 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___93 *offmap;
		};
		struct {
			struct xdp_umem___3 *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___93 {
	int (*xdo_dev_state_add)(struct xfrm_state___15 *);
	void (*xdo_dev_state_delete)(struct xfrm_state___15 *);
	void (*xdo_dev_state_free)(struct xfrm_state___15 *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___94 *, struct xfrm_state___15 *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state___15 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct xfrm_state_offload___15 {
	struct net_device___93 *dev;
	long unsigned int offload_handle;
	unsigned int num_exthdrs;
	u8 flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct xfrm_replay___15;

struct xfrm_type___15;

struct xfrm_mode___15;

struct xfrm_type_offload___15;

struct xfrm_state___15 {
	possible_net_t___95 xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	refcount_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
		u32 output_mark;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	const char *geniv;
	struct xfrm_encap_tmpl *encap;
	xfrm_address_t *coaddr;
	struct xfrm_state___15 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	const struct xfrm_replay___15 *repl;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct tasklet_hrtimer mtimer;
	struct xfrm_state_offload___15 xso;
	long int saved_tmo;
	long unsigned int lastused;
	struct page_frag___449 xfrag;
	const struct xfrm_type___15 *type;
	struct xfrm_mode___15 *inner_mode;
	struct xfrm_mode___15 *inner_mode_iaf;
	struct xfrm_mode___15 *outer_mode;
	const struct xfrm_type_offload___15 *type_offload;
	struct xfrm_sec_ctx___2 *security;
	void *data;
	u32 output_mark_mask;
	u32 if_id;
};

struct tlsdev_ops___93 {
	int (*tls_dev_add)(struct net_device___93 *, struct sock___73 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___93 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___93 *, struct sock___73 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide46;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___93 {
	int (*ndo_init)(struct net_device___93 *);
	void (*ndo_uninit)(struct net_device___93 *);
	int (*ndo_open)(struct net_device___93 *);
	int (*ndo_stop)(struct net_device___93 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___94 *, struct net_device___93 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___94 *, struct net_device___93 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___93 *, struct sk_buff___94 *, struct net_device___93 *, select_queue_fallback_t___93);
	void (*ndo_change_rx_flags)(struct net_device___93 *, int);
	void (*ndo_set_rx_mode)(struct net_device___93 *);
	int (*ndo_set_mac_address)(struct net_device___93 *, void *);
	int (*ndo_validate_addr)(struct net_device___93 *);
	int (*ndo_do_ioctl)(struct net_device___93 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___93 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___93 *, int);
	int (*ndo_neigh_setup)(struct net_device___93 *, struct neigh_parms___73 *);
	void (*ndo_tx_timeout)(struct net_device___93 *);
	void (*ndo_get_stats64)(struct net_device___93 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___93 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___93 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___93 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___93 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___93 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___93 *);
	int (*ndo_netpoll_setup)(struct net_device___93 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___93 *);
	int (*ndo_set_vf_mac)(struct net_device___93 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___93 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___93 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___93 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___93 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___93 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___93 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___93 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___93 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___93 *, int, struct sk_buff___94 *);
	int (*ndo_set_vf_guid)(struct net_device___93 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___93 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___93 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___93 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___93 *, const struct sk_buff___94 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___93 *, struct net_device___93 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___93 *, struct net_device___93 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___93 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___93 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___93 *, struct neighbour___73 *);
	void (*ndo_neigh_destroy)(struct net_device___93 *, struct neighbour___73 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___93 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___93 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide47;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___93 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___94 *, struct netlink_callback___95 *, struct net_device___93 *, struct net_device___93 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___93 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___93 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide48;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___94 *, u32, u32, struct net_device___93 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___93 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___93 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___93 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___93 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___93 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___93 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___93 *, struct net_device___93 *);
	void (*ndo_dfwd_del_station)(struct net_device___93 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___93 *);
	int (*ndo_set_tx_maxrate)(struct net_device___93 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___93 *);
	int (*ndo_change_proto_down)(struct net_device___93 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___93 *, struct sk_buff___94 *);
	void (*ndo_set_rx_headroom)(struct net_device___93 *, int);
	int (*ndo_bpf)(struct net_device___93 *, struct netdev_bpf___93 *);
	int (*ndo_xdp_xmit)(struct net_device___93 *, int, struct xdp_frame___93 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___93 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___93 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide49;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___73 {
	possible_net_t___95 net;
	struct net_device___93 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___73 *);
	void (*neigh_cleanup)(struct neighbour___73 *);
	struct neigh_table___73 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___73 {
	u32 (*l3mdev_fib_table)(const struct net_device___93 *);
	struct sk_buff___94 * (*l3mdev_l3_rcv)(struct net_device___93 *, struct sk_buff___94 *, u16);
	struct sk_buff___94 * (*l3mdev_l3_out)(struct net_device___93 *, struct sock___73 *, struct sk_buff___94 *, u16);
	struct dst_entry___73 * (*l3mdev_link_scope_lookup)(const struct net_device___93 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct ndisc_ops___44 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___93 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___93 *, struct neighbour___73 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___93 *, u8, struct neighbour___73 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___93 *, struct sk_buff___94 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___104 *, struct net_device___93 *, const struct prefix_info *, struct inet6_dev___44 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___44;

struct ifacaddr6___19;

struct inet6_dev___44 {
	struct net_device___93 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___44 *mc_list;
	struct ifmcaddr6___44 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___19 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	u8 rndid[8];
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___73 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
};

struct tcf_proto___85;

struct mini_Qdisc___85 {
	struct tcf_proto___85 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___85 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___93 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___104 *, struct net_device___93 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___93 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___93 *, struct list_head *);
	size_t (*get_size)(const struct net_device___93 *);
	int (*fill_info)(struct sk_buff___94 *, const struct net_device___93 *);
	size_t (*get_xstats_size)(const struct net_device___93 *);
	int (*fill_xstats)(struct sk_buff___94 *, const struct net_device___93 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___93 *, struct net_device___93 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___93 *, const struct net_device___93 *);
	int (*fill_slave_info)(struct sk_buff___94 *, const struct net_device___93 *, const struct net_device___93 *);
	struct net___104 * (*get_link_net)(const struct net_device___93 *);
	size_t (*get_linkxstats_size)(const struct net_device___93 *, int);
	int (*fill_linkxstats)(struct sk_buff___94 *, const struct net_device___93 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct offload_callbacks___12 {
	struct sk_buff___94 * (*gso_segment)(struct sk_buff___94 *, netdev_features_t);
	struct sk_buff___94 ** (*gro_receive)(struct sk_buff___94 **, struct sk_buff___94 *);
	int (*gro_complete)(struct sk_buff___94 *, int);
};

struct softnet_data___93 {
	struct list_head poll_list;
	struct sk_buff_head___93 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___93 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___85 *output_queue;
	struct Qdisc___85 **output_queue_tailp;
	struct sk_buff___94 *completion_queue;
	struct sk_buff_head___93 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___93 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___93 input_pkt_queue;
	struct napi_struct___93 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct in_ifaddr___9 {
	struct hlist_node hash;
	struct in_ifaddr___9 *ifa_next;
	struct in_device___9 *ifa_dev;
	struct callback_head callback_head;
	__be32 ifa_local;
	__be32 ifa_address;
	__be32 ifa_mask;
	__u32 ifa_rt_priority;
	__be32 ifa_broadcast;
	unsigned char ifa_scope;
	unsigned char ifa_prefixlen;
	__u32 ifa_flags;
	char ifa_label[16];
	__u32 ifa_valid_lft;
	__u32 ifa_preferred_lft;
	long unsigned int ifa_cstamp;
	long unsigned int ifa_tstamp;
};

struct gnet_dump___85 {
	spinlock_t *lock;
	struct sk_buff___94 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___85;

struct Qdisc_ops___85 {
	struct Qdisc_ops___85 *next;
	const struct Qdisc_class_ops___85 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___94 *, struct Qdisc___85 *, struct sk_buff___94 **);
	struct sk_buff___94 * (*dequeue)(struct Qdisc___85 *);
	struct sk_buff___94 * (*peek)(struct Qdisc___85 *);
	int (*init)(struct Qdisc___85 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___85 *);
	void (*destroy)(struct Qdisc___85 *);
	int (*change)(struct Qdisc___85 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___85 *);
	int (*change_tx_queue_len)(struct Qdisc___85 *, unsigned int);
	int (*dump)(struct Qdisc___85 *, struct sk_buff___94 *);
	int (*dump_stats)(struct Qdisc___85 *, struct gnet_dump___85 *);
	void (*ingress_block_set)(struct Qdisc___85 *, u32);
	void (*egress_block_set)(struct Qdisc___85 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___85 *);
	u32 (*egress_block_get)(struct Qdisc___85 *);
	struct module___374 *owner;
};

struct tcf_block___85;

struct Qdisc_class_ops___85 {
	unsigned int flags;
	struct netdev_queue___93 * (*select_queue)(struct Qdisc___85 *, struct tcmsg *);
	int (*graft)(struct Qdisc___85 *, long unsigned int, struct Qdisc___85 *, struct Qdisc___85 **, struct netlink_ext_ack *);
	struct Qdisc___85 * (*leaf)(struct Qdisc___85 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___85 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___85 *, u32);
	int (*change)(struct Qdisc___85 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___85 *, long unsigned int);
	void (*walk)(struct Qdisc___85 *, struct qdisc_walker *);
	struct tcf_block___85 * (*tcf_block)(struct Qdisc___85 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___85 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___85 *, long unsigned int);
	int (*dump)(struct Qdisc___85 *, long unsigned int, struct sk_buff___94 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___85 *, long unsigned int, struct gnet_dump___85 *);
};

struct tcf_chain___85;

struct tcf_block___85 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___104 *net;
	struct Qdisc___85 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___85 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___85;

struct tcf_proto_ops___85;

struct tcf_proto___85 {
	struct tcf_proto___85 *next;
	void *root;
	int (*classify)(struct sk_buff___94 *, const struct tcf_proto___85 *, struct tcf_result___85 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___85 *ops;
	struct tcf_chain___85 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___85 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___85 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___85 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___94 *, const struct tcf_proto___85 *, struct tcf_result___85 *);
	int (*init)(struct tcf_proto___85 *);
	void (*destroy)(struct tcf_proto___85 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___85 *, u32);
	void (*put)(struct tcf_proto___85 *, void *);
	int (*change)(struct net___104 *, struct sk_buff___94 *, struct tcf_proto___85 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___85 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___85 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___85 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___104 *, struct tcf_chain___85 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___104 *, struct tcf_proto___85 *, void *, struct sk_buff___94 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___94 *, struct net___104 *, void *);
	struct module___374 *owner;
	int flags;
};

struct tcf_chain___85 {
	struct mutex filter_chain_lock;
	struct tcf_proto___85 *filter_chain;
	struct list_head list;
	struct tcf_block___85 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___85 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___73 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___83 *prog;
};

struct bpf_redirect_info___83 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___298 *map;
	struct bpf_map___298 *map_to_flush;
	u32 kern_flags;
};

typedef struct poll_table_struct___287 poll_table___44;

struct pneigh_entry___73;

struct neigh_hash_table___73;

struct neigh_table___73 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___93 *, __u32 *);
	bool (*key_eq)(const struct neighbour___73 *, const void *);
	int (*constructor)(struct neighbour___73 *);
	int (*pconstructor)(struct pneigh_entry___73 *);
	void (*pdestructor)(struct pneigh_entry___73 *);
	void (*proxy_redo)(struct sk_buff___94 *);
	char *id;
	struct neigh_parms___73 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___93 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___73 *nht;
	struct pneigh_entry___73 **phash_buckets;
};

struct neigh_ops___73 {
	int family;
	void (*solicit)(struct neighbour___73 *, struct sk_buff___94 *);
	void (*error_report)(struct neighbour___73 *, struct sk_buff___94 *);
	int (*output)(struct neighbour___73 *, struct sk_buff___94 *);
	int (*connected_output)(struct neighbour___73 *, struct sk_buff___94 *);
};

struct pneigh_entry___73 {
	struct pneigh_entry___73 *next;
	possible_net_t___95 net;
	struct net_device___93 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___73 {
	struct neighbour___73 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___73 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___73 *ctarget;
	struct net___104 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___73 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___73 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___56;

struct timewait_sock_ops___52;

struct proto___73 {
	void (*close)(struct sock___73 *, long int);
	int (*pre_connect)(struct sock___73 *, struct sockaddr *, int);
	int (*connect)(struct sock___73 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___73 *, int);
	struct sock___73 * (*accept)(struct sock___73 *, int, int *, bool);
	int (*ioctl)(struct sock___73 *, int, long unsigned int);
	int (*init)(struct sock___73 *);
	void (*destroy)(struct sock___73 *);
	void (*shutdown)(struct sock___73 *, int);
	int (*setsockopt)(struct sock___73 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___73 *, int, int, char *, int *);
	void (*keepalive)(struct sock___73 *, int);
	int (*sendmsg)(struct sock___73 *, struct msghdr___76 *, size_t);
	int (*recvmsg)(struct sock___73 *, struct msghdr___76 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___73 *, struct page___449 *, int, size_t, int);
	int (*bind)(struct sock___73 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___73 *, struct sk_buff___94 *);
	void (*release_cb)(struct sock___73 *);
	int (*hash)(struct sock___73 *);
	void (*unhash)(struct sock___73 *);
	void (*rehash)(struct sock___73 *);
	int (*get_port)(struct sock___73 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___73 *);
	bool (*stream_memory_read)(const struct sock___73 *);
	void (*enter_memory_pressure)(struct sock___73 *);
	void (*leave_memory_pressure)(struct sock___73 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___56 *rsk_prot;
	struct timewait_sock_ops___52 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___374 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___73 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct xfrm_policy_queue___15 {
	struct sk_buff_head___93 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___15 {
	possible_net_t___95 xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	refcount_t refcnt;
	struct timer_list timer;
	atomic_t genid;
	u32 priority;
	u32 index;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___15 polq;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx___2 *security;
	struct xfrm_tmpl xfrm_vec[6];
	struct callback_head rcu;
	u32 if_id;
};

struct sock_reuseport___7 {
	struct callback_head rcu;
	u16 max_socks;
	u16 num_socks;
	unsigned int reuseport_id;
	bool bind_inany;
	struct bpf_prog___83 *prog;
	struct sock___73 *socks[0];
};

struct request_sock___57;

struct request_sock_ops___56 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___73 *, struct request_sock___57 *);
	void (*send_ack)(const struct sock___73 *, struct sk_buff___94 *, struct request_sock___57 *);
	void (*send_reset)(const struct sock___73 *, struct sk_buff___94 *);
	void (*destructor)(struct request_sock___57 *);
	void (*syn_ack_timeout)(const struct request_sock___57 *);
};

struct timewait_sock_ops___52 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___73 *, struct sock___73 *, void *);
	void (*twsk_destructor)(struct sock___73 *);
};

struct request_sock___57 {
	struct sock_common___73 __req_common;
	struct request_sock___57 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___56 *rsk_ops;
	struct sock___73 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct inet_cork___16 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___73 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
	__u16 gso_size;
	u64 transmit_time;
};

struct inet_cork_full___16 {
	struct inet_cork___16 base;
	struct flowi fl;
};

struct ipv6_pinfo___16;

struct inet_sock___16 {
	struct sock___73 sk;
	struct ipv6_pinfo___16 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	__be16 inet_sport;
	__u16 inet_id;
	struct ip_options_rcu *inet_opt;
	int rx_dst_ifindex;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 bind_address_no_port: 1;
	__u8 defer_connect: 1;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___16 cork;
};

struct ipv6_fl_socklist___15;

struct ipv6_pinfo___16 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
			__u16 recvfragsize: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 repflow: 1;
	__u16 pmtudisc: 3;
	__u16 padding: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u16 autoflowlabel: 1;
	__u16 autoflowlabel_set: 1;
	__u8 min_hopcount;
	__u8 tclass;
	__be32 rcv_flowinfo;
	__u32 dst_cookie;
	__u32 rx_dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___15 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___94 *pktoptions;
	struct sk_buff___94 *rxpmtu;
	struct inet6_cork cork;
};

struct udp_sock {
	struct inet_sock___16 inet;
	int pending;
	unsigned int corkflag;
	__u8 encap_type;
	unsigned char no_check6_tx: 1;
	unsigned char no_check6_rx: 1;
	__u16 len;
	__u16 gso_size;
	__u16 pcslen;
	__u16 pcrlen;
	__u8 pcflag;
	__u8 unused[3];
	int (*encap_rcv)(struct sock___73 *, struct sk_buff___94 *);
	int (*encap_err_lookup)(struct sock___73 *, struct sk_buff___94 *);
	void (*encap_destroy)(struct sock___73 *);
	struct sk_buff___94 ** (*gro_receive)(struct sock___73 *, struct sk_buff___94 **, struct sk_buff___94 *);
	int (*gro_complete)(struct sock___73 *, struct sk_buff___94 *, int);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___93 reader_queue;
	int forward_deficit;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ip6_flowlabel___15;

struct ipv6_fl_socklist___15 {
	struct ipv6_fl_socklist___15 *next;
	struct ip6_flowlabel___15 *fl;
	struct callback_head rcu;
};

struct ifmcaddr6___44 {
	struct in6_addr mca_addr;
	struct inet6_dev___44 *idev;
	struct ifmcaddr6___44 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___19 {
	struct in6_addr aca_addr;
	struct fib6_info___19 *aca_rt;
	struct ifacaddr6___19 *aca_next;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct ip6_ra_chain___44 {
	struct ip6_ra_chain___44 *next;
	struct sock___73 *sk;
	int sel;
	void (*destructor)(struct sock___73 *);
};

struct ip6_flowlabel___15 {
	struct ip6_flowlabel___15 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___250 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___104 *fl_net;
};

struct rtable___11 {
	struct dst_entry___73 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	__be32 rt_gateway;
	u32 rt_mtu_locked: 1;
	u32 rt_pmtu: 31;
	struct list_head rt_uncached;
	struct uncached_list *rt_uncached_list;
};

struct xfrm_replay___15 {
	void (*advance)(struct xfrm_state___15 *, __be32);
	int (*check)(struct xfrm_state___15 *, struct sk_buff___94 *, __be32);
	int (*recheck)(struct xfrm_state___15 *, struct sk_buff___94 *, __be32);
	void (*notify)(struct xfrm_state___15 *, int);
	int (*overflow)(struct xfrm_state___15 *, struct sk_buff___94 *);
};

struct xfrm_type___15 {
	char *description;
	struct module___374 *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___15 *);
	void (*destructor)(struct xfrm_state___15 *);
	int (*input)(struct xfrm_state___15 *, struct sk_buff___94 *);
	int (*output)(struct xfrm_state___15 *, struct sk_buff___94 *);
	int (*reject)(struct xfrm_state___15 *, struct sk_buff___94 *, const struct flowi *);
	int (*hdr_offset)(struct xfrm_state___15 *, struct sk_buff___94 *, u8 **);
	u32 (*get_mtu)(struct xfrm_state___15 *, int);
};

struct xfrm_state_afinfo___15;

struct xfrm_mode___15 {
	int (*input2)(struct xfrm_state___15 *, struct sk_buff___94 *);
	int (*input)(struct xfrm_state___15 *, struct sk_buff___94 *);
	int (*output2)(struct xfrm_state___15 *, struct sk_buff___94 *);
	int (*output)(struct xfrm_state___15 *, struct sk_buff___94 *);
	struct sk_buff___94 * (*gso_segment)(struct xfrm_state___15 *, struct sk_buff___94 *, netdev_features_t);
	void (*xmit)(struct xfrm_state___15 *, struct sk_buff___94 *);
	struct xfrm_state_afinfo___15 *afinfo;
	struct module___374 *owner;
	unsigned int encap;
	int flags;
};

struct xfrm_type_offload___15 {
	char *description;
	struct module___374 *owner;
	u8 proto;
	void (*encap)(struct xfrm_state___15 *, struct sk_buff___94 *);
	int (*input_tail)(struct xfrm_state___15 *, struct sk_buff___94 *);
	int (*xmit)(struct xfrm_state___15 *, struct sk_buff___94 *, netdev_features_t);
};

struct xfrm_state_afinfo___15 {
	unsigned int family;
	unsigned int proto;
	__be16 eth_proto;
	struct module___374 *owner;
	const struct xfrm_type___15 *type_map[256];
	const struct xfrm_type_offload___15 *type_offload_map[256];
	struct xfrm_mode___15 *mode_map[5];
	int (*init_flags)(struct xfrm_state___15 *);
	void (*init_tempsel)(struct xfrm_selector *, const struct flowi *);
	void (*init_temprop)(struct xfrm_state___15 *, const struct xfrm_tmpl *, const xfrm_address_t *, const xfrm_address_t *);
	int (*tmpl_sort)(struct xfrm_tmpl **, struct xfrm_tmpl **, int);
	int (*state_sort)(struct xfrm_state___15 **, struct xfrm_state___15 **, int);
	int (*output)(struct net___104 *, struct sock___73 *, struct sk_buff___94 *);
	int (*output_finish)(struct sock___73 *, struct sk_buff___94 *);
	int (*extract_input)(struct xfrm_state___15 *, struct sk_buff___94 *);
	int (*extract_output)(struct xfrm_state___15 *, struct sk_buff___94 *);
	int (*transport_finish)(struct sk_buff___94 *, int);
	void (*local_error)(struct sk_buff___94 *, u32);
};

struct udp_skb_cb {
	union {
		struct inet_skb_parm h4;
		struct inet6_skb_parm h6;
	} header;
	__u16 cscov;
	__u8 partial_cov;
};

struct udp_dev_scratch {
	u32 _tsize_state;
	u16 len;
	bool is_linear;
	bool csum_unnecessary;
};

struct udp_seq_afinfo {
	sa_family_t family;
	struct udp_table *udp_table;
};

struct udp_iter_state {
	struct seq_net_private___9 p;
	int bucket;
};

struct net_protocol___10 {
	int (*early_demux)(struct sk_buff___94 *);
	int (*early_demux_handler)(struct sk_buff___94 *);
	int (*handler)(struct sk_buff___94 *);
	void (*err_handler)(struct sk_buff___94 *, u32);
	unsigned int no_policy: 1;
	unsigned int netns_ok: 1;
	unsigned int icmp_strict_tag_validation: 1;
};

struct inet6_protocol___10 {
	void (*early_demux)(struct sk_buff___94 *);
	void (*early_demux_handler)(struct sk_buff___94 *);
	int (*handler)(struct sk_buff___94 *);
	void (*err_handler)(struct sk_buff___94 *, struct inet6_skb_parm *, u8, u8, int, __be32);
	unsigned int flags;
};

struct net_offload___10 {
	struct offload_callbacks___12 callbacks;
	unsigned int flags;
};

struct ipv6_stub___12 {
	int (*ipv6_sock_mc_join)(struct sock___73 *, int, const struct in6_addr *);
	int (*ipv6_sock_mc_drop)(struct sock___73 *, int, const struct in6_addr *);
	int (*ipv6_dst_lookup)(struct net___104 *, struct sock___73 *, struct dst_entry___73 **, struct flowi6 *);
	struct fib6_table___19 * (*fib6_get_table)(struct net___104 *, u32);
	struct fib6_info___19 * (*fib6_lookup)(struct net___104 *, int, struct flowi6 *, int);
	struct fib6_info___19 * (*fib6_table_lookup)(struct net___104 *, struct fib6_table___19 *, int, struct flowi6 *, int);
	struct fib6_info___19 * (*fib6_multipath_select)(const struct net___104 *, struct fib6_info___19 *, struct flowi6 *, int, const struct sk_buff___94 *, int);
	u32 (*ip6_mtu_from_fib6)(struct fib6_info___19 *, struct in6_addr *, struct in6_addr *);
	void (*udpv6_encap_enable)();
	void (*ndisc_send_na)(struct net_device___93 *, const struct in6_addr *, const struct in6_addr *, bool, bool, bool, bool);
	struct neigh_table___73 *nd_tbl;
};

struct ipv6_bpf_stub___12 {
	int (*inet6_bind)(struct sock___73 *, struct sockaddr *, int, bool, bool);
	struct sock___73 * (*udp6_lib_lookup)(struct net___104 *, const struct in6_addr *, __be16, const struct in6_addr *, __be16, int, int, struct udp_table *, struct sk_buff___94 *);
};

struct udp_sock___2 {
	struct inet_sock___15 inet;
	int pending;
	unsigned int corkflag;
	__u8 encap_type;
	unsigned char no_check6_tx: 1;
	unsigned char no_check6_rx: 1;
	__u16 len;
	__u16 gso_size;
	__u16 pcslen;
	__u16 pcrlen;
	__u8 pcflag;
	__u8 unused[3];
	int (*encap_rcv)(struct sock___72 *, struct sk_buff___93 *);
	int (*encap_err_lookup)(struct sock___72 *, struct sk_buff___93 *);
	void (*encap_destroy)(struct sock___72 *);
	struct sk_buff___93 ** (*gro_receive)(struct sock___72 *, struct sk_buff___93 **, struct sk_buff___93 *);
	int (*gro_complete)(struct sock___72 *, struct sk_buff___93 *, int);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___92 reader_queue;
	int forward_deficit;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct inet_protosw {
	struct list_head list;
	short unsigned int type;
	short unsigned int protocol;
	struct proto___72 *prot;
	const struct proto_ops___73 *ops;
	unsigned char flags;
};

typedef struct sk_buff___93 ** (*gro_receive_sk_t)(struct sock___72 *, struct sk_buff___93 **, struct sk_buff___93 *);

typedef struct sock___72 * (*udp_lookup_t)(struct sk_buff___93 *, __be16, __be16);

struct netdev_notifier_info___8 {
	struct net_device___84 *dev;
	struct netlink_ext_ack *extack;
};

struct netdev_notifier_change_info___2 {
	struct netdev_notifier_info___8 info;
	unsigned int flags_changed;
};

struct arpreq {
	struct sockaddr arp_pa;
	struct sockaddr arp_ha;
	int arp_flags;
	struct sockaddr arp_netmask;
	char arp_dev[16];
};

struct neigh_seq_state___2 {
	struct seq_net_private___7 p;
	struct neigh_table___64 *tbl;
	struct neigh_hash_table___64 *nht;
	void * (*neigh_sub_iter)(struct neigh_seq_state___2 *, struct neighbour___64 *, loff_t *);
	unsigned int bucket;
	unsigned int flags;
};

typedef struct {
	char ax25_call[7];
} ax25_address;

enum {
	AX25_VALUES_IPDEFMODE = 0,
	AX25_VALUES_AXDEFMODE = 1,
	AX25_VALUES_BACKOFF = 2,
	AX25_VALUES_CONMODE = 3,
	AX25_VALUES_WINDOW = 4,
	AX25_VALUES_EWINDOW = 5,
	AX25_VALUES_T1 = 6,
	AX25_VALUES_T2 = 7,
	AX25_VALUES_T3 = 8,
	AX25_VALUES_IDLE = 9,
	AX25_VALUES_N2 = 10,
	AX25_VALUES_PACLEN = 11,
	AX25_VALUES_PROTOCOL = 12,
	AX25_VALUES_DS_TIMEOUT = 13,
	AX25_MAX_VALUES = 14,
};

struct ax25_dev {
	struct ax25_dev *next;
	struct net_device___84 *dev;
	struct net_device___84 *forward;
	struct ctl_table_header *sysheader;
	int values[14];
};

typedef struct ax25_dev ax25_dev;

enum {
	XFRM_LOOKUP_ICMP = 1,
	XFRM_LOOKUP_QUEUE = 2,
	XFRM_LOOKUP_KEEP_DST_REF = 4,
};

struct pingv6_ops {
	int (*ipv6_recv_error)(struct sock___65 *, struct msghdr___67 *, int, int *);
	void (*ip6_datagram_recv_common_ctl)(struct sock___65 *, struct msghdr___67 *, struct sk_buff___85 *);
	void (*ip6_datagram_recv_specific_ctl)(struct sock___65 *, struct msghdr___67 *, struct sk_buff___85 *);
	int (*icmpv6_err_convert)(u8, u8, int *);
	void (*ipv6_icmp_error)(struct sock___65 *, struct sk_buff___85 *, int, __be16, u32, u8 *);
	int (*ipv6_chk_addr)(struct net___95 *, const struct in6_addr *, const struct net_device___84 *, int);
};

struct icmp_bxm {
	struct sk_buff___85 *skb;
	int offset;
	int data_len;
	struct {
		struct icmphdr icmph;
		__be32 times[3];
	} data;
	int head_len;
	struct ip_options_data replyopts;
};

struct icmp_control {
	bool (*handler)(struct sk_buff___85 *);
	short int error;
};

struct module___375;

struct file___449;

struct kiocb___449;

struct iov_iter___216;

struct poll_table_struct___288;

struct vm_area_struct___450;

struct inode___449;

struct file_lock___449;

struct page___450;

struct pipe_inode_info___130;

struct seq_file___388;

struct file_operations___449 {
	struct module___375 *owner;
	loff_t (*llseek)(struct file___449 *, loff_t, int);
	ssize_t (*read)(struct file___449 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___449 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___449 *, struct iov_iter___216 *);
	ssize_t (*write_iter)(struct kiocb___449 *, struct iov_iter___216 *);
	int (*iopoll)(struct kiocb___449 *, bool);
	int (*iterate)(struct file___449 *, struct dir_context *);
	int (*iterate_shared)(struct file___449 *, struct dir_context *);
	__poll_t (*poll)(struct file___449 *, struct poll_table_struct___288 *);
	long int (*unlocked_ioctl)(struct file___449 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___449 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___449 *, struct vm_area_struct___450 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___449 *, struct file___449 *);
	int (*flush)(struct file___449 *, fl_owner_t);
	int (*release)(struct inode___449 *, struct file___449 *);
	int (*fsync)(struct file___449 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___449 *, int);
	int (*lock)(struct file___449 *, int, struct file_lock___449 *);
	ssize_t (*sendpage)(struct file___449 *, struct page___450 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___449 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___449 *, int, struct file_lock___449 *);
	ssize_t (*splice_write)(struct pipe_inode_info___130 *, struct file___449 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___449 *, loff_t *, struct pipe_inode_info___130 *, size_t, unsigned int);
	int (*setlease)(struct file___449 *, long int, struct file_lock___449 **, void **);
	long int (*fallocate)(struct file___449 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___388 *, struct file___449 *);
	ssize_t (*copy_file_range)(struct file___449 *, loff_t, struct file___449 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___449 *, loff_t, struct file___449 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___449 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___450 {
	u64 seqnum;
	struct vm_area_struct___450 *vmas[4];
};

struct page_frag___450 {
	struct page___450 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___450;

struct mem_cgroup___182;

struct cred___417;

struct nsproxy___344;

struct signal_struct___324;

struct bio_list___239;

struct backing_dev_info___239;

struct css_set___298;

struct vm_struct___353;

struct task_struct___451 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___451 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___450 *mm;
	struct mm_struct___450 *active_mm;
	struct vmacache___450 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___451 *real_parent;
	struct task_struct___451 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___451 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___182 *active_memcg;
	long int rh_reserved2;
	struct pid___250 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___250 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___250 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___417 *ptracer_cred;
	const struct cred___417 *real_cred;
	const struct cred___417 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___344 *nsproxy;
	struct signal_struct___324 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___451 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___239 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___239 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___298 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___130 *splice_pipe;
	struct page_frag___450 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___182 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___451 *oom_reaper_list;
	struct vm_struct___353 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___156 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rw_semaphore___451 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___451 *owner;
};

struct key___417;

struct ucounts___314;

struct user_namespace___314 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___314 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___29 ns;
	long unsigned int flags;
	struct key___417 *persistent_keyring_register;
	struct rw_semaphore___451 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___314 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct secondary_data___451 {
	void *stack;
	struct task_struct___451 *task;
	long int status;
};

typedef struct page___450 *pgtable_t___450;

struct address_space___449;

struct dev_pagemap___437;

struct page___450 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___449 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___450 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___450 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___450 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___437 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___182 *mem_cgroup;
};

struct user_struct___417 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___417 *uid_keyring;
	struct key___417 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___437;

struct vm_area_struct___450 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___450 *vm_next;
	struct vm_area_struct___450 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___450 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___437 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___449 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___450;

struct mm_struct___450 {
	struct {
		struct vm_area_struct___450 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___449 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___451 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___450 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___451 *owner;
		struct user_namespace___314 *user_ns;
		struct file___449 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___450 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup___298;

struct cgroup_subsys___298;

struct cgroup_subsys_state___298 {
	struct cgroup___298 *cgroup;
	struct cgroup_subsys___298 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___298 *parent;
};

struct kernfs_node___444;

struct cgroup_file___298 {
	struct kernfs_node___444 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___182;

struct mem_cgroup___182 {
	struct cgroup_subsys_state___298 css;
	struct mem_cgroup_id___13 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___298 events_file;
	struct cgroup_file___298 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___451 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___182 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cred___417 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___417 *session_keyring;
	struct key___417 *process_keyring;
	struct key___417 *thread_keyring;
	struct key___417 *request_key_auth;
	void *security;
	struct user_struct___417 *user;
	struct user_namespace___314 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___105;

struct cgroup_namespace___298;

struct nsproxy___344 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net___105 *net_ns;
	struct cgroup_namespace___298 *cgroup_ns;
};

struct signal_struct___324 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___451 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___451 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___250 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___250 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___450 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___250 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___239;

struct bio_list___239 {
	struct bio___239 *head;
	struct bio___239 *tail;
};

struct bdi_writeback_congested___239;

struct bdi_writeback___239 {
	struct backing_dev_info___239 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___239 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___298 *memcg_css;
	struct cgroup_subsys_state___298 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___417;

struct dentry___449;

struct backing_dev_info___239 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___239 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___417 *dev;
	struct device___417 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___449 *debug_dir;
	struct dentry___449 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___298 {
	struct cgroup_subsys_state___298 *subsys[13];
	refcount_t refcount;
	struct css_set___298 *dom_cset;
	struct cgroup___298 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___298 *mg_src_cgrp;
	struct cgroup___298 *mg_dst_cgrp;
	struct css_set___298 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___449;

struct pipe_buffer___130;

struct pipe_inode_info___130 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___450 *tmp_page;
	struct fasync_struct___449 *fasync_readers;
	struct fasync_struct___449 *fasync_writers;
	struct pipe_buffer___130 *bufs;
	struct user_struct___417 *user;
};

struct vm_struct___353 {
	struct vm_struct___353 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___450 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___336 {
	struct task_struct___451 task;
	long unsigned int stack[8192];
};

struct address_space_operations___449;

struct address_space___449 {
	struct inode___449 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___451 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___449 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___437)(struct vm_area_struct___450 *, long unsigned int, const struct page___450 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___437)(struct page___450 *, void *);

struct dev_pagemap___437 {
	dev_page_fault_t___437 page_fault;
	dev_page_free_t___437 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___417 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___450 {
	struct vfsmount *mnt;
	struct dentry___449 *dentry;
};

struct file___449 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___450 f_path;
	struct inode___449 *f_inode;
	const struct file_operations___449 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___250 f_owner;
	const struct cred___417 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___449 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___437;

struct vm_operations_struct___437 {
	void (*open)(struct vm_area_struct___450 *);
	void (*close)(struct vm_area_struct___450 *);
	int (*split)(struct vm_area_struct___450 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___450 *);
	vm_fault_t (*fault)(struct vm_fault___437 *);
	vm_fault_t (*huge_fault)(struct vm_fault___437 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___437 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___450 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___437 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___437 *);
	int (*access)(struct vm_area_struct___450 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___450 *);
	int (*set_policy)(struct vm_area_struct___450 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___450 *, long unsigned int);
	struct page___450 * (*find_special_page)(struct vm_area_struct___450 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___450 {
	struct task_struct___451 *task;
	struct core_thread___450 *next;
};

struct core_state___450 {
	atomic_t nr_threads;
	struct core_thread___450 dumper;
	struct completion startup;
};

struct vm_fault___437 {
	struct vm_area_struct___450 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___450 *cow_page;
	struct mem_cgroup___182 *memcg;
	struct page___450 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___450 prealloc_pte;
};

struct pglist_data___450;

struct lruvec___450 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___450 *pgdat;
};

struct zone___450 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___450 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___450 {
	struct zone___450 *zone;
	int zone_idx;
};

struct zonelist___450 {
	struct zoneref___450 _zonerefs[25];
};

struct pglist_data___450 {
	struct zone___450 node_zones[3];
	struct zonelist___450 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___451 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___451 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___450 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___450 {
	struct rw_semaphore___451 rwsem;
	struct notifier_block *head;
};

struct kernfs_root___443;

struct kernfs_elem_dir___443 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___443 *root;
};

struct kernfs_syscall_ops___443;

struct kernfs_root___443 {
	struct kernfs_node___444 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___443 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___443 {
	struct kernfs_node___444 *target_kn;
};

struct kernfs_ops___443;

struct kernfs_elem_attr___443 {
	const struct kernfs_ops___443 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___444 *notify_next;
};

struct kernfs_node___444 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___444 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___443 dir;
		struct kernfs_elem_symlink___443 symlink;
		struct kernfs_elem_attr___443 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___443;

struct kernfs_ops___443 {
	int (*open)(struct kernfs_open_file___443 *);
	void (*release)(struct kernfs_open_file___443 *);
	int (*seq_show)(struct seq_file___388 *, void *);
	void * (*seq_start)(struct seq_file___388 *, loff_t *);
	void * (*seq_next)(struct seq_file___388 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___388 *, void *);
	ssize_t (*read)(struct kernfs_open_file___443 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___443 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___443 *, struct vm_area_struct___450 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___443 *, struct poll_table_struct___288 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___443 {
	int (*remount_fs)(struct kernfs_root___443 *, int *, char *);
	int (*show_options)(struct seq_file___388 *, struct kernfs_root___443 *);
	int (*mkdir)(struct kernfs_node___444 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___444 *);
	int (*rename)(struct kernfs_node___444 *, struct kernfs_node___444 *, const char *);
	int (*show_path)(struct seq_file___388 *, struct kernfs_node___444 *, struct kernfs_root___443 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___388;

struct seq_file___388 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___388 *op;
	int poll_event;
	const struct file___449 *file;
	void *private;
};

struct kernfs_open_file___443 {
	struct kernfs_node___444 *kn;
	struct file___449 *file;
	struct seq_file___388 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___437 *vm_ops;
};

typedef void (*poll_queue_proc___298)(struct file___449 *, wait_queue_head_t *, struct poll_table_struct___288 *);

struct poll_table_struct___288 {
	poll_queue_proc___298 _qproc;
	__poll_t _key;
};

struct sock___74;

struct kobj_ns_type_operations___74 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___74 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___105 *net;
} possible_net_t___96;

struct proto___74;

struct sock_common___74 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___74 *skc_prot;
	possible_net_t___96 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___74 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___95;

struct sk_buff_head___94 {
	struct sk_buff___95 *next;
	struct sk_buff___95 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___74;

struct socket_wq___75;

struct dst_entry___74;

struct socket___76;

struct net_device___94;

struct sock___74 {
	struct sock_common___74 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___94 sk_error_queue;
	struct sk_buff_head___94 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___95 *head;
		struct sk_buff___95 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___74 *sk_filter;
	union {
		struct socket_wq___75 *sk_wq;
		struct socket_wq___75 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___74 *sk_rx_dst;
	struct dst_entry___74 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___95 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___94 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___450 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___74 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___250 *sk_peer_pid;
	const struct cred___417 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___76 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___182 *sk_memcg;
	void (*sk_state_change)(struct sock___74 *);
	void (*sk_data_ready)(struct sock___74 *);
	void (*sk_write_space)(struct sock___74 *);
	void (*sk_error_report)(struct sock___74 *);
	int (*sk_backlog_rcv)(struct sock___74 *, struct sk_buff___95 *);
	struct sk_buff___95 * (*sk_validate_xmit_skb)(struct sock___74 *, struct net_device___94 *, struct sk_buff___95 *);
	void (*sk_destruct)(struct sock___74 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kobject___437;

struct bin_attribute___413;

struct attribute_group___414 {
	const char *name;
	umode_t (*is_visible)(struct kobject___437 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___437 *, struct bin_attribute___413 *, int);
	struct attribute **attrs;
	struct bin_attribute___413 **bin_attrs;
};

struct kset___436;

struct kobj_type___436;

struct kobject___437 {
	const char *name;
	struct list_head entry;
	struct kobject___437 *parent;
	struct kset___436 *kset;
	struct kobj_type___436 *ktype;
	struct kernfs_node___444 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___413 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___449 *, struct kobject___437 *, struct bin_attribute___413 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___449 *, struct kobject___437 *, struct bin_attribute___413 *, char *, loff_t, size_t);
	int (*mmap)(struct file___449 *, struct kobject___437 *, struct bin_attribute___413 *, struct vm_area_struct___450 *);
};

struct sysfs_ops___436 {
	ssize_t (*show)(struct kobject___437 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___437 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___436;

struct kset___436 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___437 kobj;
	const struct kset_uevent_ops___436 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___436 {
	void (*release)(struct kobject___437 *);
	const struct sysfs_ops___436 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___74 * (*child_ns_type)(struct kobject___437 *);
	const void * (*namespace)(struct kobject___437 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___436 {
	int (* const filter)(struct kset___436 *, struct kobject___437 *);
	const char * (* const name)(struct kset___436 *, struct kobject___437 *);
	int (* const uevent)(struct kset___436 *, struct kobject___437 *, struct kobj_uevent_env *);
};

struct kobj_attribute___427 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___437 *, struct kobj_attribute___427 *, char *);
	ssize_t (*store)(struct kobject___437 *, struct kobj_attribute___427 *, const char *, size_t);
};

struct kernel_param___375;

struct kernel_param_ops___375 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___375 *);
	int (*get)(char *, const struct kernel_param___375 *);
	void (*free)(void *);
};

struct kparam_array___375;

struct kernel_param___375 {
	const char *name;
	struct module___375 *mod;
	const struct kernel_param_ops___375 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___375 *arr;
	};
};

struct kparam_array___375 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___375 *ops;
	void *elem;
};

struct module_kobject___375 {
	struct kobject___437 kobj;
	struct module___375 *mod;
	struct kobject___437 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___375 {
	struct module___375 *mod;
	struct latch_tree_node node;
};

struct module_layout___375 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___375 mtn;
};

struct module_attribute___375;

struct module___375 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___375 mkobj;
	struct module_attribute___375 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___437 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___375 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___375 core_layout;
	struct module_layout___375 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___375 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___375 *, struct module_kobject___375 *, char *);
	ssize_t (*store)(struct module_attribute___375 *, struct module_kobject___375 *, const char *, size_t);
	void (*setup)(struct module___375 *, const char *);
	int (*test)(struct module___375 *);
	void (*free)(struct module___375 *);
};

typedef int (*key_restrict_link_func_t___418)(struct key___417 *, const struct key_type *, const union key_payload *, struct key___417 *);

struct key_restriction___417;

struct key___417 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___451 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___417 *restrict_link;
};

struct key_restriction___417 {
	key_restrict_link_func_t___418 check;
	struct key___417 *key;
	struct key_type *keytype;
};

struct shrink_control___182 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___182 *memcg;
};

struct shrinker___182 {
	long unsigned int (*count_objects)(struct shrinker___182 *, struct shrink_control___182 *);
	long unsigned int (*scan_objects)(struct shrinker___182 *, struct shrink_control___182 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct dev_pm_info___417 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___417 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___417;

struct bus_type___417;

struct device_driver___417;

struct dev_pm_domain___417;

struct dma_map_ops___189;

struct fwnode_handle___337;

struct class___417;

struct device___417 {
	struct device___417 *parent;
	struct device_private *p;
	struct kobject___437 kobj;
	const char *init_name;
	const struct device_type___417 *type;
	struct mutex mutex;
	struct bus_type___417 *bus;
	struct device_driver___417 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___417 power;
	struct dev_pm_domain___417 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___189 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___337 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___417 *class;
	const struct attribute_group___414 **groups;
	void (*release)(struct device___417 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___449;

struct super_block___449;

struct dentry___449 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___449 *d_parent;
	struct qstr d_name;
	struct inode___449 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___449 *d_op;
	struct super_block___449 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___449;

struct block_device___449;

struct inode___449 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___449 *i_op;
	struct super_block___449 *i_sb;
	struct address_space___449 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___451 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___239 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___449 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___449 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___130 *i_pipe;
		struct block_device___449 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___449 {
	int (*d_revalidate)(struct dentry___449 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___449 *, unsigned int);
	int (*d_hash)(const struct dentry___449 *, struct qstr *);
	int (*d_compare)(const struct dentry___449 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___449 *);
	int (*d_init)(struct dentry___449 *);
	void (*d_release)(struct dentry___449 *);
	void (*d_prune)(struct dentry___449 *);
	void (*d_iput)(struct dentry___449 *, struct inode___449 *);
	char * (*d_dname)(struct dentry___449 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___450 *);
	int (*d_manage)(const struct path___450 *, bool);
	struct dentry___449 * (*d_real)(struct dentry___449 *, const struct inode___449 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___449;

struct mem_dqinfo___449 {
	struct quota_format_type___449 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___449;

struct quota_info___449 {
	unsigned int flags;
	struct rw_semaphore___451 dqio_sem;
	struct inode___449 *files[3];
	struct mem_dqinfo___449 info[3];
	const struct quota_format_ops___449 *ops[3];
};

struct rcuwait___449 {
	struct task_struct___451 *task;
};

struct percpu_rw_semaphore___449 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___451 rw_sem;
	struct rcuwait___449 writer;
	int readers_block;
};

struct sb_writers___449 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___449 rw_sem[3];
};

struct file_system_type___449;

struct super_operations___449;

struct dquot_operations___449;

struct quotactl_ops___449;

struct super_block___449 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___449 *s_type;
	const struct super_operations___449 *s_op;
	const struct dquot_operations___449 *dq_op;
	const struct quotactl_ops___449 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___449 *s_root;
	struct rw_semaphore___451 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___449 *s_bdev;
	struct backing_dev_info___239 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___449 s_dquot;
	struct sb_writers___449 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___449 *s_d_op;
	int cleancache_poolid;
	struct shrinker___182 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___314 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___449 {
	struct file___449 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___449 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___449 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___449 *ia_file;
};

struct dquot___449 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___449 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___449 {
	int qf_fmt_id;
	const struct quota_format_ops___449 *qf_ops;
	struct module___375 *qf_owner;
	struct quota_format_type___449 *qf_next;
};

struct quota_format_ops___449 {
	int (*check_quota_file)(struct super_block___449 *, int);
	int (*read_file_info)(struct super_block___449 *, int);
	int (*write_file_info)(struct super_block___449 *, int);
	int (*free_file_info)(struct super_block___449 *, int);
	int (*read_dqblk)(struct dquot___449 *);
	int (*commit_dqblk)(struct dquot___449 *);
	int (*release_dqblk)(struct dquot___449 *);
	int (*get_next_id)(struct super_block___449 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___449 {
	int (*write_dquot)(struct dquot___449 *);
	struct dquot___449 * (*alloc_dquot)(struct super_block___449 *, int);
	void (*destroy_dquot)(struct dquot___449 *);
	int (*acquire_dquot)(struct dquot___449 *);
	int (*release_dquot)(struct dquot___449 *);
	int (*mark_dirty)(struct dquot___449 *);
	int (*write_info)(struct super_block___449 *, int);
	qsize_t * (*get_reserved_space)(struct inode___449 *);
	int (*get_projid)(struct inode___449 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___449 *, qsize_t *);
	int (*get_next_id)(struct super_block___449 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___449 {
	int (*quota_on)(struct super_block___449 *, int, int, const struct path___450 *);
	int (*quota_off)(struct super_block___449 *, int);
	int (*quota_enable)(struct super_block___449 *, unsigned int);
	int (*quota_disable)(struct super_block___449 *, unsigned int);
	int (*quota_sync)(struct super_block___449 *, int);
	int (*set_info)(struct super_block___449 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___449 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___449 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___449 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___449 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___449 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___202;

struct address_space_operations___449 {
	int (*writepage)(struct page___450 *, struct writeback_control___202 *);
	int (*readpage)(struct file___449 *, struct page___450 *);
	int (*writepages)(struct address_space___449 *, struct writeback_control___202 *);
	int (*set_page_dirty)(struct page___450 *);
	int (*readpages)(struct file___449 *, struct address_space___449 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___449 *, struct address_space___449 *, loff_t, unsigned int, unsigned int, struct page___450 **, void **);
	int (*write_end)(struct file___449 *, struct address_space___449 *, loff_t, unsigned int, unsigned int, struct page___450 *, void *);
	sector_t (*bmap)(struct address_space___449 *, sector_t);
	void (*invalidatepage)(struct page___450 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___450 *, gfp_t);
	void (*freepage)(struct page___450 *);
	ssize_t (*direct_IO)(struct kiocb___449 *, struct iov_iter___216 *);
	int (*migratepage)(struct address_space___449 *, struct page___450 *, struct page___450 *, enum migrate_mode);
	bool (*isolate_page)(struct page___450 *, isolate_mode_t);
	void (*putback_page)(struct page___450 *);
	int (*launder_page)(struct page___450 *);
	int (*is_partially_uptodate)(struct page___450 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___450 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___449 *, struct page___450 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___449 *, sector_t *);
	void (*swap_deactivate)(struct file___449 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___202 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___239 *wb;
	struct inode___449 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___241;

struct iov_iter___216 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___241 *bvec;
		struct pipe_inode_info___130 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___449 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___449 *bd_inode;
	struct super_block___449 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___449 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___239 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___449 {
	struct dentry___449 * (*lookup)(struct inode___449 *, struct dentry___449 *, unsigned int);
	const char * (*get_link)(struct dentry___449 *, struct inode___449 *, struct delayed_call *);
	int (*permission)(struct inode___449 *, int);
	struct posix_acl * (*get_acl)(struct inode___449 *, int);
	int (*readlink)(struct dentry___449 *, char *, int);
	int (*create)(struct inode___449 *, struct dentry___449 *, umode_t, bool);
	int (*link)(struct dentry___449 *, struct inode___449 *, struct dentry___449 *);
	int (*unlink)(struct inode___449 *, struct dentry___449 *);
	int (*symlink)(struct inode___449 *, struct dentry___449 *, const char *);
	int (*mkdir)(struct inode___449 *, struct dentry___449 *, umode_t);
	int (*rmdir)(struct inode___449 *, struct dentry___449 *);
	int (*mknod)(struct inode___449 *, struct dentry___449 *, umode_t, dev_t);
	int (*rename)(struct inode___449 *, struct dentry___449 *, struct inode___449 *, struct dentry___449 *, unsigned int);
	int (*setattr)(struct dentry___449 *, struct iattr___449 *);
	int (*getattr)(const struct path___450 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___449 *, char *, size_t);
	int (*fiemap)(struct inode___449 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___449 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___449 *, struct dentry___449 *, struct file___449 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___449 *, struct dentry___449 *, umode_t);
	int (*set_acl)(struct inode___449 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___449 {
	void (*fl_copy_lock)(struct file_lock___449 *, struct file_lock___449 *);
	void (*fl_release_private)(struct file_lock___449 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___449;

struct file_lock___449 {
	struct file_lock___449 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___449 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___449 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___449 *fl_ops;
	const struct lock_manager_operations___449 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___449 {
	int (*lm_compare_owner)(struct file_lock___449 *, struct file_lock___449 *);
	long unsigned int (*lm_owner_key)(struct file_lock___449 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___449 *);
	int (*lm_grant)(struct file_lock___449 *, int);
	bool (*lm_break)(struct file_lock___449 *);
	int (*lm_change)(struct file_lock___449 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___449 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___449 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___449 *fa_next;
	struct file___449 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___449 {
	const char *name;
	int fs_flags;
	struct dentry___449 * (*mount)(struct file_system_type___449 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___449 *);
	struct module___375 *owner;
	struct file_system_type___449 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___449 {
	struct inode___449 * (*alloc_inode)(struct super_block___449 *);
	void (*destroy_inode)(struct inode___449 *);
	void (*dirty_inode)(struct inode___449 *, int);
	int (*write_inode)(struct inode___449 *, struct writeback_control___202 *);
	int (*drop_inode)(struct inode___449 *);
	void (*evict_inode)(struct inode___449 *);
	void (*put_super)(struct super_block___449 *);
	int (*sync_fs)(struct super_block___449 *, int);
	int (*freeze_super)(struct super_block___449 *);
	int (*freeze_fs)(struct super_block___449 *);
	int (*thaw_super)(struct super_block___449 *);
	int (*unfreeze_fs)(struct super_block___449 *);
	int (*statfs)(struct dentry___449 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___449 *, int *, char *);
	void (*umount_begin)(struct super_block___449 *);
	int (*show_options)(struct seq_file___388 *, struct dentry___449 *);
	int (*show_devname)(struct seq_file___388 *, struct dentry___449 *);
	int (*show_path)(struct seq_file___388 *, struct dentry___449 *);
	int (*show_stats)(struct seq_file___388 *, struct dentry___449 *);
	ssize_t (*quota_read)(struct super_block___449 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___449 *, int, const char *, size_t, loff_t);
	struct dquot___449 ** (*get_dquots)(struct inode___449 *);
	int (*bdev_try_to_free_page)(struct super_block___449 *, struct page___450 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___449 *, struct shrink_control___182 *);
	long int (*free_cached_objects)(struct super_block___449 *, struct shrink_control___182 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___239(struct bio___239 *);

struct bio_vec___241 {
	struct page___450 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___239;

struct bio_set___239;

struct bio___239 {
	struct bio___239 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___239 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___239 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___241 *bi_io_vec;
	struct bio_set___239 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___241 bi_inline_vecs[0];
};

typedef void compound_page_dtor___437(struct page___450 *);

struct msghdr___77 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___216 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___449 *msg_iocb;
};

struct socket_wq___75 {
	wait_queue_head_t wait;
	struct fasync_struct___449 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___75;

struct socket___76 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___75 *wq;
	struct file___449 *file;
	struct sock___74 *sk;
	const struct proto_ops___75 *ops;
};

typedef int (*sk_read_actor_t___74)(read_descriptor_t *, struct sk_buff___95 *, unsigned int, size_t);

struct proto_ops___75 {
	int family;
	struct module___375 *owner;
	int (*release)(struct socket___76 *);
	int (*bind)(struct socket___76 *, struct sockaddr *, int);
	int (*connect)(struct socket___76 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___76 *, struct socket___76 *);
	int (*accept)(struct socket___76 *, struct socket___76 *, int, bool);
	int (*getname)(struct socket___76 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___449 *, struct socket___76 *, struct poll_table_struct___288 *);
	int (*ioctl)(struct socket___76 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___76 *, int);
	int (*shutdown)(struct socket___76 *, int);
	int (*setsockopt)(struct socket___76 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___76 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___76 *, struct msghdr___77 *, size_t);
	int (*recvmsg)(struct socket___76 *, struct msghdr___77 *, size_t, int);
	int (*mmap)(struct file___449 *, struct socket___76 *, struct vm_area_struct___450 *);
	ssize_t (*sendpage)(struct socket___76 *, struct page___450 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___76 *, loff_t *, struct pipe_inode_info___130 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___74 *, int);
	int (*peek_len)(struct socket___76 *);
	int (*read_sock)(struct sock___74 *, read_descriptor_t *, sk_read_actor_t___74);
	int (*sendpage_locked)(struct sock___74 *, struct page___450 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___74 *, struct msghdr___77 *, size_t);
	int (*set_rcvlowat)(struct sock___74 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct nf_bridge_info___94;

struct sk_buff___95 {
	union {
		struct {
			struct sk_buff___95 *next;
			struct sk_buff___95 *prev;
			union {
				struct net_device___94 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___74 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___95 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___94 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___94;

struct netns_frags___94 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___94 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ip_ra_chain___40;

struct fib_rules_ops___74;

struct fib_notifier_ops___75;

struct netns_ipv4___94 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___40 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___74 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___74 *fibnl;
	struct sock___74 **icmp_sk;
	struct sock___74 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___74 **tcp_sk;
	struct netns_frags___94 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___74 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___75 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___75 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___74;

struct dst_ops___105 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___105 *);
	struct dst_entry___74 * (*check)(struct dst_entry___74 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___74 *);
	unsigned int (*mtu)(const struct dst_entry___74 *);
	u32 * (*cow_metrics)(struct dst_entry___74 *, long unsigned int);
	void (*destroy)(struct dst_entry___74 *);
	void (*ifdown)(struct dst_entry___74 *, struct net_device___94 *, int);
	struct dst_entry___74 * (*negative_advice)(struct dst_entry___74 *);
	void (*link_failure)(struct sk_buff___95 *);
	void (*update_pmtu)(struct dst_entry___74 *, struct sock___74 *, struct sk_buff___95 *, u32);
	void (*redirect)(struct dst_entry___74 *, struct sock___74 *, struct sk_buff___95 *);
	int (*local_out)(struct net___105 *, struct sock___74 *, struct sk_buff___95 *);
	struct neighbour___74 * (*neigh_lookup)(const struct dst_entry___74 *, struct sk_buff___95 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___74 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___105 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___94 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___105 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___74 *fib6_rules_ops;
	struct sock___74 **icmp_sk;
	struct sock___74 *ndisc_sk;
	struct sock___74 *tcp_sk;
	struct sock___74 *igmp_sk;
	struct sock___74 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___74 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___75 *notifier_ops;
	struct fib_notifier_ops___75 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___75 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___74 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___94 {
	struct netns_frags___94 frags;
};

struct netns_xfrm___105 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___74 *nlsk;
	struct sock___74 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___105 xfrm4_dst_ops;
	struct dst_ops___105 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___84;

struct net___105 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___314 *user_ns;
	struct ucounts___314 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___29 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___74 *rtnl;
	struct sock___74 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___94 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___94 ipv4;
	struct netns_ipv6___105 ipv6;
	struct netns_sctp___75 sctp;
	struct netns_nf___13 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___94 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___74 *nfnl;
	struct sock___74 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___105 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___74 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___84 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___417 {
	int (*prepare)(struct device___417 *);
	void (*complete)(struct device___417 *);
	int (*suspend)(struct device___417 *);
	int (*resume)(struct device___417 *);
	int (*freeze)(struct device___417 *);
	int (*thaw)(struct device___417 *);
	int (*poweroff)(struct device___417 *);
	int (*restore)(struct device___417 *);
	int (*suspend_late)(struct device___417 *);
	int (*resume_early)(struct device___417 *);
	int (*freeze_late)(struct device___417 *);
	int (*thaw_early)(struct device___417 *);
	int (*poweroff_late)(struct device___417 *);
	int (*restore_early)(struct device___417 *);
	int (*suspend_noirq)(struct device___417 *);
	int (*resume_noirq)(struct device___417 *);
	int (*freeze_noirq)(struct device___417 *);
	int (*thaw_noirq)(struct device___417 *);
	int (*poweroff_noirq)(struct device___417 *);
	int (*restore_noirq)(struct device___417 *);
	int (*runtime_suspend)(struct device___417 *);
	int (*runtime_resume)(struct device___417 *);
	int (*runtime_idle)(struct device___417 *);
};

struct dev_pm_domain___417 {
	struct dev_pm_ops___417 ops;
	void (*detach)(struct device___417 *, bool);
	int (*activate)(struct device___417 *);
	void (*sync)(struct device___417 *);
	void (*dismiss)(struct device___417 *);
};

struct bus_type___417 {
	const char *name;
	const char *dev_name;
	struct device___417 *dev_root;
	const struct attribute_group___414 **bus_groups;
	const struct attribute_group___414 **dev_groups;
	const struct attribute_group___414 **drv_groups;
	int (*match)(struct device___417 *, struct device_driver___417 *);
	int (*uevent)(struct device___417 *, struct kobj_uevent_env *);
	int (*probe)(struct device___417 *);
	int (*remove)(struct device___417 *);
	void (*shutdown)(struct device___417 *);
	int (*online)(struct device___417 *);
	int (*offline)(struct device___417 *);
	int (*suspend)(struct device___417 *, pm_message_t);
	int (*resume)(struct device___417 *);
	int (*num_vf)(struct device___417 *);
	int (*dma_configure)(struct device___417 *);
	const struct dev_pm_ops___417 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___417 {
	const char *name;
	struct bus_type___417 *bus;
	struct module___375 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___417 *);
	int (*remove)(struct device___417 *);
	void (*shutdown)(struct device___417 *);
	int (*suspend)(struct device___417 *, pm_message_t);
	int (*resume)(struct device___417 *);
	const struct attribute_group___414 **groups;
	const struct dev_pm_ops___417 *pm;
	void (*coredump)(struct device___417 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___417 {
	const char *name;
	const struct attribute_group___414 **groups;
	int (*uevent)(struct device___417 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___417 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___417 *);
	const struct dev_pm_ops___417 *pm;
};

struct class___417 {
	const char *name;
	struct module___375 *owner;
	const struct attribute_group___414 **class_groups;
	const struct attribute_group___414 **dev_groups;
	struct kobject___437 *dev_kobj;
	int (*dev_uevent)(struct device___417 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___417 *, umode_t *);
	void (*class_release)(struct class___417 *);
	void (*dev_release)(struct device___417 *);
	int (*shutdown_pre)(struct device___417 *);
	const struct kobj_ns_type_operations___74 *ns_type;
	const void * (*namespace)(struct device___417 *);
	const struct dev_pm_ops___417 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___189 {
	void * (*alloc)(struct device___417 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___417 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___417 *, struct vm_area_struct___450 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___417 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___417 *, struct page___450 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___417 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___417 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___417 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___417 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___417 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___417 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___417 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___417 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___417 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___417 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___417 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___417 *, u64);
	u64 (*get_required_mask)(struct device___417 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___337;

struct fwnode_handle___337 {
	struct fwnode_handle___337 *secondary;
	const struct fwnode_operations___337 *ops;
};

struct fwnode_reference_args___337;

struct fwnode_endpoint___337;

struct fwnode_operations___337 {
	struct fwnode_handle___337 * (*get)(struct fwnode_handle___337 *);
	void (*put)(struct fwnode_handle___337 *);
	bool (*device_is_available)(const struct fwnode_handle___337 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___337 *, const struct device___417 *);
	bool (*property_present)(const struct fwnode_handle___337 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___337 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___337 *, const char *, const char **, size_t);
	struct fwnode_handle___337 * (*get_parent)(const struct fwnode_handle___337 *);
	struct fwnode_handle___337 * (*get_next_child_node)(const struct fwnode_handle___337 *, struct fwnode_handle___337 *);
	struct fwnode_handle___337 * (*get_named_child_node)(const struct fwnode_handle___337 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___337 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___337 *);
	struct fwnode_handle___337 * (*graph_get_next_endpoint)(const struct fwnode_handle___337 *, struct fwnode_handle___337 *);
	struct fwnode_handle___337 * (*graph_get_remote_endpoint)(const struct fwnode_handle___337 *);
	struct fwnode_handle___337 * (*graph_get_port_parent)(struct fwnode_handle___337 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___337 *, struct fwnode_endpoint___337 *);
};

struct fwnode_endpoint___337 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___337 *local_fwnode;
};

struct fwnode_reference_args___337 {
	struct fwnode_handle___337 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___130;

struct pipe_buffer___130 {
	struct page___450 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___130 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___130 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___130 *, struct pipe_buffer___130 *);
	void (*release)(struct pipe_inode_info___130 *, struct pipe_buffer___130 *);
	int (*steal)(struct pipe_inode_info___130 *, struct pipe_buffer___130 *);
	union {
		bool (*get)(struct pipe_inode_info___130 *, struct pipe_buffer___130 *);
		struct {
			void (*get)(struct pipe_inode_info___130 *, struct pipe_buffer___130 *);
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
};

struct nf_bridge_info___94 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___94 = 0,
		BRNF_PROTO_8021Q___94 = 1,
		BRNF_PROTO_PPPOE___94 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___94 *physindev;
	struct net_device___94 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___94(struct sk_buff___95 **);

struct net_device_ops___94;

struct ethtool_ops___94;

struct l3mdev_ops___74;

struct ndisc_ops___45;

struct xfrmdev_ops___94;

struct tlsdev_ops___94;

struct header_ops___94;

struct in_device___10;

struct inet6_dev___45;

struct netdev_rx_queue___94;

struct mini_Qdisc___86;

struct netdev_queue___94;

struct Qdisc___86;

struct rtnl_link_ops___86;

struct dcbnl_rtnl_ops___94;

struct net_device___94 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___94 *netdev_ops;
	const struct ethtool_ops___94 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___74 *l3mdev_ops;
	const struct ndisc_ops___45 *ndisc_ops;
	const struct xfrmdev_ops___94 *xfrmdev_ops;
	const struct tlsdev_ops___94 *tlsdev_ops;
	const struct header_ops___94 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___436 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device___10 *ip_ptr;
	struct inet6_dev___45 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___94 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___84 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___94 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___86 *miniq_ingress;
	struct netdev_queue___94 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___94 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___86 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___86 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___94 = 0,
		NETREG_REGISTERED___94 = 1,
		NETREG_UNREGISTERING___94 = 2,
		NETREG_UNREGISTERED___94 = 3,
		NETREG_RELEASED___94 = 4,
		NETREG_DUMMY___94 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___94 = 0,
		RTNL_LINK_INITIALIZING___94 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___94 *);
	struct netpoll_info *npinfo;
	possible_net_t___96 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___417 dev;
	const struct attribute_group___414 *sysfs_groups[4];
	const struct attribute_group___414 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___86 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___94 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide35;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct cgroup_namespace___298 {
	refcount_t count;
	struct ns_common___29 ns;
	struct user_namespace___314 *user_ns;
	struct ucounts___314 *ucounts;
	struct css_set___298 *root_cset;
};

struct netlink_skb_parms___15 {
	struct scm_creds creds;
	__u32 portid;
	__u32 dst_group;
	__u32 flags;
	struct sock___74 *sk;
	bool nsid_is_set;
	int nsid;
};

struct netlink_callback___96 {
	struct sk_buff___95 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___96 *);
	int (*dump)(struct sk_buff___95 *, struct netlink_callback___96 *);
	int (*done)(struct netlink_callback___96 *);
	void *data;
	struct module___375 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct ifaddrmsg {
	__u8 ifa_family;
	__u8 ifa_prefixlen;
	__u8 ifa_flags;
	__u8 ifa_scope;
	__u32 ifa_index;
};

enum {
	IFA_UNSPEC = 0,
	IFA_ADDRESS = 1,
	IFA_LOCAL = 2,
	IFA_LABEL = 3,
	IFA_BROADCAST = 4,
	IFA_ANYCAST = 5,
	IFA_CACHEINFO = 6,
	IFA_MULTICAST = 7,
	IFA_FLAGS = 8,
	IFA_RT_PRIORITY = 9,
	IFA_TARGET_NETNSID = 10,
	__IFA_MAX = 11,
};

struct ifa_cacheinfo {
	__u32 ifa_prefered;
	__u32 ifa_valid;
	__u32 cstamp;
	__u32 tstamp;
};

struct inet_frag_queue___94;

struct inet_frags___94 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___94 *, const void *);
	void (*destructor)(struct inet_frag_queue___94 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___94 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___95 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___95 *fragments_tail;
	struct sk_buff___95 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___94 *net;
	struct callback_head rcu;
};

struct ip_ra_chain___40 {
	struct ip_ra_chain___40 *next;
	struct sock___74 *sk;
	union {
		void (*destructor)(struct sock___74 *);
		struct sock___74 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___74;

struct fib_lookup_arg___74;

struct fib_rules_ops___74 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___74 *, struct flowi *, int, struct fib_lookup_arg___74 *);
	bool (*suppress)(struct fib_rule___74 *, struct fib_lookup_arg___74 *);
	int (*match)(struct fib_rule___74 *, struct flowi *, int);
	int (*configure)(struct fib_rule___74 *, struct sk_buff___95 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___74 *);
	int (*compare)(struct fib_rule___74 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___74 *, struct sk_buff___95 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___74 *);
	void (*flush_cache)(struct fib_rules_ops___74 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___375 *owner;
	struct net___105 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___75 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___105 *);
	int (*fib_dump)(struct net___105 *, struct notifier_block *);
	struct module___375 *owner;
	struct callback_head rcu;
};

struct dst_entry___74 {
	struct net_device___94 *dev;
	struct dst_ops___105 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___95 *);
	int (*output)(struct net___105 *, struct sock___74 *, struct sk_buff___95 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___74;

struct neigh_parms___74;

struct neigh_ops___74;

struct neighbour___74 {
	struct neighbour___74 *next;
	struct neigh_table___74 *tbl;
	struct neigh_parms___74 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___94 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___74 *, struct sk_buff___95 *);
	const struct neigh_ops___74 *ops;
	struct callback_head rcu;
	struct net_device___94 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct ucounts___314 {
	struct hlist_node node;
	struct user_namespace___314 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_prog_aux___87;

struct bpf_prog___84 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___87 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

struct seq_operations___388 {
	void * (*start)(struct seq_file___388 *, loff_t *);
	void (*stop)(struct seq_file___388 *, void *);
	void * (*next)(struct seq_file___388 *, void *, loff_t *);
	int (*show)(struct seq_file___388 *, void *);
};

struct pernet_operations___95 {
	struct list_head list;
	int (*init)(struct net___105 *);
	void (*exit)(struct net___105 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct ethtool_ops___94 {
	int (*get_settings)(struct net_device___94 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___94 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___94 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___94 *);
	void (*get_regs)(struct net_device___94 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___94 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___94 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___94 *);
	void (*set_msglevel)(struct net_device___94 *, u32);
	int (*nway_reset)(struct net_device___94 *);
	u32 (*get_link)(struct net_device___94 *);
	int (*get_eeprom_len)(struct net_device___94 *);
	int (*get_eeprom)(struct net_device___94 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___94 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___94 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___94 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___94 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___94 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___94 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___94 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___94 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___94 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___94 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___94 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___94 *);
	void (*complete)(struct net_device___94 *);
	u32 (*get_priv_flags)(struct net_device___94 *);
	int (*set_priv_flags)(struct net_device___94 *, u32);
	int (*get_sset_count)(struct net_device___94 *, int);
	int (*get_rxnfc)(struct net_device___94 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___94 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___94 *, struct ethtool_flash *);
	int (*reset)(struct net_device___94 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___94 *);
	u32 (*get_rxfh_indir_size)(struct net_device___94 *);
	int (*get_rxfh)(struct net_device___94 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___94 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___94 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___94 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___94 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___94 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___94 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___94 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___94 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___94 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___94 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___94 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___94 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___94 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___94 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___94 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___94 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___94 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___94 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___94 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___94 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___94 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	int (*get_fecparam)(struct net_device___94 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___94 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___94 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___94 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___94 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct dcbnl_rtnl_ops___94 {
	int (*ieee_getets)(struct net_device___94 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___94 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___94 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___94 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___94 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___94 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___94 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___94 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___94 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___94 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___94 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___94 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___94 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___94 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___94 *);
	u8 (*setstate)(struct net_device___94 *, u8);
	void (*getpermhwaddr)(struct net_device___94 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___94 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___94 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___94 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___94 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___94 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___94 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___94 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___94 *, int, u8 *);
	void (*setpfccfg)(struct net_device___94 *, int, u8);
	void (*getpfccfg)(struct net_device___94 *, int, u8 *);
	u8 (*setall)(struct net_device___94 *);
	u8 (*getcap)(struct net_device___94 *, int, u8 *);
	int (*getnumtcs)(struct net_device___94 *, int, u8 *);
	int (*setnumtcs)(struct net_device___94 *, int, u8);
	u8 (*getpfcstate)(struct net_device___94 *);
	void (*setpfcstate)(struct net_device___94 *, u8);
	void (*getbcncfg)(struct net_device___94 *, int, u32 *);
	void (*setbcncfg)(struct net_device___94 *, int, u32);
	void (*getbcnrp)(struct net_device___94 *, int, u8 *);
	void (*setbcnrp)(struct net_device___94 *, int, u8);
	int (*setapp)(struct net_device___94 *, u8, u16, u8);
	int (*getapp)(struct net_device___94 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___94 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___94 *, int, u8);
	u8 (*getdcbx)(struct net_device___94 *);
	u8 (*setdcbx)(struct net_device___94 *, u8);
	int (*peer_getappinfo)(struct net_device___94 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___94 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___94 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___94 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___94 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___94 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct bpf_map___299;

struct bpf_map_ops___298 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___299 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___299 *, struct file___449 *);
	void (*map_free)(struct bpf_map___299 *);
	int (*map_get_next_key)(struct bpf_map___299 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___299 *);
	void * (*map_lookup_elem)(struct bpf_map___299 *, void *);
	int (*map_update_elem)(struct bpf_map___299 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___299 *, void *);
	int (*map_push_elem)(struct bpf_map___299 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___299 *, void *);
	int (*map_peek_elem)(struct bpf_map___299 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___299 *, struct file___449 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___299 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___299 *, void *, struct seq_file___388 *);
	int (*map_check_btf)(const struct bpf_map___299 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___299 {
	const struct bpf_map_ops___298 *ops;
	struct bpf_map___299 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___417 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___94;

struct bpf_map_dev_ops___94 {
	int (*map_get_next_key)(struct bpf_offloaded_map___94 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___94 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___94 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___94 *, void *);
};

struct bpf_offloaded_map___94 {
	struct bpf_map___299 map;
	struct net_device___94 *netdev;
	const struct bpf_map_dev_ops___94 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___84 {
	int (*test_run)(struct bpf_prog___84 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___84 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___84 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___84 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___84 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___84 *, u32 *);
};

struct bpf_prog_offload_ops___84 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___84 *);
	int (*translate)(struct bpf_prog___84 *);
	void (*destroy)(struct bpf_prog___84 *);
};

struct bpf_prog_offload___84 {
	struct bpf_prog___84 *prog;
	struct net_device___94 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___84 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___87 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___84 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___84 *ops;
	struct bpf_map___299 **used_maps;
	struct bpf_prog___84 *prog;
	struct user_struct___417 *user;
	u64 load_time;
	struct bpf_map___299 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___84 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___84 {
	struct bpf_prog___84 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___84 {
	struct callback_head rcu;
	struct bpf_prog_array_item___84 items[0];
};

struct cgroup_bpf___84 {
	struct bpf_prog_array___84 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___84 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___299;

typedef void (*kthread_work_func_t___299)(struct kthread_work___299 *);

struct kthread_worker___299;

struct kthread_work___299 {
	struct list_head node;
	kthread_work_func_t___299 func;
	struct kthread_worker___299 *worker;
	int canceling;
};

struct kthread_worker___299 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___451 *task;
	struct kthread_work___299 *current_work;
};

struct kthread_delayed_work___298 {
	struct kthread_work___299 work;
	struct timer_list timer;
};

struct psi_group___298 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___299 *poll_kworker;
	struct kthread_delayed_work___298 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___298;

struct cgroup_rstat_cpu___298;

struct cgroup___298 {
	struct cgroup_subsys_state___298 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___444 *kn;
	struct cgroup_file___298 procs_file;
	struct cgroup_file___298 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___298 *subsys[13];
	struct cgroup_root___298 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___298 *dom_cgrp;
	struct cgroup_rstat_cpu___298 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___84 bpf;
	atomic_t congestion_count;
	struct cgroup___298 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___298 psi;
	int ancestor_ids[0];
};

struct cftype___298;

struct cgroup_subsys___298 {
	struct cgroup_subsys_state___298 * (*css_alloc)(struct cgroup_subsys_state___298 *);
	int (*css_online)(struct cgroup_subsys_state___298 *);
	void (*css_offline)(struct cgroup_subsys_state___298 *);
	void (*css_released)(struct cgroup_subsys_state___298 *);
	void (*css_free)(struct cgroup_subsys_state___298 *);
	void (*css_reset)(struct cgroup_subsys_state___298 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___298 *, int);
	int (*css_extra_stat_show)(struct seq_file___388 *, struct cgroup_subsys_state___298 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___451 *);
	void (*cancel_fork)(struct task_struct___451 *);
	void (*fork)(struct task_struct___451 *);
	void (*exit)(struct task_struct___451 *);
	void (*free)(struct task_struct___451 *);
	void (*bind)(struct cgroup_subsys_state___298 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___298 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___298 *dfl_cftypes;
	struct cftype___298 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___298 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___298 *updated_children;
	struct cgroup___298 *updated_next;
};

struct cgroup_root___298 {
	struct kernfs_root___443 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___298 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___298 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___298 *ss;
	struct list_head node;
	struct kernfs_ops___443 *kf_ops;
	int (*open)(struct kernfs_open_file___443 *);
	void (*release)(struct kernfs_open_file___443 *);
	u64 (*read_u64)(struct cgroup_subsys_state___298 *, struct cftype___298 *);
	s64 (*read_s64)(struct cgroup_subsys_state___298 *, struct cftype___298 *);
	int (*seq_show)(struct seq_file___388 *, void *);
	void * (*seq_start)(struct seq_file___388 *, loff_t *);
	void * (*seq_next)(struct seq_file___388 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___388 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___298 *, struct cftype___298 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___298 *, struct cftype___298 *, s64);
	ssize_t (*write)(struct kernfs_open_file___443 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___443 *, struct poll_table_struct___288 *);
};

struct xdp_rxq_info___94 {
	struct net_device___94 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___94 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___94 *dev_rx;
};

enum {
	IFLA_INET_UNSPEC = 0,
	IFLA_INET_CONF = 1,
	__IFLA_INET_MAX = 2,
};

struct header_ops___94 {
	int (*create)(struct sk_buff___95 *, struct net_device___94 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___95 *, unsigned char *);
	int (*cache)(const struct neighbour___74 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___94 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___94 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___94 *, int);
	int poll_owner;
	struct net_device___94 *dev;
	struct sk_buff___95 *gro_list;
	struct sk_buff___95 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___94 {
	struct net_device___94 *dev;
	struct Qdisc___86 *qdisc;
	struct Qdisc___86 *qdisc_sleeping;
	struct kobject___437 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___94 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem___3 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___86 {
	struct sk_buff___95 *head;
	struct sk_buff___95 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___86;

struct Qdisc___86 {
	int (*enqueue)(struct sk_buff___95 *, struct Qdisc___86 *, struct sk_buff___95 **);
	struct sk_buff___95 * (*dequeue)(struct Qdisc___86 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___86 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___94 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___94 gso_skb;
	struct qdisc_skb_head___86 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___86 *next_sched;
	struct sk_buff_head___94 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___94 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___437 kobj;
	struct net_device___94 *dev;
	long: 64;
	struct xdp_rxq_info___94 xdp_rxq;
	union {
		struct xdp_umem___3 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___94)(struct net_device___94 *, struct sk_buff___95 *, struct net_device___94 *);

struct netdev_bpf___94 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___84 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___84 *prog;
			const struct bpf_prog_offload_ops___84 *ops;
		} verifier;
		struct {
			struct bpf_prog___84 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___94 *offmap;
		};
		struct {
			struct xdp_umem___3 *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___94 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___95 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___94 {
	int (*tls_dev_add)(struct net_device___94 *, struct sock___74 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___94 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___94 *, struct sock___74 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___94 {
	int (*ndo_init)(struct net_device___94 *);
	void (*ndo_uninit)(struct net_device___94 *);
	int (*ndo_open)(struct net_device___94 *);
	int (*ndo_stop)(struct net_device___94 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___95 *, struct net_device___94 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___95 *, struct net_device___94 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___94 *, struct sk_buff___95 *, struct net_device___94 *, select_queue_fallback_t___94);
	void (*ndo_change_rx_flags)(struct net_device___94 *, int);
	void (*ndo_set_rx_mode)(struct net_device___94 *);
	int (*ndo_set_mac_address)(struct net_device___94 *, void *);
	int (*ndo_validate_addr)(struct net_device___94 *);
	int (*ndo_do_ioctl)(struct net_device___94 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___94 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___94 *, int);
	int (*ndo_neigh_setup)(struct net_device___94 *, struct neigh_parms___74 *);
	void (*ndo_tx_timeout)(struct net_device___94 *);
	void (*ndo_get_stats64)(struct net_device___94 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___94 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___94 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___94 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___94 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___94 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___94 *);
	int (*ndo_netpoll_setup)(struct net_device___94 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___94 *);
	int (*ndo_set_vf_mac)(struct net_device___94 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___94 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___94 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___94 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___94 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___94 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___94 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___94 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___94 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___94 *, int, struct sk_buff___95 *);
	int (*ndo_set_vf_guid)(struct net_device___94 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___94 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___94 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___94 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___94 *, const struct sk_buff___95 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___94 *, struct net_device___94 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___94 *, struct net_device___94 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___94 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___94 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___94 *, struct neighbour___74 *);
	void (*ndo_neigh_destroy)(struct net_device___94 *, struct neighbour___74 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___94 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___94 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___94 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___95 *, struct netlink_callback___96 *, struct net_device___94 *, struct net_device___94 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___94 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___94 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___95 *, u32, u32, struct net_device___94 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___94 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___94 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___94 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___94 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___94 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___94 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___94 *, struct net_device___94 *);
	void (*ndo_dfwd_del_station)(struct net_device___94 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___94 *);
	int (*ndo_set_tx_maxrate)(struct net_device___94 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___94 *);
	int (*ndo_change_proto_down)(struct net_device___94 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___94 *, struct sk_buff___95 *);
	void (*ndo_set_rx_headroom)(struct net_device___94 *, int);
	int (*ndo_bpf)(struct net_device___94 *, struct netdev_bpf___94 *);
	int (*ndo_xdp_xmit)(struct net_device___94 *, int, struct xdp_frame___94 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___94 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___94 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___74 {
	possible_net_t___96 net;
	struct net_device___94 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___74 *);
	void (*neigh_cleanup)(struct neighbour___74 *);
	struct neigh_table___74 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___74 {
	u32 (*l3mdev_fib_table)(const struct net_device___94 *);
	struct sk_buff___95 * (*l3mdev_l3_rcv)(struct net_device___94 *, struct sk_buff___95 *, u16);
	struct sk_buff___95 * (*l3mdev_l3_out)(struct net_device___94 *, struct sock___74 *, struct sk_buff___95 *, u16);
	struct dst_entry___74 * (*l3mdev_link_scope_lookup)(const struct net_device___94 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct ndisc_ops___45 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___94 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___94 *, struct neighbour___74 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___94 *, u8, struct neighbour___74 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___94 *, struct sk_buff___95 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___105 *, struct net_device___94 *, const struct prefix_info *, struct inet6_dev___45 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct in_ifaddr___10;

struct ip_mc_list___3;

struct in_device___10 {
	struct net_device___94 *dev;
	refcount_t refcnt;
	int dead;
	struct in_ifaddr___10 *ifa_list;
	struct ip_mc_list___3 *mc_list;
	struct ip_mc_list___3 **mc_hash;
	int mc_count;
	spinlock_t mc_tomb_lock;
	struct ip_mc_list___3 *mc_tomb;
	long unsigned int mr_v1_seen;
	long unsigned int mr_v2_seen;
	long unsigned int mr_maxdelay;
	long unsigned int mr_qi;
	long unsigned int mr_qri;
	unsigned char mr_qrv;
	unsigned char mr_gq_running;
	unsigned char mr_ifc_count;
	struct timer_list mr_gq_timer;
	struct timer_list mr_ifc_timer;
	struct neigh_parms___74 *arp_parms;
	struct ipv4_devconf cnf;
	struct callback_head callback_head;
};

struct ifmcaddr6___45;

struct inet6_dev___45 {
	struct net_device___94 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___45 *mc_list;
	struct ifmcaddr6___45 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___19 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	u8 rndid[8];
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___74 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
};

struct tcf_proto___86;

struct mini_Qdisc___86 {
	struct tcf_proto___86 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___86 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___94 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___105 *, struct net_device___94 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___94 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___94 *, struct list_head *);
	size_t (*get_size)(const struct net_device___94 *);
	int (*fill_info)(struct sk_buff___95 *, const struct net_device___94 *);
	size_t (*get_xstats_size)(const struct net_device___94 *);
	int (*fill_xstats)(struct sk_buff___95 *, const struct net_device___94 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___94 *, struct net_device___94 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___94 *, const struct net_device___94 *);
	int (*fill_slave_info)(struct sk_buff___95 *, const struct net_device___94 *, const struct net_device___94 *);
	struct net___105 * (*get_link_net)(const struct net_device___94 *);
	size_t (*get_linkxstats_size)(const struct net_device___94 *, int);
	int (*fill_linkxstats)(struct sk_buff___95 *, const struct net_device___94 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct netdev_notifier_info___9 {
	struct net_device___94 *dev;
	struct netlink_ext_ack *extack;
};

struct softnet_data___94 {
	struct list_head poll_list;
	struct sk_buff_head___94 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___94 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___86 *output_queue;
	struct Qdisc___86 **output_queue_tailp;
	struct sk_buff___95 *completion_queue;
	struct sk_buff_head___94 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___94 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___94 input_pkt_queue;
	struct napi_struct___94 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct in_ifaddr___10 {
	struct hlist_node hash;
	struct in_ifaddr___10 *ifa_next;
	struct in_device___10 *ifa_dev;
	struct callback_head callback_head;
	__be32 ifa_local;
	__be32 ifa_address;
	__be32 ifa_mask;
	__u32 ifa_rt_priority;
	__be32 ifa_broadcast;
	unsigned char ifa_scope;
	unsigned char ifa_prefixlen;
	__u32 ifa_flags;
	char ifa_label[16];
	__u32 ifa_valid_lft;
	__u32 ifa_preferred_lft;
	long unsigned int ifa_cstamp;
	long unsigned int ifa_tstamp;
};

struct ip_mc_list___3 {
	struct in_device___10 *interface;
	__be32 multiaddr;
	unsigned int sfmode;
	struct ip_sf_list *sources;
	struct ip_sf_list *tomb;
	long unsigned int sfcount[2];
	union {
		struct ip_mc_list___3 *next;
		struct ip_mc_list___3 *next_rcu;
	};
	struct ip_mc_list___3 *next_hash;
	struct timer_list timer;
	int users;
	refcount_t refcnt;
	spinlock_t lock;
	char tm_running;
	char reporter;
	char unsolicit_count;
	char loaded;
	unsigned char gsquery;
	unsigned char crcount;
	struct callback_head rcu;
};

struct in_validator_info {
	__be32 ivi_addr;
	struct in_device___10 *ivi_dev;
	struct netlink_ext_ack *extack;
};

struct netconfmsg {
	__u8 ncm_family;
};

enum {
	NETCONFA_UNSPEC = 0,
	NETCONFA_IFINDEX = 1,
	NETCONFA_FORWARDING = 2,
	NETCONFA_RP_FILTER = 3,
	NETCONFA_MC_FORWARDING = 4,
	NETCONFA_PROXY_NEIGH = 5,
	NETCONFA_IGNORE_ROUTES_WITH_LINKDOWN = 6,
	NETCONFA_INPUT = 7,
	NETCONFA_BC_FORWARDING = 8,
	__NETCONFA_MAX = 9,
};

struct rtnl_af_ops___2 {
	struct list_head list;
	int family;
	int (*fill_link_af)(struct sk_buff___95 *, const struct net_device___94 *, u32);
	size_t (*get_link_af_size)(const struct net_device___94 *, u32);
	int (*validate_link_af)(const struct net_device___94 *, const struct nlattr *);
	int (*set_link_af)(struct net_device___94 *, const struct nlattr *);
	int (*fill_stats_af)(struct sk_buff___95 *, const struct net_device___94 *);
	size_t (*get_stats_af_size)(const struct net_device___94 *);
};

struct pneigh_entry___74;

struct neigh_hash_table___74;

struct neigh_table___74 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___94 *, __u32 *);
	bool (*key_eq)(const struct neighbour___74 *, const void *);
	int (*constructor)(struct neighbour___74 *);
	int (*pconstructor)(struct pneigh_entry___74 *);
	void (*pdestructor)(struct pneigh_entry___74 *);
	void (*proxy_redo)(struct sk_buff___95 *);
	char *id;
	struct neigh_parms___74 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___94 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___74 *nht;
	struct pneigh_entry___74 **phash_buckets;
};

struct neigh_ops___74 {
	int family;
	void (*solicit)(struct neighbour___74 *, struct sk_buff___95 *);
	void (*error_report)(struct neighbour___74 *, struct sk_buff___95 *);
	int (*output)(struct neighbour___74 *, struct sk_buff___95 *);
	int (*connected_output)(struct neighbour___74 *, struct sk_buff___95 *);
};

struct pneigh_entry___74 {
	struct pneigh_entry___74 *next;
	possible_net_t___96 net;
	struct net_device___94 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___74 {
	struct neighbour___74 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct bdi_writeback_congested___239 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___239 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___239 {
	struct bio___239 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___241 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___241 bip_inline_vecs[0];
};

struct bio_set___239 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___239 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___182 {
	struct mem_cgroup___182 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___182 {
	struct lruvec___450 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___182 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___182 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct gnet_dump___86 {
	spinlock_t *lock;
	struct sk_buff___95 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___86;

struct Qdisc_ops___86 {
	struct Qdisc_ops___86 *next;
	const struct Qdisc_class_ops___86 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___95 *, struct Qdisc___86 *, struct sk_buff___95 **);
	struct sk_buff___95 * (*dequeue)(struct Qdisc___86 *);
	struct sk_buff___95 * (*peek)(struct Qdisc___86 *);
	int (*init)(struct Qdisc___86 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___86 *);
	void (*destroy)(struct Qdisc___86 *);
	int (*change)(struct Qdisc___86 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___86 *);
	int (*change_tx_queue_len)(struct Qdisc___86 *, unsigned int);
	int (*dump)(struct Qdisc___86 *, struct sk_buff___95 *);
	int (*dump_stats)(struct Qdisc___86 *, struct gnet_dump___86 *);
	void (*ingress_block_set)(struct Qdisc___86 *, u32);
	void (*egress_block_set)(struct Qdisc___86 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___86 *);
	u32 (*egress_block_get)(struct Qdisc___86 *);
	struct module___375 *owner;
};

struct tcf_block___86;

struct Qdisc_class_ops___86 {
	unsigned int flags;
	struct netdev_queue___94 * (*select_queue)(struct Qdisc___86 *, struct tcmsg *);
	int (*graft)(struct Qdisc___86 *, long unsigned int, struct Qdisc___86 *, struct Qdisc___86 **, struct netlink_ext_ack *);
	struct Qdisc___86 * (*leaf)(struct Qdisc___86 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___86 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___86 *, u32);
	int (*change)(struct Qdisc___86 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___86 *, long unsigned int);
	void (*walk)(struct Qdisc___86 *, struct qdisc_walker *);
	struct tcf_block___86 * (*tcf_block)(struct Qdisc___86 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___86 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___86 *, long unsigned int);
	int (*dump)(struct Qdisc___86 *, long unsigned int, struct sk_buff___95 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___86 *, long unsigned int, struct gnet_dump___86 *);
};

struct tcf_chain___86;

struct tcf_block___86 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___105 *net;
	struct Qdisc___86 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___86 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___86;

struct tcf_proto_ops___86;

struct tcf_proto___86 {
	struct tcf_proto___86 *next;
	void *root;
	int (*classify)(struct sk_buff___95 *, const struct tcf_proto___86 *, struct tcf_result___86 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___86 *ops;
	struct tcf_chain___86 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___86 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___86 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___86 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___95 *, const struct tcf_proto___86 *, struct tcf_result___86 *);
	int (*init)(struct tcf_proto___86 *);
	void (*destroy)(struct tcf_proto___86 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___86 *, u32);
	void (*put)(struct tcf_proto___86 *, void *);
	int (*change)(struct net___105 *, struct sk_buff___95 *, struct tcf_proto___86 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___86 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___86 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___86 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___105 *, struct tcf_chain___86 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___105 *, struct tcf_proto___86 *, void *, struct sk_buff___95 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___95 *, struct net___105 *, void *);
	struct module___375 *owner;
	int flags;
};

struct tcf_chain___86 {
	struct mutex filter_chain_lock;
	struct tcf_proto___86 *filter_chain;
	struct list_head list;
	struct tcf_block___86 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___86 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___74 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___84 *prog;
};

struct bpf_redirect_info___84 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___299 *map;
	struct bpf_map___299 *map_to_flush;
	u32 kern_flags;
};

struct fib_rule___74 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___74 *ctarget;
	struct net___105 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___74 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___74 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___57;

struct timewait_sock_ops___53;

struct proto___74 {
	void (*close)(struct sock___74 *, long int);
	int (*pre_connect)(struct sock___74 *, struct sockaddr *, int);
	int (*connect)(struct sock___74 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___74 *, int);
	struct sock___74 * (*accept)(struct sock___74 *, int, int *, bool);
	int (*ioctl)(struct sock___74 *, int, long unsigned int);
	int (*init)(struct sock___74 *);
	void (*destroy)(struct sock___74 *);
	void (*shutdown)(struct sock___74 *, int);
	int (*setsockopt)(struct sock___74 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___74 *, int, int, char *, int *);
	void (*keepalive)(struct sock___74 *, int);
	int (*sendmsg)(struct sock___74 *, struct msghdr___77 *, size_t);
	int (*recvmsg)(struct sock___74 *, struct msghdr___77 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___74 *, struct page___450 *, int, size_t, int);
	int (*bind)(struct sock___74 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___74 *, struct sk_buff___95 *);
	void (*release_cb)(struct sock___74 *);
	int (*hash)(struct sock___74 *);
	void (*unhash)(struct sock___74 *);
	void (*rehash)(struct sock___74 *);
	int (*get_port)(struct sock___74 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___74 *);
	bool (*stream_memory_read)(const struct sock___74 *);
	void (*enter_memory_pressure)(struct sock___74 *);
	void (*leave_memory_pressure)(struct sock___74 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___57 *rsk_prot;
	struct timewait_sock_ops___53 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___375 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___74 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct request_sock___58;

struct request_sock_ops___57 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___74 *, struct request_sock___58 *);
	void (*send_ack)(const struct sock___74 *, struct sk_buff___95 *, struct request_sock___58 *);
	void (*send_reset)(const struct sock___74 *, struct sk_buff___95 *);
	void (*destructor)(struct request_sock___58 *);
	void (*syn_ack_timeout)(const struct request_sock___58 *);
};

struct timewait_sock_ops___53 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___74 *, struct sock___74 *, void *);
	void (*twsk_destructor)(struct sock___74 *);
};

struct request_sock___58 {
	struct sock_common___74 __req_common;
	struct request_sock___58 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___57 *rsk_ops;
	struct sock___74 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___45 {
	struct in6_addr mca_addr;
	struct inet6_dev___45 *idev;
	struct ifmcaddr6___45 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ip6_ra_chain___45 {
	struct ip6_ra_chain___45 *next;
	struct sock___74 *sk;
	int sel;
	void (*destructor)(struct sock___74 *);
};

struct rtable___12;

struct fib_nh_exception___4 {
	struct fib_nh_exception___4 *fnhe_next;
	int fnhe_genid;
	__be32 fnhe_daddr;
	u32 fnhe_pmtu;
	bool fnhe_mtu_locked;
	__be32 fnhe_gw;
	long unsigned int fnhe_expires;
	struct rtable___12 *fnhe_rth_input;
	struct rtable___12 *fnhe_rth_output;
	long unsigned int fnhe_stamp;
	struct callback_head rcu;
};

struct rtable___12 {
	struct dst_entry___74 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	__be32 rt_gateway;
	u32 rt_mtu_locked: 1;
	u32 rt_pmtu: 31;
	struct list_head rt_uncached;
	struct uncached_list *rt_uncached_list;
};

struct fnhe_hash_bucket___4 {
	struct fib_nh_exception___4 *chain;
};

struct fib_info___4;

struct fib_nh___4 {
	struct net_device___94 *nh_dev;
	struct hlist_node nh_hash;
	struct fib_info___4 *nh_parent;
	unsigned int nh_flags;
	unsigned char nh_scope;
	int nh_weight;
	atomic_t nh_upper_bound;
	__u32 nh_tclassid;
	int nh_oif;
	__be32 nh_gw;
	__be32 nh_saddr;
	int nh_saddr_genid;
	struct rtable___12 **nh_pcpu_rth_output;
	struct rtable___12 *nh_rth_input;
	struct fnhe_hash_bucket___4 *nh_exceptions;
	struct lwtunnel_state *nh_lwtstate;
};

struct fib_info___4 {
	struct hlist_node fib_hash;
	struct hlist_node fib_lhash;
	struct net___105 *fib_net;
	int fib_treeref;
	refcount_t fib_clntref;
	unsigned int fib_flags;
	unsigned char fib_dead;
	unsigned char fib_protocol;
	unsigned char fib_scope;
	unsigned char fib_type;
	__be32 fib_prefsrc;
	u32 fib_tb_id;
	u32 fib_priority;
	struct dst_metrics *fib_metrics;
	int fib_nhs;
	struct callback_head rcu;
	struct fib_nh___4 fib_nh[0];
};

struct fib_result___3 {
	__be32 prefix;
	unsigned char prefixlen;
	unsigned char nh_sel;
	unsigned char type;
	unsigned char scope;
	u32 tclassid;
	struct fib_info___4 *fi;
	struct fib_table *table;
	struct hlist_head *fa_head;
};

struct ipv6_stub___13 {
	int (*ipv6_sock_mc_join)(struct sock___74 *, int, const struct in6_addr *);
	int (*ipv6_sock_mc_drop)(struct sock___74 *, int, const struct in6_addr *);
	int (*ipv6_dst_lookup)(struct net___105 *, struct sock___74 *, struct dst_entry___74 **, struct flowi6 *);
	struct fib6_table * (*fib6_get_table)(struct net___105 *, u32);
	struct fib6_info * (*fib6_lookup)(struct net___105 *, int, struct flowi6 *, int);
	struct fib6_info * (*fib6_table_lookup)(struct net___105 *, struct fib6_table *, int, struct flowi6 *, int);
	struct fib6_info * (*fib6_multipath_select)(const struct net___105 *, struct fib6_info *, struct flowi6 *, int, const struct sk_buff___95 *, int);
	u32 (*ip6_mtu_from_fib6)(struct fib6_info *, struct in6_addr *, struct in6_addr *);
	void (*udpv6_encap_enable)();
	void (*ndisc_send_na)(struct net_device___94 *, const struct in6_addr *, const struct in6_addr *, bool, bool, bool, bool);
	struct neigh_table___74 *nd_tbl;
};

struct ipv6_bpf_stub___13 {
	int (*inet6_bind)(struct sock___74 *, struct sockaddr *, int, bool, bool);
	struct sock___74 * (*udp6_lib_lookup)(struct net___105 *, const struct in6_addr *, __be16, const struct in6_addr *, __be16, int, int, struct udp_table *, struct sk_buff___95 *);
};

struct inet_fill_args {
	u32 portid;
	u32 seq;
	int event;
	unsigned int flags;
	int netnsid;
	int ifindex;
};

struct devinet_sysctl_table {
	struct ctl_table_header *sysctl_header;
	struct ctl_table devinet_vars[33];
};

struct module___376;

struct file___450;

struct kiocb___450;

struct iov_iter___217;

struct poll_table_struct___289;

struct vm_area_struct___451;

struct inode___450;

struct file_lock___450;

struct page___451;

struct pipe_inode_info___131;

struct seq_file___389;

struct file_operations___450 {
	struct module___376 *owner;
	loff_t (*llseek)(struct file___450 *, loff_t, int);
	ssize_t (*read)(struct file___450 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___450 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___450 *, struct iov_iter___217 *);
	ssize_t (*write_iter)(struct kiocb___450 *, struct iov_iter___217 *);
	int (*iopoll)(struct kiocb___450 *, bool);
	int (*iterate)(struct file___450 *, struct dir_context *);
	int (*iterate_shared)(struct file___450 *, struct dir_context *);
	__poll_t (*poll)(struct file___450 *, struct poll_table_struct___289 *);
	long int (*unlocked_ioctl)(struct file___450 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___450 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___450 *, struct vm_area_struct___451 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___450 *, struct file___450 *);
	int (*flush)(struct file___450 *, fl_owner_t);
	int (*release)(struct inode___450 *, struct file___450 *);
	int (*fsync)(struct file___450 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___450 *, int);
	int (*lock)(struct file___450 *, int, struct file_lock___450 *);
	ssize_t (*sendpage)(struct file___450 *, struct page___451 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___450 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___450 *, int, struct file_lock___450 *);
	ssize_t (*splice_write)(struct pipe_inode_info___131 *, struct file___450 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___450 *, loff_t *, struct pipe_inode_info___131 *, size_t, unsigned int);
	int (*setlease)(struct file___450 *, long int, struct file_lock___450 **, void **);
	long int (*fallocate)(struct file___450 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___389 *, struct file___450 *);
	ssize_t (*copy_file_range)(struct file___450 *, loff_t, struct file___450 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___450 *, loff_t, struct file___450 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___450 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___451 {
	u64 seqnum;
	struct vm_area_struct___451 *vmas[4];
};

struct page_frag___451 {
	struct page___451 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___451;

struct mem_cgroup___183;

struct pid___251;

struct cred___418;

struct nsproxy___345;

struct signal_struct___325;

struct bio_list___240;

struct backing_dev_info___240;

struct css_set___299;

struct vm_struct___354;

struct task_struct___452 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___452 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___451 *mm;
	struct mm_struct___451 *active_mm;
	struct vmacache___451 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___452 *real_parent;
	struct task_struct___452 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___452 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___183 *active_memcg;
	long int rh_reserved2;
	struct pid___251 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___251 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___251 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___418 *ptracer_cred;
	const struct cred___418 *real_cred;
	const struct cred___418 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___345 *nsproxy;
	struct signal_struct___325 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___452 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___240 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___240 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___299 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___131 *splice_pipe;
	struct page_frag___451 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___183 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___452 *oom_reaper_list;
	struct vm_struct___354 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___156 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___451 *pgtable_t___451;

struct address_space___450;

struct dev_pagemap___438;

struct page___451 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___450 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___451 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___451 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___451 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___438 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___183 *mem_cgroup;
};

struct pglist_data___451;

struct lruvec___451 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___451 *pgdat;
};

struct zone___451 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___451 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___451 {
	struct zone___451 *zone;
	int zone_idx;
};

struct zonelist___451 {
	struct zoneref___451 _zonerefs[25];
};

struct pglist_data___451 {
	struct zone___451 node_zones[3];
	struct zonelist___451 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___452 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___452 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___451 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___452 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___452 *owner;
};

struct secondary_data___452 {
	void *stack;
	struct task_struct___452 *task;
	long int status;
};

struct blocking_notifier_head___451 {
	struct rw_semaphore___452 rwsem;
	struct notifier_block *head;
};

struct cgroup___299;

struct cgroup_subsys___299;

struct cgroup_subsys_state___299 {
	struct cgroup___299 *cgroup;
	struct cgroup_subsys___299 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___299 *parent;
};

struct kernfs_node___445;

struct cgroup_file___299 {
	struct kernfs_node___445 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___183;

struct mem_cgroup___183 {
	struct cgroup_subsys_state___299 css;
	struct mem_cgroup_id___16 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___299 events_file;
	struct cgroup_file___299 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___452 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___183 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___251;

struct upid___251 {
	int nr;
	struct pid_namespace___251 *ns;
};

struct dentry___450;

struct user_namespace___315;

struct ucounts___315;

struct pid_namespace___251 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___452 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___251 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___450 *proc_self;
	struct dentry___450 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___315 *user_ns;
	struct ucounts___315 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___29 ns;
};

struct pid___251 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___251 numbers[1];
};

struct key___418;

struct user_namespace___315 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___315 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___29 ns;
	long unsigned int flags;
	struct key___418 *persistent_keyring_register;
	struct rw_semaphore___452 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___315 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct user_struct___418 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___418 *uid_keyring;
	struct key___418 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___438;

struct vm_area_struct___451 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___451 *vm_next;
	struct vm_area_struct___451 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___451 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___438 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___450 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___451;

struct mm_struct___451 {
	struct {
		struct vm_area_struct___451 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___450 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___452 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___451 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___452 *owner;
		struct user_namespace___315 *user_ns;
		struct file___450 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___451 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___418 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___418 *session_keyring;
	struct key___418 *process_keyring;
	struct key___418 *thread_keyring;
	struct key___418 *request_key_auth;
	void *security;
	struct user_struct___418 *user;
	struct user_namespace___315 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___106;

struct cgroup_namespace___299;

struct nsproxy___345 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___251 *pid_ns_for_children;
	struct net___106 *net_ns;
	struct cgroup_namespace___299 *cgroup_ns;
};

struct signal_struct___325 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___452 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___452 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___251 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___251 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___451 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___251 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___240;

struct bio_list___240 {
	struct bio___240 *head;
	struct bio___240 *tail;
};

struct bdi_writeback_congested___240;

struct bdi_writeback___240 {
	struct backing_dev_info___240 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___240 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___299 *memcg_css;
	struct cgroup_subsys_state___299 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___418;

struct backing_dev_info___240 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___240 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___418 *dev;
	struct device___418 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___450 *debug_dir;
	struct dentry___450 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___299 {
	struct cgroup_subsys_state___299 *subsys[13];
	refcount_t refcount;
	struct css_set___299 *dom_cset;
	struct cgroup___299 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___299 *mg_src_cgrp;
	struct cgroup___299 *mg_dst_cgrp;
	struct css_set___299 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___450;

struct pipe_buffer___131;

struct pipe_inode_info___131 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___451 *tmp_page;
	struct fasync_struct___450 *fasync_readers;
	struct fasync_struct___450 *fasync_writers;
	struct pipe_buffer___131 *bufs;
	struct user_struct___418 *user;
};

struct vm_struct___354 {
	struct vm_struct___354 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___451 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___337 {
	struct task_struct___452 task;
	long unsigned int stack[8192];
};

struct address_space_operations___450;

struct address_space___450 {
	struct inode___450 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___452 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___450 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___438)(struct vm_area_struct___451 *, long unsigned int, const struct page___451 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___438)(struct page___451 *, void *);

struct dev_pagemap___438 {
	dev_page_fault_t___438 page_fault;
	dev_page_free_t___438 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___418 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___451 {
	struct vfsmount *mnt;
	struct dentry___450 *dentry;
};

struct fown_struct___251 {
	rwlock_t lock;
	struct pid___251 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___450 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___451 f_path;
	struct inode___450 *f_inode;
	const struct file_operations___450 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___251 f_owner;
	const struct cred___418 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___450 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___438;

struct vm_operations_struct___438 {
	void (*open)(struct vm_area_struct___451 *);
	void (*close)(struct vm_area_struct___451 *);
	int (*split)(struct vm_area_struct___451 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___451 *);
	vm_fault_t (*fault)(struct vm_fault___438 *);
	vm_fault_t (*huge_fault)(struct vm_fault___438 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___438 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___451 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___438 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___438 *);
	int (*access)(struct vm_area_struct___451 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___451 *);
	int (*set_policy)(struct vm_area_struct___451 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___451 *, long unsigned int);
	struct page___451 * (*find_special_page)(struct vm_area_struct___451 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___451 {
	struct task_struct___452 *task;
	struct core_thread___451 *next;
};

struct core_state___451 {
	atomic_t nr_threads;
	struct core_thread___451 dumper;
	struct completion startup;
};

struct vm_fault___438 {
	struct vm_area_struct___451 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___451 *cow_page;
	struct mem_cgroup___183 *memcg;
	struct page___451 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___451 prealloc_pte;
};

struct crypto_async_request___37;

typedef void (*crypto_completion_t___37)(struct crypto_async_request___37 *, int);

struct crypto_tfm___37;

struct crypto_async_request___37 {
	struct list_head list;
	crypto_completion_t___37 complete;
	void *data;
	struct crypto_tfm___37 *tfm;
	u32 flags;
};

struct crypto_ablkcipher___37;

struct ablkcipher_request___37;

struct ablkcipher_tfm___37 {
	int (*setkey)(struct crypto_ablkcipher___37 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___37 *);
	int (*decrypt)(struct ablkcipher_request___37 *);
	struct crypto_ablkcipher___37 *base;
	unsigned int ivsize;
	unsigned int reqsize;
};

struct blkcipher_desc___37;

struct blkcipher_tfm___37 {
	void *iv;
	int (*setkey)(struct crypto_tfm___37 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___37 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___37 *, struct scatterlist *, struct scatterlist *, unsigned int);
};

struct cipher_tfm___37 {
	int (*cit_setkey)(struct crypto_tfm___37 *, const u8 *, unsigned int);
	void (*cit_encrypt_one)(struct crypto_tfm___37 *, u8 *, const u8 *);
	void (*cit_decrypt_one)(struct crypto_tfm___37 *, u8 *, const u8 *);
};

struct compress_tfm___37 {
	int (*cot_compress)(struct crypto_tfm___37 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*cot_decompress)(struct crypto_tfm___37 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___37;

struct crypto_tfm___37 {
	u32 crt_flags;
	union {
		struct ablkcipher_tfm___37 ablkcipher;
		struct blkcipher_tfm___37 blkcipher;
		struct cipher_tfm___37 cipher;
		struct compress_tfm___37 compress;
	} crt_u;
	void (*exit)(struct crypto_tfm___37 *);
	struct crypto_alg___37 *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct ablkcipher_request___37 {
	struct crypto_async_request___37 base;
	unsigned int nbytes;
	void *info;
	struct scatterlist *src;
	struct scatterlist *dst;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_blkcipher___37;

struct blkcipher_desc___37 {
	struct crypto_blkcipher___37 *tfm;
	void *info;
	u32 flags;
};

struct crypto_blkcipher___37 {
	struct crypto_tfm___37 base;
};

struct ablkcipher_alg___37 {
	int (*setkey)(struct crypto_ablkcipher___37 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___37 *);
	int (*decrypt)(struct ablkcipher_request___37 *);
	int (*givencrypt)(struct skcipher_givcrypt_request *);
	int (*givdecrypt)(struct skcipher_givcrypt_request *);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct crypto_ablkcipher___37 {
	struct crypto_tfm___37 base;
};

struct blkcipher_alg___37 {
	int (*setkey)(struct crypto_tfm___37 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___37 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___37 *, struct scatterlist *, struct scatterlist *, unsigned int);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct cipher_alg___37 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___37 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___37 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___37 *, u8 *, const u8 *);
};

struct compress_alg___37 {
	int (*coa_compress)(struct crypto_tfm___37 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___37 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___37 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type *cra_type;
	union {
		struct ablkcipher_alg___37 ablkcipher;
		struct blkcipher_alg___37 blkcipher;
		struct cipher_alg___37 cipher;
		struct compress_alg___37 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___37 *);
	void (*cra_exit)(struct crypto_tfm___37 *);
	void (*cra_destroy)(struct crypto_alg___37 *);
	struct module___376 *cra_module;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___437;

struct kobj_type___437;

struct kobject___438 {
	const char *name;
	struct list_head entry;
	struct kobject___438 *parent;
	struct kset___437 *kset;
	struct kobj_type___437 *ktype;
	struct kernfs_node___445 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___376 {
	struct kobject___438 kobj;
	struct module___376 *mod;
	struct kobject___438 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___376 {
	struct module___376 *mod;
	struct latch_tree_node node;
};

struct module_layout___376 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___376 mtn;
};

struct module_attribute___376;

struct kernel_param___376;

struct module___376 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___376 mkobj;
	struct module_attribute___376 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___438 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___376 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___376 core_layout;
	struct module_layout___376 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide53;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide54;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct crypto_cipher___21 {
	struct crypto_tfm___37 base;
};

struct bio_vec___242 {
	struct page___451 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___217 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___242 *bvec;
		struct pipe_inode_info___131 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct msghdr___78 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___217 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___450 *msg_iocb;
};

struct kiocb___450 {
	struct file___450 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___450 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dentry_operations___450;

struct super_block___450;

struct dentry___450 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___450 *d_parent;
	struct qstr d_name;
	struct inode___450 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___450 *d_op;
	struct super_block___450 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___450;

struct block_device___450;

struct inode___450 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___450 *i_op;
	struct super_block___450 *i_sb;
	struct address_space___450 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___452 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___240 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___450 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___450 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___131 *i_pipe;
		struct block_device___450 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___450 {
	int (*d_revalidate)(struct dentry___450 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___450 *, unsigned int);
	int (*d_hash)(const struct dentry___450 *, struct qstr *);
	int (*d_compare)(const struct dentry___450 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___450 *);
	int (*d_init)(struct dentry___450 *);
	void (*d_release)(struct dentry___450 *);
	void (*d_prune)(struct dentry___450 *);
	void (*d_iput)(struct dentry___450 *, struct inode___450 *);
	char * (*d_dname)(struct dentry___450 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___451 *);
	int (*d_manage)(const struct path___451 *, bool);
	struct dentry___450 * (*d_real)(struct dentry___450 *, const struct inode___450 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___450;

struct mem_dqinfo___450 {
	struct quota_format_type___450 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___450;

struct quota_info___450 {
	unsigned int flags;
	struct rw_semaphore___452 dqio_sem;
	struct inode___450 *files[3];
	struct mem_dqinfo___450 info[3];
	const struct quota_format_ops___450 *ops[3];
};

struct rcuwait___450 {
	struct task_struct___452 *task;
};

struct percpu_rw_semaphore___450 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___452 rw_sem;
	struct rcuwait___450 writer;
	int readers_block;
};

struct sb_writers___450 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___450 rw_sem[3];
};

struct shrink_control___183;

struct shrinker___183 {
	long unsigned int (*count_objects)(struct shrinker___183 *, struct shrink_control___183 *);
	long unsigned int (*scan_objects)(struct shrinker___183 *, struct shrink_control___183 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___450;

struct super_operations___450;

struct dquot_operations___450;

struct quotactl_ops___450;

struct super_block___450 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___450 *s_type;
	const struct super_operations___450 *s_op;
	const struct dquot_operations___450 *dq_op;
	const struct quotactl_ops___450 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___450 *s_root;
	struct rw_semaphore___452 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___450 *s_bdev;
	struct backing_dev_info___240 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___450 s_dquot;
	struct sb_writers___450 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___450 *s_d_op;
	int cleancache_poolid;
	struct shrinker___183 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___315 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___183 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___183 *memcg;
};

struct iattr___450 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___450 *ia_file;
};

struct dquot___450 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___450 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___450 {
	int qf_fmt_id;
	const struct quota_format_ops___450 *qf_ops;
	struct module___376 *qf_owner;
	struct quota_format_type___450 *qf_next;
};

struct quota_format_ops___450 {
	int (*check_quota_file)(struct super_block___450 *, int);
	int (*read_file_info)(struct super_block___450 *, int);
	int (*write_file_info)(struct super_block___450 *, int);
	int (*free_file_info)(struct super_block___450 *, int);
	int (*read_dqblk)(struct dquot___450 *);
	int (*commit_dqblk)(struct dquot___450 *);
	int (*release_dqblk)(struct dquot___450 *);
	int (*get_next_id)(struct super_block___450 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___450 {
	int (*write_dquot)(struct dquot___450 *);
	struct dquot___450 * (*alloc_dquot)(struct super_block___450 *, int);
	void (*destroy_dquot)(struct dquot___450 *);
	int (*acquire_dquot)(struct dquot___450 *);
	int (*release_dquot)(struct dquot___450 *);
	int (*mark_dirty)(struct dquot___450 *);
	int (*write_info)(struct super_block___450 *, int);
	qsize_t * (*get_reserved_space)(struct inode___450 *);
	int (*get_projid)(struct inode___450 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___450 *, qsize_t *);
	int (*get_next_id)(struct super_block___450 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___450 {
	int (*quota_on)(struct super_block___450 *, int, int, const struct path___451 *);
	int (*quota_off)(struct super_block___450 *, int);
	int (*quota_enable)(struct super_block___450 *, unsigned int);
	int (*quota_disable)(struct super_block___450 *, unsigned int);
	int (*quota_sync)(struct super_block___450 *, int);
	int (*set_info)(struct super_block___450 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___450 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___450 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___450 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___450 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___450 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___203;

struct address_space_operations___450 {
	int (*writepage)(struct page___451 *, struct writeback_control___203 *);
	int (*readpage)(struct file___450 *, struct page___451 *);
	int (*writepages)(struct address_space___450 *, struct writeback_control___203 *);
	int (*set_page_dirty)(struct page___451 *);
	int (*readpages)(struct file___450 *, struct address_space___450 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___450 *, struct address_space___450 *, loff_t, unsigned int, unsigned int, struct page___451 **, void **);
	int (*write_end)(struct file___450 *, struct address_space___450 *, loff_t, unsigned int, unsigned int, struct page___451 *, void *);
	sector_t (*bmap)(struct address_space___450 *, sector_t);
	void (*invalidatepage)(struct page___451 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___451 *, gfp_t);
	void (*freepage)(struct page___451 *);
	ssize_t (*direct_IO)(struct kiocb___450 *, struct iov_iter___217 *);
	int (*migratepage)(struct address_space___450 *, struct page___451 *, struct page___451 *, enum migrate_mode);
	bool (*isolate_page)(struct page___451 *, isolate_mode_t);
	void (*putback_page)(struct page___451 *);
	int (*launder_page)(struct page___451 *);
	int (*is_partially_uptodate)(struct page___451 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___451 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___450 *, struct page___451 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___450 *, sector_t *);
	void (*swap_deactivate)(struct file___450 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___203 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___240 *wb;
	struct inode___450 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___450 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___450 *bd_inode;
	struct super_block___450 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___450 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___240 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___450 {
	struct dentry___450 * (*lookup)(struct inode___450 *, struct dentry___450 *, unsigned int);
	const char * (*get_link)(struct dentry___450 *, struct inode___450 *, struct delayed_call *);
	int (*permission)(struct inode___450 *, int);
	struct posix_acl * (*get_acl)(struct inode___450 *, int);
	int (*readlink)(struct dentry___450 *, char *, int);
	int (*create)(struct inode___450 *, struct dentry___450 *, umode_t, bool);
	int (*link)(struct dentry___450 *, struct inode___450 *, struct dentry___450 *);
	int (*unlink)(struct inode___450 *, struct dentry___450 *);
	int (*symlink)(struct inode___450 *, struct dentry___450 *, const char *);
	int (*mkdir)(struct inode___450 *, struct dentry___450 *, umode_t);
	int (*rmdir)(struct inode___450 *, struct dentry___450 *);
	int (*mknod)(struct inode___450 *, struct dentry___450 *, umode_t, dev_t);
	int (*rename)(struct inode___450 *, struct dentry___450 *, struct inode___450 *, struct dentry___450 *, unsigned int);
	int (*setattr)(struct dentry___450 *, struct iattr___450 *);
	int (*getattr)(const struct path___451 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___450 *, char *, size_t);
	int (*fiemap)(struct inode___450 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___450 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___450 *, struct dentry___450 *, struct file___450 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___450 *, struct dentry___450 *, umode_t);
	int (*set_acl)(struct inode___450 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___450 {
	void (*fl_copy_lock)(struct file_lock___450 *, struct file_lock___450 *);
	void (*fl_release_private)(struct file_lock___450 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___450;

struct file_lock___450 {
	struct file_lock___450 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___450 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___450 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___450 *fl_ops;
	const struct lock_manager_operations___450 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___450 {
	int (*lm_compare_owner)(struct file_lock___450 *, struct file_lock___450 *);
	long unsigned int (*lm_owner_key)(struct file_lock___450 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___450 *);
	int (*lm_grant)(struct file_lock___450 *, int);
	bool (*lm_break)(struct file_lock___450 *);
	int (*lm_change)(struct file_lock___450 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___450 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___450 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___450 *fa_next;
	struct file___450 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___450 {
	const char *name;
	int fs_flags;
	struct dentry___450 * (*mount)(struct file_system_type___450 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___450 *);
	struct module___376 *owner;
	struct file_system_type___450 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___450 {
	struct inode___450 * (*alloc_inode)(struct super_block___450 *);
	void (*destroy_inode)(struct inode___450 *);
	void (*dirty_inode)(struct inode___450 *, int);
	int (*write_inode)(struct inode___450 *, struct writeback_control___203 *);
	int (*drop_inode)(struct inode___450 *);
	void (*evict_inode)(struct inode___450 *);
	void (*put_super)(struct super_block___450 *);
	int (*sync_fs)(struct super_block___450 *, int);
	int (*freeze_super)(struct super_block___450 *);
	int (*freeze_fs)(struct super_block___450 *);
	int (*thaw_super)(struct super_block___450 *);
	int (*unfreeze_fs)(struct super_block___450 *);
	int (*statfs)(struct dentry___450 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___450 *, int *, char *);
	void (*umount_begin)(struct super_block___450 *);
	int (*show_options)(struct seq_file___389 *, struct dentry___450 *);
	int (*show_devname)(struct seq_file___389 *, struct dentry___450 *);
	int (*show_path)(struct seq_file___389 *, struct dentry___450 *);
	int (*show_stats)(struct seq_file___389 *, struct dentry___450 *);
	ssize_t (*quota_read)(struct super_block___450 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___450 *, int, const char *, size_t, loff_t);
	struct dquot___450 ** (*get_dquots)(struct inode___450 *);
	int (*bdev_try_to_free_page)(struct super_block___450 *, struct page___451 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___450 *, struct shrink_control___183 *);
	long int (*free_cached_objects)(struct super_block___450 *, struct shrink_control___183 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___299)(struct file___450 *, wait_queue_head_t *, struct poll_table_struct___289 *);

struct poll_table_struct___289 {
	poll_queue_proc___299 _qproc;
	__poll_t _key;
};

struct seq_operations___389;

struct seq_file___389 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___389 *op;
	int poll_event;
	const struct file___450 *file;
	void *private;
};

typedef void bio_end_io_t___240(struct bio___240 *);

struct bio_integrity_payload___240;

struct bio_set___240;

struct bio___240 {
	struct bio___240 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___240 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___240 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___242 *bi_io_vec;
	struct bio_set___240 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___242 bi_inline_vecs[0];
};

struct socket_wq___76 {
	wait_queue_head_t wait;
	struct fasync_struct___450 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct sock___75;

struct proto_ops___76;

struct socket___77 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___76 *wq;
	struct file___450 *file;
	struct sock___75 *sk;
	const struct proto_ops___76 *ops;
};

typedef struct {
	struct net___106 *net;
} possible_net_t___97;

struct proto___75;

struct sock_common___75 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___75 *skc_prot;
	possible_net_t___97 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___75 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___96;

struct sk_buff_head___95 {
	struct sk_buff___96 *next;
	struct sk_buff___96 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___75;

struct xfrm_policy___16;

struct dst_entry___75;

struct net_device___95;

struct sock___75 {
	struct sock_common___75 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___95 sk_error_queue;
	struct sk_buff_head___95 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___96 *head;
		struct sk_buff___96 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___75 *sk_filter;
	union {
		struct socket_wq___76 *sk_wq;
		struct socket_wq___76 *sk_wq_raw;
	};
	struct xfrm_policy___16 *sk_policy[2];
	struct dst_entry___75 *sk_rx_dst;
	struct dst_entry___75 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___96 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___95 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___451 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___75 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___251 *sk_peer_pid;
	const struct cred___418 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___77 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___183 *sk_memcg;
	void (*sk_state_change)(struct sock___75 *);
	void (*sk_data_ready)(struct sock___75 *);
	void (*sk_write_space)(struct sock___75 *);
	void (*sk_error_report)(struct sock___75 *);
	int (*sk_backlog_rcv)(struct sock___75 *, struct sk_buff___96 *);
	struct sk_buff___96 * (*sk_validate_xmit_skb)(struct sock___75 *, struct net_device___95 *, struct sk_buff___96 *);
	void (*sk_destruct)(struct sock___75 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

typedef int (*sk_read_actor_t___75)(read_descriptor_t *, struct sk_buff___96 *, unsigned int, size_t);

struct proto_ops___76 {
	int family;
	struct module___376 *owner;
	int (*release)(struct socket___77 *);
	int (*bind)(struct socket___77 *, struct sockaddr *, int);
	int (*connect)(struct socket___77 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___77 *, struct socket___77 *);
	int (*accept)(struct socket___77 *, struct socket___77 *, int, bool);
	int (*getname)(struct socket___77 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___450 *, struct socket___77 *, struct poll_table_struct___289 *);
	int (*ioctl)(struct socket___77 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___77 *, int);
	int (*shutdown)(struct socket___77 *, int);
	int (*setsockopt)(struct socket___77 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___77 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___77 *, struct msghdr___78 *, size_t);
	int (*recvmsg)(struct socket___77 *, struct msghdr___78 *, size_t, int);
	int (*mmap)(struct file___450 *, struct socket___77 *, struct vm_area_struct___451 *);
	ssize_t (*sendpage)(struct socket___77 *, struct page___451 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___77 *, loff_t *, struct pipe_inode_info___131 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___75 *, int);
	int (*peek_len)(struct socket___77 *);
	int (*read_sock)(struct sock___75 *, read_descriptor_t *, sk_read_actor_t___75);
	int (*sendpage_locked)(struct sock___75 *, struct page___451 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___75 *, struct msghdr___78 *, size_t);
	int (*set_rcvlowat)(struct sock___75 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct sec_path___16;

struct nf_bridge_info___95;

struct sk_buff___96 {
	union {
		struct {
			struct sk_buff___96 *next;
			struct sk_buff___96 *prev;
			union {
				struct net_device___95 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___75 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___96 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path___16 *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___95 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct net_proto_family___4 {
	int family;
	int (*create)(struct net___106 *, struct socket___77 *, int, int);
	struct module___376 *owner;
};

struct inet_frags___95;

struct netns_frags___95 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___95 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ip_ra_chain___41;

struct fib_rules_ops___75;

struct tcp_congestion_ops___18;

struct tcp_fastopen_context___18;

struct fib_notifier_ops___76;

struct netns_ipv4___95 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___41 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___75 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___75 *fibnl;
	struct sock___75 **icmp_sk;
	struct sock___75 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___75 **tcp_sk;
	struct netns_frags___95 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops___18 *tcp_congestion_control;
	struct tcp_fastopen_context___18 *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___75 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___76 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___76 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___75;

struct dst_ops___106 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___106 *);
	struct dst_entry___75 * (*check)(struct dst_entry___75 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___75 *);
	unsigned int (*mtu)(const struct dst_entry___75 *);
	u32 * (*cow_metrics)(struct dst_entry___75 *, long unsigned int);
	void (*destroy)(struct dst_entry___75 *);
	void (*ifdown)(struct dst_entry___75 *, struct net_device___95 *, int);
	struct dst_entry___75 * (*negative_advice)(struct dst_entry___75 *);
	void (*link_failure)(struct sk_buff___96 *);
	void (*update_pmtu)(struct dst_entry___75 *, struct sock___75 *, struct sk_buff___96 *, u32);
	void (*redirect)(struct dst_entry___75 *, struct sock___75 *, struct sk_buff___96 *);
	int (*local_out)(struct net___106 *, struct sock___75 *, struct sk_buff___96 *);
	struct neighbour___75 * (*neigh_lookup)(const struct dst_entry___75 *, struct sk_buff___96 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___75 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_info___20;

struct rt6_info___20;

struct fib6_table___20;

struct netns_ipv6___106 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___95 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info___20 *fib6_null_entry;
	struct rt6_info___20 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___20 *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___106 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info___20 *ip6_prohibit_entry;
	struct rt6_info___20 *ip6_blk_hole_entry;
	struct fib6_table___20 *fib6_local_tbl;
	struct fib_rules_ops___75 *fib6_rules_ops;
	struct sock___75 **icmp_sk;
	struct sock___75 *ndisc_sk;
	struct sock___75 *tcp_sk;
	struct sock___75 *igmp_sk;
	struct sock___75 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___75 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___76 *notifier_ops;
	struct fib_notifier_ops___76 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___76 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___75 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct nf_hook_entries___13;

struct netns_nf___14 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_queue_handler *queue_handler;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header *nf_log_dir_header;
	struct nf_hook_entries___13 *hooks_ipv4[5];
	struct nf_hook_entries___13 *hooks_ipv6[5];
	struct nf_hook_entries___13 *hooks_arp[3];
	struct nf_hook_entries___13 *hooks_bridge[5];
	bool defrag_ipv4;
	bool defrag_ipv6;
};

struct netns_nf_frag___95 {
	struct netns_frags___95 frags;
};

struct netns_xfrm___106 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___75 *nlsk;
	struct sock___75 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___106 xfrm4_dst_ops;
	struct dst_ops___106 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___85;

struct net___106 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___315 *user_ns;
	struct ucounts___315 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___29 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___75 *rtnl;
	struct sock___75 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___95 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___95 ipv4;
	struct netns_ipv6___106 ipv6;
	struct netns_sctp___76 sctp;
	struct netns_nf___14 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___95 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___75 *nfnl;
	struct sock___75 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___106 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___75 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___85 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_info___418 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___418 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___418;

struct bus_type___418;

struct device_driver___418;

struct dev_pm_domain___418;

struct dma_map_ops___190;

struct fwnode_handle___338;

struct class___418;

struct attribute_group___415;

struct device___418 {
	struct device___418 *parent;
	struct device_private *p;
	struct kobject___438 kobj;
	const char *init_name;
	const struct device_type___418 *type;
	struct mutex mutex;
	struct bus_type___418 *bus;
	struct device_driver___418 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___418 power;
	struct dev_pm_domain___418 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___190 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___338 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___418 *class;
	const struct attribute_group___415 **groups;
	void (*release)(struct device___418 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct kobj_attribute___428 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___438 *, struct kobj_attribute___428 *, char *);
	ssize_t (*store)(struct kobject___438 *, struct kobj_attribute___428 *, const char *, size_t);
};

typedef void compound_page_dtor___438(struct page___451 *);

struct kernfs_root___444;

struct kernfs_elem_dir___444 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___444 *root;
};

struct kernfs_syscall_ops___444;

struct kernfs_root___444 {
	struct kernfs_node___445 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___444 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___444 {
	struct kernfs_node___445 *target_kn;
};

struct kernfs_ops___444;

struct kernfs_elem_attr___444 {
	const struct kernfs_ops___444 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___445 *notify_next;
};

struct kernfs_node___445 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___445 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___444 dir;
		struct kernfs_elem_symlink___444 symlink;
		struct kernfs_elem_attr___444 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___444;

struct kernfs_ops___444 {
	int (*open)(struct kernfs_open_file___444 *);
	void (*release)(struct kernfs_open_file___444 *);
	int (*seq_show)(struct seq_file___389 *, void *);
	void * (*seq_start)(struct seq_file___389 *, loff_t *);
	void * (*seq_next)(struct seq_file___389 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___389 *, void *);
	ssize_t (*read)(struct kernfs_open_file___444 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___444 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___444 *, struct vm_area_struct___451 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___444 *, struct poll_table_struct___289 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___444 {
	int (*remount_fs)(struct kernfs_root___444 *, int *, char *);
	int (*show_options)(struct seq_file___389 *, struct kernfs_root___444 *);
	int (*mkdir)(struct kernfs_node___445 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___445 *);
	int (*rename)(struct kernfs_node___445 *, struct kernfs_node___445 *, const char *);
	int (*show_path)(struct seq_file___389 *, struct kernfs_node___445 *, struct kernfs_root___444 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___444 {
	struct kernfs_node___445 *kn;
	struct file___450 *file;
	struct seq_file___389 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___438 *vm_ops;
};

struct kobj_ns_type_operations___75 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___75 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___414;

struct attribute_group___415 {
	const char *name;
	umode_t (*is_visible)(struct kobject___438 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___438 *, struct bin_attribute___414 *, int);
	struct attribute **attrs;
	struct bin_attribute___414 **bin_attrs;
};

struct bin_attribute___414 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___450 *, struct kobject___438 *, struct bin_attribute___414 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___450 *, struct kobject___438 *, struct bin_attribute___414 *, char *, loff_t, size_t);
	int (*mmap)(struct file___450 *, struct kobject___438 *, struct bin_attribute___414 *, struct vm_area_struct___451 *);
};

struct sysfs_ops___437 {
	ssize_t (*show)(struct kobject___438 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___438 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___437;

struct kset___437 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___438 kobj;
	const struct kset_uevent_ops___437 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___437 {
	void (*release)(struct kobject___438 *);
	const struct sysfs_ops___437 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___75 * (*child_ns_type)(struct kobject___438 *);
	const void * (*namespace)(struct kobject___438 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___437 {
	int (* const filter)(struct kset___437 *, struct kobject___438 *);
	const char * (* const name)(struct kset___437 *, struct kobject___438 *);
	int (* const uevent)(struct kset___437 *, struct kobject___438 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___418 {
	int (*prepare)(struct device___418 *);
	void (*complete)(struct device___418 *);
	int (*suspend)(struct device___418 *);
	int (*resume)(struct device___418 *);
	int (*freeze)(struct device___418 *);
	int (*thaw)(struct device___418 *);
	int (*poweroff)(struct device___418 *);
	int (*restore)(struct device___418 *);
	int (*suspend_late)(struct device___418 *);
	int (*resume_early)(struct device___418 *);
	int (*freeze_late)(struct device___418 *);
	int (*thaw_early)(struct device___418 *);
	int (*poweroff_late)(struct device___418 *);
	int (*restore_early)(struct device___418 *);
	int (*suspend_noirq)(struct device___418 *);
	int (*resume_noirq)(struct device___418 *);
	int (*freeze_noirq)(struct device___418 *);
	int (*thaw_noirq)(struct device___418 *);
	int (*poweroff_noirq)(struct device___418 *);
	int (*restore_noirq)(struct device___418 *);
	int (*runtime_suspend)(struct device___418 *);
	int (*runtime_resume)(struct device___418 *);
	int (*runtime_idle)(struct device___418 *);
};

struct dev_pm_domain___418 {
	struct dev_pm_ops___418 ops;
	void (*detach)(struct device___418 *, bool);
	int (*activate)(struct device___418 *);
	void (*sync)(struct device___418 *);
	void (*dismiss)(struct device___418 *);
};

struct bus_type___418 {
	const char *name;
	const char *dev_name;
	struct device___418 *dev_root;
	const struct attribute_group___415 **bus_groups;
	const struct attribute_group___415 **dev_groups;
	const struct attribute_group___415 **drv_groups;
	int (*match)(struct device___418 *, struct device_driver___418 *);
	int (*uevent)(struct device___418 *, struct kobj_uevent_env *);
	int (*probe)(struct device___418 *);
	int (*remove)(struct device___418 *);
	void (*shutdown)(struct device___418 *);
	int (*online)(struct device___418 *);
	int (*offline)(struct device___418 *);
	int (*suspend)(struct device___418 *, pm_message_t);
	int (*resume)(struct device___418 *);
	int (*num_vf)(struct device___418 *);
	int (*dma_configure)(struct device___418 *);
	const struct dev_pm_ops___418 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___418 {
	const char *name;
	struct bus_type___418 *bus;
	struct module___376 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___418 *);
	int (*remove)(struct device___418 *);
	void (*shutdown)(struct device___418 *);
	int (*suspend)(struct device___418 *, pm_message_t);
	int (*resume)(struct device___418 *);
	const struct attribute_group___415 **groups;
	const struct dev_pm_ops___418 *pm;
	void (*coredump)(struct device___418 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___418 {
	const char *name;
	const struct attribute_group___415 **groups;
	int (*uevent)(struct device___418 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___418 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___418 *);
	const struct dev_pm_ops___418 *pm;
};

struct class___418 {
	const char *name;
	struct module___376 *owner;
	const struct attribute_group___415 **class_groups;
	const struct attribute_group___415 **dev_groups;
	struct kobject___438 *dev_kobj;
	int (*dev_uevent)(struct device___418 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___418 *, umode_t *);
	void (*class_release)(struct class___418 *);
	void (*dev_release)(struct device___418 *);
	int (*shutdown_pre)(struct device___418 *);
	const struct kobj_ns_type_operations___75 *ns_type;
	const void * (*namespace)(struct device___418 *);
	const struct dev_pm_ops___418 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___190 {
	void * (*alloc)(struct device___418 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___418 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___418 *, struct vm_area_struct___451 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___418 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___418 *, struct page___451 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___418 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___418 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___418 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___418 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___418 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___418 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___418 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___418 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___418 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___418 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___418 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___418 *, u64);
	u64 (*get_required_mask)(struct device___418 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___338;

struct fwnode_handle___338 {
	struct fwnode_handle___338 *secondary;
	const struct fwnode_operations___338 *ops;
};

struct fwnode_reference_args___338;

struct fwnode_endpoint___338;

struct fwnode_operations___338 {
	struct fwnode_handle___338 * (*get)(struct fwnode_handle___338 *);
	void (*put)(struct fwnode_handle___338 *);
	bool (*device_is_available)(const struct fwnode_handle___338 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___338 *, const struct device___418 *);
	bool (*property_present)(const struct fwnode_handle___338 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___338 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___338 *, const char *, const char **, size_t);
	struct fwnode_handle___338 * (*get_parent)(const struct fwnode_handle___338 *);
	struct fwnode_handle___338 * (*get_next_child_node)(const struct fwnode_handle___338 *, struct fwnode_handle___338 *);
	struct fwnode_handle___338 * (*get_named_child_node)(const struct fwnode_handle___338 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___338 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___338 *);
	struct fwnode_handle___338 * (*graph_get_next_endpoint)(const struct fwnode_handle___338 *, struct fwnode_handle___338 *);
	struct fwnode_handle___338 * (*graph_get_remote_endpoint)(const struct fwnode_handle___338 *);
	struct fwnode_handle___338 * (*graph_get_port_parent)(struct fwnode_handle___338 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___338 *, struct fwnode_endpoint___338 *);
};

struct fwnode_endpoint___338 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___338 *local_fwnode;
};

struct fwnode_reference_args___338 {
	struct fwnode_handle___338 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___131;

struct pipe_buffer___131 {
	struct page___451 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___131 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___131 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___131 *, struct pipe_buffer___131 *);
	void (*release)(struct pipe_inode_info___131 *, struct pipe_buffer___131 *);
	int (*steal)(struct pipe_inode_info___131 *, struct pipe_buffer___131 *);
	union {
		bool (*get)(struct pipe_inode_info___131 *, struct pipe_buffer___131 *);
		struct {
			void (*get)(struct pipe_inode_info___131 *, struct pipe_buffer___131 *);
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
};

struct nf_bridge_info___95 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___95 = 0,
		BRNF_PROTO_8021Q___95 = 1,
		BRNF_PROTO_PPPOE___95 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___95 *physindev;
	struct net_device___95 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___95(struct sk_buff___96 **);

struct net_device_ops___95;

struct ethtool_ops___95;

struct l3mdev_ops___75;

struct ndisc_ops___46;

struct xfrmdev_ops___95;

struct tlsdev_ops___95;

struct header_ops___95;

struct in_device___11;

struct inet6_dev___46;

struct netdev_rx_queue___95;

struct mini_Qdisc___87;

struct netdev_queue___95;

struct Qdisc___87;

struct rtnl_link_ops___87;

struct dcbnl_rtnl_ops___95;

struct net_device___95 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___95 *netdev_ops;
	const struct ethtool_ops___95 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___75 *l3mdev_ops;
	const struct ndisc_ops___46 *ndisc_ops;
	const struct xfrmdev_ops___95 *xfrmdev_ops;
	const struct tlsdev_ops___95 *tlsdev_ops;
	const struct header_ops___95 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___437 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device___11 *ip_ptr;
	struct inet6_dev___46 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___95 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___85 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___95 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___87 *miniq_ingress;
	struct netdev_queue___95 *ingress_queue;
	struct nf_hook_entries___13 *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___95 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___87 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___87 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___95 = 0,
		NETREG_REGISTERED___95 = 1,
		NETREG_UNREGISTERING___95 = 2,
		NETREG_UNREGISTERED___95 = 3,
		NETREG_RELEASED___95 = 4,
		NETREG_DUMMY___95 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___95 = 0,
		RTNL_LINK_INITIALIZING___95 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___95 *);
	struct netpoll_info *npinfo;
	possible_net_t___97 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___418 dev;
	const struct attribute_group___415 *sysfs_groups[4];
	const struct attribute_group___415 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___87 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___95 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct skb_frag_struct___24 {
	struct {
		struct page___451 *p;
	} page;
	__u32 page_offset;
	__u32 size;
};

typedef struct skb_frag_struct___24 skb_frag_t___24;

struct skb_shared_info___24 {
	__u8 __unused;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___96 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___24 frags[16];
};

struct xfrm_state___16;

struct sec_path___16 {
	refcount_t refcnt;
	int len;
	int olen;
	struct xfrm_state___16 *xvec[6];
	struct xfrm_offload ovec[1];
};

struct ethtool_ops___95 {
	int (*get_settings)(struct net_device___95 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___95 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___95 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___95 *);
	void (*get_regs)(struct net_device___95 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___95 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___95 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___95 *);
	void (*set_msglevel)(struct net_device___95 *, u32);
	int (*nway_reset)(struct net_device___95 *);
	u32 (*get_link)(struct net_device___95 *);
	int (*get_eeprom_len)(struct net_device___95 *);
	int (*get_eeprom)(struct net_device___95 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___95 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___95 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___95 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___95 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___95 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___95 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___95 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___95 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___95 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___95 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___95 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___95 *);
	void (*complete)(struct net_device___95 *);
	u32 (*get_priv_flags)(struct net_device___95 *);
	int (*set_priv_flags)(struct net_device___95 *, u32);
	int (*get_sset_count)(struct net_device___95 *, int);
	int (*get_rxnfc)(struct net_device___95 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___95 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___95 *, struct ethtool_flash *);
	int (*reset)(struct net_device___95 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___95 *);
	u32 (*get_rxfh_indir_size)(struct net_device___95 *);
	int (*get_rxfh)(struct net_device___95 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___95 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___95 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___95 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___95 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___95 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___95 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___95 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___95 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___95 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___95 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___95 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___95 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___95 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___95 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___95 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___95 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___95 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___95 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___95 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___95 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___95 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	int (*get_fecparam)(struct net_device___95 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___95 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___95 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___95 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___95 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___95;

struct inet_frags___95 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___95 *, const void *);
	void (*destructor)(struct inet_frag_queue___95 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___95 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___96 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___96 *fragments_tail;
	struct sk_buff___96 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___95 *net;
	struct callback_head rcu;
};

struct ip_ra_chain___41 {
	struct ip_ra_chain___41 *next;
	struct sock___75 *sk;
	union {
		void (*destructor)(struct sock___75 *);
		struct sock___75 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___75;

struct fib_lookup_arg___75;

struct fib_rules_ops___75 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___75 *, struct flowi *, int, struct fib_lookup_arg___75 *);
	bool (*suppress)(struct fib_rule___75 *, struct fib_lookup_arg___75 *);
	int (*match)(struct fib_rule___75 *, struct flowi *, int);
	int (*configure)(struct fib_rule___75 *, struct sk_buff___96 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___75 *);
	int (*compare)(struct fib_rule___75 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___75 *, struct sk_buff___96 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___75 *);
	void (*flush_cache)(struct fib_rules_ops___75 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___376 *owner;
	struct net___106 *fro_net;
	struct callback_head rcu;
};

struct tcp_congestion_ops___18 {
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___75 *);
	void (*release)(struct sock___75 *);
	u32 (*ssthresh)(struct sock___75 *);
	void (*cong_avoid)(struct sock___75 *, u32, u32);
	void (*set_state)(struct sock___75 *, u8);
	void (*cwnd_event)(struct sock___75 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___75 *, u32);
	u32 (*undo_cwnd)(struct sock___75 *);
	void (*pkts_acked)(struct sock___75 *, const struct ack_sample *);
	u32 (*min_tso_segs)(struct sock___75 *);
	u32 (*sndbuf_expand)(struct sock___75 *);
	void (*cong_control)(struct sock___75 *, const struct rate_sample *);
	size_t (*get_info)(struct sock___75 *, u32, int *, union tcp_cc_info *);
	char name[16];
	struct module___376 *owner;
};

struct tcp_fastopen_context___18 {
	struct crypto_cipher___21 *tfm;
	__u8 key[16];
	struct callback_head rcu;
};

struct fib_notifier_ops___76 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___106 *);
	int (*fib_dump)(struct net___106 *, struct notifier_block *);
	struct module___376 *owner;
	struct callback_head rcu;
};

struct lwtunnel_state___9;

struct dst_entry___75 {
	struct net_device___95 *dev;
	struct dst_ops___106 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state___16 *xfrm;
	int (*input)(struct sk_buff___96 *);
	int (*output)(struct net___106 *, struct sock___75 *, struct sk_buff___96 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___9 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___75;

struct neigh_parms___75;

struct neigh_ops___75;

struct neighbour___75 {
	struct neighbour___75 *next;
	struct neigh_table___75 *tbl;
	struct neigh_parms___75 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___95 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___75 *, struct sk_buff___96 *);
	const struct neigh_ops___75 *ops;
	struct callback_head rcu;
	struct net_device___95 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct fib6_nh___20 {
	struct in6_addr nh_gw;
	struct net_device___95 *nh_dev;
	struct lwtunnel_state___9 *nh_lwtstate;
	unsigned int nh_flags;
	atomic_t nh_upper_bound;
	int nh_weight;
};

struct fib6_node___20;

struct fib6_info___20 {
	struct fib6_table___20 *fib6_table;
	struct fib6_info___20 *fib6_next;
	struct fib6_node___20 *fib6_node;
	struct list_head fib6_siblings;
	unsigned int fib6_nsiblings;
	atomic_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	struct rt6_info___20 **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
	long unsigned int last_probe;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 exception_bucket_flushed: 1;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 dst_host: 1;
	u8 fib6_destroying: 1;
	u8 unused: 2;
	struct fib6_nh___20 fib6_nh;
	struct callback_head rcu;
};

struct rt6_info___20 {
	struct dst_entry___75 dst;
	struct fib6_info___20 *from;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___46 *rt6i_idev;
	u32 rt6i_flags;
	struct rt6key rt6i_prefsrc;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct fib6_node___20 {
	struct fib6_node___20 *parent;
	struct fib6_node___20 *left;
	struct fib6_node___20 *right;
	struct fib6_info___20 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info___20 *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table___20 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node___20 tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

struct nf_hook_state___13;

typedef unsigned int nf_hookfn___13(void *, struct sk_buff___96 *, const struct nf_hook_state___13 *);

struct nf_hook_entry___13 {
	nf_hookfn___13 *hook;
	void *priv;
};

struct nf_hook_entries___13 {
	u16 num_hook_entries;
	struct nf_hook_entry___13 hooks[0];
};

struct ucounts___315 {
	struct hlist_node node;
	struct user_namespace___315 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_prog_aux___88;

struct bpf_prog___85 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___88 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

typedef int (*key_restrict_link_func_t___419)(struct key___418 *, const struct key_type *, const union key_payload *, struct key___418 *);

struct key_restriction___418;

struct key___418 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___452 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___418 *restrict_link;
};

struct key_restriction___418 {
	key_restrict_link_func_t___419 check;
	struct key___418 *key;
	struct key_type *keytype;
};

struct seq_operations___389 {
	void * (*start)(struct seq_file___389 *, loff_t *);
	void (*stop)(struct seq_file___389 *, void *);
	void * (*next)(struct seq_file___389 *, void *, loff_t *);
	int (*show)(struct seq_file___389 *, void *);
};

struct pernet_operations___96 {
	struct list_head list;
	int (*init)(struct net___106 *);
	void (*exit)(struct net___106 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___95 {
	int (*ieee_getets)(struct net_device___95 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___95 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___95 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___95 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___95 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___95 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___95 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___95 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___95 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___95 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___95 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___95 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___95 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___95 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___95 *);
	u8 (*setstate)(struct net_device___95 *, u8);
	void (*getpermhwaddr)(struct net_device___95 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___95 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___95 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___95 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___95 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___95 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___95 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___95 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___95 *, int, u8 *);
	void (*setpfccfg)(struct net_device___95 *, int, u8);
	void (*getpfccfg)(struct net_device___95 *, int, u8 *);
	u8 (*setall)(struct net_device___95 *);
	u8 (*getcap)(struct net_device___95 *, int, u8 *);
	int (*getnumtcs)(struct net_device___95 *, int, u8 *);
	int (*setnumtcs)(struct net_device___95 *, int, u8);
	u8 (*getpfcstate)(struct net_device___95 *);
	void (*setpfcstate)(struct net_device___95 *, u8);
	void (*getbcncfg)(struct net_device___95 *, int, u32 *);
	void (*setbcncfg)(struct net_device___95 *, int, u32);
	void (*getbcnrp)(struct net_device___95 *, int, u8 *);
	void (*setbcnrp)(struct net_device___95 *, int, u8);
	int (*setapp)(struct net_device___95 *, u8, u16, u8);
	int (*getapp)(struct net_device___95 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___95 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___95 *, int, u8);
	u8 (*getdcbx)(struct net_device___95 *);
	u8 (*setdcbx)(struct net_device___95 *, u8);
	int (*peer_getappinfo)(struct net_device___95 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___95 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___95 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___95 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___95 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___95 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___299 {
	refcount_t count;
	struct ns_common___29 ns;
	struct user_namespace___315 *user_ns;
	struct ucounts___315 *ucounts;
	struct css_set___299 *root_cset;
};

struct bpf_map___300;

struct bpf_map_ops___299 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___300 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___300 *, struct file___450 *);
	void (*map_free)(struct bpf_map___300 *);
	int (*map_get_next_key)(struct bpf_map___300 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___300 *);
	void * (*map_lookup_elem)(struct bpf_map___300 *, void *);
	int (*map_update_elem)(struct bpf_map___300 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___300 *, void *);
	int (*map_push_elem)(struct bpf_map___300 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___300 *, void *);
	int (*map_peek_elem)(struct bpf_map___300 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___300 *, struct file___450 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___300 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___300 *, void *, struct seq_file___389 *);
	int (*map_check_btf)(const struct bpf_map___300 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___300 {
	const struct bpf_map_ops___299 *ops;
	struct bpf_map___300 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___418 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___95;

struct bpf_map_dev_ops___95 {
	int (*map_get_next_key)(struct bpf_offloaded_map___95 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___95 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___95 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___95 *, void *);
};

struct bpf_offloaded_map___95 {
	struct bpf_map___300 map;
	struct net_device___95 *netdev;
	const struct bpf_map_dev_ops___95 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___85 {
	int (*test_run)(struct bpf_prog___85 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___85 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___85 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___85 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___85 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___85 *, u32 *);
};

struct bpf_prog_offload_ops___85 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___85 *);
	int (*translate)(struct bpf_prog___85 *);
	void (*destroy)(struct bpf_prog___85 *);
};

struct bpf_prog_offload___85 {
	struct bpf_prog___85 *prog;
	struct net_device___95 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___85 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___88 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___85 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___85 *ops;
	struct bpf_map___300 **used_maps;
	struct bpf_prog___85 *prog;
	struct user_struct___418 *user;
	u64 load_time;
	struct bpf_map___300 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___85 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___85 {
	struct bpf_prog___85 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___85 {
	struct callback_head rcu;
	struct bpf_prog_array_item___85 items[0];
};

struct cgroup_bpf___85 {
	struct bpf_prog_array___85 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___85 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___300;

typedef void (*kthread_work_func_t___300)(struct kthread_work___300 *);

struct kthread_worker___300;

struct kthread_work___300 {
	struct list_head node;
	kthread_work_func_t___300 func;
	struct kthread_worker___300 *worker;
	int canceling;
};

struct kthread_worker___300 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___452 *task;
	struct kthread_work___300 *current_work;
};

struct kthread_delayed_work___299 {
	struct kthread_work___300 work;
	struct timer_list timer;
};

struct psi_group___299 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___300 *poll_kworker;
	struct kthread_delayed_work___299 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___299;

struct cgroup_rstat_cpu___299;

struct cgroup___299 {
	struct cgroup_subsys_state___299 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___445 *kn;
	struct cgroup_file___299 procs_file;
	struct cgroup_file___299 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___299 *subsys[13];
	struct cgroup_root___299 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___299 *dom_cgrp;
	struct cgroup_rstat_cpu___299 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___85 bpf;
	atomic_t congestion_count;
	struct cgroup___299 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___299 psi;
	int ancestor_ids[0];
};

struct cftype___299;

struct cgroup_subsys___299 {
	struct cgroup_subsys_state___299 * (*css_alloc)(struct cgroup_subsys_state___299 *);
	int (*css_online)(struct cgroup_subsys_state___299 *);
	void (*css_offline)(struct cgroup_subsys_state___299 *);
	void (*css_released)(struct cgroup_subsys_state___299 *);
	void (*css_free)(struct cgroup_subsys_state___299 *);
	void (*css_reset)(struct cgroup_subsys_state___299 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___299 *, int);
	int (*css_extra_stat_show)(struct seq_file___389 *, struct cgroup_subsys_state___299 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___452 *);
	void (*cancel_fork)(struct task_struct___452 *);
	void (*fork)(struct task_struct___452 *);
	void (*exit)(struct task_struct___452 *);
	void (*free)(struct task_struct___452 *);
	void (*bind)(struct cgroup_subsys_state___299 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___299 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___299 *dfl_cftypes;
	struct cftype___299 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___299 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___299 *updated_children;
	struct cgroup___299 *updated_next;
};

struct cgroup_root___299 {
	struct kernfs_root___444 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___299 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___299 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___299 *ss;
	struct list_head node;
	struct kernfs_ops___444 *kf_ops;
	int (*open)(struct kernfs_open_file___444 *);
	void (*release)(struct kernfs_open_file___444 *);
	u64 (*read_u64)(struct cgroup_subsys_state___299 *, struct cftype___299 *);
	s64 (*read_s64)(struct cgroup_subsys_state___299 *, struct cftype___299 *);
	int (*seq_show)(struct seq_file___389 *, void *);
	void * (*seq_start)(struct seq_file___389 *, loff_t *);
	void * (*seq_next)(struct seq_file___389 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___389 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___299 *, struct cftype___299 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___299 *, struct cftype___299 *, s64);
	ssize_t (*write)(struct kernfs_open_file___444 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___444 *, struct poll_table_struct___289 *);
};

struct xdp_rxq_info___95 {
	struct net_device___95 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___95 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___95 *dev_rx;
};

struct netlink_callback___97 {
	struct sk_buff___96 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___97 *);
	int (*dump)(struct sk_buff___96 *, struct netlink_callback___97 *);
	int (*done)(struct netlink_callback___97 *);
	void *data;
	struct module___376 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___95 {
	int (*create)(struct sk_buff___96 *, struct net_device___95 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___96 *, unsigned char *);
	int (*cache)(const struct neighbour___75 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___95 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___95 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___95 *, int);
	int poll_owner;
	struct net_device___95 *dev;
	struct sk_buff___96 *gro_list;
	struct sk_buff___96 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___95 {
	struct net_device___95 *dev;
	struct Qdisc___87 *qdisc;
	struct Qdisc___87 *qdisc_sleeping;
	struct kobject___438 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___95 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___87 {
	struct sk_buff___96 *head;
	struct sk_buff___96 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___87;

struct Qdisc___87 {
	int (*enqueue)(struct sk_buff___96 *, struct Qdisc___87 *, struct sk_buff___96 **);
	struct sk_buff___96 * (*dequeue)(struct Qdisc___87 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___87 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___95 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___95 gso_skb;
	struct qdisc_skb_head___87 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___87 *next_sched;
	struct sk_buff_head___95 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___95 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___438 kobj;
	struct net_device___95 *dev;
	long: 64;
	struct xdp_rxq_info___95 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___95)(struct net_device___95 *, struct sk_buff___96 *, struct net_device___95 *);

struct netdev_bpf___95 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___85 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___85 *prog;
			const struct bpf_prog_offload_ops___85 *ops;
		} verifier;
		struct {
			struct bpf_prog___85 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___95 *offmap;
		};
		struct {
			struct xdp_umem___3 *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___95 {
	int (*xdo_dev_state_add)(struct xfrm_state___16 *);
	void (*xdo_dev_state_delete)(struct xfrm_state___16 *);
	void (*xdo_dev_state_free)(struct xfrm_state___16 *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___96 *, struct xfrm_state___16 *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state___16 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct xfrm_state_offload___16 {
	struct net_device___95 *dev;
	long unsigned int offload_handle;
	unsigned int num_exthdrs;
	u8 flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct xfrm_replay___16;

struct xfrm_type___16;

struct xfrm_mode___16;

struct xfrm_type_offload___16;

struct xfrm_state___16 {
	possible_net_t___97 xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	refcount_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
		u32 output_mark;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	const char *geniv;
	struct xfrm_encap_tmpl *encap;
	xfrm_address_t *coaddr;
	struct xfrm_state___16 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	const struct xfrm_replay___16 *repl;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct tasklet_hrtimer mtimer;
	struct xfrm_state_offload___16 xso;
	long int saved_tmo;
	long unsigned int lastused;
	struct page_frag___451 xfrag;
	const struct xfrm_type___16 *type;
	struct xfrm_mode___16 *inner_mode;
	struct xfrm_mode___16 *inner_mode_iaf;
	struct xfrm_mode___16 *outer_mode;
	const struct xfrm_type_offload___16 *type_offload;
	struct xfrm_sec_ctx___2 *security;
	void *data;
	u32 output_mark_mask;
	u32 if_id;
};

struct tlsdev_ops___95 {
	int (*tls_dev_add)(struct net_device___95 *, struct sock___75 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___95 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___95 *, struct sock___75 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___95 {
	int (*ndo_init)(struct net_device___95 *);
	void (*ndo_uninit)(struct net_device___95 *);
	int (*ndo_open)(struct net_device___95 *);
	int (*ndo_stop)(struct net_device___95 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___96 *, struct net_device___95 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___96 *, struct net_device___95 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___95 *, struct sk_buff___96 *, struct net_device___95 *, select_queue_fallback_t___95);
	void (*ndo_change_rx_flags)(struct net_device___95 *, int);
	void (*ndo_set_rx_mode)(struct net_device___95 *);
	int (*ndo_set_mac_address)(struct net_device___95 *, void *);
	int (*ndo_validate_addr)(struct net_device___95 *);
	int (*ndo_do_ioctl)(struct net_device___95 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___95 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___95 *, int);
	int (*ndo_neigh_setup)(struct net_device___95 *, struct neigh_parms___75 *);
	void (*ndo_tx_timeout)(struct net_device___95 *);
	void (*ndo_get_stats64)(struct net_device___95 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___95 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___95 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___95 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___95 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___95 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___95 *);
	int (*ndo_netpoll_setup)(struct net_device___95 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___95 *);
	int (*ndo_set_vf_mac)(struct net_device___95 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___95 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___95 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___95 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___95 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___95 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___95 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___95 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___95 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___95 *, int, struct sk_buff___96 *);
	int (*ndo_set_vf_guid)(struct net_device___95 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___95 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___95 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___95 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___95 *, const struct sk_buff___96 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___95 *, struct net_device___95 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___95 *, struct net_device___95 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___95 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___95 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___95 *, struct neighbour___75 *);
	void (*ndo_neigh_destroy)(struct net_device___95 *, struct neighbour___75 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___95 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___95 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___95 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___96 *, struct netlink_callback___97 *, struct net_device___95 *, struct net_device___95 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___95 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___95 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___96 *, u32, u32, struct net_device___95 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___95 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___95 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___95 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___95 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___95 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___95 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___95 *, struct net_device___95 *);
	void (*ndo_dfwd_del_station)(struct net_device___95 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___95 *);
	int (*ndo_set_tx_maxrate)(struct net_device___95 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___95 *);
	int (*ndo_change_proto_down)(struct net_device___95 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___95 *, struct sk_buff___96 *);
	void (*ndo_set_rx_headroom)(struct net_device___95 *, int);
	int (*ndo_bpf)(struct net_device___95 *, struct netdev_bpf___95 *);
	int (*ndo_xdp_xmit)(struct net_device___95 *, int, struct xdp_frame___95 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___95 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___95 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___75 {
	possible_net_t___97 net;
	struct net_device___95 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___75 *);
	void (*neigh_cleanup)(struct neighbour___75 *);
	struct neigh_table___75 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___75 {
	u32 (*l3mdev_fib_table)(const struct net_device___95 *);
	struct sk_buff___96 * (*l3mdev_l3_rcv)(struct net_device___95 *, struct sk_buff___96 *, u16);
	struct sk_buff___96 * (*l3mdev_l3_out)(struct net_device___95 *, struct sock___75 *, struct sk_buff___96 *, u16);
	struct dst_entry___75 * (*l3mdev_link_scope_lookup)(const struct net_device___95 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct ndisc_ops___46 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___95 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___95 *, struct neighbour___75 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___95 *, u8, struct neighbour___75 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___95 *, struct sk_buff___96 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___106 *, struct net_device___95 *, const struct prefix_info *, struct inet6_dev___46 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct in_ifaddr___11;

struct ip_mc_list___4;

struct in_device___11 {
	struct net_device___95 *dev;
	refcount_t refcnt;
	int dead;
	struct in_ifaddr___11 *ifa_list;
	struct ip_mc_list___4 *mc_list;
	struct ip_mc_list___4 **mc_hash;
	int mc_count;
	spinlock_t mc_tomb_lock;
	struct ip_mc_list___4 *mc_tomb;
	long unsigned int mr_v1_seen;
	long unsigned int mr_v2_seen;
	long unsigned int mr_maxdelay;
	long unsigned int mr_qi;
	long unsigned int mr_qri;
	unsigned char mr_qrv;
	unsigned char mr_gq_running;
	unsigned char mr_ifc_count;
	struct timer_list mr_gq_timer;
	struct timer_list mr_ifc_timer;
	struct neigh_parms___75 *arp_parms;
	struct ipv4_devconf cnf;
	struct callback_head callback_head;
};

struct ifmcaddr6___46;

struct ifacaddr6___20;

struct inet6_dev___46 {
	struct net_device___95 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___46 *mc_list;
	struct ifmcaddr6___46 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___20 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	u8 rndid[8];
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___75 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
};

struct tcf_proto___87;

struct mini_Qdisc___87 {
	struct tcf_proto___87 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___87 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___95 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___106 *, struct net_device___95 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___95 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___95 *, struct list_head *);
	size_t (*get_size)(const struct net_device___95 *);
	int (*fill_info)(struct sk_buff___96 *, const struct net_device___95 *);
	size_t (*get_xstats_size)(const struct net_device___95 *);
	int (*fill_xstats)(struct sk_buff___96 *, const struct net_device___95 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___95 *, struct net_device___95 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___95 *, const struct net_device___95 *);
	int (*fill_slave_info)(struct sk_buff___96 *, const struct net_device___95 *, const struct net_device___95 *);
	struct net___106 * (*get_link_net)(const struct net_device___95 *);
	size_t (*get_linkxstats_size)(const struct net_device___95 *, int);
	int (*fill_linkxstats)(struct sk_buff___96 *, const struct net_device___95 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct napi_gro_cb___5 {
	void *frag0;
	unsigned int frag0_len;
	int data_offset;
	u16 flush;
	u16 flush_id;
	u16 count;
	u16 gro_remcsum_start;
	long unsigned int age;
	u16 proto;
	u8 same_flow: 1;
	u8 encap_mark: 1;
	u8 csum_valid: 1;
	u8 csum_cnt: 3;
	u8 free: 2;
	u8 is_ipv6: 1;
	u8 is_fou: 1;
	u8 is_atomic: 1;
	u8 recursion_counter: 4;
	__wsum csum;
	struct sk_buff___96 *last;
};

struct packet_type___4 {
	__be16 type;
	struct net_device___95 *dev;
	int (*func)(struct sk_buff___96 *, struct net_device___95 *, struct packet_type___4 *, struct net_device___95 *);
	bool (*id_match)(struct packet_type___4 *, struct sock___75 *);
	void *af_packet_priv;
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct offload_callbacks___13 {
	struct sk_buff___96 * (*gso_segment)(struct sk_buff___96 *, netdev_features_t);
	struct sk_buff___96 ** (*gro_receive)(struct sk_buff___96 **, struct sk_buff___96 *);
	int (*gro_complete)(struct sk_buff___96 *, int);
};

struct packet_offload___3 {
	__be16 type;
	u16 priority;
	struct offload_callbacks___13 callbacks;
	struct list_head list;
};

struct softnet_data___95 {
	struct list_head poll_list;
	struct sk_buff_head___95 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___95 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___87 *output_queue;
	struct Qdisc___87 **output_queue_tailp;
	struct sk_buff___96 *completion_queue;
	struct sk_buff_head___95 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___95 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___95 input_pkt_queue;
	struct napi_struct___95 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct nf_hook_state___13 {
	unsigned int hook;
	u_int8_t pf;
	struct net_device___95 *in;
	struct net_device___95 *out;
	struct sock___75 *sk;
	struct net___106 *net;
	int (*okfn)(struct net___106 *, struct sock___75 *, struct sk_buff___96 *);
};

struct nf_nat_hook___13 {
	int (*parse_nat_setup)(struct nf_conn *, enum nf_nat_manip_type, const struct nlattr *);
	void (*decode_session)(struct sk_buff___96 *, struct flowi *);
	unsigned int (*manip_pkt)(struct sk_buff___96 *, struct nf_conn *, enum nf_nat_manip_type, enum ip_conntrack_dir);
};

struct nf_ct_hook___13 {
	int (*update)(struct net___106 *, struct sk_buff___96 *);
	void (*destroy)(struct nf_conntrack *);
	bool (*get_tuple_skb)(struct nf_conntrack_tuple *, const struct sk_buff___96 *);
};

struct nfnl_ct_hook___13 {
	struct nf_conn * (*get_ct)(const struct sk_buff___96 *, enum ip_conntrack_info *);
	size_t (*build_size)(const struct nf_conn *);
	int (*build)(struct sk_buff___96 *, struct nf_conn *, enum ip_conntrack_info, u_int16_t, u_int16_t);
	int (*parse)(const struct nlattr *, struct nf_conn *);
	int (*attach_expect)(const struct nlattr *, struct nf_conn *, u32, u32);
	void (*seq_adjust)(struct sk_buff___96 *, struct nf_conn *, enum ip_conntrack_info, s32);
};

struct ip_mc_list___4 {
	struct in_device___11 *interface;
	__be32 multiaddr;
	unsigned int sfmode;
	struct ip_sf_list *sources;
	struct ip_sf_list *tomb;
	long unsigned int sfcount[2];
	union {
		struct ip_mc_list___4 *next;
		struct ip_mc_list___4 *next_rcu;
	};
	struct ip_mc_list___4 *next_hash;
	struct timer_list timer;
	int users;
	refcount_t refcnt;
	spinlock_t lock;
	char tm_running;
	char reporter;
	char unsolicit_count;
	char loaded;
	unsigned char gsquery;
	unsigned char crcount;
	struct callback_head rcu;
};

struct in_ifaddr___11 {
	struct hlist_node hash;
	struct in_ifaddr___11 *ifa_next;
	struct in_device___11 *ifa_dev;
	struct callback_head callback_head;
	__be32 ifa_local;
	__be32 ifa_address;
	__be32 ifa_mask;
	__u32 ifa_rt_priority;
	__be32 ifa_broadcast;
	unsigned char ifa_scope;
	unsigned char ifa_prefixlen;
	__u32 ifa_flags;
	char ifa_label[16];
	__u32 ifa_valid_lft;
	__u32 ifa_preferred_lft;
	long unsigned int ifa_cstamp;
	long unsigned int ifa_tstamp;
};

struct bdi_writeback_congested___240 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___240 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___240 {
	struct bio___240 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___242 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___242 bip_inline_vecs[0];
};

struct bio_set___240 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___240 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___183 {
	struct mem_cgroup___183 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___183 {
	struct lruvec___451 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___183 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___183 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct kernel_param_ops___376 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___376 *);
	int (*get)(char *, const struct kernel_param___376 *);
	void (*free)(void *);
};

struct kparam_array___376;

struct kernel_param___376 {
	const char *name;
	struct module___376 *mod;
	const struct kernel_param_ops___376 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___376 *arr;
	};
};

struct kparam_array___376 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___376 *ops;
	void *elem;
};

struct module_attribute___376 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___376 *, struct module_kobject___376 *, char *);
	ssize_t (*store)(struct module_attribute___376 *, struct module_kobject___376 *, const char *, size_t);
	void (*setup)(struct module___376 *, const char *);
	int (*test)(struct module___376 *);
	void (*free)(struct module___376 *);
};

struct gnet_dump___87 {
	spinlock_t *lock;
	struct sk_buff___96 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___87;

struct Qdisc_ops___87 {
	struct Qdisc_ops___87 *next;
	const struct Qdisc_class_ops___87 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___96 *, struct Qdisc___87 *, struct sk_buff___96 **);
	struct sk_buff___96 * (*dequeue)(struct Qdisc___87 *);
	struct sk_buff___96 * (*peek)(struct Qdisc___87 *);
	int (*init)(struct Qdisc___87 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___87 *);
	void (*destroy)(struct Qdisc___87 *);
	int (*change)(struct Qdisc___87 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___87 *);
	int (*change_tx_queue_len)(struct Qdisc___87 *, unsigned int);
	int (*dump)(struct Qdisc___87 *, struct sk_buff___96 *);
	int (*dump_stats)(struct Qdisc___87 *, struct gnet_dump___87 *);
	void (*ingress_block_set)(struct Qdisc___87 *, u32);
	void (*egress_block_set)(struct Qdisc___87 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___87 *);
	u32 (*egress_block_get)(struct Qdisc___87 *);
	struct module___376 *owner;
};

struct tcf_block___87;

struct Qdisc_class_ops___87 {
	unsigned int flags;
	struct netdev_queue___95 * (*select_queue)(struct Qdisc___87 *, struct tcmsg *);
	int (*graft)(struct Qdisc___87 *, long unsigned int, struct Qdisc___87 *, struct Qdisc___87 **, struct netlink_ext_ack *);
	struct Qdisc___87 * (*leaf)(struct Qdisc___87 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___87 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___87 *, u32);
	int (*change)(struct Qdisc___87 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___87 *, long unsigned int);
	void (*walk)(struct Qdisc___87 *, struct qdisc_walker *);
	struct tcf_block___87 * (*tcf_block)(struct Qdisc___87 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___87 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___87 *, long unsigned int);
	int (*dump)(struct Qdisc___87 *, long unsigned int, struct sk_buff___96 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___87 *, long unsigned int, struct gnet_dump___87 *);
};

struct tcf_chain___87;

struct tcf_block___87 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___106 *net;
	struct Qdisc___87 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___87 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___87;

struct tcf_proto_ops___87;

struct tcf_proto___87 {
	struct tcf_proto___87 *next;
	void *root;
	int (*classify)(struct sk_buff___96 *, const struct tcf_proto___87 *, struct tcf_result___87 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___87 *ops;
	struct tcf_chain___87 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___87 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___87 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___87 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___96 *, const struct tcf_proto___87 *, struct tcf_result___87 *);
	int (*init)(struct tcf_proto___87 *);
	void (*destroy)(struct tcf_proto___87 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___87 *, u32);
	void (*put)(struct tcf_proto___87 *, void *);
	int (*change)(struct net___106 *, struct sk_buff___96 *, struct tcf_proto___87 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___87 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___87 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___87 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___106 *, struct tcf_chain___87 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___106 *, struct tcf_proto___87 *, void *, struct sk_buff___96 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___96 *, struct net___106 *, void *);
	struct module___376 *owner;
	int flags;
};

struct tcf_chain___87 {
	struct mutex filter_chain_lock;
	struct tcf_proto___87 *filter_chain;
	struct list_head list;
	struct tcf_block___87 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___87 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___75 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___85 *prog;
};

struct bpf_redirect_info___85 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___300 *map;
	struct bpf_map___300 *map_to_flush;
	u32 kern_flags;
};

struct bpf_sock_ops_kern___9 {
	struct sock___75 *sk;
	u32 op;
	union {
		u32 args[4];
		u32 reply;
		u32 replylong[4];
	};
	u32 is_fullsock;
	u64 temp;
};

struct pneigh_entry___75;

struct neigh_hash_table___75;

struct neigh_table___75 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___95 *, __u32 *);
	bool (*key_eq)(const struct neighbour___75 *, const void *);
	int (*constructor)(struct neighbour___75 *);
	int (*pconstructor)(struct pneigh_entry___75 *);
	void (*pdestructor)(struct pneigh_entry___75 *);
	void (*proxy_redo)(struct sk_buff___96 *);
	char *id;
	struct neigh_parms___75 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___95 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___75 *nht;
	struct pneigh_entry___75 **phash_buckets;
};

struct neigh_ops___75 {
	int family;
	void (*solicit)(struct neighbour___75 *, struct sk_buff___96 *);
	void (*error_report)(struct neighbour___75 *, struct sk_buff___96 *);
	int (*output)(struct neighbour___75 *, struct sk_buff___96 *);
	int (*connected_output)(struct neighbour___75 *, struct sk_buff___96 *);
};

struct pneigh_entry___75 {
	struct pneigh_entry___75 *next;
	possible_net_t___97 net;
	struct net_device___95 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___75 {
	struct neighbour___75 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___9 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___106 *, struct sock___75 *, struct sk_buff___96 *);
	int (*orig_input)(struct sk_buff___96 *);
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	__u8 data[0];
};

struct fib_rule___75 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___75 *ctarget;
	struct net___106 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___75 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___75 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___58;

struct timewait_sock_ops___54;

struct proto___75 {
	void (*close)(struct sock___75 *, long int);
	int (*pre_connect)(struct sock___75 *, struct sockaddr *, int);
	int (*connect)(struct sock___75 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___75 *, int);
	struct sock___75 * (*accept)(struct sock___75 *, int, int *, bool);
	int (*ioctl)(struct sock___75 *, int, long unsigned int);
	int (*init)(struct sock___75 *);
	void (*destroy)(struct sock___75 *);
	void (*shutdown)(struct sock___75 *, int);
	int (*setsockopt)(struct sock___75 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___75 *, int, int, char *, int *);
	void (*keepalive)(struct sock___75 *, int);
	int (*sendmsg)(struct sock___75 *, struct msghdr___78 *, size_t);
	int (*recvmsg)(struct sock___75 *, struct msghdr___78 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___75 *, struct page___451 *, int, size_t, int);
	int (*bind)(struct sock___75 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___75 *, struct sk_buff___96 *);
	void (*release_cb)(struct sock___75 *);
	int (*hash)(struct sock___75 *);
	void (*unhash)(struct sock___75 *);
	void (*rehash)(struct sock___75 *);
	int (*get_port)(struct sock___75 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___75 *);
	bool (*stream_memory_read)(const struct sock___75 *);
	void (*enter_memory_pressure)(struct sock___75 *);
	void (*leave_memory_pressure)(struct sock___75 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___58 *rsk_prot;
	struct timewait_sock_ops___54 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___376 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___75 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct xfrm_policy_queue___16 {
	struct sk_buff_head___95 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___16 {
	possible_net_t___97 xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	refcount_t refcnt;
	struct timer_list timer;
	atomic_t genid;
	u32 priority;
	u32 index;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___16 polq;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx___2 *security;
	struct xfrm_tmpl xfrm_vec[6];
	struct callback_head rcu;
	u32 if_id;
};

struct request_sock___59;

struct request_sock_ops___58 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___75 *, struct request_sock___59 *);
	void (*send_ack)(const struct sock___75 *, struct sk_buff___96 *, struct request_sock___59 *);
	void (*send_reset)(const struct sock___75 *, struct sk_buff___96 *);
	void (*destructor)(struct request_sock___59 *);
	void (*syn_ack_timeout)(const struct request_sock___59 *);
};

struct timewait_sock_ops___54 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___75 *, struct sock___75 *, void *);
	void (*twsk_destructor)(struct sock___75 *);
};

struct socket_alloc___5 {
	struct socket___77 socket;
	struct inode___450 vfs_inode;
};

struct request_sock___59 {
	struct sock_common___75 __req_common;
	struct request_sock___59 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___58 *rsk_ops;
	struct sock___75 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct fastopen_queue___12 {
	struct request_sock___59 *rskq_rst_head;
	struct request_sock___59 *rskq_rst_tail;
	spinlock_t lock;
	int qlen;
	int max_qlen;
	struct tcp_fastopen_context___18 *ctx;
};

struct request_sock_queue___12 {
	spinlock_t rskq_lock;
	u8 rskq_defer_accept;
	u32 synflood_warned;
	atomic_t qlen;
	atomic_t young;
	struct request_sock___59 *rskq_accept_head;
	struct request_sock___59 *rskq_accept_tail;
	struct fastopen_queue___12 fastopenq;
};

struct inet_cork___17 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___75 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
	__u16 gso_size;
	u64 transmit_time;
};

struct inet_cork_full___17 {
	struct inet_cork___17 base;
	struct flowi fl;
};

struct ipv6_pinfo___17;

struct inet_sock___17 {
	struct sock___75 sk;
	struct ipv6_pinfo___17 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	__be16 inet_sport;
	__u16 inet_id;
	struct ip_options_rcu *inet_opt;
	int rx_dst_ifindex;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 bind_address_no_port: 1;
	__u8 defer_connect: 1;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___17 cork;
};

struct ipv6_fl_socklist___16;

struct ipv6_pinfo___17 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
			__u16 recvfragsize: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 repflow: 1;
	__u16 pmtudisc: 3;
	__u16 padding: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u16 autoflowlabel: 1;
	__u16 autoflowlabel_set: 1;
	__u8 min_hopcount;
	__u8 tclass;
	__be32 rcv_flowinfo;
	__u32 dst_cookie;
	__u32 rx_dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___16 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___96 *pktoptions;
	struct sk_buff___96 *rxpmtu;
	struct inet6_cork cork;
};

struct inet_connection_sock_af_ops___11 {
	int (*queue_xmit)(struct sock___75 *, struct sk_buff___96 *, struct flowi *);
	void (*send_check)(struct sock___75 *, struct sk_buff___96 *);
	int (*rebuild_header)(struct sock___75 *);
	void (*sk_rx_dst_set)(struct sock___75 *, const struct sk_buff___96 *);
	int (*conn_request)(struct sock___75 *, struct sk_buff___96 *);
	struct sock___75 * (*syn_recv_sock)(const struct sock___75 *, struct sk_buff___96 *, struct request_sock___59 *, struct dst_entry___75 *, struct request_sock___59 *, bool *);
	u16 net_header_len;
	u16 net_frag_header_len;
	u16 sockaddr_len;
	int (*setsockopt)(struct sock___75 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___75 *, int, int, char *, int *);
	void (*addr2sockaddr)(struct sock___75 *, struct sockaddr *);
	void (*mtu_reduced)(struct sock___75 *);
};

struct inet_bind_bucket___11;

struct tcp_ulp_ops___10;

struct inet_connection_sock___12 {
	struct inet_sock___17 icsk_inet;
	struct request_sock_queue___12 icsk_accept_queue;
	struct inet_bind_bucket___11 *icsk_bind_hash;
	long unsigned int icsk_timeout;
	struct timer_list icsk_retransmit_timer;
	struct timer_list icsk_delack_timer;
	__u32 icsk_rto;
	__u32 icsk_pmtu_cookie;
	const struct tcp_congestion_ops___18 *icsk_ca_ops;
	const struct inet_connection_sock_af_ops___11 *icsk_af_ops;
	const struct tcp_ulp_ops___10 *icsk_ulp_ops;
	void *icsk_ulp_data;
	void (*icsk_clean_acked)(struct sock___75 *, u32);
	struct hlist_node icsk_listen_portaddr_node;
	unsigned int (*icsk_sync_mss)(struct sock___75 *, u32);
	__u8 icsk_ca_state: 6;
	__u8 icsk_ca_setsockopt: 1;
	__u8 icsk_ca_dst_locked: 1;
	__u8 icsk_retransmits;
	__u8 icsk_pending;
	__u8 icsk_backoff;
	__u8 icsk_syn_retries;
	__u8 icsk_probes_out;
	__u16 icsk_ext_hdr_len;
	struct {
		__u8 pending;
		__u8 quick;
		__u8 pingpong;
		__u8 blocked;
		__u32 ato;
		long unsigned int timeout;
		__u32 lrcvtime;
		__u16 last_seg_size;
		__u16 rcv_mss;
	} icsk_ack;
	struct {
		int enabled;
		int search_high;
		int search_low;
		int probe_size;
		u32 probe_timestamp;
	} icsk_mtup;
	u32 icsk_user_timeout;
	u64 icsk_ca_priv[11];
};

struct inet_bind_bucket___11 {
	possible_net_t___97 ib_net;
	short unsigned int port;
	signed char fastreuse;
	signed char fastreuseport;
	kuid_t fastuid;
	struct in6_addr fast_v6_rcv_saddr;
	__be32 fast_rcv_saddr;
	short unsigned int fast_sk_family;
	bool fast_ipv6_only;
	struct hlist_node node;
	struct hlist_head owners;
};

struct tcp_ulp_ops___10 {
	struct list_head list;
	int (*init)(struct sock___75 *);
	void (*release)(struct sock___75 *);
	char name[16];
	struct module___376 *owner;
};

struct tcp_sock_af_ops___10;

struct tcp_fastopen_request___10;

struct tcp_sock___10 {
	struct inet_connection_sock___12 inet_conn;
	u16 tcp_header_len;
	u16 gso_segs;
	__be32 pred_flags;
	u64 bytes_received;
	u32 segs_in;
	u32 data_segs_in;
	u32 rcv_nxt;
	u32 copied_seq;
	u32 rcv_wup;
	u32 snd_nxt;
	u32 segs_out;
	u32 data_segs_out;
	u64 bytes_acked;
	u32 snd_una;
	u32 snd_sml;
	u32 rcv_tstamp;
	u32 lsndtime;
	u32 last_oow_ack_time;
	u32 compressed_ack_rcv_nxt;
	u32 tsoffset;
	struct list_head tsq_node;
	struct list_head tsorted_sent_queue;
	u32 snd_wl1;
	u32 snd_wnd;
	u32 max_window;
	u32 mss_cache;
	u32 window_clamp;
	u32 rcv_ssthresh;
	struct tcp_rack rack;
	u16 advmss;
	u8 compressed_ack;
	u32 chrono_start;
	u32 chrono_stat[3];
	u8 chrono_type: 2;
	u8 rate_app_limited: 1;
	u8 fastopen_connect: 1;
	u8 fastopen_no_cookie: 1;
	u8 is_sack_reneg: 1;
	u8 unused: 2;
	u8 nonagle: 4;
	u8 thin_lto: 1;
	u8 recvmsg_inq: 1;
	u8 repair: 1;
	u8 frto: 1;
	u8 repair_queue;
	u8 syn_data: 1;
	u8 syn_fastopen: 1;
	u8 syn_fastopen_exp: 1;
	u8 syn_fastopen_ch: 1;
	u8 syn_data_acked: 1;
	u8 save_syn: 1;
	u8 is_cwnd_limited: 1;
	u8 syn_smc: 1;
	u32 tlp_high_seq;
	u64 tcp_mstamp;
	u32 srtt_us;
	u32 mdev_us;
	u32 mdev_max_us;
	u32 rttvar_us;
	u32 rtt_seq;
	struct minmax rtt_min;
	u32 packets_out;
	u32 retrans_out;
	u32 max_packets_out;
	u32 max_packets_seq;
	u16 urg_data;
	u8 ecn_flags;
	u8 keepalive_probes;
	u32 reordering;
	u32 snd_up;
	struct tcp_options_received rx_opt;
	u32 snd_ssthresh;
	u32 snd_cwnd;
	u32 snd_cwnd_cnt;
	u32 snd_cwnd_clamp;
	u32 snd_cwnd_used;
	u32 snd_cwnd_stamp;
	u32 prior_cwnd;
	u32 prr_delivered;
	u32 prr_out;
	u32 delivered;
	u32 delivered_ce;
	u32 lost;
	u32 app_limited;
	u64 first_tx_mstamp;
	u64 delivered_mstamp;
	u32 rate_delivered;
	u32 rate_interval_us;
	u32 rcv_wnd;
	u32 write_seq;
	u32 notsent_lowat;
	u32 pushed_seq;
	u32 lost_out;
	u32 sacked_out;
	struct hrtimer pacing_timer;
	struct hrtimer compressed_ack_timer;
	struct sk_buff___96 *lost_skb_hint;
	struct sk_buff___96 *retransmit_skb_hint;
	struct rb_root out_of_order_queue;
	struct sk_buff___96 *ooo_last_skb;
	struct tcp_sack_block duplicate_sack[1];
	struct tcp_sack_block selective_acks[4];
	struct tcp_sack_block recv_sack_cache[4];
	struct sk_buff___96 *highest_sack;
	int lost_cnt_hint;
	u32 prior_ssthresh;
	u32 high_seq;
	u32 retrans_stamp;
	u32 undo_marker;
	int undo_retrans;
	u32 total_retrans;
	u32 urg_seq;
	unsigned int keepalive_time;
	unsigned int keepalive_intvl;
	int linger2;
	u8 bpf_sock_ops_cb_flags;
	struct {
		u32 rtt_us;
		u32 seq;
		u64 time;
	} rcv_rtt_est;
	struct {
		u32 space;
		u32 seq;
		u64 time;
	} rcvq_space;
	struct {
		u32 probe_seq_start;
		u32 probe_seq_end;
	} mtu_probe;
	u32 mtu_info;
	const struct tcp_sock_af_ops___10 *af_specific;
	struct tcp_md5sig_info *md5sig_info;
	struct tcp_fastopen_request___10 *fastopen_req;
	struct request_sock___59 *fastopen_rsk;
	u32 *saved_syn;
};

struct tcp_sock_af_ops___10 {
	struct tcp_md5sig_key * (*md5_lookup)(const struct sock___75 *, const struct sock___75 *);
	int (*calc_md5_hash)(char *, const struct tcp_md5sig_key *, const struct sock___75 *, const struct sk_buff___96 *);
	int (*md5_parse)(struct sock___75 *, int, char *, int);
};

struct tcp_fastopen_request___10 {
	struct tcp_fastopen_cookie cookie;
	struct msghdr___78 *data;
	size_t size;
	int copied;
};

struct ip6_flowlabel___16;

struct ipv6_fl_socklist___16 {
	struct ipv6_fl_socklist___16 *next;
	struct ip6_flowlabel___16 *fl;
	struct callback_head rcu;
};

struct ifmcaddr6___46 {
	struct in6_addr mca_addr;
	struct inet6_dev___46 *idev;
	struct ifmcaddr6___46 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___20 {
	struct in6_addr aca_addr;
	struct fib6_info___20 *aca_rt;
	struct ifacaddr6___20 *aca_next;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct ip6_ra_chain___46 {
	struct ip6_ra_chain___46 *next;
	struct sock___75 *sk;
	int sel;
	void (*destructor)(struct sock___75 *);
};

struct ip6_flowlabel___16 {
	struct ip6_flowlabel___16 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___251 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___106 *fl_net;
};

struct rtable___13 {
	struct dst_entry___75 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	__be32 rt_gateway;
	u32 rt_mtu_locked: 1;
	u32 rt_pmtu: 31;
	struct list_head rt_uncached;
	struct uncached_list *rt_uncached_list;
};

struct rtentry {
	long unsigned int rt_pad1;
	struct sockaddr rt_dst;
	struct sockaddr rt_gateway;
	struct sockaddr rt_genmask;
	short unsigned int rt_flags;
	short int rt_pad2;
	long unsigned int rt_pad3;
	void *rt_pad4;
	short int rt_metric;
	char *rt_dev;
	long unsigned int rt_mtu;
	long unsigned int rt_window;
	short unsigned int rt_irtt;
};

struct net_protocol___11 {
	int (*early_demux)(struct sk_buff___96 *);
	int (*early_demux_handler)(struct sk_buff___96 *);
	int (*handler)(struct sk_buff___96 *);
	void (*err_handler)(struct sk_buff___96 *, u32);
	unsigned int no_policy: 1;
	unsigned int netns_ok: 1;
	unsigned int icmp_strict_tag_validation: 1;
};

struct inet6_protocol___11 {
	void (*early_demux)(struct sk_buff___96 *);
	void (*early_demux_handler)(struct sk_buff___96 *);
	int (*handler)(struct sk_buff___96 *);
	void (*err_handler)(struct sk_buff___96 *, struct inet6_skb_parm *, u8, u8, int, __be32);
	unsigned int flags;
};

struct net_offload___11 {
	struct offload_callbacks___13 callbacks;
	unsigned int flags;
};

struct inet_protosw___2 {
	struct list_head list;
	short unsigned int type;
	short unsigned int protocol;
	struct proto___75 *prot;
	const struct proto_ops___76 *ops;
	unsigned char flags;
};

struct pingv6_ops___2 {
	int (*ipv6_recv_error)(struct sock___75 *, struct msghdr___78 *, int, int *);
	void (*ip6_datagram_recv_common_ctl)(struct sock___75 *, struct msghdr___78 *, struct sk_buff___96 *);
	void (*ip6_datagram_recv_specific_ctl)(struct sock___75 *, struct msghdr___78 *, struct sk_buff___96 *);
	int (*icmpv6_err_convert)(u8, u8, int *);
	void (*ipv6_icmp_error)(struct sock___75 *, struct sk_buff___96 *, int, __be16, u32, u8 *);
	int (*ipv6_chk_addr)(struct net___106 *, const struct in6_addr *, const struct net_device___95 *, int);
};

struct ipv6_stub___14 {
	int (*ipv6_sock_mc_join)(struct sock___75 *, int, const struct in6_addr *);
	int (*ipv6_sock_mc_drop)(struct sock___75 *, int, const struct in6_addr *);
	int (*ipv6_dst_lookup)(struct net___106 *, struct sock___75 *, struct dst_entry___75 **, struct flowi6 *);
	struct fib6_table___20 * (*fib6_get_table)(struct net___106 *, u32);
	struct fib6_info___20 * (*fib6_lookup)(struct net___106 *, int, struct flowi6 *, int);
	struct fib6_info___20 * (*fib6_table_lookup)(struct net___106 *, struct fib6_table___20 *, int, struct flowi6 *, int);
	struct fib6_info___20 * (*fib6_multipath_select)(const struct net___106 *, struct fib6_info___20 *, struct flowi6 *, int, const struct sk_buff___96 *, int);
	u32 (*ip6_mtu_from_fib6)(struct fib6_info___20 *, struct in6_addr *, struct in6_addr *);
	void (*udpv6_encap_enable)();
	void (*ndisc_send_na)(struct net_device___95 *, const struct in6_addr *, const struct in6_addr *, bool, bool, bool, bool);
	struct neigh_table___75 *nd_tbl;
};

struct ipv6_bpf_stub___14 {
	int (*inet6_bind)(struct sock___75 *, struct sockaddr *, int, bool, bool);
	struct sock___75 * (*udp6_lib_lookup)(struct net___106 *, const struct in6_addr *, __be16, const struct in6_addr *, __be16, int, int, struct udp_table *, struct sk_buff___96 *);
};

struct ip_tunnel_encap_ops___8 {
	size_t (*encap_hlen)(struct ip_tunnel_encap *);
	int (*build_header)(struct sk_buff___96 *, struct ip_tunnel_encap *, u8 *, struct flowi4 *);
};

struct xfrm_replay___16 {
	void (*advance)(struct xfrm_state___16 *, __be32);
	int (*check)(struct xfrm_state___16 *, struct sk_buff___96 *, __be32);
	int (*recheck)(struct xfrm_state___16 *, struct sk_buff___96 *, __be32);
	void (*notify)(struct xfrm_state___16 *, int);
	int (*overflow)(struct xfrm_state___16 *, struct sk_buff___96 *);
};

struct xfrm_type___16 {
	char *description;
	struct module___376 *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___16 *);
	void (*destructor)(struct xfrm_state___16 *);
	int (*input)(struct xfrm_state___16 *, struct sk_buff___96 *);
	int (*output)(struct xfrm_state___16 *, struct sk_buff___96 *);
	int (*reject)(struct xfrm_state___16 *, struct sk_buff___96 *, const struct flowi *);
	int (*hdr_offset)(struct xfrm_state___16 *, struct sk_buff___96 *, u8 **);
	u32 (*get_mtu)(struct xfrm_state___16 *, int);
};

struct xfrm_state_afinfo___16;

struct xfrm_mode___16 {
	int (*input2)(struct xfrm_state___16 *, struct sk_buff___96 *);
	int (*input)(struct xfrm_state___16 *, struct sk_buff___96 *);
	int (*output2)(struct xfrm_state___16 *, struct sk_buff___96 *);
	int (*output)(struct xfrm_state___16 *, struct sk_buff___96 *);
	struct sk_buff___96 * (*gso_segment)(struct xfrm_state___16 *, struct sk_buff___96 *, netdev_features_t);
	void (*xmit)(struct xfrm_state___16 *, struct sk_buff___96 *);
	struct xfrm_state_afinfo___16 *afinfo;
	struct module___376 *owner;
	unsigned int encap;
	int flags;
};

struct xfrm_type_offload___16 {
	char *description;
	struct module___376 *owner;
	u8 proto;
	void (*encap)(struct xfrm_state___16 *, struct sk_buff___96 *);
	int (*input_tail)(struct xfrm_state___16 *, struct sk_buff___96 *);
	int (*xmit)(struct xfrm_state___16 *, struct sk_buff___96 *, netdev_features_t);
};

struct xfrm_state_afinfo___16 {
	unsigned int family;
	unsigned int proto;
	__be16 eth_proto;
	struct module___376 *owner;
	const struct xfrm_type___16 *type_map[256];
	const struct xfrm_type_offload___16 *type_offload_map[256];
	struct xfrm_mode___16 *mode_map[5];
	int (*init_flags)(struct xfrm_state___16 *);
	void (*init_tempsel)(struct xfrm_selector *, const struct flowi *);
	void (*init_temprop)(struct xfrm_state___16 *, const struct xfrm_tmpl *, const xfrm_address_t *, const xfrm_address_t *);
	int (*tmpl_sort)(struct xfrm_tmpl **, struct xfrm_tmpl **, int);
	int (*state_sort)(struct xfrm_state___16 **, struct xfrm_state___16 **, int);
	int (*output)(struct net___106 *, struct sock___75 *, struct sk_buff___96 *);
	int (*output_finish)(struct sock___75 *, struct sk_buff___96 *);
	int (*extract_input)(struct xfrm_state___16 *, struct sk_buff___96 *);
	int (*extract_output)(struct xfrm_state___16 *, struct sk_buff___96 *);
	int (*transport_finish)(struct sk_buff___96 *, int);
	void (*local_error)(struct sk_buff___96 *, u32);
};

struct igmphdr {
	__u8 type;
	__u8 code;
	__sum16 csum;
	__be32 group;
};

struct igmpv3_grec {
	__u8 grec_type;
	__u8 grec_auxwords;
	__be16 grec_nsrcs;
	__be32 grec_mca;
	__be32 grec_src[0];
};

struct igmpv3_report {
	__u8 type;
	__u8 resv1;
	__sum16 csum;
	__be16 resv2;
	__be16 ngrec;
	struct igmpv3_grec grec[0];
};

struct igmpv3_query {
	__u8 type;
	__u8 code;
	__sum16 csum;
	__be32 group;
	__u8 qrv: 3;
	__u8 suppress: 1;
	__u8 resv: 4;
	__u8 qqic;
	__be16 nsrcs;
	__be32 srcs[0];
};

struct igmp_mc_iter_state {
	struct seq_net_private___7 p;
	struct net_device___84 *dev;
	struct in_device___8 *in_dev;
};

struct igmp_mcf_iter_state {
	struct seq_net_private___7 p;
	struct net_device___84 *dev;
	struct in_device___8 *idev;
	struct ip_mc_list *im;
};

struct netlink_kernel_cfg___7 {
	unsigned int groups;
	unsigned int flags;
	void (*input)(struct sk_buff___85 *);
	struct mutex *cb_mutex;
	int (*bind)(struct net___95 *, int);
	void (*unbind)(struct net___95 *, int);
	bool (*compare)(struct net___95 *, struct sock___65 *);
};

struct netdev_notifier_info_ext___2 {
	struct netdev_notifier_info___8 info;
	union {
		u32 mtu;
	} ext;
};

struct netdev_notifier_changeupper_info___2 {
	struct netdev_notifier_info___8 info;
	struct net_device___84 *upper_dev;
	bool master;
	bool linking;
	void *upper_info;
};

struct nl_info {
	struct nlmsghdr *nlh;
	struct net___95 *nl_net;
	u32 portid;
	bool skip_notify;
};

struct fib_config {
	u8 fc_dst_len;
	u8 fc_tos;
	u8 fc_protocol;
	u8 fc_scope;
	u8 fc_type;
	u32 fc_table;
	__be32 fc_dst;
	__be32 fc_gw;
	int fc_oif;
	u32 fc_flags;
	u32 fc_priority;
	__be32 fc_prefsrc;
	struct nlattr *fc_mx;
	struct rtnexthop *fc_mp;
	int fc_mx_len;
	int fc_mp_len;
	u32 fc_flow;
	u32 fc_nlflags;
	struct nl_info fc_nlinfo;
	struct nlattr *fc_encap;
	u16 fc_encap_type;
};

struct fib_result_nl {
	__be32 fl_addr;
	u32 fl_mark;
	unsigned char fl_tos;
	unsigned char fl_scope;
	unsigned char tb_id_in;
	unsigned char tb_id;
	unsigned char prefixlen;
	unsigned char nh_sel;
	unsigned char type;
	unsigned char scope;
	int err;
};

struct fib_dump_filter {
	u32 table_id;
	bool filter_set;
	bool dump_all_families;
	bool dump_routes;
	bool dump_exceptions;
	unsigned char protocol;
	unsigned char rt_type;
	unsigned int flags;
	struct net_device___84 *dev;
};

struct nl_info___2 {
	struct nlmsghdr *nlh;
	struct net___106 *nl_net;
	u32 portid;
	bool skip_notify;
};

struct fib_notifier_info___3 {
	struct net___106 *net;
	int family;
	struct netlink_ext_ack *extack;
};

struct fib_config___2 {
	u8 fc_dst_len;
	u8 fc_tos;
	u8 fc_protocol;
	u8 fc_scope;
	u8 fc_type;
	u32 fc_table;
	__be32 fc_dst;
	__be32 fc_gw;
	int fc_oif;
	u32 fc_flags;
	u32 fc_priority;
	__be32 fc_prefsrc;
	struct nlattr *fc_mx;
	struct rtnexthop *fc_mp;
	int fc_mx_len;
	int fc_mp_len;
	u32 fc_flow;
	u32 fc_nlflags;
	struct nl_info___2 fc_nlinfo;
	struct nlattr *fc_encap;
	u16 fc_encap_type;
};

struct fib_nh_exception___5 {
	struct fib_nh_exception___5 *fnhe_next;
	int fnhe_genid;
	__be32 fnhe_daddr;
	u32 fnhe_pmtu;
	bool fnhe_mtu_locked;
	__be32 fnhe_gw;
	long unsigned int fnhe_expires;
	struct rtable___13 *fnhe_rth_input;
	struct rtable___13 *fnhe_rth_output;
	long unsigned int fnhe_stamp;
	struct callback_head rcu;
};

struct fnhe_hash_bucket___5 {
	struct fib_nh_exception___5 *chain;
};

struct fib_info___5;

struct fib_nh___5 {
	struct net_device___95 *nh_dev;
	struct hlist_node nh_hash;
	struct fib_info___5 *nh_parent;
	unsigned int nh_flags;
	unsigned char nh_scope;
	int nh_weight;
	atomic_t nh_upper_bound;
	__u32 nh_tclassid;
	int nh_oif;
	__be32 nh_gw;
	__be32 nh_saddr;
	int nh_saddr_genid;
	struct rtable___13 **nh_pcpu_rth_output;
	struct rtable___13 *nh_rth_input;
	struct fnhe_hash_bucket___5 *nh_exceptions;
	struct lwtunnel_state___9 *nh_lwtstate;
};

struct fib_info___5 {
	struct hlist_node fib_hash;
	struct hlist_node fib_lhash;
	struct net___106 *fib_net;
	int fib_treeref;
	refcount_t fib_clntref;
	unsigned int fib_flags;
	unsigned char fib_dead;
	unsigned char fib_protocol;
	unsigned char fib_scope;
	unsigned char fib_type;
	__be32 fib_prefsrc;
	u32 fib_tb_id;
	u32 fib_priority;
	struct dst_metrics *fib_metrics;
	int fib_nhs;
	struct callback_head rcu;
	struct fib_nh___5 fib_nh[0];
};

struct fib_result___4 {
	__be32 prefix;
	unsigned char prefixlen;
	unsigned char nh_sel;
	unsigned char type;
	unsigned char scope;
	u32 tclassid;
	struct fib_info___5 *fi;
	struct fib_table *table;
	struct hlist_head *fa_head;
};

struct fib_nh_notifier_info {
	struct fib_notifier_info___3 info;
	struct fib_nh___5 *fib_nh;
};

struct fib_alias {
	struct hlist_node fa_list;
	struct fib_info___5 *fa_info;
	u8 fa_tos;
	u8 fa_type;
	u8 fa_state;
	u8 fa_slen;
	u32 tb_id;
	s16 fa_default;
	struct callback_head rcu;
};

struct seq_net_private___10 {
	struct net___106 *net;
};

struct netlink_skb_parms___16 {
	struct scm_creds creds;
	__u32 portid;
	__u32 dst_group;
	__u32 flags;
	struct sock___75 *sk;
	bool nsid_is_set;
	int nsid;
};

struct fib_entry_notifier_info {
	struct fib_notifier_info___3 info;
	u32 dst;
	int dst_len;
	struct fib_info___5 *fi;
	u8 tos;
	u8 type;
	u32 tb_id;
};

struct fib_dump_filter___2 {
	u32 table_id;
	bool filter_set;
	bool dump_all_families;
	bool dump_routes;
	bool dump_exceptions;
	unsigned char protocol;
	unsigned char rt_type;
	unsigned int flags;
	struct net_device___95 *dev;
};

typedef unsigned int t_key;

struct key_vector {
	t_key key;
	unsigned char pos;
	unsigned char bits;
	unsigned char slen;
	union {
		struct hlist_head leaf;
		struct key_vector *tnode[0];
	};
};

struct tnode {
	struct callback_head rcu;
	t_key empty_children;
	t_key full_children;
	struct key_vector *parent;
	struct key_vector kv[1];
};

struct trie_use_stats {
	unsigned int gets;
	unsigned int backtrack;
	unsigned int semantic_match_passed;
	unsigned int semantic_match_miss;
	unsigned int null_node_hit;
	unsigned int resize_node_skipped;
};

struct trie_stat {
	unsigned int totdepth;
	unsigned int maxdepth;
	unsigned int tnodes;
	unsigned int leaves;
	unsigned int nullpointers;
	unsigned int prefixes;
	unsigned int nodesizes[32];
};

struct trie {
	struct key_vector kv[1];
	struct trie_use_stats *stats;
};

struct fib_trie_iter {
	struct seq_net_private___10 p;
	struct fib_table *tb;
	struct key_vector *tnode;
	unsigned int index;
	unsigned int depth;
};

struct fib_route_iter {
	struct seq_net_private___10 p;
	struct fib_table *main_tb;
	struct key_vector *tnode;
	loff_t pos;
	t_key key;
};

struct fib_notifier_info___4 {
	struct net___103 *net;
	int family;
	struct netlink_ext_ack *extack;
};

struct ipfrag_skb_cb {
	union {
		struct inet_skb_parm h4;
		struct inet6_skb_parm h6;
	};
	struct sk_buff___89 *next_frag;
	int frag_run_len;
};

struct icmpv6_echo {
	__be16 identifier;
	__be16 sequence;
};

struct icmpv6_nd_advt {
	__u32 reserved: 5;
	__u32 override: 1;
	__u32 solicited: 1;
	__u32 router: 1;
	__u32 reserved2: 24;
};

struct icmpv6_nd_ra {
	__u8 hop_limit;
	__u8 reserved: 3;
	__u8 router_pref: 2;
	__u8 home_agent: 1;
	__u8 other: 1;
	__u8 managed: 1;
	__be16 rt_lifetime;
};

struct icmp6hdr {
	__u8 icmp6_type;
	__u8 icmp6_code;
	__sum16 icmp6_cksum;
	union {
		__be32 un_data32[1];
		__be16 un_data16[2];
		__u8 un_data8[4];
		struct icmpv6_echo u_echo;
		struct icmpv6_nd_advt u_nd_advt;
		struct icmpv6_nd_ra u_nd_ra;
	} icmp6_dataun;
};

struct ping_iter_state {
	struct seq_net_private___10 p;
	int bucket;
	sa_family_t family;
};

struct pingfakehdr {
	struct icmphdr icmph;
	struct msghdr___78 *msg;
	sa_family_t family;
	__wsum wcheck;
};

struct ping_table {
	struct hlist_nulls_head hash[64];
	rwlock_t lock;
};

struct module___377;

struct file___451;

struct kiocb___451;

struct iov_iter___218;

struct poll_table_struct___290;

struct vm_area_struct___452;

struct inode___451;

struct file_lock___451;

struct page___452;

struct pipe_inode_info___132;

struct seq_file___390;

struct file_operations___451 {
	struct module___377 *owner;
	loff_t (*llseek)(struct file___451 *, loff_t, int);
	ssize_t (*read)(struct file___451 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___451 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___451 *, struct iov_iter___218 *);
	ssize_t (*write_iter)(struct kiocb___451 *, struct iov_iter___218 *);
	int (*iopoll)(struct kiocb___451 *, bool);
	int (*iterate)(struct file___451 *, struct dir_context *);
	int (*iterate_shared)(struct file___451 *, struct dir_context *);
	__poll_t (*poll)(struct file___451 *, struct poll_table_struct___290 *);
	long int (*unlocked_ioctl)(struct file___451 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___451 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___451 *, struct vm_area_struct___452 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___451 *, struct file___451 *);
	int (*flush)(struct file___451 *, fl_owner_t);
	int (*release)(struct inode___451 *, struct file___451 *);
	int (*fsync)(struct file___451 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___451 *, int);
	int (*lock)(struct file___451 *, int, struct file_lock___451 *);
	ssize_t (*sendpage)(struct file___451 *, struct page___452 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___451 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___451 *, int, struct file_lock___451 *);
	ssize_t (*splice_write)(struct pipe_inode_info___132 *, struct file___451 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___451 *, loff_t *, struct pipe_inode_info___132 *, size_t, unsigned int);
	int (*setlease)(struct file___451 *, long int, struct file_lock___451 **, void **);
	long int (*fallocate)(struct file___451 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___390 *, struct file___451 *);
	ssize_t (*copy_file_range)(struct file___451 *, loff_t, struct file___451 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___451 *, loff_t, struct file___451 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___451 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___452 {
	u64 seqnum;
	struct vm_area_struct___452 *vmas[4];
};

struct page_frag___452 {
	struct page___452 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___452;

struct mem_cgroup___184;

struct pid___252;

struct cred___419;

struct nsproxy___346;

struct signal_struct___326;

struct bio_list___241;

struct backing_dev_info___241;

struct css_set___300;

struct vm_struct___355;

struct task_struct___453 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___453 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___452 *mm;
	struct mm_struct___452 *active_mm;
	struct vmacache___452 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___453 *real_parent;
	struct task_struct___453 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___453 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___184 *active_memcg;
	long int rh_reserved2;
	struct pid___252 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___252 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___252 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___419 *ptracer_cred;
	const struct cred___419 *real_cred;
	const struct cred___419 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___346 *nsproxy;
	struct signal_struct___326 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___453 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___241 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___241 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___300 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___132 *splice_pipe;
	struct page_frag___452 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___184 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___453 *oom_reaper_list;
	struct vm_struct___355 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___156 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___452 *pgtable_t___452;

struct address_space___451;

struct dev_pagemap___439;

struct page___452 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___451 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___452 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___452 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___452 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___439 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___184 *mem_cgroup;
};

struct pglist_data___452;

struct lruvec___452 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___452 *pgdat;
};

struct zone___452 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___452 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___452 {
	struct zone___452 *zone;
	int zone_idx;
};

struct zonelist___452 {
	struct zoneref___452 _zonerefs[25];
};

struct pglist_data___452 {
	struct zone___452 node_zones[3];
	struct zonelist___452 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___453 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___453 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___452 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___453 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___453 *owner;
};

struct secondary_data___453 {
	void *stack;
	struct task_struct___453 *task;
	long int status;
};

struct blocking_notifier_head___452 {
	struct rw_semaphore___453 rwsem;
	struct notifier_block *head;
};

struct cgroup___300;

struct cgroup_subsys___300;

struct cgroup_subsys_state___300 {
	struct cgroup___300 *cgroup;
	struct cgroup_subsys___300 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___300 *parent;
};

struct kernfs_node___446;

struct cgroup_file___300 {
	struct kernfs_node___446 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___184;

struct mem_cgroup___184 {
	struct cgroup_subsys_state___300 css;
	struct mem_cgroup_id___16 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___300 events_file;
	struct cgroup_file___300 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___453 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___184 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___252;

struct upid___252 {
	int nr;
	struct pid_namespace___252 *ns;
};

struct dentry___451;

struct user_namespace___316;

struct ucounts___316;

struct pid_namespace___252 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___453 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___252 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___451 *proc_self;
	struct dentry___451 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___316 *user_ns;
	struct ucounts___316 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___29 ns;
};

struct pid___252 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___252 numbers[1];
};

struct key___419;

struct user_namespace___316 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___316 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___29 ns;
	long unsigned int flags;
	struct key___419 *persistent_keyring_register;
	struct rw_semaphore___453 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___316 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct user_struct___419 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___419 *uid_keyring;
	struct key___419 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___439;

struct vm_area_struct___452 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___452 *vm_next;
	struct vm_area_struct___452 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___452 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___439 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___451 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___452;

struct mm_struct___452 {
	struct {
		struct vm_area_struct___452 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___451 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___453 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___452 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___453 *owner;
		struct user_namespace___316 *user_ns;
		struct file___451 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___452 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___419 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___419 *session_keyring;
	struct key___419 *process_keyring;
	struct key___419 *thread_keyring;
	struct key___419 *request_key_auth;
	void *security;
	struct user_struct___419 *user;
	struct user_namespace___316 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___107;

struct cgroup_namespace___300;

struct nsproxy___346 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___252 *pid_ns_for_children;
	struct net___107 *net_ns;
	struct cgroup_namespace___300 *cgroup_ns;
};

struct signal_struct___326 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___453 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___453 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___252 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___252 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___452 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___252 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___241;

struct bio_list___241 {
	struct bio___241 *head;
	struct bio___241 *tail;
};

struct bdi_writeback_congested___241;

struct bdi_writeback___241 {
	struct backing_dev_info___241 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___241 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___300 *memcg_css;
	struct cgroup_subsys_state___300 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___419;

struct backing_dev_info___241 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___241 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___419 *dev;
	struct device___419 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___451 *debug_dir;
	struct dentry___451 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___300 {
	struct cgroup_subsys_state___300 *subsys[13];
	refcount_t refcount;
	struct css_set___300 *dom_cset;
	struct cgroup___300 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___300 *mg_src_cgrp;
	struct cgroup___300 *mg_dst_cgrp;
	struct css_set___300 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___451;

struct pipe_buffer___132;

struct pipe_inode_info___132 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___452 *tmp_page;
	struct fasync_struct___451 *fasync_readers;
	struct fasync_struct___451 *fasync_writers;
	struct pipe_buffer___132 *bufs;
	struct user_struct___419 *user;
};

struct vm_struct___355 {
	struct vm_struct___355 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___452 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___338 {
	struct task_struct___453 task;
	long unsigned int stack[8192];
};

struct address_space_operations___451;

struct address_space___451 {
	struct inode___451 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___453 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___451 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___439)(struct vm_area_struct___452 *, long unsigned int, const struct page___452 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___439)(struct page___452 *, void *);

struct dev_pagemap___439 {
	dev_page_fault_t___439 page_fault;
	dev_page_free_t___439 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___419 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___452 {
	struct vfsmount *mnt;
	struct dentry___451 *dentry;
};

struct fown_struct___252 {
	rwlock_t lock;
	struct pid___252 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___451 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___452 f_path;
	struct inode___451 *f_inode;
	const struct file_operations___451 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___252 f_owner;
	const struct cred___419 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___451 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___439;

struct vm_operations_struct___439 {
	void (*open)(struct vm_area_struct___452 *);
	void (*close)(struct vm_area_struct___452 *);
	int (*split)(struct vm_area_struct___452 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___452 *);
	vm_fault_t (*fault)(struct vm_fault___439 *);
	vm_fault_t (*huge_fault)(struct vm_fault___439 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___439 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___452 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___439 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___439 *);
	int (*access)(struct vm_area_struct___452 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___452 *);
	int (*set_policy)(struct vm_area_struct___452 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___452 *, long unsigned int);
	struct page___452 * (*find_special_page)(struct vm_area_struct___452 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___452 {
	struct task_struct___453 *task;
	struct core_thread___452 *next;
};

struct core_state___452 {
	atomic_t nr_threads;
	struct core_thread___452 dumper;
	struct completion startup;
};

struct vm_fault___439 {
	struct vm_area_struct___452 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___452 *cow_page;
	struct mem_cgroup___184 *memcg;
	struct page___452 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___452 prealloc_pte;
};

struct kset___438;

struct kobj_type___438;

struct kobject___439 {
	const char *name;
	struct list_head entry;
	struct kobject___439 *parent;
	struct kset___438 *kset;
	struct kobj_type___438 *ktype;
	struct kernfs_node___446 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___377 {
	struct kobject___439 kobj;
	struct module___377 *mod;
	struct kobject___439 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___377 {
	struct module___377 *mod;
	struct latch_tree_node node;
};

struct module_layout___377 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___377 mtn;
};

struct module_attribute___377;

struct kernel_param___377;

struct module___377 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___377 mkobj;
	struct module_attribute___377 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___439 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___377 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___377 core_layout;
	struct module_layout___377 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide53;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide54;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bio_vec___243 {
	struct page___452 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___218 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___243 *bvec;
		struct pipe_inode_info___132 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct msghdr___79 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___218 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___451 *msg_iocb;
};

struct kiocb___451 {
	struct file___451 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___451 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dentry_operations___451;

struct super_block___451;

struct dentry___451 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___451 *d_parent;
	struct qstr d_name;
	struct inode___451 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___451 *d_op;
	struct super_block___451 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___451;

struct block_device___451;

struct inode___451 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___451 *i_op;
	struct super_block___451 *i_sb;
	struct address_space___451 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___453 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___241 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___451 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___451 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___132 *i_pipe;
		struct block_device___451 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___451 {
	int (*d_revalidate)(struct dentry___451 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___451 *, unsigned int);
	int (*d_hash)(const struct dentry___451 *, struct qstr *);
	int (*d_compare)(const struct dentry___451 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___451 *);
	int (*d_init)(struct dentry___451 *);
	void (*d_release)(struct dentry___451 *);
	void (*d_prune)(struct dentry___451 *);
	void (*d_iput)(struct dentry___451 *, struct inode___451 *);
	char * (*d_dname)(struct dentry___451 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___452 *);
	int (*d_manage)(const struct path___452 *, bool);
	struct dentry___451 * (*d_real)(struct dentry___451 *, const struct inode___451 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___451;

struct mem_dqinfo___451 {
	struct quota_format_type___451 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___451;

struct quota_info___451 {
	unsigned int flags;
	struct rw_semaphore___453 dqio_sem;
	struct inode___451 *files[3];
	struct mem_dqinfo___451 info[3];
	const struct quota_format_ops___451 *ops[3];
};

struct rcuwait___451 {
	struct task_struct___453 *task;
};

struct percpu_rw_semaphore___451 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___453 rw_sem;
	struct rcuwait___451 writer;
	int readers_block;
};

struct sb_writers___451 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___451 rw_sem[3];
};

struct shrink_control___184;

struct shrinker___184 {
	long unsigned int (*count_objects)(struct shrinker___184 *, struct shrink_control___184 *);
	long unsigned int (*scan_objects)(struct shrinker___184 *, struct shrink_control___184 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___451;

struct super_operations___451;

struct dquot_operations___451;

struct quotactl_ops___451;

struct super_block___451 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___451 *s_type;
	const struct super_operations___451 *s_op;
	const struct dquot_operations___451 *dq_op;
	const struct quotactl_ops___451 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___451 *s_root;
	struct rw_semaphore___453 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___451 *s_bdev;
	struct backing_dev_info___241 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___451 s_dquot;
	struct sb_writers___451 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___451 *s_d_op;
	int cleancache_poolid;
	struct shrinker___184 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___316 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___184 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___184 *memcg;
};

struct iattr___451 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___451 *ia_file;
};

struct dquot___451 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___451 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___451 {
	int qf_fmt_id;
	const struct quota_format_ops___451 *qf_ops;
	struct module___377 *qf_owner;
	struct quota_format_type___451 *qf_next;
};

struct quota_format_ops___451 {
	int (*check_quota_file)(struct super_block___451 *, int);
	int (*read_file_info)(struct super_block___451 *, int);
	int (*write_file_info)(struct super_block___451 *, int);
	int (*free_file_info)(struct super_block___451 *, int);
	int (*read_dqblk)(struct dquot___451 *);
	int (*commit_dqblk)(struct dquot___451 *);
	int (*release_dqblk)(struct dquot___451 *);
	int (*get_next_id)(struct super_block___451 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___451 {
	int (*write_dquot)(struct dquot___451 *);
	struct dquot___451 * (*alloc_dquot)(struct super_block___451 *, int);
	void (*destroy_dquot)(struct dquot___451 *);
	int (*acquire_dquot)(struct dquot___451 *);
	int (*release_dquot)(struct dquot___451 *);
	int (*mark_dirty)(struct dquot___451 *);
	int (*write_info)(struct super_block___451 *, int);
	qsize_t * (*get_reserved_space)(struct inode___451 *);
	int (*get_projid)(struct inode___451 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___451 *, qsize_t *);
	int (*get_next_id)(struct super_block___451 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___451 {
	int (*quota_on)(struct super_block___451 *, int, int, const struct path___452 *);
	int (*quota_off)(struct super_block___451 *, int);
	int (*quota_enable)(struct super_block___451 *, unsigned int);
	int (*quota_disable)(struct super_block___451 *, unsigned int);
	int (*quota_sync)(struct super_block___451 *, int);
	int (*set_info)(struct super_block___451 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___451 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___451 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___451 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___451 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___451 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___204;

struct address_space_operations___451 {
	int (*writepage)(struct page___452 *, struct writeback_control___204 *);
	int (*readpage)(struct file___451 *, struct page___452 *);
	int (*writepages)(struct address_space___451 *, struct writeback_control___204 *);
	int (*set_page_dirty)(struct page___452 *);
	int (*readpages)(struct file___451 *, struct address_space___451 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___451 *, struct address_space___451 *, loff_t, unsigned int, unsigned int, struct page___452 **, void **);
	int (*write_end)(struct file___451 *, struct address_space___451 *, loff_t, unsigned int, unsigned int, struct page___452 *, void *);
	sector_t (*bmap)(struct address_space___451 *, sector_t);
	void (*invalidatepage)(struct page___452 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___452 *, gfp_t);
	void (*freepage)(struct page___452 *);
	ssize_t (*direct_IO)(struct kiocb___451 *, struct iov_iter___218 *);
	int (*migratepage)(struct address_space___451 *, struct page___452 *, struct page___452 *, enum migrate_mode);
	bool (*isolate_page)(struct page___452 *, isolate_mode_t);
	void (*putback_page)(struct page___452 *);
	int (*launder_page)(struct page___452 *);
	int (*is_partially_uptodate)(struct page___452 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___452 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___451 *, struct page___452 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___451 *, sector_t *);
	void (*swap_deactivate)(struct file___451 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___204 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___241 *wb;
	struct inode___451 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___451 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___451 *bd_inode;
	struct super_block___451 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___451 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___241 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___451 {
	struct dentry___451 * (*lookup)(struct inode___451 *, struct dentry___451 *, unsigned int);
	const char * (*get_link)(struct dentry___451 *, struct inode___451 *, struct delayed_call *);
	int (*permission)(struct inode___451 *, int);
	struct posix_acl * (*get_acl)(struct inode___451 *, int);
	int (*readlink)(struct dentry___451 *, char *, int);
	int (*create)(struct inode___451 *, struct dentry___451 *, umode_t, bool);
	int (*link)(struct dentry___451 *, struct inode___451 *, struct dentry___451 *);
	int (*unlink)(struct inode___451 *, struct dentry___451 *);
	int (*symlink)(struct inode___451 *, struct dentry___451 *, const char *);
	int (*mkdir)(struct inode___451 *, struct dentry___451 *, umode_t);
	int (*rmdir)(struct inode___451 *, struct dentry___451 *);
	int (*mknod)(struct inode___451 *, struct dentry___451 *, umode_t, dev_t);
	int (*rename)(struct inode___451 *, struct dentry___451 *, struct inode___451 *, struct dentry___451 *, unsigned int);
	int (*setattr)(struct dentry___451 *, struct iattr___451 *);
	int (*getattr)(const struct path___452 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___451 *, char *, size_t);
	int (*fiemap)(struct inode___451 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___451 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___451 *, struct dentry___451 *, struct file___451 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___451 *, struct dentry___451 *, umode_t);
	int (*set_acl)(struct inode___451 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___451 {
	void (*fl_copy_lock)(struct file_lock___451 *, struct file_lock___451 *);
	void (*fl_release_private)(struct file_lock___451 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___451;

struct file_lock___451 {
	struct file_lock___451 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___451 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___451 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___451 *fl_ops;
	const struct lock_manager_operations___451 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___451 {
	int (*lm_compare_owner)(struct file_lock___451 *, struct file_lock___451 *);
	long unsigned int (*lm_owner_key)(struct file_lock___451 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___451 *);
	int (*lm_grant)(struct file_lock___451 *, int);
	bool (*lm_break)(struct file_lock___451 *);
	int (*lm_change)(struct file_lock___451 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___451 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___451 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___451 *fa_next;
	struct file___451 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___451 {
	const char *name;
	int fs_flags;
	struct dentry___451 * (*mount)(struct file_system_type___451 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___451 *);
	struct module___377 *owner;
	struct file_system_type___451 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___451 {
	struct inode___451 * (*alloc_inode)(struct super_block___451 *);
	void (*destroy_inode)(struct inode___451 *);
	void (*dirty_inode)(struct inode___451 *, int);
	int (*write_inode)(struct inode___451 *, struct writeback_control___204 *);
	int (*drop_inode)(struct inode___451 *);
	void (*evict_inode)(struct inode___451 *);
	void (*put_super)(struct super_block___451 *);
	int (*sync_fs)(struct super_block___451 *, int);
	int (*freeze_super)(struct super_block___451 *);
	int (*freeze_fs)(struct super_block___451 *);
	int (*thaw_super)(struct super_block___451 *);
	int (*unfreeze_fs)(struct super_block___451 *);
	int (*statfs)(struct dentry___451 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___451 *, int *, char *);
	void (*umount_begin)(struct super_block___451 *);
	int (*show_options)(struct seq_file___390 *, struct dentry___451 *);
	int (*show_devname)(struct seq_file___390 *, struct dentry___451 *);
	int (*show_path)(struct seq_file___390 *, struct dentry___451 *);
	int (*show_stats)(struct seq_file___390 *, struct dentry___451 *);
	ssize_t (*quota_read)(struct super_block___451 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___451 *, int, const char *, size_t, loff_t);
	struct dquot___451 ** (*get_dquots)(struct inode___451 *);
	int (*bdev_try_to_free_page)(struct super_block___451 *, struct page___452 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___451 *, struct shrink_control___184 *);
	long int (*free_cached_objects)(struct super_block___451 *, struct shrink_control___184 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___300)(struct file___451 *, wait_queue_head_t *, struct poll_table_struct___290 *);

struct poll_table_struct___290 {
	poll_queue_proc___300 _qproc;
	__poll_t _key;
};

struct seq_operations___390;

struct seq_file___390 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___390 *op;
	int poll_event;
	const struct file___451 *file;
	void *private;
};

typedef void bio_end_io_t___241(struct bio___241 *);

struct bio_integrity_payload___241;

struct bio_set___241;

struct bio___241 {
	struct bio___241 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___241 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___241 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___243 *bi_io_vec;
	struct bio_set___241 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___243 bi_inline_vecs[0];
};

struct socket_wq___77 {
	wait_queue_head_t wait;
	struct fasync_struct___451 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct sock___76;

struct proto_ops___77;

struct socket___78 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___77 *wq;
	struct file___451 *file;
	struct sock___76 *sk;
	const struct proto_ops___77 *ops;
};

typedef struct {
	struct net___107 *net;
} possible_net_t___98;

struct proto___76;

struct sock_common___76 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___76 *skc_prot;
	possible_net_t___98 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___76 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___97;

struct sk_buff_head___96 {
	struct sk_buff___97 *next;
	struct sk_buff___97 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___76;

struct xfrm_policy___17;

struct dst_entry___76;

struct net_device___96;

struct sock___76 {
	struct sock_common___76 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___96 sk_error_queue;
	struct sk_buff_head___96 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___97 *head;
		struct sk_buff___97 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___76 *sk_filter;
	union {
		struct socket_wq___77 *sk_wq;
		struct socket_wq___77 *sk_wq_raw;
	};
	struct xfrm_policy___17 *sk_policy[2];
	struct dst_entry___76 *sk_rx_dst;
	struct dst_entry___76 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___97 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___96 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___452 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___76 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___252 *sk_peer_pid;
	const struct cred___419 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___78 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___184 *sk_memcg;
	void (*sk_state_change)(struct sock___76 *);
	void (*sk_data_ready)(struct sock___76 *);
	void (*sk_write_space)(struct sock___76 *);
	void (*sk_error_report)(struct sock___76 *);
	int (*sk_backlog_rcv)(struct sock___76 *, struct sk_buff___97 *);
	struct sk_buff___97 * (*sk_validate_xmit_skb)(struct sock___76 *, struct net_device___96 *, struct sk_buff___97 *);
	void (*sk_destruct)(struct sock___76 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

typedef int (*sk_read_actor_t___76)(read_descriptor_t *, struct sk_buff___97 *, unsigned int, size_t);

struct proto_ops___77 {
	int family;
	struct module___377 *owner;
	int (*release)(struct socket___78 *);
	int (*bind)(struct socket___78 *, struct sockaddr *, int);
	int (*connect)(struct socket___78 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___78 *, struct socket___78 *);
	int (*accept)(struct socket___78 *, struct socket___78 *, int, bool);
	int (*getname)(struct socket___78 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___451 *, struct socket___78 *, struct poll_table_struct___290 *);
	int (*ioctl)(struct socket___78 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___78 *, int);
	int (*shutdown)(struct socket___78 *, int);
	int (*setsockopt)(struct socket___78 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___78 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___78 *, struct msghdr___79 *, size_t);
	int (*recvmsg)(struct socket___78 *, struct msghdr___79 *, size_t, int);
	int (*mmap)(struct file___451 *, struct socket___78 *, struct vm_area_struct___452 *);
	ssize_t (*sendpage)(struct socket___78 *, struct page___452 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___78 *, loff_t *, struct pipe_inode_info___132 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___76 *, int);
	int (*peek_len)(struct socket___78 *);
	int (*read_sock)(struct sock___76 *, read_descriptor_t *, sk_read_actor_t___76);
	int (*sendpage_locked)(struct sock___76 *, struct page___452 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___76 *, struct msghdr___79 *, size_t);
	int (*set_rcvlowat)(struct sock___76 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct sec_path___17;

struct nf_bridge_info___96;

struct sk_buff___97 {
	union {
		struct {
			struct sk_buff___97 *next;
			struct sk_buff___97 *prev;
			union {
				struct net_device___96 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___76 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___97 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path___17 *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___96 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___96;

struct netns_frags___96 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___96 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ip_ra_chain___42;

struct fib_rules_ops___76;

struct fib_notifier_ops___77;

struct netns_ipv4___96 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___42 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___76 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___76 *fibnl;
	struct sock___76 **icmp_sk;
	struct sock___76 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___76 **tcp_sk;
	struct netns_frags___96 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___76 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___77 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___77 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___76;

struct dst_ops___107 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___107 *);
	struct dst_entry___76 * (*check)(struct dst_entry___76 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___76 *);
	unsigned int (*mtu)(const struct dst_entry___76 *);
	u32 * (*cow_metrics)(struct dst_entry___76 *, long unsigned int);
	void (*destroy)(struct dst_entry___76 *);
	void (*ifdown)(struct dst_entry___76 *, struct net_device___96 *, int);
	struct dst_entry___76 * (*negative_advice)(struct dst_entry___76 *);
	void (*link_failure)(struct sk_buff___97 *);
	void (*update_pmtu)(struct dst_entry___76 *, struct sock___76 *, struct sk_buff___97 *, u32);
	void (*redirect)(struct dst_entry___76 *, struct sock___76 *, struct sk_buff___97 *);
	int (*local_out)(struct net___107 *, struct sock___76 *, struct sk_buff___97 *);
	struct neighbour___76 * (*neigh_lookup)(const struct dst_entry___76 *, struct sk_buff___97 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___76 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_info___21;

struct rt6_info___21;

struct fib6_table___21;

struct netns_ipv6___107 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___96 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info___21 *fib6_null_entry;
	struct rt6_info___21 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___21 *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___107 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info___21 *ip6_prohibit_entry;
	struct rt6_info___21 *ip6_blk_hole_entry;
	struct fib6_table___21 *fib6_local_tbl;
	struct fib_rules_ops___76 *fib6_rules_ops;
	struct sock___76 **icmp_sk;
	struct sock___76 *ndisc_sk;
	struct sock___76 *tcp_sk;
	struct sock___76 *igmp_sk;
	struct sock___76 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___76 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___77 *notifier_ops;
	struct fib_notifier_ops___77 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___77 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___76 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct nf_hook_entries___14;

struct netns_nf___15 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_queue_handler *queue_handler;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header *nf_log_dir_header;
	struct nf_hook_entries___14 *hooks_ipv4[5];
	struct nf_hook_entries___14 *hooks_ipv6[5];
	struct nf_hook_entries___14 *hooks_arp[3];
	struct nf_hook_entries___14 *hooks_bridge[5];
	bool defrag_ipv4;
	bool defrag_ipv6;
};

struct netns_nf_frag___96 {
	struct netns_frags___96 frags;
};

struct netns_xfrm___107 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___76 *nlsk;
	struct sock___76 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___107 xfrm4_dst_ops;
	struct dst_ops___107 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___86;

struct net___107 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___316 *user_ns;
	struct ucounts___316 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___29 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___76 *rtnl;
	struct sock___76 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___96 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___96 ipv4;
	struct netns_ipv6___107 ipv6;
	struct netns_sctp___77 sctp;
	struct netns_nf___15 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___96 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___76 *nfnl;
	struct sock___76 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___107 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___76 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___86 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kernfs_root___445;

struct kernfs_elem_dir___445 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___445 *root;
};

struct kernfs_syscall_ops___445;

struct kernfs_root___445 {
	struct kernfs_node___446 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___445 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___445 {
	struct kernfs_node___446 *target_kn;
};

struct kernfs_ops___445;

struct kernfs_elem_attr___445 {
	const struct kernfs_ops___445 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___446 *notify_next;
};

struct kernfs_node___446 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___446 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___445 dir;
		struct kernfs_elem_symlink___445 symlink;
		struct kernfs_elem_attr___445 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___445;

struct kernfs_ops___445 {
	int (*open)(struct kernfs_open_file___445 *);
	void (*release)(struct kernfs_open_file___445 *);
	int (*seq_show)(struct seq_file___390 *, void *);
	void * (*seq_start)(struct seq_file___390 *, loff_t *);
	void * (*seq_next)(struct seq_file___390 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___390 *, void *);
	ssize_t (*read)(struct kernfs_open_file___445 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___445 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___445 *, struct vm_area_struct___452 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___445 *, struct poll_table_struct___290 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___445 {
	int (*remount_fs)(struct kernfs_root___445 *, int *, char *);
	int (*show_options)(struct seq_file___390 *, struct kernfs_root___445 *);
	int (*mkdir)(struct kernfs_node___446 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___446 *);
	int (*rename)(struct kernfs_node___446 *, struct kernfs_node___446 *, const char *);
	int (*show_path)(struct seq_file___390 *, struct kernfs_node___446 *, struct kernfs_root___445 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___445 {
	struct kernfs_node___446 *kn;
	struct file___451 *file;
	struct seq_file___390 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___439 *vm_ops;
};

struct kobj_ns_type_operations___76 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___76 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___415;

struct attribute_group___416 {
	const char *name;
	umode_t (*is_visible)(struct kobject___439 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___439 *, struct bin_attribute___415 *, int);
	struct attribute **attrs;
	struct bin_attribute___415 **bin_attrs;
};

struct bin_attribute___415 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___451 *, struct kobject___439 *, struct bin_attribute___415 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___451 *, struct kobject___439 *, struct bin_attribute___415 *, char *, loff_t, size_t);
	int (*mmap)(struct file___451 *, struct kobject___439 *, struct bin_attribute___415 *, struct vm_area_struct___452 *);
};

struct sysfs_ops___438 {
	ssize_t (*show)(struct kobject___439 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___439 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___438;

struct kset___438 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___439 kobj;
	const struct kset_uevent_ops___438 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___438 {
	void (*release)(struct kobject___439 *);
	const struct sysfs_ops___438 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___76 * (*child_ns_type)(struct kobject___439 *);
	const void * (*namespace)(struct kobject___439 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___438 {
	int (* const filter)(struct kset___438 *, struct kobject___439 *);
	const char * (* const name)(struct kset___438 *, struct kobject___439 *);
	int (* const uevent)(struct kset___438 *, struct kobject___439 *, struct kobj_uevent_env *);
};

struct kobj_attribute___429 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___439 *, struct kobj_attribute___429 *, char *);
	ssize_t (*store)(struct kobject___439 *, struct kobj_attribute___429 *, const char *, size_t);
};

struct dev_pm_ops___419 {
	int (*prepare)(struct device___419 *);
	void (*complete)(struct device___419 *);
	int (*suspend)(struct device___419 *);
	int (*resume)(struct device___419 *);
	int (*freeze)(struct device___419 *);
	int (*thaw)(struct device___419 *);
	int (*poweroff)(struct device___419 *);
	int (*restore)(struct device___419 *);
	int (*suspend_late)(struct device___419 *);
	int (*resume_early)(struct device___419 *);
	int (*freeze_late)(struct device___419 *);
	int (*thaw_early)(struct device___419 *);
	int (*poweroff_late)(struct device___419 *);
	int (*restore_early)(struct device___419 *);
	int (*suspend_noirq)(struct device___419 *);
	int (*resume_noirq)(struct device___419 *);
	int (*freeze_noirq)(struct device___419 *);
	int (*thaw_noirq)(struct device___419 *);
	int (*poweroff_noirq)(struct device___419 *);
	int (*restore_noirq)(struct device___419 *);
	int (*runtime_suspend)(struct device___419 *);
	int (*runtime_resume)(struct device___419 *);
	int (*runtime_idle)(struct device___419 *);
};

struct dev_pm_info___419 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___419 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___419;

struct bus_type___419;

struct device_driver___419;

struct dev_pm_domain___419;

struct dma_map_ops___191;

struct fwnode_handle___339;

struct class___419;

struct device___419 {
	struct device___419 *parent;
	struct device_private *p;
	struct kobject___439 kobj;
	const char *init_name;
	const struct device_type___419 *type;
	struct mutex mutex;
	struct bus_type___419 *bus;
	struct device_driver___419 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___419 power;
	struct dev_pm_domain___419 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___191 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___339 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___419 *class;
	const struct attribute_group___416 **groups;
	void (*release)(struct device___419 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___419 {
	struct dev_pm_ops___419 ops;
	void (*detach)(struct device___419 *, bool);
	int (*activate)(struct device___419 *);
	void (*sync)(struct device___419 *);
	void (*dismiss)(struct device___419 *);
};

struct bus_type___419 {
	const char *name;
	const char *dev_name;
	struct device___419 *dev_root;
	const struct attribute_group___416 **bus_groups;
	const struct attribute_group___416 **dev_groups;
	const struct attribute_group___416 **drv_groups;
	int (*match)(struct device___419 *, struct device_driver___419 *);
	int (*uevent)(struct device___419 *, struct kobj_uevent_env *);
	int (*probe)(struct device___419 *);
	int (*remove)(struct device___419 *);
	void (*shutdown)(struct device___419 *);
	int (*online)(struct device___419 *);
	int (*offline)(struct device___419 *);
	int (*suspend)(struct device___419 *, pm_message_t);
	int (*resume)(struct device___419 *);
	int (*num_vf)(struct device___419 *);
	int (*dma_configure)(struct device___419 *);
	const struct dev_pm_ops___419 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___419 {
	const char *name;
	struct bus_type___419 *bus;
	struct module___377 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___419 *);
	int (*remove)(struct device___419 *);
	void (*shutdown)(struct device___419 *);
	int (*suspend)(struct device___419 *, pm_message_t);
	int (*resume)(struct device___419 *);
	const struct attribute_group___416 **groups;
	const struct dev_pm_ops___419 *pm;
	void (*coredump)(struct device___419 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___419 {
	const char *name;
	const struct attribute_group___416 **groups;
	int (*uevent)(struct device___419 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___419 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___419 *);
	const struct dev_pm_ops___419 *pm;
};

struct class___419 {
	const char *name;
	struct module___377 *owner;
	const struct attribute_group___416 **class_groups;
	const struct attribute_group___416 **dev_groups;
	struct kobject___439 *dev_kobj;
	int (*dev_uevent)(struct device___419 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___419 *, umode_t *);
	void (*class_release)(struct class___419 *);
	void (*dev_release)(struct device___419 *);
	int (*shutdown_pre)(struct device___419 *);
	const struct kobj_ns_type_operations___76 *ns_type;
	const void * (*namespace)(struct device___419 *);
	const struct dev_pm_ops___419 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___191 {
	void * (*alloc)(struct device___419 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___419 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___419 *, struct vm_area_struct___452 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___419 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___419 *, struct page___452 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___419 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___419 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___419 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___419 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___419 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___419 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___419 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___419 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___419 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___419 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___419 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___419 *, u64);
	u64 (*get_required_mask)(struct device___419 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___339;

struct fwnode_handle___339 {
	struct fwnode_handle___339 *secondary;
	const struct fwnode_operations___339 *ops;
};

typedef void compound_page_dtor___439(struct page___452 *);

struct fwnode_reference_args___339;

struct fwnode_endpoint___339;

struct fwnode_operations___339 {
	struct fwnode_handle___339 * (*get)(struct fwnode_handle___339 *);
	void (*put)(struct fwnode_handle___339 *);
	bool (*device_is_available)(const struct fwnode_handle___339 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___339 *, const struct device___419 *);
	bool (*property_present)(const struct fwnode_handle___339 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___339 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___339 *, const char *, const char **, size_t);
	struct fwnode_handle___339 * (*get_parent)(const struct fwnode_handle___339 *);
	struct fwnode_handle___339 * (*get_next_child_node)(const struct fwnode_handle___339 *, struct fwnode_handle___339 *);
	struct fwnode_handle___339 * (*get_named_child_node)(const struct fwnode_handle___339 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___339 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___339 *);
	struct fwnode_handle___339 * (*graph_get_next_endpoint)(const struct fwnode_handle___339 *, struct fwnode_handle___339 *);
	struct fwnode_handle___339 * (*graph_get_remote_endpoint)(const struct fwnode_handle___339 *);
	struct fwnode_handle___339 * (*graph_get_port_parent)(struct fwnode_handle___339 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___339 *, struct fwnode_endpoint___339 *);
};

struct fwnode_endpoint___339 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___339 *local_fwnode;
};

struct fwnode_reference_args___339 {
	struct fwnode_handle___339 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___132;

struct pipe_buffer___132 {
	struct page___452 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___132 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___132 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___132 *, struct pipe_buffer___132 *);
	void (*release)(struct pipe_inode_info___132 *, struct pipe_buffer___132 *);
	int (*steal)(struct pipe_inode_info___132 *, struct pipe_buffer___132 *);
	union {
		bool (*get)(struct pipe_inode_info___132 *, struct pipe_buffer___132 *);
		struct {
			void (*get)(struct pipe_inode_info___132 *, struct pipe_buffer___132 *);
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
};

struct nf_bridge_info___96 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___96 = 0,
		BRNF_PROTO_8021Q___96 = 1,
		BRNF_PROTO_PPPOE___96 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___96 *physindev;
	struct net_device___96 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___96(struct sk_buff___97 **);

struct net_device_ops___96;

struct ethtool_ops___96;

struct l3mdev_ops___76;

struct ndisc_ops___47;

struct xfrmdev_ops___96;

struct tlsdev_ops___96;

struct header_ops___96;

struct in_device___12;

struct inet6_dev___47;

struct netdev_rx_queue___96;

struct mini_Qdisc___88;

struct netdev_queue___96;

struct Qdisc___88;

struct rtnl_link_ops___88;

struct dcbnl_rtnl_ops___96;

struct net_device___96 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___96 *netdev_ops;
	const struct ethtool_ops___96 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___76 *l3mdev_ops;
	const struct ndisc_ops___47 *ndisc_ops;
	const struct xfrmdev_ops___96 *xfrmdev_ops;
	const struct tlsdev_ops___96 *tlsdev_ops;
	const struct header_ops___96 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___438 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device___12 *ip_ptr;
	struct inet6_dev___47 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___96 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___86 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___96 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___88 *miniq_ingress;
	struct netdev_queue___96 *ingress_queue;
	struct nf_hook_entries___14 *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___96 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___88 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___88 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___96 = 0,
		NETREG_REGISTERED___96 = 1,
		NETREG_UNREGISTERING___96 = 2,
		NETREG_UNREGISTERED___96 = 3,
		NETREG_RELEASED___96 = 4,
		NETREG_DUMMY___96 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___96 = 0,
		RTNL_LINK_INITIALIZING___96 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___96 *);
	struct netpoll_info *npinfo;
	possible_net_t___98 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___419 dev;
	const struct attribute_group___416 *sysfs_groups[4];
	const struct attribute_group___416 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___88 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___96 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct skb_frag_struct___25 {
	struct {
		struct page___452 *p;
	} page;
	__u32 page_offset;
	__u32 size;
};

typedef struct skb_frag_struct___25 skb_frag_t___25;

struct skb_shared_info___25 {
	__u8 __unused;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___97 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___25 frags[16];
};

struct xfrm_state___17;

struct sec_path___17 {
	refcount_t refcnt;
	int len;
	int olen;
	struct xfrm_state___17 *xvec[6];
	struct xfrm_offload ovec[1];
};

struct ethtool_ops___96 {
	int (*get_settings)(struct net_device___96 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___96 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___96 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___96 *);
	void (*get_regs)(struct net_device___96 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___96 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___96 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___96 *);
	void (*set_msglevel)(struct net_device___96 *, u32);
	int (*nway_reset)(struct net_device___96 *);
	u32 (*get_link)(struct net_device___96 *);
	int (*get_eeprom_len)(struct net_device___96 *);
	int (*get_eeprom)(struct net_device___96 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___96 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___96 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___96 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___96 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___96 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___96 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___96 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___96 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___96 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___96 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___96 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___96 *);
	void (*complete)(struct net_device___96 *);
	u32 (*get_priv_flags)(struct net_device___96 *);
	int (*set_priv_flags)(struct net_device___96 *, u32);
	int (*get_sset_count)(struct net_device___96 *, int);
	int (*get_rxnfc)(struct net_device___96 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___96 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___96 *, struct ethtool_flash *);
	int (*reset)(struct net_device___96 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___96 *);
	u32 (*get_rxfh_indir_size)(struct net_device___96 *);
	int (*get_rxfh)(struct net_device___96 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___96 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___96 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___96 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___96 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___96 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___96 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___96 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___96 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___96 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___96 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___96 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___96 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___96 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___96 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___96 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___96 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___96 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___96 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___96 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___96 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___96 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	int (*get_fecparam)(struct net_device___96 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___96 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___96 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___96 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___96 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___96;

struct inet_frags___96 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___96 *, const void *);
	void (*destructor)(struct inet_frag_queue___96 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___96 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___97 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___97 *fragments_tail;
	struct sk_buff___97 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___96 *net;
	struct callback_head rcu;
};

struct ip_ra_chain___42 {
	struct ip_ra_chain___42 *next;
	struct sock___76 *sk;
	union {
		void (*destructor)(struct sock___76 *);
		struct sock___76 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___76;

struct fib_lookup_arg___76;

struct fib_rules_ops___76 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___76 *, struct flowi *, int, struct fib_lookup_arg___76 *);
	bool (*suppress)(struct fib_rule___76 *, struct fib_lookup_arg___76 *);
	int (*match)(struct fib_rule___76 *, struct flowi *, int);
	int (*configure)(struct fib_rule___76 *, struct sk_buff___97 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___76 *);
	int (*compare)(struct fib_rule___76 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___76 *, struct sk_buff___97 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___76 *);
	void (*flush_cache)(struct fib_rules_ops___76 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___377 *owner;
	struct net___107 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___77 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___107 *);
	int (*fib_dump)(struct net___107 *, struct notifier_block *);
	struct module___377 *owner;
	struct callback_head rcu;
};

struct lwtunnel_state___10;

struct dst_entry___76 {
	struct net_device___96 *dev;
	struct dst_ops___107 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state___17 *xfrm;
	int (*input)(struct sk_buff___97 *);
	int (*output)(struct net___107 *, struct sock___76 *, struct sk_buff___97 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___10 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___76;

struct neigh_parms___76;

struct neigh_ops___76;

struct neighbour___76 {
	struct neighbour___76 *next;
	struct neigh_table___76 *tbl;
	struct neigh_parms___76 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___96 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___76 *, struct sk_buff___97 *);
	const struct neigh_ops___76 *ops;
	struct callback_head rcu;
	struct net_device___96 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct fib6_nh___21 {
	struct in6_addr nh_gw;
	struct net_device___96 *nh_dev;
	struct lwtunnel_state___10 *nh_lwtstate;
	unsigned int nh_flags;
	atomic_t nh_upper_bound;
	int nh_weight;
};

struct fib6_node___21;

struct fib6_info___21 {
	struct fib6_table___21 *fib6_table;
	struct fib6_info___21 *fib6_next;
	struct fib6_node___21 *fib6_node;
	struct list_head fib6_siblings;
	unsigned int fib6_nsiblings;
	atomic_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	struct rt6_info___21 **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
	long unsigned int last_probe;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 exception_bucket_flushed: 1;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 dst_host: 1;
	u8 fib6_destroying: 1;
	u8 unused: 2;
	struct fib6_nh___21 fib6_nh;
	struct callback_head rcu;
};

struct rt6_info___21 {
	struct dst_entry___76 dst;
	struct fib6_info___21 *from;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___47 *rt6i_idev;
	u32 rt6i_flags;
	struct rt6key rt6i_prefsrc;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct fib6_node___21 {
	struct fib6_node___21 *parent;
	struct fib6_node___21 *left;
	struct fib6_node___21 *right;
	struct fib6_info___21 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info___21 *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table___21 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node___21 tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

struct nf_hook_state___14;

typedef unsigned int nf_hookfn___14(void *, struct sk_buff___97 *, const struct nf_hook_state___14 *);

struct nf_hook_entry___14 {
	nf_hookfn___14 *hook;
	void *priv;
};

struct nf_hook_entries___14 {
	u16 num_hook_entries;
	struct nf_hook_entry___14 hooks[0];
};

struct ucounts___316 {
	struct hlist_node node;
	struct user_namespace___316 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_prog_aux___89;

struct bpf_prog___86 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___89 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

typedef int (*key_restrict_link_func_t___420)(struct key___419 *, const struct key_type *, const union key_payload *, struct key___419 *);

struct key_restriction___419;

struct key___419 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___453 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___419 *restrict_link;
};

struct key_restriction___419 {
	key_restrict_link_func_t___420 check;
	struct key___419 *key;
	struct key_type *keytype;
};

struct seq_operations___390 {
	void * (*start)(struct seq_file___390 *, loff_t *);
	void (*stop)(struct seq_file___390 *, void *);
	void * (*next)(struct seq_file___390 *, void *, loff_t *);
	int (*show)(struct seq_file___390 *, void *);
};

struct pernet_operations___97 {
	struct list_head list;
	int (*init)(struct net___107 *);
	void (*exit)(struct net___107 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___96 {
	int (*ieee_getets)(struct net_device___96 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___96 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___96 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___96 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___96 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___96 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___96 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___96 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___96 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___96 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___96 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___96 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___96 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___96 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___96 *);
	u8 (*setstate)(struct net_device___96 *, u8);
	void (*getpermhwaddr)(struct net_device___96 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___96 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___96 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___96 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___96 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___96 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___96 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___96 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___96 *, int, u8 *);
	void (*setpfccfg)(struct net_device___96 *, int, u8);
	void (*getpfccfg)(struct net_device___96 *, int, u8 *);
	u8 (*setall)(struct net_device___96 *);
	u8 (*getcap)(struct net_device___96 *, int, u8 *);
	int (*getnumtcs)(struct net_device___96 *, int, u8 *);
	int (*setnumtcs)(struct net_device___96 *, int, u8);
	u8 (*getpfcstate)(struct net_device___96 *);
	void (*setpfcstate)(struct net_device___96 *, u8);
	void (*getbcncfg)(struct net_device___96 *, int, u32 *);
	void (*setbcncfg)(struct net_device___96 *, int, u32);
	void (*getbcnrp)(struct net_device___96 *, int, u8 *);
	void (*setbcnrp)(struct net_device___96 *, int, u8);
	int (*setapp)(struct net_device___96 *, u8, u16, u8);
	int (*getapp)(struct net_device___96 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___96 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___96 *, int, u8);
	u8 (*getdcbx)(struct net_device___96 *);
	u8 (*setdcbx)(struct net_device___96 *, u8);
	int (*peer_getappinfo)(struct net_device___96 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___96 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___96 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___96 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___96 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___96 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___300 {
	refcount_t count;
	struct ns_common___29 ns;
	struct user_namespace___316 *user_ns;
	struct ucounts___316 *ucounts;
	struct css_set___300 *root_cset;
};

struct bpf_map___301;

struct bpf_map_ops___300 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___301 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___301 *, struct file___451 *);
	void (*map_free)(struct bpf_map___301 *);
	int (*map_get_next_key)(struct bpf_map___301 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___301 *);
	void * (*map_lookup_elem)(struct bpf_map___301 *, void *);
	int (*map_update_elem)(struct bpf_map___301 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___301 *, void *);
	int (*map_push_elem)(struct bpf_map___301 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___301 *, void *);
	int (*map_peek_elem)(struct bpf_map___301 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___301 *, struct file___451 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___301 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___301 *, void *, struct seq_file___390 *);
	int (*map_check_btf)(const struct bpf_map___301 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___301 {
	const struct bpf_map_ops___300 *ops;
	struct bpf_map___301 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___419 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___96;

struct bpf_map_dev_ops___96 {
	int (*map_get_next_key)(struct bpf_offloaded_map___96 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___96 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___96 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___96 *, void *);
};

struct bpf_offloaded_map___96 {
	struct bpf_map___301 map;
	struct net_device___96 *netdev;
	const struct bpf_map_dev_ops___96 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___86 {
	int (*test_run)(struct bpf_prog___86 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___86 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___86 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___86 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___86 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___86 *, u32 *);
};

struct bpf_prog_offload_ops___86 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___86 *);
	int (*translate)(struct bpf_prog___86 *);
	void (*destroy)(struct bpf_prog___86 *);
};

struct bpf_prog_offload___86 {
	struct bpf_prog___86 *prog;
	struct net_device___96 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___86 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___89 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___86 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___86 *ops;
	struct bpf_map___301 **used_maps;
	struct bpf_prog___86 *prog;
	struct user_struct___419 *user;
	u64 load_time;
	struct bpf_map___301 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___86 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___86 {
	struct bpf_prog___86 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___86 {
	struct callback_head rcu;
	struct bpf_prog_array_item___86 items[0];
};

struct cgroup_bpf___86 {
	struct bpf_prog_array___86 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___86 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___301;

typedef void (*kthread_work_func_t___301)(struct kthread_work___301 *);

struct kthread_worker___301;

struct kthread_work___301 {
	struct list_head node;
	kthread_work_func_t___301 func;
	struct kthread_worker___301 *worker;
	int canceling;
};

struct kthread_worker___301 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___453 *task;
	struct kthread_work___301 *current_work;
};

struct kthread_delayed_work___300 {
	struct kthread_work___301 work;
	struct timer_list timer;
};

struct psi_group___300 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___301 *poll_kworker;
	struct kthread_delayed_work___300 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___300;

struct cgroup_rstat_cpu___300;

struct cgroup___300 {
	struct cgroup_subsys_state___300 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___446 *kn;
	struct cgroup_file___300 procs_file;
	struct cgroup_file___300 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___300 *subsys[13];
	struct cgroup_root___300 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___300 *dom_cgrp;
	struct cgroup_rstat_cpu___300 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___86 bpf;
	atomic_t congestion_count;
	struct cgroup___300 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___300 psi;
	int ancestor_ids[0];
};

struct cftype___300;

struct cgroup_subsys___300 {
	struct cgroup_subsys_state___300 * (*css_alloc)(struct cgroup_subsys_state___300 *);
	int (*css_online)(struct cgroup_subsys_state___300 *);
	void (*css_offline)(struct cgroup_subsys_state___300 *);
	void (*css_released)(struct cgroup_subsys_state___300 *);
	void (*css_free)(struct cgroup_subsys_state___300 *);
	void (*css_reset)(struct cgroup_subsys_state___300 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___300 *, int);
	int (*css_extra_stat_show)(struct seq_file___390 *, struct cgroup_subsys_state___300 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___453 *);
	void (*cancel_fork)(struct task_struct___453 *);
	void (*fork)(struct task_struct___453 *);
	void (*exit)(struct task_struct___453 *);
	void (*free)(struct task_struct___453 *);
	void (*bind)(struct cgroup_subsys_state___300 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___300 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___300 *dfl_cftypes;
	struct cftype___300 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___300 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___300 *updated_children;
	struct cgroup___300 *updated_next;
};

struct cgroup_root___300 {
	struct kernfs_root___445 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___300 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___300 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___300 *ss;
	struct list_head node;
	struct kernfs_ops___445 *kf_ops;
	int (*open)(struct kernfs_open_file___445 *);
	void (*release)(struct kernfs_open_file___445 *);
	u64 (*read_u64)(struct cgroup_subsys_state___300 *, struct cftype___300 *);
	s64 (*read_s64)(struct cgroup_subsys_state___300 *, struct cftype___300 *);
	int (*seq_show)(struct seq_file___390 *, void *);
	void * (*seq_start)(struct seq_file___390 *, loff_t *);
	void * (*seq_next)(struct seq_file___390 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___390 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___300 *, struct cftype___300 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___300 *, struct cftype___300 *, s64);
	ssize_t (*write)(struct kernfs_open_file___445 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___445 *, struct poll_table_struct___290 *);
};

struct xdp_rxq_info___96 {
	struct net_device___96 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___96 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___96 *dev_rx;
};

struct netlink_callback___98 {
	struct sk_buff___97 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___98 *);
	int (*dump)(struct sk_buff___97 *, struct netlink_callback___98 *);
	int (*done)(struct netlink_callback___98 *);
	void *data;
	struct module___377 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___96 {
	int (*create)(struct sk_buff___97 *, struct net_device___96 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___97 *, unsigned char *);
	int (*cache)(const struct neighbour___76 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___96 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___96 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___96 *, int);
	int poll_owner;
	struct net_device___96 *dev;
	struct sk_buff___97 *gro_list;
	struct sk_buff___97 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___96 {
	struct net_device___96 *dev;
	struct Qdisc___88 *qdisc;
	struct Qdisc___88 *qdisc_sleeping;
	struct kobject___439 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___96 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___88 {
	struct sk_buff___97 *head;
	struct sk_buff___97 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___88;

struct Qdisc___88 {
	int (*enqueue)(struct sk_buff___97 *, struct Qdisc___88 *, struct sk_buff___97 **);
	struct sk_buff___97 * (*dequeue)(struct Qdisc___88 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___88 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___96 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___96 gso_skb;
	struct qdisc_skb_head___88 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___88 *next_sched;
	struct sk_buff_head___96 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___96 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___439 kobj;
	struct net_device___96 *dev;
	long: 64;
	struct xdp_rxq_info___96 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___96)(struct net_device___96 *, struct sk_buff___97 *, struct net_device___96 *);

struct netdev_bpf___96 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___86 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___86 *prog;
			const struct bpf_prog_offload_ops___86 *ops;
		} verifier;
		struct {
			struct bpf_prog___86 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___96 *offmap;
		};
		struct {
			struct xdp_umem___3 *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___96 {
	int (*xdo_dev_state_add)(struct xfrm_state___17 *);
	void (*xdo_dev_state_delete)(struct xfrm_state___17 *);
	void (*xdo_dev_state_free)(struct xfrm_state___17 *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___97 *, struct xfrm_state___17 *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state___17 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct xfrm_state_offload___17 {
	struct net_device___96 *dev;
	long unsigned int offload_handle;
	unsigned int num_exthdrs;
	u8 flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct xfrm_replay___17;

struct xfrm_type___17;

struct xfrm_mode___17;

struct xfrm_type_offload___17;

struct xfrm_state___17 {
	possible_net_t___98 xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	refcount_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
		u32 output_mark;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	const char *geniv;
	struct xfrm_encap_tmpl *encap;
	xfrm_address_t *coaddr;
	struct xfrm_state___17 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	const struct xfrm_replay___17 *repl;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct tasklet_hrtimer mtimer;
	struct xfrm_state_offload___17 xso;
	long int saved_tmo;
	long unsigned int lastused;
	struct page_frag___452 xfrag;
	const struct xfrm_type___17 *type;
	struct xfrm_mode___17 *inner_mode;
	struct xfrm_mode___17 *inner_mode_iaf;
	struct xfrm_mode___17 *outer_mode;
	const struct xfrm_type_offload___17 *type_offload;
	struct xfrm_sec_ctx___2 *security;
	void *data;
	u32 output_mark_mask;
	u32 if_id;
};

struct tlsdev_ops___96 {
	int (*tls_dev_add)(struct net_device___96 *, struct sock___76 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___96 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___96 *, struct sock___76 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___96 {
	int (*ndo_init)(struct net_device___96 *);
	void (*ndo_uninit)(struct net_device___96 *);
	int (*ndo_open)(struct net_device___96 *);
	int (*ndo_stop)(struct net_device___96 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___97 *, struct net_device___96 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___97 *, struct net_device___96 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___96 *, struct sk_buff___97 *, struct net_device___96 *, select_queue_fallback_t___96);
	void (*ndo_change_rx_flags)(struct net_device___96 *, int);
	void (*ndo_set_rx_mode)(struct net_device___96 *);
	int (*ndo_set_mac_address)(struct net_device___96 *, void *);
	int (*ndo_validate_addr)(struct net_device___96 *);
	int (*ndo_do_ioctl)(struct net_device___96 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___96 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___96 *, int);
	int (*ndo_neigh_setup)(struct net_device___96 *, struct neigh_parms___76 *);
	void (*ndo_tx_timeout)(struct net_device___96 *);
	void (*ndo_get_stats64)(struct net_device___96 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___96 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___96 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___96 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___96 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___96 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___96 *);
	int (*ndo_netpoll_setup)(struct net_device___96 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___96 *);
	int (*ndo_set_vf_mac)(struct net_device___96 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___96 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___96 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___96 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___96 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___96 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___96 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___96 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___96 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___96 *, int, struct sk_buff___97 *);
	int (*ndo_set_vf_guid)(struct net_device___96 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___96 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___96 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___96 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___96 *, const struct sk_buff___97 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___96 *, struct net_device___96 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___96 *, struct net_device___96 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___96 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___96 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___96 *, struct neighbour___76 *);
	void (*ndo_neigh_destroy)(struct net_device___96 *, struct neighbour___76 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___96 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___96 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___96 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___97 *, struct netlink_callback___98 *, struct net_device___96 *, struct net_device___96 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___96 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___96 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___97 *, u32, u32, struct net_device___96 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___96 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___96 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___96 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___96 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___96 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___96 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___96 *, struct net_device___96 *);
	void (*ndo_dfwd_del_station)(struct net_device___96 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___96 *);
	int (*ndo_set_tx_maxrate)(struct net_device___96 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___96 *);
	int (*ndo_change_proto_down)(struct net_device___96 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___96 *, struct sk_buff___97 *);
	void (*ndo_set_rx_headroom)(struct net_device___96 *, int);
	int (*ndo_bpf)(struct net_device___96 *, struct netdev_bpf___96 *);
	int (*ndo_xdp_xmit)(struct net_device___96 *, int, struct xdp_frame___96 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___96 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___96 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___76 {
	possible_net_t___98 net;
	struct net_device___96 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___76 *);
	void (*neigh_cleanup)(struct neighbour___76 *);
	struct neigh_table___76 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___76 {
	u32 (*l3mdev_fib_table)(const struct net_device___96 *);
	struct sk_buff___97 * (*l3mdev_l3_rcv)(struct net_device___96 *, struct sk_buff___97 *, u16);
	struct sk_buff___97 * (*l3mdev_l3_out)(struct net_device___96 *, struct sock___76 *, struct sk_buff___97 *, u16);
	struct dst_entry___76 * (*l3mdev_link_scope_lookup)(const struct net_device___96 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct ndisc_ops___47 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___96 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___96 *, struct neighbour___76 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___96 *, u8, struct neighbour___76 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___96 *, struct sk_buff___97 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___107 *, struct net_device___96 *, const struct prefix_info *, struct inet6_dev___47 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct in_ifaddr___12;

struct in_device___12 {
	struct net_device___96 *dev;
	refcount_t refcnt;
	int dead;
	struct in_ifaddr___12 *ifa_list;
	struct ip_mc_list *mc_list;
	struct ip_mc_list **mc_hash;
	int mc_count;
	spinlock_t mc_tomb_lock;
	struct ip_mc_list *mc_tomb;
	long unsigned int mr_v1_seen;
	long unsigned int mr_v2_seen;
	long unsigned int mr_maxdelay;
	long unsigned int mr_qi;
	long unsigned int mr_qri;
	unsigned char mr_qrv;
	unsigned char mr_gq_running;
	unsigned char mr_ifc_count;
	struct timer_list mr_gq_timer;
	struct timer_list mr_ifc_timer;
	struct neigh_parms___76 *arp_parms;
	struct ipv4_devconf cnf;
	struct callback_head callback_head;
};

struct ifmcaddr6___47;

struct ifacaddr6___21;

struct inet6_dev___47 {
	struct net_device___96 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___47 *mc_list;
	struct ifmcaddr6___47 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___21 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	u8 rndid[8];
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___76 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
};

struct tcf_proto___88;

struct mini_Qdisc___88 {
	struct tcf_proto___88 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___88 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___96 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___107 *, struct net_device___96 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___96 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___96 *, struct list_head *);
	size_t (*get_size)(const struct net_device___96 *);
	int (*fill_info)(struct sk_buff___97 *, const struct net_device___96 *);
	size_t (*get_xstats_size)(const struct net_device___96 *);
	int (*fill_xstats)(struct sk_buff___97 *, const struct net_device___96 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___96 *, struct net_device___96 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___96 *, const struct net_device___96 *);
	int (*fill_slave_info)(struct sk_buff___97 *, const struct net_device___96 *, const struct net_device___96 *);
	struct net___107 * (*get_link_net)(const struct net_device___96 *);
	size_t (*get_linkxstats_size)(const struct net_device___96 *, int);
	int (*fill_linkxstats)(struct sk_buff___97 *, const struct net_device___96 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct offload_callbacks___14 {
	struct sk_buff___97 * (*gso_segment)(struct sk_buff___97 *, netdev_features_t);
	struct sk_buff___97 ** (*gro_receive)(struct sk_buff___97 **, struct sk_buff___97 *);
	int (*gro_complete)(struct sk_buff___97 *, int);
};

struct softnet_data___96 {
	struct list_head poll_list;
	struct sk_buff_head___96 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___96 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___88 *output_queue;
	struct Qdisc___88 **output_queue_tailp;
	struct sk_buff___97 *completion_queue;
	struct sk_buff_head___96 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___96 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___96 input_pkt_queue;
	struct napi_struct___96 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct in_ifaddr___12 {
	struct hlist_node hash;
	struct in_ifaddr___12 *ifa_next;
	struct in_device___12 *ifa_dev;
	struct callback_head callback_head;
	__be32 ifa_local;
	__be32 ifa_address;
	__be32 ifa_mask;
	__u32 ifa_rt_priority;
	__be32 ifa_broadcast;
	unsigned char ifa_scope;
	unsigned char ifa_prefixlen;
	__u32 ifa_flags;
	char ifa_label[16];
	__u32 ifa_valid_lft;
	__u32 ifa_preferred_lft;
	long unsigned int ifa_cstamp;
	long unsigned int ifa_tstamp;
};

struct nf_hook_state___14 {
	unsigned int hook;
	u_int8_t pf;
	struct net_device___96 *in;
	struct net_device___96 *out;
	struct sock___76 *sk;
	struct net___107 *net;
	int (*okfn)(struct net___107 *, struct sock___76 *, struct sk_buff___97 *);
};

struct nf_nat_hook___14 {
	int (*parse_nat_setup)(struct nf_conn *, enum nf_nat_manip_type, const struct nlattr *);
	void (*decode_session)(struct sk_buff___97 *, struct flowi *);
	unsigned int (*manip_pkt)(struct sk_buff___97 *, struct nf_conn *, enum nf_nat_manip_type, enum ip_conntrack_dir);
};

struct nf_ct_hook___14 {
	int (*update)(struct net___107 *, struct sk_buff___97 *);
	void (*destroy)(struct nf_conntrack *);
	bool (*get_tuple_skb)(struct nf_conntrack_tuple *, const struct sk_buff___97 *);
};

struct nfnl_ct_hook___14 {
	struct nf_conn * (*get_ct)(const struct sk_buff___97 *, enum ip_conntrack_info *);
	size_t (*build_size)(const struct nf_conn *);
	int (*build)(struct sk_buff___97 *, struct nf_conn *, enum ip_conntrack_info, u_int16_t, u_int16_t);
	int (*parse)(const struct nlattr *, struct nf_conn *);
	int (*attach_expect)(const struct nlattr *, struct nf_conn *, u32, u32);
	void (*seq_adjust)(struct sk_buff___97 *, struct nf_conn *, enum ip_conntrack_info, s32);
};

struct bdi_writeback_congested___241 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___241 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___241 {
	struct bio___241 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___243 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___243 bip_inline_vecs[0];
};

struct bio_set___241 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___241 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___184 {
	struct mem_cgroup___184 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___184 {
	struct lruvec___452 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___184 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___184 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct kernel_param_ops___377 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___377 *);
	int (*get)(char *, const struct kernel_param___377 *);
	void (*free)(void *);
};

struct kparam_array___377;

struct kernel_param___377 {
	const char *name;
	struct module___377 *mod;
	const struct kernel_param_ops___377 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___377 *arr;
	};
};

struct kparam_array___377 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___377 *ops;
	void *elem;
};

struct module_attribute___377 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___377 *, struct module_kobject___377 *, char *);
	ssize_t (*store)(struct module_attribute___377 *, struct module_kobject___377 *, const char *, size_t);
	void (*setup)(struct module___377 *, const char *);
	int (*test)(struct module___377 *);
	void (*free)(struct module___377 *);
};

struct gnet_dump___88 {
	spinlock_t *lock;
	struct sk_buff___97 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___88;

struct Qdisc_ops___88 {
	struct Qdisc_ops___88 *next;
	const struct Qdisc_class_ops___88 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___97 *, struct Qdisc___88 *, struct sk_buff___97 **);
	struct sk_buff___97 * (*dequeue)(struct Qdisc___88 *);
	struct sk_buff___97 * (*peek)(struct Qdisc___88 *);
	int (*init)(struct Qdisc___88 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___88 *);
	void (*destroy)(struct Qdisc___88 *);
	int (*change)(struct Qdisc___88 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___88 *);
	int (*change_tx_queue_len)(struct Qdisc___88 *, unsigned int);
	int (*dump)(struct Qdisc___88 *, struct sk_buff___97 *);
	int (*dump_stats)(struct Qdisc___88 *, struct gnet_dump___88 *);
	void (*ingress_block_set)(struct Qdisc___88 *, u32);
	void (*egress_block_set)(struct Qdisc___88 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___88 *);
	u32 (*egress_block_get)(struct Qdisc___88 *);
	struct module___377 *owner;
};

struct tcf_block___88;

struct Qdisc_class_ops___88 {
	unsigned int flags;
	struct netdev_queue___96 * (*select_queue)(struct Qdisc___88 *, struct tcmsg *);
	int (*graft)(struct Qdisc___88 *, long unsigned int, struct Qdisc___88 *, struct Qdisc___88 **, struct netlink_ext_ack *);
	struct Qdisc___88 * (*leaf)(struct Qdisc___88 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___88 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___88 *, u32);
	int (*change)(struct Qdisc___88 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___88 *, long unsigned int);
	void (*walk)(struct Qdisc___88 *, struct qdisc_walker *);
	struct tcf_block___88 * (*tcf_block)(struct Qdisc___88 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___88 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___88 *, long unsigned int);
	int (*dump)(struct Qdisc___88 *, long unsigned int, struct sk_buff___97 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___88 *, long unsigned int, struct gnet_dump___88 *);
};

struct tcf_chain___88;

struct tcf_block___88 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___107 *net;
	struct Qdisc___88 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___88 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___88;

struct tcf_proto_ops___88;

struct tcf_proto___88 {
	struct tcf_proto___88 *next;
	void *root;
	int (*classify)(struct sk_buff___97 *, const struct tcf_proto___88 *, struct tcf_result___88 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___88 *ops;
	struct tcf_chain___88 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___88 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___88 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___88 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___97 *, const struct tcf_proto___88 *, struct tcf_result___88 *);
	int (*init)(struct tcf_proto___88 *);
	void (*destroy)(struct tcf_proto___88 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___88 *, u32);
	void (*put)(struct tcf_proto___88 *, void *);
	int (*change)(struct net___107 *, struct sk_buff___97 *, struct tcf_proto___88 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___88 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___88 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___88 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___107 *, struct tcf_chain___88 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___107 *, struct tcf_proto___88 *, void *, struct sk_buff___97 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___97 *, struct net___107 *, void *);
	struct module___377 *owner;
	int flags;
};

struct tcf_chain___88 {
	struct mutex filter_chain_lock;
	struct tcf_proto___88 *filter_chain;
	struct list_head list;
	struct tcf_block___88 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___88 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___76 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___86 *prog;
};

struct bpf_redirect_info___86 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___301 *map;
	struct bpf_map___301 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___76;

struct neigh_hash_table___76;

struct neigh_table___76 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___96 *, __u32 *);
	bool (*key_eq)(const struct neighbour___76 *, const void *);
	int (*constructor)(struct neighbour___76 *);
	int (*pconstructor)(struct pneigh_entry___76 *);
	void (*pdestructor)(struct pneigh_entry___76 *);
	void (*proxy_redo)(struct sk_buff___97 *);
	char *id;
	struct neigh_parms___76 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___96 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___76 *nht;
	struct pneigh_entry___76 **phash_buckets;
};

struct neigh_ops___76 {
	int family;
	void (*solicit)(struct neighbour___76 *, struct sk_buff___97 *);
	void (*error_report)(struct neighbour___76 *, struct sk_buff___97 *);
	int (*output)(struct neighbour___76 *, struct sk_buff___97 *);
	int (*connected_output)(struct neighbour___76 *, struct sk_buff___97 *);
};

struct pneigh_entry___76 {
	struct pneigh_entry___76 *next;
	possible_net_t___98 net;
	struct net_device___96 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___76 {
	struct neighbour___76 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___10 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___107 *, struct sock___76 *, struct sk_buff___97 *);
	int (*orig_input)(struct sk_buff___97 *);
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	__u8 data[0];
};

struct fib_rule___76 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___76 *ctarget;
	struct net___107 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___76 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___76 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___59;

struct timewait_sock_ops___55;

struct proto___76 {
	void (*close)(struct sock___76 *, long int);
	int (*pre_connect)(struct sock___76 *, struct sockaddr *, int);
	int (*connect)(struct sock___76 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___76 *, int);
	struct sock___76 * (*accept)(struct sock___76 *, int, int *, bool);
	int (*ioctl)(struct sock___76 *, int, long unsigned int);
	int (*init)(struct sock___76 *);
	void (*destroy)(struct sock___76 *);
	void (*shutdown)(struct sock___76 *, int);
	int (*setsockopt)(struct sock___76 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___76 *, int, int, char *, int *);
	void (*keepalive)(struct sock___76 *, int);
	int (*sendmsg)(struct sock___76 *, struct msghdr___79 *, size_t);
	int (*recvmsg)(struct sock___76 *, struct msghdr___79 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___76 *, struct page___452 *, int, size_t, int);
	int (*bind)(struct sock___76 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___76 *, struct sk_buff___97 *);
	void (*release_cb)(struct sock___76 *);
	int (*hash)(struct sock___76 *);
	void (*unhash)(struct sock___76 *);
	void (*rehash)(struct sock___76 *);
	int (*get_port)(struct sock___76 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___76 *);
	bool (*stream_memory_read)(const struct sock___76 *);
	void (*enter_memory_pressure)(struct sock___76 *);
	void (*leave_memory_pressure)(struct sock___76 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___59 *rsk_prot;
	struct timewait_sock_ops___55 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___377 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___76 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct xfrm_policy_queue___17 {
	struct sk_buff_head___96 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___17 {
	possible_net_t___98 xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	refcount_t refcnt;
	struct timer_list timer;
	atomic_t genid;
	u32 priority;
	u32 index;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___17 polq;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx___2 *security;
	struct xfrm_tmpl xfrm_vec[6];
	struct callback_head rcu;
	u32 if_id;
};

struct request_sock___60;

struct request_sock_ops___59 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___76 *, struct request_sock___60 *);
	void (*send_ack)(const struct sock___76 *, struct sk_buff___97 *, struct request_sock___60 *);
	void (*send_reset)(const struct sock___76 *, struct sk_buff___97 *);
	void (*destructor)(struct request_sock___60 *);
	void (*syn_ack_timeout)(const struct request_sock___60 *);
};

struct timewait_sock_ops___55 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___76 *, struct sock___76 *, void *);
	void (*twsk_destructor)(struct sock___76 *);
};

struct request_sock___60 {
	struct sock_common___76 __req_common;
	struct request_sock___60 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___59 *rsk_ops;
	struct sock___76 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___47 {
	struct in6_addr mca_addr;
	struct inet6_dev___47 *idev;
	struct ifmcaddr6___47 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___21 {
	struct in6_addr aca_addr;
	struct fib6_info___21 *aca_rt;
	struct ifacaddr6___21 *aca_next;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct ip6_ra_chain___47 {
	struct ip6_ra_chain___47 *next;
	struct sock___76 *sk;
	int sel;
	void (*destructor)(struct sock___76 *);
};

struct rtable___14 {
	struct dst_entry___76 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	__be32 rt_gateway;
	u32 rt_mtu_locked: 1;
	u32 rt_pmtu: 31;
	struct list_head rt_uncached;
	struct uncached_list *rt_uncached_list;
};

struct net_protocol___12 {
	int (*early_demux)(struct sk_buff___97 *);
	int (*early_demux_handler)(struct sk_buff___97 *);
	int (*handler)(struct sk_buff___97 *);
	void (*err_handler)(struct sk_buff___97 *, u32);
	unsigned int no_policy: 1;
	unsigned int netns_ok: 1;
	unsigned int icmp_strict_tag_validation: 1;
};

struct inet6_protocol___12 {
	void (*early_demux)(struct sk_buff___97 *);
	void (*early_demux_handler)(struct sk_buff___97 *);
	int (*handler)(struct sk_buff___97 *);
	void (*err_handler)(struct sk_buff___97 *, struct inet6_skb_parm *, u8, u8, int, __be32);
	unsigned int flags;
};

struct net_offload___12 {
	struct offload_callbacks___14 callbacks;
	unsigned int flags;
};

enum lwtunnel_ip_t {
	LWTUNNEL_IP_UNSPEC = 0,
	LWTUNNEL_IP_ID = 1,
	LWTUNNEL_IP_DST = 2,
	LWTUNNEL_IP_SRC = 3,
	LWTUNNEL_IP_TTL = 4,
	LWTUNNEL_IP_TOS = 5,
	LWTUNNEL_IP_FLAGS = 6,
	LWTUNNEL_IP_PAD = 7,
	__LWTUNNEL_IP_MAX = 8,
};

enum lwtunnel_ip6_t {
	LWTUNNEL_IP6_UNSPEC = 0,
	LWTUNNEL_IP6_ID = 1,
	LWTUNNEL_IP6_DST = 2,
	LWTUNNEL_IP6_SRC = 3,
	LWTUNNEL_IP6_HOPLIMIT = 4,
	LWTUNNEL_IP6_TC = 5,
	LWTUNNEL_IP6_FLAGS = 6,
	LWTUNNEL_IP6_PAD = 7,
	__LWTUNNEL_IP6_MAX = 8,
};

struct lwtunnel_encap_ops___2 {
	int (*build_state)(struct nlattr *, unsigned int, const void *, struct lwtunnel_state___10 **, struct netlink_ext_ack *);
	void (*destroy_state)(struct lwtunnel_state___10 *);
	int (*output)(struct net___107 *, struct sock___76 *, struct sk_buff___97 *);
	int (*input)(struct sk_buff___97 *);
	int (*fill_encap)(struct sk_buff___97 *, struct lwtunnel_state___10 *);
	int (*get_encap_size)(struct lwtunnel_state___10 *);
	int (*cmp_encap)(struct lwtunnel_state___10 *, struct lwtunnel_state___10 *);
	int (*xmit)(struct sk_buff___97 *);
	struct module___377 *owner;
};

struct ipv6_stub___15 {
	int (*ipv6_sock_mc_join)(struct sock___76 *, int, const struct in6_addr *);
	int (*ipv6_sock_mc_drop)(struct sock___76 *, int, const struct in6_addr *);
	int (*ipv6_dst_lookup)(struct net___107 *, struct sock___76 *, struct dst_entry___76 **, struct flowi6 *);
	struct fib6_table___21 * (*fib6_get_table)(struct net___107 *, u32);
	struct fib6_info___21 * (*fib6_lookup)(struct net___107 *, int, struct flowi6 *, int);
	struct fib6_info___21 * (*fib6_table_lookup)(struct net___107 *, struct fib6_table___21 *, int, struct flowi6 *, int);
	struct fib6_info___21 * (*fib6_multipath_select)(const struct net___107 *, struct fib6_info___21 *, struct flowi6 *, int, const struct sk_buff___97 *, int);
	u32 (*ip6_mtu_from_fib6)(struct fib6_info___21 *, struct in6_addr *, struct in6_addr *);
	void (*udpv6_encap_enable)();
	void (*ndisc_send_na)(struct net_device___96 *, const struct in6_addr *, const struct in6_addr *, bool, bool, bool, bool);
	struct neigh_table___76 *nd_tbl;
};

struct ipv6_bpf_stub___15 {
	int (*inet6_bind)(struct sock___76 *, struct sockaddr *, int, bool, bool);
	struct sock___76 * (*udp6_lib_lookup)(struct net___107 *, const struct in6_addr *, __be16, const struct in6_addr *, __be16, int, int, struct udp_table *, struct sk_buff___97 *);
};

struct ip_tunnel_encap_ops___9 {
	size_t (*encap_hlen)(struct ip_tunnel_encap *);
	int (*build_header)(struct sk_buff___97 *, struct ip_tunnel_encap *, u8 *, struct flowi4 *);
};

struct ip6_tnl_encap_ops {
	size_t (*encap_hlen)(struct ip_tunnel_encap *);
	int (*build_header)(struct sk_buff___97 *, struct ip_tunnel_encap *, u8 *, struct flowi6 *);
};

struct xfrm_replay___17 {
	void (*advance)(struct xfrm_state___17 *, __be32);
	int (*check)(struct xfrm_state___17 *, struct sk_buff___97 *, __be32);
	int (*recheck)(struct xfrm_state___17 *, struct sk_buff___97 *, __be32);
	void (*notify)(struct xfrm_state___17 *, int);
	int (*overflow)(struct xfrm_state___17 *, struct sk_buff___97 *);
};

struct xfrm_type___17 {
	char *description;
	struct module___377 *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___17 *);
	void (*destructor)(struct xfrm_state___17 *);
	int (*input)(struct xfrm_state___17 *, struct sk_buff___97 *);
	int (*output)(struct xfrm_state___17 *, struct sk_buff___97 *);
	int (*reject)(struct xfrm_state___17 *, struct sk_buff___97 *, const struct flowi *);
	int (*hdr_offset)(struct xfrm_state___17 *, struct sk_buff___97 *, u8 **);
	u32 (*get_mtu)(struct xfrm_state___17 *, int);
};

struct xfrm_state_afinfo___17;

struct xfrm_mode___17 {
	int (*input2)(struct xfrm_state___17 *, struct sk_buff___97 *);
	int (*input)(struct xfrm_state___17 *, struct sk_buff___97 *);
	int (*output2)(struct xfrm_state___17 *, struct sk_buff___97 *);
	int (*output)(struct xfrm_state___17 *, struct sk_buff___97 *);
	struct sk_buff___97 * (*gso_segment)(struct xfrm_state___17 *, struct sk_buff___97 *, netdev_features_t);
	void (*xmit)(struct xfrm_state___17 *, struct sk_buff___97 *);
	struct xfrm_state_afinfo___17 *afinfo;
	struct module___377 *owner;
	unsigned int encap;
	int flags;
};

struct xfrm_type_offload___17 {
	char *description;
	struct module___377 *owner;
	u8 proto;
	void (*encap)(struct xfrm_state___17 *, struct sk_buff___97 *);
	int (*input_tail)(struct xfrm_state___17 *, struct sk_buff___97 *);
	int (*xmit)(struct xfrm_state___17 *, struct sk_buff___97 *, netdev_features_t);
};

struct xfrm_state_afinfo___17 {
	unsigned int family;
	unsigned int proto;
	__be16 eth_proto;
	struct module___377 *owner;
	const struct xfrm_type___17 *type_map[256];
	const struct xfrm_type_offload___17 *type_offload_map[256];
	struct xfrm_mode___17 *mode_map[5];
	int (*init_flags)(struct xfrm_state___17 *);
	void (*init_tempsel)(struct xfrm_selector *, const struct flowi *);
	void (*init_temprop)(struct xfrm_state___17 *, const struct xfrm_tmpl *, const xfrm_address_t *, const xfrm_address_t *);
	int (*tmpl_sort)(struct xfrm_tmpl **, struct xfrm_tmpl **, int);
	int (*state_sort)(struct xfrm_state___17 **, struct xfrm_state___17 **, int);
	int (*output)(struct net___107 *, struct sock___76 *, struct sk_buff___97 *);
	int (*output_finish)(struct sock___76 *, struct sk_buff___97 *);
	int (*extract_input)(struct xfrm_state___17 *, struct sk_buff___97 *);
	int (*extract_output)(struct xfrm_state___17 *, struct sk_buff___97 *);
	int (*transport_finish)(struct sk_buff___97 *, int);
	void (*local_error)(struct sk_buff___97 *, u32);
};

struct hw_port_info___7 {
	struct net_device___96 *lower_dev;
	u32 port_id;
};

struct metadata_dst___7 {
	struct dst_entry___76 dst;
	enum metadata_type type;
	union {
		struct ip_tunnel_info tun_info;
		struct hw_port_info___7 port_info;
	} u;
};

struct napi_gro_cb___6 {
	void *frag0;
	unsigned int frag0_len;
	int data_offset;
	u16 flush;
	u16 flush_id;
	u16 count;
	u16 gro_remcsum_start;
	long unsigned int age;
	u16 proto;
	u8 same_flow: 1;
	u8 encap_mark: 1;
	u8 csum_valid: 1;
	u8 csum_cnt: 3;
	u8 free: 2;
	u8 is_ipv6: 1;
	u8 is_fou: 1;
	u8 is_atomic: 1;
	u8 recursion_counter: 4;
	__wsum csum;
	struct sk_buff___97 *last;
};

typedef struct sk_buff___97 ** (*gro_receive_t___2)(struct sk_buff___97 **, struct sk_buff___97 *);

struct packet_offload___4 {
	__be16 type;
	u16 priority;
	struct offload_callbacks___14 callbacks;
	struct list_head list;
};

struct module___378;

struct file___452;

struct kiocb___452;

struct iov_iter___219;

struct poll_table_struct___291;

struct vm_area_struct___453;

struct inode___452;

struct file_lock___452;

struct page___453;

struct pipe_inode_info___133;

struct seq_file___391;

struct file_operations___452 {
	struct module___378 *owner;
	loff_t (*llseek)(struct file___452 *, loff_t, int);
	ssize_t (*read)(struct file___452 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___452 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___452 *, struct iov_iter___219 *);
	ssize_t (*write_iter)(struct kiocb___452 *, struct iov_iter___219 *);
	int (*iopoll)(struct kiocb___452 *, bool);
	int (*iterate)(struct file___452 *, struct dir_context *);
	int (*iterate_shared)(struct file___452 *, struct dir_context *);
	__poll_t (*poll)(struct file___452 *, struct poll_table_struct___291 *);
	long int (*unlocked_ioctl)(struct file___452 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___452 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___452 *, struct vm_area_struct___453 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___452 *, struct file___452 *);
	int (*flush)(struct file___452 *, fl_owner_t);
	int (*release)(struct inode___452 *, struct file___452 *);
	int (*fsync)(struct file___452 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___452 *, int);
	int (*lock)(struct file___452 *, int, struct file_lock___452 *);
	ssize_t (*sendpage)(struct file___452 *, struct page___453 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___452 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___452 *, int, struct file_lock___452 *);
	ssize_t (*splice_write)(struct pipe_inode_info___133 *, struct file___452 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___452 *, loff_t *, struct pipe_inode_info___133 *, size_t, unsigned int);
	int (*setlease)(struct file___452 *, long int, struct file_lock___452 **, void **);
	long int (*fallocate)(struct file___452 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___391 *, struct file___452 *);
	ssize_t (*copy_file_range)(struct file___452 *, loff_t, struct file___452 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___452 *, loff_t, struct file___452 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___452 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___453 {
	u64 seqnum;
	struct vm_area_struct___453 *vmas[4];
};

struct page_frag___453 {
	struct page___453 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___453;

struct mem_cgroup___185;

struct cred___420;

struct nsproxy___347;

struct signal_struct___327;

struct bio_list___242;

struct backing_dev_info___242;

struct css_set___301;

struct vm_struct___356;

struct task_struct___454 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___454 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___453 *mm;
	struct mm_struct___453 *active_mm;
	struct vmacache___453 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___454 *real_parent;
	struct task_struct___454 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___454 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___185 *active_memcg;
	long int rh_reserved2;
	struct pid___252 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___252 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___252 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___420 *ptracer_cred;
	const struct cred___420 *real_cred;
	const struct cred___420 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___347 *nsproxy;
	struct signal_struct___327 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___454 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___242 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___242 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___301 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___133 *splice_pipe;
	struct page_frag___453 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___185 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___454 *oom_reaper_list;
	struct vm_struct___356 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___156 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___453 *pgtable_t___453;

struct address_space___452;

struct dev_pagemap___440;

struct page___453 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___452 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___453 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___453 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___453 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___440 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___185 *mem_cgroup;
};

struct pglist_data___453;

struct lruvec___453 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___453 *pgdat;
};

struct zone___453 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___453 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___453 {
	struct zone___453 *zone;
	int zone_idx;
};

struct zonelist___453 {
	struct zoneref___453 _zonerefs[25];
};

struct pglist_data___453 {
	struct zone___453 node_zones[3];
	struct zonelist___453 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___454 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___454 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___453 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___454 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___454 *owner;
};

struct secondary_data___454 {
	void *stack;
	struct task_struct___454 *task;
	long int status;
};

struct blocking_notifier_head___453 {
	struct rw_semaphore___454 rwsem;
	struct notifier_block *head;
};

struct cgroup___301;

struct cgroup_subsys___301;

struct cgroup_subsys_state___301 {
	struct cgroup___301 *cgroup;
	struct cgroup_subsys___301 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___301 *parent;
};

struct kernfs_node___447;

struct cgroup_file___301 {
	struct kernfs_node___447 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___185;

struct mem_cgroup___185 {
	struct cgroup_subsys_state___301 css;
	struct mem_cgroup_id___16 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___301 events_file;
	struct cgroup_file___301 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___454 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___185 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct key___420;

struct ucounts___317;

struct user_namespace___317 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___317 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___29 ns;
	long unsigned int flags;
	struct key___420 *persistent_keyring_register;
	struct rw_semaphore___454 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___317 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct user_struct___420 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___420 *uid_keyring;
	struct key___420 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___440;

struct vm_area_struct___453 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___453 *vm_next;
	struct vm_area_struct___453 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___453 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___440 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___452 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___453;

struct mm_struct___453 {
	struct {
		struct vm_area_struct___453 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___452 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___454 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___453 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___454 *owner;
		struct user_namespace___317 *user_ns;
		struct file___452 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___453 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___420 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___420 *session_keyring;
	struct key___420 *process_keyring;
	struct key___420 *thread_keyring;
	struct key___420 *request_key_auth;
	void *security;
	struct user_struct___420 *user;
	struct user_namespace___317 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___108;

struct cgroup_namespace___301;

struct nsproxy___347 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net___108 *net_ns;
	struct cgroup_namespace___301 *cgroup_ns;
};

struct signal_struct___327 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___454 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___454 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___252 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___252 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___453 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___252 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___242;

struct bio_list___242 {
	struct bio___242 *head;
	struct bio___242 *tail;
};

struct bdi_writeback_congested___242;

struct bdi_writeback___242 {
	struct backing_dev_info___242 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___242 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___301 *memcg_css;
	struct cgroup_subsys_state___301 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___420;

struct dentry___452;

struct backing_dev_info___242 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___242 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___420 *dev;
	struct device___420 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___452 *debug_dir;
	struct dentry___452 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___301 {
	struct cgroup_subsys_state___301 *subsys[13];
	refcount_t refcount;
	struct css_set___301 *dom_cset;
	struct cgroup___301 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___301 *mg_src_cgrp;
	struct cgroup___301 *mg_dst_cgrp;
	struct css_set___301 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___452;

struct pipe_buffer___133;

struct pipe_inode_info___133 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___453 *tmp_page;
	struct fasync_struct___452 *fasync_readers;
	struct fasync_struct___452 *fasync_writers;
	struct pipe_buffer___133 *bufs;
	struct user_struct___420 *user;
};

struct vm_struct___356 {
	struct vm_struct___356 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___453 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___339 {
	struct task_struct___454 task;
	long unsigned int stack[8192];
};

struct address_space_operations___452;

struct address_space___452 {
	struct inode___452 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___454 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___452 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___440)(struct vm_area_struct___453 *, long unsigned int, const struct page___453 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___440)(struct page___453 *, void *);

struct dev_pagemap___440 {
	dev_page_fault_t___440 page_fault;
	dev_page_free_t___440 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___420 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___453 {
	struct vfsmount *mnt;
	struct dentry___452 *dentry;
};

struct file___452 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___453 f_path;
	struct inode___452 *f_inode;
	const struct file_operations___452 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___252 f_owner;
	const struct cred___420 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___452 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___440;

struct vm_operations_struct___440 {
	void (*open)(struct vm_area_struct___453 *);
	void (*close)(struct vm_area_struct___453 *);
	int (*split)(struct vm_area_struct___453 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___453 *);
	vm_fault_t (*fault)(struct vm_fault___440 *);
	vm_fault_t (*huge_fault)(struct vm_fault___440 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___440 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___453 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___440 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___440 *);
	int (*access)(struct vm_area_struct___453 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___453 *);
	int (*set_policy)(struct vm_area_struct___453 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___453 *, long unsigned int);
	struct page___453 * (*find_special_page)(struct vm_area_struct___453 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___453 {
	struct task_struct___454 *task;
	struct core_thread___453 *next;
};

struct core_state___453 {
	atomic_t nr_threads;
	struct core_thread___453 dumper;
	struct completion startup;
};

struct vm_fault___440 {
	struct vm_area_struct___453 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___453 *cow_page;
	struct mem_cgroup___185 *memcg;
	struct page___453 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___453 prealloc_pte;
};

struct crypto_async_request___38;

typedef void (*crypto_completion_t___38)(struct crypto_async_request___38 *, int);

struct crypto_tfm___38;

struct crypto_async_request___38 {
	struct list_head list;
	crypto_completion_t___38 complete;
	void *data;
	struct crypto_tfm___38 *tfm;
	u32 flags;
};

struct crypto_ablkcipher___38;

struct ablkcipher_request___38;

struct ablkcipher_tfm___38 {
	int (*setkey)(struct crypto_ablkcipher___38 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___38 *);
	int (*decrypt)(struct ablkcipher_request___38 *);
	struct crypto_ablkcipher___38 *base;
	unsigned int ivsize;
	unsigned int reqsize;
};

struct blkcipher_desc___38;

struct blkcipher_tfm___38 {
	void *iv;
	int (*setkey)(struct crypto_tfm___38 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___38 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___38 *, struct scatterlist *, struct scatterlist *, unsigned int);
};

struct cipher_tfm___38 {
	int (*cit_setkey)(struct crypto_tfm___38 *, const u8 *, unsigned int);
	void (*cit_encrypt_one)(struct crypto_tfm___38 *, u8 *, const u8 *);
	void (*cit_decrypt_one)(struct crypto_tfm___38 *, u8 *, const u8 *);
};

struct compress_tfm___38 {
	int (*cot_compress)(struct crypto_tfm___38 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*cot_decompress)(struct crypto_tfm___38 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___38;

struct crypto_tfm___38 {
	u32 crt_flags;
	union {
		struct ablkcipher_tfm___38 ablkcipher;
		struct blkcipher_tfm___38 blkcipher;
		struct cipher_tfm___38 cipher;
		struct compress_tfm___38 compress;
	} crt_u;
	void (*exit)(struct crypto_tfm___38 *);
	struct crypto_alg___38 *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct ablkcipher_request___38 {
	struct crypto_async_request___38 base;
	unsigned int nbytes;
	void *info;
	struct scatterlist *src;
	struct scatterlist *dst;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_blkcipher___38;

struct blkcipher_desc___38 {
	struct crypto_blkcipher___38 *tfm;
	void *info;
	u32 flags;
};

struct crypto_blkcipher___38 {
	struct crypto_tfm___38 base;
};

struct ablkcipher_alg___38 {
	int (*setkey)(struct crypto_ablkcipher___38 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___38 *);
	int (*decrypt)(struct ablkcipher_request___38 *);
	int (*givencrypt)(struct skcipher_givcrypt_request *);
	int (*givdecrypt)(struct skcipher_givcrypt_request *);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct crypto_ablkcipher___38 {
	struct crypto_tfm___38 base;
};

struct blkcipher_alg___38 {
	int (*setkey)(struct crypto_tfm___38 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___38 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___38 *, struct scatterlist *, struct scatterlist *, unsigned int);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct cipher_alg___38 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___38 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___38 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___38 *, u8 *, const u8 *);
};

struct compress_alg___38 {
	int (*coa_compress)(struct crypto_tfm___38 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___38 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___38 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type *cra_type;
	union {
		struct ablkcipher_alg___38 ablkcipher;
		struct blkcipher_alg___38 blkcipher;
		struct cipher_alg___38 cipher;
		struct compress_alg___38 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___38 *);
	void (*cra_exit)(struct crypto_tfm___38 *);
	void (*cra_destroy)(struct crypto_alg___38 *);
	struct module___378 *cra_module;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___439;

struct kobj_type___439;

struct kobject___440 {
	const char *name;
	struct list_head entry;
	struct kobject___440 *parent;
	struct kset___439 *kset;
	struct kobj_type___439 *ktype;
	struct kernfs_node___447 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___378 {
	struct kobject___440 kobj;
	struct module___378 *mod;
	struct kobject___440 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___378 {
	struct module___378 *mod;
	struct latch_tree_node node;
};

struct module_layout___378 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___378 mtn;
};

struct module_attribute___378;

struct kernel_param___378;

struct module___378 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___378 mkobj;
	struct module_attribute___378 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___440 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___378 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___378 core_layout;
	struct module_layout___378 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide53;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide54;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct crypto_cipher___22 {
	struct crypto_tfm___38 base;
};

struct bio_vec___244 {
	struct page___453 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___219 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___244 *bvec;
		struct pipe_inode_info___133 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct msghdr___80 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___219 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___452 *msg_iocb;
};

struct kiocb___452 {
	struct file___452 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___452 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dentry_operations___452;

struct super_block___452;

struct dentry___452 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___452 *d_parent;
	struct qstr d_name;
	struct inode___452 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___452 *d_op;
	struct super_block___452 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___452;

struct block_device___452;

struct inode___452 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___452 *i_op;
	struct super_block___452 *i_sb;
	struct address_space___452 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___454 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___242 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___452 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___452 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___133 *i_pipe;
		struct block_device___452 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___452 {
	int (*d_revalidate)(struct dentry___452 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___452 *, unsigned int);
	int (*d_hash)(const struct dentry___452 *, struct qstr *);
	int (*d_compare)(const struct dentry___452 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___452 *);
	int (*d_init)(struct dentry___452 *);
	void (*d_release)(struct dentry___452 *);
	void (*d_prune)(struct dentry___452 *);
	void (*d_iput)(struct dentry___452 *, struct inode___452 *);
	char * (*d_dname)(struct dentry___452 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___453 *);
	int (*d_manage)(const struct path___453 *, bool);
	struct dentry___452 * (*d_real)(struct dentry___452 *, const struct inode___452 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___452;

struct mem_dqinfo___452 {
	struct quota_format_type___452 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___452;

struct quota_info___452 {
	unsigned int flags;
	struct rw_semaphore___454 dqio_sem;
	struct inode___452 *files[3];
	struct mem_dqinfo___452 info[3];
	const struct quota_format_ops___452 *ops[3];
};

struct rcuwait___452 {
	struct task_struct___454 *task;
};

struct percpu_rw_semaphore___452 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___454 rw_sem;
	struct rcuwait___452 writer;
	int readers_block;
};

struct sb_writers___452 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___452 rw_sem[3];
};

struct shrink_control___185;

struct shrinker___185 {
	long unsigned int (*count_objects)(struct shrinker___185 *, struct shrink_control___185 *);
	long unsigned int (*scan_objects)(struct shrinker___185 *, struct shrink_control___185 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___452;

struct super_operations___452;

struct dquot_operations___452;

struct quotactl_ops___452;

struct super_block___452 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___452 *s_type;
	const struct super_operations___452 *s_op;
	const struct dquot_operations___452 *dq_op;
	const struct quotactl_ops___452 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___452 *s_root;
	struct rw_semaphore___454 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___452 *s_bdev;
	struct backing_dev_info___242 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___452 s_dquot;
	struct sb_writers___452 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___452 *s_d_op;
	int cleancache_poolid;
	struct shrinker___185 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___317 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___185 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___185 *memcg;
};

struct iattr___452 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___452 *ia_file;
};

struct dquot___452 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___452 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___452 {
	int qf_fmt_id;
	const struct quota_format_ops___452 *qf_ops;
	struct module___378 *qf_owner;
	struct quota_format_type___452 *qf_next;
};

struct quota_format_ops___452 {
	int (*check_quota_file)(struct super_block___452 *, int);
	int (*read_file_info)(struct super_block___452 *, int);
	int (*write_file_info)(struct super_block___452 *, int);
	int (*free_file_info)(struct super_block___452 *, int);
	int (*read_dqblk)(struct dquot___452 *);
	int (*commit_dqblk)(struct dquot___452 *);
	int (*release_dqblk)(struct dquot___452 *);
	int (*get_next_id)(struct super_block___452 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___452 {
	int (*write_dquot)(struct dquot___452 *);
	struct dquot___452 * (*alloc_dquot)(struct super_block___452 *, int);
	void (*destroy_dquot)(struct dquot___452 *);
	int (*acquire_dquot)(struct dquot___452 *);
	int (*release_dquot)(struct dquot___452 *);
	int (*mark_dirty)(struct dquot___452 *);
	int (*write_info)(struct super_block___452 *, int);
	qsize_t * (*get_reserved_space)(struct inode___452 *);
	int (*get_projid)(struct inode___452 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___452 *, qsize_t *);
	int (*get_next_id)(struct super_block___452 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___452 {
	int (*quota_on)(struct super_block___452 *, int, int, const struct path___453 *);
	int (*quota_off)(struct super_block___452 *, int);
	int (*quota_enable)(struct super_block___452 *, unsigned int);
	int (*quota_disable)(struct super_block___452 *, unsigned int);
	int (*quota_sync)(struct super_block___452 *, int);
	int (*set_info)(struct super_block___452 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___452 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___452 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___452 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___452 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___452 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___205;

struct address_space_operations___452 {
	int (*writepage)(struct page___453 *, struct writeback_control___205 *);
	int (*readpage)(struct file___452 *, struct page___453 *);
	int (*writepages)(struct address_space___452 *, struct writeback_control___205 *);
	int (*set_page_dirty)(struct page___453 *);
	int (*readpages)(struct file___452 *, struct address_space___452 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___452 *, struct address_space___452 *, loff_t, unsigned int, unsigned int, struct page___453 **, void **);
	int (*write_end)(struct file___452 *, struct address_space___452 *, loff_t, unsigned int, unsigned int, struct page___453 *, void *);
	sector_t (*bmap)(struct address_space___452 *, sector_t);
	void (*invalidatepage)(struct page___453 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___453 *, gfp_t);
	void (*freepage)(struct page___453 *);
	ssize_t (*direct_IO)(struct kiocb___452 *, struct iov_iter___219 *);
	int (*migratepage)(struct address_space___452 *, struct page___453 *, struct page___453 *, enum migrate_mode);
	bool (*isolate_page)(struct page___453 *, isolate_mode_t);
	void (*putback_page)(struct page___453 *);
	int (*launder_page)(struct page___453 *);
	int (*is_partially_uptodate)(struct page___453 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___453 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___452 *, struct page___453 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___452 *, sector_t *);
	void (*swap_deactivate)(struct file___452 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___205 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___242 *wb;
	struct inode___452 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___452 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___452 *bd_inode;
	struct super_block___452 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___452 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___242 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___452 {
	struct dentry___452 * (*lookup)(struct inode___452 *, struct dentry___452 *, unsigned int);
	const char * (*get_link)(struct dentry___452 *, struct inode___452 *, struct delayed_call *);
	int (*permission)(struct inode___452 *, int);
	struct posix_acl * (*get_acl)(struct inode___452 *, int);
	int (*readlink)(struct dentry___452 *, char *, int);
	int (*create)(struct inode___452 *, struct dentry___452 *, umode_t, bool);
	int (*link)(struct dentry___452 *, struct inode___452 *, struct dentry___452 *);
	int (*unlink)(struct inode___452 *, struct dentry___452 *);
	int (*symlink)(struct inode___452 *, struct dentry___452 *, const char *);
	int (*mkdir)(struct inode___452 *, struct dentry___452 *, umode_t);
	int (*rmdir)(struct inode___452 *, struct dentry___452 *);
	int (*mknod)(struct inode___452 *, struct dentry___452 *, umode_t, dev_t);
	int (*rename)(struct inode___452 *, struct dentry___452 *, struct inode___452 *, struct dentry___452 *, unsigned int);
	int (*setattr)(struct dentry___452 *, struct iattr___452 *);
	int (*getattr)(const struct path___453 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___452 *, char *, size_t);
	int (*fiemap)(struct inode___452 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___452 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___452 *, struct dentry___452 *, struct file___452 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___452 *, struct dentry___452 *, umode_t);
	int (*set_acl)(struct inode___452 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___452 {
	void (*fl_copy_lock)(struct file_lock___452 *, struct file_lock___452 *);
	void (*fl_release_private)(struct file_lock___452 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___452;

struct file_lock___452 {
	struct file_lock___452 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___452 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___452 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___452 *fl_ops;
	const struct lock_manager_operations___452 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___452 {
	int (*lm_compare_owner)(struct file_lock___452 *, struct file_lock___452 *);
	long unsigned int (*lm_owner_key)(struct file_lock___452 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___452 *);
	int (*lm_grant)(struct file_lock___452 *, int);
	bool (*lm_break)(struct file_lock___452 *);
	int (*lm_change)(struct file_lock___452 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___452 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___452 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___452 *fa_next;
	struct file___452 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___452 {
	const char *name;
	int fs_flags;
	struct dentry___452 * (*mount)(struct file_system_type___452 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___452 *);
	struct module___378 *owner;
	struct file_system_type___452 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___452 {
	struct inode___452 * (*alloc_inode)(struct super_block___452 *);
	void (*destroy_inode)(struct inode___452 *);
	void (*dirty_inode)(struct inode___452 *, int);
	int (*write_inode)(struct inode___452 *, struct writeback_control___205 *);
	int (*drop_inode)(struct inode___452 *);
	void (*evict_inode)(struct inode___452 *);
	void (*put_super)(struct super_block___452 *);
	int (*sync_fs)(struct super_block___452 *, int);
	int (*freeze_super)(struct super_block___452 *);
	int (*freeze_fs)(struct super_block___452 *);
	int (*thaw_super)(struct super_block___452 *);
	int (*unfreeze_fs)(struct super_block___452 *);
	int (*statfs)(struct dentry___452 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___452 *, int *, char *);
	void (*umount_begin)(struct super_block___452 *);
	int (*show_options)(struct seq_file___391 *, struct dentry___452 *);
	int (*show_devname)(struct seq_file___391 *, struct dentry___452 *);
	int (*show_path)(struct seq_file___391 *, struct dentry___452 *);
	int (*show_stats)(struct seq_file___391 *, struct dentry___452 *);
	ssize_t (*quota_read)(struct super_block___452 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___452 *, int, const char *, size_t, loff_t);
	struct dquot___452 ** (*get_dquots)(struct inode___452 *);
	int (*bdev_try_to_free_page)(struct super_block___452 *, struct page___453 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___452 *, struct shrink_control___185 *);
	long int (*free_cached_objects)(struct super_block___452 *, struct shrink_control___185 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___301)(struct file___452 *, wait_queue_head_t *, struct poll_table_struct___291 *);

struct poll_table_struct___291 {
	poll_queue_proc___301 _qproc;
	__poll_t _key;
};

struct seq_operations___391;

struct seq_file___391 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___391 *op;
	int poll_event;
	const struct file___452 *file;
	void *private;
};

typedef void bio_end_io_t___242(struct bio___242 *);

struct bio_integrity_payload___242;

struct bio_set___242;

struct bio___242 {
	struct bio___242 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___242 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___242 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___244 *bi_io_vec;
	struct bio_set___242 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___244 bi_inline_vecs[0];
};

struct socket_wq___78 {
	wait_queue_head_t wait;
	struct fasync_struct___452 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct sock___77;

struct proto_ops___78;

struct socket___79 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___78 *wq;
	struct file___452 *file;
	struct sock___77 *sk;
	const struct proto_ops___78 *ops;
};

typedef struct {
	struct net___108 *net;
} possible_net_t___99;

struct proto___77;

struct sock_common___77 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___77 *skc_prot;
	possible_net_t___99 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___77 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___98;

struct sk_buff_head___97 {
	struct sk_buff___98 *next;
	struct sk_buff___98 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___77;

struct dst_entry___77;

struct net_device___97;

struct sock___77 {
	struct sock_common___77 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___97 sk_error_queue;
	struct sk_buff_head___97 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___98 *head;
		struct sk_buff___98 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___77 *sk_filter;
	union {
		struct socket_wq___78 *sk_wq;
		struct socket_wq___78 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___77 *sk_rx_dst;
	struct dst_entry___77 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___98 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___97 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___453 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___77 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___252 *sk_peer_pid;
	const struct cred___420 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___79 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___185 *sk_memcg;
	void (*sk_state_change)(struct sock___77 *);
	void (*sk_data_ready)(struct sock___77 *);
	void (*sk_write_space)(struct sock___77 *);
	void (*sk_error_report)(struct sock___77 *);
	int (*sk_backlog_rcv)(struct sock___77 *, struct sk_buff___98 *);
	struct sk_buff___98 * (*sk_validate_xmit_skb)(struct sock___77 *, struct net_device___97 *, struct sk_buff___98 *);
	void (*sk_destruct)(struct sock___77 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

typedef int (*sk_read_actor_t___77)(read_descriptor_t *, struct sk_buff___98 *, unsigned int, size_t);

struct proto_ops___78 {
	int family;
	struct module___378 *owner;
	int (*release)(struct socket___79 *);
	int (*bind)(struct socket___79 *, struct sockaddr *, int);
	int (*connect)(struct socket___79 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___79 *, struct socket___79 *);
	int (*accept)(struct socket___79 *, struct socket___79 *, int, bool);
	int (*getname)(struct socket___79 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___452 *, struct socket___79 *, struct poll_table_struct___291 *);
	int (*ioctl)(struct socket___79 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___79 *, int);
	int (*shutdown)(struct socket___79 *, int);
	int (*setsockopt)(struct socket___79 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___79 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___79 *, struct msghdr___80 *, size_t);
	int (*recvmsg)(struct socket___79 *, struct msghdr___80 *, size_t, int);
	int (*mmap)(struct file___452 *, struct socket___79 *, struct vm_area_struct___453 *);
	ssize_t (*sendpage)(struct socket___79 *, struct page___453 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___79 *, loff_t *, struct pipe_inode_info___133 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___77 *, int);
	int (*peek_len)(struct socket___79 *);
	int (*read_sock)(struct sock___77 *, read_descriptor_t *, sk_read_actor_t___77);
	int (*sendpage_locked)(struct sock___77 *, struct page___453 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___77 *, struct msghdr___80 *, size_t);
	int (*set_rcvlowat)(struct sock___77 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct nf_bridge_info___97;

struct sk_buff___98 {
	union {
		struct {
			struct sk_buff___98 *next;
			struct sk_buff___98 *prev;
			union {
				struct net_device___97 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___77 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___98 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___97 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___97;

struct netns_frags___97 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___97 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ip_ra_chain___43;

struct fib_rules_ops___77;

struct tcp_congestion_ops___19;

struct tcp_fastopen_context___19;

struct fib_notifier_ops___78;

struct netns_ipv4___97 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___43 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___77 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___77 *fibnl;
	struct sock___77 **icmp_sk;
	struct sock___77 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___77 **tcp_sk;
	struct netns_frags___97 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops___19 *tcp_congestion_control;
	struct tcp_fastopen_context___19 *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___77 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___78 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___78 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___77;

struct dst_ops___108 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___108 *);
	struct dst_entry___77 * (*check)(struct dst_entry___77 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___77 *);
	unsigned int (*mtu)(const struct dst_entry___77 *);
	u32 * (*cow_metrics)(struct dst_entry___77 *, long unsigned int);
	void (*destroy)(struct dst_entry___77 *);
	void (*ifdown)(struct dst_entry___77 *, struct net_device___97 *, int);
	struct dst_entry___77 * (*negative_advice)(struct dst_entry___77 *);
	void (*link_failure)(struct sk_buff___98 *);
	void (*update_pmtu)(struct dst_entry___77 *, struct sock___77 *, struct sk_buff___98 *, u32);
	void (*redirect)(struct dst_entry___77 *, struct sock___77 *, struct sk_buff___98 *);
	int (*local_out)(struct net___108 *, struct sock___77 *, struct sk_buff___98 *);
	struct neighbour___77 * (*neigh_lookup)(const struct dst_entry___77 *, struct sk_buff___98 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___77 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___108 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___97 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___108 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___77 *fib6_rules_ops;
	struct sock___77 **icmp_sk;
	struct sock___77 *ndisc_sk;
	struct sock___77 *tcp_sk;
	struct sock___77 *igmp_sk;
	struct sock___77 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___77 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___78 *notifier_ops;
	struct fib_notifier_ops___78 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___78 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___77 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___97 {
	struct netns_frags___97 frags;
};

struct netns_xfrm___108 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___77 *nlsk;
	struct sock___77 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___108 xfrm4_dst_ops;
	struct dst_ops___108 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___87;

struct net___108 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___317 *user_ns;
	struct ucounts___317 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___29 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___77 *rtnl;
	struct sock___77 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___97 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___97 ipv4;
	struct netns_ipv6___108 ipv6;
	struct netns_sctp___78 sctp;
	struct netns_nf___15 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___97 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___77 *nfnl;
	struct sock___77 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___108 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___77 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___87 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kernfs_root___446;

struct kernfs_elem_dir___446 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___446 *root;
};

struct kernfs_syscall_ops___446;

struct kernfs_root___446 {
	struct kernfs_node___447 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___446 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___446 {
	struct kernfs_node___447 *target_kn;
};

struct kernfs_ops___446;

struct kernfs_elem_attr___446 {
	const struct kernfs_ops___446 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___447 *notify_next;
};

struct kernfs_node___447 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___447 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___446 dir;
		struct kernfs_elem_symlink___446 symlink;
		struct kernfs_elem_attr___446 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___446;

struct kernfs_ops___446 {
	int (*open)(struct kernfs_open_file___446 *);
	void (*release)(struct kernfs_open_file___446 *);
	int (*seq_show)(struct seq_file___391 *, void *);
	void * (*seq_start)(struct seq_file___391 *, loff_t *);
	void * (*seq_next)(struct seq_file___391 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___391 *, void *);
	ssize_t (*read)(struct kernfs_open_file___446 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___446 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___446 *, struct vm_area_struct___453 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___446 *, struct poll_table_struct___291 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___446 {
	int (*remount_fs)(struct kernfs_root___446 *, int *, char *);
	int (*show_options)(struct seq_file___391 *, struct kernfs_root___446 *);
	int (*mkdir)(struct kernfs_node___447 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___447 *);
	int (*rename)(struct kernfs_node___447 *, struct kernfs_node___447 *, const char *);
	int (*show_path)(struct seq_file___391 *, struct kernfs_node___447 *, struct kernfs_root___446 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___446 {
	struct kernfs_node___447 *kn;
	struct file___452 *file;
	struct seq_file___391 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___440 *vm_ops;
};

struct kobj_ns_type_operations___77 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___77 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___416;

struct attribute_group___417 {
	const char *name;
	umode_t (*is_visible)(struct kobject___440 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___440 *, struct bin_attribute___416 *, int);
	struct attribute **attrs;
	struct bin_attribute___416 **bin_attrs;
};

struct bin_attribute___416 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___452 *, struct kobject___440 *, struct bin_attribute___416 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___452 *, struct kobject___440 *, struct bin_attribute___416 *, char *, loff_t, size_t);
	int (*mmap)(struct file___452 *, struct kobject___440 *, struct bin_attribute___416 *, struct vm_area_struct___453 *);
};

struct sysfs_ops___439 {
	ssize_t (*show)(struct kobject___440 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___440 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___439;

struct kset___439 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___440 kobj;
	const struct kset_uevent_ops___439 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___439 {
	void (*release)(struct kobject___440 *);
	const struct sysfs_ops___439 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___77 * (*child_ns_type)(struct kobject___440 *);
	const void * (*namespace)(struct kobject___440 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___439 {
	int (* const filter)(struct kset___439 *, struct kobject___440 *);
	const char * (* const name)(struct kset___439 *, struct kobject___440 *);
	int (* const uevent)(struct kset___439 *, struct kobject___440 *, struct kobj_uevent_env *);
};

struct kobj_attribute___430 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___440 *, struct kobj_attribute___430 *, char *);
	ssize_t (*store)(struct kobject___440 *, struct kobj_attribute___430 *, const char *, size_t);
};

struct dev_pm_ops___420 {
	int (*prepare)(struct device___420 *);
	void (*complete)(struct device___420 *);
	int (*suspend)(struct device___420 *);
	int (*resume)(struct device___420 *);
	int (*freeze)(struct device___420 *);
	int (*thaw)(struct device___420 *);
	int (*poweroff)(struct device___420 *);
	int (*restore)(struct device___420 *);
	int (*suspend_late)(struct device___420 *);
	int (*resume_early)(struct device___420 *);
	int (*freeze_late)(struct device___420 *);
	int (*thaw_early)(struct device___420 *);
	int (*poweroff_late)(struct device___420 *);
	int (*restore_early)(struct device___420 *);
	int (*suspend_noirq)(struct device___420 *);
	int (*resume_noirq)(struct device___420 *);
	int (*freeze_noirq)(struct device___420 *);
	int (*thaw_noirq)(struct device___420 *);
	int (*poweroff_noirq)(struct device___420 *);
	int (*restore_noirq)(struct device___420 *);
	int (*runtime_suspend)(struct device___420 *);
	int (*runtime_resume)(struct device___420 *);
	int (*runtime_idle)(struct device___420 *);
};

struct dev_pm_info___420 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___420 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___420;

struct bus_type___420;

struct device_driver___420;

struct dev_pm_domain___420;

struct dma_map_ops___192;

struct fwnode_handle___340;

struct class___420;

struct device___420 {
	struct device___420 *parent;
	struct device_private *p;
	struct kobject___440 kobj;
	const char *init_name;
	const struct device_type___420 *type;
	struct mutex mutex;
	struct bus_type___420 *bus;
	struct device_driver___420 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___420 power;
	struct dev_pm_domain___420 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___192 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___340 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___420 *class;
	const struct attribute_group___417 **groups;
	void (*release)(struct device___420 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___420 {
	struct dev_pm_ops___420 ops;
	void (*detach)(struct device___420 *, bool);
	int (*activate)(struct device___420 *);
	void (*sync)(struct device___420 *);
	void (*dismiss)(struct device___420 *);
};

struct bus_type___420 {
	const char *name;
	const char *dev_name;
	struct device___420 *dev_root;
	const struct attribute_group___417 **bus_groups;
	const struct attribute_group___417 **dev_groups;
	const struct attribute_group___417 **drv_groups;
	int (*match)(struct device___420 *, struct device_driver___420 *);
	int (*uevent)(struct device___420 *, struct kobj_uevent_env *);
	int (*probe)(struct device___420 *);
	int (*remove)(struct device___420 *);
	void (*shutdown)(struct device___420 *);
	int (*online)(struct device___420 *);
	int (*offline)(struct device___420 *);
	int (*suspend)(struct device___420 *, pm_message_t);
	int (*resume)(struct device___420 *);
	int (*num_vf)(struct device___420 *);
	int (*dma_configure)(struct device___420 *);
	const struct dev_pm_ops___420 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___420 {
	const char *name;
	struct bus_type___420 *bus;
	struct module___378 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___420 *);
	int (*remove)(struct device___420 *);
	void (*shutdown)(struct device___420 *);
	int (*suspend)(struct device___420 *, pm_message_t);
	int (*resume)(struct device___420 *);
	const struct attribute_group___417 **groups;
	const struct dev_pm_ops___420 *pm;
	void (*coredump)(struct device___420 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___420 {
	const char *name;
	const struct attribute_group___417 **groups;
	int (*uevent)(struct device___420 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___420 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___420 *);
	const struct dev_pm_ops___420 *pm;
};

struct class___420 {
	const char *name;
	struct module___378 *owner;
	const struct attribute_group___417 **class_groups;
	const struct attribute_group___417 **dev_groups;
	struct kobject___440 *dev_kobj;
	int (*dev_uevent)(struct device___420 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___420 *, umode_t *);
	void (*class_release)(struct class___420 *);
	void (*dev_release)(struct device___420 *);
	int (*shutdown_pre)(struct device___420 *);
	const struct kobj_ns_type_operations___77 *ns_type;
	const void * (*namespace)(struct device___420 *);
	const struct dev_pm_ops___420 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___192 {
	void * (*alloc)(struct device___420 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___420 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___420 *, struct vm_area_struct___453 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___420 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___420 *, struct page___453 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___420 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___420 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___420 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___420 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___420 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___420 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___420 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___420 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___420 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___420 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___420 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___420 *, u64);
	u64 (*get_required_mask)(struct device___420 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___340;

struct fwnode_handle___340 {
	struct fwnode_handle___340 *secondary;
	const struct fwnode_operations___340 *ops;
};

typedef void compound_page_dtor___440(struct page___453 *);

struct fwnode_reference_args___340;

struct fwnode_endpoint___340;

struct fwnode_operations___340 {
	struct fwnode_handle___340 * (*get)(struct fwnode_handle___340 *);
	void (*put)(struct fwnode_handle___340 *);
	bool (*device_is_available)(const struct fwnode_handle___340 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___340 *, const struct device___420 *);
	bool (*property_present)(const struct fwnode_handle___340 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___340 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___340 *, const char *, const char **, size_t);
	struct fwnode_handle___340 * (*get_parent)(const struct fwnode_handle___340 *);
	struct fwnode_handle___340 * (*get_next_child_node)(const struct fwnode_handle___340 *, struct fwnode_handle___340 *);
	struct fwnode_handle___340 * (*get_named_child_node)(const struct fwnode_handle___340 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___340 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___340 *);
	struct fwnode_handle___340 * (*graph_get_next_endpoint)(const struct fwnode_handle___340 *, struct fwnode_handle___340 *);
	struct fwnode_handle___340 * (*graph_get_remote_endpoint)(const struct fwnode_handle___340 *);
	struct fwnode_handle___340 * (*graph_get_port_parent)(struct fwnode_handle___340 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___340 *, struct fwnode_endpoint___340 *);
};

struct fwnode_endpoint___340 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___340 *local_fwnode;
};

struct fwnode_reference_args___340 {
	struct fwnode_handle___340 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___133;

struct pipe_buffer___133 {
	struct page___453 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___133 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___133 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___133 *, struct pipe_buffer___133 *);
	void (*release)(struct pipe_inode_info___133 *, struct pipe_buffer___133 *);
	int (*steal)(struct pipe_inode_info___133 *, struct pipe_buffer___133 *);
	union {
		bool (*get)(struct pipe_inode_info___133 *, struct pipe_buffer___133 *);
		struct {
			void (*get)(struct pipe_inode_info___133 *, struct pipe_buffer___133 *);
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
};

struct nf_bridge_info___97 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___97 = 0,
		BRNF_PROTO_8021Q___97 = 1,
		BRNF_PROTO_PPPOE___97 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___97 *physindev;
	struct net_device___97 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___97(struct sk_buff___98 **);

struct net_device_ops___97;

struct ethtool_ops___97;

struct l3mdev_ops___77;

struct ndisc_ops___48;

struct xfrmdev_ops___97;

struct tlsdev_ops___97;

struct header_ops___97;

struct inet6_dev___48;

struct netdev_rx_queue___97;

struct mini_Qdisc___89;

struct netdev_queue___97;

struct Qdisc___89;

struct rtnl_link_ops___89;

struct dcbnl_rtnl_ops___97;

struct net_device___97 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___97 *netdev_ops;
	const struct ethtool_ops___97 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___77 *l3mdev_ops;
	const struct ndisc_ops___48 *ndisc_ops;
	const struct xfrmdev_ops___97 *xfrmdev_ops;
	const struct tlsdev_ops___97 *tlsdev_ops;
	const struct header_ops___97 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___439 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___48 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___97 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___87 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___97 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___89 *miniq_ingress;
	struct netdev_queue___97 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___97 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___89 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___89 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___97 = 0,
		NETREG_REGISTERED___97 = 1,
		NETREG_UNREGISTERING___97 = 2,
		NETREG_UNREGISTERED___97 = 3,
		NETREG_RELEASED___97 = 4,
		NETREG_DUMMY___97 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___97 = 0,
		RTNL_LINK_INITIALIZING___97 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___97 *);
	struct netpoll_info *npinfo;
	possible_net_t___99 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___420 dev;
	const struct attribute_group___417 *sysfs_groups[4];
	const struct attribute_group___417 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___89 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___97 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

typedef int (*key_restrict_link_func_t___421)(struct key___420 *, const struct key_type *, const union key_payload *, struct key___420 *);

struct key_restriction___420;

struct key___420 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___454 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___420 *restrict_link;
};

struct key_restriction___420 {
	key_restrict_link_func_t___421 check;
	struct key___420 *key;
	struct key_type *keytype;
};

struct cgroup_namespace___301 {
	refcount_t count;
	struct ns_common___29 ns;
	struct user_namespace___317 *user_ns;
	struct ucounts___317 *ucounts;
	struct css_set___301 *root_cset;
};

struct netlink_callback___99 {
	struct sk_buff___98 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___99 *);
	int (*dump)(struct sk_buff___98 *, struct netlink_callback___99 *);
	int (*done)(struct netlink_callback___99 *);
	void *data;
	struct module___378 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct ethtool_ops___97 {
	int (*get_settings)(struct net_device___97 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___97 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___97 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___97 *);
	void (*get_regs)(struct net_device___97 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___97 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___97 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___97 *);
	void (*set_msglevel)(struct net_device___97 *, u32);
	int (*nway_reset)(struct net_device___97 *);
	u32 (*get_link)(struct net_device___97 *);
	int (*get_eeprom_len)(struct net_device___97 *);
	int (*get_eeprom)(struct net_device___97 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___97 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___97 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___97 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___97 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___97 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___97 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___97 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___97 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___97 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___97 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___97 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___97 *);
	void (*complete)(struct net_device___97 *);
	u32 (*get_priv_flags)(struct net_device___97 *);
	int (*set_priv_flags)(struct net_device___97 *, u32);
	int (*get_sset_count)(struct net_device___97 *, int);
	int (*get_rxnfc)(struct net_device___97 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___97 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___97 *, struct ethtool_flash *);
	int (*reset)(struct net_device___97 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___97 *);
	u32 (*get_rxfh_indir_size)(struct net_device___97 *);
	int (*get_rxfh)(struct net_device___97 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___97 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___97 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___97 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___97 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___97 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___97 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___97 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___97 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___97 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___97 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___97 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___97 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___97 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___97 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___97 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___97 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___97 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___97 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___97 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___97 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___97 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	int (*get_fecparam)(struct net_device___97 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___97 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___97 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___97 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___97 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___97;

struct inet_frags___97 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___97 *, const void *);
	void (*destructor)(struct inet_frag_queue___97 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___97 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___98 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___98 *fragments_tail;
	struct sk_buff___98 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___97 *net;
	struct callback_head rcu;
};

struct ip_ra_chain___43 {
	struct ip_ra_chain___43 *next;
	struct sock___77 *sk;
	union {
		void (*destructor)(struct sock___77 *);
		struct sock___77 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___77;

struct fib_lookup_arg___77;

struct fib_rules_ops___77 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___77 *, struct flowi *, int, struct fib_lookup_arg___77 *);
	bool (*suppress)(struct fib_rule___77 *, struct fib_lookup_arg___77 *);
	int (*match)(struct fib_rule___77 *, struct flowi *, int);
	int (*configure)(struct fib_rule___77 *, struct sk_buff___98 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___77 *);
	int (*compare)(struct fib_rule___77 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___77 *, struct sk_buff___98 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___77 *);
	void (*flush_cache)(struct fib_rules_ops___77 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___378 *owner;
	struct net___108 *fro_net;
	struct callback_head rcu;
};

struct tcp_congestion_ops___19 {
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___77 *);
	void (*release)(struct sock___77 *);
	u32 (*ssthresh)(struct sock___77 *);
	void (*cong_avoid)(struct sock___77 *, u32, u32);
	void (*set_state)(struct sock___77 *, u8);
	void (*cwnd_event)(struct sock___77 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___77 *, u32);
	u32 (*undo_cwnd)(struct sock___77 *);
	void (*pkts_acked)(struct sock___77 *, const struct ack_sample *);
	u32 (*min_tso_segs)(struct sock___77 *);
	u32 (*sndbuf_expand)(struct sock___77 *);
	void (*cong_control)(struct sock___77 *, const struct rate_sample *);
	size_t (*get_info)(struct sock___77 *, u32, int *, union tcp_cc_info *);
	char name[16];
	struct module___378 *owner;
};

struct tcp_fastopen_context___19 {
	struct crypto_cipher___22 *tfm;
	__u8 key[16];
	struct callback_head rcu;
};

struct fib_notifier_ops___78 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___108 *);
	int (*fib_dump)(struct net___108 *, struct notifier_block *);
	struct module___378 *owner;
	struct callback_head rcu;
};

struct dst_entry___77 {
	struct net_device___97 *dev;
	struct dst_ops___108 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___98 *);
	int (*output)(struct net___108 *, struct sock___77 *, struct sk_buff___98 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___77;

struct neigh_parms___77;

struct neigh_ops___77;

struct neighbour___77 {
	struct neighbour___77 *next;
	struct neigh_table___77 *tbl;
	struct neigh_parms___77 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___97 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___77 *, struct sk_buff___98 *);
	const struct neigh_ops___77 *ops;
	struct callback_head rcu;
	struct net_device___97 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct ucounts___317 {
	struct hlist_node node;
	struct user_namespace___317 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_prog_aux___90;

struct bpf_prog___87 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___90 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

struct seq_operations___391 {
	void * (*start)(struct seq_file___391 *, loff_t *);
	void (*stop)(struct seq_file___391 *, void *);
	void * (*next)(struct seq_file___391 *, void *, loff_t *);
	int (*show)(struct seq_file___391 *, void *);
};

struct pernet_operations___98 {
	struct list_head list;
	int (*init)(struct net___108 *);
	void (*exit)(struct net___108 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___97 {
	int (*ieee_getets)(struct net_device___97 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___97 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___97 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___97 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___97 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___97 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___97 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___97 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___97 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___97 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___97 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___97 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___97 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___97 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___97 *);
	u8 (*setstate)(struct net_device___97 *, u8);
	void (*getpermhwaddr)(struct net_device___97 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___97 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___97 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___97 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___97 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___97 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___97 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___97 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___97 *, int, u8 *);
	void (*setpfccfg)(struct net_device___97 *, int, u8);
	void (*getpfccfg)(struct net_device___97 *, int, u8 *);
	u8 (*setall)(struct net_device___97 *);
	u8 (*getcap)(struct net_device___97 *, int, u8 *);
	int (*getnumtcs)(struct net_device___97 *, int, u8 *);
	int (*setnumtcs)(struct net_device___97 *, int, u8);
	u8 (*getpfcstate)(struct net_device___97 *);
	void (*setpfcstate)(struct net_device___97 *, u8);
	void (*getbcncfg)(struct net_device___97 *, int, u32 *);
	void (*setbcncfg)(struct net_device___97 *, int, u32);
	void (*getbcnrp)(struct net_device___97 *, int, u8 *);
	void (*setbcnrp)(struct net_device___97 *, int, u8);
	int (*setapp)(struct net_device___97 *, u8, u16, u8);
	int (*getapp)(struct net_device___97 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___97 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___97 *, int, u8);
	u8 (*getdcbx)(struct net_device___97 *);
	u8 (*setdcbx)(struct net_device___97 *, u8);
	int (*peer_getappinfo)(struct net_device___97 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___97 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___97 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___97 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___97 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___97 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct bpf_map___302;

struct bpf_map_ops___301 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___302 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___302 *, struct file___452 *);
	void (*map_free)(struct bpf_map___302 *);
	int (*map_get_next_key)(struct bpf_map___302 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___302 *);
	void * (*map_lookup_elem)(struct bpf_map___302 *, void *);
	int (*map_update_elem)(struct bpf_map___302 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___302 *, void *);
	int (*map_push_elem)(struct bpf_map___302 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___302 *, void *);
	int (*map_peek_elem)(struct bpf_map___302 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___302 *, struct file___452 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___302 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___302 *, void *, struct seq_file___391 *);
	int (*map_check_btf)(const struct bpf_map___302 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___302 {
	const struct bpf_map_ops___301 *ops;
	struct bpf_map___302 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___420 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___97;

struct bpf_map_dev_ops___97 {
	int (*map_get_next_key)(struct bpf_offloaded_map___97 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___97 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___97 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___97 *, void *);
};

struct bpf_offloaded_map___97 {
	struct bpf_map___302 map;
	struct net_device___97 *netdev;
	const struct bpf_map_dev_ops___97 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___87 {
	int (*test_run)(struct bpf_prog___87 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___87 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___87 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___87 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___87 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___87 *, u32 *);
};

struct bpf_prog_offload_ops___87 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___87 *);
	int (*translate)(struct bpf_prog___87 *);
	void (*destroy)(struct bpf_prog___87 *);
};

struct bpf_prog_offload___87 {
	struct bpf_prog___87 *prog;
	struct net_device___97 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___87 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___90 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___87 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___87 *ops;
	struct bpf_map___302 **used_maps;
	struct bpf_prog___87 *prog;
	struct user_struct___420 *user;
	u64 load_time;
	struct bpf_map___302 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___87 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___87 {
	struct bpf_prog___87 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___87 {
	struct callback_head rcu;
	struct bpf_prog_array_item___87 items[0];
};

struct cgroup_bpf___87 {
	struct bpf_prog_array___87 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___87 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___302;

typedef void (*kthread_work_func_t___302)(struct kthread_work___302 *);

struct kthread_worker___302;

struct kthread_work___302 {
	struct list_head node;
	kthread_work_func_t___302 func;
	struct kthread_worker___302 *worker;
	int canceling;
};

struct kthread_worker___302 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___454 *task;
	struct kthread_work___302 *current_work;
};

struct kthread_delayed_work___301 {
	struct kthread_work___302 work;
	struct timer_list timer;
};

struct psi_group___301 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___302 *poll_kworker;
	struct kthread_delayed_work___301 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___301;

struct cgroup_rstat_cpu___301;

struct cgroup___301 {
	struct cgroup_subsys_state___301 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___447 *kn;
	struct cgroup_file___301 procs_file;
	struct cgroup_file___301 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___301 *subsys[13];
	struct cgroup_root___301 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___301 *dom_cgrp;
	struct cgroup_rstat_cpu___301 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___87 bpf;
	atomic_t congestion_count;
	struct cgroup___301 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___301 psi;
	int ancestor_ids[0];
};

struct cftype___301;

struct cgroup_subsys___301 {
	struct cgroup_subsys_state___301 * (*css_alloc)(struct cgroup_subsys_state___301 *);
	int (*css_online)(struct cgroup_subsys_state___301 *);
	void (*css_offline)(struct cgroup_subsys_state___301 *);
	void (*css_released)(struct cgroup_subsys_state___301 *);
	void (*css_free)(struct cgroup_subsys_state___301 *);
	void (*css_reset)(struct cgroup_subsys_state___301 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___301 *, int);
	int (*css_extra_stat_show)(struct seq_file___391 *, struct cgroup_subsys_state___301 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___454 *);
	void (*cancel_fork)(struct task_struct___454 *);
	void (*fork)(struct task_struct___454 *);
	void (*exit)(struct task_struct___454 *);
	void (*free)(struct task_struct___454 *);
	void (*bind)(struct cgroup_subsys_state___301 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___301 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___301 *dfl_cftypes;
	struct cftype___301 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___301 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___301 *updated_children;
	struct cgroup___301 *updated_next;
};

struct cgroup_root___301 {
	struct kernfs_root___446 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___301 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___301 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___301 *ss;
	struct list_head node;
	struct kernfs_ops___446 *kf_ops;
	int (*open)(struct kernfs_open_file___446 *);
	void (*release)(struct kernfs_open_file___446 *);
	u64 (*read_u64)(struct cgroup_subsys_state___301 *, struct cftype___301 *);
	s64 (*read_s64)(struct cgroup_subsys_state___301 *, struct cftype___301 *);
	int (*seq_show)(struct seq_file___391 *, void *);
	void * (*seq_start)(struct seq_file___391 *, loff_t *);
	void * (*seq_next)(struct seq_file___391 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___391 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___301 *, struct cftype___301 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___301 *, struct cftype___301 *, s64);
	ssize_t (*write)(struct kernfs_open_file___446 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___446 *, struct poll_table_struct___291 *);
};

struct xdp_rxq_info___97 {
	struct net_device___97 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___97 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___97 *dev_rx;
};

struct header_ops___97 {
	int (*create)(struct sk_buff___98 *, struct net_device___97 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___98 *, unsigned char *);
	int (*cache)(const struct neighbour___77 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___97 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___97 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___97 *, int);
	int poll_owner;
	struct net_device___97 *dev;
	struct sk_buff___98 *gro_list;
	struct sk_buff___98 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___97 {
	struct net_device___97 *dev;
	struct Qdisc___89 *qdisc;
	struct Qdisc___89 *qdisc_sleeping;
	struct kobject___440 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___97 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___89 {
	struct sk_buff___98 *head;
	struct sk_buff___98 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___89;

struct Qdisc___89 {
	int (*enqueue)(struct sk_buff___98 *, struct Qdisc___89 *, struct sk_buff___98 **);
	struct sk_buff___98 * (*dequeue)(struct Qdisc___89 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___89 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___97 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___97 gso_skb;
	struct qdisc_skb_head___89 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___89 *next_sched;
	struct sk_buff_head___97 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___97 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___440 kobj;
	struct net_device___97 *dev;
	long: 64;
	struct xdp_rxq_info___97 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___97)(struct net_device___97 *, struct sk_buff___98 *, struct net_device___97 *);

struct netdev_bpf___97 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___87 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___87 *prog;
			const struct bpf_prog_offload_ops___87 *ops;
		} verifier;
		struct {
			struct bpf_prog___87 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___97 *offmap;
		};
		struct {
			struct xdp_umem___3 *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___97 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___98 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___97 {
	int (*tls_dev_add)(struct net_device___97 *, struct sock___77 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___97 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___97 *, struct sock___77 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___97 {
	int (*ndo_init)(struct net_device___97 *);
	void (*ndo_uninit)(struct net_device___97 *);
	int (*ndo_open)(struct net_device___97 *);
	int (*ndo_stop)(struct net_device___97 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___98 *, struct net_device___97 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___98 *, struct net_device___97 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___97 *, struct sk_buff___98 *, struct net_device___97 *, select_queue_fallback_t___97);
	void (*ndo_change_rx_flags)(struct net_device___97 *, int);
	void (*ndo_set_rx_mode)(struct net_device___97 *);
	int (*ndo_set_mac_address)(struct net_device___97 *, void *);
	int (*ndo_validate_addr)(struct net_device___97 *);
	int (*ndo_do_ioctl)(struct net_device___97 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___97 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___97 *, int);
	int (*ndo_neigh_setup)(struct net_device___97 *, struct neigh_parms___77 *);
	void (*ndo_tx_timeout)(struct net_device___97 *);
	void (*ndo_get_stats64)(struct net_device___97 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___97 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___97 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___97 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___97 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___97 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___97 *);
	int (*ndo_netpoll_setup)(struct net_device___97 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___97 *);
	int (*ndo_set_vf_mac)(struct net_device___97 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___97 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___97 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___97 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___97 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___97 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___97 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___97 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___97 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___97 *, int, struct sk_buff___98 *);
	int (*ndo_set_vf_guid)(struct net_device___97 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___97 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___97 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___97 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___97 *, const struct sk_buff___98 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___97 *, struct net_device___97 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___97 *, struct net_device___97 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___97 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___97 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___97 *, struct neighbour___77 *);
	void (*ndo_neigh_destroy)(struct net_device___97 *, struct neighbour___77 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___97 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___97 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___97 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___98 *, struct netlink_callback___99 *, struct net_device___97 *, struct net_device___97 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___97 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___97 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___98 *, u32, u32, struct net_device___97 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___97 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___97 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___97 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___97 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___97 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___97 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___97 *, struct net_device___97 *);
	void (*ndo_dfwd_del_station)(struct net_device___97 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___97 *);
	int (*ndo_set_tx_maxrate)(struct net_device___97 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___97 *);
	int (*ndo_change_proto_down)(struct net_device___97 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___97 *, struct sk_buff___98 *);
	void (*ndo_set_rx_headroom)(struct net_device___97 *, int);
	int (*ndo_bpf)(struct net_device___97 *, struct netdev_bpf___97 *);
	int (*ndo_xdp_xmit)(struct net_device___97 *, int, struct xdp_frame___97 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___97 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___97 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___77 {
	possible_net_t___99 net;
	struct net_device___97 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___77 *);
	void (*neigh_cleanup)(struct neighbour___77 *);
	struct neigh_table___77 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___77 {
	u32 (*l3mdev_fib_table)(const struct net_device___97 *);
	struct sk_buff___98 * (*l3mdev_l3_rcv)(struct net_device___97 *, struct sk_buff___98 *, u16);
	struct sk_buff___98 * (*l3mdev_l3_out)(struct net_device___97 *, struct sock___77 *, struct sk_buff___98 *, u16);
	struct dst_entry___77 * (*l3mdev_link_scope_lookup)(const struct net_device___97 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct ndisc_ops___48 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___97 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___97 *, struct neighbour___77 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___97 *, u8, struct neighbour___77 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___97 *, struct sk_buff___98 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___108 *, struct net_device___97 *, const struct prefix_info *, struct inet6_dev___48 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___48;

struct inet6_dev___48 {
	struct net_device___97 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___48 *mc_list;
	struct ifmcaddr6___48 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___21 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	u8 rndid[8];
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___77 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
};

struct tcf_proto___89;

struct mini_Qdisc___89 {
	struct tcf_proto___89 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___89 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___97 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___108 *, struct net_device___97 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___97 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___97 *, struct list_head *);
	size_t (*get_size)(const struct net_device___97 *);
	int (*fill_info)(struct sk_buff___98 *, const struct net_device___97 *);
	size_t (*get_xstats_size)(const struct net_device___97 *);
	int (*fill_xstats)(struct sk_buff___98 *, const struct net_device___97 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___97 *, struct net_device___97 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___97 *, const struct net_device___97 *);
	int (*fill_slave_info)(struct sk_buff___98 *, const struct net_device___97 *, const struct net_device___97 *);
	struct net___108 * (*get_link_net)(const struct net_device___97 *);
	size_t (*get_linkxstats_size)(const struct net_device___97 *, int);
	int (*fill_linkxstats)(struct sk_buff___98 *, const struct net_device___97 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___97 {
	struct list_head poll_list;
	struct sk_buff_head___97 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___97 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___89 *output_queue;
	struct Qdisc___89 **output_queue_tailp;
	struct sk_buff___98 *completion_queue;
	struct sk_buff_head___97 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___97 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___97 input_pkt_queue;
	struct napi_struct___97 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bdi_writeback_congested___242 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___242 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___242 {
	struct bio___242 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___244 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___244 bip_inline_vecs[0];
};

struct bio_set___242 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___242 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___185 {
	struct mem_cgroup___185 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___185 {
	struct lruvec___453 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___185 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___185 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct kernel_param_ops___378 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___378 *);
	int (*get)(char *, const struct kernel_param___378 *);
	void (*free)(void *);
};

struct kparam_array___378;

struct kernel_param___378 {
	const char *name;
	struct module___378 *mod;
	const struct kernel_param_ops___378 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___378 *arr;
	};
};

struct kparam_array___378 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___378 *ops;
	void *elem;
};

struct module_attribute___378 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___378 *, struct module_kobject___378 *, char *);
	ssize_t (*store)(struct module_attribute___378 *, struct module_kobject___378 *, const char *, size_t);
	void (*setup)(struct module___378 *, const char *);
	int (*test)(struct module___378 *);
	void (*free)(struct module___378 *);
};

struct gnet_dump___89 {
	spinlock_t *lock;
	struct sk_buff___98 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___89;

struct Qdisc_ops___89 {
	struct Qdisc_ops___89 *next;
	const struct Qdisc_class_ops___89 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___98 *, struct Qdisc___89 *, struct sk_buff___98 **);
	struct sk_buff___98 * (*dequeue)(struct Qdisc___89 *);
	struct sk_buff___98 * (*peek)(struct Qdisc___89 *);
	int (*init)(struct Qdisc___89 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___89 *);
	void (*destroy)(struct Qdisc___89 *);
	int (*change)(struct Qdisc___89 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___89 *);
	int (*change_tx_queue_len)(struct Qdisc___89 *, unsigned int);
	int (*dump)(struct Qdisc___89 *, struct sk_buff___98 *);
	int (*dump_stats)(struct Qdisc___89 *, struct gnet_dump___89 *);
	void (*ingress_block_set)(struct Qdisc___89 *, u32);
	void (*egress_block_set)(struct Qdisc___89 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___89 *);
	u32 (*egress_block_get)(struct Qdisc___89 *);
	struct module___378 *owner;
};

struct tcf_block___89;

struct Qdisc_class_ops___89 {
	unsigned int flags;
	struct netdev_queue___97 * (*select_queue)(struct Qdisc___89 *, struct tcmsg *);
	int (*graft)(struct Qdisc___89 *, long unsigned int, struct Qdisc___89 *, struct Qdisc___89 **, struct netlink_ext_ack *);
	struct Qdisc___89 * (*leaf)(struct Qdisc___89 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___89 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___89 *, u32);
	int (*change)(struct Qdisc___89 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___89 *, long unsigned int);
	void (*walk)(struct Qdisc___89 *, struct qdisc_walker *);
	struct tcf_block___89 * (*tcf_block)(struct Qdisc___89 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___89 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___89 *, long unsigned int);
	int (*dump)(struct Qdisc___89 *, long unsigned int, struct sk_buff___98 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___89 *, long unsigned int, struct gnet_dump___89 *);
};

struct tcf_chain___89;

struct tcf_block___89 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___108 *net;
	struct Qdisc___89 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___89 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___89;

struct tcf_proto_ops___89;

struct tcf_proto___89 {
	struct tcf_proto___89 *next;
	void *root;
	int (*classify)(struct sk_buff___98 *, const struct tcf_proto___89 *, struct tcf_result___89 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___89 *ops;
	struct tcf_chain___89 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___89 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___89 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___89 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___98 *, const struct tcf_proto___89 *, struct tcf_result___89 *);
	int (*init)(struct tcf_proto___89 *);
	void (*destroy)(struct tcf_proto___89 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___89 *, u32);
	void (*put)(struct tcf_proto___89 *, void *);
	int (*change)(struct net___108 *, struct sk_buff___98 *, struct tcf_proto___89 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___89 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___89 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___89 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___108 *, struct tcf_chain___89 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___108 *, struct tcf_proto___89 *, void *, struct sk_buff___98 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___98 *, struct net___108 *, void *);
	struct module___378 *owner;
	int flags;
};

struct tcf_chain___89 {
	struct mutex filter_chain_lock;
	struct tcf_proto___89 *filter_chain;
	struct list_head list;
	struct tcf_block___89 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___89 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___77 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___87 *prog;
};

struct bpf_redirect_info___87 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___302 *map;
	struct bpf_map___302 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___77;

struct neigh_hash_table___77;

struct neigh_table___77 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___97 *, __u32 *);
	bool (*key_eq)(const struct neighbour___77 *, const void *);
	int (*constructor)(struct neighbour___77 *);
	int (*pconstructor)(struct pneigh_entry___77 *);
	void (*pdestructor)(struct pneigh_entry___77 *);
	void (*proxy_redo)(struct sk_buff___98 *);
	char *id;
	struct neigh_parms___77 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___97 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___77 *nht;
	struct pneigh_entry___77 **phash_buckets;
};

struct neigh_ops___77 {
	int family;
	void (*solicit)(struct neighbour___77 *, struct sk_buff___98 *);
	void (*error_report)(struct neighbour___77 *, struct sk_buff___98 *);
	int (*output)(struct neighbour___77 *, struct sk_buff___98 *);
	int (*connected_output)(struct neighbour___77 *, struct sk_buff___98 *);
};

struct pneigh_entry___77 {
	struct pneigh_entry___77 *next;
	possible_net_t___99 net;
	struct net_device___97 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___77 {
	struct neighbour___77 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___77 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___77 *ctarget;
	struct net___108 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___77 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___77 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___60;

struct timewait_sock_ops___56;

struct proto___77 {
	void (*close)(struct sock___77 *, long int);
	int (*pre_connect)(struct sock___77 *, struct sockaddr *, int);
	int (*connect)(struct sock___77 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___77 *, int);
	struct sock___77 * (*accept)(struct sock___77 *, int, int *, bool);
	int (*ioctl)(struct sock___77 *, int, long unsigned int);
	int (*init)(struct sock___77 *);
	void (*destroy)(struct sock___77 *);
	void (*shutdown)(struct sock___77 *, int);
	int (*setsockopt)(struct sock___77 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___77 *, int, int, char *, int *);
	void (*keepalive)(struct sock___77 *, int);
	int (*sendmsg)(struct sock___77 *, struct msghdr___80 *, size_t);
	int (*recvmsg)(struct sock___77 *, struct msghdr___80 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___77 *, struct page___453 *, int, size_t, int);
	int (*bind)(struct sock___77 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___77 *, struct sk_buff___98 *);
	void (*release_cb)(struct sock___77 *);
	int (*hash)(struct sock___77 *);
	void (*unhash)(struct sock___77 *);
	void (*rehash)(struct sock___77 *);
	int (*get_port)(struct sock___77 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___77 *);
	bool (*stream_memory_read)(const struct sock___77 *);
	void (*enter_memory_pressure)(struct sock___77 *);
	void (*leave_memory_pressure)(struct sock___77 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___60 *rsk_prot;
	struct timewait_sock_ops___56 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___378 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___77 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct request_sock___61;

struct request_sock_ops___60 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___77 *, struct request_sock___61 *);
	void (*send_ack)(const struct sock___77 *, struct sk_buff___98 *, struct request_sock___61 *);
	void (*send_reset)(const struct sock___77 *, struct sk_buff___98 *);
	void (*destructor)(struct request_sock___61 *);
	void (*syn_ack_timeout)(const struct request_sock___61 *);
};

struct timewait_sock_ops___56 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___77 *, struct sock___77 *, void *);
	void (*twsk_destructor)(struct sock___77 *);
};

struct request_sock___61 {
	struct sock_common___77 __req_common;
	struct request_sock___61 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___60 *rsk_ops;
	struct sock___77 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___48 {
	struct in6_addr mca_addr;
	struct inet6_dev___48 *idev;
	struct ifmcaddr6___48 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ip6_ra_chain___48 {
	struct ip6_ra_chain___48 *next;
	struct sock___77 *sk;
	int sel;
	void (*destructor)(struct sock___77 *);
};

struct module___379;

struct file___453;

struct kiocb___453;

struct iov_iter___220;

struct poll_table_struct___292;

struct vm_area_struct___454;

struct inode___453;

struct file_lock___453;

struct page___454;

struct pipe_inode_info___134;

struct seq_file___392;

struct file_operations___453 {
	struct module___379 *owner;
	loff_t (*llseek)(struct file___453 *, loff_t, int);
	ssize_t (*read)(struct file___453 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___453 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___453 *, struct iov_iter___220 *);
	ssize_t (*write_iter)(struct kiocb___453 *, struct iov_iter___220 *);
	int (*iopoll)(struct kiocb___453 *, bool);
	int (*iterate)(struct file___453 *, struct dir_context *);
	int (*iterate_shared)(struct file___453 *, struct dir_context *);
	__poll_t (*poll)(struct file___453 *, struct poll_table_struct___292 *);
	long int (*unlocked_ioctl)(struct file___453 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___453 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___453 *, struct vm_area_struct___454 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___453 *, struct file___453 *);
	int (*flush)(struct file___453 *, fl_owner_t);
	int (*release)(struct inode___453 *, struct file___453 *);
	int (*fsync)(struct file___453 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___453 *, int);
	int (*lock)(struct file___453 *, int, struct file_lock___453 *);
	ssize_t (*sendpage)(struct file___453 *, struct page___454 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___453 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___453 *, int, struct file_lock___453 *);
	ssize_t (*splice_write)(struct pipe_inode_info___134 *, struct file___453 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___453 *, loff_t *, struct pipe_inode_info___134 *, size_t, unsigned int);
	int (*setlease)(struct file___453 *, long int, struct file_lock___453 **, void **);
	long int (*fallocate)(struct file___453 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___392 *, struct file___453 *);
	ssize_t (*copy_file_range)(struct file___453 *, loff_t, struct file___453 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___453 *, loff_t, struct file___453 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___453 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___454 {
	u64 seqnum;
	struct vm_area_struct___454 *vmas[4];
};

struct page_frag___454 {
	struct page___454 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___454;

struct mem_cgroup___186;

struct cred___421;

struct nsproxy___348;

struct signal_struct___328;

struct bio_list___243;

struct backing_dev_info___243;

struct css_set___302;

struct vm_struct___357;

struct task_struct___455 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___455 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___454 *mm;
	struct mm_struct___454 *active_mm;
	struct vmacache___454 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___455 *real_parent;
	struct task_struct___455 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___455 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___186 *active_memcg;
	long int rh_reserved2;
	struct pid___252 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___252 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___252 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___421 *ptracer_cred;
	const struct cred___421 *real_cred;
	const struct cred___421 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___348 *nsproxy;
	struct signal_struct___328 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___455 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___243 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___243 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___302 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___134 *splice_pipe;
	struct page_frag___454 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___186 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___455 *oom_reaper_list;
	struct vm_struct___357 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___156 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___454 *pgtable_t___454;

struct address_space___453;

struct dev_pagemap___441;

struct page___454 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___453 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___454 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___454 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___454 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___441 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___186 *mem_cgroup;
};

struct pglist_data___454;

struct lruvec___454 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___454 *pgdat;
};

struct zone___454 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___454 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___454 {
	struct zone___454 *zone;
	int zone_idx;
};

struct zonelist___454 {
	struct zoneref___454 _zonerefs[25];
};

struct pglist_data___454 {
	struct zone___454 node_zones[3];
	struct zonelist___454 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___455 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___455 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___454 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___455 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___455 *owner;
};

struct secondary_data___455 {
	void *stack;
	struct task_struct___455 *task;
	long int status;
};

struct blocking_notifier_head___454 {
	struct rw_semaphore___455 rwsem;
	struct notifier_block *head;
};

struct vm_operations_struct___441;

struct vm_area_struct___454 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___454 *vm_next;
	struct vm_area_struct___454 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___454 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___441 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___453 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___454;

struct user_namespace___318;

struct mm_struct___454 {
	struct {
		struct vm_area_struct___454 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___453 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___455 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___454 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___455 *owner;
		struct user_namespace___318 *user_ns;
		struct file___453 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___454 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___453;

struct address_space___453 {
	struct inode___453 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___455 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___453 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___441)(struct vm_area_struct___454 *, long unsigned int, const struct page___454 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___441)(struct page___454 *, void *);

struct device___421;

struct dev_pagemap___441 {
	dev_page_fault_t___441 page_fault;
	dev_page_free_t___441 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___421 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct cgroup___302;

struct cgroup_subsys___302;

struct cgroup_subsys_state___302 {
	struct cgroup___302 *cgroup;
	struct cgroup_subsys___302 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___302 *parent;
};

struct kernfs_node___448;

struct cgroup_file___302 {
	struct kernfs_node___448 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___186;

struct mem_cgroup___186 {
	struct cgroup_subsys_state___302 css;
	struct mem_cgroup_id___13 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___302 events_file;
	struct cgroup_file___302 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___455 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___186 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry___453;

struct path___454 {
	struct vfsmount *mnt;
	struct dentry___453 *dentry;
};

struct file___453 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___454 f_path;
	struct inode___453 *f_inode;
	const struct file_operations___453 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___252 f_owner;
	const struct cred___421 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___453 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___441;

struct vm_operations_struct___441 {
	void (*open)(struct vm_area_struct___454 *);
	void (*close)(struct vm_area_struct___454 *);
	int (*split)(struct vm_area_struct___454 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___454 *);
	vm_fault_t (*fault)(struct vm_fault___441 *);
	vm_fault_t (*huge_fault)(struct vm_fault___441 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___441 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___454 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___441 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___441 *);
	int (*access)(struct vm_area_struct___454 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___454 *);
	int (*set_policy)(struct vm_area_struct___454 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___454 *, long unsigned int);
	struct page___454 * (*find_special_page)(struct vm_area_struct___454 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___454 {
	struct task_struct___455 *task;
	struct core_thread___454 *next;
};

struct core_state___454 {
	atomic_t nr_threads;
	struct core_thread___454 dumper;
	struct completion startup;
};

struct key___421;

struct ucounts___318;

struct user_namespace___318 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___318 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___29 ns;
	long unsigned int flags;
	struct key___421 *persistent_keyring_register;
	struct rw_semaphore___455 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___318 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___441 {
	struct vm_area_struct___454 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___454 *cow_page;
	struct mem_cgroup___186 *memcg;
	struct page___454 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___454 prealloc_pte;
};

struct shrink_control___186 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___186 *memcg;
};

struct shrinker___186 {
	long unsigned int (*count_objects)(struct shrinker___186 *, struct shrink_control___186 *);
	long unsigned int (*scan_objects)(struct shrinker___186 *, struct shrink_control___186 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct user_struct___421 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___421 *uid_keyring;
	struct key___421 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___421 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___421 *session_keyring;
	struct key___421 *process_keyring;
	struct key___421 *thread_keyring;
	struct key___421 *request_key_auth;
	void *security;
	struct user_struct___421 *user;
	struct user_namespace___318 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___109;

struct cgroup_namespace___302;

struct nsproxy___348 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net___109 *net_ns;
	struct cgroup_namespace___302 *cgroup_ns;
};

struct signal_struct___328 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___455 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___455 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___252 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___252 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___454 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___252 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___243;

struct bio_list___243 {
	struct bio___243 *head;
	struct bio___243 *tail;
};

struct bdi_writeback_congested___243;

struct bdi_writeback___243 {
	struct backing_dev_info___243 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___243 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___302 *memcg_css;
	struct cgroup_subsys_state___302 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___243 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___243 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___421 *dev;
	struct device___421 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___453 *debug_dir;
	struct dentry___453 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___302 {
	struct cgroup_subsys_state___302 *subsys[13];
	refcount_t refcount;
	struct css_set___302 *dom_cset;
	struct cgroup___302 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___302 *mg_src_cgrp;
	struct cgroup___302 *mg_dst_cgrp;
	struct css_set___302 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___453;

struct pipe_buffer___134;

struct pipe_inode_info___134 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___454 *tmp_page;
	struct fasync_struct___453 *fasync_readers;
	struct fasync_struct___453 *fasync_writers;
	struct pipe_buffer___134 *bufs;
	struct user_struct___421 *user;
};

struct vm_struct___357 {
	struct vm_struct___357 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___454 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___340 {
	struct task_struct___455 task;
	long unsigned int stack[8192];
};

struct kset___440;

struct kobj_type___440;

struct kobject___441 {
	const char *name;
	struct list_head entry;
	struct kobject___441 *parent;
	struct kset___440 *kset;
	struct kobj_type___440 *ktype;
	struct kernfs_node___448 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___421 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___421 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___421;

struct bus_type___421;

struct device_driver___421;

struct dev_pm_domain___421;

struct dma_map_ops___193;

struct fwnode_handle___341;

struct class___421;

struct attribute_group___418;

struct device___421 {
	struct device___421 *parent;
	struct device_private *p;
	struct kobject___441 kobj;
	const char *init_name;
	const struct device_type___421 *type;
	struct mutex mutex;
	struct bus_type___421 *bus;
	struct device_driver___421 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___421 power;
	struct dev_pm_domain___421 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___193 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___341 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___421 *class;
	const struct attribute_group___418 **groups;
	void (*release)(struct device___421 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___453;

struct super_block___453;

struct dentry___453 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___453 *d_parent;
	struct qstr d_name;
	struct inode___453 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___453 *d_op;
	struct super_block___453 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___453;

struct block_device___453;

struct inode___453 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___453 *i_op;
	struct super_block___453 *i_sb;
	struct address_space___453 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___455 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___243 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___453 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___453 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___134 *i_pipe;
		struct block_device___453 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___453 {
	int (*d_revalidate)(struct dentry___453 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___453 *, unsigned int);
	int (*d_hash)(const struct dentry___453 *, struct qstr *);
	int (*d_compare)(const struct dentry___453 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___453 *);
	int (*d_init)(struct dentry___453 *);
	void (*d_release)(struct dentry___453 *);
	void (*d_prune)(struct dentry___453 *);
	void (*d_iput)(struct dentry___453 *, struct inode___453 *);
	char * (*d_dname)(struct dentry___453 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___454 *);
	int (*d_manage)(const struct path___454 *, bool);
	struct dentry___453 * (*d_real)(struct dentry___453 *, const struct inode___453 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___453;

struct mem_dqinfo___453 {
	struct quota_format_type___453 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___453;

struct quota_info___453 {
	unsigned int flags;
	struct rw_semaphore___455 dqio_sem;
	struct inode___453 *files[3];
	struct mem_dqinfo___453 info[3];
	const struct quota_format_ops___453 *ops[3];
};

struct rcuwait___453 {
	struct task_struct___455 *task;
};

struct percpu_rw_semaphore___453 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___455 rw_sem;
	struct rcuwait___453 writer;
	int readers_block;
};

struct sb_writers___453 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___453 rw_sem[3];
};

struct file_system_type___453;

struct super_operations___453;

struct dquot_operations___453;

struct quotactl_ops___453;

struct super_block___453 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___453 *s_type;
	const struct super_operations___453 *s_op;
	const struct dquot_operations___453 *dq_op;
	const struct quotactl_ops___453 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___453 *s_root;
	struct rw_semaphore___455 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___453 *s_bdev;
	struct backing_dev_info___243 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___453 s_dquot;
	struct sb_writers___453 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___453 *s_d_op;
	int cleancache_poolid;
	struct shrinker___186 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___318 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___453 {
	struct file___453 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___453 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___453 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___453 *ia_file;
};

struct dquot___453 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___453 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___453 {
	int qf_fmt_id;
	const struct quota_format_ops___453 *qf_ops;
	struct module___379 *qf_owner;
	struct quota_format_type___453 *qf_next;
};

struct quota_format_ops___453 {
	int (*check_quota_file)(struct super_block___453 *, int);
	int (*read_file_info)(struct super_block___453 *, int);
	int (*write_file_info)(struct super_block___453 *, int);
	int (*free_file_info)(struct super_block___453 *, int);
	int (*read_dqblk)(struct dquot___453 *);
	int (*commit_dqblk)(struct dquot___453 *);
	int (*release_dqblk)(struct dquot___453 *);
	int (*get_next_id)(struct super_block___453 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___453 {
	int (*write_dquot)(struct dquot___453 *);
	struct dquot___453 * (*alloc_dquot)(struct super_block___453 *, int);
	void (*destroy_dquot)(struct dquot___453 *);
	int (*acquire_dquot)(struct dquot___453 *);
	int (*release_dquot)(struct dquot___453 *);
	int (*mark_dirty)(struct dquot___453 *);
	int (*write_info)(struct super_block___453 *, int);
	qsize_t * (*get_reserved_space)(struct inode___453 *);
	int (*get_projid)(struct inode___453 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___453 *, qsize_t *);
	int (*get_next_id)(struct super_block___453 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___453 {
	int (*quota_on)(struct super_block___453 *, int, int, const struct path___454 *);
	int (*quota_off)(struct super_block___453 *, int);
	int (*quota_enable)(struct super_block___453 *, unsigned int);
	int (*quota_disable)(struct super_block___453 *, unsigned int);
	int (*quota_sync)(struct super_block___453 *, int);
	int (*set_info)(struct super_block___453 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___453 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___453 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___453 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___453 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___453 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___379 {
	struct kobject___441 kobj;
	struct module___379 *mod;
	struct kobject___441 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___379 {
	struct module___379 *mod;
	struct latch_tree_node node;
};

struct module_layout___379 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___379 mtn;
};

struct module_attribute___379;

struct kernel_param___379;

struct module___379 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___379 mkobj;
	struct module_attribute___379 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___441 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___379 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___379 core_layout;
	struct module_layout___379 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide14;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___206;

struct swap_info_struct___95;

struct address_space_operations___453 {
	int (*writepage)(struct page___454 *, struct writeback_control___206 *);
	int (*readpage)(struct file___453 *, struct page___454 *);
	int (*writepages)(struct address_space___453 *, struct writeback_control___206 *);
	int (*set_page_dirty)(struct page___454 *);
	int (*readpages)(struct file___453 *, struct address_space___453 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___453 *, struct address_space___453 *, loff_t, unsigned int, unsigned int, struct page___454 **, void **);
	int (*write_end)(struct file___453 *, struct address_space___453 *, loff_t, unsigned int, unsigned int, struct page___454 *, void *);
	sector_t (*bmap)(struct address_space___453 *, sector_t);
	void (*invalidatepage)(struct page___454 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___454 *, gfp_t);
	void (*freepage)(struct page___454 *);
	ssize_t (*direct_IO)(struct kiocb___453 *, struct iov_iter___220 *);
	int (*migratepage)(struct address_space___453 *, struct page___454 *, struct page___454 *, enum migrate_mode);
	bool (*isolate_page)(struct page___454 *, isolate_mode_t);
	void (*putback_page)(struct page___454 *);
	int (*launder_page)(struct page___454 *);
	int (*is_partially_uptodate)(struct page___454 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___454 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___453 *, struct page___454 *);
	int (*swap_activate)(struct swap_info_struct___95 *, struct file___453 *, sector_t *);
	void (*swap_deactivate)(struct file___453 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___206 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___243 *wb;
	struct inode___453 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___245;

struct iov_iter___220 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___245 *bvec;
		struct pipe_inode_info___134 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct swap_info_struct___95 {
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	struct plist_node avail_lists[8];
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	struct percpu_cluster *percpu_cluster;
	struct swap_extent *curr_swap_extent;
	struct swap_extent first_swap_extent;
	struct block_device___453 *bdev;
	struct file___453 *swap_file;
	unsigned int old_block_size;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___453 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___453 *bd_inode;
	struct super_block___453 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___453 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___243 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___453 {
	struct dentry___453 * (*lookup)(struct inode___453 *, struct dentry___453 *, unsigned int);
	const char * (*get_link)(struct dentry___453 *, struct inode___453 *, struct delayed_call *);
	int (*permission)(struct inode___453 *, int);
	struct posix_acl * (*get_acl)(struct inode___453 *, int);
	int (*readlink)(struct dentry___453 *, char *, int);
	int (*create)(struct inode___453 *, struct dentry___453 *, umode_t, bool);
	int (*link)(struct dentry___453 *, struct inode___453 *, struct dentry___453 *);
	int (*unlink)(struct inode___453 *, struct dentry___453 *);
	int (*symlink)(struct inode___453 *, struct dentry___453 *, const char *);
	int (*mkdir)(struct inode___453 *, struct dentry___453 *, umode_t);
	int (*rmdir)(struct inode___453 *, struct dentry___453 *);
	int (*mknod)(struct inode___453 *, struct dentry___453 *, umode_t, dev_t);
	int (*rename)(struct inode___453 *, struct dentry___453 *, struct inode___453 *, struct dentry___453 *, unsigned int);
	int (*setattr)(struct dentry___453 *, struct iattr___453 *);
	int (*getattr)(const struct path___454 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___453 *, char *, size_t);
	int (*fiemap)(struct inode___453 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___453 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___453 *, struct dentry___453 *, struct file___453 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___453 *, struct dentry___453 *, umode_t);
	int (*set_acl)(struct inode___453 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___453 {
	void (*fl_copy_lock)(struct file_lock___453 *, struct file_lock___453 *);
	void (*fl_release_private)(struct file_lock___453 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___453;

struct file_lock___453 {
	struct file_lock___453 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___453 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___453 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___453 *fl_ops;
	const struct lock_manager_operations___453 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___453 {
	int (*lm_compare_owner)(struct file_lock___453 *, struct file_lock___453 *);
	long unsigned int (*lm_owner_key)(struct file_lock___453 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___453 *);
	int (*lm_grant)(struct file_lock___453 *, int);
	bool (*lm_break)(struct file_lock___453 *);
	int (*lm_change)(struct file_lock___453 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___453 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___453 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___453 *fa_next;
	struct file___453 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___453 {
	const char *name;
	int fs_flags;
	struct dentry___453 * (*mount)(struct file_system_type___453 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___453 *);
	struct module___379 *owner;
	struct file_system_type___453 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___453 {
	struct inode___453 * (*alloc_inode)(struct super_block___453 *);
	void (*destroy_inode)(struct inode___453 *);
	void (*dirty_inode)(struct inode___453 *, int);
	int (*write_inode)(struct inode___453 *, struct writeback_control___206 *);
	int (*drop_inode)(struct inode___453 *);
	void (*evict_inode)(struct inode___453 *);
	void (*put_super)(struct super_block___453 *);
	int (*sync_fs)(struct super_block___453 *, int);
	int (*freeze_super)(struct super_block___453 *);
	int (*freeze_fs)(struct super_block___453 *);
	int (*thaw_super)(struct super_block___453 *);
	int (*unfreeze_fs)(struct super_block___453 *);
	int (*statfs)(struct dentry___453 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___453 *, int *, char *);
	void (*umount_begin)(struct super_block___453 *);
	int (*show_options)(struct seq_file___392 *, struct dentry___453 *);
	int (*show_devname)(struct seq_file___392 *, struct dentry___453 *);
	int (*show_path)(struct seq_file___392 *, struct dentry___453 *);
	int (*show_stats)(struct seq_file___392 *, struct dentry___453 *);
	ssize_t (*quota_read)(struct super_block___453 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___453 *, int, const char *, size_t, loff_t);
	struct dquot___453 ** (*get_dquots)(struct inode___453 *);
	int (*bdev_try_to_free_page)(struct super_block___453 *, struct page___454 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___453 *, struct shrink_control___186 *);
	long int (*free_cached_objects)(struct super_block___453 *, struct shrink_control___186 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___302)(struct file___453 *, wait_queue_head_t *, struct poll_table_struct___292 *);

struct poll_table_struct___292 {
	poll_queue_proc___302 _qproc;
	__poll_t _key;
};

struct seq_operations___392;

struct seq_file___392 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___392 *op;
	int poll_event;
	const struct file___453 *file;
	void *private;
};

typedef void bio_end_io_t___243(struct bio___243 *);

struct bio_vec___245 {
	struct page___454 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___243;

struct bio_set___243;

struct bio___243 {
	struct bio___243 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___243 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___243 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___245 *bi_io_vec;
	struct bio_set___243 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___245 bi_inline_vecs[0];
};

struct kobj_attribute___431 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___441 *, struct kobj_attribute___431 *, char *);
	ssize_t (*store)(struct kobject___441 *, struct kobj_attribute___431 *, const char *, size_t);
};

typedef void compound_page_dtor___441(struct page___454 *);

struct kernfs_root___447;

struct kernfs_elem_dir___447 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___447 *root;
};

struct kernfs_syscall_ops___447;

struct kernfs_root___447 {
	struct kernfs_node___448 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___447 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___447 {
	struct kernfs_node___448 *target_kn;
};

struct kernfs_ops___447;

struct kernfs_elem_attr___447 {
	const struct kernfs_ops___447 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___448 *notify_next;
};

struct kernfs_node___448 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___448 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___447 dir;
		struct kernfs_elem_symlink___447 symlink;
		struct kernfs_elem_attr___447 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___447;

struct kernfs_ops___447 {
	int (*open)(struct kernfs_open_file___447 *);
	void (*release)(struct kernfs_open_file___447 *);
	int (*seq_show)(struct seq_file___392 *, void *);
	void * (*seq_start)(struct seq_file___392 *, loff_t *);
	void * (*seq_next)(struct seq_file___392 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___392 *, void *);
	ssize_t (*read)(struct kernfs_open_file___447 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___447 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___447 *, struct vm_area_struct___454 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___447 *, struct poll_table_struct___292 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide13;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___447 {
	int (*remount_fs)(struct kernfs_root___447 *, int *, char *);
	int (*show_options)(struct seq_file___392 *, struct kernfs_root___447 *);
	int (*mkdir)(struct kernfs_node___448 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___448 *);
	int (*rename)(struct kernfs_node___448 *, struct kernfs_node___448 *, const char *);
	int (*show_path)(struct seq_file___392 *, struct kernfs_node___448 *, struct kernfs_root___447 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___447 {
	struct kernfs_node___448 *kn;
	struct file___453 *file;
	struct seq_file___392 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___441 *vm_ops;
};

struct sock___78;

struct kobj_ns_type_operations___78 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___78 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___109 *net;
} possible_net_t___100;

struct proto___78;

struct sock_common___78 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___78 *skc_prot;
	possible_net_t___100 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___78 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___99;

struct sk_buff_head___98 {
	struct sk_buff___99 *next;
	struct sk_buff___99 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___78;

struct socket_wq___79;

struct dst_entry___78;

struct socket___80;

struct net_device___98;

struct sock___78 {
	struct sock_common___78 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___98 sk_error_queue;
	struct sk_buff_head___98 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___99 *head;
		struct sk_buff___99 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___78 *sk_filter;
	union {
		struct socket_wq___79 *sk_wq;
		struct socket_wq___79 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___78 *sk_rx_dst;
	struct dst_entry___78 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___99 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___98 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___454 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___78 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___252 *sk_peer_pid;
	const struct cred___421 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___80 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___186 *sk_memcg;
	void (*sk_state_change)(struct sock___78 *);
	void (*sk_data_ready)(struct sock___78 *);
	void (*sk_write_space)(struct sock___78 *);
	void (*sk_error_report)(struct sock___78 *);
	int (*sk_backlog_rcv)(struct sock___78 *, struct sk_buff___99 *);
	struct sk_buff___99 * (*sk_validate_xmit_skb)(struct sock___78 *, struct net_device___98 *, struct sk_buff___99 *);
	void (*sk_destruct)(struct sock___78 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct bin_attribute___417;

struct attribute_group___418 {
	const char *name;
	umode_t (*is_visible)(struct kobject___441 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___441 *, struct bin_attribute___417 *, int);
	struct attribute **attrs;
	struct bin_attribute___417 **bin_attrs;
};

struct bin_attribute___417 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___453 *, struct kobject___441 *, struct bin_attribute___417 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___453 *, struct kobject___441 *, struct bin_attribute___417 *, char *, loff_t, size_t);
	int (*mmap)(struct file___453 *, struct kobject___441 *, struct bin_attribute___417 *, struct vm_area_struct___454 *);
};

struct sysfs_ops___440 {
	ssize_t (*show)(struct kobject___441 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___441 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___440;

struct kset___440 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___441 kobj;
	const struct kset_uevent_ops___440 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___440 {
	void (*release)(struct kobject___441 *);
	const struct sysfs_ops___440 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___78 * (*child_ns_type)(struct kobject___441 *);
	const void * (*namespace)(struct kobject___441 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___440 {
	int (* const filter)(struct kset___440 *, struct kobject___441 *);
	const char * (* const name)(struct kset___440 *, struct kobject___441 *);
	int (* const uevent)(struct kset___440 *, struct kobject___441 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___379 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___379 *);
	int (*get)(char *, const struct kernel_param___379 *);
	void (*free)(void *);
};

struct kparam_array___379;

struct kernel_param___379 {
	const char *name;
	struct module___379 *mod;
	const struct kernel_param_ops___379 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___379 *arr;
	};
};

struct kparam_array___379 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___379 *ops;
	void *elem;
};

struct module_attribute___379 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___379 *, struct module_kobject___379 *, char *);
	ssize_t (*store)(struct module_attribute___379 *, struct module_kobject___379 *, const char *, size_t);
	void (*setup)(struct module___379 *, const char *);
	int (*test)(struct module___379 *);
	void (*free)(struct module___379 *);
};

struct crypto_async_request___39;

typedef void (*crypto_completion_t___39)(struct crypto_async_request___39 *, int);

struct crypto_tfm___39;

struct crypto_async_request___39 {
	struct list_head list;
	crypto_completion_t___39 complete;
	void *data;
	struct crypto_tfm___39 *tfm;
	u32 flags;
};

struct crypto_ablkcipher___39;

struct ablkcipher_request___39;

struct ablkcipher_tfm___39 {
	int (*setkey)(struct crypto_ablkcipher___39 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___39 *);
	int (*decrypt)(struct ablkcipher_request___39 *);
	struct crypto_ablkcipher___39 *base;
	unsigned int ivsize;
	unsigned int reqsize;
};

struct blkcipher_desc___39;

struct blkcipher_tfm___39 {
	void *iv;
	int (*setkey)(struct crypto_tfm___39 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___39 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___39 *, struct scatterlist *, struct scatterlist *, unsigned int);
};

struct cipher_tfm___39 {
	int (*cit_setkey)(struct crypto_tfm___39 *, const u8 *, unsigned int);
	void (*cit_encrypt_one)(struct crypto_tfm___39 *, u8 *, const u8 *);
	void (*cit_decrypt_one)(struct crypto_tfm___39 *, u8 *, const u8 *);
};

struct compress_tfm___39 {
	int (*cot_compress)(struct crypto_tfm___39 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*cot_decompress)(struct crypto_tfm___39 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___39;

struct crypto_tfm___39 {
	u32 crt_flags;
	union {
		struct ablkcipher_tfm___39 ablkcipher;
		struct blkcipher_tfm___39 blkcipher;
		struct cipher_tfm___39 cipher;
		struct compress_tfm___39 compress;
	} crt_u;
	void (*exit)(struct crypto_tfm___39 *);
	struct crypto_alg___39 *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct ablkcipher_request___39 {
	struct crypto_async_request___39 base;
	unsigned int nbytes;
	void *info;
	struct scatterlist *src;
	struct scatterlist *dst;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_blkcipher___39;

struct blkcipher_desc___39 {
	struct crypto_blkcipher___39 *tfm;
	void *info;
	u32 flags;
};

struct crypto_blkcipher___39 {
	struct crypto_tfm___39 base;
};

struct ablkcipher_alg___39 {
	int (*setkey)(struct crypto_ablkcipher___39 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___39 *);
	int (*decrypt)(struct ablkcipher_request___39 *);
	int (*givencrypt)(struct skcipher_givcrypt_request *);
	int (*givdecrypt)(struct skcipher_givcrypt_request *);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct crypto_ablkcipher___39 {
	struct crypto_tfm___39 base;
};

struct blkcipher_alg___39 {
	int (*setkey)(struct crypto_tfm___39 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___39 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___39 *, struct scatterlist *, struct scatterlist *, unsigned int);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct cipher_alg___39 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___39 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___39 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___39 *, u8 *, const u8 *);
};

struct compress_alg___39 {
	int (*coa_compress)(struct crypto_tfm___39 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___39 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___39 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type *cra_type;
	union {
		struct ablkcipher_alg___39 ablkcipher;
		struct blkcipher_alg___39 blkcipher;
		struct cipher_alg___39 cipher;
		struct compress_alg___39 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___39 *);
	void (*cra_exit)(struct crypto_tfm___39 *);
	void (*cra_destroy)(struct crypto_alg___39 *);
	struct module___379 *cra_module;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct crypto_cipher___23 {
	struct crypto_tfm___39 base;
};

struct msghdr___81 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___220 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___453 *msg_iocb;
};

struct socket_wq___79 {
	wait_queue_head_t wait;
	struct fasync_struct___453 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___79;

struct socket___80 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___79 *wq;
	struct file___453 *file;
	struct sock___78 *sk;
	const struct proto_ops___79 *ops;
};

typedef int (*sk_read_actor_t___78)(read_descriptor_t *, struct sk_buff___99 *, unsigned int, size_t);

struct proto_ops___79 {
	int family;
	struct module___379 *owner;
	int (*release)(struct socket___80 *);
	int (*bind)(struct socket___80 *, struct sockaddr *, int);
	int (*connect)(struct socket___80 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___80 *, struct socket___80 *);
	int (*accept)(struct socket___80 *, struct socket___80 *, int, bool);
	int (*getname)(struct socket___80 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___453 *, struct socket___80 *, struct poll_table_struct___292 *);
	int (*ioctl)(struct socket___80 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___80 *, int);
	int (*shutdown)(struct socket___80 *, int);
	int (*setsockopt)(struct socket___80 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___80 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___80 *, struct msghdr___81 *, size_t);
	int (*recvmsg)(struct socket___80 *, struct msghdr___81 *, size_t, int);
	int (*mmap)(struct file___453 *, struct socket___80 *, struct vm_area_struct___454 *);
	ssize_t (*sendpage)(struct socket___80 *, struct page___454 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___80 *, loff_t *, struct pipe_inode_info___134 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___78 *, int);
	int (*peek_len)(struct socket___80 *);
	int (*read_sock)(struct sock___78 *, read_descriptor_t *, sk_read_actor_t___78);
	int (*sendpage_locked)(struct sock___78 *, struct page___454 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___78 *, struct msghdr___81 *, size_t);
	int (*set_rcvlowat)(struct sock___78 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct nf_bridge_info___98;

struct sk_buff___99 {
	union {
		struct {
			struct sk_buff___99 *next;
			struct sk_buff___99 *prev;
			union {
				struct net_device___98 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___78 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___99 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___98 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___98;

struct netns_frags___98 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___98 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ip_ra_chain___44;

struct fib_rules_ops___78;

struct tcp_congestion_ops___20;

struct tcp_fastopen_context___20;

struct fib_notifier_ops___79;

struct netns_ipv4___98 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___44 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___78 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___78 *fibnl;
	struct sock___78 **icmp_sk;
	struct sock___78 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___78 **tcp_sk;
	struct netns_frags___98 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops___20 *tcp_congestion_control;
	struct tcp_fastopen_context___20 *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___78 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___79 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___79 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___78;

struct dst_ops___109 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___109 *);
	struct dst_entry___78 * (*check)(struct dst_entry___78 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___78 *);
	unsigned int (*mtu)(const struct dst_entry___78 *);
	u32 * (*cow_metrics)(struct dst_entry___78 *, long unsigned int);
	void (*destroy)(struct dst_entry___78 *);
	void (*ifdown)(struct dst_entry___78 *, struct net_device___98 *, int);
	struct dst_entry___78 * (*negative_advice)(struct dst_entry___78 *);
	void (*link_failure)(struct sk_buff___99 *);
	void (*update_pmtu)(struct dst_entry___78 *, struct sock___78 *, struct sk_buff___99 *, u32);
	void (*redirect)(struct dst_entry___78 *, struct sock___78 *, struct sk_buff___99 *);
	int (*local_out)(struct net___109 *, struct sock___78 *, struct sk_buff___99 *);
	struct neighbour___78 * (*neigh_lookup)(const struct dst_entry___78 *, struct sk_buff___99 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___78 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___109 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___98 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___109 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___78 *fib6_rules_ops;
	struct sock___78 **icmp_sk;
	struct sock___78 *ndisc_sk;
	struct sock___78 *tcp_sk;
	struct sock___78 *igmp_sk;
	struct sock___78 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___78 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___79 *notifier_ops;
	struct fib_notifier_ops___79 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___79 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___78 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___98 {
	struct netns_frags___98 frags;
};

struct netns_xfrm___109 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___78 *nlsk;
	struct sock___78 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___109 xfrm4_dst_ops;
	struct dst_ops___109 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___88;

struct net___109 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___318 *user_ns;
	struct ucounts___318 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___29 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___78 *rtnl;
	struct sock___78 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___98 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___98 ipv4;
	struct netns_ipv6___109 ipv6;
	struct netns_sctp___79 sctp;
	struct netns_nf___15 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___98 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___78 *nfnl;
	struct sock___78 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___109 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___78 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___88 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___421 {
	int (*prepare)(struct device___421 *);
	void (*complete)(struct device___421 *);
	int (*suspend)(struct device___421 *);
	int (*resume)(struct device___421 *);
	int (*freeze)(struct device___421 *);
	int (*thaw)(struct device___421 *);
	int (*poweroff)(struct device___421 *);
	int (*restore)(struct device___421 *);
	int (*suspend_late)(struct device___421 *);
	int (*resume_early)(struct device___421 *);
	int (*freeze_late)(struct device___421 *);
	int (*thaw_early)(struct device___421 *);
	int (*poweroff_late)(struct device___421 *);
	int (*restore_early)(struct device___421 *);
	int (*suspend_noirq)(struct device___421 *);
	int (*resume_noirq)(struct device___421 *);
	int (*freeze_noirq)(struct device___421 *);
	int (*thaw_noirq)(struct device___421 *);
	int (*poweroff_noirq)(struct device___421 *);
	int (*restore_noirq)(struct device___421 *);
	int (*runtime_suspend)(struct device___421 *);
	int (*runtime_resume)(struct device___421 *);
	int (*runtime_idle)(struct device___421 *);
};

struct dev_pm_domain___421 {
	struct dev_pm_ops___421 ops;
	void (*detach)(struct device___421 *, bool);
	int (*activate)(struct device___421 *);
	void (*sync)(struct device___421 *);
	void (*dismiss)(struct device___421 *);
};

struct bus_type___421 {
	const char *name;
	const char *dev_name;
	struct device___421 *dev_root;
	const struct attribute_group___418 **bus_groups;
	const struct attribute_group___418 **dev_groups;
	const struct attribute_group___418 **drv_groups;
	int (*match)(struct device___421 *, struct device_driver___421 *);
	int (*uevent)(struct device___421 *, struct kobj_uevent_env *);
	int (*probe)(struct device___421 *);
	int (*remove)(struct device___421 *);
	void (*shutdown)(struct device___421 *);
	int (*online)(struct device___421 *);
	int (*offline)(struct device___421 *);
	int (*suspend)(struct device___421 *, pm_message_t);
	int (*resume)(struct device___421 *);
	int (*num_vf)(struct device___421 *);
	int (*dma_configure)(struct device___421 *);
	const struct dev_pm_ops___421 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___421 {
	const char *name;
	struct bus_type___421 *bus;
	struct module___379 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___421 *);
	int (*remove)(struct device___421 *);
	void (*shutdown)(struct device___421 *);
	int (*suspend)(struct device___421 *, pm_message_t);
	int (*resume)(struct device___421 *);
	const struct attribute_group___418 **groups;
	const struct dev_pm_ops___421 *pm;
	void (*coredump)(struct device___421 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___421 {
	const char *name;
	const struct attribute_group___418 **groups;
	int (*uevent)(struct device___421 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___421 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___421 *);
	const struct dev_pm_ops___421 *pm;
};

struct class___421 {
	const char *name;
	struct module___379 *owner;
	const struct attribute_group___418 **class_groups;
	const struct attribute_group___418 **dev_groups;
	struct kobject___441 *dev_kobj;
	int (*dev_uevent)(struct device___421 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___421 *, umode_t *);
	void (*class_release)(struct class___421 *);
	void (*dev_release)(struct device___421 *);
	int (*shutdown_pre)(struct device___421 *);
	const struct kobj_ns_type_operations___78 *ns_type;
	const void * (*namespace)(struct device___421 *);
	const struct dev_pm_ops___421 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___193 {
	void * (*alloc)(struct device___421 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___421 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___421 *, struct vm_area_struct___454 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___421 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___421 *, struct page___454 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___421 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___421 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___421 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___421 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___421 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___421 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___421 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___421 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___421 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___421 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___421 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___421 *, u64);
	u64 (*get_required_mask)(struct device___421 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___341;

struct fwnode_handle___341 {
	struct fwnode_handle___341 *secondary;
	const struct fwnode_operations___341 *ops;
};

struct fwnode_reference_args___341;

struct fwnode_endpoint___341;

struct fwnode_operations___341 {
	struct fwnode_handle___341 * (*get)(struct fwnode_handle___341 *);
	void (*put)(struct fwnode_handle___341 *);
	bool (*device_is_available)(const struct fwnode_handle___341 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___341 *, const struct device___421 *);
	bool (*property_present)(const struct fwnode_handle___341 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___341 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___341 *, const char *, const char **, size_t);
	struct fwnode_handle___341 * (*get_parent)(const struct fwnode_handle___341 *);
	struct fwnode_handle___341 * (*get_next_child_node)(const struct fwnode_handle___341 *, struct fwnode_handle___341 *);
	struct fwnode_handle___341 * (*get_named_child_node)(const struct fwnode_handle___341 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___341 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___341 *);
	struct fwnode_handle___341 * (*graph_get_next_endpoint)(const struct fwnode_handle___341 *, struct fwnode_handle___341 *);
	struct fwnode_handle___341 * (*graph_get_remote_endpoint)(const struct fwnode_handle___341 *);
	struct fwnode_handle___341 * (*graph_get_port_parent)(struct fwnode_handle___341 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___341 *, struct fwnode_endpoint___341 *);
};

struct fwnode_endpoint___341 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___341 *local_fwnode;
};

struct fwnode_reference_args___341 {
	struct fwnode_handle___341 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___134;

struct pipe_buffer___134 {
	struct page___454 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___134 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___134 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___134 *, struct pipe_buffer___134 *);
	void (*release)(struct pipe_inode_info___134 *, struct pipe_buffer___134 *);
	int (*steal)(struct pipe_inode_info___134 *, struct pipe_buffer___134 *);
	union {
		bool (*get)(struct pipe_inode_info___134 *, struct pipe_buffer___134 *);
		struct {
			void (*get)(struct pipe_inode_info___134 *, struct pipe_buffer___134 *);
		} __UNIQUE_ID_rh_kabi_hide21;
		union {		};
	};
};

struct nf_bridge_info___98 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___98 = 0,
		BRNF_PROTO_8021Q___98 = 1,
		BRNF_PROTO_PPPOE___98 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___98 *physindev;
	struct net_device___98 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___98(struct sk_buff___99 **);

struct net_device_ops___98;

struct ethtool_ops___98;

struct l3mdev_ops___78;

struct ndisc_ops___49;

struct xfrmdev_ops___98;

struct tlsdev_ops___98;

struct header_ops___98;

struct in_device___13;

struct inet6_dev___49;

struct netdev_rx_queue___98;

struct mini_Qdisc___90;

struct netdev_queue___98;

struct Qdisc___90;

struct rtnl_link_ops___90;

struct dcbnl_rtnl_ops___98;

struct net_device___98 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___98 *netdev_ops;
	const struct ethtool_ops___98 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___78 *l3mdev_ops;
	const struct ndisc_ops___49 *ndisc_ops;
	const struct xfrmdev_ops___98 *xfrmdev_ops;
	const struct tlsdev_ops___98 *tlsdev_ops;
	const struct header_ops___98 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___440 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device___13 *ip_ptr;
	struct inet6_dev___49 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___98 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___88 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___98 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___90 *miniq_ingress;
	struct netdev_queue___98 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___98 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___90 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___90 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___98 = 0,
		NETREG_REGISTERED___98 = 1,
		NETREG_UNREGISTERING___98 = 2,
		NETREG_UNREGISTERED___98 = 3,
		NETREG_RELEASED___98 = 4,
		NETREG_DUMMY___98 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___98 = 0,
		RTNL_LINK_INITIALIZING___98 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___98 *);
	struct netpoll_info *npinfo;
	possible_net_t___100 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___421 dev;
	const struct attribute_group___418 *sysfs_groups[4];
	const struct attribute_group___418 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___90 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___98 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide35;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct ip_mc_list___5 {
	struct in_device___13 *interface;
	__be32 multiaddr;
	unsigned int sfmode;
	struct ip_sf_list *sources;
	struct ip_sf_list *tomb;
	long unsigned int sfcount[2];
	union {
		struct ip_mc_list___5 *next;
		struct ip_mc_list___5 *next_rcu;
	};
	struct ip_mc_list___5 *next_hash;
	struct timer_list timer;
	int users;
	refcount_t refcnt;
	spinlock_t lock;
	char tm_running;
	char reporter;
	char unsolicit_count;
	char loaded;
	unsigned char gsquery;
	unsigned char crcount;
	struct callback_head rcu;
};

struct in_ifaddr___13;

struct neigh_parms___78;

struct in_device___13 {
	struct net_device___98 *dev;
	refcount_t refcnt;
	int dead;
	struct in_ifaddr___13 *ifa_list;
	struct ip_mc_list___5 *mc_list;
	struct ip_mc_list___5 **mc_hash;
	int mc_count;
	spinlock_t mc_tomb_lock;
	struct ip_mc_list___5 *mc_tomb;
	long unsigned int mr_v1_seen;
	long unsigned int mr_v2_seen;
	long unsigned int mr_maxdelay;
	long unsigned int mr_qi;
	long unsigned int mr_qri;
	unsigned char mr_qrv;
	unsigned char mr_gq_running;
	unsigned char mr_ifc_count;
	struct timer_list mr_gq_timer;
	struct timer_list mr_ifc_timer;
	struct neigh_parms___78 *arp_parms;
	struct ipv4_devconf cnf;
	struct callback_head callback_head;
};

struct ethtool_ops___98 {
	int (*get_settings)(struct net_device___98 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___98 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___98 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___98 *);
	void (*get_regs)(struct net_device___98 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___98 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___98 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___98 *);
	void (*set_msglevel)(struct net_device___98 *, u32);
	int (*nway_reset)(struct net_device___98 *);
	u32 (*get_link)(struct net_device___98 *);
	int (*get_eeprom_len)(struct net_device___98 *);
	int (*get_eeprom)(struct net_device___98 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___98 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___98 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___98 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___98 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___98 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___98 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___98 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___98 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___98 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___98 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___98 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___98 *);
	void (*complete)(struct net_device___98 *);
	u32 (*get_priv_flags)(struct net_device___98 *);
	int (*set_priv_flags)(struct net_device___98 *, u32);
	int (*get_sset_count)(struct net_device___98 *, int);
	int (*get_rxnfc)(struct net_device___98 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___98 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___98 *, struct ethtool_flash *);
	int (*reset)(struct net_device___98 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___98 *);
	u32 (*get_rxfh_indir_size)(struct net_device___98 *);
	int (*get_rxfh)(struct net_device___98 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___98 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___98 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___98 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___98 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___98 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___98 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___98 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___98 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___98 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___98 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___98 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___98 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___98 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___98 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___98 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___98 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___98 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___98 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___98 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___98 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___98 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	int (*get_fecparam)(struct net_device___98 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___98 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___98 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___98 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___98 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___98;

struct inet_frags___98 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___98 *, const void *);
	void (*destructor)(struct inet_frag_queue___98 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___98 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___99 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___99 *fragments_tail;
	struct sk_buff___99 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___98 *net;
	struct callback_head rcu;
};

struct ip_ra_chain___44 {
	struct ip_ra_chain___44 *next;
	struct sock___78 *sk;
	union {
		void (*destructor)(struct sock___78 *);
		struct sock___78 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___78;

struct fib_lookup_arg___78;

struct fib_rules_ops___78 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___78 *, struct flowi *, int, struct fib_lookup_arg___78 *);
	bool (*suppress)(struct fib_rule___78 *, struct fib_lookup_arg___78 *);
	int (*match)(struct fib_rule___78 *, struct flowi *, int);
	int (*configure)(struct fib_rule___78 *, struct sk_buff___99 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___78 *);
	int (*compare)(struct fib_rule___78 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___78 *, struct sk_buff___99 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___78 *);
	void (*flush_cache)(struct fib_rules_ops___78 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___379 *owner;
	struct net___109 *fro_net;
	struct callback_head rcu;
};

struct tcp_congestion_ops___20 {
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___78 *);
	void (*release)(struct sock___78 *);
	u32 (*ssthresh)(struct sock___78 *);
	void (*cong_avoid)(struct sock___78 *, u32, u32);
	void (*set_state)(struct sock___78 *, u8);
	void (*cwnd_event)(struct sock___78 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___78 *, u32);
	u32 (*undo_cwnd)(struct sock___78 *);
	void (*pkts_acked)(struct sock___78 *, const struct ack_sample *);
	u32 (*min_tso_segs)(struct sock___78 *);
	u32 (*sndbuf_expand)(struct sock___78 *);
	void (*cong_control)(struct sock___78 *, const struct rate_sample *);
	size_t (*get_info)(struct sock___78 *, u32, int *, union tcp_cc_info *);
	char name[16];
	struct module___379 *owner;
};

struct tcp_fastopen_context___20 {
	struct crypto_cipher___23 *tfm;
	__u8 key[16];
	struct callback_head rcu;
};

struct fib_notifier_ops___79 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___109 *);
	int (*fib_dump)(struct net___109 *, struct notifier_block *);
	struct module___379 *owner;
	struct callback_head rcu;
};

struct dst_entry___78 {
	struct net_device___98 *dev;
	struct dst_ops___109 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___99 *);
	int (*output)(struct net___109 *, struct sock___78 *, struct sk_buff___99 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___78;

struct neigh_ops___78;

struct neighbour___78 {
	struct neighbour___78 *next;
	struct neigh_table___78 *tbl;
	struct neigh_parms___78 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___98 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___78 *, struct sk_buff___99 *);
	const struct neigh_ops___78 *ops;
	struct callback_head rcu;
	struct net_device___98 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct ucounts___318 {
	struct hlist_node node;
	struct user_namespace___318 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_prog_aux___91;

struct bpf_prog___88 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___91 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

typedef int (*key_restrict_link_func_t___422)(struct key___421 *, const struct key_type *, const union key_payload *, struct key___421 *);

struct key_restriction___421;

struct key___421 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___455 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___421 *restrict_link;
};

struct key_restriction___421 {
	key_restrict_link_func_t___422 check;
	struct key___421 *key;
	struct key_type *keytype;
};

struct seq_operations___392 {
	void * (*start)(struct seq_file___392 *, loff_t *);
	void (*stop)(struct seq_file___392 *, void *);
	void * (*next)(struct seq_file___392 *, void *, loff_t *);
	int (*show)(struct seq_file___392 *, void *);
};

struct pernet_operations___99 {
	struct list_head list;
	int (*init)(struct net___109 *);
	void (*exit)(struct net___109 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___98 {
	int (*ieee_getets)(struct net_device___98 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___98 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___98 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___98 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___98 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___98 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___98 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___98 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___98 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___98 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___98 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___98 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___98 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___98 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___98 *);
	u8 (*setstate)(struct net_device___98 *, u8);
	void (*getpermhwaddr)(struct net_device___98 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___98 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___98 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___98 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___98 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___98 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___98 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___98 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___98 *, int, u8 *);
	void (*setpfccfg)(struct net_device___98 *, int, u8);
	void (*getpfccfg)(struct net_device___98 *, int, u8 *);
	u8 (*setall)(struct net_device___98 *);
	u8 (*getcap)(struct net_device___98 *, int, u8 *);
	int (*getnumtcs)(struct net_device___98 *, int, u8 *);
	int (*setnumtcs)(struct net_device___98 *, int, u8);
	u8 (*getpfcstate)(struct net_device___98 *);
	void (*setpfcstate)(struct net_device___98 *, u8);
	void (*getbcncfg)(struct net_device___98 *, int, u32 *);
	void (*setbcncfg)(struct net_device___98 *, int, u32);
	void (*getbcnrp)(struct net_device___98 *, int, u8 *);
	void (*setbcnrp)(struct net_device___98 *, int, u8);
	int (*setapp)(struct net_device___98 *, u8, u16, u8);
	int (*getapp)(struct net_device___98 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___98 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___98 *, int, u8);
	u8 (*getdcbx)(struct net_device___98 *);
	u8 (*setdcbx)(struct net_device___98 *, u8);
	int (*peer_getappinfo)(struct net_device___98 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___98 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___98 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___98 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___98 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___98 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___302 {
	refcount_t count;
	struct ns_common___29 ns;
	struct user_namespace___318 *user_ns;
	struct ucounts___318 *ucounts;
	struct css_set___302 *root_cset;
};

struct bpf_map___303;

struct bpf_map_ops___302 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___303 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___303 *, struct file___453 *);
	void (*map_free)(struct bpf_map___303 *);
	int (*map_get_next_key)(struct bpf_map___303 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___303 *);
	void * (*map_lookup_elem)(struct bpf_map___303 *, void *);
	int (*map_update_elem)(struct bpf_map___303 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___303 *, void *);
	int (*map_push_elem)(struct bpf_map___303 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___303 *, void *);
	int (*map_peek_elem)(struct bpf_map___303 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___303 *, struct file___453 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___303 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___303 *, void *, struct seq_file___392 *);
	int (*map_check_btf)(const struct bpf_map___303 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___303 {
	const struct bpf_map_ops___302 *ops;
	struct bpf_map___303 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___421 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___98;

struct bpf_map_dev_ops___98 {
	int (*map_get_next_key)(struct bpf_offloaded_map___98 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___98 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___98 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___98 *, void *);
};

struct bpf_offloaded_map___98 {
	struct bpf_map___303 map;
	struct net_device___98 *netdev;
	const struct bpf_map_dev_ops___98 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___88 {
	int (*test_run)(struct bpf_prog___88 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___88 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___88 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___88 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___88 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___88 *, u32 *);
};

struct bpf_prog_offload_ops___88 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___88 *);
	int (*translate)(struct bpf_prog___88 *);
	void (*destroy)(struct bpf_prog___88 *);
};

struct bpf_prog_offload___88 {
	struct bpf_prog___88 *prog;
	struct net_device___98 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___88 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___91 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___88 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___88 *ops;
	struct bpf_map___303 **used_maps;
	struct bpf_prog___88 *prog;
	struct user_struct___421 *user;
	u64 load_time;
	struct bpf_map___303 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___88 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___88 {
	struct bpf_prog___88 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___88 {
	struct callback_head rcu;
	struct bpf_prog_array_item___88 items[0];
};

struct cgroup_bpf___88 {
	struct bpf_prog_array___88 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___88 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___303;

typedef void (*kthread_work_func_t___303)(struct kthread_work___303 *);

struct kthread_worker___303;

struct kthread_work___303 {
	struct list_head node;
	kthread_work_func_t___303 func;
	struct kthread_worker___303 *worker;
	int canceling;
};

struct kthread_worker___303 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___455 *task;
	struct kthread_work___303 *current_work;
};

struct kthread_delayed_work___302 {
	struct kthread_work___303 work;
	struct timer_list timer;
};

struct psi_group___302 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___303 *poll_kworker;
	struct kthread_delayed_work___302 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___302;

struct cgroup_rstat_cpu___302;

struct cgroup___302 {
	struct cgroup_subsys_state___302 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___448 *kn;
	struct cgroup_file___302 procs_file;
	struct cgroup_file___302 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___302 *subsys[13];
	struct cgroup_root___302 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___302 *dom_cgrp;
	struct cgroup_rstat_cpu___302 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___88 bpf;
	atomic_t congestion_count;
	struct cgroup___302 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___302 psi;
	int ancestor_ids[0];
};

struct cftype___302;

struct cgroup_subsys___302 {
	struct cgroup_subsys_state___302 * (*css_alloc)(struct cgroup_subsys_state___302 *);
	int (*css_online)(struct cgroup_subsys_state___302 *);
	void (*css_offline)(struct cgroup_subsys_state___302 *);
	void (*css_released)(struct cgroup_subsys_state___302 *);
	void (*css_free)(struct cgroup_subsys_state___302 *);
	void (*css_reset)(struct cgroup_subsys_state___302 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___302 *, int);
	int (*css_extra_stat_show)(struct seq_file___392 *, struct cgroup_subsys_state___302 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___455 *);
	void (*cancel_fork)(struct task_struct___455 *);
	void (*fork)(struct task_struct___455 *);
	void (*exit)(struct task_struct___455 *);
	void (*free)(struct task_struct___455 *);
	void (*bind)(struct cgroup_subsys_state___302 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___302 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___302 *dfl_cftypes;
	struct cftype___302 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___302 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___302 *updated_children;
	struct cgroup___302 *updated_next;
};

struct cgroup_root___302 {
	struct kernfs_root___447 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___302 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___302 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___302 *ss;
	struct list_head node;
	struct kernfs_ops___447 *kf_ops;
	int (*open)(struct kernfs_open_file___447 *);
	void (*release)(struct kernfs_open_file___447 *);
	u64 (*read_u64)(struct cgroup_subsys_state___302 *, struct cftype___302 *);
	s64 (*read_s64)(struct cgroup_subsys_state___302 *, struct cftype___302 *);
	int (*seq_show)(struct seq_file___392 *, void *);
	void * (*seq_start)(struct seq_file___392 *, loff_t *);
	void * (*seq_next)(struct seq_file___392 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___392 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___302 *, struct cftype___302 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___302 *, struct cftype___302 *, s64);
	ssize_t (*write)(struct kernfs_open_file___447 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___447 *, struct poll_table_struct___292 *);
};

struct xdp_rxq_info___98 {
	struct net_device___98 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___98 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___98 *dev_rx;
};

struct netlink_callback___100 {
	struct sk_buff___99 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___100 *);
	int (*dump)(struct sk_buff___99 *, struct netlink_callback___100 *);
	int (*done)(struct netlink_callback___100 *);
	void *data;
	struct module___379 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___98 {
	int (*create)(struct sk_buff___99 *, struct net_device___98 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___99 *, unsigned char *);
	int (*cache)(const struct neighbour___78 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___98 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___98 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___98 *, int);
	int poll_owner;
	struct net_device___98 *dev;
	struct sk_buff___99 *gro_list;
	struct sk_buff___99 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___98 {
	struct net_device___98 *dev;
	struct Qdisc___90 *qdisc;
	struct Qdisc___90 *qdisc_sleeping;
	struct kobject___441 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___98 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem___3 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___90 {
	struct sk_buff___99 *head;
	struct sk_buff___99 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___90;

struct Qdisc___90 {
	int (*enqueue)(struct sk_buff___99 *, struct Qdisc___90 *, struct sk_buff___99 **);
	struct sk_buff___99 * (*dequeue)(struct Qdisc___90 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___90 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___98 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___98 gso_skb;
	struct qdisc_skb_head___90 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___90 *next_sched;
	struct sk_buff_head___98 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___98 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___441 kobj;
	struct net_device___98 *dev;
	long: 64;
	struct xdp_rxq_info___98 xdp_rxq;
	union {
		struct xdp_umem___3 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___98)(struct net_device___98 *, struct sk_buff___99 *, struct net_device___98 *);

struct netdev_bpf___98 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___88 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___88 *prog;
			const struct bpf_prog_offload_ops___88 *ops;
		} verifier;
		struct {
			struct bpf_prog___88 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___98 *offmap;
		};
		struct {
			struct xdp_umem___3 *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___98 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___99 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___98 {
	int (*tls_dev_add)(struct net_device___98 *, struct sock___78 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___98 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___98 *, struct sock___78 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___98 {
	int (*ndo_init)(struct net_device___98 *);
	void (*ndo_uninit)(struct net_device___98 *);
	int (*ndo_open)(struct net_device___98 *);
	int (*ndo_stop)(struct net_device___98 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___99 *, struct net_device___98 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___99 *, struct net_device___98 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___98 *, struct sk_buff___99 *, struct net_device___98 *, select_queue_fallback_t___98);
	void (*ndo_change_rx_flags)(struct net_device___98 *, int);
	void (*ndo_set_rx_mode)(struct net_device___98 *);
	int (*ndo_set_mac_address)(struct net_device___98 *, void *);
	int (*ndo_validate_addr)(struct net_device___98 *);
	int (*ndo_do_ioctl)(struct net_device___98 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___98 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___98 *, int);
	int (*ndo_neigh_setup)(struct net_device___98 *, struct neigh_parms___78 *);
	void (*ndo_tx_timeout)(struct net_device___98 *);
	void (*ndo_get_stats64)(struct net_device___98 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___98 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___98 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___98 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___98 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___98 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___98 *);
	int (*ndo_netpoll_setup)(struct net_device___98 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___98 *);
	int (*ndo_set_vf_mac)(struct net_device___98 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___98 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___98 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___98 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___98 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___98 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___98 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___98 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___98 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___98 *, int, struct sk_buff___99 *);
	int (*ndo_set_vf_guid)(struct net_device___98 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___98 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___98 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___98 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___98 *, const struct sk_buff___99 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___98 *, struct net_device___98 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___98 *, struct net_device___98 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___98 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___98 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___98 *, struct neighbour___78 *);
	void (*ndo_neigh_destroy)(struct net_device___98 *, struct neighbour___78 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___98 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___98 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___98 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___99 *, struct netlink_callback___100 *, struct net_device___98 *, struct net_device___98 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___98 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___98 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___99 *, u32, u32, struct net_device___98 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___98 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___98 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___98 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___98 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___98 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___98 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___98 *, struct net_device___98 *);
	void (*ndo_dfwd_del_station)(struct net_device___98 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___98 *);
	int (*ndo_set_tx_maxrate)(struct net_device___98 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___98 *);
	int (*ndo_change_proto_down)(struct net_device___98 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___98 *, struct sk_buff___99 *);
	void (*ndo_set_rx_headroom)(struct net_device___98 *, int);
	int (*ndo_bpf)(struct net_device___98 *, struct netdev_bpf___98 *);
	int (*ndo_xdp_xmit)(struct net_device___98 *, int, struct xdp_frame___98 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___98 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___98 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___78 {
	possible_net_t___100 net;
	struct net_device___98 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___78 *);
	void (*neigh_cleanup)(struct neighbour___78 *);
	struct neigh_table___78 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___78 {
	u32 (*l3mdev_fib_table)(const struct net_device___98 *);
	struct sk_buff___99 * (*l3mdev_l3_rcv)(struct net_device___98 *, struct sk_buff___99 *, u16);
	struct sk_buff___99 * (*l3mdev_l3_out)(struct net_device___98 *, struct sock___78 *, struct sk_buff___99 *, u16);
	struct dst_entry___78 * (*l3mdev_link_scope_lookup)(const struct net_device___98 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct ndisc_ops___49 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___98 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___98 *, struct neighbour___78 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___98 *, u8, struct neighbour___78 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___98 *, struct sk_buff___99 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___109 *, struct net_device___98 *, const struct prefix_info *, struct inet6_dev___49 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___49;

struct inet6_dev___49 {
	struct net_device___98 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___49 *mc_list;
	struct ifmcaddr6___49 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___21 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	u8 rndid[8];
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___78 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
};

struct tcf_proto___90;

struct mini_Qdisc___90 {
	struct tcf_proto___90 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___90 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___98 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___109 *, struct net_device___98 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___98 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___98 *, struct list_head *);
	size_t (*get_size)(const struct net_device___98 *);
	int (*fill_info)(struct sk_buff___99 *, const struct net_device___98 *);
	size_t (*get_xstats_size)(const struct net_device___98 *);
	int (*fill_xstats)(struct sk_buff___99 *, const struct net_device___98 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___98 *, struct net_device___98 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___98 *, const struct net_device___98 *);
	int (*fill_slave_info)(struct sk_buff___99 *, const struct net_device___98 *, const struct net_device___98 *);
	struct net___109 * (*get_link_net)(const struct net_device___98 *);
	size_t (*get_linkxstats_size)(const struct net_device___98 *, int);
	int (*fill_linkxstats)(struct sk_buff___99 *, const struct net_device___98 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct offload_callbacks___15 {
	struct sk_buff___99 * (*gso_segment)(struct sk_buff___99 *, netdev_features_t);
	struct sk_buff___99 ** (*gro_receive)(struct sk_buff___99 **, struct sk_buff___99 *);
	int (*gro_complete)(struct sk_buff___99 *, int);
};

struct softnet_data___98 {
	struct list_head poll_list;
	struct sk_buff_head___98 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___98 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___90 *output_queue;
	struct Qdisc___90 **output_queue_tailp;
	struct sk_buff___99 *completion_queue;
	struct sk_buff_head___98 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___98 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___98 input_pkt_queue;
	struct napi_struct___98 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct in_ifaddr___13 {
	struct hlist_node hash;
	struct in_ifaddr___13 *ifa_next;
	struct in_device___13 *ifa_dev;
	struct callback_head callback_head;
	__be32 ifa_local;
	__be32 ifa_address;
	__be32 ifa_mask;
	__u32 ifa_rt_priority;
	__be32 ifa_broadcast;
	unsigned char ifa_scope;
	unsigned char ifa_prefixlen;
	__u32 ifa_flags;
	char ifa_label[16];
	__u32 ifa_valid_lft;
	__u32 ifa_preferred_lft;
	long unsigned int ifa_cstamp;
	long unsigned int ifa_tstamp;
};

struct bdi_writeback_congested___243 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___243 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___243 {
	struct bio___243 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___245 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___245 bip_inline_vecs[0];
};

struct bio_set___243 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___243 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___186 {
	struct mem_cgroup___186 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___186 {
	struct lruvec___454 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___186 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___186 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct node___229 {
	struct device___421 dev;
};

struct gnet_dump___90 {
	spinlock_t *lock;
	struct sk_buff___99 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___90;

struct Qdisc_ops___90 {
	struct Qdisc_ops___90 *next;
	const struct Qdisc_class_ops___90 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___99 *, struct Qdisc___90 *, struct sk_buff___99 **);
	struct sk_buff___99 * (*dequeue)(struct Qdisc___90 *);
	struct sk_buff___99 * (*peek)(struct Qdisc___90 *);
	int (*init)(struct Qdisc___90 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___90 *);
	void (*destroy)(struct Qdisc___90 *);
	int (*change)(struct Qdisc___90 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___90 *);
	int (*change_tx_queue_len)(struct Qdisc___90 *, unsigned int);
	int (*dump)(struct Qdisc___90 *, struct sk_buff___99 *);
	int (*dump_stats)(struct Qdisc___90 *, struct gnet_dump___90 *);
	void (*ingress_block_set)(struct Qdisc___90 *, u32);
	void (*egress_block_set)(struct Qdisc___90 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___90 *);
	u32 (*egress_block_get)(struct Qdisc___90 *);
	struct module___379 *owner;
};

struct tcf_block___90;

struct Qdisc_class_ops___90 {
	unsigned int flags;
	struct netdev_queue___98 * (*select_queue)(struct Qdisc___90 *, struct tcmsg *);
	int (*graft)(struct Qdisc___90 *, long unsigned int, struct Qdisc___90 *, struct Qdisc___90 **, struct netlink_ext_ack *);
	struct Qdisc___90 * (*leaf)(struct Qdisc___90 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___90 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___90 *, u32);
	int (*change)(struct Qdisc___90 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___90 *, long unsigned int);
	void (*walk)(struct Qdisc___90 *, struct qdisc_walker *);
	struct tcf_block___90 * (*tcf_block)(struct Qdisc___90 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___90 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___90 *, long unsigned int);
	int (*dump)(struct Qdisc___90 *, long unsigned int, struct sk_buff___99 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___90 *, long unsigned int, struct gnet_dump___90 *);
};

struct tcf_chain___90;

struct tcf_block___90 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___109 *net;
	struct Qdisc___90 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___90 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___90;

struct tcf_proto_ops___90;

struct tcf_proto___90 {
	struct tcf_proto___90 *next;
	void *root;
	int (*classify)(struct sk_buff___99 *, const struct tcf_proto___90 *, struct tcf_result___90 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___90 *ops;
	struct tcf_chain___90 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___90 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___90 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___90 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___99 *, const struct tcf_proto___90 *, struct tcf_result___90 *);
	int (*init)(struct tcf_proto___90 *);
	void (*destroy)(struct tcf_proto___90 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___90 *, u32);
	void (*put)(struct tcf_proto___90 *, void *);
	int (*change)(struct net___109 *, struct sk_buff___99 *, struct tcf_proto___90 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___90 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___90 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___90 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___109 *, struct tcf_chain___90 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___109 *, struct tcf_proto___90 *, void *, struct sk_buff___99 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___99 *, struct net___109 *, void *);
	struct module___379 *owner;
	int flags;
};

struct tcf_chain___90 {
	struct mutex filter_chain_lock;
	struct tcf_proto___90 *filter_chain;
	struct list_head list;
	struct tcf_block___90 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___90 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___78 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___88 *prog;
};

struct bpf_redirect_info___88 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___303 *map;
	struct bpf_map___303 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___78;

struct neigh_hash_table___78;

struct neigh_table___78 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___98 *, __u32 *);
	bool (*key_eq)(const struct neighbour___78 *, const void *);
	int (*constructor)(struct neighbour___78 *);
	int (*pconstructor)(struct pneigh_entry___78 *);
	void (*pdestructor)(struct pneigh_entry___78 *);
	void (*proxy_redo)(struct sk_buff___99 *);
	char *id;
	struct neigh_parms___78 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___98 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___78 *nht;
	struct pneigh_entry___78 **phash_buckets;
};

struct neigh_ops___78 {
	int family;
	void (*solicit)(struct neighbour___78 *, struct sk_buff___99 *);
	void (*error_report)(struct neighbour___78 *, struct sk_buff___99 *);
	int (*output)(struct neighbour___78 *, struct sk_buff___99 *);
	int (*connected_output)(struct neighbour___78 *, struct sk_buff___99 *);
};

struct pneigh_entry___78 {
	struct pneigh_entry___78 *next;
	possible_net_t___100 net;
	struct net_device___98 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___78 {
	struct neighbour___78 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___78 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___78 *ctarget;
	struct net___109 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___78 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___78 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___61;

struct timewait_sock_ops___57;

struct proto___78 {
	void (*close)(struct sock___78 *, long int);
	int (*pre_connect)(struct sock___78 *, struct sockaddr *, int);
	int (*connect)(struct sock___78 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___78 *, int);
	struct sock___78 * (*accept)(struct sock___78 *, int, int *, bool);
	int (*ioctl)(struct sock___78 *, int, long unsigned int);
	int (*init)(struct sock___78 *);
	void (*destroy)(struct sock___78 *);
	void (*shutdown)(struct sock___78 *, int);
	int (*setsockopt)(struct sock___78 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___78 *, int, int, char *, int *);
	void (*keepalive)(struct sock___78 *, int);
	int (*sendmsg)(struct sock___78 *, struct msghdr___81 *, size_t);
	int (*recvmsg)(struct sock___78 *, struct msghdr___81 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___78 *, struct page___454 *, int, size_t, int);
	int (*bind)(struct sock___78 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___78 *, struct sk_buff___99 *);
	void (*release_cb)(struct sock___78 *);
	int (*hash)(struct sock___78 *);
	void (*unhash)(struct sock___78 *);
	void (*rehash)(struct sock___78 *);
	int (*get_port)(struct sock___78 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___78 *);
	bool (*stream_memory_read)(const struct sock___78 *);
	void (*enter_memory_pressure)(struct sock___78 *);
	void (*leave_memory_pressure)(struct sock___78 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___61 *rsk_prot;
	struct timewait_sock_ops___57 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___379 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___78 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct request_sock___62;

struct request_sock_ops___61 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___78 *, struct request_sock___62 *);
	void (*send_ack)(const struct sock___78 *, struct sk_buff___99 *, struct request_sock___62 *);
	void (*send_reset)(const struct sock___78 *, struct sk_buff___99 *);
	void (*destructor)(struct request_sock___62 *);
	void (*syn_ack_timeout)(const struct request_sock___62 *);
};

struct timewait_sock_ops___57 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___78 *, struct sock___78 *, void *);
	void (*twsk_destructor)(struct sock___78 *);
};

struct request_sock___62 {
	struct sock_common___78 __req_common;
	struct request_sock___62 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___61 *rsk_ops;
	struct sock___78 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___49 {
	struct in6_addr mca_addr;
	struct inet6_dev___49 *idev;
	struct ifmcaddr6___49 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ip6_ra_chain___49 {
	struct ip6_ra_chain___49 *next;
	struct sock___78 *sk;
	int sel;
	void (*destructor)(struct sock___78 *);
};

struct pingv6_ops___3 {
	int (*ipv6_recv_error)(struct sock___78 *, struct msghdr___81 *, int, int *);
	void (*ip6_datagram_recv_common_ctl)(struct sock___78 *, struct msghdr___81 *, struct sk_buff___99 *);
	void (*ip6_datagram_recv_specific_ctl)(struct sock___78 *, struct msghdr___81 *, struct sk_buff___99 *);
	int (*icmpv6_err_convert)(u8, u8, int *);
	void (*ipv6_icmp_error)(struct sock___78 *, struct sk_buff___99 *, int, __be16, u32, u8 *);
	int (*ipv6_chk_addr)(struct net___109 *, const struct in6_addr *, const struct net_device___98 *, int);
};

struct net_protocol___13 {
	int (*early_demux)(struct sk_buff___99 *);
	int (*early_demux_handler)(struct sk_buff___99 *);
	int (*handler)(struct sk_buff___99 *);
	void (*err_handler)(struct sk_buff___99 *, u32);
	unsigned int no_policy: 1;
	unsigned int netns_ok: 1;
	unsigned int icmp_strict_tag_validation: 1;
};

struct inet6_protocol___13 {
	void (*early_demux)(struct sk_buff___99 *);
	void (*early_demux_handler)(struct sk_buff___99 *);
	int (*handler)(struct sk_buff___99 *);
	void (*err_handler)(struct sk_buff___99 *, struct inet6_skb_parm *, u8, u8, int, __be32);
	unsigned int flags;
};

struct net_offload___13 {
	struct offload_callbacks___15 callbacks;
	unsigned int flags;
};

struct snmp_mib {
	const char *name;
	int entry;
};

struct offload_callbacks___16 {
	struct sk_buff___65 * (*gso_segment)(struct sk_buff___65 *, netdev_features_t);
	struct sk_buff___65 ** (*gro_receive)(struct sk_buff___65 **, struct sk_buff___65 *);
	int (*gro_complete)(struct sk_buff___65 *, int);
};

struct net_protocol___14 {
	int (*early_demux)(struct sk_buff___65 *);
	int (*early_demux_handler)(struct sk_buff___65 *);
	int (*handler)(struct sk_buff___65 *);
	void (*err_handler)(struct sk_buff___65 *, u32);
	unsigned int no_policy: 1;
	unsigned int netns_ok: 1;
	unsigned int icmp_strict_tag_validation: 1;
};

struct inet6_protocol___14 {
	void (*early_demux)(struct sk_buff___65 *);
	void (*early_demux_handler)(struct sk_buff___65 *);
	int (*handler)(struct sk_buff___65 *);
	void (*err_handler)(struct sk_buff___65 *, struct inet6_skb_parm *, u8, u8, int, __be32);
	unsigned int flags;
};

struct net_offload___14 {
	struct offload_callbacks___16 callbacks;
	unsigned int flags;
};

struct rtable___15;

struct fib_nh_exception___6 {
	struct fib_nh_exception___6 *fnhe_next;
	int fnhe_genid;
	__be32 fnhe_daddr;
	u32 fnhe_pmtu;
	bool fnhe_mtu_locked;
	__be32 fnhe_gw;
	long unsigned int fnhe_expires;
	struct rtable___15 *fnhe_rth_input;
	struct rtable___15 *fnhe_rth_output;
	long unsigned int fnhe_stamp;
	struct callback_head rcu;
};

struct rtable___15 {
	struct dst_entry___46 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	__be32 rt_gateway;
	u32 rt_mtu_locked: 1;
	u32 rt_pmtu: 31;
	struct list_head rt_uncached;
	struct uncached_list *rt_uncached_list;
};

struct fnhe_hash_bucket___6 {
	struct fib_nh_exception___6 *chain;
};

struct fib_info___6;

struct fib_nh___6 {
	struct net_device___64 *nh_dev;
	struct hlist_node nh_hash;
	struct fib_info___6 *nh_parent;
	unsigned int nh_flags;
	unsigned char nh_scope;
	int nh_weight;
	atomic_t nh_upper_bound;
	__u32 nh_tclassid;
	int nh_oif;
	__be32 nh_gw;
	__be32 nh_saddr;
	int nh_saddr_genid;
	struct rtable___15 **nh_pcpu_rth_output;
	struct rtable___15 *nh_rth_input;
	struct fnhe_hash_bucket___6 *nh_exceptions;
	struct lwtunnel_state *nh_lwtstate;
};

struct fib_info___6 {
	struct hlist_node fib_hash;
	struct hlist_node fib_lhash;
	struct net___75 *fib_net;
	int fib_treeref;
	refcount_t fib_clntref;
	unsigned int fib_flags;
	unsigned char fib_dead;
	unsigned char fib_protocol;
	unsigned char fib_scope;
	unsigned char fib_type;
	__be32 fib_prefsrc;
	u32 fib_tb_id;
	u32 fib_priority;
	struct dst_metrics *fib_metrics;
	int fib_nhs;
	struct callback_head rcu;
	struct fib_nh___6 fib_nh[0];
};

struct fib_result___5 {
	__be32 prefix;
	unsigned char prefixlen;
	unsigned char nh_sel;
	unsigned char type;
	unsigned char scope;
	u32 tclassid;
	struct fib_info___6 *fi;
	struct fib_table *table;
	struct hlist_head *fa_head;
};

struct fib4_rule {
	struct fib_rule___46 common;
	u8 dst_len;
	u8 src_len;
	u8 tos;
	__be32 src;
	__be32 srcmask;
	__be32 dst;
	__be32 dstmask;
	u32 tclassid;
};

struct module___380;

struct file___454;

struct kiocb___454;

struct iov_iter___221;

struct poll_table_struct___293;

struct vm_area_struct___455;

struct inode___454;

struct file_lock___454;

struct page___455;

struct pipe_inode_info___135;

struct seq_file___393;

struct file_operations___454 {
	struct module___380 *owner;
	loff_t (*llseek)(struct file___454 *, loff_t, int);
	ssize_t (*read)(struct file___454 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___454 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___454 *, struct iov_iter___221 *);
	ssize_t (*write_iter)(struct kiocb___454 *, struct iov_iter___221 *);
	int (*iopoll)(struct kiocb___454 *, bool);
	int (*iterate)(struct file___454 *, struct dir_context *);
	int (*iterate_shared)(struct file___454 *, struct dir_context *);
	__poll_t (*poll)(struct file___454 *, struct poll_table_struct___293 *);
	long int (*unlocked_ioctl)(struct file___454 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___454 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___454 *, struct vm_area_struct___455 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___454 *, struct file___454 *);
	int (*flush)(struct file___454 *, fl_owner_t);
	int (*release)(struct inode___454 *, struct file___454 *);
	int (*fsync)(struct file___454 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___454 *, int);
	int (*lock)(struct file___454 *, int, struct file_lock___454 *);
	ssize_t (*sendpage)(struct file___454 *, struct page___455 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___454 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___454 *, int, struct file_lock___454 *);
	ssize_t (*splice_write)(struct pipe_inode_info___135 *, struct file___454 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___454 *, loff_t *, struct pipe_inode_info___135 *, size_t, unsigned int);
	int (*setlease)(struct file___454 *, long int, struct file_lock___454 **, void **);
	long int (*fallocate)(struct file___454 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___393 *, struct file___454 *);
	ssize_t (*copy_file_range)(struct file___454 *, loff_t, struct file___454 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___454 *, loff_t, struct file___454 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___454 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___455 {
	u64 seqnum;
	struct vm_area_struct___455 *vmas[4];
};

struct page_frag___455 {
	struct page___455 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___455;

struct mem_cgroup___187;

struct cred___422;

struct nsproxy___349;

struct signal_struct___329;

struct bio_list___244;

struct backing_dev_info___244;

struct css_set___303;

struct vm_struct___358;

struct task_struct___456 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___456 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___455 *mm;
	struct mm_struct___455 *active_mm;
	struct vmacache___455 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___456 *real_parent;
	struct task_struct___456 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___456 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___187 *active_memcg;
	long int rh_reserved2;
	struct pid___252 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___252 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___252 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___422 *ptracer_cred;
	const struct cred___422 *real_cred;
	const struct cred___422 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___349 *nsproxy;
	struct signal_struct___329 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___456 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___244 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___244 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___303 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___135 *splice_pipe;
	struct page_frag___455 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___187 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___456 *oom_reaper_list;
	struct vm_struct___358 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___156 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rw_semaphore___456 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___456 *owner;
};

struct key___422;

struct ucounts___319;

struct user_namespace___319 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___319 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___29 ns;
	long unsigned int flags;
	struct key___422 *persistent_keyring_register;
	struct rw_semaphore___456 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___319 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct secondary_data___456 {
	void *stack;
	struct task_struct___456 *task;
	long int status;
};

typedef struct page___455 *pgtable_t___455;

struct address_space___454;

struct dev_pagemap___442;

struct page___455 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___454 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___455 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___455 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___455 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___442 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___187 *mem_cgroup;
};

struct user_struct___422 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___422 *uid_keyring;
	struct key___422 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___442;

struct vm_area_struct___455 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___455 *vm_next;
	struct vm_area_struct___455 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___455 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___442 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___454 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___455;

struct mm_struct___455 {
	struct {
		struct vm_area_struct___455 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___454 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___456 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___455 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___456 *owner;
		struct user_namespace___319 *user_ns;
		struct file___454 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___455 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup___303;

struct cgroup_subsys___303;

struct cgroup_subsys_state___303 {
	struct cgroup___303 *cgroup;
	struct cgroup_subsys___303 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___303 *parent;
};

struct kernfs_node___449;

struct cgroup_file___303 {
	struct kernfs_node___449 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___187;

struct mem_cgroup___187 {
	struct cgroup_subsys_state___303 css;
	struct mem_cgroup_id___16 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___303 events_file;
	struct cgroup_file___303 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___456 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___187 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cred___422 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___422 *session_keyring;
	struct key___422 *process_keyring;
	struct key___422 *thread_keyring;
	struct key___422 *request_key_auth;
	void *security;
	struct user_struct___422 *user;
	struct user_namespace___319 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___110;

struct cgroup_namespace___303;

struct nsproxy___349 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net___110 *net_ns;
	struct cgroup_namespace___303 *cgroup_ns;
};

struct signal_struct___329 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___456 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___456 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___252 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___252 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___455 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___252 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___244;

struct bio_list___244 {
	struct bio___244 *head;
	struct bio___244 *tail;
};

struct bdi_writeback_congested___244;

struct bdi_writeback___244 {
	struct backing_dev_info___244 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___244 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___303 *memcg_css;
	struct cgroup_subsys_state___303 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___422;

struct dentry___454;

struct backing_dev_info___244 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___244 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___422 *dev;
	struct device___422 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___454 *debug_dir;
	struct dentry___454 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___303 {
	struct cgroup_subsys_state___303 *subsys[13];
	refcount_t refcount;
	struct css_set___303 *dom_cset;
	struct cgroup___303 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___303 *mg_src_cgrp;
	struct cgroup___303 *mg_dst_cgrp;
	struct css_set___303 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___454;

struct pipe_buffer___135;

struct pipe_inode_info___135 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___455 *tmp_page;
	struct fasync_struct___454 *fasync_readers;
	struct fasync_struct___454 *fasync_writers;
	struct pipe_buffer___135 *bufs;
	struct user_struct___422 *user;
};

struct vm_struct___358 {
	struct vm_struct___358 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___455 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___341 {
	struct task_struct___456 task;
	long unsigned int stack[8192];
};

struct address_space_operations___454;

struct address_space___454 {
	struct inode___454 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___456 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___454 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___442)(struct vm_area_struct___455 *, long unsigned int, const struct page___455 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___442)(struct page___455 *, void *);

struct dev_pagemap___442 {
	dev_page_fault_t___442 page_fault;
	dev_page_free_t___442 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___422 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___455 {
	struct vfsmount *mnt;
	struct dentry___454 *dentry;
};

struct file___454 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___455 f_path;
	struct inode___454 *f_inode;
	const struct file_operations___454 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___252 f_owner;
	const struct cred___422 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___454 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___442;

struct vm_operations_struct___442 {
	void (*open)(struct vm_area_struct___455 *);
	void (*close)(struct vm_area_struct___455 *);
	int (*split)(struct vm_area_struct___455 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___455 *);
	vm_fault_t (*fault)(struct vm_fault___442 *);
	vm_fault_t (*huge_fault)(struct vm_fault___442 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___442 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___455 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___442 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___442 *);
	int (*access)(struct vm_area_struct___455 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___455 *);
	int (*set_policy)(struct vm_area_struct___455 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___455 *, long unsigned int);
	struct page___455 * (*find_special_page)(struct vm_area_struct___455 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___455 {
	struct task_struct___456 *task;
	struct core_thread___455 *next;
};

struct core_state___455 {
	atomic_t nr_threads;
	struct core_thread___455 dumper;
	struct completion startup;
};

struct vm_fault___442 {
	struct vm_area_struct___455 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___455 *cow_page;
	struct mem_cgroup___187 *memcg;
	struct page___455 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___455 prealloc_pte;
};

struct pglist_data___455;

struct lruvec___455 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___455 *pgdat;
};

struct zone___455 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___455 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___455 {
	struct zone___455 *zone;
	int zone_idx;
};

struct zonelist___455 {
	struct zoneref___455 _zonerefs[25];
};

struct pglist_data___455 {
	struct zone___455 node_zones[3];
	struct zonelist___455 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___456 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___456 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___455 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___455 {
	struct rw_semaphore___456 rwsem;
	struct notifier_block *head;
};

struct shrink_control___187 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___187 *memcg;
};

struct shrinker___187 {
	long unsigned int (*count_objects)(struct shrinker___187 *, struct shrink_control___187 *);
	long unsigned int (*scan_objects)(struct shrinker___187 *, struct shrink_control___187 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct kset___441;

struct kobj_type___441;

struct kobject___442 {
	const char *name;
	struct list_head entry;
	struct kobject___442 *parent;
	struct kset___441 *kset;
	struct kobj_type___441 *ktype;
	struct kernfs_node___449 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___422 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___422 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___422;

struct bus_type___422;

struct device_driver___422;

struct dev_pm_domain___422;

struct dma_map_ops___194;

struct fwnode_handle___342;

struct class___422;

struct attribute_group___419;

struct device___422 {
	struct device___422 *parent;
	struct device_private *p;
	struct kobject___442 kobj;
	const char *init_name;
	const struct device_type___422 *type;
	struct mutex mutex;
	struct bus_type___422 *bus;
	struct device_driver___422 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___422 power;
	struct dev_pm_domain___422 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___194 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___342 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___422 *class;
	const struct attribute_group___419 **groups;
	void (*release)(struct device___422 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___454;

struct super_block___454;

struct dentry___454 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___454 *d_parent;
	struct qstr d_name;
	struct inode___454 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___454 *d_op;
	struct super_block___454 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___454;

struct block_device___454;

struct inode___454 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___454 *i_op;
	struct super_block___454 *i_sb;
	struct address_space___454 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___456 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___244 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___454 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___454 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___135 *i_pipe;
		struct block_device___454 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___454 {
	int (*d_revalidate)(struct dentry___454 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___454 *, unsigned int);
	int (*d_hash)(const struct dentry___454 *, struct qstr *);
	int (*d_compare)(const struct dentry___454 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___454 *);
	int (*d_init)(struct dentry___454 *);
	void (*d_release)(struct dentry___454 *);
	void (*d_prune)(struct dentry___454 *);
	void (*d_iput)(struct dentry___454 *, struct inode___454 *);
	char * (*d_dname)(struct dentry___454 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___455 *);
	int (*d_manage)(const struct path___455 *, bool);
	struct dentry___454 * (*d_real)(struct dentry___454 *, const struct inode___454 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___454;

struct mem_dqinfo___454 {
	struct quota_format_type___454 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___454;

struct quota_info___454 {
	unsigned int flags;
	struct rw_semaphore___456 dqio_sem;
	struct inode___454 *files[3];
	struct mem_dqinfo___454 info[3];
	const struct quota_format_ops___454 *ops[3];
};

struct rcuwait___454 {
	struct task_struct___456 *task;
};

struct percpu_rw_semaphore___454 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___456 rw_sem;
	struct rcuwait___454 writer;
	int readers_block;
};

struct sb_writers___454 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___454 rw_sem[3];
};

struct file_system_type___454;

struct super_operations___454;

struct dquot_operations___454;

struct quotactl_ops___454;

struct super_block___454 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___454 *s_type;
	const struct super_operations___454 *s_op;
	const struct dquot_operations___454 *dq_op;
	const struct quotactl_ops___454 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___454 *s_root;
	struct rw_semaphore___456 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___454 *s_bdev;
	struct backing_dev_info___244 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___454 s_dquot;
	struct sb_writers___454 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___454 *s_d_op;
	int cleancache_poolid;
	struct shrinker___187 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___319 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___454 {
	struct file___454 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___454 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___454 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___454 *ia_file;
};

struct dquot___454 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___454 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___454 {
	int qf_fmt_id;
	const struct quota_format_ops___454 *qf_ops;
	struct module___380 *qf_owner;
	struct quota_format_type___454 *qf_next;
};

struct quota_format_ops___454 {
	int (*check_quota_file)(struct super_block___454 *, int);
	int (*read_file_info)(struct super_block___454 *, int);
	int (*write_file_info)(struct super_block___454 *, int);
	int (*free_file_info)(struct super_block___454 *, int);
	int (*read_dqblk)(struct dquot___454 *);
	int (*commit_dqblk)(struct dquot___454 *);
	int (*release_dqblk)(struct dquot___454 *);
	int (*get_next_id)(struct super_block___454 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___454 {
	int (*write_dquot)(struct dquot___454 *);
	struct dquot___454 * (*alloc_dquot)(struct super_block___454 *, int);
	void (*destroy_dquot)(struct dquot___454 *);
	int (*acquire_dquot)(struct dquot___454 *);
	int (*release_dquot)(struct dquot___454 *);
	int (*mark_dirty)(struct dquot___454 *);
	int (*write_info)(struct super_block___454 *, int);
	qsize_t * (*get_reserved_space)(struct inode___454 *);
	int (*get_projid)(struct inode___454 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___454 *, qsize_t *);
	int (*get_next_id)(struct super_block___454 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___454 {
	int (*quota_on)(struct super_block___454 *, int, int, const struct path___455 *);
	int (*quota_off)(struct super_block___454 *, int);
	int (*quota_enable)(struct super_block___454 *, unsigned int);
	int (*quota_disable)(struct super_block___454 *, unsigned int);
	int (*quota_sync)(struct super_block___454 *, int);
	int (*set_info)(struct super_block___454 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___454 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___454 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___454 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___454 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___454 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___380 {
	struct kobject___442 kobj;
	struct module___380 *mod;
	struct kobject___442 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___380 {
	struct module___380 *mod;
	struct latch_tree_node node;
};

struct module_layout___380 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___380 mtn;
};

struct module_attribute___380;

struct kernel_param___380;

struct module___380 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___380 mkobj;
	struct module_attribute___380 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___442 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___380 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___380 core_layout;
	struct module_layout___380 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide53;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide54;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___207;

struct address_space_operations___454 {
	int (*writepage)(struct page___455 *, struct writeback_control___207 *);
	int (*readpage)(struct file___454 *, struct page___455 *);
	int (*writepages)(struct address_space___454 *, struct writeback_control___207 *);
	int (*set_page_dirty)(struct page___455 *);
	int (*readpages)(struct file___454 *, struct address_space___454 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___454 *, struct address_space___454 *, loff_t, unsigned int, unsigned int, struct page___455 **, void **);
	int (*write_end)(struct file___454 *, struct address_space___454 *, loff_t, unsigned int, unsigned int, struct page___455 *, void *);
	sector_t (*bmap)(struct address_space___454 *, sector_t);
	void (*invalidatepage)(struct page___455 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___455 *, gfp_t);
	void (*freepage)(struct page___455 *);
	ssize_t (*direct_IO)(struct kiocb___454 *, struct iov_iter___221 *);
	int (*migratepage)(struct address_space___454 *, struct page___455 *, struct page___455 *, enum migrate_mode);
	bool (*isolate_page)(struct page___455 *, isolate_mode_t);
	void (*putback_page)(struct page___455 *);
	int (*launder_page)(struct page___455 *);
	int (*is_partially_uptodate)(struct page___455 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___455 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___454 *, struct page___455 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___454 *, sector_t *);
	void (*swap_deactivate)(struct file___454 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___207 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___244 *wb;
	struct inode___454 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___246;

struct iov_iter___221 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___246 *bvec;
		struct pipe_inode_info___135 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___454 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___454 *bd_inode;
	struct super_block___454 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___454 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___244 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___454 {
	struct dentry___454 * (*lookup)(struct inode___454 *, struct dentry___454 *, unsigned int);
	const char * (*get_link)(struct dentry___454 *, struct inode___454 *, struct delayed_call *);
	int (*permission)(struct inode___454 *, int);
	struct posix_acl * (*get_acl)(struct inode___454 *, int);
	int (*readlink)(struct dentry___454 *, char *, int);
	int (*create)(struct inode___454 *, struct dentry___454 *, umode_t, bool);
	int (*link)(struct dentry___454 *, struct inode___454 *, struct dentry___454 *);
	int (*unlink)(struct inode___454 *, struct dentry___454 *);
	int (*symlink)(struct inode___454 *, struct dentry___454 *, const char *);
	int (*mkdir)(struct inode___454 *, struct dentry___454 *, umode_t);
	int (*rmdir)(struct inode___454 *, struct dentry___454 *);
	int (*mknod)(struct inode___454 *, struct dentry___454 *, umode_t, dev_t);
	int (*rename)(struct inode___454 *, struct dentry___454 *, struct inode___454 *, struct dentry___454 *, unsigned int);
	int (*setattr)(struct dentry___454 *, struct iattr___454 *);
	int (*getattr)(const struct path___455 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___454 *, char *, size_t);
	int (*fiemap)(struct inode___454 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___454 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___454 *, struct dentry___454 *, struct file___454 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___454 *, struct dentry___454 *, umode_t);
	int (*set_acl)(struct inode___454 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___454 {
	void (*fl_copy_lock)(struct file_lock___454 *, struct file_lock___454 *);
	void (*fl_release_private)(struct file_lock___454 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___454;

struct file_lock___454 {
	struct file_lock___454 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___454 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___454 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___454 *fl_ops;
	const struct lock_manager_operations___454 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___454 {
	int (*lm_compare_owner)(struct file_lock___454 *, struct file_lock___454 *);
	long unsigned int (*lm_owner_key)(struct file_lock___454 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___454 *);
	int (*lm_grant)(struct file_lock___454 *, int);
	bool (*lm_break)(struct file_lock___454 *);
	int (*lm_change)(struct file_lock___454 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___454 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___454 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___454 *fa_next;
	struct file___454 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___454 {
	const char *name;
	int fs_flags;
	struct dentry___454 * (*mount)(struct file_system_type___454 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___454 *);
	struct module___380 *owner;
	struct file_system_type___454 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___454 {
	struct inode___454 * (*alloc_inode)(struct super_block___454 *);
	void (*destroy_inode)(struct inode___454 *);
	void (*dirty_inode)(struct inode___454 *, int);
	int (*write_inode)(struct inode___454 *, struct writeback_control___207 *);
	int (*drop_inode)(struct inode___454 *);
	void (*evict_inode)(struct inode___454 *);
	void (*put_super)(struct super_block___454 *);
	int (*sync_fs)(struct super_block___454 *, int);
	int (*freeze_super)(struct super_block___454 *);
	int (*freeze_fs)(struct super_block___454 *);
	int (*thaw_super)(struct super_block___454 *);
	int (*unfreeze_fs)(struct super_block___454 *);
	int (*statfs)(struct dentry___454 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___454 *, int *, char *);
	void (*umount_begin)(struct super_block___454 *);
	int (*show_options)(struct seq_file___393 *, struct dentry___454 *);
	int (*show_devname)(struct seq_file___393 *, struct dentry___454 *);
	int (*show_path)(struct seq_file___393 *, struct dentry___454 *);
	int (*show_stats)(struct seq_file___393 *, struct dentry___454 *);
	ssize_t (*quota_read)(struct super_block___454 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___454 *, int, const char *, size_t, loff_t);
	struct dquot___454 ** (*get_dquots)(struct inode___454 *);
	int (*bdev_try_to_free_page)(struct super_block___454 *, struct page___455 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___454 *, struct shrink_control___187 *);
	long int (*free_cached_objects)(struct super_block___454 *, struct shrink_control___187 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___303)(struct file___454 *, wait_queue_head_t *, struct poll_table_struct___293 *);

struct poll_table_struct___293 {
	poll_queue_proc___303 _qproc;
	__poll_t _key;
};

struct seq_operations___393;

struct seq_file___393 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___393 *op;
	int poll_event;
	const struct file___454 *file;
	void *private;
};

typedef void bio_end_io_t___244(struct bio___244 *);

struct bio_vec___246 {
	struct page___455 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___244;

struct bio_set___244;

struct bio___244 {
	struct bio___244 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___244 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___244 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___246 *bi_io_vec;
	struct bio_set___244 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___246 bi_inline_vecs[0];
};

struct kobj_attribute___432 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___442 *, struct kobj_attribute___432 *, char *);
	ssize_t (*store)(struct kobject___442 *, struct kobj_attribute___432 *, const char *, size_t);
};

typedef void compound_page_dtor___442(struct page___455 *);

struct msghdr___82 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___221 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___454 *msg_iocb;
};

struct inet_frags___99;

struct netns_frags___99 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___99 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct inet_frag_queue___99;

struct inet_frags___99 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___99 *, const void *);
	void (*destructor)(struct inet_frag_queue___99 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct sk_buff___100;

struct inet_frag_queue___99 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___100 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___100 *fragments_tail;
	struct sk_buff___100 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___99 *net;
	struct callback_head rcu;
};

struct net_device___99;

struct sock___79;

struct nf_bridge_info___99;

struct sk_buff___100 {
	union {
		struct {
			struct sk_buff___100 *next;
			struct sk_buff___100 *prev;
			union {
				struct net_device___99 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___79 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___100 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___99 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct ip_ra_chain___45;

struct fib_rules_ops___79;

struct fib_notifier_ops___80;

struct netns_ipv4___99 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___45 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___79 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___79 *fibnl;
	struct sock___79 **icmp_sk;
	struct sock___79 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___79 **tcp_sk;
	struct netns_frags___99 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___79 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___80 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___80 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct ip_ra_chain___45 {
	struct ip_ra_chain___45 *next;
	struct sock___79 *sk;
	union {
		void (*destructor)(struct sock___79 *);
		struct sock___79 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___79;

struct fib_lookup_arg___79;

struct fib_rules_ops___79 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___79 *, struct flowi *, int, struct fib_lookup_arg___79 *);
	bool (*suppress)(struct fib_rule___79 *, struct fib_lookup_arg___79 *);
	int (*match)(struct fib_rule___79 *, struct flowi *, int);
	int (*configure)(struct fib_rule___79 *, struct sk_buff___100 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___79 *);
	int (*compare)(struct fib_rule___79 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___79 *, struct sk_buff___100 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___79 *);
	void (*flush_cache)(struct fib_rules_ops___79 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___380 *owner;
	struct net___110 *fro_net;
	struct callback_head rcu;
};

typedef struct {
	struct net___110 *net;
} possible_net_t___101;

struct proto___79;

struct sock_common___79 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___79 *skc_prot;
	possible_net_t___101 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___79 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff_head___99 {
	struct sk_buff___100 *next;
	struct sk_buff___100 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___79;

struct socket_wq___80;

struct dst_entry___79;

struct socket___81;

struct sock___79 {
	struct sock_common___79 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___99 sk_error_queue;
	struct sk_buff_head___99 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___100 *head;
		struct sk_buff___100 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___79 *sk_filter;
	union {
		struct socket_wq___80 *sk_wq;
		struct socket_wq___80 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___79 *sk_rx_dst;
	struct dst_entry___79 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___100 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___99 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___455 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___79 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___252 *sk_peer_pid;
	const struct cred___422 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___81 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___187 *sk_memcg;
	void (*sk_state_change)(struct sock___79 *);
	void (*sk_data_ready)(struct sock___79 *);
	void (*sk_write_space)(struct sock___79 *);
	void (*sk_error_report)(struct sock___79 *);
	int (*sk_backlog_rcv)(struct sock___79 *, struct sk_buff___100 *);
	struct sk_buff___100 * (*sk_validate_xmit_skb)(struct sock___79 *, struct net_device___99 *, struct sk_buff___100 *);
	void (*sk_destruct)(struct sock___79 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct fib_notifier_ops___80 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___110 *);
	int (*fib_dump)(struct net___110 *, struct notifier_block *);
	struct module___380 *owner;
	struct callback_head rcu;
};

struct neighbour___79;

struct dst_ops___110 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___110 *);
	struct dst_entry___79 * (*check)(struct dst_entry___79 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___79 *);
	unsigned int (*mtu)(const struct dst_entry___79 *);
	u32 * (*cow_metrics)(struct dst_entry___79 *, long unsigned int);
	void (*destroy)(struct dst_entry___79 *);
	void (*ifdown)(struct dst_entry___79 *, struct net_device___99 *, int);
	struct dst_entry___79 * (*negative_advice)(struct dst_entry___79 *);
	void (*link_failure)(struct sk_buff___100 *);
	void (*update_pmtu)(struct dst_entry___79 *, struct sock___79 *, struct sk_buff___100 *, u32);
	void (*redirect)(struct dst_entry___79 *, struct sock___79 *, struct sk_buff___100 *);
	int (*local_out)(struct net___110 *, struct sock___79 *, struct sk_buff___100 *);
	struct neighbour___79 * (*neigh_lookup)(const struct dst_entry___79 *, struct sk_buff___100 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___79 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct lwtunnel_state___11;

struct dst_entry___79 {
	struct net_device___99 *dev;
	struct dst_ops___110 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___100 *);
	int (*output)(struct net___110 *, struct sock___79 *, struct sk_buff___100 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___11 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

typedef rx_handler_result_t rx_handler_func_t___99(struct sk_buff___100 **);

struct net_device_ops___99;

struct ethtool_ops___99;

struct switchdev_ops___4;

struct l3mdev_ops___79;

struct ndisc_ops___50;

struct xfrmdev_ops___99;

struct tlsdev_ops___99;

struct header_ops___99;

struct in_device___14;

struct inet6_dev___50;

struct netdev_rx_queue___99;

struct bpf_prog___89;

struct mini_Qdisc___91;

struct netdev_queue___99;

struct nf_hook_entries___15;

struct Qdisc___91;

struct rtnl_link_ops___91;

struct dcbnl_rtnl_ops___99;

struct net_device___99 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___99 *netdev_ops;
	const struct ethtool_ops___99 *ethtool_ops;
	const struct switchdev_ops___4 *switchdev_ops;
	const struct l3mdev_ops___79 *l3mdev_ops;
	const struct ndisc_ops___50 *ndisc_ops;
	const struct xfrmdev_ops___99 *xfrmdev_ops;
	const struct tlsdev_ops___99 *tlsdev_ops;
	const struct header_ops___99 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___441 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device___14 *ip_ptr;
	struct inet6_dev___50 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___99 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___89 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___99 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___91 *miniq_ingress;
	struct netdev_queue___99 *ingress_queue;
	struct nf_hook_entries___15 *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___99 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___91 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___91 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___99 = 0,
		NETREG_REGISTERED___99 = 1,
		NETREG_UNREGISTERING___99 = 2,
		NETREG_UNREGISTERED___99 = 3,
		NETREG_RELEASED___99 = 4,
		NETREG_DUMMY___99 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___99 = 0,
		RTNL_LINK_INITIALIZING___99 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___99 *);
	struct netpoll_info *npinfo;
	possible_net_t___101 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___422 dev;
	const struct attribute_group___419 *sysfs_groups[4];
	const struct attribute_group___419 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___91 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___99 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct fib6_info___22;

struct rt6_info___22;

struct fib6_table___22;

struct netns_ipv6___110 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___99 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info___22 *fib6_null_entry;
	struct rt6_info___22 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___22 *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___110 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info___22 *ip6_prohibit_entry;
	struct rt6_info___22 *ip6_blk_hole_entry;
	struct fib6_table___22 *fib6_local_tbl;
	struct fib_rules_ops___79 *fib6_rules_ops;
	struct sock___79 **icmp_sk;
	struct sock___79 *ndisc_sk;
	struct sock___79 *tcp_sk;
	struct sock___79 *igmp_sk;
	struct sock___79 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___79 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___80 *notifier_ops;
	struct fib_notifier_ops___80 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___80 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___79 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf___16 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_queue_handler *queue_handler;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header *nf_log_dir_header;
	struct nf_hook_entries___15 *hooks_ipv4[5];
	struct nf_hook_entries___15 *hooks_ipv6[5];
	struct nf_hook_entries___15 *hooks_arp[3];
	struct nf_hook_entries___15 *hooks_bridge[5];
	bool defrag_ipv4;
	bool defrag_ipv6;
};

struct netns_nf_frag___99 {
	struct netns_frags___99 frags;
};

struct netns_xfrm___110 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___79 *nlsk;
	struct sock___79 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___110 xfrm4_dst_ops;
	struct dst_ops___110 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct net___110 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___319 *user_ns;
	struct ucounts___319 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___29 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___79 *rtnl;
	struct sock___79 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___99 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___99 ipv4;
	struct netns_ipv6___110 ipv6;
	struct netns_sctp___80 sctp;
	struct netns_nf___16 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___99 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___79 *nfnl;
	struct sock___79 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___110 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___79 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___89 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neigh_table___79;

struct neigh_parms___79;

struct neigh_ops___79;

struct neighbour___79 {
	struct neighbour___79 *next;
	struct neigh_table___79 *tbl;
	struct neigh_parms___79 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___99 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___79 *, struct sk_buff___100 *);
	const struct neigh_ops___79 *ops;
	struct callback_head rcu;
	struct net_device___99 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct fib6_nh___22 {
	struct in6_addr nh_gw;
	struct net_device___99 *nh_dev;
	struct lwtunnel_state___11 *nh_lwtstate;
	unsigned int nh_flags;
	atomic_t nh_upper_bound;
	int nh_weight;
};

struct fib6_node___22;

struct fib6_info___22 {
	struct fib6_table___22 *fib6_table;
	struct fib6_info___22 *fib6_next;
	struct fib6_node___22 *fib6_node;
	struct list_head fib6_siblings;
	unsigned int fib6_nsiblings;
	atomic_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	struct rt6_info___22 **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
	long unsigned int last_probe;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 exception_bucket_flushed: 1;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 dst_host: 1;
	u8 fib6_destroying: 1;
	u8 unused: 2;
	struct fib6_nh___22 fib6_nh;
	struct callback_head rcu;
};

struct rt6_info___22 {
	struct dst_entry___79 dst;
	struct fib6_info___22 *from;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___50 *rt6i_idev;
	u32 rt6i_flags;
	struct rt6key rt6i_prefsrc;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct fib6_node___22 {
	struct fib6_node___22 *parent;
	struct fib6_node___22 *left;
	struct fib6_node___22 *right;
	struct fib6_info___22 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info___22 *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table___22 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node___22 tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

struct nf_hook_state___15;

typedef unsigned int nf_hookfn___15(void *, struct sk_buff___100 *, const struct nf_hook_state___15 *);

struct nf_hook_entry___15 {
	nf_hookfn___15 *hook;
	void *priv;
};

struct nf_hook_entries___15 {
	u16 num_hook_entries;
	struct nf_hook_entry___15 hooks[0];
};

struct socket_wq___80 {
	wait_queue_head_t wait;
	struct fasync_struct___454 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___80;

struct socket___81 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___80 *wq;
	struct file___454 *file;
	struct sock___79 *sk;
	const struct proto_ops___80 *ops;
};

typedef int (*sk_read_actor_t___79)(read_descriptor_t *, struct sk_buff___100 *, unsigned int, size_t);

struct proto_ops___80 {
	int family;
	struct module___380 *owner;
	int (*release)(struct socket___81 *);
	int (*bind)(struct socket___81 *, struct sockaddr *, int);
	int (*connect)(struct socket___81 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___81 *, struct socket___81 *);
	int (*accept)(struct socket___81 *, struct socket___81 *, int, bool);
	int (*getname)(struct socket___81 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___454 *, struct socket___81 *, struct poll_table_struct___293 *);
	int (*ioctl)(struct socket___81 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___81 *, int);
	int (*shutdown)(struct socket___81 *, int);
	int (*setsockopt)(struct socket___81 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___81 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___81 *, struct msghdr___82 *, size_t);
	int (*recvmsg)(struct socket___81 *, struct msghdr___82 *, size_t, int);
	int (*mmap)(struct file___454 *, struct socket___81 *, struct vm_area_struct___455 *);
	ssize_t (*sendpage)(struct socket___81 *, struct page___455 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___81 *, loff_t *, struct pipe_inode_info___135 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___79 *, int);
	int (*peek_len)(struct socket___81 *);
	int (*read_sock)(struct sock___79 *, read_descriptor_t *, sk_read_actor_t___79);
	int (*sendpage_locked)(struct sock___79 *, struct page___455 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___79 *, struct msghdr___82 *, size_t);
	int (*set_rcvlowat)(struct sock___79 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct kernfs_root___448;

struct kernfs_elem_dir___448 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___448 *root;
};

struct kernfs_syscall_ops___448;

struct kernfs_root___448 {
	struct kernfs_node___449 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___448 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___448 {
	struct kernfs_node___449 *target_kn;
};

struct kernfs_ops___448;

struct kernfs_elem_attr___448 {
	const struct kernfs_ops___448 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___449 *notify_next;
};

struct kernfs_node___449 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___449 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___448 dir;
		struct kernfs_elem_symlink___448 symlink;
		struct kernfs_elem_attr___448 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___448;

struct kernfs_ops___448 {
	int (*open)(struct kernfs_open_file___448 *);
	void (*release)(struct kernfs_open_file___448 *);
	int (*seq_show)(struct seq_file___393 *, void *);
	void * (*seq_start)(struct seq_file___393 *, loff_t *);
	void * (*seq_next)(struct seq_file___393 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___393 *, void *);
	ssize_t (*read)(struct kernfs_open_file___448 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___448 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___448 *, struct vm_area_struct___455 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___448 *, struct poll_table_struct___293 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide15;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___448 {
	int (*remount_fs)(struct kernfs_root___448 *, int *, char *);
	int (*show_options)(struct seq_file___393 *, struct kernfs_root___448 *);
	int (*mkdir)(struct kernfs_node___449 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___449 *);
	int (*rename)(struct kernfs_node___449 *, struct kernfs_node___449 *, const char *);
	int (*show_path)(struct seq_file___393 *, struct kernfs_node___449 *, struct kernfs_root___448 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___448 {
	struct kernfs_node___449 *kn;
	struct file___454 *file;
	struct seq_file___393 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___442 *vm_ops;
};

struct kobj_ns_type_operations___79 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___79 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___418;

struct attribute_group___419 {
	const char *name;
	umode_t (*is_visible)(struct kobject___442 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___442 *, struct bin_attribute___418 *, int);
	struct attribute **attrs;
	struct bin_attribute___418 **bin_attrs;
};

struct bin_attribute___418 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___454 *, struct kobject___442 *, struct bin_attribute___418 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___454 *, struct kobject___442 *, struct bin_attribute___418 *, char *, loff_t, size_t);
	int (*mmap)(struct file___454 *, struct kobject___442 *, struct bin_attribute___418 *, struct vm_area_struct___455 *);
};

struct sysfs_ops___441 {
	ssize_t (*show)(struct kobject___442 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___442 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___441;

struct kset___441 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___442 kobj;
	const struct kset_uevent_ops___441 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___441 {
	void (*release)(struct kobject___442 *);
	const struct sysfs_ops___441 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___79 * (*child_ns_type)(struct kobject___442 *);
	const void * (*namespace)(struct kobject___442 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___441 {
	int (* const filter)(struct kset___441 *, struct kobject___442 *);
	const char * (* const name)(struct kset___441 *, struct kobject___442 *);
	int (* const uevent)(struct kset___441 *, struct kobject___442 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___422 {
	int (*prepare)(struct device___422 *);
	void (*complete)(struct device___422 *);
	int (*suspend)(struct device___422 *);
	int (*resume)(struct device___422 *);
	int (*freeze)(struct device___422 *);
	int (*thaw)(struct device___422 *);
	int (*poweroff)(struct device___422 *);
	int (*restore)(struct device___422 *);
	int (*suspend_late)(struct device___422 *);
	int (*resume_early)(struct device___422 *);
	int (*freeze_late)(struct device___422 *);
	int (*thaw_early)(struct device___422 *);
	int (*poweroff_late)(struct device___422 *);
	int (*restore_early)(struct device___422 *);
	int (*suspend_noirq)(struct device___422 *);
	int (*resume_noirq)(struct device___422 *);
	int (*freeze_noirq)(struct device___422 *);
	int (*thaw_noirq)(struct device___422 *);
	int (*poweroff_noirq)(struct device___422 *);
	int (*restore_noirq)(struct device___422 *);
	int (*runtime_suspend)(struct device___422 *);
	int (*runtime_resume)(struct device___422 *);
	int (*runtime_idle)(struct device___422 *);
};

struct dev_pm_domain___422 {
	struct dev_pm_ops___422 ops;
	void (*detach)(struct device___422 *, bool);
	int (*activate)(struct device___422 *);
	void (*sync)(struct device___422 *);
	void (*dismiss)(struct device___422 *);
};

struct bus_type___422 {
	const char *name;
	const char *dev_name;
	struct device___422 *dev_root;
	const struct attribute_group___419 **bus_groups;
	const struct attribute_group___419 **dev_groups;
	const struct attribute_group___419 **drv_groups;
	int (*match)(struct device___422 *, struct device_driver___422 *);
	int (*uevent)(struct device___422 *, struct kobj_uevent_env *);
	int (*probe)(struct device___422 *);
	int (*remove)(struct device___422 *);
	void (*shutdown)(struct device___422 *);
	int (*online)(struct device___422 *);
	int (*offline)(struct device___422 *);
	int (*suspend)(struct device___422 *, pm_message_t);
	int (*resume)(struct device___422 *);
	int (*num_vf)(struct device___422 *);
	int (*dma_configure)(struct device___422 *);
	const struct dev_pm_ops___422 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___422 {
	const char *name;
	struct bus_type___422 *bus;
	struct module___380 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___422 *);
	int (*remove)(struct device___422 *);
	void (*shutdown)(struct device___422 *);
	int (*suspend)(struct device___422 *, pm_message_t);
	int (*resume)(struct device___422 *);
	const struct attribute_group___419 **groups;
	const struct dev_pm_ops___422 *pm;
	void (*coredump)(struct device___422 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___422 {
	const char *name;
	const struct attribute_group___419 **groups;
	int (*uevent)(struct device___422 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___422 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___422 *);
	const struct dev_pm_ops___422 *pm;
};

struct class___422 {
	const char *name;
	struct module___380 *owner;
	const struct attribute_group___419 **class_groups;
	const struct attribute_group___419 **dev_groups;
	struct kobject___442 *dev_kobj;
	int (*dev_uevent)(struct device___422 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___422 *, umode_t *);
	void (*class_release)(struct class___422 *);
	void (*dev_release)(struct device___422 *);
	int (*shutdown_pre)(struct device___422 *);
	const struct kobj_ns_type_operations___79 *ns_type;
	const void * (*namespace)(struct device___422 *);
	const struct dev_pm_ops___422 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___194 {
	void * (*alloc)(struct device___422 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___422 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___422 *, struct vm_area_struct___455 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___422 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___422 *, struct page___455 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___422 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___422 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___422 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___422 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___422 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___422 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___422 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___422 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___422 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___422 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___422 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___422 *, u64);
	u64 (*get_required_mask)(struct device___422 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___342;

struct fwnode_handle___342 {
	struct fwnode_handle___342 *secondary;
	const struct fwnode_operations___342 *ops;
};

struct fwnode_reference_args___342;

struct fwnode_endpoint___342;

struct fwnode_operations___342 {
	struct fwnode_handle___342 * (*get)(struct fwnode_handle___342 *);
	void (*put)(struct fwnode_handle___342 *);
	bool (*device_is_available)(const struct fwnode_handle___342 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___342 *, const struct device___422 *);
	bool (*property_present)(const struct fwnode_handle___342 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___342 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___342 *, const char *, const char **, size_t);
	struct fwnode_handle___342 * (*get_parent)(const struct fwnode_handle___342 *);
	struct fwnode_handle___342 * (*get_next_child_node)(const struct fwnode_handle___342 *, struct fwnode_handle___342 *);
	struct fwnode_handle___342 * (*get_named_child_node)(const struct fwnode_handle___342 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___342 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___342 *);
	struct fwnode_handle___342 * (*graph_get_next_endpoint)(const struct fwnode_handle___342 *, struct fwnode_handle___342 *);
	struct fwnode_handle___342 * (*graph_get_remote_endpoint)(const struct fwnode_handle___342 *);
	struct fwnode_handle___342 * (*graph_get_port_parent)(struct fwnode_handle___342 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___342 *, struct fwnode_endpoint___342 *);
};

struct fwnode_endpoint___342 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___342 *local_fwnode;
};

struct fwnode_reference_args___342 {
	struct fwnode_handle___342 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___135;

struct pipe_buffer___135 {
	struct page___455 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___135 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___135 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___135 *, struct pipe_buffer___135 *);
	void (*release)(struct pipe_inode_info___135 *, struct pipe_buffer___135 *);
	int (*steal)(struct pipe_inode_info___135 *, struct pipe_buffer___135 *);
	union {
		bool (*get)(struct pipe_inode_info___135 *, struct pipe_buffer___135 *);
		struct {
			void (*get)(struct pipe_inode_info___135 *, struct pipe_buffer___135 *);
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
};

struct nf_bridge_info___99 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___99 = 0,
		BRNF_PROTO_8021Q___99 = 1,
		BRNF_PROTO_PPPOE___99 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___99 *physindev;
	struct net_device___99 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

struct skb_frag_struct___26 {
	struct {
		struct page___455 *p;
	} page;
	__u32 page_offset;
	__u32 size;
};

typedef struct skb_frag_struct___26 skb_frag_t___26;

struct skb_shared_info___26 {
	__u8 __unused;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___100 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___26 frags[16];
};

struct ucounts___319 {
	struct hlist_node node;
	struct user_namespace___319 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_prog_aux___92;

struct bpf_prog___89 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___92 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

typedef int (*key_restrict_link_func_t___423)(struct key___422 *, const struct key_type *, const union key_payload *, struct key___422 *);

struct key_restriction___422;

struct key___422 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___456 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___422 *restrict_link;
};

struct key_restriction___422 {
	key_restrict_link_func_t___423 check;
	struct key___422 *key;
	struct key_type *keytype;
};

struct seq_operations___393 {
	void * (*start)(struct seq_file___393 *, loff_t *);
	void (*stop)(struct seq_file___393 *, void *);
	void * (*next)(struct seq_file___393 *, void *, loff_t *);
	int (*show)(struct seq_file___393 *, void *);
};

struct seq_net_private___11 {
	struct net___110 *net;
};

struct pernet_operations___100 {
	struct list_head list;
	int (*init)(struct net___110 *);
	void (*exit)(struct net___110 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct ethtool_ops___99 {
	int (*get_settings)(struct net_device___99 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___99 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___99 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___99 *);
	void (*get_regs)(struct net_device___99 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___99 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___99 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___99 *);
	void (*set_msglevel)(struct net_device___99 *, u32);
	int (*nway_reset)(struct net_device___99 *);
	u32 (*get_link)(struct net_device___99 *);
	int (*get_eeprom_len)(struct net_device___99 *);
	int (*get_eeprom)(struct net_device___99 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___99 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___99 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___99 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___99 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___99 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___99 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___99 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___99 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___99 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___99 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___99 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___99 *);
	void (*complete)(struct net_device___99 *);
	u32 (*get_priv_flags)(struct net_device___99 *);
	int (*set_priv_flags)(struct net_device___99 *, u32);
	int (*get_sset_count)(struct net_device___99 *, int);
	int (*get_rxnfc)(struct net_device___99 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___99 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___99 *, struct ethtool_flash *);
	int (*reset)(struct net_device___99 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___99 *);
	u32 (*get_rxfh_indir_size)(struct net_device___99 *);
	int (*get_rxfh)(struct net_device___99 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___99 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___99 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___99 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___99 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___99 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___99 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___99 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___99 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___99 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___99 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___99 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___99 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___99 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___99 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___99 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___99 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___99 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___99 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___99 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___99 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___99 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	int (*get_fecparam)(struct net_device___99 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___99 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___99 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___99 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___99 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct dcbnl_rtnl_ops___99 {
	int (*ieee_getets)(struct net_device___99 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___99 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___99 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___99 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___99 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___99 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___99 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___99 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___99 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___99 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___99 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___99 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___99 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___99 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___99 *);
	u8 (*setstate)(struct net_device___99 *, u8);
	void (*getpermhwaddr)(struct net_device___99 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___99 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___99 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___99 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___99 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___99 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___99 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___99 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___99 *, int, u8 *);
	void (*setpfccfg)(struct net_device___99 *, int, u8);
	void (*getpfccfg)(struct net_device___99 *, int, u8 *);
	u8 (*setall)(struct net_device___99 *);
	u8 (*getcap)(struct net_device___99 *, int, u8 *);
	int (*getnumtcs)(struct net_device___99 *, int, u8 *);
	int (*setnumtcs)(struct net_device___99 *, int, u8);
	u8 (*getpfcstate)(struct net_device___99 *);
	void (*setpfcstate)(struct net_device___99 *, u8);
	void (*getbcncfg)(struct net_device___99 *, int, u32 *);
	void (*setbcncfg)(struct net_device___99 *, int, u32);
	void (*getbcnrp)(struct net_device___99 *, int, u8 *);
	void (*setbcnrp)(struct net_device___99 *, int, u8);
	int (*setapp)(struct net_device___99 *, u8, u16, u8);
	int (*getapp)(struct net_device___99 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___99 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___99 *, int, u8);
	u8 (*getdcbx)(struct net_device___99 *);
	u8 (*setdcbx)(struct net_device___99 *, u8);
	int (*peer_getappinfo)(struct net_device___99 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___99 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___99 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___99 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___99 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___99 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___303 {
	refcount_t count;
	struct ns_common___29 ns;
	struct user_namespace___319 *user_ns;
	struct ucounts___319 *ucounts;
	struct css_set___303 *root_cset;
};

struct bpf_map___304;

struct bpf_map_ops___303 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___304 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___304 *, struct file___454 *);
	void (*map_free)(struct bpf_map___304 *);
	int (*map_get_next_key)(struct bpf_map___304 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___304 *);
	void * (*map_lookup_elem)(struct bpf_map___304 *, void *);
	int (*map_update_elem)(struct bpf_map___304 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___304 *, void *);
	int (*map_push_elem)(struct bpf_map___304 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___304 *, void *);
	int (*map_peek_elem)(struct bpf_map___304 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___304 *, struct file___454 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___304 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___304 *, void *, struct seq_file___393 *);
	int (*map_check_btf)(const struct bpf_map___304 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___304 {
	const struct bpf_map_ops___303 *ops;
	struct bpf_map___304 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___422 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___99;

struct bpf_map_dev_ops___99 {
	int (*map_get_next_key)(struct bpf_offloaded_map___99 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___99 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___99 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___99 *, void *);
};

struct bpf_offloaded_map___99 {
	struct bpf_map___304 map;
	struct net_device___99 *netdev;
	const struct bpf_map_dev_ops___99 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___89 {
	int (*test_run)(struct bpf_prog___89 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___89 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___89 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___89 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___89 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___89 *, u32 *);
};

struct bpf_prog_offload_ops___89 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___89 *);
	int (*translate)(struct bpf_prog___89 *);
	void (*destroy)(struct bpf_prog___89 *);
};

struct bpf_prog_offload___89 {
	struct bpf_prog___89 *prog;
	struct net_device___99 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___89 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___92 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___89 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___89 *ops;
	struct bpf_map___304 **used_maps;
	struct bpf_prog___89 *prog;
	struct user_struct___422 *user;
	u64 load_time;
	struct bpf_map___304 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___89 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___89 {
	struct bpf_prog___89 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___89 {
	struct callback_head rcu;
	struct bpf_prog_array_item___89 items[0];
};

struct cgroup_bpf___89 {
	struct bpf_prog_array___89 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___89 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___304;

typedef void (*kthread_work_func_t___304)(struct kthread_work___304 *);

struct kthread_worker___304;

struct kthread_work___304 {
	struct list_head node;
	kthread_work_func_t___304 func;
	struct kthread_worker___304 *worker;
	int canceling;
};

struct kthread_worker___304 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___456 *task;
	struct kthread_work___304 *current_work;
};

struct kthread_delayed_work___303 {
	struct kthread_work___304 work;
	struct timer_list timer;
};

struct psi_group___303 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___304 *poll_kworker;
	struct kthread_delayed_work___303 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___303;

struct cgroup_rstat_cpu___303;

struct cgroup___303 {
	struct cgroup_subsys_state___303 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___449 *kn;
	struct cgroup_file___303 procs_file;
	struct cgroup_file___303 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___303 *subsys[13];
	struct cgroup_root___303 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___303 *dom_cgrp;
	struct cgroup_rstat_cpu___303 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___89 bpf;
	atomic_t congestion_count;
	struct cgroup___303 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___303 psi;
	int ancestor_ids[0];
};

struct cftype___303;

struct cgroup_subsys___303 {
	struct cgroup_subsys_state___303 * (*css_alloc)(struct cgroup_subsys_state___303 *);
	int (*css_online)(struct cgroup_subsys_state___303 *);
	void (*css_offline)(struct cgroup_subsys_state___303 *);
	void (*css_released)(struct cgroup_subsys_state___303 *);
	void (*css_free)(struct cgroup_subsys_state___303 *);
	void (*css_reset)(struct cgroup_subsys_state___303 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___303 *, int);
	int (*css_extra_stat_show)(struct seq_file___393 *, struct cgroup_subsys_state___303 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___456 *);
	void (*cancel_fork)(struct task_struct___456 *);
	void (*fork)(struct task_struct___456 *);
	void (*exit)(struct task_struct___456 *);
	void (*free)(struct task_struct___456 *);
	void (*bind)(struct cgroup_subsys_state___303 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___303 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___303 *dfl_cftypes;
	struct cftype___303 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___303 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___303 *updated_children;
	struct cgroup___303 *updated_next;
};

struct cgroup_root___303 {
	struct kernfs_root___448 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___303 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___303 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___303 *ss;
	struct list_head node;
	struct kernfs_ops___448 *kf_ops;
	int (*open)(struct kernfs_open_file___448 *);
	void (*release)(struct kernfs_open_file___448 *);
	u64 (*read_u64)(struct cgroup_subsys_state___303 *, struct cftype___303 *);
	s64 (*read_s64)(struct cgroup_subsys_state___303 *, struct cftype___303 *);
	int (*seq_show)(struct seq_file___393 *, void *);
	void * (*seq_start)(struct seq_file___393 *, loff_t *);
	void * (*seq_next)(struct seq_file___393 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___393 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___303 *, struct cftype___303 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___303 *, struct cftype___303 *, s64);
	ssize_t (*write)(struct kernfs_open_file___448 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___448 *, struct poll_table_struct___293 *);
};

struct xdp_rxq_info___99 {
	struct net_device___99 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___99 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___99 *dev_rx;
};

struct netlink_skb_parms___17 {
	struct scm_creds creds;
	__u32 portid;
	__u32 dst_group;
	__u32 flags;
	struct sock___79 *sk;
	bool nsid_is_set;
	int nsid;
};

struct netlink_callback___101 {
	struct sk_buff___100 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___101 *);
	int (*dump)(struct sk_buff___100 *, struct netlink_callback___101 *);
	int (*done)(struct netlink_callback___101 *);
	void *data;
	struct module___380 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___99 {
	int (*create)(struct sk_buff___100 *, struct net_device___99 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___100 *, unsigned char *);
	int (*cache)(const struct neighbour___79 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___99 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___99 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___99 *, int);
	int poll_owner;
	struct net_device___99 *dev;
	struct sk_buff___100 *gro_list;
	struct sk_buff___100 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___99 {
	struct net_device___99 *dev;
	struct Qdisc___91 *qdisc;
	struct Qdisc___91 *qdisc_sleeping;
	struct kobject___442 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___99 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___91 {
	struct sk_buff___100 *head;
	struct sk_buff___100 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___91;

struct Qdisc___91 {
	int (*enqueue)(struct sk_buff___100 *, struct Qdisc___91 *, struct sk_buff___100 **);
	struct sk_buff___100 * (*dequeue)(struct Qdisc___91 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___91 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___99 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___99 gso_skb;
	struct qdisc_skb_head___91 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___91 *next_sched;
	struct sk_buff_head___99 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___99 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___442 kobj;
	struct net_device___99 *dev;
	long: 64;
	struct xdp_rxq_info___99 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___99)(struct net_device___99 *, struct sk_buff___100 *, struct net_device___99 *);

struct netdev_bpf___99 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___89 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___89 *prog;
			const struct bpf_prog_offload_ops___89 *ops;
		} verifier;
		struct {
			struct bpf_prog___89 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___99 *offmap;
		};
		struct {
			struct xdp_umem___3 *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___99 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___100 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___99 {
	int (*tls_dev_add)(struct net_device___99 *, struct sock___79 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___99 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___99 *, struct sock___79 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___99 {
	int (*ndo_init)(struct net_device___99 *);
	void (*ndo_uninit)(struct net_device___99 *);
	int (*ndo_open)(struct net_device___99 *);
	int (*ndo_stop)(struct net_device___99 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___100 *, struct net_device___99 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___100 *, struct net_device___99 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___99 *, struct sk_buff___100 *, struct net_device___99 *, select_queue_fallback_t___99);
	void (*ndo_change_rx_flags)(struct net_device___99 *, int);
	void (*ndo_set_rx_mode)(struct net_device___99 *);
	int (*ndo_set_mac_address)(struct net_device___99 *, void *);
	int (*ndo_validate_addr)(struct net_device___99 *);
	int (*ndo_do_ioctl)(struct net_device___99 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___99 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___99 *, int);
	int (*ndo_neigh_setup)(struct net_device___99 *, struct neigh_parms___79 *);
	void (*ndo_tx_timeout)(struct net_device___99 *);
	void (*ndo_get_stats64)(struct net_device___99 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___99 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___99 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___99 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___99 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___99 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___99 *);
	int (*ndo_netpoll_setup)(struct net_device___99 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___99 *);
	int (*ndo_set_vf_mac)(struct net_device___99 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___99 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___99 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___99 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___99 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___99 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___99 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___99 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___99 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___99 *, int, struct sk_buff___100 *);
	int (*ndo_set_vf_guid)(struct net_device___99 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___99 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___99 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___99 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___99 *, const struct sk_buff___100 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___99 *, struct net_device___99 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___99 *, struct net_device___99 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___99 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___99 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___99 *, struct neighbour___79 *);
	void (*ndo_neigh_destroy)(struct net_device___99 *, struct neighbour___79 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___99 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___99 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___99 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___100 *, struct netlink_callback___101 *, struct net_device___99 *, struct net_device___99 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___99 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___99 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___100 *, u32, u32, struct net_device___99 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___99 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___99 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___99 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___99 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___99 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___99 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___99 *, struct net_device___99 *);
	void (*ndo_dfwd_del_station)(struct net_device___99 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___99 *);
	int (*ndo_set_tx_maxrate)(struct net_device___99 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___99 *);
	int (*ndo_change_proto_down)(struct net_device___99 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___99 *, struct sk_buff___100 *);
	void (*ndo_set_rx_headroom)(struct net_device___99 *, int);
	int (*ndo_bpf)(struct net_device___99 *, struct netdev_bpf___99 *);
	int (*ndo_xdp_xmit)(struct net_device___99 *, int, struct xdp_frame___99 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___99 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___99 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___79 {
	possible_net_t___101 net;
	struct net_device___99 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___79 *);
	void (*neigh_cleanup)(struct neighbour___79 *);
	struct neigh_table___79 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct switchdev_attr___4;

struct switchdev_obj___4;

struct switchdev_ops___4 {
	int (*switchdev_port_attr_get)(struct net_device___99 *, struct switchdev_attr___4 *);
	int (*switchdev_port_attr_set)(struct net_device___99 *, const struct switchdev_attr___4 *, struct switchdev_trans *);
	int (*rh_reserved_switchdev_port_obj_add)(struct net_device___99 *, const struct switchdev_obj___4 *, struct switchdev_trans *);
	int (*rh_reserved_switchdev_port_obj_del)(struct net_device___99 *, const struct switchdev_obj___4 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t switchdev_ops_extended_size_rh;
	struct switchdev_ops_extended_rh switchdev_ops_extended_rh;
};

struct l3mdev_ops___79 {
	u32 (*l3mdev_fib_table)(const struct net_device___99 *);
	struct sk_buff___100 * (*l3mdev_l3_rcv)(struct net_device___99 *, struct sk_buff___100 *, u16);
	struct sk_buff___100 * (*l3mdev_l3_out)(struct net_device___99 *, struct sock___79 *, struct sk_buff___100 *, u16);
	struct dst_entry___79 * (*l3mdev_link_scope_lookup)(const struct net_device___99 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct ndisc_ops___50 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___99 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___99 *, struct neighbour___79 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___99 *, u8, struct neighbour___79 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___99 *, struct sk_buff___100 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___110 *, struct net_device___99 *, const struct prefix_info *, struct inet6_dev___50 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct in_ifaddr___14;

struct ip_mc_list___6;

struct in_device___14 {
	struct net_device___99 *dev;
	refcount_t refcnt;
	int dead;
	struct in_ifaddr___14 *ifa_list;
	struct ip_mc_list___6 *mc_list;
	struct ip_mc_list___6 **mc_hash;
	int mc_count;
	spinlock_t mc_tomb_lock;
	struct ip_mc_list___6 *mc_tomb;
	long unsigned int mr_v1_seen;
	long unsigned int mr_v2_seen;
	long unsigned int mr_maxdelay;
	long unsigned int mr_qi;
	long unsigned int mr_qri;
	unsigned char mr_qrv;
	unsigned char mr_gq_running;
	unsigned char mr_ifc_count;
	struct timer_list mr_gq_timer;
	struct timer_list mr_ifc_timer;
	struct neigh_parms___79 *arp_parms;
	struct ipv4_devconf cnf;
	struct callback_head callback_head;
};

struct ifmcaddr6___50;

struct ifacaddr6___22;

struct inet6_dev___50 {
	struct net_device___99 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___50 *mc_list;
	struct ifmcaddr6___50 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___22 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	u8 rndid[8];
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___79 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
};

struct tcf_proto___91;

struct mini_Qdisc___91 {
	struct tcf_proto___91 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___91 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___99 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___110 *, struct net_device___99 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___99 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___99 *, struct list_head *);
	size_t (*get_size)(const struct net_device___99 *);
	int (*fill_info)(struct sk_buff___100 *, const struct net_device___99 *);
	size_t (*get_xstats_size)(const struct net_device___99 *);
	int (*fill_xstats)(struct sk_buff___100 *, const struct net_device___99 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___99 *, struct net_device___99 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___99 *, const struct net_device___99 *);
	int (*fill_slave_info)(struct sk_buff___100 *, const struct net_device___99 *, const struct net_device___99 *);
	struct net___110 * (*get_link_net)(const struct net_device___99 *);
	size_t (*get_linkxstats_size)(const struct net_device___99 *, int);
	int (*fill_linkxstats)(struct sk_buff___100 *, const struct net_device___99 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct offload_callbacks___17 {
	struct sk_buff___100 * (*gso_segment)(struct sk_buff___100 *, netdev_features_t);
	struct sk_buff___100 ** (*gro_receive)(struct sk_buff___100 **, struct sk_buff___100 *);
	int (*gro_complete)(struct sk_buff___100 *, int);
};

struct netdev_notifier_info___10 {
	struct net_device___99 *dev;
	struct netlink_ext_ack *extack;
};

struct softnet_data___99 {
	struct list_head poll_list;
	struct sk_buff_head___99 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___99 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___91 *output_queue;
	struct Qdisc___91 **output_queue_tailp;
	struct sk_buff___100 *completion_queue;
	struct sk_buff_head___99 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___99 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___99 input_pkt_queue;
	struct napi_struct___99 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct in_ifaddr___14 {
	struct hlist_node hash;
	struct in_ifaddr___14 *ifa_next;
	struct in_device___14 *ifa_dev;
	struct callback_head callback_head;
	__be32 ifa_local;
	__be32 ifa_address;
	__be32 ifa_mask;
	__u32 ifa_rt_priority;
	__be32 ifa_broadcast;
	unsigned char ifa_scope;
	unsigned char ifa_prefixlen;
	__u32 ifa_flags;
	char ifa_label[16];
	__u32 ifa_valid_lft;
	__u32 ifa_preferred_lft;
	long unsigned int ifa_cstamp;
	long unsigned int ifa_tstamp;
};

struct ip_mc_list___6 {
	struct in_device___14 *interface;
	__be32 multiaddr;
	unsigned int sfmode;
	struct ip_sf_list *sources;
	struct ip_sf_list *tomb;
	long unsigned int sfcount[2];
	union {
		struct ip_mc_list___6 *next;
		struct ip_mc_list___6 *next_rcu;
	};
	struct ip_mc_list___6 *next_hash;
	struct timer_list timer;
	int users;
	refcount_t refcnt;
	spinlock_t lock;
	char tm_running;
	char reporter;
	char unsolicit_count;
	char loaded;
	unsigned char gsquery;
	unsigned char crcount;
	struct callback_head rcu;
};

enum {
	PIM_TYPE_HELLO = 0,
	PIM_TYPE_REGISTER = 1,
	PIM_TYPE_REGISTER_STOP = 2,
	PIM_TYPE_JOIN_PRUNE = 3,
	PIM_TYPE_BOOTSTRAP = 4,
	PIM_TYPE_ASSERT = 5,
	PIM_TYPE_GRAFT = 6,
	PIM_TYPE_GRAFT_ACK = 7,
	PIM_TYPE_CANDIDATE_RP_ADV = 8,
};

struct pimreghdr {
	__u8 type;
	__u8 reserved;
	__be16 csum;
	__be32 flags;
};

struct fib_notifier_info___5 {
	struct net___110 *net;
	int family;
	struct netlink_ext_ack *extack;
};

struct fib_rule___79 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___79 *ctarget;
	struct net___110 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___79 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___79 *rule;
	u32 table;
	int flags;
};

typedef short unsigned int vifi_t;

struct vifctl {
	vifi_t vifc_vifi;
	unsigned char vifc_flags;
	unsigned char vifc_threshold;
	unsigned int vifc_rate_limit;
	union {
		struct in_addr vifc_lcl_addr;
		int vifc_lcl_ifindex;
	};
	struct in_addr vifc_rmt_addr;
};

struct mfcctl {
	struct in_addr mfcc_origin;
	struct in_addr mfcc_mcastgrp;
	vifi_t mfcc_parent;
	unsigned char mfcc_ttls[32];
	unsigned int mfcc_pkt_cnt;
	unsigned int mfcc_byte_cnt;
	unsigned int mfcc_wrong_if;
	int mfcc_expire;
};

struct sioc_sg_req {
	struct in_addr src;
	struct in_addr grp;
	long unsigned int pktcnt;
	long unsigned int bytecnt;
	long unsigned int wrong_if;
};

struct sioc_vif_req {
	vifi_t vifi;
	long unsigned int icount;
	long unsigned int ocount;
	long unsigned int ibytes;
	long unsigned int obytes;
};

struct igmpmsg {
	__u32 unused1;
	__u32 unused2;
	unsigned char im_msgtype;
	unsigned char im_mbz;
	unsigned char im_vif;
	unsigned char unused3;
	struct in_addr im_src;
	struct in_addr im_dst;
};

enum {
	IPMRA_TABLE_UNSPEC = 0,
	IPMRA_TABLE_ID = 1,
	IPMRA_TABLE_CACHE_RES_QUEUE_LEN = 2,
	IPMRA_TABLE_MROUTE_REG_VIF_NUM = 3,
	IPMRA_TABLE_MROUTE_DO_ASSERT = 4,
	IPMRA_TABLE_MROUTE_DO_PIM = 5,
	IPMRA_TABLE_VIFS = 6,
	__IPMRA_TABLE_MAX = 7,
};

enum {
	IPMRA_VIF_UNSPEC = 0,
	IPMRA_VIF = 1,
	__IPMRA_VIF_MAX = 2,
};

enum {
	IPMRA_VIFA_UNSPEC = 0,
	IPMRA_VIFA_IFINDEX = 1,
	IPMRA_VIFA_VIF_ID = 2,
	IPMRA_VIFA_FLAGS = 3,
	IPMRA_VIFA_BYTES_IN = 4,
	IPMRA_VIFA_BYTES_OUT = 5,
	IPMRA_VIFA_PACKETS_IN = 6,
	IPMRA_VIFA_PACKETS_OUT = 7,
	IPMRA_VIFA_LOCAL_ADDR = 8,
	IPMRA_VIFA_REMOTE_ADDR = 9,
	IPMRA_VIFA_PAD = 10,
	__IPMRA_VIFA_MAX = 11,
};

enum {
	IPMRA_CREPORT_UNSPEC = 0,
	IPMRA_CREPORT_MSGTYPE = 1,
	IPMRA_CREPORT_VIF_ID = 2,
	IPMRA_CREPORT_SRC_ADDR = 3,
	IPMRA_CREPORT_DST_ADDR = 4,
	IPMRA_CREPORT_PKT = 5,
	__IPMRA_CREPORT_MAX = 6,
};

struct bdi_writeback_congested___244 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___244 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___244 {
	struct bio___244 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___246 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___246 bip_inline_vecs[0];
};

struct bio_set___244 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___244 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___187 {
	struct mem_cgroup___187 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___187 {
	struct lruvec___455 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___187 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___187 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct kernel_param_ops___380 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___380 *);
	int (*get)(char *, const struct kernel_param___380 *);
	void (*free)(void *);
};

struct kparam_array___380;

struct kernel_param___380 {
	const char *name;
	struct module___380 *mod;
	const struct kernel_param_ops___380 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___380 *arr;
	};
};

struct kparam_array___380 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___380 *ops;
	void *elem;
};

struct module_attribute___380 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___380 *, struct module_kobject___380 *, char *);
	ssize_t (*store)(struct module_attribute___380 *, struct module_kobject___380 *, const char *, size_t);
	void (*setup)(struct module___380 *, const char *);
	int (*test)(struct module___380 *);
	void (*free)(struct module___380 *);
};

struct gnet_dump___91 {
	spinlock_t *lock;
	struct sk_buff___100 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___91;

struct Qdisc_ops___91 {
	struct Qdisc_ops___91 *next;
	const struct Qdisc_class_ops___91 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___100 *, struct Qdisc___91 *, struct sk_buff___100 **);
	struct sk_buff___100 * (*dequeue)(struct Qdisc___91 *);
	struct sk_buff___100 * (*peek)(struct Qdisc___91 *);
	int (*init)(struct Qdisc___91 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___91 *);
	void (*destroy)(struct Qdisc___91 *);
	int (*change)(struct Qdisc___91 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___91 *);
	int (*change_tx_queue_len)(struct Qdisc___91 *, unsigned int);
	int (*dump)(struct Qdisc___91 *, struct sk_buff___100 *);
	int (*dump_stats)(struct Qdisc___91 *, struct gnet_dump___91 *);
	void (*ingress_block_set)(struct Qdisc___91 *, u32);
	void (*egress_block_set)(struct Qdisc___91 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___91 *);
	u32 (*egress_block_get)(struct Qdisc___91 *);
	struct module___380 *owner;
};

struct tcf_block___91;

struct Qdisc_class_ops___91 {
	unsigned int flags;
	struct netdev_queue___99 * (*select_queue)(struct Qdisc___91 *, struct tcmsg *);
	int (*graft)(struct Qdisc___91 *, long unsigned int, struct Qdisc___91 *, struct Qdisc___91 **, struct netlink_ext_ack *);
	struct Qdisc___91 * (*leaf)(struct Qdisc___91 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___91 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___91 *, u32);
	int (*change)(struct Qdisc___91 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___91 *, long unsigned int);
	void (*walk)(struct Qdisc___91 *, struct qdisc_walker *);
	struct tcf_block___91 * (*tcf_block)(struct Qdisc___91 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___91 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___91 *, long unsigned int);
	int (*dump)(struct Qdisc___91 *, long unsigned int, struct sk_buff___100 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___91 *, long unsigned int, struct gnet_dump___91 *);
};

struct tcf_chain___91;

struct tcf_block___91 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___110 *net;
	struct Qdisc___91 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___91 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___91;

struct tcf_proto_ops___91;

struct tcf_proto___91 {
	struct tcf_proto___91 *next;
	void *root;
	int (*classify)(struct sk_buff___100 *, const struct tcf_proto___91 *, struct tcf_result___91 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___91 *ops;
	struct tcf_chain___91 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___91 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___91 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___91 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___100 *, const struct tcf_proto___91 *, struct tcf_result___91 *);
	int (*init)(struct tcf_proto___91 *);
	void (*destroy)(struct tcf_proto___91 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___91 *, u32);
	void (*put)(struct tcf_proto___91 *, void *);
	int (*change)(struct net___110 *, struct sk_buff___100 *, struct tcf_proto___91 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___91 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___91 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___91 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___110 *, struct tcf_chain___91 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___110 *, struct tcf_proto___91 *, void *, struct sk_buff___100 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___100 *, struct net___110 *, void *);
	struct module___380 *owner;
	int flags;
};

struct tcf_chain___91 {
	struct mutex filter_chain_lock;
	struct tcf_proto___91 *filter_chain;
	struct list_head list;
	struct tcf_block___91 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___91 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___79 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___89 *prog;
};

struct bpf_redirect_info___89 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___304 *map;
	struct bpf_map___304 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___79;

struct neigh_hash_table___79;

struct neigh_table___79 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___99 *, __u32 *);
	bool (*key_eq)(const struct neighbour___79 *, const void *);
	int (*constructor)(struct neighbour___79 *);
	int (*pconstructor)(struct pneigh_entry___79 *);
	void (*pdestructor)(struct pneigh_entry___79 *);
	void (*proxy_redo)(struct sk_buff___100 *);
	char *id;
	struct neigh_parms___79 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___99 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___79 *nht;
	struct pneigh_entry___79 **phash_buckets;
};

struct neigh_ops___79 {
	int family;
	void (*solicit)(struct neighbour___79 *, struct sk_buff___100 *);
	void (*error_report)(struct neighbour___79 *, struct sk_buff___100 *);
	int (*output)(struct neighbour___79 *, struct sk_buff___100 *);
	int (*connected_output)(struct neighbour___79 *, struct sk_buff___100 *);
};

struct pneigh_entry___79 {
	struct pneigh_entry___79 *next;
	possible_net_t___101 net;
	struct net_device___99 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___79 {
	struct neighbour___79 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___11 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___110 *, struct sock___79 *, struct sk_buff___100 *);
	int (*orig_input)(struct sk_buff___100 *);
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	__u8 data[0];
};

struct request_sock_ops___62;

struct timewait_sock_ops___58;

struct proto___79 {
	void (*close)(struct sock___79 *, long int);
	int (*pre_connect)(struct sock___79 *, struct sockaddr *, int);
	int (*connect)(struct sock___79 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___79 *, int);
	struct sock___79 * (*accept)(struct sock___79 *, int, int *, bool);
	int (*ioctl)(struct sock___79 *, int, long unsigned int);
	int (*init)(struct sock___79 *);
	void (*destroy)(struct sock___79 *);
	void (*shutdown)(struct sock___79 *, int);
	int (*setsockopt)(struct sock___79 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___79 *, int, int, char *, int *);
	void (*keepalive)(struct sock___79 *, int);
	int (*sendmsg)(struct sock___79 *, struct msghdr___82 *, size_t);
	int (*recvmsg)(struct sock___79 *, struct msghdr___82 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___79 *, struct page___455 *, int, size_t, int);
	int (*bind)(struct sock___79 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___79 *, struct sk_buff___100 *);
	void (*release_cb)(struct sock___79 *);
	int (*hash)(struct sock___79 *);
	void (*unhash)(struct sock___79 *);
	void (*rehash)(struct sock___79 *);
	int (*get_port)(struct sock___79 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___79 *);
	bool (*stream_memory_read)(const struct sock___79 *);
	void (*enter_memory_pressure)(struct sock___79 *);
	void (*leave_memory_pressure)(struct sock___79 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___62 *rsk_prot;
	struct timewait_sock_ops___58 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___380 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___79 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct request_sock___63;

struct request_sock_ops___62 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___79 *, struct request_sock___63 *);
	void (*send_ack)(const struct sock___79 *, struct sk_buff___100 *, struct request_sock___63 *);
	void (*send_reset)(const struct sock___79 *, struct sk_buff___100 *);
	void (*destructor)(struct request_sock___63 *);
	void (*syn_ack_timeout)(const struct request_sock___63 *);
};

struct timewait_sock_ops___58 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___79 *, struct sock___79 *, void *);
	void (*twsk_destructor)(struct sock___79 *);
};

struct request_sock___63 {
	struct sock_common___79 __req_common;
	struct request_sock___63 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___62 *rsk_ops;
	struct sock___79 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct inet_cork___18 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___79 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
	__u16 gso_size;
	u64 transmit_time;
};

struct inet_cork_full___18 {
	struct inet_cork___18 base;
	struct flowi fl;
};

struct ipv6_pinfo___18;

struct inet_sock___18 {
	struct sock___79 sk;
	struct ipv6_pinfo___18 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	__be16 inet_sport;
	__u16 inet_id;
	struct ip_options_rcu *inet_opt;
	int rx_dst_ifindex;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 bind_address_no_port: 1;
	__u8 defer_connect: 1;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___18 cork;
};

struct ipv6_fl_socklist___17;

struct ipv6_pinfo___18 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
			__u16 recvfragsize: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 repflow: 1;
	__u16 pmtudisc: 3;
	__u16 padding: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u16 autoflowlabel: 1;
	__u16 autoflowlabel_set: 1;
	__u8 min_hopcount;
	__u8 tclass;
	__be32 rcv_flowinfo;
	__u32 dst_cookie;
	__u32 rx_dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___17 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___100 *pktoptions;
	struct sk_buff___100 *rxpmtu;
	struct inet6_cork cork;
};

struct ip6_flowlabel___17;

struct ipv6_fl_socklist___17 {
	struct ipv6_fl_socklist___17 *next;
	struct ip6_flowlabel___17 *fl;
	struct callback_head rcu;
};

struct ifmcaddr6___50 {
	struct in6_addr mca_addr;
	struct inet6_dev___50 *idev;
	struct ifmcaddr6___50 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___22 {
	struct in6_addr aca_addr;
	struct fib6_info___22 *aca_rt;
	struct ifacaddr6___22 *aca_next;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct ip6_ra_chain___50 {
	struct ip6_ra_chain___50 *next;
	struct sock___79 *sk;
	int sel;
	void (*destructor)(struct sock___79 *);
};

struct ip6_flowlabel___17 {
	struct ip6_flowlabel___17 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___251 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___110 *fl_net;
};

struct rtable___16 {
	struct dst_entry___79 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	__be32 rt_gateway;
	u32 rt_mtu_locked: 1;
	u32 rt_pmtu: 31;
	struct list_head rt_uncached;
	struct uncached_list *rt_uncached_list;
};

struct fib_dump_filter___3 {
	u32 table_id;
	bool filter_set;
	bool dump_all_families;
	bool dump_routes;
	bool dump_exceptions;
	unsigned char protocol;
	unsigned char rt_type;
	unsigned int flags;
	struct net_device___99 *dev;
};

struct vif_device {
	struct net_device___99 *dev;
	long unsigned int bytes_in;
	long unsigned int bytes_out;
	long unsigned int pkt_in;
	long unsigned int pkt_out;
	long unsigned int rate_limit;
	unsigned char threshold;
	short unsigned int flags;
	int link;
	struct netdev_phys_item_id dev_parent_id;
	__be32 local;
	__be32 remote;
};

struct vif_entry_notifier_info {
	struct fib_notifier_info___5 info;
	struct net_device___99 *dev;
	short unsigned int vif_index;
	short unsigned int vif_flags;
	u32 tb_id;
};

enum {
	MFC_STATIC = 1,
	MFC_OFFLOAD = 2,
};

struct mr_mfc {
	struct rhlist_head mnode;
	short unsigned int mfc_parent;
	int mfc_flags;
	union {
		struct {
			long unsigned int expires;
			struct sk_buff_head___99 unresolved;
		} unres;
		struct {
			long unsigned int last_assert;
			int minvif;
			int maxvif;
			long unsigned int bytes;
			long unsigned int pkt;
			long unsigned int wrong_if;
			long unsigned int lastuse;
			unsigned char ttls[32];
			refcount_t refcount;
		} res;
	} mfc_un;
	struct list_head list;
	struct callback_head rcu;
	void (*free)(struct callback_head *);
};

struct mfc_entry_notifier_info {
	struct fib_notifier_info___5 info;
	struct mr_mfc *mfc;
	u32 tb_id;
};

struct mr_table_ops {
	const struct rhashtable_params *rht_params;
	void *cmparg_any;
};

struct mr_table {
	struct list_head list;
	possible_net_t___101 net;
	struct mr_table_ops ops;
	u32 id;
	struct sock___79 *mroute_sk;
	struct timer_list ipmr_expire_timer;
	struct list_head mfc_unres_queue;
	struct vif_device vif_table[32];
	struct rhltable mfc_hash;
	struct list_head mfc_cache_list;
	int maxvif;
	atomic_t cache_resolve_queue_len;
	bool mroute_do_assert;
	bool mroute_do_pim;
	int mroute_reg_vif_num;
};

struct mr_vif_iter {
	struct seq_net_private___11 p;
	struct mr_table *mrt;
	int ct;
};

struct mr_mfc_iter {
	struct seq_net_private___11 p;
	struct mr_table *mrt;
	struct list_head *cache;
	spinlock_t *lock;
};

struct mfc_cache_cmp_arg {
	__be32 mfc_mcastgrp;
	__be32 mfc_origin;
};

struct mfc_cache {
	struct mr_mfc _c;
	union {
		struct {
			__be32 mfc_mcastgrp;
			__be32 mfc_origin;
		};
		struct mfc_cache_cmp_arg cmparg;
	};
};

struct net_protocol___15 {
	int (*early_demux)(struct sk_buff___100 *);
	int (*early_demux_handler)(struct sk_buff___100 *);
	int (*handler)(struct sk_buff___100 *);
	void (*err_handler)(struct sk_buff___100 *, u32);
	unsigned int no_policy: 1;
	unsigned int netns_ok: 1;
	unsigned int icmp_strict_tag_validation: 1;
};

struct inet6_protocol___15 {
	void (*early_demux)(struct sk_buff___100 *);
	void (*early_demux_handler)(struct sk_buff___100 *);
	int (*handler)(struct sk_buff___100 *);
	void (*err_handler)(struct sk_buff___100 *, struct inet6_skb_parm *, u8, u8, int, __be32);
	unsigned int flags;
};

struct net_offload___15 {
	struct offload_callbacks___17 callbacks;
	unsigned int flags;
};

struct raw_sock___2 {
	struct inet_sock___18 inet;
	struct icmp_filter filter;
	u32 ipmr_table;
};

struct nf_hook_state___15 {
	unsigned int hook;
	u_int8_t pf;
	struct net_device___99 *in;
	struct net_device___99 *out;
	struct sock___79 *sk;
	struct net___110 *net;
	int (*okfn)(struct net___110 *, struct sock___79 *, struct sk_buff___100 *);
};

struct nf_nat_hook___15 {
	int (*parse_nat_setup)(struct nf_conn *, enum nf_nat_manip_type, const struct nlattr *);
	void (*decode_session)(struct sk_buff___100 *, struct flowi *);
	unsigned int (*manip_pkt)(struct sk_buff___100 *, struct nf_conn *, enum nf_nat_manip_type, enum ip_conntrack_dir);
};

struct nf_ct_hook___15 {
	int (*update)(struct net___110 *, struct sk_buff___100 *);
	void (*destroy)(struct nf_conntrack *);
	bool (*get_tuple_skb)(struct nf_conntrack_tuple *, const struct sk_buff___100 *);
};

struct nfnl_ct_hook___15 {
	struct nf_conn * (*get_ct)(const struct sk_buff___100 *, enum ip_conntrack_info *);
	size_t (*build_size)(const struct nf_conn *);
	int (*build)(struct sk_buff___100 *, struct nf_conn *, enum ip_conntrack_info, u_int16_t, u_int16_t);
	int (*parse)(const struct nlattr *, struct nf_conn *);
	int (*attach_expect)(const struct nlattr *, struct nf_conn *, u32, u32);
	void (*seq_adjust)(struct sk_buff___100 *, struct nf_conn *, enum ip_conntrack_info, s32);
};

struct ip_tunnel_parm {
	char name[16];
	int link;
	__be16 i_flags;
	__be16 o_flags;
	__be32 i_key;
	__be32 o_key;
	struct iphdr iph;
};

struct ipv6_stub___16 {
	int (*ipv6_sock_mc_join)(struct sock___79 *, int, const struct in6_addr *);
	int (*ipv6_sock_mc_drop)(struct sock___79 *, int, const struct in6_addr *);
	int (*ipv6_dst_lookup)(struct net___110 *, struct sock___79 *, struct dst_entry___79 **, struct flowi6 *);
	struct fib6_table___22 * (*fib6_get_table)(struct net___110 *, u32);
	struct fib6_info___22 * (*fib6_lookup)(struct net___110 *, int, struct flowi6 *, int);
	struct fib6_info___22 * (*fib6_table_lookup)(struct net___110 *, struct fib6_table___22 *, int, struct flowi6 *, int);
	struct fib6_info___22 * (*fib6_multipath_select)(const struct net___110 *, struct fib6_info___22 *, struct flowi6 *, int, const struct sk_buff___100 *, int);
	u32 (*ip6_mtu_from_fib6)(struct fib6_info___22 *, struct in6_addr *, struct in6_addr *);
	void (*udpv6_encap_enable)();
	void (*ndisc_send_na)(struct net_device___99 *, const struct in6_addr *, const struct in6_addr *, bool, bool, bool, bool);
	struct neigh_table___79 *nd_tbl;
};

struct ipv6_bpf_stub___16 {
	int (*inet6_bind)(struct sock___79 *, struct sockaddr *, int, bool, bool);
	struct sock___79 * (*udp6_lib_lookup)(struct net___110 *, const struct in6_addr *, __be16, const struct in6_addr *, __be16, int, int, struct udp_table *, struct sk_buff___100 *);
};

struct ip_tunnel_encap_ops___10 {
	size_t (*encap_hlen)(struct ip_tunnel_encap *);
	int (*build_header)(struct sk_buff___100 *, struct ip_tunnel_encap *, u8 *, struct flowi4 *);
};

struct switchdev_attr___4 {
	struct net_device___99 *orig_dev;
	enum switchdev_attr_id id;
	u32 flags;
	void *complete_priv;
	void (*complete)(struct net_device___99 *, int, void *);
	union {
		struct netdev_phys_item_id ppid;
		u8 stp_state;
		long unsigned int brport_flags;
		long unsigned int brport_flags_support;
		bool mrouter;
		clock_t ageing_time;
		bool vlan_filtering;
		bool mc_disabled;
	} u;
};

struct switchdev_obj___4 {
	struct net_device___99 *orig_dev;
	enum switchdev_obj_id id;
	u32 flags;
	void *complete_priv;
	void (*complete)(struct net_device___99 *, int, void *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct ipmr_result {
	struct mr_table *mrt;
};

struct netlink_skb_parms___18 {
	struct scm_creds creds;
	__u32 portid;
	__u32 dst_group;
	__u32 flags;
	struct sock___76 *sk;
	bool nsid_is_set;
	int nsid;
};

struct rta_mfc_stats {
	__u64 mfcs_packets;
	__u64 mfcs_bytes;
	__u64 mfcs_wrong_if;
};

struct fib_dump_filter___4 {
	u32 table_id;
	bool filter_set;
	bool dump_all_families;
	bool dump_routes;
	bool dump_exceptions;
	unsigned char protocol;
	unsigned char rt_type;
	unsigned int flags;
	struct net_device___96 *dev;
};

struct vif_device___2 {
	struct net_device___96 *dev;
	long unsigned int bytes_in;
	long unsigned int bytes_out;
	long unsigned int pkt_in;
	long unsigned int pkt_out;
	long unsigned int rate_limit;
	unsigned char threshold;
	short unsigned int flags;
	int link;
	struct netdev_phys_item_id dev_parent_id;
	__be32 local;
	__be32 remote;
};

struct vif_entry_notifier_info___2 {
	struct fib_notifier_info___4 info;
	struct net_device___96 *dev;
	short unsigned int vif_index;
	short unsigned int vif_flags;
	u32 tb_id;
};

struct mr_mfc___2 {
	struct rhlist_head mnode;
	short unsigned int mfc_parent;
	int mfc_flags;
	union {
		struct {
			long unsigned int expires;
			struct sk_buff_head___96 unresolved;
		} unres;
		struct {
			long unsigned int last_assert;
			int minvif;
			int maxvif;
			long unsigned int bytes;
			long unsigned int pkt;
			long unsigned int wrong_if;
			long unsigned int lastuse;
			unsigned char ttls[32];
			refcount_t refcount;
		} res;
	} mfc_un;
	struct list_head list;
	struct callback_head rcu;
	void (*free)(struct callback_head *);
};

struct mfc_entry_notifier_info___2 {
	struct fib_notifier_info___4 info;
	struct mr_mfc___2 *mfc;
	u32 tb_id;
};

struct mr_table___2 {
	struct list_head list;
	possible_net_t___98 net;
	struct mr_table_ops ops;
	u32 id;
	struct sock___76 *mroute_sk;
	struct timer_list ipmr_expire_timer;
	struct list_head mfc_unres_queue;
	struct vif_device___2 vif_table[32];
	struct rhltable mfc_hash;
	struct list_head mfc_cache_list;
	int maxvif;
	atomic_t cache_resolve_queue_len;
	bool mroute_do_assert;
	bool mroute_do_pim;
	int mroute_reg_vif_num;
};

struct mr_vif_iter___2 {
	struct seq_net_private___8 p;
	struct mr_table___2 *mrt;
	int ct;
};

struct mr_mfc_iter___2 {
	struct seq_net_private___8 p;
	struct mr_table___2 *mrt;
	struct list_head *cache;
	spinlock_t *lock;
};

struct module___381;

struct file___455;

struct kiocb___455;

struct iov_iter___222;

struct poll_table_struct___294;

struct vm_area_struct___456;

struct inode___455;

struct file_lock___455;

struct page___456;

struct pipe_inode_info___136;

struct seq_file___394;

struct file_operations___455 {
	struct module___381 *owner;
	loff_t (*llseek)(struct file___455 *, loff_t, int);
	ssize_t (*read)(struct file___455 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___455 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___455 *, struct iov_iter___222 *);
	ssize_t (*write_iter)(struct kiocb___455 *, struct iov_iter___222 *);
	int (*iopoll)(struct kiocb___455 *, bool);
	int (*iterate)(struct file___455 *, struct dir_context *);
	int (*iterate_shared)(struct file___455 *, struct dir_context *);
	__poll_t (*poll)(struct file___455 *, struct poll_table_struct___294 *);
	long int (*unlocked_ioctl)(struct file___455 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___455 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___455 *, struct vm_area_struct___456 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___455 *, struct file___455 *);
	int (*flush)(struct file___455 *, fl_owner_t);
	int (*release)(struct inode___455 *, struct file___455 *);
	int (*fsync)(struct file___455 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___455 *, int);
	int (*lock)(struct file___455 *, int, struct file_lock___455 *);
	ssize_t (*sendpage)(struct file___455 *, struct page___456 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___455 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___455 *, int, struct file_lock___455 *);
	ssize_t (*splice_write)(struct pipe_inode_info___136 *, struct file___455 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___455 *, loff_t *, struct pipe_inode_info___136 *, size_t, unsigned int);
	int (*setlease)(struct file___455 *, long int, struct file_lock___455 **, void **);
	long int (*fallocate)(struct file___455 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___394 *, struct file___455 *);
	ssize_t (*copy_file_range)(struct file___455 *, loff_t, struct file___455 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___455 *, loff_t, struct file___455 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___455 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___456 {
	u64 seqnum;
	struct vm_area_struct___456 *vmas[4];
};

struct page_frag___456 {
	struct page___456 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___456;

struct mem_cgroup___188;

struct pid___253;

struct cred___423;

struct nsproxy___350;

struct signal_struct___330;

struct bio_list___245;

struct backing_dev_info___245;

struct css_set___304;

struct vm_struct___359;

struct task_struct___457 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___457 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___456 *mm;
	struct mm_struct___456 *active_mm;
	struct vmacache___456 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___457 *real_parent;
	struct task_struct___457 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___457 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___188 *active_memcg;
	long int rh_reserved2;
	struct pid___253 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___253 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___253 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___423 *ptracer_cred;
	const struct cred___423 *real_cred;
	const struct cred___423 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___350 *nsproxy;
	struct signal_struct___330 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___457 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___245 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___245 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___304 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___136 *splice_pipe;
	struct page_frag___456 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___188 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___457 *oom_reaper_list;
	struct vm_struct___359 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___156 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___456 *pgtable_t___456;

struct address_space___455;

struct dev_pagemap___443;

struct page___456 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___455 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___456 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___456 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___456 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___443 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___188 *mem_cgroup;
};

struct pglist_data___456;

struct lruvec___456 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___456 *pgdat;
};

struct zone___456 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___456 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___456 {
	struct zone___456 *zone;
	int zone_idx;
};

struct zonelist___456 {
	struct zoneref___456 _zonerefs[25];
};

struct pglist_data___456 {
	struct zone___456 node_zones[3];
	struct zonelist___456 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___457 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___457 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___456 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___457 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___457 *owner;
};

struct secondary_data___457 {
	void *stack;
	struct task_struct___457 *task;
	long int status;
};

struct blocking_notifier_head___456 {
	struct rw_semaphore___457 rwsem;
	struct notifier_block *head;
};

struct cgroup___304;

struct cgroup_subsys___304;

struct cgroup_subsys_state___304 {
	struct cgroup___304 *cgroup;
	struct cgroup_subsys___304 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___304 *parent;
};

struct kernfs_node___450;

struct cgroup_file___304 {
	struct kernfs_node___450 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___188;

struct mem_cgroup___188 {
	struct cgroup_subsys_state___304 css;
	struct mem_cgroup_id___16 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___304 events_file;
	struct cgroup_file___304 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___457 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___188 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___253;

struct upid___253 {
	int nr;
	struct pid_namespace___253 *ns;
};

struct dentry___455;

struct user_namespace___320;

struct ucounts___320;

struct pid_namespace___253 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___457 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___253 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___455 *proc_self;
	struct dentry___455 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___320 *user_ns;
	struct ucounts___320 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___29 ns;
};

struct pid___253 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___253 numbers[1];
};

struct key___423;

struct user_namespace___320 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___320 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___29 ns;
	long unsigned int flags;
	struct key___423 *persistent_keyring_register;
	struct rw_semaphore___457 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___320 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct user_struct___423 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___423 *uid_keyring;
	struct key___423 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___443;

struct vm_area_struct___456 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___456 *vm_next;
	struct vm_area_struct___456 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___456 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___443 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___455 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___456;

struct mm_struct___456 {
	struct {
		struct vm_area_struct___456 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___455 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___457 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___456 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___457 *owner;
		struct user_namespace___320 *user_ns;
		struct file___455 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___456 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___423 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___423 *session_keyring;
	struct key___423 *process_keyring;
	struct key___423 *thread_keyring;
	struct key___423 *request_key_auth;
	void *security;
	struct user_struct___423 *user;
	struct user_namespace___320 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___111;

struct cgroup_namespace___304;

struct nsproxy___350 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___253 *pid_ns_for_children;
	struct net___111 *net_ns;
	struct cgroup_namespace___304 *cgroup_ns;
};

struct signal_struct___330 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___457 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___457 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___253 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___253 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___456 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___253 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___245;

struct bio_list___245 {
	struct bio___245 *head;
	struct bio___245 *tail;
};

struct bdi_writeback_congested___245;

struct bdi_writeback___245 {
	struct backing_dev_info___245 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___245 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___304 *memcg_css;
	struct cgroup_subsys_state___304 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___423;

struct backing_dev_info___245 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___245 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___423 *dev;
	struct device___423 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___455 *debug_dir;
	struct dentry___455 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___304 {
	struct cgroup_subsys_state___304 *subsys[13];
	refcount_t refcount;
	struct css_set___304 *dom_cset;
	struct cgroup___304 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___304 *mg_src_cgrp;
	struct cgroup___304 *mg_dst_cgrp;
	struct css_set___304 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___455;

struct pipe_buffer___136;

struct pipe_inode_info___136 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___456 *tmp_page;
	struct fasync_struct___455 *fasync_readers;
	struct fasync_struct___455 *fasync_writers;
	struct pipe_buffer___136 *bufs;
	struct user_struct___423 *user;
};

struct vm_struct___359 {
	struct vm_struct___359 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___456 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___342 {
	struct task_struct___457 task;
	long unsigned int stack[8192];
};

struct address_space_operations___455;

struct address_space___455 {
	struct inode___455 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___457 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___455 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___443)(struct vm_area_struct___456 *, long unsigned int, const struct page___456 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___443)(struct page___456 *, void *);

struct dev_pagemap___443 {
	dev_page_fault_t___443 page_fault;
	dev_page_free_t___443 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___423 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___456 {
	struct vfsmount *mnt;
	struct dentry___455 *dentry;
};

struct fown_struct___253 {
	rwlock_t lock;
	struct pid___253 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___455 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___456 f_path;
	struct inode___455 *f_inode;
	const struct file_operations___455 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___253 f_owner;
	const struct cred___423 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___455 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___443;

struct vm_operations_struct___443 {
	void (*open)(struct vm_area_struct___456 *);
	void (*close)(struct vm_area_struct___456 *);
	int (*split)(struct vm_area_struct___456 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___456 *);
	vm_fault_t (*fault)(struct vm_fault___443 *);
	vm_fault_t (*huge_fault)(struct vm_fault___443 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___443 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___456 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___443 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___443 *);
	int (*access)(struct vm_area_struct___456 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___456 *);
	int (*set_policy)(struct vm_area_struct___456 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___456 *, long unsigned int);
	struct page___456 * (*find_special_page)(struct vm_area_struct___456 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___456 {
	struct task_struct___457 *task;
	struct core_thread___456 *next;
};

struct core_state___456 {
	atomic_t nr_threads;
	struct core_thread___456 dumper;
	struct completion startup;
};

struct vm_fault___443 {
	struct vm_area_struct___456 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___456 *cow_page;
	struct mem_cgroup___188 *memcg;
	struct page___456 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___456 prealloc_pte;
};

struct kset___442;

struct kobj_type___442;

struct kobject___443 {
	const char *name;
	struct list_head entry;
	struct kobject___443 *parent;
	struct kset___442 *kset;
	struct kobj_type___442 *ktype;
	struct kernfs_node___450 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___381 {
	struct kobject___443 kobj;
	struct module___381 *mod;
	struct kobject___443 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___381 {
	struct module___381 *mod;
	struct latch_tree_node node;
};

struct module_layout___381 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___381 mtn;
};

struct module_attribute___381;

struct kernel_param___381;

struct module___381 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___381 mkobj;
	struct module_attribute___381 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___443 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___381 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___381 core_layout;
	struct module_layout___381 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide53;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide54;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bio_vec___247 {
	struct page___456 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___222 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___247 *bvec;
		struct pipe_inode_info___136 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct msghdr___83 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___222 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___455 *msg_iocb;
};

struct kiocb___455 {
	struct file___455 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___455 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dentry_operations___455;

struct super_block___455;

struct dentry___455 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___455 *d_parent;
	struct qstr d_name;
	struct inode___455 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___455 *d_op;
	struct super_block___455 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___455;

struct block_device___455;

struct inode___455 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___455 *i_op;
	struct super_block___455 *i_sb;
	struct address_space___455 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___457 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___245 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___455 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___455 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___136 *i_pipe;
		struct block_device___455 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___455 {
	int (*d_revalidate)(struct dentry___455 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___455 *, unsigned int);
	int (*d_hash)(const struct dentry___455 *, struct qstr *);
	int (*d_compare)(const struct dentry___455 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___455 *);
	int (*d_init)(struct dentry___455 *);
	void (*d_release)(struct dentry___455 *);
	void (*d_prune)(struct dentry___455 *);
	void (*d_iput)(struct dentry___455 *, struct inode___455 *);
	char * (*d_dname)(struct dentry___455 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___456 *);
	int (*d_manage)(const struct path___456 *, bool);
	struct dentry___455 * (*d_real)(struct dentry___455 *, const struct inode___455 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___455;

struct mem_dqinfo___455 {
	struct quota_format_type___455 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___455;

struct quota_info___455 {
	unsigned int flags;
	struct rw_semaphore___457 dqio_sem;
	struct inode___455 *files[3];
	struct mem_dqinfo___455 info[3];
	const struct quota_format_ops___455 *ops[3];
};

struct rcuwait___455 {
	struct task_struct___457 *task;
};

struct percpu_rw_semaphore___455 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___457 rw_sem;
	struct rcuwait___455 writer;
	int readers_block;
};

struct sb_writers___455 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___455 rw_sem[3];
};

struct shrink_control___188;

struct shrinker___188 {
	long unsigned int (*count_objects)(struct shrinker___188 *, struct shrink_control___188 *);
	long unsigned int (*scan_objects)(struct shrinker___188 *, struct shrink_control___188 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___455;

struct super_operations___455;

struct dquot_operations___455;

struct quotactl_ops___455;

struct super_block___455 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___455 *s_type;
	const struct super_operations___455 *s_op;
	const struct dquot_operations___455 *dq_op;
	const struct quotactl_ops___455 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___455 *s_root;
	struct rw_semaphore___457 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___455 *s_bdev;
	struct backing_dev_info___245 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___455 s_dquot;
	struct sb_writers___455 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___455 *s_d_op;
	int cleancache_poolid;
	struct shrinker___188 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___320 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___188 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___188 *memcg;
};

struct iattr___455 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___455 *ia_file;
};

struct dquot___455 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___455 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___455 {
	int qf_fmt_id;
	const struct quota_format_ops___455 *qf_ops;
	struct module___381 *qf_owner;
	struct quota_format_type___455 *qf_next;
};

struct quota_format_ops___455 {
	int (*check_quota_file)(struct super_block___455 *, int);
	int (*read_file_info)(struct super_block___455 *, int);
	int (*write_file_info)(struct super_block___455 *, int);
	int (*free_file_info)(struct super_block___455 *, int);
	int (*read_dqblk)(struct dquot___455 *);
	int (*commit_dqblk)(struct dquot___455 *);
	int (*release_dqblk)(struct dquot___455 *);
	int (*get_next_id)(struct super_block___455 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___455 {
	int (*write_dquot)(struct dquot___455 *);
	struct dquot___455 * (*alloc_dquot)(struct super_block___455 *, int);
	void (*destroy_dquot)(struct dquot___455 *);
	int (*acquire_dquot)(struct dquot___455 *);
	int (*release_dquot)(struct dquot___455 *);
	int (*mark_dirty)(struct dquot___455 *);
	int (*write_info)(struct super_block___455 *, int);
	qsize_t * (*get_reserved_space)(struct inode___455 *);
	int (*get_projid)(struct inode___455 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___455 *, qsize_t *);
	int (*get_next_id)(struct super_block___455 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___455 {
	int (*quota_on)(struct super_block___455 *, int, int, const struct path___456 *);
	int (*quota_off)(struct super_block___455 *, int);
	int (*quota_enable)(struct super_block___455 *, unsigned int);
	int (*quota_disable)(struct super_block___455 *, unsigned int);
	int (*quota_sync)(struct super_block___455 *, int);
	int (*set_info)(struct super_block___455 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___455 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___455 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___455 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___455 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___455 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___208;

struct address_space_operations___455 {
	int (*writepage)(struct page___456 *, struct writeback_control___208 *);
	int (*readpage)(struct file___455 *, struct page___456 *);
	int (*writepages)(struct address_space___455 *, struct writeback_control___208 *);
	int (*set_page_dirty)(struct page___456 *);
	int (*readpages)(struct file___455 *, struct address_space___455 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___455 *, struct address_space___455 *, loff_t, unsigned int, unsigned int, struct page___456 **, void **);
	int (*write_end)(struct file___455 *, struct address_space___455 *, loff_t, unsigned int, unsigned int, struct page___456 *, void *);
	sector_t (*bmap)(struct address_space___455 *, sector_t);
	void (*invalidatepage)(struct page___456 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___456 *, gfp_t);
	void (*freepage)(struct page___456 *);
	ssize_t (*direct_IO)(struct kiocb___455 *, struct iov_iter___222 *);
	int (*migratepage)(struct address_space___455 *, struct page___456 *, struct page___456 *, enum migrate_mode);
	bool (*isolate_page)(struct page___456 *, isolate_mode_t);
	void (*putback_page)(struct page___456 *);
	int (*launder_page)(struct page___456 *);
	int (*is_partially_uptodate)(struct page___456 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___456 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___455 *, struct page___456 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___455 *, sector_t *);
	void (*swap_deactivate)(struct file___455 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___208 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___245 *wb;
	struct inode___455 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___455 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___455 *bd_inode;
	struct super_block___455 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___455 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___245 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___455 {
	struct dentry___455 * (*lookup)(struct inode___455 *, struct dentry___455 *, unsigned int);
	const char * (*get_link)(struct dentry___455 *, struct inode___455 *, struct delayed_call *);
	int (*permission)(struct inode___455 *, int);
	struct posix_acl * (*get_acl)(struct inode___455 *, int);
	int (*readlink)(struct dentry___455 *, char *, int);
	int (*create)(struct inode___455 *, struct dentry___455 *, umode_t, bool);
	int (*link)(struct dentry___455 *, struct inode___455 *, struct dentry___455 *);
	int (*unlink)(struct inode___455 *, struct dentry___455 *);
	int (*symlink)(struct inode___455 *, struct dentry___455 *, const char *);
	int (*mkdir)(struct inode___455 *, struct dentry___455 *, umode_t);
	int (*rmdir)(struct inode___455 *, struct dentry___455 *);
	int (*mknod)(struct inode___455 *, struct dentry___455 *, umode_t, dev_t);
	int (*rename)(struct inode___455 *, struct dentry___455 *, struct inode___455 *, struct dentry___455 *, unsigned int);
	int (*setattr)(struct dentry___455 *, struct iattr___455 *);
	int (*getattr)(const struct path___456 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___455 *, char *, size_t);
	int (*fiemap)(struct inode___455 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___455 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___455 *, struct dentry___455 *, struct file___455 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___455 *, struct dentry___455 *, umode_t);
	int (*set_acl)(struct inode___455 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___455 {
	void (*fl_copy_lock)(struct file_lock___455 *, struct file_lock___455 *);
	void (*fl_release_private)(struct file_lock___455 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___455;

struct file_lock___455 {
	struct file_lock___455 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___455 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___455 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___455 *fl_ops;
	const struct lock_manager_operations___455 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___455 {
	int (*lm_compare_owner)(struct file_lock___455 *, struct file_lock___455 *);
	long unsigned int (*lm_owner_key)(struct file_lock___455 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___455 *);
	int (*lm_grant)(struct file_lock___455 *, int);
	bool (*lm_break)(struct file_lock___455 *);
	int (*lm_change)(struct file_lock___455 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___455 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___455 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___455 *fa_next;
	struct file___455 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___455 {
	const char *name;
	int fs_flags;
	struct dentry___455 * (*mount)(struct file_system_type___455 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___455 *);
	struct module___381 *owner;
	struct file_system_type___455 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___455 {
	struct inode___455 * (*alloc_inode)(struct super_block___455 *);
	void (*destroy_inode)(struct inode___455 *);
	void (*dirty_inode)(struct inode___455 *, int);
	int (*write_inode)(struct inode___455 *, struct writeback_control___208 *);
	int (*drop_inode)(struct inode___455 *);
	void (*evict_inode)(struct inode___455 *);
	void (*put_super)(struct super_block___455 *);
	int (*sync_fs)(struct super_block___455 *, int);
	int (*freeze_super)(struct super_block___455 *);
	int (*freeze_fs)(struct super_block___455 *);
	int (*thaw_super)(struct super_block___455 *);
	int (*unfreeze_fs)(struct super_block___455 *);
	int (*statfs)(struct dentry___455 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___455 *, int *, char *);
	void (*umount_begin)(struct super_block___455 *);
	int (*show_options)(struct seq_file___394 *, struct dentry___455 *);
	int (*show_devname)(struct seq_file___394 *, struct dentry___455 *);
	int (*show_path)(struct seq_file___394 *, struct dentry___455 *);
	int (*show_stats)(struct seq_file___394 *, struct dentry___455 *);
	ssize_t (*quota_read)(struct super_block___455 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___455 *, int, const char *, size_t, loff_t);
	struct dquot___455 ** (*get_dquots)(struct inode___455 *);
	int (*bdev_try_to_free_page)(struct super_block___455 *, struct page___456 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___455 *, struct shrink_control___188 *);
	long int (*free_cached_objects)(struct super_block___455 *, struct shrink_control___188 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___304)(struct file___455 *, wait_queue_head_t *, struct poll_table_struct___294 *);

struct poll_table_struct___294 {
	poll_queue_proc___304 _qproc;
	__poll_t _key;
};

struct seq_operations___394;

struct seq_file___394 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___394 *op;
	int poll_event;
	const struct file___455 *file;
	void *private;
};

typedef void bio_end_io_t___245(struct bio___245 *);

struct bio_integrity_payload___245;

struct bio_set___245;

struct bio___245 {
	struct bio___245 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___245 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___245 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___247 *bi_io_vec;
	struct bio_set___245 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___247 bi_inline_vecs[0];
};

struct socket_wq___81 {
	wait_queue_head_t wait;
	struct fasync_struct___455 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct sock___80;

struct proto_ops___81;

struct socket___82 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___81 *wq;
	struct file___455 *file;
	struct sock___80 *sk;
	const struct proto_ops___81 *ops;
};

typedef struct {
	struct net___111 *net;
} possible_net_t___102;

struct proto___80;

struct sock_common___80 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___80 *skc_prot;
	possible_net_t___102 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___80 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___101;

struct sk_buff_head___100 {
	struct sk_buff___101 *next;
	struct sk_buff___101 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___80;

struct xfrm_policy___18;

struct dst_entry___80;

struct net_device___100;

struct sock___80 {
	struct sock_common___80 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___100 sk_error_queue;
	struct sk_buff_head___100 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___101 *head;
		struct sk_buff___101 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___80 *sk_filter;
	union {
		struct socket_wq___81 *sk_wq;
		struct socket_wq___81 *sk_wq_raw;
	};
	struct xfrm_policy___18 *sk_policy[2];
	struct dst_entry___80 *sk_rx_dst;
	struct dst_entry___80 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___101 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___100 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___456 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___80 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___253 *sk_peer_pid;
	const struct cred___423 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___82 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___188 *sk_memcg;
	void (*sk_state_change)(struct sock___80 *);
	void (*sk_data_ready)(struct sock___80 *);
	void (*sk_write_space)(struct sock___80 *);
	void (*sk_error_report)(struct sock___80 *);
	int (*sk_backlog_rcv)(struct sock___80 *, struct sk_buff___101 *);
	struct sk_buff___101 * (*sk_validate_xmit_skb)(struct sock___80 *, struct net_device___100 *, struct sk_buff___101 *);
	void (*sk_destruct)(struct sock___80 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

typedef int (*sk_read_actor_t___80)(read_descriptor_t *, struct sk_buff___101 *, unsigned int, size_t);

struct proto_ops___81 {
	int family;
	struct module___381 *owner;
	int (*release)(struct socket___82 *);
	int (*bind)(struct socket___82 *, struct sockaddr *, int);
	int (*connect)(struct socket___82 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___82 *, struct socket___82 *);
	int (*accept)(struct socket___82 *, struct socket___82 *, int, bool);
	int (*getname)(struct socket___82 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___455 *, struct socket___82 *, struct poll_table_struct___294 *);
	int (*ioctl)(struct socket___82 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___82 *, int);
	int (*shutdown)(struct socket___82 *, int);
	int (*setsockopt)(struct socket___82 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___82 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___82 *, struct msghdr___83 *, size_t);
	int (*recvmsg)(struct socket___82 *, struct msghdr___83 *, size_t, int);
	int (*mmap)(struct file___455 *, struct socket___82 *, struct vm_area_struct___456 *);
	ssize_t (*sendpage)(struct socket___82 *, struct page___456 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___82 *, loff_t *, struct pipe_inode_info___136 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___80 *, int);
	int (*peek_len)(struct socket___82 *);
	int (*read_sock)(struct sock___80 *, read_descriptor_t *, sk_read_actor_t___80);
	int (*sendpage_locked)(struct sock___80 *, struct page___456 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___80 *, struct msghdr___83 *, size_t);
	int (*set_rcvlowat)(struct sock___80 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct sec_path___18;

struct nf_bridge_info___100;

struct sk_buff___101 {
	union {
		struct {
			struct sk_buff___101 *next;
			struct sk_buff___101 *prev;
			union {
				struct net_device___100 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___80 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___101 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path___18 *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___100 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___100;

struct netns_frags___100 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___100 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ip_ra_chain___46;

struct fib_rules_ops___80;

struct fib_notifier_ops___81;

struct netns_ipv4___100 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___46 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___80 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___80 *fibnl;
	struct sock___80 **icmp_sk;
	struct sock___80 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___80 **tcp_sk;
	struct netns_frags___100 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___80 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___81 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___81 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___80;

struct dst_ops___111 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___111 *);
	struct dst_entry___80 * (*check)(struct dst_entry___80 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___80 *);
	unsigned int (*mtu)(const struct dst_entry___80 *);
	u32 * (*cow_metrics)(struct dst_entry___80 *, long unsigned int);
	void (*destroy)(struct dst_entry___80 *);
	void (*ifdown)(struct dst_entry___80 *, struct net_device___100 *, int);
	struct dst_entry___80 * (*negative_advice)(struct dst_entry___80 *);
	void (*link_failure)(struct sk_buff___101 *);
	void (*update_pmtu)(struct dst_entry___80 *, struct sock___80 *, struct sk_buff___101 *, u32);
	void (*redirect)(struct dst_entry___80 *, struct sock___80 *, struct sk_buff___101 *);
	int (*local_out)(struct net___111 *, struct sock___80 *, struct sk_buff___101 *);
	struct neighbour___80 * (*neigh_lookup)(const struct dst_entry___80 *, struct sk_buff___101 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___80 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_info___23;

struct rt6_info___23;

struct fib6_table___23;

struct netns_ipv6___111 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___100 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info___23 *fib6_null_entry;
	struct rt6_info___23 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___23 *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___111 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info___23 *ip6_prohibit_entry;
	struct rt6_info___23 *ip6_blk_hole_entry;
	struct fib6_table___23 *fib6_local_tbl;
	struct fib_rules_ops___80 *fib6_rules_ops;
	struct sock___80 **icmp_sk;
	struct sock___80 *ndisc_sk;
	struct sock___80 *tcp_sk;
	struct sock___80 *igmp_sk;
	struct sock___80 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___80 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___81 *notifier_ops;
	struct fib_notifier_ops___81 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___81 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___80 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct nf_queue_handler___3;

struct nf_hook_entries___16;

struct netns_nf___17 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_queue_handler___3 *queue_handler;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header *nf_log_dir_header;
	struct nf_hook_entries___16 *hooks_ipv4[5];
	struct nf_hook_entries___16 *hooks_ipv6[5];
	struct nf_hook_entries___16 *hooks_arp[3];
	struct nf_hook_entries___16 *hooks_bridge[5];
	bool defrag_ipv4;
	bool defrag_ipv6;
};

struct netns_nf_frag___100 {
	struct netns_frags___100 frags;
};

struct netns_xfrm___111 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___80 *nlsk;
	struct sock___80 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___111 xfrm4_dst_ops;
	struct dst_ops___111 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___90;

struct net___111 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___320 *user_ns;
	struct ucounts___320 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___29 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___80 *rtnl;
	struct sock___80 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___100 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___100 ipv4;
	struct netns_ipv6___111 ipv6;
	struct netns_sctp___81 sctp;
	struct netns_nf___17 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___100 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___80 *nfnl;
	struct sock___80 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___111 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___80 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___90 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kernfs_root___449;

struct kernfs_elem_dir___449 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___449 *root;
};

struct kernfs_syscall_ops___449;

struct kernfs_root___449 {
	struct kernfs_node___450 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___449 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___449 {
	struct kernfs_node___450 *target_kn;
};

struct kernfs_ops___449;

struct kernfs_elem_attr___449 {
	const struct kernfs_ops___449 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___450 *notify_next;
};

struct kernfs_node___450 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___450 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___449 dir;
		struct kernfs_elem_symlink___449 symlink;
		struct kernfs_elem_attr___449 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___449;

struct kernfs_ops___449 {
	int (*open)(struct kernfs_open_file___449 *);
	void (*release)(struct kernfs_open_file___449 *);
	int (*seq_show)(struct seq_file___394 *, void *);
	void * (*seq_start)(struct seq_file___394 *, loff_t *);
	void * (*seq_next)(struct seq_file___394 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___394 *, void *);
	ssize_t (*read)(struct kernfs_open_file___449 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___449 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___449 *, struct vm_area_struct___456 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___449 *, struct poll_table_struct___294 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___449 {
	int (*remount_fs)(struct kernfs_root___449 *, int *, char *);
	int (*show_options)(struct seq_file___394 *, struct kernfs_root___449 *);
	int (*mkdir)(struct kernfs_node___450 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___450 *);
	int (*rename)(struct kernfs_node___450 *, struct kernfs_node___450 *, const char *);
	int (*show_path)(struct seq_file___394 *, struct kernfs_node___450 *, struct kernfs_root___449 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___449 {
	struct kernfs_node___450 *kn;
	struct file___455 *file;
	struct seq_file___394 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___443 *vm_ops;
};

struct kobj_ns_type_operations___80 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___80 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___419;

struct attribute_group___420 {
	const char *name;
	umode_t (*is_visible)(struct kobject___443 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___443 *, struct bin_attribute___419 *, int);
	struct attribute **attrs;
	struct bin_attribute___419 **bin_attrs;
};

struct bin_attribute___419 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___455 *, struct kobject___443 *, struct bin_attribute___419 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___455 *, struct kobject___443 *, struct bin_attribute___419 *, char *, loff_t, size_t);
	int (*mmap)(struct file___455 *, struct kobject___443 *, struct bin_attribute___419 *, struct vm_area_struct___456 *);
};

struct sysfs_ops___442 {
	ssize_t (*show)(struct kobject___443 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___443 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___442;

struct kset___442 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___443 kobj;
	const struct kset_uevent_ops___442 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___442 {
	void (*release)(struct kobject___443 *);
	const struct sysfs_ops___442 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___80 * (*child_ns_type)(struct kobject___443 *);
	const void * (*namespace)(struct kobject___443 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___442 {
	int (* const filter)(struct kset___442 *, struct kobject___443 *);
	const char * (* const name)(struct kset___442 *, struct kobject___443 *);
	int (* const uevent)(struct kset___442 *, struct kobject___443 *, struct kobj_uevent_env *);
};

struct kobj_attribute___433 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___443 *, struct kobj_attribute___433 *, char *);
	ssize_t (*store)(struct kobject___443 *, struct kobj_attribute___433 *, const char *, size_t);
};

struct dev_pm_ops___423 {
	int (*prepare)(struct device___423 *);
	void (*complete)(struct device___423 *);
	int (*suspend)(struct device___423 *);
	int (*resume)(struct device___423 *);
	int (*freeze)(struct device___423 *);
	int (*thaw)(struct device___423 *);
	int (*poweroff)(struct device___423 *);
	int (*restore)(struct device___423 *);
	int (*suspend_late)(struct device___423 *);
	int (*resume_early)(struct device___423 *);
	int (*freeze_late)(struct device___423 *);
	int (*thaw_early)(struct device___423 *);
	int (*poweroff_late)(struct device___423 *);
	int (*restore_early)(struct device___423 *);
	int (*suspend_noirq)(struct device___423 *);
	int (*resume_noirq)(struct device___423 *);
	int (*freeze_noirq)(struct device___423 *);
	int (*thaw_noirq)(struct device___423 *);
	int (*poweroff_noirq)(struct device___423 *);
	int (*restore_noirq)(struct device___423 *);
	int (*runtime_suspend)(struct device___423 *);
	int (*runtime_resume)(struct device___423 *);
	int (*runtime_idle)(struct device___423 *);
};

struct dev_pm_info___423 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___423 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___423;

struct bus_type___423;

struct device_driver___423;

struct dev_pm_domain___423;

struct dma_map_ops___195;

struct fwnode_handle___343;

struct class___423;

struct device___423 {
	struct device___423 *parent;
	struct device_private *p;
	struct kobject___443 kobj;
	const char *init_name;
	const struct device_type___423 *type;
	struct mutex mutex;
	struct bus_type___423 *bus;
	struct device_driver___423 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___423 power;
	struct dev_pm_domain___423 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___195 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___343 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___423 *class;
	const struct attribute_group___420 **groups;
	void (*release)(struct device___423 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___423 {
	struct dev_pm_ops___423 ops;
	void (*detach)(struct device___423 *, bool);
	int (*activate)(struct device___423 *);
	void (*sync)(struct device___423 *);
	void (*dismiss)(struct device___423 *);
};

struct bus_type___423 {
	const char *name;
	const char *dev_name;
	struct device___423 *dev_root;
	const struct attribute_group___420 **bus_groups;
	const struct attribute_group___420 **dev_groups;
	const struct attribute_group___420 **drv_groups;
	int (*match)(struct device___423 *, struct device_driver___423 *);
	int (*uevent)(struct device___423 *, struct kobj_uevent_env *);
	int (*probe)(struct device___423 *);
	int (*remove)(struct device___423 *);
	void (*shutdown)(struct device___423 *);
	int (*online)(struct device___423 *);
	int (*offline)(struct device___423 *);
	int (*suspend)(struct device___423 *, pm_message_t);
	int (*resume)(struct device___423 *);
	int (*num_vf)(struct device___423 *);
	int (*dma_configure)(struct device___423 *);
	const struct dev_pm_ops___423 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___423 {
	const char *name;
	struct bus_type___423 *bus;
	struct module___381 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___423 *);
	int (*remove)(struct device___423 *);
	void (*shutdown)(struct device___423 *);
	int (*suspend)(struct device___423 *, pm_message_t);
	int (*resume)(struct device___423 *);
	const struct attribute_group___420 **groups;
	const struct dev_pm_ops___423 *pm;
	void (*coredump)(struct device___423 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___423 {
	const char *name;
	const struct attribute_group___420 **groups;
	int (*uevent)(struct device___423 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___423 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___423 *);
	const struct dev_pm_ops___423 *pm;
};

struct class___423 {
	const char *name;
	struct module___381 *owner;
	const struct attribute_group___420 **class_groups;
	const struct attribute_group___420 **dev_groups;
	struct kobject___443 *dev_kobj;
	int (*dev_uevent)(struct device___423 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___423 *, umode_t *);
	void (*class_release)(struct class___423 *);
	void (*dev_release)(struct device___423 *);
	int (*shutdown_pre)(struct device___423 *);
	const struct kobj_ns_type_operations___80 *ns_type;
	const void * (*namespace)(struct device___423 *);
	const struct dev_pm_ops___423 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___195 {
	void * (*alloc)(struct device___423 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___423 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___423 *, struct vm_area_struct___456 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___423 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___423 *, struct page___456 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___423 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___423 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___423 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___423 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___423 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___423 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___423 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___423 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___423 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___423 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___423 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___423 *, u64);
	u64 (*get_required_mask)(struct device___423 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___343;

struct fwnode_handle___343 {
	struct fwnode_handle___343 *secondary;
	const struct fwnode_operations___343 *ops;
};

typedef void compound_page_dtor___443(struct page___456 *);

struct fwnode_reference_args___343;

struct fwnode_endpoint___343;

struct fwnode_operations___343 {
	struct fwnode_handle___343 * (*get)(struct fwnode_handle___343 *);
	void (*put)(struct fwnode_handle___343 *);
	bool (*device_is_available)(const struct fwnode_handle___343 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___343 *, const struct device___423 *);
	bool (*property_present)(const struct fwnode_handle___343 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___343 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___343 *, const char *, const char **, size_t);
	struct fwnode_handle___343 * (*get_parent)(const struct fwnode_handle___343 *);
	struct fwnode_handle___343 * (*get_next_child_node)(const struct fwnode_handle___343 *, struct fwnode_handle___343 *);
	struct fwnode_handle___343 * (*get_named_child_node)(const struct fwnode_handle___343 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___343 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___343 *);
	struct fwnode_handle___343 * (*graph_get_next_endpoint)(const struct fwnode_handle___343 *, struct fwnode_handle___343 *);
	struct fwnode_handle___343 * (*graph_get_remote_endpoint)(const struct fwnode_handle___343 *);
	struct fwnode_handle___343 * (*graph_get_port_parent)(struct fwnode_handle___343 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___343 *, struct fwnode_endpoint___343 *);
};

struct fwnode_endpoint___343 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___343 *local_fwnode;
};

struct fwnode_reference_args___343 {
	struct fwnode_handle___343 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___136;

struct pipe_buffer___136 {
	struct page___456 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___136 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___136 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___136 *, struct pipe_buffer___136 *);
	void (*release)(struct pipe_inode_info___136 *, struct pipe_buffer___136 *);
	int (*steal)(struct pipe_inode_info___136 *, struct pipe_buffer___136 *);
	union {
		bool (*get)(struct pipe_inode_info___136 *, struct pipe_buffer___136 *);
		struct {
			void (*get)(struct pipe_inode_info___136 *, struct pipe_buffer___136 *);
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
};

struct nf_bridge_info___100 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___100 = 0,
		BRNF_PROTO_8021Q___100 = 1,
		BRNF_PROTO_PPPOE___100 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___100 *physindev;
	struct net_device___100 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___100(struct sk_buff___101 **);

struct net_device_ops___100;

struct ethtool_ops___100;

struct l3mdev_ops___80;

struct ndisc_ops___51;

struct xfrmdev_ops___100;

struct tlsdev_ops___100;

struct header_ops___100;

struct inet6_dev___51;

struct netdev_rx_queue___100;

struct mini_Qdisc___92;

struct netdev_queue___100;

struct Qdisc___92;

struct rtnl_link_ops___92;

struct dcbnl_rtnl_ops___100;

struct net_device___100 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___100 *netdev_ops;
	const struct ethtool_ops___100 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___80 *l3mdev_ops;
	const struct ndisc_ops___51 *ndisc_ops;
	const struct xfrmdev_ops___100 *xfrmdev_ops;
	const struct tlsdev_ops___100 *tlsdev_ops;
	const struct header_ops___100 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___442 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___51 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___100 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___90 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___100 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___92 *miniq_ingress;
	struct netdev_queue___100 *ingress_queue;
	struct nf_hook_entries___16 *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___100 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___92 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___92 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___100 = 0,
		NETREG_REGISTERED___100 = 1,
		NETREG_UNREGISTERING___100 = 2,
		NETREG_UNREGISTERED___100 = 3,
		NETREG_RELEASED___100 = 4,
		NETREG_DUMMY___100 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___100 = 0,
		RTNL_LINK_INITIALIZING___100 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___100 *);
	struct netpoll_info *npinfo;
	possible_net_t___102 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___423 dev;
	const struct attribute_group___420 *sysfs_groups[4];
	const struct attribute_group___420 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___92 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___100 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct xfrm_state___18;

struct sec_path___18 {
	refcount_t refcnt;
	int len;
	int olen;
	struct xfrm_state___18 *xvec[6];
	struct xfrm_offload ovec[1];
};

struct ethtool_ops___100 {
	int (*get_settings)(struct net_device___100 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___100 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___100 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___100 *);
	void (*get_regs)(struct net_device___100 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___100 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___100 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___100 *);
	void (*set_msglevel)(struct net_device___100 *, u32);
	int (*nway_reset)(struct net_device___100 *);
	u32 (*get_link)(struct net_device___100 *);
	int (*get_eeprom_len)(struct net_device___100 *);
	int (*get_eeprom)(struct net_device___100 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___100 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___100 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___100 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___100 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___100 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___100 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___100 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___100 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___100 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___100 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___100 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___100 *);
	void (*complete)(struct net_device___100 *);
	u32 (*get_priv_flags)(struct net_device___100 *);
	int (*set_priv_flags)(struct net_device___100 *, u32);
	int (*get_sset_count)(struct net_device___100 *, int);
	int (*get_rxnfc)(struct net_device___100 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___100 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___100 *, struct ethtool_flash *);
	int (*reset)(struct net_device___100 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___100 *);
	u32 (*get_rxfh_indir_size)(struct net_device___100 *);
	int (*get_rxfh)(struct net_device___100 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___100 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___100 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___100 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___100 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___100 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___100 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___100 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___100 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___100 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___100 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___100 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___100 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___100 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___100 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___100 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___100 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___100 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___100 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___100 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___100 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___100 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	int (*get_fecparam)(struct net_device___100 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___100 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___100 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___100 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___100 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___100;

struct inet_frags___100 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___100 *, const void *);
	void (*destructor)(struct inet_frag_queue___100 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___100 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___101 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___101 *fragments_tail;
	struct sk_buff___101 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___100 *net;
	struct callback_head rcu;
};

struct ip_ra_chain___46 {
	struct ip_ra_chain___46 *next;
	struct sock___80 *sk;
	union {
		void (*destructor)(struct sock___80 *);
		struct sock___80 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___80;

struct fib_lookup_arg___80;

struct fib_rules_ops___80 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___80 *, struct flowi *, int, struct fib_lookup_arg___80 *);
	bool (*suppress)(struct fib_rule___80 *, struct fib_lookup_arg___80 *);
	int (*match)(struct fib_rule___80 *, struct flowi *, int);
	int (*configure)(struct fib_rule___80 *, struct sk_buff___101 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___80 *);
	int (*compare)(struct fib_rule___80 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___80 *, struct sk_buff___101 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___80 *);
	void (*flush_cache)(struct fib_rules_ops___80 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___381 *owner;
	struct net___111 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___81 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___111 *);
	int (*fib_dump)(struct net___111 *, struct notifier_block *);
	struct module___381 *owner;
	struct callback_head rcu;
};

struct dst_entry___80 {
	struct net_device___100 *dev;
	struct dst_ops___111 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state___18 *xfrm;
	int (*input)(struct sk_buff___101 *);
	int (*output)(struct net___111 *, struct sock___80 *, struct sk_buff___101 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___80;

struct neigh_parms___80;

struct neigh_ops___80;

struct neighbour___80 {
	struct neighbour___80 *next;
	struct neigh_table___80 *tbl;
	struct neigh_parms___80 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___100 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___80 *, struct sk_buff___101 *);
	const struct neigh_ops___80 *ops;
	struct callback_head rcu;
	struct net_device___100 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct fib6_nh___23 {
	struct in6_addr nh_gw;
	struct net_device___100 *nh_dev;
	struct lwtunnel_state *nh_lwtstate;
	unsigned int nh_flags;
	atomic_t nh_upper_bound;
	int nh_weight;
};

struct fib6_node___23;

struct fib6_info___23 {
	struct fib6_table___23 *fib6_table;
	struct fib6_info___23 *fib6_next;
	struct fib6_node___23 *fib6_node;
	struct list_head fib6_siblings;
	unsigned int fib6_nsiblings;
	atomic_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	struct rt6_info___23 **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
	long unsigned int last_probe;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 exception_bucket_flushed: 1;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 dst_host: 1;
	u8 fib6_destroying: 1;
	u8 unused: 2;
	struct fib6_nh___23 fib6_nh;
	struct callback_head rcu;
};

struct rt6_info___23 {
	struct dst_entry___80 dst;
	struct fib6_info___23 *from;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___51 *rt6i_idev;
	u32 rt6i_flags;
	struct rt6key rt6i_prefsrc;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct fib6_node___23 {
	struct fib6_node___23 *parent;
	struct fib6_node___23 *left;
	struct fib6_node___23 *right;
	struct fib6_info___23 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info___23 *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table___23 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node___23 tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

struct nf_queue_entry___4;

struct nf_queue_handler___3 {
	int (*outfn)(struct nf_queue_entry___4 *, unsigned int);
	void (*nf_hook_drop)(struct net___111 *);
};

struct nf_hook_state___16;

typedef unsigned int nf_hookfn___16(void *, struct sk_buff___101 *, const struct nf_hook_state___16 *);

struct nf_hook_entry___16 {
	nf_hookfn___16 *hook;
	void *priv;
};

struct nf_hook_entries___16 {
	u16 num_hook_entries;
	struct nf_hook_entry___16 hooks[0];
};

struct ucounts___320 {
	struct hlist_node node;
	struct user_namespace___320 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_prog_aux___93;

struct bpf_prog___90 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___93 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

typedef int (*key_restrict_link_func_t___424)(struct key___423 *, const struct key_type *, const union key_payload *, struct key___423 *);

struct key_restriction___423;

struct key___423 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___457 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___423 *restrict_link;
};

struct key_restriction___423 {
	key_restrict_link_func_t___424 check;
	struct key___423 *key;
	struct key_type *keytype;
};

struct seq_operations___394 {
	void * (*start)(struct seq_file___394 *, loff_t *);
	void (*stop)(struct seq_file___394 *, void *);
	void * (*next)(struct seq_file___394 *, void *, loff_t *);
	int (*show)(struct seq_file___394 *, void *);
};

struct pernet_operations___101 {
	struct list_head list;
	int (*init)(struct net___111 *);
	void (*exit)(struct net___111 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___100 {
	int (*ieee_getets)(struct net_device___100 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___100 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___100 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___100 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___100 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___100 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___100 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___100 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___100 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___100 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___100 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___100 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___100 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___100 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___100 *);
	u8 (*setstate)(struct net_device___100 *, u8);
	void (*getpermhwaddr)(struct net_device___100 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___100 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___100 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___100 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___100 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___100 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___100 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___100 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___100 *, int, u8 *);
	void (*setpfccfg)(struct net_device___100 *, int, u8);
	void (*getpfccfg)(struct net_device___100 *, int, u8 *);
	u8 (*setall)(struct net_device___100 *);
	u8 (*getcap)(struct net_device___100 *, int, u8 *);
	int (*getnumtcs)(struct net_device___100 *, int, u8 *);
	int (*setnumtcs)(struct net_device___100 *, int, u8);
	u8 (*getpfcstate)(struct net_device___100 *);
	void (*setpfcstate)(struct net_device___100 *, u8);
	void (*getbcncfg)(struct net_device___100 *, int, u32 *);
	void (*setbcncfg)(struct net_device___100 *, int, u32);
	void (*getbcnrp)(struct net_device___100 *, int, u8 *);
	void (*setbcnrp)(struct net_device___100 *, int, u8);
	int (*setapp)(struct net_device___100 *, u8, u16, u8);
	int (*getapp)(struct net_device___100 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___100 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___100 *, int, u8);
	u8 (*getdcbx)(struct net_device___100 *);
	u8 (*setdcbx)(struct net_device___100 *, u8);
	int (*peer_getappinfo)(struct net_device___100 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___100 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___100 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___100 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___100 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___100 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___304 {
	refcount_t count;
	struct ns_common___29 ns;
	struct user_namespace___320 *user_ns;
	struct ucounts___320 *ucounts;
	struct css_set___304 *root_cset;
};

struct bpf_map___305;

struct bpf_map_ops___304 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___305 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___305 *, struct file___455 *);
	void (*map_free)(struct bpf_map___305 *);
	int (*map_get_next_key)(struct bpf_map___305 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___305 *);
	void * (*map_lookup_elem)(struct bpf_map___305 *, void *);
	int (*map_update_elem)(struct bpf_map___305 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___305 *, void *);
	int (*map_push_elem)(struct bpf_map___305 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___305 *, void *);
	int (*map_peek_elem)(struct bpf_map___305 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___305 *, struct file___455 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___305 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___305 *, void *, struct seq_file___394 *);
	int (*map_check_btf)(const struct bpf_map___305 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___305 {
	const struct bpf_map_ops___304 *ops;
	struct bpf_map___305 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___423 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___100;

struct bpf_map_dev_ops___100 {
	int (*map_get_next_key)(struct bpf_offloaded_map___100 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___100 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___100 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___100 *, void *);
};

struct bpf_offloaded_map___100 {
	struct bpf_map___305 map;
	struct net_device___100 *netdev;
	const struct bpf_map_dev_ops___100 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___90 {
	int (*test_run)(struct bpf_prog___90 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___90 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___90 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___90 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___90 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___90 *, u32 *);
};

struct bpf_prog_offload_ops___90 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___90 *);
	int (*translate)(struct bpf_prog___90 *);
	void (*destroy)(struct bpf_prog___90 *);
};

struct bpf_prog_offload___90 {
	struct bpf_prog___90 *prog;
	struct net_device___100 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___90 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___93 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___90 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___90 *ops;
	struct bpf_map___305 **used_maps;
	struct bpf_prog___90 *prog;
	struct user_struct___423 *user;
	u64 load_time;
	struct bpf_map___305 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___90 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___90 {
	struct bpf_prog___90 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___90 {
	struct callback_head rcu;
	struct bpf_prog_array_item___90 items[0];
};

struct cgroup_bpf___90 {
	struct bpf_prog_array___90 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___90 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___305;

typedef void (*kthread_work_func_t___305)(struct kthread_work___305 *);

struct kthread_worker___305;

struct kthread_work___305 {
	struct list_head node;
	kthread_work_func_t___305 func;
	struct kthread_worker___305 *worker;
	int canceling;
};

struct kthread_worker___305 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___457 *task;
	struct kthread_work___305 *current_work;
};

struct kthread_delayed_work___304 {
	struct kthread_work___305 work;
	struct timer_list timer;
};

struct psi_group___304 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___305 *poll_kworker;
	struct kthread_delayed_work___304 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___304;

struct cgroup_rstat_cpu___304;

struct cgroup___304 {
	struct cgroup_subsys_state___304 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___450 *kn;
	struct cgroup_file___304 procs_file;
	struct cgroup_file___304 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___304 *subsys[13];
	struct cgroup_root___304 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___304 *dom_cgrp;
	struct cgroup_rstat_cpu___304 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___90 bpf;
	atomic_t congestion_count;
	struct cgroup___304 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___304 psi;
	int ancestor_ids[0];
};

struct cftype___304;

struct cgroup_subsys___304 {
	struct cgroup_subsys_state___304 * (*css_alloc)(struct cgroup_subsys_state___304 *);
	int (*css_online)(struct cgroup_subsys_state___304 *);
	void (*css_offline)(struct cgroup_subsys_state___304 *);
	void (*css_released)(struct cgroup_subsys_state___304 *);
	void (*css_free)(struct cgroup_subsys_state___304 *);
	void (*css_reset)(struct cgroup_subsys_state___304 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___304 *, int);
	int (*css_extra_stat_show)(struct seq_file___394 *, struct cgroup_subsys_state___304 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___457 *);
	void (*cancel_fork)(struct task_struct___457 *);
	void (*fork)(struct task_struct___457 *);
	void (*exit)(struct task_struct___457 *);
	void (*free)(struct task_struct___457 *);
	void (*bind)(struct cgroup_subsys_state___304 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___304 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___304 *dfl_cftypes;
	struct cftype___304 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___304 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___304 *updated_children;
	struct cgroup___304 *updated_next;
};

struct cgroup_root___304 {
	struct kernfs_root___449 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___304 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___304 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___304 *ss;
	struct list_head node;
	struct kernfs_ops___449 *kf_ops;
	int (*open)(struct kernfs_open_file___449 *);
	void (*release)(struct kernfs_open_file___449 *);
	u64 (*read_u64)(struct cgroup_subsys_state___304 *, struct cftype___304 *);
	s64 (*read_s64)(struct cgroup_subsys_state___304 *, struct cftype___304 *);
	int (*seq_show)(struct seq_file___394 *, void *);
	void * (*seq_start)(struct seq_file___394 *, loff_t *);
	void * (*seq_next)(struct seq_file___394 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___394 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___304 *, struct cftype___304 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___304 *, struct cftype___304 *, s64);
	ssize_t (*write)(struct kernfs_open_file___449 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___449 *, struct poll_table_struct___294 *);
};

struct xdp_rxq_info___100 {
	struct net_device___100 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___100 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___100 *dev_rx;
};

struct netlink_callback___102 {
	struct sk_buff___101 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___102 *);
	int (*dump)(struct sk_buff___101 *, struct netlink_callback___102 *);
	int (*done)(struct netlink_callback___102 *);
	void *data;
	struct module___381 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___100 {
	int (*create)(struct sk_buff___101 *, struct net_device___100 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___101 *, unsigned char *);
	int (*cache)(const struct neighbour___80 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___100 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___100 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___100 *, int);
	int poll_owner;
	struct net_device___100 *dev;
	struct sk_buff___101 *gro_list;
	struct sk_buff___101 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___100 {
	struct net_device___100 *dev;
	struct Qdisc___92 *qdisc;
	struct Qdisc___92 *qdisc_sleeping;
	struct kobject___443 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___100 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___92 {
	struct sk_buff___101 *head;
	struct sk_buff___101 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___92;

struct Qdisc___92 {
	int (*enqueue)(struct sk_buff___101 *, struct Qdisc___92 *, struct sk_buff___101 **);
	struct sk_buff___101 * (*dequeue)(struct Qdisc___92 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___92 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___100 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___100 gso_skb;
	struct qdisc_skb_head___92 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___92 *next_sched;
	struct sk_buff_head___100 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___100 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___443 kobj;
	struct net_device___100 *dev;
	long: 64;
	struct xdp_rxq_info___100 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___100)(struct net_device___100 *, struct sk_buff___101 *, struct net_device___100 *);

struct netdev_bpf___100 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___90 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___90 *prog;
			const struct bpf_prog_offload_ops___90 *ops;
		} verifier;
		struct {
			struct bpf_prog___90 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___100 *offmap;
		};
		struct {
			struct xdp_umem___3 *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___100 {
	int (*xdo_dev_state_add)(struct xfrm_state___18 *);
	void (*xdo_dev_state_delete)(struct xfrm_state___18 *);
	void (*xdo_dev_state_free)(struct xfrm_state___18 *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___101 *, struct xfrm_state___18 *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state___18 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct xfrm_state_offload___18 {
	struct net_device___100 *dev;
	long unsigned int offload_handle;
	unsigned int num_exthdrs;
	u8 flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct xfrm_replay___18;

struct xfrm_type___18;

struct xfrm_mode___18;

struct xfrm_type_offload___18;

struct xfrm_state___18 {
	possible_net_t___102 xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	refcount_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
		u32 output_mark;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	const char *geniv;
	struct xfrm_encap_tmpl *encap;
	xfrm_address_t *coaddr;
	struct xfrm_state___18 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	const struct xfrm_replay___18 *repl;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct tasklet_hrtimer mtimer;
	struct xfrm_state_offload___18 xso;
	long int saved_tmo;
	long unsigned int lastused;
	struct page_frag___456 xfrag;
	const struct xfrm_type___18 *type;
	struct xfrm_mode___18 *inner_mode;
	struct xfrm_mode___18 *inner_mode_iaf;
	struct xfrm_mode___18 *outer_mode;
	const struct xfrm_type_offload___18 *type_offload;
	struct xfrm_sec_ctx___2 *security;
	void *data;
	u32 output_mark_mask;
	u32 if_id;
};

struct tlsdev_ops___100 {
	int (*tls_dev_add)(struct net_device___100 *, struct sock___80 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___100 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___100 *, struct sock___80 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___100 {
	int (*ndo_init)(struct net_device___100 *);
	void (*ndo_uninit)(struct net_device___100 *);
	int (*ndo_open)(struct net_device___100 *);
	int (*ndo_stop)(struct net_device___100 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___101 *, struct net_device___100 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___101 *, struct net_device___100 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___100 *, struct sk_buff___101 *, struct net_device___100 *, select_queue_fallback_t___100);
	void (*ndo_change_rx_flags)(struct net_device___100 *, int);
	void (*ndo_set_rx_mode)(struct net_device___100 *);
	int (*ndo_set_mac_address)(struct net_device___100 *, void *);
	int (*ndo_validate_addr)(struct net_device___100 *);
	int (*ndo_do_ioctl)(struct net_device___100 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___100 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___100 *, int);
	int (*ndo_neigh_setup)(struct net_device___100 *, struct neigh_parms___80 *);
	void (*ndo_tx_timeout)(struct net_device___100 *);
	void (*ndo_get_stats64)(struct net_device___100 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___100 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___100 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___100 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___100 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___100 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___100 *);
	int (*ndo_netpoll_setup)(struct net_device___100 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___100 *);
	int (*ndo_set_vf_mac)(struct net_device___100 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___100 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___100 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___100 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___100 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___100 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___100 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___100 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___100 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___100 *, int, struct sk_buff___101 *);
	int (*ndo_set_vf_guid)(struct net_device___100 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___100 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___100 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___100 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___100 *, const struct sk_buff___101 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___100 *, struct net_device___100 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___100 *, struct net_device___100 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___100 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___100 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___100 *, struct neighbour___80 *);
	void (*ndo_neigh_destroy)(struct net_device___100 *, struct neighbour___80 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___100 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___100 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___100 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___101 *, struct netlink_callback___102 *, struct net_device___100 *, struct net_device___100 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___100 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___100 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___101 *, u32, u32, struct net_device___100 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___100 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___100 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___100 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___100 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___100 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___100 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___100 *, struct net_device___100 *);
	void (*ndo_dfwd_del_station)(struct net_device___100 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___100 *);
	int (*ndo_set_tx_maxrate)(struct net_device___100 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___100 *);
	int (*ndo_change_proto_down)(struct net_device___100 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___100 *, struct sk_buff___101 *);
	void (*ndo_set_rx_headroom)(struct net_device___100 *, int);
	int (*ndo_bpf)(struct net_device___100 *, struct netdev_bpf___100 *);
	int (*ndo_xdp_xmit)(struct net_device___100 *, int, struct xdp_frame___100 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___100 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___100 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___80 {
	possible_net_t___102 net;
	struct net_device___100 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___80 *);
	void (*neigh_cleanup)(struct neighbour___80 *);
	struct neigh_table___80 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___80 {
	u32 (*l3mdev_fib_table)(const struct net_device___100 *);
	struct sk_buff___101 * (*l3mdev_l3_rcv)(struct net_device___100 *, struct sk_buff___101 *, u16);
	struct sk_buff___101 * (*l3mdev_l3_out)(struct net_device___100 *, struct sock___80 *, struct sk_buff___101 *, u16);
	struct dst_entry___80 * (*l3mdev_link_scope_lookup)(const struct net_device___100 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct ndisc_ops___51 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___100 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___100 *, struct neighbour___80 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___100 *, u8, struct neighbour___80 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___100 *, struct sk_buff___101 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___111 *, struct net_device___100 *, const struct prefix_info *, struct inet6_dev___51 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___51;

struct ifacaddr6___23;

struct inet6_dev___51 {
	struct net_device___100 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___51 *mc_list;
	struct ifmcaddr6___51 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___23 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	u8 rndid[8];
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___80 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
};

struct tcf_proto___92;

struct mini_Qdisc___92 {
	struct tcf_proto___92 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___92 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___100 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___111 *, struct net_device___100 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___100 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___100 *, struct list_head *);
	size_t (*get_size)(const struct net_device___100 *);
	int (*fill_info)(struct sk_buff___101 *, const struct net_device___100 *);
	size_t (*get_xstats_size)(const struct net_device___100 *);
	int (*fill_xstats)(struct sk_buff___101 *, const struct net_device___100 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___100 *, struct net_device___100 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___100 *, const struct net_device___100 *);
	int (*fill_slave_info)(struct sk_buff___101 *, const struct net_device___100 *, const struct net_device___100 *);
	struct net___111 * (*get_link_net)(const struct net_device___100 *);
	size_t (*get_linkxstats_size)(const struct net_device___100 *, int);
	int (*fill_linkxstats)(struct sk_buff___101 *, const struct net_device___100 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___100 {
	struct list_head poll_list;
	struct sk_buff_head___100 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___100 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___92 *output_queue;
	struct Qdisc___92 **output_queue_tailp;
	struct sk_buff___101 *completion_queue;
	struct sk_buff_head___100 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___100 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___100 input_pkt_queue;
	struct napi_struct___100 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct nf_hook_state___16 {
	unsigned int hook;
	u_int8_t pf;
	struct net_device___100 *in;
	struct net_device___100 *out;
	struct sock___80 *sk;
	struct net___111 *net;
	int (*okfn)(struct net___111 *, struct sock___80 *, struct sk_buff___101 *);
};

struct nf_nat_hook___16 {
	int (*parse_nat_setup)(struct nf_conn *, enum nf_nat_manip_type, const struct nlattr *);
	void (*decode_session)(struct sk_buff___101 *, struct flowi *);
	unsigned int (*manip_pkt)(struct sk_buff___101 *, struct nf_conn *, enum nf_nat_manip_type, enum ip_conntrack_dir);
};

struct nf_ct_hook___16 {
	int (*update)(struct net___111 *, struct sk_buff___101 *);
	void (*destroy)(struct nf_conntrack *);
	bool (*get_tuple_skb)(struct nf_conntrack_tuple *, const struct sk_buff___101 *);
};

struct nfnl_ct_hook___16 {
	struct nf_conn * (*get_ct)(const struct sk_buff___101 *, enum ip_conntrack_info *);
	size_t (*build_size)(const struct nf_conn *);
	int (*build)(struct sk_buff___101 *, struct nf_conn *, enum ip_conntrack_info, u_int16_t, u_int16_t);
	int (*parse)(const struct nlattr *, struct nf_conn *);
	int (*attach_expect)(const struct nlattr *, struct nf_conn *, u32, u32);
	void (*seq_adjust)(struct sk_buff___101 *, struct nf_conn *, enum ip_conntrack_info, s32);
};

struct pneigh_entry___80;

struct neigh_hash_table___80;

struct neigh_table___80 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___100 *, __u32 *);
	bool (*key_eq)(const struct neighbour___80 *, const void *);
	int (*constructor)(struct neighbour___80 *);
	int (*pconstructor)(struct pneigh_entry___80 *);
	void (*pdestructor)(struct pneigh_entry___80 *);
	void (*proxy_redo)(struct sk_buff___101 *);
	char *id;
	struct neigh_parms___80 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___100 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___80 *nht;
	struct pneigh_entry___80 **phash_buckets;
};

struct neigh_ops___80 {
	int family;
	void (*solicit)(struct neighbour___80 *, struct sk_buff___101 *);
	void (*error_report)(struct neighbour___80 *, struct sk_buff___101 *);
	int (*output)(struct neighbour___80 *, struct sk_buff___101 *);
	int (*connected_output)(struct neighbour___80 *, struct sk_buff___101 *);
};

struct pneigh_entry___80 {
	struct pneigh_entry___80 *next;
	possible_net_t___102 net;
	struct net_device___100 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___80 {
	struct neighbour___80 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct bdi_writeback_congested___245 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___245 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___245 {
	struct bio___245 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___247 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___247 bip_inline_vecs[0];
};

struct bio_set___245 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___245 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___188 {
	struct mem_cgroup___188 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___188 {
	struct lruvec___456 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___188 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___188 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct kernel_param_ops___381 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___381 *);
	int (*get)(char *, const struct kernel_param___381 *);
	void (*free)(void *);
};

struct kparam_array___381;

struct kernel_param___381 {
	const char *name;
	struct module___381 *mod;
	const struct kernel_param_ops___381 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___381 *arr;
	};
};

struct kparam_array___381 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___381 *ops;
	void *elem;
};

struct module_attribute___381 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___381 *, struct module_kobject___381 *, char *);
	ssize_t (*store)(struct module_attribute___381 *, struct module_kobject___381 *, const char *, size_t);
	void (*setup)(struct module___381 *, const char *);
	int (*test)(struct module___381 *);
	void (*free)(struct module___381 *);
};

struct gnet_dump___92 {
	spinlock_t *lock;
	struct sk_buff___101 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___92;

struct Qdisc_ops___92 {
	struct Qdisc_ops___92 *next;
	const struct Qdisc_class_ops___92 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___101 *, struct Qdisc___92 *, struct sk_buff___101 **);
	struct sk_buff___101 * (*dequeue)(struct Qdisc___92 *);
	struct sk_buff___101 * (*peek)(struct Qdisc___92 *);
	int (*init)(struct Qdisc___92 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___92 *);
	void (*destroy)(struct Qdisc___92 *);
	int (*change)(struct Qdisc___92 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___92 *);
	int (*change_tx_queue_len)(struct Qdisc___92 *, unsigned int);
	int (*dump)(struct Qdisc___92 *, struct sk_buff___101 *);
	int (*dump_stats)(struct Qdisc___92 *, struct gnet_dump___92 *);
	void (*ingress_block_set)(struct Qdisc___92 *, u32);
	void (*egress_block_set)(struct Qdisc___92 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___92 *);
	u32 (*egress_block_get)(struct Qdisc___92 *);
	struct module___381 *owner;
};

struct tcf_block___92;

struct Qdisc_class_ops___92 {
	unsigned int flags;
	struct netdev_queue___100 * (*select_queue)(struct Qdisc___92 *, struct tcmsg *);
	int (*graft)(struct Qdisc___92 *, long unsigned int, struct Qdisc___92 *, struct Qdisc___92 **, struct netlink_ext_ack *);
	struct Qdisc___92 * (*leaf)(struct Qdisc___92 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___92 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___92 *, u32);
	int (*change)(struct Qdisc___92 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___92 *, long unsigned int);
	void (*walk)(struct Qdisc___92 *, struct qdisc_walker *);
	struct tcf_block___92 * (*tcf_block)(struct Qdisc___92 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___92 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___92 *, long unsigned int);
	int (*dump)(struct Qdisc___92 *, long unsigned int, struct sk_buff___101 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___92 *, long unsigned int, struct gnet_dump___92 *);
};

struct tcf_chain___92;

struct tcf_block___92 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___111 *net;
	struct Qdisc___92 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___92 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___92;

struct tcf_proto_ops___92;

struct tcf_proto___92 {
	struct tcf_proto___92 *next;
	void *root;
	int (*classify)(struct sk_buff___101 *, const struct tcf_proto___92 *, struct tcf_result___92 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___92 *ops;
	struct tcf_chain___92 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___92 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___92 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___92 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___101 *, const struct tcf_proto___92 *, struct tcf_result___92 *);
	int (*init)(struct tcf_proto___92 *);
	void (*destroy)(struct tcf_proto___92 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___92 *, u32);
	void (*put)(struct tcf_proto___92 *, void *);
	int (*change)(struct net___111 *, struct sk_buff___101 *, struct tcf_proto___92 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___92 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___92 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___92 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___111 *, struct tcf_chain___92 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___111 *, struct tcf_proto___92 *, void *, struct sk_buff___101 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___101 *, struct net___111 *, void *);
	struct module___381 *owner;
	int flags;
};

struct tcf_chain___92 {
	struct mutex filter_chain_lock;
	struct tcf_proto___92 *filter_chain;
	struct list_head list;
	struct tcf_block___92 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___92 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___80 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___90 *prog;
};

struct bpf_redirect_info___90 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___305 *map;
	struct bpf_map___305 *map_to_flush;
	u32 kern_flags;
};

struct fib_rule___80 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___80 *ctarget;
	struct net___111 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___80 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___80 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___63;

struct timewait_sock_ops___59;

struct proto___80 {
	void (*close)(struct sock___80 *, long int);
	int (*pre_connect)(struct sock___80 *, struct sockaddr *, int);
	int (*connect)(struct sock___80 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___80 *, int);
	struct sock___80 * (*accept)(struct sock___80 *, int, int *, bool);
	int (*ioctl)(struct sock___80 *, int, long unsigned int);
	int (*init)(struct sock___80 *);
	void (*destroy)(struct sock___80 *);
	void (*shutdown)(struct sock___80 *, int);
	int (*setsockopt)(struct sock___80 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___80 *, int, int, char *, int *);
	void (*keepalive)(struct sock___80 *, int);
	int (*sendmsg)(struct sock___80 *, struct msghdr___83 *, size_t);
	int (*recvmsg)(struct sock___80 *, struct msghdr___83 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___80 *, struct page___456 *, int, size_t, int);
	int (*bind)(struct sock___80 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___80 *, struct sk_buff___101 *);
	void (*release_cb)(struct sock___80 *);
	int (*hash)(struct sock___80 *);
	void (*unhash)(struct sock___80 *);
	void (*rehash)(struct sock___80 *);
	int (*get_port)(struct sock___80 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___80 *);
	bool (*stream_memory_read)(const struct sock___80 *);
	void (*enter_memory_pressure)(struct sock___80 *);
	void (*leave_memory_pressure)(struct sock___80 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___63 *rsk_prot;
	struct timewait_sock_ops___59 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___381 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___80 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct xfrm_policy_queue___18 {
	struct sk_buff_head___100 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___18 {
	possible_net_t___102 xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	refcount_t refcnt;
	struct timer_list timer;
	atomic_t genid;
	u32 priority;
	u32 index;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___18 polq;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx___2 *security;
	struct xfrm_tmpl xfrm_vec[6];
	struct callback_head rcu;
	u32 if_id;
};

struct request_sock___64;

struct request_sock_ops___63 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___80 *, struct request_sock___64 *);
	void (*send_ack)(const struct sock___80 *, struct sk_buff___101 *, struct request_sock___64 *);
	void (*send_reset)(const struct sock___80 *, struct sk_buff___101 *);
	void (*destructor)(struct request_sock___64 *);
	void (*syn_ack_timeout)(const struct request_sock___64 *);
};

struct timewait_sock_ops___59 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___80 *, struct sock___80 *, void *);
	void (*twsk_destructor)(struct sock___80 *);
};

struct request_sock___64 {
	struct sock_common___80 __req_common;
	struct request_sock___64 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___63 *rsk_ops;
	struct sock___80 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct inet_cork___19 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___80 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
	__u16 gso_size;
	u64 transmit_time;
};

struct inet_cork_full___19 {
	struct inet_cork___19 base;
	struct flowi fl;
};

struct ipv6_pinfo___19;

struct inet_sock___19 {
	struct sock___80 sk;
	struct ipv6_pinfo___19 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	__be16 inet_sport;
	__u16 inet_id;
	struct ip_options_rcu *inet_opt;
	int rx_dst_ifindex;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 bind_address_no_port: 1;
	__u8 defer_connect: 1;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___19 cork;
};

struct ipv6_fl_socklist___18;

struct ipv6_pinfo___19 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
			__u16 recvfragsize: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 repflow: 1;
	__u16 pmtudisc: 3;
	__u16 padding: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u16 autoflowlabel: 1;
	__u16 autoflowlabel_set: 1;
	__u8 min_hopcount;
	__u8 tclass;
	__be32 rcv_flowinfo;
	__u32 dst_cookie;
	__u32 rx_dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___18 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___101 *pktoptions;
	struct sk_buff___101 *rxpmtu;
	struct inet6_cork cork;
};

struct ip6_flowlabel___18;

struct ipv6_fl_socklist___18 {
	struct ipv6_fl_socklist___18 *next;
	struct ip6_flowlabel___18 *fl;
	struct callback_head rcu;
};

struct ifmcaddr6___51 {
	struct in6_addr mca_addr;
	struct inet6_dev___51 *idev;
	struct ifmcaddr6___51 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___23 {
	struct in6_addr aca_addr;
	struct fib6_info___23 *aca_rt;
	struct ifacaddr6___23 *aca_next;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct ip6_ra_chain___51 {
	struct ip6_ra_chain___51 *next;
	struct sock___80 *sk;
	int sel;
	void (*destructor)(struct sock___80 *);
};

struct ip6_flowlabel___18 {
	struct ip6_flowlabel___18 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___253 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___111 *fl_net;
};

struct rtable___17 {
	struct dst_entry___80 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	__be32 rt_gateway;
	u32 rt_mtu_locked: 1;
	u32 rt_pmtu: 31;
	struct list_head rt_uncached;
	struct uncached_list *rt_uncached_list;
};

struct xfrm_replay___18 {
	void (*advance)(struct xfrm_state___18 *, __be32);
	int (*check)(struct xfrm_state___18 *, struct sk_buff___101 *, __be32);
	int (*recheck)(struct xfrm_state___18 *, struct sk_buff___101 *, __be32);
	void (*notify)(struct xfrm_state___18 *, int);
	int (*overflow)(struct xfrm_state___18 *, struct sk_buff___101 *);
};

struct xfrm_type___18 {
	char *description;
	struct module___381 *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___18 *);
	void (*destructor)(struct xfrm_state___18 *);
	int (*input)(struct xfrm_state___18 *, struct sk_buff___101 *);
	int (*output)(struct xfrm_state___18 *, struct sk_buff___101 *);
	int (*reject)(struct xfrm_state___18 *, struct sk_buff___101 *, const struct flowi *);
	int (*hdr_offset)(struct xfrm_state___18 *, struct sk_buff___101 *, u8 **);
	u32 (*get_mtu)(struct xfrm_state___18 *, int);
};

struct xfrm_state_afinfo___18;

struct xfrm_mode___18 {
	int (*input2)(struct xfrm_state___18 *, struct sk_buff___101 *);
	int (*input)(struct xfrm_state___18 *, struct sk_buff___101 *);
	int (*output2)(struct xfrm_state___18 *, struct sk_buff___101 *);
	int (*output)(struct xfrm_state___18 *, struct sk_buff___101 *);
	struct sk_buff___101 * (*gso_segment)(struct xfrm_state___18 *, struct sk_buff___101 *, netdev_features_t);
	void (*xmit)(struct xfrm_state___18 *, struct sk_buff___101 *);
	struct xfrm_state_afinfo___18 *afinfo;
	struct module___381 *owner;
	unsigned int encap;
	int flags;
};

struct xfrm_type_offload___18 {
	char *description;
	struct module___381 *owner;
	u8 proto;
	void (*encap)(struct xfrm_state___18 *, struct sk_buff___101 *);
	int (*input_tail)(struct xfrm_state___18 *, struct sk_buff___101 *);
	int (*xmit)(struct xfrm_state___18 *, struct sk_buff___101 *, netdev_features_t);
};

struct xfrm_state_afinfo___18 {
	unsigned int family;
	unsigned int proto;
	__be16 eth_proto;
	struct module___381 *owner;
	const struct xfrm_type___18 *type_map[256];
	const struct xfrm_type_offload___18 *type_offload_map[256];
	struct xfrm_mode___18 *mode_map[5];
	int (*init_flags)(struct xfrm_state___18 *);
	void (*init_tempsel)(struct xfrm_selector *, const struct flowi *);
	void (*init_temprop)(struct xfrm_state___18 *, const struct xfrm_tmpl *, const xfrm_address_t *, const xfrm_address_t *);
	int (*tmpl_sort)(struct xfrm_tmpl **, struct xfrm_tmpl **, int);
	int (*state_sort)(struct xfrm_state___18 **, struct xfrm_state___18 **, int);
	int (*output)(struct net___111 *, struct sock___80 *, struct sk_buff___101 *);
	int (*output_finish)(struct sock___80 *, struct sk_buff___101 *);
	int (*extract_input)(struct xfrm_state___18 *, struct sk_buff___101 *);
	int (*extract_output)(struct xfrm_state___18 *, struct sk_buff___101 *);
	int (*transport_finish)(struct sk_buff___101 *, int);
	void (*local_error)(struct sk_buff___101 *, u32);
};

struct nf_queue_entry___4 {
	struct list_head list;
	struct sk_buff___101 *skb;
	unsigned int id;
	unsigned int hook_index;
	struct nf_hook_state___16 state;
	u16 size;
};

struct module_version_attribute___11 {
	struct module_attribute___379 mattr;
	const char *module_name;
	const char *version;
};

struct bictcp {
	u32 cnt;
	u32 last_max_cwnd;
	u32 last_cwnd;
	u32 last_time;
	u32 bic_origin_point;
	u32 bic_K;
	u32 delay_min;
	u32 epoch_start;
	u32 ack_cnt;
	u32 tcp_cwnd;
	u16 unused;
	u8 sample_cnt;
	u8 found;
	u32 round_start;
	u32 end_seq;
	u32 last_ack;
	u32 curr_rtt;
};

struct tls_crypto_info {
	__u16 version;
	__u16 cipher_type;
};

struct tls_prot_info {
	u16 version;
	u16 cipher_type;
	u16 prepend_size;
	u16 tag_size;
	u16 overhead_size;
	u16 iv_size;
	u16 rec_seq_size;
	u16 aad_size;
	u16 tail_size;
};

struct tls12_crypto_info_aes_gcm_128 {
	struct tls_crypto_info info;
	unsigned char iv[8];
	unsigned char key[16];
	unsigned char salt[4];
	unsigned char rec_seq[8];
};

struct tls12_crypto_info_aes_gcm_256 {
	struct tls_crypto_info info;
	unsigned char iv[8];
	unsigned char key[32];
	unsigned char salt[4];
	unsigned char rec_seq[8];
};

union tls_crypto_context {
	struct tls_crypto_info info;
	struct tls12_crypto_info_aes_gcm_128 aes_gcm_128;
	struct tls12_crypto_info_aes_gcm_256 aes_gcm_256;
	char rh_kabi_padding[72];
};

struct cipher_context {
	char *iv;
	char *rec_seq;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct tls_context {
	struct tls_prot_info prot_info;
	union tls_crypto_context crypto_send;
	union tls_crypto_context crypto_recv;
	struct list_head list;
	struct net_device___63 *netdev;
	refcount_t refcount;
	void *priv_ctx_tx;
	void *priv_ctx_rx;
	u8 tx_conf: 3;
	u8 rx_conf: 3;
	struct cipher_context tx;
	struct cipher_context rx;
	struct scatterlist *partially_sent_record;
	u16 partially_sent_offset;
	long unsigned int flags;
	bool in_tcp_sendpages;
	bool pending_open_record_frags;
	int (*push_pending_record)(struct sock___46 *, int);
	void (*sk_write_space)(struct sock___46 *);
	void (*sk_destruct)(struct sock___46 *);
	void (*sk_proto_close)(struct sock___46 *, long int);
	int (*setsockopt)(struct sock___46 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___46 *, int, int, char *, int *);
	int (*hash)(struct sock___46 *);
	void (*unhash)(struct sock___46 *);
};

struct fastopen_queue___13 {
	struct request_sock___31 *rskq_rst_head;
	struct request_sock___31 *rskq_rst_tail;
	spinlock_t lock;
	int qlen;
	int max_qlen;
	struct tcp_fastopen_context___6 *ctx;
};

struct request_sock_queue___13 {
	spinlock_t rskq_lock;
	u8 rskq_defer_accept;
	u32 synflood_warned;
	atomic_t qlen;
	atomic_t young;
	struct request_sock___31 *rskq_accept_head;
	struct request_sock___31 *rskq_accept_tail;
	struct fastopen_queue___13 fastopenq;
};

struct inet_cork___20 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___45 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
	__u16 gso_size;
	u64 transmit_time;
};

struct inet_cork_full___20 {
	struct inet_cork___20 base;
	struct flowi fl;
};

struct ipv6_pinfo___20;

struct inet_sock___20 {
	struct sock___46 sk;
	struct ipv6_pinfo___20 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	__be16 inet_sport;
	__u16 inet_id;
	struct ip_options_rcu *inet_opt;
	int rx_dst_ifindex;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 bind_address_no_port: 1;
	__u8 defer_connect: 1;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___20 cork;
};

struct ipv6_fl_socklist___19;

struct ipv6_pinfo___20 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
			__u16 recvfragsize: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 repflow: 1;
	__u16 pmtudisc: 3;
	__u16 padding: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u16 autoflowlabel: 1;
	__u16 autoflowlabel_set: 1;
	__u8 min_hopcount;
	__u8 tclass;
	__be32 rcv_flowinfo;
	__u32 dst_cookie;
	__u32 rx_dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___19 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___64 *pktoptions;
	struct sk_buff___64 *rxpmtu;
	struct inet6_cork cork;
};

struct inet_connection_sock_af_ops___12 {
	int (*queue_xmit)(struct sock___46 *, struct sk_buff___64 *, struct flowi *);
	void (*send_check)(struct sock___46 *, struct sk_buff___64 *);
	int (*rebuild_header)(struct sock___46 *);
	void (*sk_rx_dst_set)(struct sock___46 *, const struct sk_buff___64 *);
	int (*conn_request)(struct sock___46 *, struct sk_buff___64 *);
	struct sock___46 * (*syn_recv_sock)(const struct sock___46 *, struct sk_buff___64 *, struct request_sock___31 *, struct dst_entry___45 *, struct request_sock___31 *, bool *);
	u16 net_header_len;
	u16 net_frag_header_len;
	u16 sockaddr_len;
	int (*setsockopt)(struct sock___46 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___46 *, int, int, char *, int *);
	void (*addr2sockaddr)(struct sock___46 *, struct sockaddr *);
	void (*mtu_reduced)(struct sock___46 *);
};

struct inet_bind_bucket___12;

struct tcp_ulp_ops___11;

struct inet_connection_sock___13 {
	struct inet_sock___20 icsk_inet;
	struct request_sock_queue___13 icsk_accept_queue;
	struct inet_bind_bucket___12 *icsk_bind_hash;
	long unsigned int icsk_timeout;
	struct timer_list icsk_retransmit_timer;
	struct timer_list icsk_delack_timer;
	__u32 icsk_rto;
	__u32 icsk_pmtu_cookie;
	const struct tcp_congestion_ops___6 *icsk_ca_ops;
	const struct inet_connection_sock_af_ops___12 *icsk_af_ops;
	const struct tcp_ulp_ops___11 *icsk_ulp_ops;
	void *icsk_ulp_data;
	void (*icsk_clean_acked)(struct sock___46 *, u32);
	struct hlist_node icsk_listen_portaddr_node;
	unsigned int (*icsk_sync_mss)(struct sock___46 *, u32);
	__u8 icsk_ca_state: 6;
	__u8 icsk_ca_setsockopt: 1;
	__u8 icsk_ca_dst_locked: 1;
	__u8 icsk_retransmits;
	__u8 icsk_pending;
	__u8 icsk_backoff;
	__u8 icsk_syn_retries;
	__u8 icsk_probes_out;
	__u16 icsk_ext_hdr_len;
	struct {
		__u8 pending;
		__u8 quick;
		__u8 pingpong;
		__u8 blocked;
		__u32 ato;
		long unsigned int timeout;
		__u32 lrcvtime;
		__u16 last_seg_size;
		__u16 rcv_mss;
	} icsk_ack;
	struct {
		int enabled;
		int search_high;
		int search_low;
		int probe_size;
		u32 probe_timestamp;
	} icsk_mtup;
	u32 icsk_user_timeout;
	u64 icsk_ca_priv[11];
};

struct inet_bind_bucket___12 {
	possible_net_t___64 ib_net;
	short unsigned int port;
	signed char fastreuse;
	signed char fastreuseport;
	kuid_t fastuid;
	struct in6_addr fast_v6_rcv_saddr;
	__be32 fast_rcv_saddr;
	short unsigned int fast_sk_family;
	bool fast_ipv6_only;
	struct hlist_node node;
	struct hlist_head owners;
};

struct tcp_ulp_ops___11 {
	struct list_head list;
	int (*init)(struct sock___46 *);
	void (*release)(struct sock___46 *);
	char name[16];
	struct module___347 *owner;
};

struct ip6_flowlabel___19;

struct ipv6_fl_socklist___19 {
	struct ipv6_fl_socklist___19 *next;
	struct ip6_flowlabel___19 *fl;
	struct callback_head rcu;
};

struct ip6_flowlabel___19 {
	struct ip6_flowlabel___19 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___253 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___74 *fl_net;
};

struct aead_request___8 {
	struct crypto_async_request___25 base;
	unsigned int assoclen;
	unsigned int cryptlen;
	u8 *iv;
	struct scatterlist *src;
	struct scatterlist *dst;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_aead___7 {
	unsigned int authsize;
	unsigned int reqsize;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_tfm___25 base;
};

struct tls_rec {
	struct list_head list;
	int tx_ready;
	int tx_flags;
	int inplace_crypto;
	struct sk_msg___2 msg_plaintext;
	struct sk_msg___2 msg_encrypted;
	struct scatterlist sg_aead_in[2];
	struct scatterlist sg_aead_out[2];
	char content_type;
	struct scatterlist sg_content_type;
	char aad_space[13];
	u8 iv_data[12];
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct aead_request___8 aead_req;
	u8 aead_req_ctx[0];
};

struct tx_work {
	struct delayed_work work;
	struct sock___46 *sk;
};

struct tls_sw_context_tx {
	struct crypto_aead___7 *aead_send;
	struct crypto_wait async_wait;
	struct tx_work tx_work;
	struct tls_rec *open_rec;
	struct list_head tx_list;
	atomic_t encrypt_pending;
	int async_notify;
	int async_capable;
	long unsigned int tx_bitmask;
};

enum {
	TCP_BPF_IPV4 = 0,
	TCP_BPF_IPV6 = 1,
	TCP_BPF_NUM_PROTS = 2,
};

enum {
	TCP_BPF_BASE = 0,
	TCP_BPF_TX = 1,
	TCP_BPF_NUM_CFGS = 2,
};

struct module___382;

struct file___456;

struct kiocb___456;

struct iov_iter___223;

struct poll_table_struct___295;

struct vm_area_struct___457;

struct inode___456;

struct file_lock___456;

struct page___457;

struct pipe_inode_info___137;

struct seq_file___395;

struct file_operations___456 {
	struct module___382 *owner;
	loff_t (*llseek)(struct file___456 *, loff_t, int);
	ssize_t (*read)(struct file___456 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___456 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___456 *, struct iov_iter___223 *);
	ssize_t (*write_iter)(struct kiocb___456 *, struct iov_iter___223 *);
	int (*iopoll)(struct kiocb___456 *, bool);
	int (*iterate)(struct file___456 *, struct dir_context *);
	int (*iterate_shared)(struct file___456 *, struct dir_context *);
	__poll_t (*poll)(struct file___456 *, struct poll_table_struct___295 *);
	long int (*unlocked_ioctl)(struct file___456 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___456 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___456 *, struct vm_area_struct___457 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___456 *, struct file___456 *);
	int (*flush)(struct file___456 *, fl_owner_t);
	int (*release)(struct inode___456 *, struct file___456 *);
	int (*fsync)(struct file___456 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___456 *, int);
	int (*lock)(struct file___456 *, int, struct file_lock___456 *);
	ssize_t (*sendpage)(struct file___456 *, struct page___457 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___456 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___456 *, int, struct file_lock___456 *);
	ssize_t (*splice_write)(struct pipe_inode_info___137 *, struct file___456 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___456 *, loff_t *, struct pipe_inode_info___137 *, size_t, unsigned int);
	int (*setlease)(struct file___456 *, long int, struct file_lock___456 **, void **);
	long int (*fallocate)(struct file___456 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___395 *, struct file___456 *);
	ssize_t (*copy_file_range)(struct file___456 *, loff_t, struct file___456 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___456 *, loff_t, struct file___456 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___456 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___457 {
	u64 seqnum;
	struct vm_area_struct___457 *vmas[4];
};

struct page_frag___457 {
	struct page___457 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___457;

struct mem_cgroup___189;

struct pid___254;

struct cred___424;

struct nsproxy___351;

struct signal_struct___331;

struct bio_list___246;

struct backing_dev_info___246;

struct css_set___305;

struct vm_struct___360;

struct task_struct___458 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___458 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___457 *mm;
	struct mm_struct___457 *active_mm;
	struct vmacache___457 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___458 *real_parent;
	struct task_struct___458 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___458 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___189 *active_memcg;
	long int rh_reserved2;
	struct pid___254 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___254 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___254 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___424 *ptracer_cred;
	const struct cred___424 *real_cred;
	const struct cred___424 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___351 *nsproxy;
	struct signal_struct___331 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___458 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___246 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___246 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___305 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___137 *splice_pipe;
	struct page_frag___457 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___189 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___458 *oom_reaper_list;
	struct vm_struct___360 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___156 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___254;

struct upid___254 {
	int nr;
	struct pid_namespace___254 *ns;
};

struct dentry___456;

struct user_namespace___321;

struct ucounts___321;

struct pid_namespace___254 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___458 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___254 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___456 *proc_self;
	struct dentry___456 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___321 *user_ns;
	struct ucounts___321 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___29 ns;
};

struct pid___254 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___254 numbers[1];
};

struct rw_semaphore___458 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___458 *owner;
};

struct key___424;

struct user_namespace___321 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___321 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___29 ns;
	long unsigned int flags;
	struct key___424 *persistent_keyring_register;
	struct rw_semaphore___458 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___321 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct secondary_data___458 {
	void *stack;
	struct task_struct___458 *task;
	long int status;
};

typedef struct page___457 *pgtable_t___457;

struct address_space___456;

struct dev_pagemap___444;

struct page___457 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___456 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___457 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___457 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___457 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___444 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___189 *mem_cgroup;
};

struct user_struct___424 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___424 *uid_keyring;
	struct key___424 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___444;

struct vm_area_struct___457 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___457 *vm_next;
	struct vm_area_struct___457 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___457 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___444 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___456 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___457;

struct mm_struct___457 {
	struct {
		struct vm_area_struct___457 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___456 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___458 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___457 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___458 *owner;
		struct user_namespace___321 *user_ns;
		struct file___456 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___457 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup___305;

struct cgroup_subsys___305;

struct cgroup_subsys_state___305 {
	struct cgroup___305 *cgroup;
	struct cgroup_subsys___305 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___305 *parent;
};

struct kernfs_node___451;

struct cgroup_file___305 {
	struct kernfs_node___451 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___189;

struct mem_cgroup___189 {
	struct cgroup_subsys_state___305 css;
	struct mem_cgroup_id___16 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___305 events_file;
	struct cgroup_file___305 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___458 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___189 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cred___424 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___424 *session_keyring;
	struct key___424 *process_keyring;
	struct key___424 *thread_keyring;
	struct key___424 *request_key_auth;
	void *security;
	struct user_struct___424 *user;
	struct user_namespace___321 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___112;

struct cgroup_namespace___305;

struct nsproxy___351 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___254 *pid_ns_for_children;
	struct net___112 *net_ns;
	struct cgroup_namespace___305 *cgroup_ns;
};

struct signal_struct___331 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___458 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___458 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___254 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___254 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___457 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___254 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___246;

struct bio_list___246 {
	struct bio___246 *head;
	struct bio___246 *tail;
};

struct bdi_writeback_congested___246;

struct bdi_writeback___246 {
	struct backing_dev_info___246 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___246 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___305 *memcg_css;
	struct cgroup_subsys_state___305 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___424;

struct backing_dev_info___246 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___246 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___424 *dev;
	struct device___424 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___456 *debug_dir;
	struct dentry___456 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___305 {
	struct cgroup_subsys_state___305 *subsys[13];
	refcount_t refcount;
	struct css_set___305 *dom_cset;
	struct cgroup___305 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___305 *mg_src_cgrp;
	struct cgroup___305 *mg_dst_cgrp;
	struct css_set___305 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___456;

struct pipe_buffer___137;

struct pipe_inode_info___137 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___457 *tmp_page;
	struct fasync_struct___456 *fasync_readers;
	struct fasync_struct___456 *fasync_writers;
	struct pipe_buffer___137 *bufs;
	struct user_struct___424 *user;
};

struct vm_struct___360 {
	struct vm_struct___360 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___457 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___343 {
	struct task_struct___458 task;
	long unsigned int stack[8192];
};

typedef int (*key_restrict_link_func_t___425)(struct key___424 *, const struct key_type *, const union key_payload *, struct key___424 *);

struct key_restriction___424;

struct key___424 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___458 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___424 *restrict_link;
};

struct key_restriction___424 {
	key_restrict_link_func_t___425 check;
	struct key___424 *key;
	struct key_type *keytype;
};

struct pglist_data___457;

struct lruvec___457 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___457 *pgdat;
};

struct zone___457 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___457 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___457 {
	struct zone___457 *zone;
	int zone_idx;
};

struct zonelist___457 {
	struct zoneref___457 _zonerefs[25];
};

struct pglist_data___457 {
	struct zone___457 node_zones[3];
	struct zonelist___457 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___458 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___458 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___457 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___457 {
	struct rw_semaphore___458 rwsem;
	struct notifier_block *head;
};

struct address_space_operations___456;

struct address_space___456 {
	struct inode___456 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___458 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___456 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___444)(struct vm_area_struct___457 *, long unsigned int, const struct page___457 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___444)(struct page___457 *, void *);

struct dev_pagemap___444 {
	dev_page_fault_t___444 page_fault;
	dev_page_free_t___444 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___424 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___457 {
	struct vfsmount *mnt;
	struct dentry___456 *dentry;
};

struct fown_struct___254 {
	rwlock_t lock;
	struct pid___254 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___456 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___457 f_path;
	struct inode___456 *f_inode;
	const struct file_operations___456 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___254 f_owner;
	const struct cred___424 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___456 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___444;

struct vm_operations_struct___444 {
	void (*open)(struct vm_area_struct___457 *);
	void (*close)(struct vm_area_struct___457 *);
	int (*split)(struct vm_area_struct___457 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___457 *);
	vm_fault_t (*fault)(struct vm_fault___444 *);
	vm_fault_t (*huge_fault)(struct vm_fault___444 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___444 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___457 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___444 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___444 *);
	int (*access)(struct vm_area_struct___457 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___457 *);
	int (*set_policy)(struct vm_area_struct___457 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___457 *, long unsigned int);
	struct page___457 * (*find_special_page)(struct vm_area_struct___457 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___457 {
	struct task_struct___458 *task;
	struct core_thread___457 *next;
};

struct core_state___457 {
	atomic_t nr_threads;
	struct core_thread___457 dumper;
	struct completion startup;
};

struct vm_fault___444 {
	struct vm_area_struct___457 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___457 *cow_page;
	struct mem_cgroup___189 *memcg;
	struct page___457 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___457 prealloc_pte;
};

struct shrink_control___189 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___189 *memcg;
};

struct shrinker___189 {
	long unsigned int (*count_objects)(struct shrinker___189 *, struct shrink_control___189 *);
	long unsigned int (*scan_objects)(struct shrinker___189 *, struct shrink_control___189 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct kset___443;

struct kobj_type___443;

struct kobject___444 {
	const char *name;
	struct list_head entry;
	struct kobject___444 *parent;
	struct kset___443 *kset;
	struct kobj_type___443 *ktype;
	struct kernfs_node___451 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___424 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___424 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___424;

struct bus_type___424;

struct device_driver___424;

struct dev_pm_domain___424;

struct dma_map_ops___196;

struct fwnode_handle___344;

struct class___424;

struct attribute_group___421;

struct device___424 {
	struct device___424 *parent;
	struct device_private *p;
	struct kobject___444 kobj;
	const char *init_name;
	const struct device_type___424 *type;
	struct mutex mutex;
	struct bus_type___424 *bus;
	struct device_driver___424 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___424 power;
	struct dev_pm_domain___424 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___196 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___344 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___424 *class;
	const struct attribute_group___421 **groups;
	void (*release)(struct device___424 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___456;

struct super_block___456;

struct dentry___456 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___456 *d_parent;
	struct qstr d_name;
	struct inode___456 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___456 *d_op;
	struct super_block___456 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___456;

struct block_device___456;

struct inode___456 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___456 *i_op;
	struct super_block___456 *i_sb;
	struct address_space___456 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___458 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___246 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___456 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___456 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___137 *i_pipe;
		struct block_device___456 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___456 {
	int (*d_revalidate)(struct dentry___456 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___456 *, unsigned int);
	int (*d_hash)(const struct dentry___456 *, struct qstr *);
	int (*d_compare)(const struct dentry___456 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___456 *);
	int (*d_init)(struct dentry___456 *);
	void (*d_release)(struct dentry___456 *);
	void (*d_prune)(struct dentry___456 *);
	void (*d_iput)(struct dentry___456 *, struct inode___456 *);
	char * (*d_dname)(struct dentry___456 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___457 *);
	int (*d_manage)(const struct path___457 *, bool);
	struct dentry___456 * (*d_real)(struct dentry___456 *, const struct inode___456 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___456;

struct mem_dqinfo___456 {
	struct quota_format_type___456 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___456;

struct quota_info___456 {
	unsigned int flags;
	struct rw_semaphore___458 dqio_sem;
	struct inode___456 *files[3];
	struct mem_dqinfo___456 info[3];
	const struct quota_format_ops___456 *ops[3];
};

struct rcuwait___456 {
	struct task_struct___458 *task;
};

struct percpu_rw_semaphore___456 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___458 rw_sem;
	struct rcuwait___456 writer;
	int readers_block;
};

struct sb_writers___456 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___456 rw_sem[3];
};

struct file_system_type___456;

struct super_operations___456;

struct dquot_operations___456;

struct quotactl_ops___456;

struct super_block___456 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___456 *s_type;
	const struct super_operations___456 *s_op;
	const struct dquot_operations___456 *dq_op;
	const struct quotactl_ops___456 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___456 *s_root;
	struct rw_semaphore___458 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___456 *s_bdev;
	struct backing_dev_info___246 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___456 s_dquot;
	struct sb_writers___456 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___456 *s_d_op;
	int cleancache_poolid;
	struct shrinker___189 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___321 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___456 {
	struct file___456 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___456 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___456 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___456 *ia_file;
};

struct dquot___456 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___456 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___456 {
	int qf_fmt_id;
	const struct quota_format_ops___456 *qf_ops;
	struct module___382 *qf_owner;
	struct quota_format_type___456 *qf_next;
};

struct quota_format_ops___456 {
	int (*check_quota_file)(struct super_block___456 *, int);
	int (*read_file_info)(struct super_block___456 *, int);
	int (*write_file_info)(struct super_block___456 *, int);
	int (*free_file_info)(struct super_block___456 *, int);
	int (*read_dqblk)(struct dquot___456 *);
	int (*commit_dqblk)(struct dquot___456 *);
	int (*release_dqblk)(struct dquot___456 *);
	int (*get_next_id)(struct super_block___456 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___456 {
	int (*write_dquot)(struct dquot___456 *);
	struct dquot___456 * (*alloc_dquot)(struct super_block___456 *, int);
	void (*destroy_dquot)(struct dquot___456 *);
	int (*acquire_dquot)(struct dquot___456 *);
	int (*release_dquot)(struct dquot___456 *);
	int (*mark_dirty)(struct dquot___456 *);
	int (*write_info)(struct super_block___456 *, int);
	qsize_t * (*get_reserved_space)(struct inode___456 *);
	int (*get_projid)(struct inode___456 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___456 *, qsize_t *);
	int (*get_next_id)(struct super_block___456 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___456 {
	int (*quota_on)(struct super_block___456 *, int, int, const struct path___457 *);
	int (*quota_off)(struct super_block___456 *, int);
	int (*quota_enable)(struct super_block___456 *, unsigned int);
	int (*quota_disable)(struct super_block___456 *, unsigned int);
	int (*quota_sync)(struct super_block___456 *, int);
	int (*set_info)(struct super_block___456 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___456 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___456 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___456 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___456 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___456 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___382 {
	struct kobject___444 kobj;
	struct module___382 *mod;
	struct kobject___444 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___382 {
	struct module___382 *mod;
	struct latch_tree_node node;
};

struct module_layout___382 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___382 mtn;
};

struct module_attribute___382;

struct kernel_param___382;

struct module___382 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___382 mkobj;
	struct module_attribute___382 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___444 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___382 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___382 core_layout;
	struct module_layout___382 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide53;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide54;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___209;

struct address_space_operations___456 {
	int (*writepage)(struct page___457 *, struct writeback_control___209 *);
	int (*readpage)(struct file___456 *, struct page___457 *);
	int (*writepages)(struct address_space___456 *, struct writeback_control___209 *);
	int (*set_page_dirty)(struct page___457 *);
	int (*readpages)(struct file___456 *, struct address_space___456 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___456 *, struct address_space___456 *, loff_t, unsigned int, unsigned int, struct page___457 **, void **);
	int (*write_end)(struct file___456 *, struct address_space___456 *, loff_t, unsigned int, unsigned int, struct page___457 *, void *);
	sector_t (*bmap)(struct address_space___456 *, sector_t);
	void (*invalidatepage)(struct page___457 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___457 *, gfp_t);
	void (*freepage)(struct page___457 *);
	ssize_t (*direct_IO)(struct kiocb___456 *, struct iov_iter___223 *);
	int (*migratepage)(struct address_space___456 *, struct page___457 *, struct page___457 *, enum migrate_mode);
	bool (*isolate_page)(struct page___457 *, isolate_mode_t);
	void (*putback_page)(struct page___457 *);
	int (*launder_page)(struct page___457 *);
	int (*is_partially_uptodate)(struct page___457 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___457 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___456 *, struct page___457 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___456 *, sector_t *);
	void (*swap_deactivate)(struct file___456 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___209 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___246 *wb;
	struct inode___456 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___248;

struct iov_iter___223 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___248 *bvec;
		struct pipe_inode_info___137 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___456 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___456 *bd_inode;
	struct super_block___456 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___456 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___246 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___456 {
	struct dentry___456 * (*lookup)(struct inode___456 *, struct dentry___456 *, unsigned int);
	const char * (*get_link)(struct dentry___456 *, struct inode___456 *, struct delayed_call *);
	int (*permission)(struct inode___456 *, int);
	struct posix_acl * (*get_acl)(struct inode___456 *, int);
	int (*readlink)(struct dentry___456 *, char *, int);
	int (*create)(struct inode___456 *, struct dentry___456 *, umode_t, bool);
	int (*link)(struct dentry___456 *, struct inode___456 *, struct dentry___456 *);
	int (*unlink)(struct inode___456 *, struct dentry___456 *);
	int (*symlink)(struct inode___456 *, struct dentry___456 *, const char *);
	int (*mkdir)(struct inode___456 *, struct dentry___456 *, umode_t);
	int (*rmdir)(struct inode___456 *, struct dentry___456 *);
	int (*mknod)(struct inode___456 *, struct dentry___456 *, umode_t, dev_t);
	int (*rename)(struct inode___456 *, struct dentry___456 *, struct inode___456 *, struct dentry___456 *, unsigned int);
	int (*setattr)(struct dentry___456 *, struct iattr___456 *);
	int (*getattr)(const struct path___457 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___456 *, char *, size_t);
	int (*fiemap)(struct inode___456 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___456 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___456 *, struct dentry___456 *, struct file___456 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___456 *, struct dentry___456 *, umode_t);
	int (*set_acl)(struct inode___456 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___456 {
	void (*fl_copy_lock)(struct file_lock___456 *, struct file_lock___456 *);
	void (*fl_release_private)(struct file_lock___456 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___456;

struct file_lock___456 {
	struct file_lock___456 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___456 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___456 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___456 *fl_ops;
	const struct lock_manager_operations___456 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___456 {
	int (*lm_compare_owner)(struct file_lock___456 *, struct file_lock___456 *);
	long unsigned int (*lm_owner_key)(struct file_lock___456 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___456 *);
	int (*lm_grant)(struct file_lock___456 *, int);
	bool (*lm_break)(struct file_lock___456 *);
	int (*lm_change)(struct file_lock___456 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___456 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___456 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___456 *fa_next;
	struct file___456 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___456 {
	const char *name;
	int fs_flags;
	struct dentry___456 * (*mount)(struct file_system_type___456 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___456 *);
	struct module___382 *owner;
	struct file_system_type___456 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___456 {
	struct inode___456 * (*alloc_inode)(struct super_block___456 *);
	void (*destroy_inode)(struct inode___456 *);
	void (*dirty_inode)(struct inode___456 *, int);
	int (*write_inode)(struct inode___456 *, struct writeback_control___209 *);
	int (*drop_inode)(struct inode___456 *);
	void (*evict_inode)(struct inode___456 *);
	void (*put_super)(struct super_block___456 *);
	int (*sync_fs)(struct super_block___456 *, int);
	int (*freeze_super)(struct super_block___456 *);
	int (*freeze_fs)(struct super_block___456 *);
	int (*thaw_super)(struct super_block___456 *);
	int (*unfreeze_fs)(struct super_block___456 *);
	int (*statfs)(struct dentry___456 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___456 *, int *, char *);
	void (*umount_begin)(struct super_block___456 *);
	int (*show_options)(struct seq_file___395 *, struct dentry___456 *);
	int (*show_devname)(struct seq_file___395 *, struct dentry___456 *);
	int (*show_path)(struct seq_file___395 *, struct dentry___456 *);
	int (*show_stats)(struct seq_file___395 *, struct dentry___456 *);
	ssize_t (*quota_read)(struct super_block___456 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___456 *, int, const char *, size_t, loff_t);
	struct dquot___456 ** (*get_dquots)(struct inode___456 *);
	int (*bdev_try_to_free_page)(struct super_block___456 *, struct page___457 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___456 *, struct shrink_control___189 *);
	long int (*free_cached_objects)(struct super_block___456 *, struct shrink_control___189 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___305)(struct file___456 *, wait_queue_head_t *, struct poll_table_struct___295 *);

struct poll_table_struct___295 {
	poll_queue_proc___305 _qproc;
	__poll_t _key;
};

struct seq_operations___395;

struct seq_file___395 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___395 *op;
	int poll_event;
	const struct file___456 *file;
	void *private;
};

typedef void bio_end_io_t___246(struct bio___246 *);

struct bio_vec___248 {
	struct page___457 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___246;

struct bio_set___246;

struct bio___246 {
	struct bio___246 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___246 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___246 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___248 *bi_io_vec;
	struct bio_set___246 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___248 bi_inline_vecs[0];
};

struct kobj_attribute___434 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___444 *, struct kobj_attribute___434 *, char *);
	ssize_t (*store)(struct kobject___444 *, struct kobj_attribute___434 *, const char *, size_t);
};

typedef void compound_page_dtor___444(struct page___457 *);

struct inet_frags___101;

struct netns_frags___101 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___101 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ip_ra_chain___47;

struct fib_rules_ops___81;

struct sock___81;

struct tcp_congestion_ops___21;

struct tcp_fastopen_context___21;

struct fib_notifier_ops___82;

struct netns_ipv4___101 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___47 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___81 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___81 *fibnl;
	struct sock___81 **icmp_sk;
	struct sock___81 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___81 **tcp_sk;
	struct netns_frags___101 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops___21 *tcp_congestion_control;
	struct tcp_fastopen_context___21 *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___81 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___82 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___82 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct dst_entry___81;

struct net_device___101;

struct sk_buff___102;

struct neighbour___81;

struct dst_ops___112 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___112 *);
	struct dst_entry___81 * (*check)(struct dst_entry___81 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___81 *);
	unsigned int (*mtu)(const struct dst_entry___81 *);
	u32 * (*cow_metrics)(struct dst_entry___81 *, long unsigned int);
	void (*destroy)(struct dst_entry___81 *);
	void (*ifdown)(struct dst_entry___81 *, struct net_device___101 *, int);
	struct dst_entry___81 * (*negative_advice)(struct dst_entry___81 *);
	void (*link_failure)(struct sk_buff___102 *);
	void (*update_pmtu)(struct dst_entry___81 *, struct sock___81 *, struct sk_buff___102 *, u32);
	void (*redirect)(struct dst_entry___81 *, struct sock___81 *, struct sk_buff___102 *);
	int (*local_out)(struct net___112 *, struct sock___81 *, struct sk_buff___102 *);
	struct neighbour___81 * (*neigh_lookup)(const struct dst_entry___81 *, struct sk_buff___102 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___81 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___112 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___101 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___112 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___81 *fib6_rules_ops;
	struct sock___81 **icmp_sk;
	struct sock___81 *ndisc_sk;
	struct sock___81 *tcp_sk;
	struct sock___81 *igmp_sk;
	struct sock___81 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___81 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___82 *notifier_ops;
	struct fib_notifier_ops___82 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___82 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___81 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___101 {
	struct netns_frags___101 frags;
};

struct netns_xfrm___112 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___81 *nlsk;
	struct sock___81 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___112 xfrm4_dst_ops;
	struct dst_ops___112 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___91;

struct net___112 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___321 *user_ns;
	struct ucounts___321 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___29 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___81 *rtnl;
	struct sock___81 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___101 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___101 ipv4;
	struct netns_ipv6___112 ipv6;
	struct netns_sctp___82 sctp;
	struct netns_nf___17 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___101 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___81 *nfnl;
	struct sock___81 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___112 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___81 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___91 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cgroup_namespace___305 {
	refcount_t count;
	struct ns_common___29 ns;
	struct user_namespace___321 *user_ns;
	struct ucounts___321 *ucounts;
	struct css_set___305 *root_cset;
};

struct ucounts___321 {
	struct hlist_node node;
	struct user_namespace___321 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct crypto_async_request___40;

typedef void (*crypto_completion_t___40)(struct crypto_async_request___40 *, int);

struct crypto_tfm___40;

struct crypto_async_request___40 {
	struct list_head list;
	crypto_completion_t___40 complete;
	void *data;
	struct crypto_tfm___40 *tfm;
	u32 flags;
};

struct crypto_ablkcipher___40;

struct ablkcipher_request___40;

struct ablkcipher_tfm___40 {
	int (*setkey)(struct crypto_ablkcipher___40 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___40 *);
	int (*decrypt)(struct ablkcipher_request___40 *);
	struct crypto_ablkcipher___40 *base;
	unsigned int ivsize;
	unsigned int reqsize;
};

struct blkcipher_desc___40;

struct blkcipher_tfm___40 {
	void *iv;
	int (*setkey)(struct crypto_tfm___40 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___40 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___40 *, struct scatterlist *, struct scatterlist *, unsigned int);
};

struct cipher_tfm___40 {
	int (*cit_setkey)(struct crypto_tfm___40 *, const u8 *, unsigned int);
	void (*cit_encrypt_one)(struct crypto_tfm___40 *, u8 *, const u8 *);
	void (*cit_decrypt_one)(struct crypto_tfm___40 *, u8 *, const u8 *);
};

struct compress_tfm___40 {
	int (*cot_compress)(struct crypto_tfm___40 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*cot_decompress)(struct crypto_tfm___40 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___40;

struct crypto_tfm___40 {
	u32 crt_flags;
	union {
		struct ablkcipher_tfm___40 ablkcipher;
		struct blkcipher_tfm___40 blkcipher;
		struct cipher_tfm___40 cipher;
		struct compress_tfm___40 compress;
	} crt_u;
	void (*exit)(struct crypto_tfm___40 *);
	struct crypto_alg___40 *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct ablkcipher_request___40 {
	struct crypto_async_request___40 base;
	unsigned int nbytes;
	void *info;
	struct scatterlist *src;
	struct scatterlist *dst;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_blkcipher___40;

struct blkcipher_desc___40 {
	struct crypto_blkcipher___40 *tfm;
	void *info;
	u32 flags;
};

struct crypto_blkcipher___40 {
	struct crypto_tfm___40 base;
};

struct ablkcipher_alg___40 {
	int (*setkey)(struct crypto_ablkcipher___40 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___40 *);
	int (*decrypt)(struct ablkcipher_request___40 *);
	int (*givencrypt)(struct skcipher_givcrypt_request *);
	int (*givdecrypt)(struct skcipher_givcrypt_request *);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct crypto_ablkcipher___40 {
	struct crypto_tfm___40 base;
};

struct blkcipher_alg___40 {
	int (*setkey)(struct crypto_tfm___40 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___40 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___40 *, struct scatterlist *, struct scatterlist *, unsigned int);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct cipher_alg___40 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___40 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___40 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___40 *, u8 *, const u8 *);
};

struct compress_alg___40 {
	int (*coa_compress)(struct crypto_tfm___40 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___40 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___40 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type *cra_type;
	union {
		struct ablkcipher_alg___40 ablkcipher;
		struct blkcipher_alg___40 blkcipher;
		struct cipher_alg___40 cipher;
		struct compress_alg___40 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___40 *);
	void (*cra_exit)(struct crypto_tfm___40 *);
	void (*cra_destroy)(struct crypto_alg___40 *);
	struct module___382 *cra_module;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct crypto_cipher___24 {
	struct crypto_tfm___40 base;
};

struct msghdr___84 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___223 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___456 *msg_iocb;
};

struct socket_wq___82 {
	wait_queue_head_t wait;
	struct fasync_struct___456 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___82;

struct socket___83 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___82 *wq;
	struct file___456 *file;
	struct sock___81 *sk;
	const struct proto_ops___82 *ops;
};

typedef struct {
	struct net___112 *net;
} possible_net_t___103;

struct proto___81;

struct sock_common___81 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___81 *skc_prot;
	possible_net_t___103 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___81 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff_head___101 {
	struct sk_buff___102 *next;
	struct sk_buff___102 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___81;

struct sock___81 {
	struct sock_common___81 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___101 sk_error_queue;
	struct sk_buff_head___101 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___102 *head;
		struct sk_buff___102 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___81 *sk_filter;
	union {
		struct socket_wq___82 *sk_wq;
		struct socket_wq___82 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___81 *sk_rx_dst;
	struct dst_entry___81 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___102 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___101 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___457 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___81 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___254 *sk_peer_pid;
	const struct cred___424 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___83 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___189 *sk_memcg;
	void (*sk_state_change)(struct sock___81 *);
	void (*sk_data_ready)(struct sock___81 *);
	void (*sk_write_space)(struct sock___81 *);
	void (*sk_error_report)(struct sock___81 *);
	int (*sk_backlog_rcv)(struct sock___81 *, struct sk_buff___102 *);
	struct sk_buff___102 * (*sk_validate_xmit_skb)(struct sock___81 *, struct net_device___101 *, struct sk_buff___102 *);
	void (*sk_destruct)(struct sock___81 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

typedef int (*sk_read_actor_t___81)(read_descriptor_t *, struct sk_buff___102 *, unsigned int, size_t);

struct proto_ops___82 {
	int family;
	struct module___382 *owner;
	int (*release)(struct socket___83 *);
	int (*bind)(struct socket___83 *, struct sockaddr *, int);
	int (*connect)(struct socket___83 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___83 *, struct socket___83 *);
	int (*accept)(struct socket___83 *, struct socket___83 *, int, bool);
	int (*getname)(struct socket___83 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___456 *, struct socket___83 *, struct poll_table_struct___295 *);
	int (*ioctl)(struct socket___83 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___83 *, int);
	int (*shutdown)(struct socket___83 *, int);
	int (*setsockopt)(struct socket___83 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___83 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___83 *, struct msghdr___84 *, size_t);
	int (*recvmsg)(struct socket___83 *, struct msghdr___84 *, size_t, int);
	int (*mmap)(struct file___456 *, struct socket___83 *, struct vm_area_struct___457 *);
	ssize_t (*sendpage)(struct socket___83 *, struct page___457 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___83 *, loff_t *, struct pipe_inode_info___137 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___81 *, int);
	int (*peek_len)(struct socket___83 *);
	int (*read_sock)(struct sock___81 *, read_descriptor_t *, sk_read_actor_t___81);
	int (*sendpage_locked)(struct sock___81 *, struct page___457 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___81 *, struct msghdr___84 *, size_t);
	int (*set_rcvlowat)(struct sock___81 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct nf_bridge_info___101;

struct sk_buff___102 {
	union {
		struct {
			struct sk_buff___102 *next;
			struct sk_buff___102 *prev;
			union {
				struct net_device___101 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___81 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___102 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___101 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct kernfs_root___450;

struct kernfs_elem_dir___450 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___450 *root;
};

struct kernfs_syscall_ops___450;

struct kernfs_root___450 {
	struct kernfs_node___451 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___450 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___450 {
	struct kernfs_node___451 *target_kn;
};

struct kernfs_ops___450;

struct kernfs_elem_attr___450 {
	const struct kernfs_ops___450 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___451 *notify_next;
};

struct kernfs_node___451 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___451 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___450 dir;
		struct kernfs_elem_symlink___450 symlink;
		struct kernfs_elem_attr___450 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___450;

struct kernfs_ops___450 {
	int (*open)(struct kernfs_open_file___450 *);
	void (*release)(struct kernfs_open_file___450 *);
	int (*seq_show)(struct seq_file___395 *, void *);
	void * (*seq_start)(struct seq_file___395 *, loff_t *);
	void * (*seq_next)(struct seq_file___395 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___395 *, void *);
	ssize_t (*read)(struct kernfs_open_file___450 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___450 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___450 *, struct vm_area_struct___457 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___450 *, struct poll_table_struct___295 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___450 {
	int (*remount_fs)(struct kernfs_root___450 *, int *, char *);
	int (*show_options)(struct seq_file___395 *, struct kernfs_root___450 *);
	int (*mkdir)(struct kernfs_node___451 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___451 *);
	int (*rename)(struct kernfs_node___451 *, struct kernfs_node___451 *, const char *);
	int (*show_path)(struct seq_file___395 *, struct kernfs_node___451 *, struct kernfs_root___450 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___450 {
	struct kernfs_node___451 *kn;
	struct file___456 *file;
	struct seq_file___395 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___444 *vm_ops;
};

struct kobj_ns_type_operations___81 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___81 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___420;

struct attribute_group___421 {
	const char *name;
	umode_t (*is_visible)(struct kobject___444 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___444 *, struct bin_attribute___420 *, int);
	struct attribute **attrs;
	struct bin_attribute___420 **bin_attrs;
};

struct bin_attribute___420 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___456 *, struct kobject___444 *, struct bin_attribute___420 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___456 *, struct kobject___444 *, struct bin_attribute___420 *, char *, loff_t, size_t);
	int (*mmap)(struct file___456 *, struct kobject___444 *, struct bin_attribute___420 *, struct vm_area_struct___457 *);
};

struct sysfs_ops___443 {
	ssize_t (*show)(struct kobject___444 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___444 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___443;

struct kset___443 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___444 kobj;
	const struct kset_uevent_ops___443 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___443 {
	void (*release)(struct kobject___444 *);
	const struct sysfs_ops___443 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___81 * (*child_ns_type)(struct kobject___444 *);
	const void * (*namespace)(struct kobject___444 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___443 {
	int (* const filter)(struct kset___443 *, struct kobject___444 *);
	const char * (* const name)(struct kset___443 *, struct kobject___444 *);
	int (* const uevent)(struct kset___443 *, struct kobject___444 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___424 {
	int (*prepare)(struct device___424 *);
	void (*complete)(struct device___424 *);
	int (*suspend)(struct device___424 *);
	int (*resume)(struct device___424 *);
	int (*freeze)(struct device___424 *);
	int (*thaw)(struct device___424 *);
	int (*poweroff)(struct device___424 *);
	int (*restore)(struct device___424 *);
	int (*suspend_late)(struct device___424 *);
	int (*resume_early)(struct device___424 *);
	int (*freeze_late)(struct device___424 *);
	int (*thaw_early)(struct device___424 *);
	int (*poweroff_late)(struct device___424 *);
	int (*restore_early)(struct device___424 *);
	int (*suspend_noirq)(struct device___424 *);
	int (*resume_noirq)(struct device___424 *);
	int (*freeze_noirq)(struct device___424 *);
	int (*thaw_noirq)(struct device___424 *);
	int (*poweroff_noirq)(struct device___424 *);
	int (*restore_noirq)(struct device___424 *);
	int (*runtime_suspend)(struct device___424 *);
	int (*runtime_resume)(struct device___424 *);
	int (*runtime_idle)(struct device___424 *);
};

struct dev_pm_domain___424 {
	struct dev_pm_ops___424 ops;
	void (*detach)(struct device___424 *, bool);
	int (*activate)(struct device___424 *);
	void (*sync)(struct device___424 *);
	void (*dismiss)(struct device___424 *);
};

struct bus_type___424 {
	const char *name;
	const char *dev_name;
	struct device___424 *dev_root;
	const struct attribute_group___421 **bus_groups;
	const struct attribute_group___421 **dev_groups;
	const struct attribute_group___421 **drv_groups;
	int (*match)(struct device___424 *, struct device_driver___424 *);
	int (*uevent)(struct device___424 *, struct kobj_uevent_env *);
	int (*probe)(struct device___424 *);
	int (*remove)(struct device___424 *);
	void (*shutdown)(struct device___424 *);
	int (*online)(struct device___424 *);
	int (*offline)(struct device___424 *);
	int (*suspend)(struct device___424 *, pm_message_t);
	int (*resume)(struct device___424 *);
	int (*num_vf)(struct device___424 *);
	int (*dma_configure)(struct device___424 *);
	const struct dev_pm_ops___424 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___424 {
	const char *name;
	struct bus_type___424 *bus;
	struct module___382 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___424 *);
	int (*remove)(struct device___424 *);
	void (*shutdown)(struct device___424 *);
	int (*suspend)(struct device___424 *, pm_message_t);
	int (*resume)(struct device___424 *);
	const struct attribute_group___421 **groups;
	const struct dev_pm_ops___424 *pm;
	void (*coredump)(struct device___424 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___424 {
	const char *name;
	const struct attribute_group___421 **groups;
	int (*uevent)(struct device___424 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___424 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___424 *);
	const struct dev_pm_ops___424 *pm;
};

struct class___424 {
	const char *name;
	struct module___382 *owner;
	const struct attribute_group___421 **class_groups;
	const struct attribute_group___421 **dev_groups;
	struct kobject___444 *dev_kobj;
	int (*dev_uevent)(struct device___424 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___424 *, umode_t *);
	void (*class_release)(struct class___424 *);
	void (*dev_release)(struct device___424 *);
	int (*shutdown_pre)(struct device___424 *);
	const struct kobj_ns_type_operations___81 *ns_type;
	const void * (*namespace)(struct device___424 *);
	const struct dev_pm_ops___424 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___196 {
	void * (*alloc)(struct device___424 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___424 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___424 *, struct vm_area_struct___457 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___424 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___424 *, struct page___457 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___424 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___424 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___424 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___424 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___424 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___424 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___424 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___424 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___424 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___424 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___424 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___424 *, u64);
	u64 (*get_required_mask)(struct device___424 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___344;

struct fwnode_handle___344 {
	struct fwnode_handle___344 *secondary;
	const struct fwnode_operations___344 *ops;
};

struct fwnode_reference_args___344;

struct fwnode_endpoint___344;

struct fwnode_operations___344 {
	struct fwnode_handle___344 * (*get)(struct fwnode_handle___344 *);
	void (*put)(struct fwnode_handle___344 *);
	bool (*device_is_available)(const struct fwnode_handle___344 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___344 *, const struct device___424 *);
	bool (*property_present)(const struct fwnode_handle___344 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___344 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___344 *, const char *, const char **, size_t);
	struct fwnode_handle___344 * (*get_parent)(const struct fwnode_handle___344 *);
	struct fwnode_handle___344 * (*get_next_child_node)(const struct fwnode_handle___344 *, struct fwnode_handle___344 *);
	struct fwnode_handle___344 * (*get_named_child_node)(const struct fwnode_handle___344 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___344 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___344 *);
	struct fwnode_handle___344 * (*graph_get_next_endpoint)(const struct fwnode_handle___344 *, struct fwnode_handle___344 *);
	struct fwnode_handle___344 * (*graph_get_remote_endpoint)(const struct fwnode_handle___344 *);
	struct fwnode_handle___344 * (*graph_get_port_parent)(struct fwnode_handle___344 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___344 *, struct fwnode_endpoint___344 *);
};

struct fwnode_endpoint___344 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___344 *local_fwnode;
};

struct fwnode_reference_args___344 {
	struct fwnode_handle___344 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___137;

struct pipe_buffer___137 {
	struct page___457 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___137 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___137 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___137 *, struct pipe_buffer___137 *);
	void (*release)(struct pipe_inode_info___137 *, struct pipe_buffer___137 *);
	int (*steal)(struct pipe_inode_info___137 *, struct pipe_buffer___137 *);
	union {
		bool (*get)(struct pipe_inode_info___137 *, struct pipe_buffer___137 *);
		struct {
			void (*get)(struct pipe_inode_info___137 *, struct pipe_buffer___137 *);
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
};

struct nf_bridge_info___101 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___101 = 0,
		BRNF_PROTO_8021Q___101 = 1,
		BRNF_PROTO_PPPOE___101 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___101 *physindev;
	struct net_device___101 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___101(struct sk_buff___102 **);

struct net_device_ops___101;

struct ethtool_ops___101;

struct l3mdev_ops___81;

struct ndisc_ops___52;

struct xfrmdev_ops___101;

struct tlsdev_ops___101;

struct header_ops___101;

struct inet6_dev___52;

struct netdev_rx_queue___101;

struct mini_Qdisc___93;

struct netdev_queue___101;

struct Qdisc___93;

struct rtnl_link_ops___93;

struct dcbnl_rtnl_ops___101;

struct net_device___101 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___101 *netdev_ops;
	const struct ethtool_ops___101 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___81 *l3mdev_ops;
	const struct ndisc_ops___52 *ndisc_ops;
	const struct xfrmdev_ops___101 *xfrmdev_ops;
	const struct tlsdev_ops___101 *tlsdev_ops;
	const struct header_ops___101 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___443 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___52 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___101 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___91 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___101 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___93 *miniq_ingress;
	struct netdev_queue___101 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___101 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___93 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___93 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___101 = 0,
		NETREG_REGISTERED___101 = 1,
		NETREG_UNREGISTERING___101 = 2,
		NETREG_UNREGISTERED___101 = 3,
		NETREG_RELEASED___101 = 4,
		NETREG_DUMMY___101 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___101 = 0,
		RTNL_LINK_INITIALIZING___101 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___101 *);
	struct netpoll_info *npinfo;
	possible_net_t___103 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___424 dev;
	const struct attribute_group___421 *sysfs_groups[4];
	const struct attribute_group___421 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___93 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___101 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct skb_frag_struct___27 {
	struct {
		struct page___457 *p;
	} page;
	__u32 page_offset;
	__u32 size;
};

typedef struct skb_frag_struct___27 skb_frag_t___27;

struct skb_shared_info___27 {
	__u8 __unused;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___102 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___27 frags[16];
};

struct ethtool_ops___101 {
	int (*get_settings)(struct net_device___101 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___101 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___101 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___101 *);
	void (*get_regs)(struct net_device___101 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___101 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___101 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___101 *);
	void (*set_msglevel)(struct net_device___101 *, u32);
	int (*nway_reset)(struct net_device___101 *);
	u32 (*get_link)(struct net_device___101 *);
	int (*get_eeprom_len)(struct net_device___101 *);
	int (*get_eeprom)(struct net_device___101 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___101 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___101 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___101 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___101 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___101 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___101 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___101 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___101 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___101 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___101 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___101 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___101 *);
	void (*complete)(struct net_device___101 *);
	u32 (*get_priv_flags)(struct net_device___101 *);
	int (*set_priv_flags)(struct net_device___101 *, u32);
	int (*get_sset_count)(struct net_device___101 *, int);
	int (*get_rxnfc)(struct net_device___101 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___101 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___101 *, struct ethtool_flash *);
	int (*reset)(struct net_device___101 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___101 *);
	u32 (*get_rxfh_indir_size)(struct net_device___101 *);
	int (*get_rxfh)(struct net_device___101 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___101 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___101 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___101 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___101 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___101 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___101 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___101 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___101 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___101 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___101 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___101 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___101 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___101 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___101 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___101 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___101 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___101 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___101 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___101 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___101 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___101 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	int (*get_fecparam)(struct net_device___101 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___101 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___101 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___101 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___101 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___101;

struct inet_frags___101 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___101 *, const void *);
	void (*destructor)(struct inet_frag_queue___101 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___101 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___102 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___102 *fragments_tail;
	struct sk_buff___102 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___101 *net;
	struct callback_head rcu;
};

struct ip_ra_chain___47 {
	struct ip_ra_chain___47 *next;
	struct sock___81 *sk;
	union {
		void (*destructor)(struct sock___81 *);
		struct sock___81 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___81;

struct fib_lookup_arg___81;

struct fib_rules_ops___81 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___81 *, struct flowi *, int, struct fib_lookup_arg___81 *);
	bool (*suppress)(struct fib_rule___81 *, struct fib_lookup_arg___81 *);
	int (*match)(struct fib_rule___81 *, struct flowi *, int);
	int (*configure)(struct fib_rule___81 *, struct sk_buff___102 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___81 *);
	int (*compare)(struct fib_rule___81 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___81 *, struct sk_buff___102 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___81 *);
	void (*flush_cache)(struct fib_rules_ops___81 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___382 *owner;
	struct net___112 *fro_net;
	struct callback_head rcu;
};

struct tcp_congestion_ops___21 {
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___81 *);
	void (*release)(struct sock___81 *);
	u32 (*ssthresh)(struct sock___81 *);
	void (*cong_avoid)(struct sock___81 *, u32, u32);
	void (*set_state)(struct sock___81 *, u8);
	void (*cwnd_event)(struct sock___81 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___81 *, u32);
	u32 (*undo_cwnd)(struct sock___81 *);
	void (*pkts_acked)(struct sock___81 *, const struct ack_sample *);
	u32 (*min_tso_segs)(struct sock___81 *);
	u32 (*sndbuf_expand)(struct sock___81 *);
	void (*cong_control)(struct sock___81 *, const struct rate_sample *);
	size_t (*get_info)(struct sock___81 *, u32, int *, union tcp_cc_info *);
	char name[16];
	struct module___382 *owner;
};

struct tcp_fastopen_context___21 {
	struct crypto_cipher___24 *tfm;
	__u8 key[16];
	struct callback_head rcu;
};

struct fib_notifier_ops___82 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___112 *);
	int (*fib_dump)(struct net___112 *, struct notifier_block *);
	struct module___382 *owner;
	struct callback_head rcu;
};

struct dst_entry___81 {
	struct net_device___101 *dev;
	struct dst_ops___112 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___102 *);
	int (*output)(struct net___112 *, struct sock___81 *, struct sk_buff___102 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___81;

struct neigh_parms___81;

struct neigh_ops___81;

struct neighbour___81 {
	struct neighbour___81 *next;
	struct neigh_table___81 *tbl;
	struct neigh_parms___81 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___101 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___81 *, struct sk_buff___102 *);
	const struct neigh_ops___81 *ops;
	struct callback_head rcu;
	struct net_device___101 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct bpf_prog_aux___94;

struct bpf_prog___91 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___94 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

struct seq_operations___395 {
	void * (*start)(struct seq_file___395 *, loff_t *);
	void (*stop)(struct seq_file___395 *, void *);
	void * (*next)(struct seq_file___395 *, void *, loff_t *);
	int (*show)(struct seq_file___395 *, void *);
};

struct pernet_operations___102 {
	struct list_head list;
	int (*init)(struct net___112 *);
	void (*exit)(struct net___112 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___101 {
	int (*ieee_getets)(struct net_device___101 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___101 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___101 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___101 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___101 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___101 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___101 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___101 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___101 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___101 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___101 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___101 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___101 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___101 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___101 *);
	u8 (*setstate)(struct net_device___101 *, u8);
	void (*getpermhwaddr)(struct net_device___101 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___101 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___101 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___101 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___101 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___101 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___101 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___101 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___101 *, int, u8 *);
	void (*setpfccfg)(struct net_device___101 *, int, u8);
	void (*getpfccfg)(struct net_device___101 *, int, u8 *);
	u8 (*setall)(struct net_device___101 *);
	u8 (*getcap)(struct net_device___101 *, int, u8 *);
	int (*getnumtcs)(struct net_device___101 *, int, u8 *);
	int (*setnumtcs)(struct net_device___101 *, int, u8);
	u8 (*getpfcstate)(struct net_device___101 *);
	void (*setpfcstate)(struct net_device___101 *, u8);
	void (*getbcncfg)(struct net_device___101 *, int, u32 *);
	void (*setbcncfg)(struct net_device___101 *, int, u32);
	void (*getbcnrp)(struct net_device___101 *, int, u8 *);
	void (*setbcnrp)(struct net_device___101 *, int, u8);
	int (*setapp)(struct net_device___101 *, u8, u16, u8);
	int (*getapp)(struct net_device___101 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___101 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___101 *, int, u8);
	u8 (*getdcbx)(struct net_device___101 *);
	u8 (*setdcbx)(struct net_device___101 *, u8);
	int (*peer_getappinfo)(struct net_device___101 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___101 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___101 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___101 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___101 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___101 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct bpf_map___306;

struct bpf_map_ops___305 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___306 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___306 *, struct file___456 *);
	void (*map_free)(struct bpf_map___306 *);
	int (*map_get_next_key)(struct bpf_map___306 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___306 *);
	void * (*map_lookup_elem)(struct bpf_map___306 *, void *);
	int (*map_update_elem)(struct bpf_map___306 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___306 *, void *);
	int (*map_push_elem)(struct bpf_map___306 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___306 *, void *);
	int (*map_peek_elem)(struct bpf_map___306 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___306 *, struct file___456 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___306 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___306 *, void *, struct seq_file___395 *);
	int (*map_check_btf)(const struct bpf_map___306 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___306 {
	const struct bpf_map_ops___305 *ops;
	struct bpf_map___306 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___424 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___101;

struct bpf_map_dev_ops___101 {
	int (*map_get_next_key)(struct bpf_offloaded_map___101 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___101 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___101 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___101 *, void *);
};

struct bpf_offloaded_map___101 {
	struct bpf_map___306 map;
	struct net_device___101 *netdev;
	const struct bpf_map_dev_ops___101 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___91 {
	int (*test_run)(struct bpf_prog___91 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___91 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___91 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___91 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___91 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___91 *, u32 *);
};

struct bpf_prog_offload_ops___91 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___91 *);
	int (*translate)(struct bpf_prog___91 *);
	void (*destroy)(struct bpf_prog___91 *);
};

struct bpf_prog_offload___91 {
	struct bpf_prog___91 *prog;
	struct net_device___101 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___91 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___94 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___91 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___91 *ops;
	struct bpf_map___306 **used_maps;
	struct bpf_prog___91 *prog;
	struct user_struct___424 *user;
	u64 load_time;
	struct bpf_map___306 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___91 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___91 {
	struct bpf_prog___91 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___91 {
	struct callback_head rcu;
	struct bpf_prog_array_item___91 items[0];
};

struct cgroup_bpf___91 {
	struct bpf_prog_array___91 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___91 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___306;

typedef void (*kthread_work_func_t___306)(struct kthread_work___306 *);

struct kthread_worker___306;

struct kthread_work___306 {
	struct list_head node;
	kthread_work_func_t___306 func;
	struct kthread_worker___306 *worker;
	int canceling;
};

struct kthread_worker___306 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___458 *task;
	struct kthread_work___306 *current_work;
};

struct kthread_delayed_work___305 {
	struct kthread_work___306 work;
	struct timer_list timer;
};

struct psi_group___305 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___306 *poll_kworker;
	struct kthread_delayed_work___305 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___305;

struct cgroup_rstat_cpu___305;

struct cgroup___305 {
	struct cgroup_subsys_state___305 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___451 *kn;
	struct cgroup_file___305 procs_file;
	struct cgroup_file___305 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___305 *subsys[13];
	struct cgroup_root___305 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___305 *dom_cgrp;
	struct cgroup_rstat_cpu___305 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___91 bpf;
	atomic_t congestion_count;
	struct cgroup___305 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___305 psi;
	int ancestor_ids[0];
};

struct cftype___305;

struct cgroup_subsys___305 {
	struct cgroup_subsys_state___305 * (*css_alloc)(struct cgroup_subsys_state___305 *);
	int (*css_online)(struct cgroup_subsys_state___305 *);
	void (*css_offline)(struct cgroup_subsys_state___305 *);
	void (*css_released)(struct cgroup_subsys_state___305 *);
	void (*css_free)(struct cgroup_subsys_state___305 *);
	void (*css_reset)(struct cgroup_subsys_state___305 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___305 *, int);
	int (*css_extra_stat_show)(struct seq_file___395 *, struct cgroup_subsys_state___305 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___458 *);
	void (*cancel_fork)(struct task_struct___458 *);
	void (*fork)(struct task_struct___458 *);
	void (*exit)(struct task_struct___458 *);
	void (*free)(struct task_struct___458 *);
	void (*bind)(struct cgroup_subsys_state___305 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___305 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___305 *dfl_cftypes;
	struct cftype___305 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___305 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___305 *updated_children;
	struct cgroup___305 *updated_next;
};

struct cgroup_root___305 {
	struct kernfs_root___450 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___305 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___305 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___305 *ss;
	struct list_head node;
	struct kernfs_ops___450 *kf_ops;
	int (*open)(struct kernfs_open_file___450 *);
	void (*release)(struct kernfs_open_file___450 *);
	u64 (*read_u64)(struct cgroup_subsys_state___305 *, struct cftype___305 *);
	s64 (*read_s64)(struct cgroup_subsys_state___305 *, struct cftype___305 *);
	int (*seq_show)(struct seq_file___395 *, void *);
	void * (*seq_start)(struct seq_file___395 *, loff_t *);
	void * (*seq_next)(struct seq_file___395 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___395 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___305 *, struct cftype___305 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___305 *, struct cftype___305 *, s64);
	ssize_t (*write)(struct kernfs_open_file___450 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___450 *, struct poll_table_struct___295 *);
};

struct xdp_rxq_info___101 {
	struct net_device___101 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___101 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___101 *dev_rx;
};

struct netlink_callback___103 {
	struct sk_buff___102 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___103 *);
	int (*dump)(struct sk_buff___102 *, struct netlink_callback___103 *);
	int (*done)(struct netlink_callback___103 *);
	void *data;
	struct module___382 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___101 {
	int (*create)(struct sk_buff___102 *, struct net_device___101 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___102 *, unsigned char *);
	int (*cache)(const struct neighbour___81 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___101 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___101 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___101 *, int);
	int poll_owner;
	struct net_device___101 *dev;
	struct sk_buff___102 *gro_list;
	struct sk_buff___102 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___101 {
	struct net_device___101 *dev;
	struct Qdisc___93 *qdisc;
	struct Qdisc___93 *qdisc_sleeping;
	struct kobject___444 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___101 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___93 {
	struct sk_buff___102 *head;
	struct sk_buff___102 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___93;

struct Qdisc___93 {
	int (*enqueue)(struct sk_buff___102 *, struct Qdisc___93 *, struct sk_buff___102 **);
	struct sk_buff___102 * (*dequeue)(struct Qdisc___93 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___93 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___101 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___101 gso_skb;
	struct qdisc_skb_head___93 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___93 *next_sched;
	struct sk_buff_head___101 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___101 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___444 kobj;
	struct net_device___101 *dev;
	long: 64;
	struct xdp_rxq_info___101 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___101)(struct net_device___101 *, struct sk_buff___102 *, struct net_device___101 *);

struct netdev_bpf___101 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___91 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___91 *prog;
			const struct bpf_prog_offload_ops___91 *ops;
		} verifier;
		struct {
			struct bpf_prog___91 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___101 *offmap;
		};
		struct {
			struct xdp_umem___3 *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___101 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___102 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___101 {
	int (*tls_dev_add)(struct net_device___101 *, struct sock___81 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___101 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___101 *, struct sock___81 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___101 {
	int (*ndo_init)(struct net_device___101 *);
	void (*ndo_uninit)(struct net_device___101 *);
	int (*ndo_open)(struct net_device___101 *);
	int (*ndo_stop)(struct net_device___101 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___102 *, struct net_device___101 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___102 *, struct net_device___101 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___101 *, struct sk_buff___102 *, struct net_device___101 *, select_queue_fallback_t___101);
	void (*ndo_change_rx_flags)(struct net_device___101 *, int);
	void (*ndo_set_rx_mode)(struct net_device___101 *);
	int (*ndo_set_mac_address)(struct net_device___101 *, void *);
	int (*ndo_validate_addr)(struct net_device___101 *);
	int (*ndo_do_ioctl)(struct net_device___101 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___101 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___101 *, int);
	int (*ndo_neigh_setup)(struct net_device___101 *, struct neigh_parms___81 *);
	void (*ndo_tx_timeout)(struct net_device___101 *);
	void (*ndo_get_stats64)(struct net_device___101 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___101 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___101 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___101 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___101 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___101 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___101 *);
	int (*ndo_netpoll_setup)(struct net_device___101 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___101 *);
	int (*ndo_set_vf_mac)(struct net_device___101 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___101 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___101 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___101 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___101 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___101 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___101 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___101 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___101 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___101 *, int, struct sk_buff___102 *);
	int (*ndo_set_vf_guid)(struct net_device___101 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___101 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___101 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___101 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___101 *, const struct sk_buff___102 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___101 *, struct net_device___101 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___101 *, struct net_device___101 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___101 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___101 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___101 *, struct neighbour___81 *);
	void (*ndo_neigh_destroy)(struct net_device___101 *, struct neighbour___81 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___101 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___101 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___101 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___102 *, struct netlink_callback___103 *, struct net_device___101 *, struct net_device___101 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___101 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___101 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___102 *, u32, u32, struct net_device___101 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___101 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___101 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___101 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___101 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___101 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___101 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___101 *, struct net_device___101 *);
	void (*ndo_dfwd_del_station)(struct net_device___101 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___101 *);
	int (*ndo_set_tx_maxrate)(struct net_device___101 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___101 *);
	int (*ndo_change_proto_down)(struct net_device___101 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___101 *, struct sk_buff___102 *);
	void (*ndo_set_rx_headroom)(struct net_device___101 *, int);
	int (*ndo_bpf)(struct net_device___101 *, struct netdev_bpf___101 *);
	int (*ndo_xdp_xmit)(struct net_device___101 *, int, struct xdp_frame___101 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___101 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___101 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___81 {
	possible_net_t___103 net;
	struct net_device___101 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___81 *);
	void (*neigh_cleanup)(struct neighbour___81 *);
	struct neigh_table___81 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___81 {
	u32 (*l3mdev_fib_table)(const struct net_device___101 *);
	struct sk_buff___102 * (*l3mdev_l3_rcv)(struct net_device___101 *, struct sk_buff___102 *, u16);
	struct sk_buff___102 * (*l3mdev_l3_out)(struct net_device___101 *, struct sock___81 *, struct sk_buff___102 *, u16);
	struct dst_entry___81 * (*l3mdev_link_scope_lookup)(const struct net_device___101 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct ndisc_ops___52 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___101 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___101 *, struct neighbour___81 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___101 *, u8, struct neighbour___81 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___101 *, struct sk_buff___102 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___112 *, struct net_device___101 *, const struct prefix_info *, struct inet6_dev___52 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___52;

struct inet6_dev___52 {
	struct net_device___101 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___52 *mc_list;
	struct ifmcaddr6___52 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___23 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	u8 rndid[8];
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___81 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
};

struct tcf_proto___93;

struct mini_Qdisc___93 {
	struct tcf_proto___93 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___93 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___101 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___112 *, struct net_device___101 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___101 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___101 *, struct list_head *);
	size_t (*get_size)(const struct net_device___101 *);
	int (*fill_info)(struct sk_buff___102 *, const struct net_device___101 *);
	size_t (*get_xstats_size)(const struct net_device___101 *);
	int (*fill_xstats)(struct sk_buff___102 *, const struct net_device___101 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___101 *, struct net_device___101 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___101 *, const struct net_device___101 *);
	int (*fill_slave_info)(struct sk_buff___102 *, const struct net_device___101 *, const struct net_device___101 *);
	struct net___112 * (*get_link_net)(const struct net_device___101 *);
	size_t (*get_linkxstats_size)(const struct net_device___101 *, int);
	int (*fill_linkxstats)(struct sk_buff___102 *, const struct net_device___101 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___101 {
	struct list_head poll_list;
	struct sk_buff_head___101 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___101 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___93 *output_queue;
	struct Qdisc___93 **output_queue_tailp;
	struct sk_buff___102 *completion_queue;
	struct sk_buff_head___101 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___101 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___101 input_pkt_queue;
	struct napi_struct___101 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bdi_writeback_congested___246 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___246 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___246 {
	struct bio___246 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___248 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___248 bip_inline_vecs[0];
};

struct bio_set___246 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___246 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___189 {
	struct mem_cgroup___189 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___189 {
	struct lruvec___457 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___189 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___189 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct kernel_param_ops___382 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___382 *);
	int (*get)(char *, const struct kernel_param___382 *);
	void (*free)(void *);
};

struct kparam_array___382;

struct kernel_param___382 {
	const char *name;
	struct module___382 *mod;
	const struct kernel_param_ops___382 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___382 *arr;
	};
};

struct kparam_array___382 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___382 *ops;
	void *elem;
};

struct module_attribute___382 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___382 *, struct module_kobject___382 *, char *);
	ssize_t (*store)(struct module_attribute___382 *, struct module_kobject___382 *, const char *, size_t);
	void (*setup)(struct module___382 *, const char *);
	int (*test)(struct module___382 *);
	void (*free)(struct module___382 *);
};

struct gnet_dump___93 {
	spinlock_t *lock;
	struct sk_buff___102 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___93;

struct Qdisc_ops___93 {
	struct Qdisc_ops___93 *next;
	const struct Qdisc_class_ops___93 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___102 *, struct Qdisc___93 *, struct sk_buff___102 **);
	struct sk_buff___102 * (*dequeue)(struct Qdisc___93 *);
	struct sk_buff___102 * (*peek)(struct Qdisc___93 *);
	int (*init)(struct Qdisc___93 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___93 *);
	void (*destroy)(struct Qdisc___93 *);
	int (*change)(struct Qdisc___93 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___93 *);
	int (*change_tx_queue_len)(struct Qdisc___93 *, unsigned int);
	int (*dump)(struct Qdisc___93 *, struct sk_buff___102 *);
	int (*dump_stats)(struct Qdisc___93 *, struct gnet_dump___93 *);
	void (*ingress_block_set)(struct Qdisc___93 *, u32);
	void (*egress_block_set)(struct Qdisc___93 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___93 *);
	u32 (*egress_block_get)(struct Qdisc___93 *);
	struct module___382 *owner;
};

struct tcf_block___93;

struct Qdisc_class_ops___93 {
	unsigned int flags;
	struct netdev_queue___101 * (*select_queue)(struct Qdisc___93 *, struct tcmsg *);
	int (*graft)(struct Qdisc___93 *, long unsigned int, struct Qdisc___93 *, struct Qdisc___93 **, struct netlink_ext_ack *);
	struct Qdisc___93 * (*leaf)(struct Qdisc___93 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___93 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___93 *, u32);
	int (*change)(struct Qdisc___93 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___93 *, long unsigned int);
	void (*walk)(struct Qdisc___93 *, struct qdisc_walker *);
	struct tcf_block___93 * (*tcf_block)(struct Qdisc___93 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___93 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___93 *, long unsigned int);
	int (*dump)(struct Qdisc___93 *, long unsigned int, struct sk_buff___102 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___93 *, long unsigned int, struct gnet_dump___93 *);
};

struct tcf_chain___93;

struct tcf_block___93 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___112 *net;
	struct Qdisc___93 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___93 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___93;

struct tcf_proto_ops___93;

struct tcf_proto___93 {
	struct tcf_proto___93 *next;
	void *root;
	int (*classify)(struct sk_buff___102 *, const struct tcf_proto___93 *, struct tcf_result___93 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___93 *ops;
	struct tcf_chain___93 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___93 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___93 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___93 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___102 *, const struct tcf_proto___93 *, struct tcf_result___93 *);
	int (*init)(struct tcf_proto___93 *);
	void (*destroy)(struct tcf_proto___93 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___93 *, u32);
	void (*put)(struct tcf_proto___93 *, void *);
	int (*change)(struct net___112 *, struct sk_buff___102 *, struct tcf_proto___93 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___93 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___93 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___93 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___112 *, struct tcf_chain___93 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___112 *, struct tcf_proto___93 *, void *, struct sk_buff___102 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___102 *, struct net___112 *, void *);
	struct module___382 *owner;
	int flags;
};

struct tcf_chain___93 {
	struct mutex filter_chain_lock;
	struct tcf_proto___93 *filter_chain;
	struct list_head list;
	struct tcf_block___93 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___93 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___81 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___91 *prog;
};

struct bpf_redirect_info___91 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___306 *map;
	struct bpf_map___306 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___81;

struct neigh_hash_table___81;

struct neigh_table___81 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___101 *, __u32 *);
	bool (*key_eq)(const struct neighbour___81 *, const void *);
	int (*constructor)(struct neighbour___81 *);
	int (*pconstructor)(struct pneigh_entry___81 *);
	void (*pdestructor)(struct pneigh_entry___81 *);
	void (*proxy_redo)(struct sk_buff___102 *);
	char *id;
	struct neigh_parms___81 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___101 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___81 *nht;
	struct pneigh_entry___81 **phash_buckets;
};

struct neigh_ops___81 {
	int family;
	void (*solicit)(struct neighbour___81 *, struct sk_buff___102 *);
	void (*error_report)(struct neighbour___81 *, struct sk_buff___102 *);
	int (*output)(struct neighbour___81 *, struct sk_buff___102 *);
	int (*connected_output)(struct neighbour___81 *, struct sk_buff___102 *);
};

struct pneigh_entry___81 {
	struct pneigh_entry___81 *next;
	possible_net_t___103 net;
	struct net_device___101 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___81 {
	struct neighbour___81 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___81 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___81 *ctarget;
	struct net___112 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___81 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___81 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___64;

struct timewait_sock_ops___60;

struct proto___81 {
	void (*close)(struct sock___81 *, long int);
	int (*pre_connect)(struct sock___81 *, struct sockaddr *, int);
	int (*connect)(struct sock___81 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___81 *, int);
	struct sock___81 * (*accept)(struct sock___81 *, int, int *, bool);
	int (*ioctl)(struct sock___81 *, int, long unsigned int);
	int (*init)(struct sock___81 *);
	void (*destroy)(struct sock___81 *);
	void (*shutdown)(struct sock___81 *, int);
	int (*setsockopt)(struct sock___81 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___81 *, int, int, char *, int *);
	void (*keepalive)(struct sock___81 *, int);
	int (*sendmsg)(struct sock___81 *, struct msghdr___84 *, size_t);
	int (*recvmsg)(struct sock___81 *, struct msghdr___84 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___81 *, struct page___457 *, int, size_t, int);
	int (*bind)(struct sock___81 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___81 *, struct sk_buff___102 *);
	void (*release_cb)(struct sock___81 *);
	int (*hash)(struct sock___81 *);
	void (*unhash)(struct sock___81 *);
	void (*rehash)(struct sock___81 *);
	int (*get_port)(struct sock___81 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___81 *);
	bool (*stream_memory_read)(const struct sock___81 *);
	void (*enter_memory_pressure)(struct sock___81 *);
	void (*leave_memory_pressure)(struct sock___81 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___64 *rsk_prot;
	struct timewait_sock_ops___60 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___382 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___81 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct request_sock___65;

struct request_sock_ops___64 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___81 *, struct request_sock___65 *);
	void (*send_ack)(const struct sock___81 *, struct sk_buff___102 *, struct request_sock___65 *);
	void (*send_reset)(const struct sock___81 *, struct sk_buff___102 *);
	void (*destructor)(struct request_sock___65 *);
	void (*syn_ack_timeout)(const struct request_sock___65 *);
};

struct timewait_sock_ops___60 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___81 *, struct sock___81 *, void *);
	void (*twsk_destructor)(struct sock___81 *);
};

struct request_sock___65 {
	struct sock_common___81 __req_common;
	struct request_sock___65 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___64 *rsk_ops;
	struct sock___81 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct fastopen_queue___14 {
	struct request_sock___65 *rskq_rst_head;
	struct request_sock___65 *rskq_rst_tail;
	spinlock_t lock;
	int qlen;
	int max_qlen;
	struct tcp_fastopen_context___21 *ctx;
};

struct request_sock_queue___14 {
	spinlock_t rskq_lock;
	u8 rskq_defer_accept;
	u32 synflood_warned;
	atomic_t qlen;
	atomic_t young;
	struct request_sock___65 *rskq_accept_head;
	struct request_sock___65 *rskq_accept_tail;
	struct fastopen_queue___14 fastopenq;
};

struct inet_request_sock___8 {
	struct request_sock___65 req;
	u16 snd_wscale: 4;
	u16 rcv_wscale: 4;
	u16 tstamp_ok: 1;
	u16 sack_ok: 1;
	u16 wscale_ok: 1;
	u16 ecn_ok: 1;
	u16 acked: 1;
	u16 no_srccheck: 1;
	u16 smc_ok: 1;
	u32 ir_mark;
	union {
		struct ip_options_rcu *ireq_opt;
		struct {
			struct ipv6_txoptions *ipv6_opt;
			struct sk_buff___102 *pktopts;
		};
	};
};

struct inet_cork___21 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___81 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
	__u16 gso_size;
	u64 transmit_time;
};

struct inet_cork_full___21 {
	struct inet_cork___21 base;
	struct flowi fl;
};

struct ipv6_pinfo___21;

struct inet_sock___21 {
	struct sock___81 sk;
	struct ipv6_pinfo___21 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	__be16 inet_sport;
	__u16 inet_id;
	struct ip_options_rcu *inet_opt;
	int rx_dst_ifindex;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 bind_address_no_port: 1;
	__u8 defer_connect: 1;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___21 cork;
};

struct ipv6_fl_socklist___20;

struct ipv6_pinfo___21 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
			__u16 recvfragsize: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 repflow: 1;
	__u16 pmtudisc: 3;
	__u16 padding: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u16 autoflowlabel: 1;
	__u16 autoflowlabel_set: 1;
	__u8 min_hopcount;
	__u8 tclass;
	__be32 rcv_flowinfo;
	__u32 dst_cookie;
	__u32 rx_dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___20 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___102 *pktoptions;
	struct sk_buff___102 *rxpmtu;
	struct inet6_cork cork;
};

struct inet_connection_sock_af_ops___13 {
	int (*queue_xmit)(struct sock___81 *, struct sk_buff___102 *, struct flowi *);
	void (*send_check)(struct sock___81 *, struct sk_buff___102 *);
	int (*rebuild_header)(struct sock___81 *);
	void (*sk_rx_dst_set)(struct sock___81 *, const struct sk_buff___102 *);
	int (*conn_request)(struct sock___81 *, struct sk_buff___102 *);
	struct sock___81 * (*syn_recv_sock)(const struct sock___81 *, struct sk_buff___102 *, struct request_sock___65 *, struct dst_entry___81 *, struct request_sock___65 *, bool *);
	u16 net_header_len;
	u16 net_frag_header_len;
	u16 sockaddr_len;
	int (*setsockopt)(struct sock___81 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___81 *, int, int, char *, int *);
	void (*addr2sockaddr)(struct sock___81 *, struct sockaddr *);
	void (*mtu_reduced)(struct sock___81 *);
};

struct inet_bind_bucket___13;

struct tcp_ulp_ops___12;

struct inet_connection_sock___14 {
	struct inet_sock___21 icsk_inet;
	struct request_sock_queue___14 icsk_accept_queue;
	struct inet_bind_bucket___13 *icsk_bind_hash;
	long unsigned int icsk_timeout;
	struct timer_list icsk_retransmit_timer;
	struct timer_list icsk_delack_timer;
	__u32 icsk_rto;
	__u32 icsk_pmtu_cookie;
	const struct tcp_congestion_ops___21 *icsk_ca_ops;
	const struct inet_connection_sock_af_ops___13 *icsk_af_ops;
	const struct tcp_ulp_ops___12 *icsk_ulp_ops;
	void *icsk_ulp_data;
	void (*icsk_clean_acked)(struct sock___81 *, u32);
	struct hlist_node icsk_listen_portaddr_node;
	unsigned int (*icsk_sync_mss)(struct sock___81 *, u32);
	__u8 icsk_ca_state: 6;
	__u8 icsk_ca_setsockopt: 1;
	__u8 icsk_ca_dst_locked: 1;
	__u8 icsk_retransmits;
	__u8 icsk_pending;
	__u8 icsk_backoff;
	__u8 icsk_syn_retries;
	__u8 icsk_probes_out;
	__u16 icsk_ext_hdr_len;
	struct {
		__u8 pending;
		__u8 quick;
		__u8 pingpong;
		__u8 blocked;
		__u32 ato;
		long unsigned int timeout;
		__u32 lrcvtime;
		__u16 last_seg_size;
		__u16 rcv_mss;
	} icsk_ack;
	struct {
		int enabled;
		int search_high;
		int search_low;
		int probe_size;
		u32 probe_timestamp;
	} icsk_mtup;
	u32 icsk_user_timeout;
	u64 icsk_ca_priv[11];
};

struct inet_bind_bucket___13 {
	possible_net_t___103 ib_net;
	short unsigned int port;
	signed char fastreuse;
	signed char fastreuseport;
	kuid_t fastuid;
	struct in6_addr fast_v6_rcv_saddr;
	__be32 fast_rcv_saddr;
	short unsigned int fast_sk_family;
	bool fast_ipv6_only;
	struct hlist_node node;
	struct hlist_head owners;
};

struct tcp_ulp_ops___12 {
	struct list_head list;
	int (*init)(struct sock___81 *);
	void (*release)(struct sock___81 *);
	char name[16];
	struct module___382 *owner;
};

struct ip6_flowlabel___20;

struct ipv6_fl_socklist___20 {
	struct ipv6_fl_socklist___20 *next;
	struct ip6_flowlabel___20 *fl;
	struct callback_head rcu;
};

struct ifmcaddr6___52 {
	struct in6_addr mca_addr;
	struct inet6_dev___52 *idev;
	struct ifmcaddr6___52 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ip6_ra_chain___52 {
	struct ip6_ra_chain___52 *next;
	struct sock___81 *sk;
	int sel;
	void (*destructor)(struct sock___81 *);
};

struct ip6_flowlabel___20 {
	struct ip6_flowlabel___20 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___254 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___112 *fl_net;
};

struct netlbl_audit {
	u32 secid;
	kuid_t loginuid;
	unsigned int sessionid;
};

struct cipso_v4_std_map_tbl {
	struct {
		u32 *cipso;
		u32 *local;
		u32 cipso_size;
		u32 local_size;
	} lvl;
	struct {
		u32 *cipso;
		u32 *local;
		u32 cipso_size;
		u32 local_size;
	} cat;
};

struct cipso_v4_doi {
	u32 doi;
	u32 type;
	union {
		struct cipso_v4_std_map_tbl *std;
	} map;
	u8 tags[5];
	refcount_t refcount;
	struct list_head list;
	struct callback_head rcu;
};

struct cipso_v4_map_cache_bkt {
	spinlock_t lock;
	u32 size;
	struct list_head list;
};

struct cipso_v4_map_cache_entry {
	u32 hash;
	unsigned char *key;
	size_t key_len;
	struct netlbl_lsm_cache *lsm_data;
	u32 activity;
	struct list_head list;
};

struct xfrm_dst___5;

struct xfrm_policy_afinfo {
	struct dst_ops___107 *dst_ops;
	struct dst_entry___76 * (*dst_lookup)(struct net___107 *, int, int, const xfrm_address_t *, const xfrm_address_t *, u32);
	int (*get_saddr)(struct net___107 *, int, xfrm_address_t *, xfrm_address_t *, u32);
	void (*decode_session)(struct sk_buff___97 *, struct flowi *, int);
	int (*get_tos)(const struct flowi *);
	int (*init_path)(struct xfrm_dst___5 *, struct dst_entry___76 *, int);
	int (*fill_dst)(struct xfrm_dst___5 *, struct net_device___96 *, const struct flowi *);
	struct dst_entry___76 * (*blackhole_route)(struct net___107 *, struct dst_entry___76 *);
};

struct xfrm_dst___5 {
	union {
		struct dst_entry___76 dst;
		struct rtable___14 rt;
		struct rt6_info___21 rt6;
	} u;
	struct dst_entry___76 *route;
	struct dst_entry___76 *child;
	struct dst_entry___76 *path;
	struct xfrm_policy___17 *pols[2];
	int num_pols;
	int num_xfrms;
	u32 xfrm_genid;
	u32 policy_genid;
	u32 route_mtu_cached;
	u32 child_mtu_cached;
	u32 route_cookie;
	u32 path_cookie;
};

struct ip_tunnel;

struct ip6_tnl;

struct xfrm_tunnel_skb_cb {
	union {
		struct inet_skb_parm h4;
		struct inet6_skb_parm h6;
	} header;
	union {
		struct ip_tunnel *ip4;
		struct ip6_tnl *ip6;
	} tunnel;
};

struct xfrm_mode_skb_cb {
	struct xfrm_tunnel_skb_cb header;
	__be16 id;
	__be16 frag_off;
	u8 ihl;
	u8 tos;
	u8 ttl;
	u8 protocol;
	u8 optlen;
	u8 flow_lbl[3];
};

struct udp_sock___3 {
	struct inet_sock___8 inet;
	int pending;
	unsigned int corkflag;
	__u8 encap_type;
	unsigned char no_check6_tx: 1;
	unsigned char no_check6_rx: 1;
	__u16 len;
	__u16 gso_size;
	__u16 pcslen;
	__u16 pcrlen;
	__u8 pcflag;
	__u8 unused[3];
	int (*encap_rcv)(struct sock___65 *, struct sk_buff___85 *);
	int (*encap_err_lookup)(struct sock___65 *, struct sk_buff___85 *);
	void (*encap_destroy)(struct sock___65 *);
	struct sk_buff___85 ** (*gro_receive)(struct sock___65 *, struct sk_buff___85 **, struct sk_buff___85 *);
	int (*gro_complete)(struct sock___65 *, struct sk_buff___85 *, int);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___84 reader_queue;
	int forward_deficit;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xfrm_spi_skb_cb {
	struct xfrm_tunnel_skb_cb header;
	unsigned int daddroff;
	unsigned int family;
	__be32 seq;
};

struct module___383;

struct file___457;

struct kiocb___457;

struct iov_iter___224;

struct poll_table_struct___296;

struct vm_area_struct___458;

struct inode___457;

struct file_lock___457;

struct page___458;

struct pipe_inode_info___138;

struct seq_file___396;

struct file_operations___457 {
	struct module___383 *owner;
	loff_t (*llseek)(struct file___457 *, loff_t, int);
	ssize_t (*read)(struct file___457 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___457 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___457 *, struct iov_iter___224 *);
	ssize_t (*write_iter)(struct kiocb___457 *, struct iov_iter___224 *);
	int (*iopoll)(struct kiocb___457 *, bool);
	int (*iterate)(struct file___457 *, struct dir_context *);
	int (*iterate_shared)(struct file___457 *, struct dir_context *);
	__poll_t (*poll)(struct file___457 *, struct poll_table_struct___296 *);
	long int (*unlocked_ioctl)(struct file___457 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___457 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___457 *, struct vm_area_struct___458 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___457 *, struct file___457 *);
	int (*flush)(struct file___457 *, fl_owner_t);
	int (*release)(struct inode___457 *, struct file___457 *);
	int (*fsync)(struct file___457 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___457 *, int);
	int (*lock)(struct file___457 *, int, struct file_lock___457 *);
	ssize_t (*sendpage)(struct file___457 *, struct page___458 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___457 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___457 *, int, struct file_lock___457 *);
	ssize_t (*splice_write)(struct pipe_inode_info___138 *, struct file___457 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___457 *, loff_t *, struct pipe_inode_info___138 *, size_t, unsigned int);
	int (*setlease)(struct file___457 *, long int, struct file_lock___457 **, void **);
	long int (*fallocate)(struct file___457 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___396 *, struct file___457 *);
	ssize_t (*copy_file_range)(struct file___457 *, loff_t, struct file___457 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___457 *, loff_t, struct file___457 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___457 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___458 {
	u64 seqnum;
	struct vm_area_struct___458 *vmas[4];
};

struct page_frag___458 {
	struct page___458 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___458;

struct mem_cgroup___190;

struct pid___255;

struct cred___425;

struct nsproxy___352;

struct signal_struct___332;

struct bio_list___247;

struct backing_dev_info___247;

struct css_set___306;

struct vm_struct___361;

struct task_struct___459 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___459 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___458 *mm;
	struct mm_struct___458 *active_mm;
	struct vmacache___458 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___459 *real_parent;
	struct task_struct___459 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___459 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___190 *active_memcg;
	long int rh_reserved2;
	struct pid___255 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___255 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___255 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___425 *ptracer_cred;
	const struct cred___425 *real_cred;
	const struct cred___425 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___352 *nsproxy;
	struct signal_struct___332 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___459 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___247 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___247 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___306 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___138 *splice_pipe;
	struct page_frag___458 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___190 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___459 *oom_reaper_list;
	struct vm_struct___361 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___156 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___458 *pgtable_t___458;

struct address_space___457;

struct dev_pagemap___445;

struct page___458 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___457 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___458 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___458 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___458 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___445 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___190 *mem_cgroup;
};

struct pglist_data___458;

struct lruvec___458 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___458 *pgdat;
};

struct zone___458 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___458 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___458 {
	struct zone___458 *zone;
	int zone_idx;
};

struct zonelist___458 {
	struct zoneref___458 _zonerefs[25];
};

struct pglist_data___458 {
	struct zone___458 node_zones[3];
	struct zonelist___458 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___459 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___459 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___458 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___459 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___459 *owner;
};

struct secondary_data___459 {
	void *stack;
	struct task_struct___459 *task;
	long int status;
};

struct blocking_notifier_head___458 {
	struct rw_semaphore___459 rwsem;
	struct notifier_block *head;
};

struct cgroup___306;

struct cgroup_subsys___306;

struct cgroup_subsys_state___306 {
	struct cgroup___306 *cgroup;
	struct cgroup_subsys___306 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___306 *parent;
};

struct kernfs_node___452;

struct cgroup_file___306 {
	struct kernfs_node___452 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___190;

struct mem_cgroup___190 {
	struct cgroup_subsys_state___306 css;
	struct mem_cgroup_id___13 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___306 events_file;
	struct cgroup_file___306 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___459 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___190 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___255;

struct upid___255 {
	int nr;
	struct pid_namespace___255 *ns;
};

struct dentry___457;

struct user_namespace___322;

struct ucounts___322;

struct pid_namespace___255 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___459 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___255 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___457 *proc_self;
	struct dentry___457 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___322 *user_ns;
	struct ucounts___322 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___29 ns;
};

struct pid___255 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___255 numbers[1];
};

struct key___425;

struct user_namespace___322 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___322 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___29 ns;
	long unsigned int flags;
	struct key___425 *persistent_keyring_register;
	struct rw_semaphore___459 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___322 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct user_struct___425 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___425 *uid_keyring;
	struct key___425 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___445;

struct vm_area_struct___458 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___458 *vm_next;
	struct vm_area_struct___458 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___458 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___445 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___457 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___458;

struct mm_struct___458 {
	struct {
		struct vm_area_struct___458 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___457 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___459 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___458 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___459 *owner;
		struct user_namespace___322 *user_ns;
		struct file___457 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___458 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___425 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___425 *session_keyring;
	struct key___425 *process_keyring;
	struct key___425 *thread_keyring;
	struct key___425 *request_key_auth;
	void *security;
	struct user_struct___425 *user;
	struct user_namespace___322 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___113;

struct cgroup_namespace___306;

struct nsproxy___352 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___255 *pid_ns_for_children;
	struct net___113 *net_ns;
	struct cgroup_namespace___306 *cgroup_ns;
};

struct signal_struct___332 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___459 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___459 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___255 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___255 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___458 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___255 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___247;

struct bio_list___247 {
	struct bio___247 *head;
	struct bio___247 *tail;
};

struct bdi_writeback_congested___247;

struct bdi_writeback___247 {
	struct backing_dev_info___247 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___247 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___306 *memcg_css;
	struct cgroup_subsys_state___306 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___425;

struct backing_dev_info___247 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___247 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___425 *dev;
	struct device___425 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___457 *debug_dir;
	struct dentry___457 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___306 {
	struct cgroup_subsys_state___306 *subsys[13];
	refcount_t refcount;
	struct css_set___306 *dom_cset;
	struct cgroup___306 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___306 *mg_src_cgrp;
	struct cgroup___306 *mg_dst_cgrp;
	struct css_set___306 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___457;

struct pipe_buffer___138;

struct pipe_inode_info___138 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___458 *tmp_page;
	struct fasync_struct___457 *fasync_readers;
	struct fasync_struct___457 *fasync_writers;
	struct pipe_buffer___138 *bufs;
	struct user_struct___425 *user;
};

struct vm_struct___361 {
	struct vm_struct___361 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___458 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___344 {
	struct task_struct___459 task;
	long unsigned int stack[8192];
};

struct address_space_operations___457;

struct address_space___457 {
	struct inode___457 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___459 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___457 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___445)(struct vm_area_struct___458 *, long unsigned int, const struct page___458 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___445)(struct page___458 *, void *);

struct dev_pagemap___445 {
	dev_page_fault_t___445 page_fault;
	dev_page_free_t___445 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___425 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___458 {
	struct vfsmount *mnt;
	struct dentry___457 *dentry;
};

struct fown_struct___255 {
	rwlock_t lock;
	struct pid___255 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___457 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___458 f_path;
	struct inode___457 *f_inode;
	const struct file_operations___457 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___255 f_owner;
	const struct cred___425 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___457 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___445;

struct vm_operations_struct___445 {
	void (*open)(struct vm_area_struct___458 *);
	void (*close)(struct vm_area_struct___458 *);
	int (*split)(struct vm_area_struct___458 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___458 *);
	vm_fault_t (*fault)(struct vm_fault___445 *);
	vm_fault_t (*huge_fault)(struct vm_fault___445 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___445 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___458 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___445 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___445 *);
	int (*access)(struct vm_area_struct___458 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___458 *);
	int (*set_policy)(struct vm_area_struct___458 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___458 *, long unsigned int);
	struct page___458 * (*find_special_page)(struct vm_area_struct___458 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___458 {
	struct task_struct___459 *task;
	struct core_thread___458 *next;
};

struct core_state___458 {
	atomic_t nr_threads;
	struct core_thread___458 dumper;
	struct completion startup;
};

struct vm_fault___445 {
	struct vm_area_struct___458 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___458 *cow_page;
	struct mem_cgroup___190 *memcg;
	struct page___458 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___458 prealloc_pte;
};

struct kset___444;

struct kobj_type___444;

struct kobject___445 {
	const char *name;
	struct list_head entry;
	struct kobject___445 *parent;
	struct kset___444 *kset;
	struct kobj_type___444 *ktype;
	struct kernfs_node___452 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___383 {
	struct kobject___445 kobj;
	struct module___383 *mod;
	struct kobject___445 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___383 {
	struct module___383 *mod;
	struct latch_tree_node node;
};

struct module_layout___383 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___383 mtn;
};

struct module_attribute___383;

struct kernel_param___383;

struct module___383 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___383 mkobj;
	struct module_attribute___383 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___445 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___383 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___383 core_layout;
	struct module_layout___383 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bio_vec___249 {
	struct page___458 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___224 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___249 *bvec;
		struct pipe_inode_info___138 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct msghdr___85 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___224 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___457 *msg_iocb;
};

struct kiocb___457 {
	struct file___457 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___457 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dentry_operations___457;

struct super_block___457;

struct dentry___457 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___457 *d_parent;
	struct qstr d_name;
	struct inode___457 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___457 *d_op;
	struct super_block___457 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___457;

struct block_device___457;

struct inode___457 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___457 *i_op;
	struct super_block___457 *i_sb;
	struct address_space___457 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___459 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___247 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___457 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___457 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___138 *i_pipe;
		struct block_device___457 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___457 {
	int (*d_revalidate)(struct dentry___457 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___457 *, unsigned int);
	int (*d_hash)(const struct dentry___457 *, struct qstr *);
	int (*d_compare)(const struct dentry___457 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___457 *);
	int (*d_init)(struct dentry___457 *);
	void (*d_release)(struct dentry___457 *);
	void (*d_prune)(struct dentry___457 *);
	void (*d_iput)(struct dentry___457 *, struct inode___457 *);
	char * (*d_dname)(struct dentry___457 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___458 *);
	int (*d_manage)(const struct path___458 *, bool);
	struct dentry___457 * (*d_real)(struct dentry___457 *, const struct inode___457 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___457;

struct mem_dqinfo___457 {
	struct quota_format_type___457 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___457;

struct quota_info___457 {
	unsigned int flags;
	struct rw_semaphore___459 dqio_sem;
	struct inode___457 *files[3];
	struct mem_dqinfo___457 info[3];
	const struct quota_format_ops___457 *ops[3];
};

struct rcuwait___457 {
	struct task_struct___459 *task;
};

struct percpu_rw_semaphore___457 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___459 rw_sem;
	struct rcuwait___457 writer;
	int readers_block;
};

struct sb_writers___457 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___457 rw_sem[3];
};

struct shrink_control___190;

struct shrinker___190 {
	long unsigned int (*count_objects)(struct shrinker___190 *, struct shrink_control___190 *);
	long unsigned int (*scan_objects)(struct shrinker___190 *, struct shrink_control___190 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___457;

struct super_operations___457;

struct dquot_operations___457;

struct quotactl_ops___457;

struct super_block___457 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___457 *s_type;
	const struct super_operations___457 *s_op;
	const struct dquot_operations___457 *dq_op;
	const struct quotactl_ops___457 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___457 *s_root;
	struct rw_semaphore___459 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___457 *s_bdev;
	struct backing_dev_info___247 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___457 s_dquot;
	struct sb_writers___457 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___457 *s_d_op;
	int cleancache_poolid;
	struct shrinker___190 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___322 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___190 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___190 *memcg;
};

struct iattr___457 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___457 *ia_file;
};

struct dquot___457 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___457 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___457 {
	int qf_fmt_id;
	const struct quota_format_ops___457 *qf_ops;
	struct module___383 *qf_owner;
	struct quota_format_type___457 *qf_next;
};

struct quota_format_ops___457 {
	int (*check_quota_file)(struct super_block___457 *, int);
	int (*read_file_info)(struct super_block___457 *, int);
	int (*write_file_info)(struct super_block___457 *, int);
	int (*free_file_info)(struct super_block___457 *, int);
	int (*read_dqblk)(struct dquot___457 *);
	int (*commit_dqblk)(struct dquot___457 *);
	int (*release_dqblk)(struct dquot___457 *);
	int (*get_next_id)(struct super_block___457 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___457 {
	int (*write_dquot)(struct dquot___457 *);
	struct dquot___457 * (*alloc_dquot)(struct super_block___457 *, int);
	void (*destroy_dquot)(struct dquot___457 *);
	int (*acquire_dquot)(struct dquot___457 *);
	int (*release_dquot)(struct dquot___457 *);
	int (*mark_dirty)(struct dquot___457 *);
	int (*write_info)(struct super_block___457 *, int);
	qsize_t * (*get_reserved_space)(struct inode___457 *);
	int (*get_projid)(struct inode___457 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___457 *, qsize_t *);
	int (*get_next_id)(struct super_block___457 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___457 {
	int (*quota_on)(struct super_block___457 *, int, int, const struct path___458 *);
	int (*quota_off)(struct super_block___457 *, int);
	int (*quota_enable)(struct super_block___457 *, unsigned int);
	int (*quota_disable)(struct super_block___457 *, unsigned int);
	int (*quota_sync)(struct super_block___457 *, int);
	int (*set_info)(struct super_block___457 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___457 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___457 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___457 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___457 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___457 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___210;

struct address_space_operations___457 {
	int (*writepage)(struct page___458 *, struct writeback_control___210 *);
	int (*readpage)(struct file___457 *, struct page___458 *);
	int (*writepages)(struct address_space___457 *, struct writeback_control___210 *);
	int (*set_page_dirty)(struct page___458 *);
	int (*readpages)(struct file___457 *, struct address_space___457 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___457 *, struct address_space___457 *, loff_t, unsigned int, unsigned int, struct page___458 **, void **);
	int (*write_end)(struct file___457 *, struct address_space___457 *, loff_t, unsigned int, unsigned int, struct page___458 *, void *);
	sector_t (*bmap)(struct address_space___457 *, sector_t);
	void (*invalidatepage)(struct page___458 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___458 *, gfp_t);
	void (*freepage)(struct page___458 *);
	ssize_t (*direct_IO)(struct kiocb___457 *, struct iov_iter___224 *);
	int (*migratepage)(struct address_space___457 *, struct page___458 *, struct page___458 *, enum migrate_mode);
	bool (*isolate_page)(struct page___458 *, isolate_mode_t);
	void (*putback_page)(struct page___458 *);
	int (*launder_page)(struct page___458 *);
	int (*is_partially_uptodate)(struct page___458 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___458 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___457 *, struct page___458 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___457 *, sector_t *);
	void (*swap_deactivate)(struct file___457 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___210 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___247 *wb;
	struct inode___457 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___457 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___457 *bd_inode;
	struct super_block___457 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___457 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___247 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___457 {
	struct dentry___457 * (*lookup)(struct inode___457 *, struct dentry___457 *, unsigned int);
	const char * (*get_link)(struct dentry___457 *, struct inode___457 *, struct delayed_call *);
	int (*permission)(struct inode___457 *, int);
	struct posix_acl * (*get_acl)(struct inode___457 *, int);
	int (*readlink)(struct dentry___457 *, char *, int);
	int (*create)(struct inode___457 *, struct dentry___457 *, umode_t, bool);
	int (*link)(struct dentry___457 *, struct inode___457 *, struct dentry___457 *);
	int (*unlink)(struct inode___457 *, struct dentry___457 *);
	int (*symlink)(struct inode___457 *, struct dentry___457 *, const char *);
	int (*mkdir)(struct inode___457 *, struct dentry___457 *, umode_t);
	int (*rmdir)(struct inode___457 *, struct dentry___457 *);
	int (*mknod)(struct inode___457 *, struct dentry___457 *, umode_t, dev_t);
	int (*rename)(struct inode___457 *, struct dentry___457 *, struct inode___457 *, struct dentry___457 *, unsigned int);
	int (*setattr)(struct dentry___457 *, struct iattr___457 *);
	int (*getattr)(const struct path___458 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___457 *, char *, size_t);
	int (*fiemap)(struct inode___457 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___457 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___457 *, struct dentry___457 *, struct file___457 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___457 *, struct dentry___457 *, umode_t);
	int (*set_acl)(struct inode___457 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___457 {
	void (*fl_copy_lock)(struct file_lock___457 *, struct file_lock___457 *);
	void (*fl_release_private)(struct file_lock___457 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___457;

struct file_lock___457 {
	struct file_lock___457 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___457 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___457 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___457 *fl_ops;
	const struct lock_manager_operations___457 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___457 {
	int (*lm_compare_owner)(struct file_lock___457 *, struct file_lock___457 *);
	long unsigned int (*lm_owner_key)(struct file_lock___457 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___457 *);
	int (*lm_grant)(struct file_lock___457 *, int);
	bool (*lm_break)(struct file_lock___457 *);
	int (*lm_change)(struct file_lock___457 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___457 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___457 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___457 *fa_next;
	struct file___457 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___457 {
	const char *name;
	int fs_flags;
	struct dentry___457 * (*mount)(struct file_system_type___457 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___457 *);
	struct module___383 *owner;
	struct file_system_type___457 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___457 {
	struct inode___457 * (*alloc_inode)(struct super_block___457 *);
	void (*destroy_inode)(struct inode___457 *);
	void (*dirty_inode)(struct inode___457 *, int);
	int (*write_inode)(struct inode___457 *, struct writeback_control___210 *);
	int (*drop_inode)(struct inode___457 *);
	void (*evict_inode)(struct inode___457 *);
	void (*put_super)(struct super_block___457 *);
	int (*sync_fs)(struct super_block___457 *, int);
	int (*freeze_super)(struct super_block___457 *);
	int (*freeze_fs)(struct super_block___457 *);
	int (*thaw_super)(struct super_block___457 *);
	int (*unfreeze_fs)(struct super_block___457 *);
	int (*statfs)(struct dentry___457 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___457 *, int *, char *);
	void (*umount_begin)(struct super_block___457 *);
	int (*show_options)(struct seq_file___396 *, struct dentry___457 *);
	int (*show_devname)(struct seq_file___396 *, struct dentry___457 *);
	int (*show_path)(struct seq_file___396 *, struct dentry___457 *);
	int (*show_stats)(struct seq_file___396 *, struct dentry___457 *);
	ssize_t (*quota_read)(struct super_block___457 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___457 *, int, const char *, size_t, loff_t);
	struct dquot___457 ** (*get_dquots)(struct inode___457 *);
	int (*bdev_try_to_free_page)(struct super_block___457 *, struct page___458 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___457 *, struct shrink_control___190 *);
	long int (*free_cached_objects)(struct super_block___457 *, struct shrink_control___190 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___306)(struct file___457 *, wait_queue_head_t *, struct poll_table_struct___296 *);

struct poll_table_struct___296 {
	poll_queue_proc___306 _qproc;
	__poll_t _key;
};

struct seq_operations___396;

struct seq_file___396 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___396 *op;
	int poll_event;
	const struct file___457 *file;
	void *private;
};

typedef void bio_end_io_t___247(struct bio___247 *);

struct bio_integrity_payload___247;

struct bio_set___247;

struct bio___247 {
	struct bio___247 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___247 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___247 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___249 *bi_io_vec;
	struct bio_set___247 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___249 bi_inline_vecs[0];
};

struct socket_wq___83 {
	wait_queue_head_t wait;
	struct fasync_struct___457 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct sock___82;

struct proto_ops___83;

struct socket___84 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___83 *wq;
	struct file___457 *file;
	struct sock___82 *sk;
	const struct proto_ops___83 *ops;
};

typedef struct {
	struct net___113 *net;
} possible_net_t___104;

struct proto___82;

struct sock_common___82 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___82 *skc_prot;
	possible_net_t___104 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___82 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___103;

struct sk_buff_head___102 {
	struct sk_buff___103 *next;
	struct sk_buff___103 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___82;

struct xfrm_policy___19;

struct dst_entry___82;

struct net_device___102;

struct sock___82 {
	struct sock_common___82 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___102 sk_error_queue;
	struct sk_buff_head___102 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___103 *head;
		struct sk_buff___103 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___82 *sk_filter;
	union {
		struct socket_wq___83 *sk_wq;
		struct socket_wq___83 *sk_wq_raw;
	};
	struct xfrm_policy___19 *sk_policy[2];
	struct dst_entry___82 *sk_rx_dst;
	struct dst_entry___82 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___103 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___102 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___458 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___82 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___255 *sk_peer_pid;
	const struct cred___425 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___84 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___190 *sk_memcg;
	void (*sk_state_change)(struct sock___82 *);
	void (*sk_data_ready)(struct sock___82 *);
	void (*sk_write_space)(struct sock___82 *);
	void (*sk_error_report)(struct sock___82 *);
	int (*sk_backlog_rcv)(struct sock___82 *, struct sk_buff___103 *);
	struct sk_buff___103 * (*sk_validate_xmit_skb)(struct sock___82 *, struct net_device___102 *, struct sk_buff___103 *);
	void (*sk_destruct)(struct sock___82 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

typedef int (*sk_read_actor_t___82)(read_descriptor_t *, struct sk_buff___103 *, unsigned int, size_t);

struct proto_ops___83 {
	int family;
	struct module___383 *owner;
	int (*release)(struct socket___84 *);
	int (*bind)(struct socket___84 *, struct sockaddr *, int);
	int (*connect)(struct socket___84 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___84 *, struct socket___84 *);
	int (*accept)(struct socket___84 *, struct socket___84 *, int, bool);
	int (*getname)(struct socket___84 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___457 *, struct socket___84 *, struct poll_table_struct___296 *);
	int (*ioctl)(struct socket___84 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___84 *, int);
	int (*shutdown)(struct socket___84 *, int);
	int (*setsockopt)(struct socket___84 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___84 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___84 *, struct msghdr___85 *, size_t);
	int (*recvmsg)(struct socket___84 *, struct msghdr___85 *, size_t, int);
	int (*mmap)(struct file___457 *, struct socket___84 *, struct vm_area_struct___458 *);
	ssize_t (*sendpage)(struct socket___84 *, struct page___458 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___84 *, loff_t *, struct pipe_inode_info___138 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___82 *, int);
	int (*peek_len)(struct socket___84 *);
	int (*read_sock)(struct sock___82 *, read_descriptor_t *, sk_read_actor_t___82);
	int (*sendpage_locked)(struct sock___82 *, struct page___458 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___82 *, struct msghdr___85 *, size_t);
	int (*set_rcvlowat)(struct sock___82 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct sec_path___19;

struct nf_bridge_info___102;

struct sk_buff___103 {
	union {
		struct {
			struct sk_buff___103 *next;
			struct sk_buff___103 *prev;
			union {
				struct net_device___102 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___82 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___103 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path___19 *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___102 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___102;

struct netns_frags___102 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___102 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ip_ra_chain___48;

struct fib_rules_ops___82;

struct fib_notifier_ops___83;

struct netns_ipv4___102 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___48 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___82 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___82 *fibnl;
	struct sock___82 **icmp_sk;
	struct sock___82 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___82 **tcp_sk;
	struct netns_frags___102 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___82 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___83 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___83 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___82;

struct dst_ops___113 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___113 *);
	struct dst_entry___82 * (*check)(struct dst_entry___82 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___82 *);
	unsigned int (*mtu)(const struct dst_entry___82 *);
	u32 * (*cow_metrics)(struct dst_entry___82 *, long unsigned int);
	void (*destroy)(struct dst_entry___82 *);
	void (*ifdown)(struct dst_entry___82 *, struct net_device___102 *, int);
	struct dst_entry___82 * (*negative_advice)(struct dst_entry___82 *);
	void (*link_failure)(struct sk_buff___103 *);
	void (*update_pmtu)(struct dst_entry___82 *, struct sock___82 *, struct sk_buff___103 *, u32);
	void (*redirect)(struct dst_entry___82 *, struct sock___82 *, struct sk_buff___103 *);
	int (*local_out)(struct net___113 *, struct sock___82 *, struct sk_buff___103 *);
	struct neighbour___82 * (*neigh_lookup)(const struct dst_entry___82 *, struct sk_buff___103 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___82 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_info___24;

struct rt6_info___24;

struct fib6_table___24;

struct netns_ipv6___113 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___102 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info___24 *fib6_null_entry;
	struct rt6_info___24 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___24 *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___113 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info___24 *ip6_prohibit_entry;
	struct rt6_info___24 *ip6_blk_hole_entry;
	struct fib6_table___24 *fib6_local_tbl;
	struct fib_rules_ops___82 *fib6_rules_ops;
	struct sock___82 **icmp_sk;
	struct sock___82 *ndisc_sk;
	struct sock___82 *tcp_sk;
	struct sock___82 *igmp_sk;
	struct sock___82 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___82 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___83 *notifier_ops;
	struct fib_notifier_ops___83 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___83 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___82 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct nf_hook_entries___17;

struct netns_nf___18 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_queue_handler *queue_handler;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header *nf_log_dir_header;
	struct nf_hook_entries___17 *hooks_ipv4[5];
	struct nf_hook_entries___17 *hooks_ipv6[5];
	struct nf_hook_entries___17 *hooks_arp[3];
	struct nf_hook_entries___17 *hooks_bridge[5];
	bool defrag_ipv4;
	bool defrag_ipv6;
};

struct netns_nf_frag___102 {
	struct netns_frags___102 frags;
};

struct netns_xfrm___113 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___82 *nlsk;
	struct sock___82 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___113 xfrm4_dst_ops;
	struct dst_ops___113 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___92;

struct net___113 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___322 *user_ns;
	struct ucounts___322 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___29 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___82 *rtnl;
	struct sock___82 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___102 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___102 ipv4;
	struct netns_ipv6___113 ipv6;
	struct netns_sctp___83 sctp;
	struct netns_nf___18 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___102 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___82 *nfnl;
	struct sock___82 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___113 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___82 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___92 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kernfs_root___451;

struct kernfs_elem_dir___451 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___451 *root;
};

struct kernfs_syscall_ops___451;

struct kernfs_root___451 {
	struct kernfs_node___452 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___451 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___451 {
	struct kernfs_node___452 *target_kn;
};

struct kernfs_ops___451;

struct kernfs_elem_attr___451 {
	const struct kernfs_ops___451 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___452 *notify_next;
};

struct kernfs_node___452 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___452 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___451 dir;
		struct kernfs_elem_symlink___451 symlink;
		struct kernfs_elem_attr___451 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___451;

struct kernfs_ops___451 {
	int (*open)(struct kernfs_open_file___451 *);
	void (*release)(struct kernfs_open_file___451 *);
	int (*seq_show)(struct seq_file___396 *, void *);
	void * (*seq_start)(struct seq_file___396 *, loff_t *);
	void * (*seq_next)(struct seq_file___396 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___396 *, void *);
	ssize_t (*read)(struct kernfs_open_file___451 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___451 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___451 *, struct vm_area_struct___458 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___451 *, struct poll_table_struct___296 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___451 {
	int (*remount_fs)(struct kernfs_root___451 *, int *, char *);
	int (*show_options)(struct seq_file___396 *, struct kernfs_root___451 *);
	int (*mkdir)(struct kernfs_node___452 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___452 *);
	int (*rename)(struct kernfs_node___452 *, struct kernfs_node___452 *, const char *);
	int (*show_path)(struct seq_file___396 *, struct kernfs_node___452 *, struct kernfs_root___451 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___451 {
	struct kernfs_node___452 *kn;
	struct file___457 *file;
	struct seq_file___396 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___445 *vm_ops;
};

struct kobj_ns_type_operations___82 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___82 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___421;

struct attribute_group___422 {
	const char *name;
	umode_t (*is_visible)(struct kobject___445 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___445 *, struct bin_attribute___421 *, int);
	struct attribute **attrs;
	struct bin_attribute___421 **bin_attrs;
};

struct bin_attribute___421 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___457 *, struct kobject___445 *, struct bin_attribute___421 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___457 *, struct kobject___445 *, struct bin_attribute___421 *, char *, loff_t, size_t);
	int (*mmap)(struct file___457 *, struct kobject___445 *, struct bin_attribute___421 *, struct vm_area_struct___458 *);
};

struct sysfs_ops___444 {
	ssize_t (*show)(struct kobject___445 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___445 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___444;

struct kset___444 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___445 kobj;
	const struct kset_uevent_ops___444 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___444 {
	void (*release)(struct kobject___445 *);
	const struct sysfs_ops___444 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___82 * (*child_ns_type)(struct kobject___445 *);
	const void * (*namespace)(struct kobject___445 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___444 {
	int (* const filter)(struct kset___444 *, struct kobject___445 *);
	const char * (* const name)(struct kset___444 *, struct kobject___445 *);
	int (* const uevent)(struct kset___444 *, struct kobject___445 *, struct kobj_uevent_env *);
};

struct kobj_attribute___435 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___445 *, struct kobj_attribute___435 *, char *);
	ssize_t (*store)(struct kobject___445 *, struct kobj_attribute___435 *, const char *, size_t);
};

struct dev_pm_ops___425 {
	int (*prepare)(struct device___425 *);
	void (*complete)(struct device___425 *);
	int (*suspend)(struct device___425 *);
	int (*resume)(struct device___425 *);
	int (*freeze)(struct device___425 *);
	int (*thaw)(struct device___425 *);
	int (*poweroff)(struct device___425 *);
	int (*restore)(struct device___425 *);
	int (*suspend_late)(struct device___425 *);
	int (*resume_early)(struct device___425 *);
	int (*freeze_late)(struct device___425 *);
	int (*thaw_early)(struct device___425 *);
	int (*poweroff_late)(struct device___425 *);
	int (*restore_early)(struct device___425 *);
	int (*suspend_noirq)(struct device___425 *);
	int (*resume_noirq)(struct device___425 *);
	int (*freeze_noirq)(struct device___425 *);
	int (*thaw_noirq)(struct device___425 *);
	int (*poweroff_noirq)(struct device___425 *);
	int (*restore_noirq)(struct device___425 *);
	int (*runtime_suspend)(struct device___425 *);
	int (*runtime_resume)(struct device___425 *);
	int (*runtime_idle)(struct device___425 *);
};

struct dev_pm_info___425 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___425 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___425;

struct bus_type___425;

struct device_driver___425;

struct dev_pm_domain___425;

struct dma_map_ops___197;

struct fwnode_handle___345;

struct class___425;

struct device___425 {
	struct device___425 *parent;
	struct device_private *p;
	struct kobject___445 kobj;
	const char *init_name;
	const struct device_type___425 *type;
	struct mutex mutex;
	struct bus_type___425 *bus;
	struct device_driver___425 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___425 power;
	struct dev_pm_domain___425 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___197 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___345 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___425 *class;
	const struct attribute_group___422 **groups;
	void (*release)(struct device___425 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___425 {
	struct dev_pm_ops___425 ops;
	void (*detach)(struct device___425 *, bool);
	int (*activate)(struct device___425 *);
	void (*sync)(struct device___425 *);
	void (*dismiss)(struct device___425 *);
};

struct bus_type___425 {
	const char *name;
	const char *dev_name;
	struct device___425 *dev_root;
	const struct attribute_group___422 **bus_groups;
	const struct attribute_group___422 **dev_groups;
	const struct attribute_group___422 **drv_groups;
	int (*match)(struct device___425 *, struct device_driver___425 *);
	int (*uevent)(struct device___425 *, struct kobj_uevent_env *);
	int (*probe)(struct device___425 *);
	int (*remove)(struct device___425 *);
	void (*shutdown)(struct device___425 *);
	int (*online)(struct device___425 *);
	int (*offline)(struct device___425 *);
	int (*suspend)(struct device___425 *, pm_message_t);
	int (*resume)(struct device___425 *);
	int (*num_vf)(struct device___425 *);
	int (*dma_configure)(struct device___425 *);
	const struct dev_pm_ops___425 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___425 {
	const char *name;
	struct bus_type___425 *bus;
	struct module___383 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___425 *);
	int (*remove)(struct device___425 *);
	void (*shutdown)(struct device___425 *);
	int (*suspend)(struct device___425 *, pm_message_t);
	int (*resume)(struct device___425 *);
	const struct attribute_group___422 **groups;
	const struct dev_pm_ops___425 *pm;
	void (*coredump)(struct device___425 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___425 {
	const char *name;
	const struct attribute_group___422 **groups;
	int (*uevent)(struct device___425 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___425 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___425 *);
	const struct dev_pm_ops___425 *pm;
};

struct class___425 {
	const char *name;
	struct module___383 *owner;
	const struct attribute_group___422 **class_groups;
	const struct attribute_group___422 **dev_groups;
	struct kobject___445 *dev_kobj;
	int (*dev_uevent)(struct device___425 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___425 *, umode_t *);
	void (*class_release)(struct class___425 *);
	void (*dev_release)(struct device___425 *);
	int (*shutdown_pre)(struct device___425 *);
	const struct kobj_ns_type_operations___82 *ns_type;
	const void * (*namespace)(struct device___425 *);
	const struct dev_pm_ops___425 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___197 {
	void * (*alloc)(struct device___425 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___425 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___425 *, struct vm_area_struct___458 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___425 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___425 *, struct page___458 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___425 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___425 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___425 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___425 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___425 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___425 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___425 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___425 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___425 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___425 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___425 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___425 *, u64);
	u64 (*get_required_mask)(struct device___425 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___345;

struct fwnode_handle___345 {
	struct fwnode_handle___345 *secondary;
	const struct fwnode_operations___345 *ops;
};

typedef void compound_page_dtor___445(struct page___458 *);

struct fwnode_reference_args___345;

struct fwnode_endpoint___345;

struct fwnode_operations___345 {
	struct fwnode_handle___345 * (*get)(struct fwnode_handle___345 *);
	void (*put)(struct fwnode_handle___345 *);
	bool (*device_is_available)(const struct fwnode_handle___345 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___345 *, const struct device___425 *);
	bool (*property_present)(const struct fwnode_handle___345 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___345 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___345 *, const char *, const char **, size_t);
	struct fwnode_handle___345 * (*get_parent)(const struct fwnode_handle___345 *);
	struct fwnode_handle___345 * (*get_next_child_node)(const struct fwnode_handle___345 *, struct fwnode_handle___345 *);
	struct fwnode_handle___345 * (*get_named_child_node)(const struct fwnode_handle___345 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___345 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___345 *);
	struct fwnode_handle___345 * (*graph_get_next_endpoint)(const struct fwnode_handle___345 *, struct fwnode_handle___345 *);
	struct fwnode_handle___345 * (*graph_get_remote_endpoint)(const struct fwnode_handle___345 *);
	struct fwnode_handle___345 * (*graph_get_port_parent)(struct fwnode_handle___345 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___345 *, struct fwnode_endpoint___345 *);
};

struct fwnode_endpoint___345 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___345 *local_fwnode;
};

struct fwnode_reference_args___345 {
	struct fwnode_handle___345 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___138;

struct pipe_buffer___138 {
	struct page___458 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___138 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___138 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___138 *, struct pipe_buffer___138 *);
	void (*release)(struct pipe_inode_info___138 *, struct pipe_buffer___138 *);
	int (*steal)(struct pipe_inode_info___138 *, struct pipe_buffer___138 *);
	union {
		bool (*get)(struct pipe_inode_info___138 *, struct pipe_buffer___138 *);
		struct {
			void (*get)(struct pipe_inode_info___138 *, struct pipe_buffer___138 *);
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
};

struct nf_bridge_info___102 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___102 = 0,
		BRNF_PROTO_8021Q___102 = 1,
		BRNF_PROTO_PPPOE___102 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___102 *physindev;
	struct net_device___102 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___102(struct sk_buff___103 **);

struct net_device_ops___102;

struct ethtool_ops___102;

struct l3mdev_ops___82;

struct ndisc_ops___53;

struct xfrmdev_ops___102;

struct tlsdev_ops___102;

struct header_ops___102;

struct inet6_dev___53;

struct netdev_rx_queue___102;

struct mini_Qdisc___94;

struct netdev_queue___102;

struct Qdisc___94;

struct rtnl_link_ops___94;

struct dcbnl_rtnl_ops___102;

struct net_device___102 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___102 *netdev_ops;
	const struct ethtool_ops___102 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___82 *l3mdev_ops;
	const struct ndisc_ops___53 *ndisc_ops;
	const struct xfrmdev_ops___102 *xfrmdev_ops;
	const struct tlsdev_ops___102 *tlsdev_ops;
	const struct header_ops___102 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___444 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___53 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___102 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___92 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___102 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___94 *miniq_ingress;
	struct netdev_queue___102 *ingress_queue;
	struct nf_hook_entries___17 *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___102 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___94 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___94 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___102 = 0,
		NETREG_REGISTERED___102 = 1,
		NETREG_UNREGISTERING___102 = 2,
		NETREG_UNREGISTERED___102 = 3,
		NETREG_RELEASED___102 = 4,
		NETREG_DUMMY___102 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___102 = 0,
		RTNL_LINK_INITIALIZING___102 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___102 *);
	struct netpoll_info *npinfo;
	possible_net_t___104 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___425 dev;
	const struct attribute_group___422 *sysfs_groups[4];
	const struct attribute_group___422 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___94 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___102 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide35;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct skb_frag_struct___28 {
	struct {
		struct page___458 *p;
	} page;
	__u32 page_offset;
	__u32 size;
};

typedef struct skb_frag_struct___28 skb_frag_t___28;

struct skb_shared_info___28 {
	__u8 __unused;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___103 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___28 frags[16];
};

struct xfrm_state___19;

struct sec_path___19 {
	refcount_t refcnt;
	int len;
	int olen;
	struct xfrm_state___19 *xvec[6];
	struct xfrm_offload ovec[1];
};

struct kernel_param_ops___383 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___383 *);
	int (*get)(char *, const struct kernel_param___383 *);
	void (*free)(void *);
};

struct kparam_array___383;

struct kernel_param___383 {
	const char *name;
	struct module___383 *mod;
	const struct kernel_param_ops___383 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___383 *arr;
	};
};

struct kparam_array___383 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___383 *ops;
	void *elem;
};

struct module_attribute___383 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___383 *, struct module_kobject___383 *, char *);
	ssize_t (*store)(struct module_attribute___383 *, struct module_kobject___383 *, const char *, size_t);
	void (*setup)(struct module___383 *, const char *);
	int (*test)(struct module___383 *);
	void (*free)(struct module___383 *);
};

struct ethtool_ops___102 {
	int (*get_settings)(struct net_device___102 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___102 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___102 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___102 *);
	void (*get_regs)(struct net_device___102 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___102 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___102 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___102 *);
	void (*set_msglevel)(struct net_device___102 *, u32);
	int (*nway_reset)(struct net_device___102 *);
	u32 (*get_link)(struct net_device___102 *);
	int (*get_eeprom_len)(struct net_device___102 *);
	int (*get_eeprom)(struct net_device___102 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___102 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___102 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___102 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___102 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___102 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___102 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___102 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___102 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___102 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___102 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___102 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___102 *);
	void (*complete)(struct net_device___102 *);
	u32 (*get_priv_flags)(struct net_device___102 *);
	int (*set_priv_flags)(struct net_device___102 *, u32);
	int (*get_sset_count)(struct net_device___102 *, int);
	int (*get_rxnfc)(struct net_device___102 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___102 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___102 *, struct ethtool_flash *);
	int (*reset)(struct net_device___102 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___102 *);
	u32 (*get_rxfh_indir_size)(struct net_device___102 *);
	int (*get_rxfh)(struct net_device___102 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___102 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___102 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___102 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___102 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___102 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___102 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___102 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___102 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___102 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___102 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___102 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___102 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___102 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___102 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___102 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___102 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___102 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___102 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___102 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___102 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___102 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	int (*get_fecparam)(struct net_device___102 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___102 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___102 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___102 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___102 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___102;

struct inet_frags___102 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___102 *, const void *);
	void (*destructor)(struct inet_frag_queue___102 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___102 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___103 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___103 *fragments_tail;
	struct sk_buff___103 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___102 *net;
	struct callback_head rcu;
};

struct ip_ra_chain___48 {
	struct ip_ra_chain___48 *next;
	struct sock___82 *sk;
	union {
		void (*destructor)(struct sock___82 *);
		struct sock___82 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___82;

struct fib_lookup_arg___82;

struct fib_rules_ops___82 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___82 *, struct flowi *, int, struct fib_lookup_arg___82 *);
	bool (*suppress)(struct fib_rule___82 *, struct fib_lookup_arg___82 *);
	int (*match)(struct fib_rule___82 *, struct flowi *, int);
	int (*configure)(struct fib_rule___82 *, struct sk_buff___103 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___82 *);
	int (*compare)(struct fib_rule___82 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___82 *, struct sk_buff___103 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___82 *);
	void (*flush_cache)(struct fib_rules_ops___82 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___383 *owner;
	struct net___113 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___83 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___113 *);
	int (*fib_dump)(struct net___113 *, struct notifier_block *);
	struct module___383 *owner;
	struct callback_head rcu;
};

struct dst_entry___82 {
	struct net_device___102 *dev;
	struct dst_ops___113 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state___19 *xfrm;
	int (*input)(struct sk_buff___103 *);
	int (*output)(struct net___113 *, struct sock___82 *, struct sk_buff___103 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___82;

struct neigh_parms___82;

struct neigh_ops___82;

struct neighbour___82 {
	struct neighbour___82 *next;
	struct neigh_table___82 *tbl;
	struct neigh_parms___82 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___102 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___82 *, struct sk_buff___103 *);
	const struct neigh_ops___82 *ops;
	struct callback_head rcu;
	struct net_device___102 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct fib6_nh___24 {
	struct in6_addr nh_gw;
	struct net_device___102 *nh_dev;
	struct lwtunnel_state *nh_lwtstate;
	unsigned int nh_flags;
	atomic_t nh_upper_bound;
	int nh_weight;
};

struct fib6_node___24;

struct fib6_info___24 {
	struct fib6_table___24 *fib6_table;
	struct fib6_info___24 *fib6_next;
	struct fib6_node___24 *fib6_node;
	struct list_head fib6_siblings;
	unsigned int fib6_nsiblings;
	atomic_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	struct rt6_info___24 **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
	long unsigned int last_probe;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 exception_bucket_flushed: 1;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 dst_host: 1;
	u8 fib6_destroying: 1;
	u8 unused: 2;
	struct fib6_nh___24 fib6_nh;
	struct callback_head rcu;
};

struct rt6_info___24 {
	struct dst_entry___82 dst;
	struct fib6_info___24 *from;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___53 *rt6i_idev;
	u32 rt6i_flags;
	struct rt6key rt6i_prefsrc;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct fib6_node___24 {
	struct fib6_node___24 *parent;
	struct fib6_node___24 *left;
	struct fib6_node___24 *right;
	struct fib6_info___24 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info___24 *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table___24 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node___24 tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

struct nf_hook_state___17;

typedef unsigned int nf_hookfn___17(void *, struct sk_buff___103 *, const struct nf_hook_state___17 *);

struct nf_hook_entry___17 {
	nf_hookfn___17 *hook;
	void *priv;
};

struct nf_hook_entries___17 {
	u16 num_hook_entries;
	struct nf_hook_entry___17 hooks[0];
};

struct ucounts___322 {
	struct hlist_node node;
	struct user_namespace___322 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_prog_aux___95;

struct bpf_prog___92 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___95 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

typedef int (*key_restrict_link_func_t___426)(struct key___425 *, const struct key_type *, const union key_payload *, struct key___425 *);

struct key_restriction___425;

struct key___425 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___459 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___425 *restrict_link;
};

struct key_restriction___425 {
	key_restrict_link_func_t___426 check;
	struct key___425 *key;
	struct key_type *keytype;
};

struct seq_operations___396 {
	void * (*start)(struct seq_file___396 *, loff_t *);
	void (*stop)(struct seq_file___396 *, void *);
	void * (*next)(struct seq_file___396 *, void *, loff_t *);
	int (*show)(struct seq_file___396 *, void *);
};

struct pernet_operations___103 {
	struct list_head list;
	int (*init)(struct net___113 *);
	void (*exit)(struct net___113 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___102 {
	int (*ieee_getets)(struct net_device___102 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___102 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___102 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___102 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___102 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___102 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___102 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___102 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___102 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___102 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___102 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___102 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___102 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___102 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___102 *);
	u8 (*setstate)(struct net_device___102 *, u8);
	void (*getpermhwaddr)(struct net_device___102 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___102 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___102 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___102 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___102 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___102 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___102 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___102 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___102 *, int, u8 *);
	void (*setpfccfg)(struct net_device___102 *, int, u8);
	void (*getpfccfg)(struct net_device___102 *, int, u8 *);
	u8 (*setall)(struct net_device___102 *);
	u8 (*getcap)(struct net_device___102 *, int, u8 *);
	int (*getnumtcs)(struct net_device___102 *, int, u8 *);
	int (*setnumtcs)(struct net_device___102 *, int, u8);
	u8 (*getpfcstate)(struct net_device___102 *);
	void (*setpfcstate)(struct net_device___102 *, u8);
	void (*getbcncfg)(struct net_device___102 *, int, u32 *);
	void (*setbcncfg)(struct net_device___102 *, int, u32);
	void (*getbcnrp)(struct net_device___102 *, int, u8 *);
	void (*setbcnrp)(struct net_device___102 *, int, u8);
	int (*setapp)(struct net_device___102 *, u8, u16, u8);
	int (*getapp)(struct net_device___102 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___102 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___102 *, int, u8);
	u8 (*getdcbx)(struct net_device___102 *);
	u8 (*setdcbx)(struct net_device___102 *, u8);
	int (*peer_getappinfo)(struct net_device___102 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___102 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___102 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___102 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___102 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___102 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___306 {
	refcount_t count;
	struct ns_common___29 ns;
	struct user_namespace___322 *user_ns;
	struct ucounts___322 *ucounts;
	struct css_set___306 *root_cset;
};

struct bpf_map___307;

struct bpf_map_ops___306 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___307 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___307 *, struct file___457 *);
	void (*map_free)(struct bpf_map___307 *);
	int (*map_get_next_key)(struct bpf_map___307 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___307 *);
	void * (*map_lookup_elem)(struct bpf_map___307 *, void *);
	int (*map_update_elem)(struct bpf_map___307 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___307 *, void *);
	int (*map_push_elem)(struct bpf_map___307 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___307 *, void *);
	int (*map_peek_elem)(struct bpf_map___307 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___307 *, struct file___457 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___307 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___307 *, void *, struct seq_file___396 *);
	int (*map_check_btf)(const struct bpf_map___307 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___307 {
	const struct bpf_map_ops___306 *ops;
	struct bpf_map___307 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___425 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___102;

struct bpf_map_dev_ops___102 {
	int (*map_get_next_key)(struct bpf_offloaded_map___102 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___102 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___102 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___102 *, void *);
};

struct bpf_offloaded_map___102 {
	struct bpf_map___307 map;
	struct net_device___102 *netdev;
	const struct bpf_map_dev_ops___102 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___92 {
	int (*test_run)(struct bpf_prog___92 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___92 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___92 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___92 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___92 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___92 *, u32 *);
};

struct bpf_prog_offload_ops___92 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___92 *);
	int (*translate)(struct bpf_prog___92 *);
	void (*destroy)(struct bpf_prog___92 *);
};

struct bpf_prog_offload___92 {
	struct bpf_prog___92 *prog;
	struct net_device___102 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___92 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___95 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___92 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___92 *ops;
	struct bpf_map___307 **used_maps;
	struct bpf_prog___92 *prog;
	struct user_struct___425 *user;
	u64 load_time;
	struct bpf_map___307 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___92 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___92 {
	struct bpf_prog___92 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___92 {
	struct callback_head rcu;
	struct bpf_prog_array_item___92 items[0];
};

struct cgroup_bpf___92 {
	struct bpf_prog_array___92 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___92 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___307;

typedef void (*kthread_work_func_t___307)(struct kthread_work___307 *);

struct kthread_worker___307;

struct kthread_work___307 {
	struct list_head node;
	kthread_work_func_t___307 func;
	struct kthread_worker___307 *worker;
	int canceling;
};

struct kthread_worker___307 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___459 *task;
	struct kthread_work___307 *current_work;
};

struct kthread_delayed_work___306 {
	struct kthread_work___307 work;
	struct timer_list timer;
};

struct psi_group___306 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___307 *poll_kworker;
	struct kthread_delayed_work___306 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___306;

struct cgroup_rstat_cpu___306;

struct cgroup___306 {
	struct cgroup_subsys_state___306 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___452 *kn;
	struct cgroup_file___306 procs_file;
	struct cgroup_file___306 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___306 *subsys[13];
	struct cgroup_root___306 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___306 *dom_cgrp;
	struct cgroup_rstat_cpu___306 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___92 bpf;
	atomic_t congestion_count;
	struct cgroup___306 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___306 psi;
	int ancestor_ids[0];
};

struct cftype___306;

struct cgroup_subsys___306 {
	struct cgroup_subsys_state___306 * (*css_alloc)(struct cgroup_subsys_state___306 *);
	int (*css_online)(struct cgroup_subsys_state___306 *);
	void (*css_offline)(struct cgroup_subsys_state___306 *);
	void (*css_released)(struct cgroup_subsys_state___306 *);
	void (*css_free)(struct cgroup_subsys_state___306 *);
	void (*css_reset)(struct cgroup_subsys_state___306 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___306 *, int);
	int (*css_extra_stat_show)(struct seq_file___396 *, struct cgroup_subsys_state___306 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___459 *);
	void (*cancel_fork)(struct task_struct___459 *);
	void (*fork)(struct task_struct___459 *);
	void (*exit)(struct task_struct___459 *);
	void (*free)(struct task_struct___459 *);
	void (*bind)(struct cgroup_subsys_state___306 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___306 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___306 *dfl_cftypes;
	struct cftype___306 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___306 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___306 *updated_children;
	struct cgroup___306 *updated_next;
};

struct cgroup_root___306 {
	struct kernfs_root___451 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___306 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___306 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___306 *ss;
	struct list_head node;
	struct kernfs_ops___451 *kf_ops;
	int (*open)(struct kernfs_open_file___451 *);
	void (*release)(struct kernfs_open_file___451 *);
	u64 (*read_u64)(struct cgroup_subsys_state___306 *, struct cftype___306 *);
	s64 (*read_s64)(struct cgroup_subsys_state___306 *, struct cftype___306 *);
	int (*seq_show)(struct seq_file___396 *, void *);
	void * (*seq_start)(struct seq_file___396 *, loff_t *);
	void * (*seq_next)(struct seq_file___396 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___396 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___306 *, struct cftype___306 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___306 *, struct cftype___306 *, s64);
	ssize_t (*write)(struct kernfs_open_file___451 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___451 *, struct poll_table_struct___296 *);
};

struct xdp_rxq_info___102 {
	struct net_device___102 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___102 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___102 *dev_rx;
};

struct netlink_callback___104 {
	struct sk_buff___103 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___104 *);
	int (*dump)(struct sk_buff___103 *, struct netlink_callback___104 *);
	int (*done)(struct netlink_callback___104 *);
	void *data;
	struct module___383 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___102 {
	int (*create)(struct sk_buff___103 *, struct net_device___102 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___103 *, unsigned char *);
	int (*cache)(const struct neighbour___82 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___102 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___102 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___102 *, int);
	int poll_owner;
	struct net_device___102 *dev;
	struct sk_buff___103 *gro_list;
	struct sk_buff___103 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___102 {
	struct net_device___102 *dev;
	struct Qdisc___94 *qdisc;
	struct Qdisc___94 *qdisc_sleeping;
	struct kobject___445 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___102 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem___3 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___94 {
	struct sk_buff___103 *head;
	struct sk_buff___103 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___94;

struct Qdisc___94 {
	int (*enqueue)(struct sk_buff___103 *, struct Qdisc___94 *, struct sk_buff___103 **);
	struct sk_buff___103 * (*dequeue)(struct Qdisc___94 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___94 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___102 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___102 gso_skb;
	struct qdisc_skb_head___94 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___94 *next_sched;
	struct sk_buff_head___102 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___102 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___445 kobj;
	struct net_device___102 *dev;
	long: 64;
	struct xdp_rxq_info___102 xdp_rxq;
	union {
		struct xdp_umem___3 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___102)(struct net_device___102 *, struct sk_buff___103 *, struct net_device___102 *);

struct netdev_bpf___102 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___92 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___92 *prog;
			const struct bpf_prog_offload_ops___92 *ops;
		} verifier;
		struct {
			struct bpf_prog___92 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___102 *offmap;
		};
		struct {
			struct xdp_umem___3 *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___102 {
	int (*xdo_dev_state_add)(struct xfrm_state___19 *);
	void (*xdo_dev_state_delete)(struct xfrm_state___19 *);
	void (*xdo_dev_state_free)(struct xfrm_state___19 *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___103 *, struct xfrm_state___19 *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state___19 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct xfrm_state_offload___19 {
	struct net_device___102 *dev;
	long unsigned int offload_handle;
	unsigned int num_exthdrs;
	u8 flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct xfrm_replay___19;

struct xfrm_type___19;

struct xfrm_mode___19;

struct xfrm_type_offload___19;

struct xfrm_state___19 {
	possible_net_t___104 xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	refcount_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
		u32 output_mark;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	const char *geniv;
	struct xfrm_encap_tmpl *encap;
	xfrm_address_t *coaddr;
	struct xfrm_state___19 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	const struct xfrm_replay___19 *repl;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct tasklet_hrtimer mtimer;
	struct xfrm_state_offload___19 xso;
	long int saved_tmo;
	long unsigned int lastused;
	struct page_frag___458 xfrag;
	const struct xfrm_type___19 *type;
	struct xfrm_mode___19 *inner_mode;
	struct xfrm_mode___19 *inner_mode_iaf;
	struct xfrm_mode___19 *outer_mode;
	const struct xfrm_type_offload___19 *type_offload;
	struct xfrm_sec_ctx___2 *security;
	void *data;
	u32 output_mark_mask;
	u32 if_id;
};

struct tlsdev_ops___102 {
	int (*tls_dev_add)(struct net_device___102 *, struct sock___82 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___102 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___102 *, struct sock___82 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___102 {
	int (*ndo_init)(struct net_device___102 *);
	void (*ndo_uninit)(struct net_device___102 *);
	int (*ndo_open)(struct net_device___102 *);
	int (*ndo_stop)(struct net_device___102 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___103 *, struct net_device___102 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___103 *, struct net_device___102 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___102 *, struct sk_buff___103 *, struct net_device___102 *, select_queue_fallback_t___102);
	void (*ndo_change_rx_flags)(struct net_device___102 *, int);
	void (*ndo_set_rx_mode)(struct net_device___102 *);
	int (*ndo_set_mac_address)(struct net_device___102 *, void *);
	int (*ndo_validate_addr)(struct net_device___102 *);
	int (*ndo_do_ioctl)(struct net_device___102 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___102 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___102 *, int);
	int (*ndo_neigh_setup)(struct net_device___102 *, struct neigh_parms___82 *);
	void (*ndo_tx_timeout)(struct net_device___102 *);
	void (*ndo_get_stats64)(struct net_device___102 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___102 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___102 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___102 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___102 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___102 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___102 *);
	int (*ndo_netpoll_setup)(struct net_device___102 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___102 *);
	int (*ndo_set_vf_mac)(struct net_device___102 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___102 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___102 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___102 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___102 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___102 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___102 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___102 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___102 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___102 *, int, struct sk_buff___103 *);
	int (*ndo_set_vf_guid)(struct net_device___102 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___102 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___102 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___102 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___102 *, const struct sk_buff___103 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___102 *, struct net_device___102 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___102 *, struct net_device___102 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___102 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___102 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___102 *, struct neighbour___82 *);
	void (*ndo_neigh_destroy)(struct net_device___102 *, struct neighbour___82 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___102 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___102 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___102 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___103 *, struct netlink_callback___104 *, struct net_device___102 *, struct net_device___102 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___102 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___102 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___103 *, u32, u32, struct net_device___102 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___102 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___102 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___102 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___102 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___102 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___102 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___102 *, struct net_device___102 *);
	void (*ndo_dfwd_del_station)(struct net_device___102 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___102 *);
	int (*ndo_set_tx_maxrate)(struct net_device___102 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___102 *);
	int (*ndo_change_proto_down)(struct net_device___102 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___102 *, struct sk_buff___103 *);
	void (*ndo_set_rx_headroom)(struct net_device___102 *, int);
	int (*ndo_bpf)(struct net_device___102 *, struct netdev_bpf___102 *);
	int (*ndo_xdp_xmit)(struct net_device___102 *, int, struct xdp_frame___102 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___102 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___102 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___82 {
	possible_net_t___104 net;
	struct net_device___102 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___82 *);
	void (*neigh_cleanup)(struct neighbour___82 *);
	struct neigh_table___82 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___82 {
	u32 (*l3mdev_fib_table)(const struct net_device___102 *);
	struct sk_buff___103 * (*l3mdev_l3_rcv)(struct net_device___102 *, struct sk_buff___103 *, u16);
	struct sk_buff___103 * (*l3mdev_l3_out)(struct net_device___102 *, struct sock___82 *, struct sk_buff___103 *, u16);
	struct dst_entry___82 * (*l3mdev_link_scope_lookup)(const struct net_device___102 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct ndisc_ops___53 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___102 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___102 *, struct neighbour___82 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___102 *, u8, struct neighbour___82 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___102 *, struct sk_buff___103 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___113 *, struct net_device___102 *, const struct prefix_info *, struct inet6_dev___53 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___53;

struct ifacaddr6___24;

struct inet6_dev___53 {
	struct net_device___102 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___53 *mc_list;
	struct ifmcaddr6___53 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___24 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	u8 rndid[8];
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___82 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
};

struct tcf_proto___94;

struct mini_Qdisc___94 {
	struct tcf_proto___94 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___94 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___102 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___113 *, struct net_device___102 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___102 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___102 *, struct list_head *);
	size_t (*get_size)(const struct net_device___102 *);
	int (*fill_info)(struct sk_buff___103 *, const struct net_device___102 *);
	size_t (*get_xstats_size)(const struct net_device___102 *);
	int (*fill_xstats)(struct sk_buff___103 *, const struct net_device___102 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___102 *, struct net_device___102 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___102 *, const struct net_device___102 *);
	int (*fill_slave_info)(struct sk_buff___103 *, const struct net_device___102 *, const struct net_device___102 *);
	struct net___113 * (*get_link_net)(const struct net_device___102 *);
	size_t (*get_linkxstats_size)(const struct net_device___102 *, int);
	int (*fill_linkxstats)(struct sk_buff___103 *, const struct net_device___102 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___102 {
	struct list_head poll_list;
	struct sk_buff_head___102 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___102 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___94 *output_queue;
	struct Qdisc___94 **output_queue_tailp;
	struct sk_buff___103 *completion_queue;
	struct sk_buff_head___102 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___102 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___102 input_pkt_queue;
	struct napi_struct___102 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct nf_hook_state___17 {
	unsigned int hook;
	u_int8_t pf;
	struct net_device___102 *in;
	struct net_device___102 *out;
	struct sock___82 *sk;
	struct net___113 *net;
	int (*okfn)(struct net___113 *, struct sock___82 *, struct sk_buff___103 *);
};

struct nf_nat_hook___17 {
	int (*parse_nat_setup)(struct nf_conn *, enum nf_nat_manip_type, const struct nlattr *);
	void (*decode_session)(struct sk_buff___103 *, struct flowi *);
	unsigned int (*manip_pkt)(struct sk_buff___103 *, struct nf_conn *, enum nf_nat_manip_type, enum ip_conntrack_dir);
};

struct nf_ct_hook___17 {
	int (*update)(struct net___113 *, struct sk_buff___103 *);
	void (*destroy)(struct nf_conntrack *);
	bool (*get_tuple_skb)(struct nf_conntrack_tuple *, const struct sk_buff___103 *);
};

struct nfnl_ct_hook___17 {
	struct nf_conn * (*get_ct)(const struct sk_buff___103 *, enum ip_conntrack_info *);
	size_t (*build_size)(const struct nf_conn *);
	int (*build)(struct sk_buff___103 *, struct nf_conn *, enum ip_conntrack_info, u_int16_t, u_int16_t);
	int (*parse)(const struct nlattr *, struct nf_conn *);
	int (*attach_expect)(const struct nlattr *, struct nf_conn *, u32, u32);
	void (*seq_adjust)(struct sk_buff___103 *, struct nf_conn *, enum ip_conntrack_info, s32);
};

struct pneigh_entry___82;

struct neigh_hash_table___82;

struct neigh_table___82 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___102 *, __u32 *);
	bool (*key_eq)(const struct neighbour___82 *, const void *);
	int (*constructor)(struct neighbour___82 *);
	int (*pconstructor)(struct pneigh_entry___82 *);
	void (*pdestructor)(struct pneigh_entry___82 *);
	void (*proxy_redo)(struct sk_buff___103 *);
	char *id;
	struct neigh_parms___82 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___102 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___82 *nht;
	struct pneigh_entry___82 **phash_buckets;
};

struct neigh_ops___82 {
	int family;
	void (*solicit)(struct neighbour___82 *, struct sk_buff___103 *);
	void (*error_report)(struct neighbour___82 *, struct sk_buff___103 *);
	int (*output)(struct neighbour___82 *, struct sk_buff___103 *);
	int (*connected_output)(struct neighbour___82 *, struct sk_buff___103 *);
};

struct pneigh_entry___82 {
	struct pneigh_entry___82 *next;
	possible_net_t___104 net;
	struct net_device___102 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___82 {
	struct neighbour___82 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct bdi_writeback_congested___247 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___247 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___247 {
	struct bio___247 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___249 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___249 bip_inline_vecs[0];
};

struct bio_set___247 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___247 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___190 {
	struct mem_cgroup___190 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___190 {
	struct lruvec___458 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___190 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___190 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct gnet_dump___94 {
	spinlock_t *lock;
	struct sk_buff___103 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___94;

struct Qdisc_ops___94 {
	struct Qdisc_ops___94 *next;
	const struct Qdisc_class_ops___94 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___103 *, struct Qdisc___94 *, struct sk_buff___103 **);
	struct sk_buff___103 * (*dequeue)(struct Qdisc___94 *);
	struct sk_buff___103 * (*peek)(struct Qdisc___94 *);
	int (*init)(struct Qdisc___94 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___94 *);
	void (*destroy)(struct Qdisc___94 *);
	int (*change)(struct Qdisc___94 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___94 *);
	int (*change_tx_queue_len)(struct Qdisc___94 *, unsigned int);
	int (*dump)(struct Qdisc___94 *, struct sk_buff___103 *);
	int (*dump_stats)(struct Qdisc___94 *, struct gnet_dump___94 *);
	void (*ingress_block_set)(struct Qdisc___94 *, u32);
	void (*egress_block_set)(struct Qdisc___94 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___94 *);
	u32 (*egress_block_get)(struct Qdisc___94 *);
	struct module___383 *owner;
};

struct tcf_block___94;

struct Qdisc_class_ops___94 {
	unsigned int flags;
	struct netdev_queue___102 * (*select_queue)(struct Qdisc___94 *, struct tcmsg *);
	int (*graft)(struct Qdisc___94 *, long unsigned int, struct Qdisc___94 *, struct Qdisc___94 **, struct netlink_ext_ack *);
	struct Qdisc___94 * (*leaf)(struct Qdisc___94 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___94 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___94 *, u32);
	int (*change)(struct Qdisc___94 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___94 *, long unsigned int);
	void (*walk)(struct Qdisc___94 *, struct qdisc_walker *);
	struct tcf_block___94 * (*tcf_block)(struct Qdisc___94 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___94 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___94 *, long unsigned int);
	int (*dump)(struct Qdisc___94 *, long unsigned int, struct sk_buff___103 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___94 *, long unsigned int, struct gnet_dump___94 *);
};

struct tcf_chain___94;

struct tcf_block___94 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___113 *net;
	struct Qdisc___94 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___94 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___94;

struct tcf_proto_ops___94;

struct tcf_proto___94 {
	struct tcf_proto___94 *next;
	void *root;
	int (*classify)(struct sk_buff___103 *, const struct tcf_proto___94 *, struct tcf_result___94 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___94 *ops;
	struct tcf_chain___94 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___94 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___94 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___94 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___103 *, const struct tcf_proto___94 *, struct tcf_result___94 *);
	int (*init)(struct tcf_proto___94 *);
	void (*destroy)(struct tcf_proto___94 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___94 *, u32);
	void (*put)(struct tcf_proto___94 *, void *);
	int (*change)(struct net___113 *, struct sk_buff___103 *, struct tcf_proto___94 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___94 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___94 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___94 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___113 *, struct tcf_chain___94 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___113 *, struct tcf_proto___94 *, void *, struct sk_buff___103 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___103 *, struct net___113 *, void *);
	struct module___383 *owner;
	int flags;
};

struct tcf_chain___94 {
	struct mutex filter_chain_lock;
	struct tcf_proto___94 *filter_chain;
	struct list_head list;
	struct tcf_block___94 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___94 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___82 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___92 *prog;
};

struct bpf_redirect_info___92 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___307 *map;
	struct bpf_map___307 *map_to_flush;
	u32 kern_flags;
};

struct fib_rule___82 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___82 *ctarget;
	struct net___113 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___82 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___82 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___65;

struct timewait_sock_ops___61;

struct proto___82 {
	void (*close)(struct sock___82 *, long int);
	int (*pre_connect)(struct sock___82 *, struct sockaddr *, int);
	int (*connect)(struct sock___82 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___82 *, int);
	struct sock___82 * (*accept)(struct sock___82 *, int, int *, bool);
	int (*ioctl)(struct sock___82 *, int, long unsigned int);
	int (*init)(struct sock___82 *);
	void (*destroy)(struct sock___82 *);
	void (*shutdown)(struct sock___82 *, int);
	int (*setsockopt)(struct sock___82 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___82 *, int, int, char *, int *);
	void (*keepalive)(struct sock___82 *, int);
	int (*sendmsg)(struct sock___82 *, struct msghdr___85 *, size_t);
	int (*recvmsg)(struct sock___82 *, struct msghdr___85 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___82 *, struct page___458 *, int, size_t, int);
	int (*bind)(struct sock___82 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___82 *, struct sk_buff___103 *);
	void (*release_cb)(struct sock___82 *);
	int (*hash)(struct sock___82 *);
	void (*unhash)(struct sock___82 *);
	void (*rehash)(struct sock___82 *);
	int (*get_port)(struct sock___82 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___82 *);
	bool (*stream_memory_read)(const struct sock___82 *);
	void (*enter_memory_pressure)(struct sock___82 *);
	void (*leave_memory_pressure)(struct sock___82 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___65 *rsk_prot;
	struct timewait_sock_ops___61 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___383 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___82 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct xfrm_policy_queue___19 {
	struct sk_buff_head___102 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___19 {
	possible_net_t___104 xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	refcount_t refcnt;
	struct timer_list timer;
	atomic_t genid;
	u32 priority;
	u32 index;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___19 polq;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx___2 *security;
	struct xfrm_tmpl xfrm_vec[6];
	struct callback_head rcu;
	u32 if_id;
};

struct request_sock___66;

struct request_sock_ops___65 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___82 *, struct request_sock___66 *);
	void (*send_ack)(const struct sock___82 *, struct sk_buff___103 *, struct request_sock___66 *);
	void (*send_reset)(const struct sock___82 *, struct sk_buff___103 *);
	void (*destructor)(struct request_sock___66 *);
	void (*syn_ack_timeout)(const struct request_sock___66 *);
};

struct timewait_sock_ops___61 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___82 *, struct sock___82 *, void *);
	void (*twsk_destructor)(struct sock___82 *);
};

struct request_sock___66 {
	struct sock_common___82 __req_common;
	struct request_sock___66 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___65 *rsk_ops;
	struct sock___82 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct inet_cork___22 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___82 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
	__u16 gso_size;
	u64 transmit_time;
};

struct inet_cork_full___22 {
	struct inet_cork___22 base;
	struct flowi fl;
};

struct ipv6_pinfo___22;

struct inet_sock___22 {
	struct sock___82 sk;
	struct ipv6_pinfo___22 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	__be16 inet_sport;
	__u16 inet_id;
	struct ip_options_rcu *inet_opt;
	int rx_dst_ifindex;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 bind_address_no_port: 1;
	__u8 defer_connect: 1;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___22 cork;
};

struct ipv6_fl_socklist___21;

struct ipv6_pinfo___22 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
			__u16 recvfragsize: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 repflow: 1;
	__u16 pmtudisc: 3;
	__u16 padding: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u16 autoflowlabel: 1;
	__u16 autoflowlabel_set: 1;
	__u8 min_hopcount;
	__u8 tclass;
	__be32 rcv_flowinfo;
	__u32 dst_cookie;
	__u32 rx_dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___21 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___103 *pktoptions;
	struct sk_buff___103 *rxpmtu;
	struct inet6_cork cork;
};

struct ip6_flowlabel___21;

struct ipv6_fl_socklist___21 {
	struct ipv6_fl_socklist___21 *next;
	struct ip6_flowlabel___21 *fl;
	struct callback_head rcu;
};

struct ifmcaddr6___53 {
	struct in6_addr mca_addr;
	struct inet6_dev___53 *idev;
	struct ifmcaddr6___53 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___24 {
	struct in6_addr aca_addr;
	struct fib6_info___24 *aca_rt;
	struct ifacaddr6___24 *aca_next;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct ip6_ra_chain___53 {
	struct ip6_ra_chain___53 *next;
	struct sock___82 *sk;
	int sel;
	void (*destructor)(struct sock___82 *);
};

struct ip6_flowlabel___21 {
	struct ip6_flowlabel___21 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___255 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___113 *fl_net;
};

struct rtable___18 {
	struct dst_entry___82 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	__be32 rt_gateway;
	u32 rt_mtu_locked: 1;
	u32 rt_pmtu: 31;
	struct list_head rt_uncached;
	struct uncached_list *rt_uncached_list;
};

struct xfrm_replay___19 {
	void (*advance)(struct xfrm_state___19 *, __be32);
	int (*check)(struct xfrm_state___19 *, struct sk_buff___103 *, __be32);
	int (*recheck)(struct xfrm_state___19 *, struct sk_buff___103 *, __be32);
	void (*notify)(struct xfrm_state___19 *, int);
	int (*overflow)(struct xfrm_state___19 *, struct sk_buff___103 *);
};

struct xfrm_type___19 {
	char *description;
	struct module___383 *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___19 *);
	void (*destructor)(struct xfrm_state___19 *);
	int (*input)(struct xfrm_state___19 *, struct sk_buff___103 *);
	int (*output)(struct xfrm_state___19 *, struct sk_buff___103 *);
	int (*reject)(struct xfrm_state___19 *, struct sk_buff___103 *, const struct flowi *);
	int (*hdr_offset)(struct xfrm_state___19 *, struct sk_buff___103 *, u8 **);
	u32 (*get_mtu)(struct xfrm_state___19 *, int);
};

struct xfrm_state_afinfo___19;

struct xfrm_mode___19 {
	int (*input2)(struct xfrm_state___19 *, struct sk_buff___103 *);
	int (*input)(struct xfrm_state___19 *, struct sk_buff___103 *);
	int (*output2)(struct xfrm_state___19 *, struct sk_buff___103 *);
	int (*output)(struct xfrm_state___19 *, struct sk_buff___103 *);
	struct sk_buff___103 * (*gso_segment)(struct xfrm_state___19 *, struct sk_buff___103 *, netdev_features_t);
	void (*xmit)(struct xfrm_state___19 *, struct sk_buff___103 *);
	struct xfrm_state_afinfo___19 *afinfo;
	struct module___383 *owner;
	unsigned int encap;
	int flags;
};

struct xfrm_type_offload___19 {
	char *description;
	struct module___383 *owner;
	u8 proto;
	void (*encap)(struct xfrm_state___19 *, struct sk_buff___103 *);
	int (*input_tail)(struct xfrm_state___19 *, struct sk_buff___103 *);
	int (*xmit)(struct xfrm_state___19 *, struct sk_buff___103 *, netdev_features_t);
};

struct xfrm_state_afinfo___19 {
	unsigned int family;
	unsigned int proto;
	__be16 eth_proto;
	struct module___383 *owner;
	const struct xfrm_type___19 *type_map[256];
	const struct xfrm_type_offload___19 *type_offload_map[256];
	struct xfrm_mode___19 *mode_map[5];
	int (*init_flags)(struct xfrm_state___19 *);
	void (*init_tempsel)(struct xfrm_selector *, const struct flowi *);
	void (*init_temprop)(struct xfrm_state___19 *, const struct xfrm_tmpl *, const xfrm_address_t *, const xfrm_address_t *);
	int (*tmpl_sort)(struct xfrm_tmpl **, struct xfrm_tmpl **, int);
	int (*state_sort)(struct xfrm_state___19 **, struct xfrm_state___19 **, int);
	int (*output)(struct net___113 *, struct sock___82 *, struct sk_buff___103 *);
	int (*output_finish)(struct sock___82 *, struct sk_buff___103 *);
	int (*extract_input)(struct xfrm_state___19 *, struct sk_buff___103 *);
	int (*extract_output)(struct xfrm_state___19 *, struct sk_buff___103 *);
	int (*transport_finish)(struct sk_buff___103 *, int);
	void (*local_error)(struct sk_buff___103 *, u32);
};

struct xfrm_input_afinfo {
	unsigned int family;
	int (*callback)(struct sk_buff___101 *, u8, int);
};

struct xfrm4_protocol {
	int (*handler)(struct sk_buff___101 *);
	int (*input_handler)(struct sk_buff___101 *, int, __be32, int);
	int (*cb_handler)(struct sk_buff___101 *, int);
	int (*err_handler)(struct sk_buff___101 *, u32);
	struct xfrm4_protocol *next;
	int priority;
};

struct module___384;

struct file___458;

struct kiocb___458;

struct iov_iter___225;

struct poll_table_struct___297;

struct vm_area_struct___459;

struct inode___458;

struct file_lock___458;

struct page___459;

struct pipe_inode_info___139;

struct seq_file___397;

struct file_operations___458 {
	struct module___384 *owner;
	loff_t (*llseek)(struct file___458 *, loff_t, int);
	ssize_t (*read)(struct file___458 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___458 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___458 *, struct iov_iter___225 *);
	ssize_t (*write_iter)(struct kiocb___458 *, struct iov_iter___225 *);
	int (*iopoll)(struct kiocb___458 *, bool);
	int (*iterate)(struct file___458 *, struct dir_context *);
	int (*iterate_shared)(struct file___458 *, struct dir_context *);
	__poll_t (*poll)(struct file___458 *, struct poll_table_struct___297 *);
	long int (*unlocked_ioctl)(struct file___458 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___458 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___458 *, struct vm_area_struct___459 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___458 *, struct file___458 *);
	int (*flush)(struct file___458 *, fl_owner_t);
	int (*release)(struct inode___458 *, struct file___458 *);
	int (*fsync)(struct file___458 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___458 *, int);
	int (*lock)(struct file___458 *, int, struct file_lock___458 *);
	ssize_t (*sendpage)(struct file___458 *, struct page___459 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___458 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___458 *, int, struct file_lock___458 *);
	ssize_t (*splice_write)(struct pipe_inode_info___139 *, struct file___458 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___458 *, loff_t *, struct pipe_inode_info___139 *, size_t, unsigned int);
	int (*setlease)(struct file___458 *, long int, struct file_lock___458 **, void **);
	long int (*fallocate)(struct file___458 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___397 *, struct file___458 *);
	ssize_t (*copy_file_range)(struct file___458 *, loff_t, struct file___458 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___458 *, loff_t, struct file___458 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___458 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___459 {
	u64 seqnum;
	struct vm_area_struct___459 *vmas[4];
};

struct page_frag___459 {
	struct page___459 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___459;

struct mem_cgroup___191;

struct pid___256;

struct cred___426;

struct nsproxy___353;

struct signal_struct___333;

struct bio_list___248;

struct backing_dev_info___248;

struct css_set___307;

struct vm_struct___362;

struct task_struct___460 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___460 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___459 *mm;
	struct mm_struct___459 *active_mm;
	struct vmacache___459 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___460 *real_parent;
	struct task_struct___460 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___460 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___191 *active_memcg;
	long int rh_reserved2;
	struct pid___256 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___256 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___256 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___426 *ptracer_cred;
	const struct cred___426 *real_cred;
	const struct cred___426 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___353 *nsproxy;
	struct signal_struct___333 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___460 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___248 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___248 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___307 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___139 *splice_pipe;
	struct page_frag___459 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___191 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___460 *oom_reaper_list;
	struct vm_struct___362 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___156 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___459 *pgtable_t___459;

struct address_space___458;

struct dev_pagemap___446;

struct page___459 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___458 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___459 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___459 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___459 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___446 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___191 *mem_cgroup;
};

struct pglist_data___459;

struct lruvec___459 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___459 *pgdat;
};

struct zone___459 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___459 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___459 {
	struct zone___459 *zone;
	int zone_idx;
};

struct zonelist___459 {
	struct zoneref___459 _zonerefs[25];
};

struct pglist_data___459 {
	struct zone___459 node_zones[3];
	struct zonelist___459 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___460 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___460 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___459 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___460 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___460 *owner;
};

struct secondary_data___460 {
	void *stack;
	struct task_struct___460 *task;
	long int status;
};

struct blocking_notifier_head___459 {
	struct rw_semaphore___460 rwsem;
	struct notifier_block *head;
};

struct cgroup___307;

struct cgroup_subsys___307;

struct cgroup_subsys_state___307 {
	struct cgroup___307 *cgroup;
	struct cgroup_subsys___307 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___307 *parent;
};

struct kernfs_node___453;

struct cgroup_file___307 {
	struct kernfs_node___453 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___191;

struct mem_cgroup___191 {
	struct cgroup_subsys_state___307 css;
	struct mem_cgroup_id___13 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___307 events_file;
	struct cgroup_file___307 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___460 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___191 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct key___426;

struct ucounts___323;

struct user_namespace___323 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___323 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___29 ns;
	long unsigned int flags;
	struct key___426 *persistent_keyring_register;
	struct rw_semaphore___460 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___323 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dentry___458;

struct path___459 {
	struct vfsmount *mnt;
	struct dentry___458 *dentry;
};

struct fown_struct___256 {
	rwlock_t lock;
	struct pid___256 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___458 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___459 f_path;
	struct inode___458 *f_inode;
	const struct file_operations___458 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___256 f_owner;
	const struct cred___426 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___458 *f_mapping;
	errseq_t f_wb_err;
};

struct user_struct___426;

struct cred___426 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___426 *session_keyring;
	struct key___426 *process_keyring;
	struct key___426 *thread_keyring;
	struct key___426 *request_key_auth;
	void *security;
	struct user_struct___426 *user;
	struct user_namespace___323 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct pid_namespace___256;

struct upid___256 {
	int nr;
	struct pid_namespace___256 *ns;
};

struct pid_namespace___256 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___460 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___256 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___458 *proc_self;
	struct dentry___458 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___323 *user_ns;
	struct ucounts___323 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___29 ns;
};

struct pid___256 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___256 numbers[1];
};

struct user_struct___426 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___426 *uid_keyring;
	struct key___426 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___446;

struct vm_area_struct___459 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___459 *vm_next;
	struct vm_area_struct___459 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___459 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___446 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___458 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___459;

struct mm_struct___459 {
	struct {
		struct vm_area_struct___459 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___458 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___460 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___459 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___460 *owner;
		struct user_namespace___323 *user_ns;
		struct file___458 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___459 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct net___114;

struct cgroup_namespace___307;

struct nsproxy___353 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___256 *pid_ns_for_children;
	struct net___114 *net_ns;
	struct cgroup_namespace___307 *cgroup_ns;
};

struct signal_struct___333 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___460 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___460 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___256 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___256 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___459 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___256 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___248;

struct bio_list___248 {
	struct bio___248 *head;
	struct bio___248 *tail;
};

struct bdi_writeback_congested___248;

struct bdi_writeback___248 {
	struct backing_dev_info___248 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___248 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___307 *memcg_css;
	struct cgroup_subsys_state___307 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___426;

struct backing_dev_info___248 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___248 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___426 *dev;
	struct device___426 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___458 *debug_dir;
	struct dentry___458 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___307 {
	struct cgroup_subsys_state___307 *subsys[13];
	refcount_t refcount;
	struct css_set___307 *dom_cset;
	struct cgroup___307 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___307 *mg_src_cgrp;
	struct cgroup___307 *mg_dst_cgrp;
	struct css_set___307 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___458;

struct pipe_buffer___139;

struct pipe_inode_info___139 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___459 *tmp_page;
	struct fasync_struct___458 *fasync_readers;
	struct fasync_struct___458 *fasync_writers;
	struct pipe_buffer___139 *bufs;
	struct user_struct___426 *user;
};

struct vm_struct___362 {
	struct vm_struct___362 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___459 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___345 {
	struct task_struct___460 task;
	long unsigned int stack[8192];
};

struct address_space_operations___458;

struct address_space___458 {
	struct inode___458 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___460 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___458 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___446)(struct vm_area_struct___459 *, long unsigned int, const struct page___459 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___446)(struct page___459 *, void *);

struct dev_pagemap___446 {
	dev_page_fault_t___446 page_fault;
	dev_page_free_t___446 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___426 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct vm_fault___446;

struct vm_operations_struct___446 {
	void (*open)(struct vm_area_struct___459 *);
	void (*close)(struct vm_area_struct___459 *);
	int (*split)(struct vm_area_struct___459 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___459 *);
	vm_fault_t (*fault)(struct vm_fault___446 *);
	vm_fault_t (*huge_fault)(struct vm_fault___446 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___446 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___459 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___446 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___446 *);
	int (*access)(struct vm_area_struct___459 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___459 *);
	int (*set_policy)(struct vm_area_struct___459 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___459 *, long unsigned int);
	struct page___459 * (*find_special_page)(struct vm_area_struct___459 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___459 {
	struct task_struct___460 *task;
	struct core_thread___459 *next;
};

struct core_state___459 {
	atomic_t nr_threads;
	struct core_thread___459 dumper;
	struct completion startup;
};

struct vm_fault___446 {
	struct vm_area_struct___459 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___459 *cow_page;
	struct mem_cgroup___191 *memcg;
	struct page___459 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___459 prealloc_pte;
};

struct kset___445;

struct kobj_type___445;

struct kobject___446 {
	const char *name;
	struct list_head entry;
	struct kobject___446 *parent;
	struct kset___445 *kset;
	struct kobj_type___445 *ktype;
	struct kernfs_node___453 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___384 {
	struct kobject___446 kobj;
	struct module___384 *mod;
	struct kobject___446 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___384 {
	struct module___384 *mod;
	struct latch_tree_node node;
};

struct module_layout___384 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___384 mtn;
};

struct module_attribute___384;

struct kernel_param___384;

struct module___384 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___384 mkobj;
	struct module_attribute___384 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___446 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___384 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___384 core_layout;
	struct module_layout___384 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide38;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide39;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bio_vec___250 {
	struct page___459 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___225 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___250 *bvec;
		struct pipe_inode_info___139 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct msghdr___86 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___225 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___458 *msg_iocb;
};

struct kiocb___458 {
	struct file___458 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___458 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dentry_operations___458;

struct super_block___458;

struct dentry___458 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___458 *d_parent;
	struct qstr d_name;
	struct inode___458 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___458 *d_op;
	struct super_block___458 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___458;

struct block_device___458;

struct inode___458 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___458 *i_op;
	struct super_block___458 *i_sb;
	struct address_space___458 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___460 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___248 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___458 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___458 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___139 *i_pipe;
		struct block_device___458 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___458 {
	int (*d_revalidate)(struct dentry___458 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___458 *, unsigned int);
	int (*d_hash)(const struct dentry___458 *, struct qstr *);
	int (*d_compare)(const struct dentry___458 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___458 *);
	int (*d_init)(struct dentry___458 *);
	void (*d_release)(struct dentry___458 *);
	void (*d_prune)(struct dentry___458 *);
	void (*d_iput)(struct dentry___458 *, struct inode___458 *);
	char * (*d_dname)(struct dentry___458 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___459 *);
	int (*d_manage)(const struct path___459 *, bool);
	struct dentry___458 * (*d_real)(struct dentry___458 *, const struct inode___458 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___458;

struct mem_dqinfo___458 {
	struct quota_format_type___458 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___458;

struct quota_info___458 {
	unsigned int flags;
	struct rw_semaphore___460 dqio_sem;
	struct inode___458 *files[3];
	struct mem_dqinfo___458 info[3];
	const struct quota_format_ops___458 *ops[3];
};

struct rcuwait___458 {
	struct task_struct___460 *task;
};

struct percpu_rw_semaphore___458 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___460 rw_sem;
	struct rcuwait___458 writer;
	int readers_block;
};

struct sb_writers___458 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___458 rw_sem[3];
};

struct shrink_control___191;

struct shrinker___191 {
	long unsigned int (*count_objects)(struct shrinker___191 *, struct shrink_control___191 *);
	long unsigned int (*scan_objects)(struct shrinker___191 *, struct shrink_control___191 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___458;

struct super_operations___458;

struct dquot_operations___458;

struct quotactl_ops___458;

struct super_block___458 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___458 *s_type;
	const struct super_operations___458 *s_op;
	const struct dquot_operations___458 *dq_op;
	const struct quotactl_ops___458 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___458 *s_root;
	struct rw_semaphore___460 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___458 *s_bdev;
	struct backing_dev_info___248 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___458 s_dquot;
	struct sb_writers___458 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___458 *s_d_op;
	int cleancache_poolid;
	struct shrinker___191 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___323 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___191 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___191 *memcg;
};

struct iattr___458 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___458 *ia_file;
};

struct dquot___458 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___458 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___458 {
	int qf_fmt_id;
	const struct quota_format_ops___458 *qf_ops;
	struct module___384 *qf_owner;
	struct quota_format_type___458 *qf_next;
};

struct quota_format_ops___458 {
	int (*check_quota_file)(struct super_block___458 *, int);
	int (*read_file_info)(struct super_block___458 *, int);
	int (*write_file_info)(struct super_block___458 *, int);
	int (*free_file_info)(struct super_block___458 *, int);
	int (*read_dqblk)(struct dquot___458 *);
	int (*commit_dqblk)(struct dquot___458 *);
	int (*release_dqblk)(struct dquot___458 *);
	int (*get_next_id)(struct super_block___458 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___458 {
	int (*write_dquot)(struct dquot___458 *);
	struct dquot___458 * (*alloc_dquot)(struct super_block___458 *, int);
	void (*destroy_dquot)(struct dquot___458 *);
	int (*acquire_dquot)(struct dquot___458 *);
	int (*release_dquot)(struct dquot___458 *);
	int (*mark_dirty)(struct dquot___458 *);
	int (*write_info)(struct super_block___458 *, int);
	qsize_t * (*get_reserved_space)(struct inode___458 *);
	int (*get_projid)(struct inode___458 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___458 *, qsize_t *);
	int (*get_next_id)(struct super_block___458 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___458 {
	int (*quota_on)(struct super_block___458 *, int, int, const struct path___459 *);
	int (*quota_off)(struct super_block___458 *, int);
	int (*quota_enable)(struct super_block___458 *, unsigned int);
	int (*quota_disable)(struct super_block___458 *, unsigned int);
	int (*quota_sync)(struct super_block___458 *, int);
	int (*set_info)(struct super_block___458 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___458 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___458 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___458 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___458 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___458 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___211;

struct address_space_operations___458 {
	int (*writepage)(struct page___459 *, struct writeback_control___211 *);
	int (*readpage)(struct file___458 *, struct page___459 *);
	int (*writepages)(struct address_space___458 *, struct writeback_control___211 *);
	int (*set_page_dirty)(struct page___459 *);
	int (*readpages)(struct file___458 *, struct address_space___458 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___458 *, struct address_space___458 *, loff_t, unsigned int, unsigned int, struct page___459 **, void **);
	int (*write_end)(struct file___458 *, struct address_space___458 *, loff_t, unsigned int, unsigned int, struct page___459 *, void *);
	sector_t (*bmap)(struct address_space___458 *, sector_t);
	void (*invalidatepage)(struct page___459 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___459 *, gfp_t);
	void (*freepage)(struct page___459 *);
	ssize_t (*direct_IO)(struct kiocb___458 *, struct iov_iter___225 *);
	int (*migratepage)(struct address_space___458 *, struct page___459 *, struct page___459 *, enum migrate_mode);
	bool (*isolate_page)(struct page___459 *, isolate_mode_t);
	void (*putback_page)(struct page___459 *);
	int (*launder_page)(struct page___459 *);
	int (*is_partially_uptodate)(struct page___459 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___459 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___458 *, struct page___459 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___458 *, sector_t *);
	void (*swap_deactivate)(struct file___458 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___211 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___248 *wb;
	struct inode___458 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___458 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___458 *bd_inode;
	struct super_block___458 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___458 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___248 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___458 {
	struct dentry___458 * (*lookup)(struct inode___458 *, struct dentry___458 *, unsigned int);
	const char * (*get_link)(struct dentry___458 *, struct inode___458 *, struct delayed_call *);
	int (*permission)(struct inode___458 *, int);
	struct posix_acl * (*get_acl)(struct inode___458 *, int);
	int (*readlink)(struct dentry___458 *, char *, int);
	int (*create)(struct inode___458 *, struct dentry___458 *, umode_t, bool);
	int (*link)(struct dentry___458 *, struct inode___458 *, struct dentry___458 *);
	int (*unlink)(struct inode___458 *, struct dentry___458 *);
	int (*symlink)(struct inode___458 *, struct dentry___458 *, const char *);
	int (*mkdir)(struct inode___458 *, struct dentry___458 *, umode_t);
	int (*rmdir)(struct inode___458 *, struct dentry___458 *);
	int (*mknod)(struct inode___458 *, struct dentry___458 *, umode_t, dev_t);
	int (*rename)(struct inode___458 *, struct dentry___458 *, struct inode___458 *, struct dentry___458 *, unsigned int);
	int (*setattr)(struct dentry___458 *, struct iattr___458 *);
	int (*getattr)(const struct path___459 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___458 *, char *, size_t);
	int (*fiemap)(struct inode___458 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___458 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___458 *, struct dentry___458 *, struct file___458 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___458 *, struct dentry___458 *, umode_t);
	int (*set_acl)(struct inode___458 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___458 {
	void (*fl_copy_lock)(struct file_lock___458 *, struct file_lock___458 *);
	void (*fl_release_private)(struct file_lock___458 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___458;

struct file_lock___458 {
	struct file_lock___458 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___458 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___458 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___458 *fl_ops;
	const struct lock_manager_operations___458 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___458 {
	int (*lm_compare_owner)(struct file_lock___458 *, struct file_lock___458 *);
	long unsigned int (*lm_owner_key)(struct file_lock___458 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___458 *);
	int (*lm_grant)(struct file_lock___458 *, int);
	bool (*lm_break)(struct file_lock___458 *);
	int (*lm_change)(struct file_lock___458 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___458 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___458 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___458 *fa_next;
	struct file___458 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___458 {
	const char *name;
	int fs_flags;
	struct dentry___458 * (*mount)(struct file_system_type___458 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___458 *);
	struct module___384 *owner;
	struct file_system_type___458 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___458 {
	struct inode___458 * (*alloc_inode)(struct super_block___458 *);
	void (*destroy_inode)(struct inode___458 *);
	void (*dirty_inode)(struct inode___458 *, int);
	int (*write_inode)(struct inode___458 *, struct writeback_control___211 *);
	int (*drop_inode)(struct inode___458 *);
	void (*evict_inode)(struct inode___458 *);
	void (*put_super)(struct super_block___458 *);
	int (*sync_fs)(struct super_block___458 *, int);
	int (*freeze_super)(struct super_block___458 *);
	int (*freeze_fs)(struct super_block___458 *);
	int (*thaw_super)(struct super_block___458 *);
	int (*unfreeze_fs)(struct super_block___458 *);
	int (*statfs)(struct dentry___458 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___458 *, int *, char *);
	void (*umount_begin)(struct super_block___458 *);
	int (*show_options)(struct seq_file___397 *, struct dentry___458 *);
	int (*show_devname)(struct seq_file___397 *, struct dentry___458 *);
	int (*show_path)(struct seq_file___397 *, struct dentry___458 *);
	int (*show_stats)(struct seq_file___397 *, struct dentry___458 *);
	ssize_t (*quota_read)(struct super_block___458 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___458 *, int, const char *, size_t, loff_t);
	struct dquot___458 ** (*get_dquots)(struct inode___458 *);
	int (*bdev_try_to_free_page)(struct super_block___458 *, struct page___459 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___458 *, struct shrink_control___191 *);
	long int (*free_cached_objects)(struct super_block___458 *, struct shrink_control___191 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___307)(struct file___458 *, wait_queue_head_t *, struct poll_table_struct___297 *);

struct poll_table_struct___297 {
	poll_queue_proc___307 _qproc;
	__poll_t _key;
};

struct seq_operations___397;

struct seq_file___397 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___397 *op;
	int poll_event;
	const struct file___458 *file;
	void *private;
};

typedef void bio_end_io_t___248(struct bio___248 *);

struct bio_integrity_payload___248;

struct bio_set___248;

struct bio___248 {
	struct bio___248 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___248 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___248 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___250 *bi_io_vec;
	struct bio_set___248 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___250 bi_inline_vecs[0];
};

struct socket_wq___84 {
	wait_queue_head_t wait;
	struct fasync_struct___458 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct sock___83;

struct proto_ops___84;

struct socket___85 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___84 *wq;
	struct file___458 *file;
	struct sock___83 *sk;
	const struct proto_ops___84 *ops;
};

typedef struct {
	struct net___114 *net;
} possible_net_t___105;

struct proto___83;

struct sock_common___83 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___83 *skc_prot;
	possible_net_t___105 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___83 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___104;

struct sk_buff_head___103 {
	struct sk_buff___104 *next;
	struct sk_buff___104 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___83;

struct xfrm_policy___20;

struct dst_entry___83;

struct net_device___103;

struct sock___83 {
	struct sock_common___83 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___103 sk_error_queue;
	struct sk_buff_head___103 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___104 *head;
		struct sk_buff___104 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___83 *sk_filter;
	union {
		struct socket_wq___84 *sk_wq;
		struct socket_wq___84 *sk_wq_raw;
	};
	struct xfrm_policy___20 *sk_policy[2];
	struct dst_entry___83 *sk_rx_dst;
	struct dst_entry___83 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___104 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___103 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___459 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___83 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___256 *sk_peer_pid;
	const struct cred___426 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___85 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___191 *sk_memcg;
	void (*sk_state_change)(struct sock___83 *);
	void (*sk_data_ready)(struct sock___83 *);
	void (*sk_write_space)(struct sock___83 *);
	void (*sk_error_report)(struct sock___83 *);
	int (*sk_backlog_rcv)(struct sock___83 *, struct sk_buff___104 *);
	struct sk_buff___104 * (*sk_validate_xmit_skb)(struct sock___83 *, struct net_device___103 *, struct sk_buff___104 *);
	void (*sk_destruct)(struct sock___83 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

typedef int (*sk_read_actor_t___83)(read_descriptor_t *, struct sk_buff___104 *, unsigned int, size_t);

struct proto_ops___84 {
	int family;
	struct module___384 *owner;
	int (*release)(struct socket___85 *);
	int (*bind)(struct socket___85 *, struct sockaddr *, int);
	int (*connect)(struct socket___85 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___85 *, struct socket___85 *);
	int (*accept)(struct socket___85 *, struct socket___85 *, int, bool);
	int (*getname)(struct socket___85 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___458 *, struct socket___85 *, struct poll_table_struct___297 *);
	int (*ioctl)(struct socket___85 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___85 *, int);
	int (*shutdown)(struct socket___85 *, int);
	int (*setsockopt)(struct socket___85 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___85 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___85 *, struct msghdr___86 *, size_t);
	int (*recvmsg)(struct socket___85 *, struct msghdr___86 *, size_t, int);
	int (*mmap)(struct file___458 *, struct socket___85 *, struct vm_area_struct___459 *);
	ssize_t (*sendpage)(struct socket___85 *, struct page___459 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___85 *, loff_t *, struct pipe_inode_info___139 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___83 *, int);
	int (*peek_len)(struct socket___85 *);
	int (*read_sock)(struct sock___83 *, read_descriptor_t *, sk_read_actor_t___83);
	int (*sendpage_locked)(struct sock___83 *, struct page___459 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___83 *, struct msghdr___86 *, size_t);
	int (*set_rcvlowat)(struct sock___83 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct sec_path___20;

struct nf_bridge_info___103;

struct sk_buff___104 {
	union {
		struct {
			struct sk_buff___104 *next;
			struct sk_buff___104 *prev;
			union {
				struct net_device___103 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___83 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___104 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path___20 *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___103 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___103;

struct netns_frags___103 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___103 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ip_ra_chain___49;

struct fib_rules_ops___83;

struct fib_notifier_ops___84;

struct netns_ipv4___103 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___49 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___83 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___83 *fibnl;
	struct sock___83 **icmp_sk;
	struct sock___83 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___83 **tcp_sk;
	struct netns_frags___103 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___83 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___84 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___84 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___83;

struct dst_ops___114 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___114 *);
	struct dst_entry___83 * (*check)(struct dst_entry___83 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___83 *);
	unsigned int (*mtu)(const struct dst_entry___83 *);
	u32 * (*cow_metrics)(struct dst_entry___83 *, long unsigned int);
	void (*destroy)(struct dst_entry___83 *);
	void (*ifdown)(struct dst_entry___83 *, struct net_device___103 *, int);
	struct dst_entry___83 * (*negative_advice)(struct dst_entry___83 *);
	void (*link_failure)(struct sk_buff___104 *);
	void (*update_pmtu)(struct dst_entry___83 *, struct sock___83 *, struct sk_buff___104 *, u32);
	void (*redirect)(struct dst_entry___83 *, struct sock___83 *, struct sk_buff___104 *);
	int (*local_out)(struct net___114 *, struct sock___83 *, struct sk_buff___104 *);
	struct neighbour___83 * (*neigh_lookup)(const struct dst_entry___83 *, struct sk_buff___104 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___83 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_info___25;

struct rt6_info___25;

struct fib6_table___25;

struct netns_ipv6___114 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___103 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info___25 *fib6_null_entry;
	struct rt6_info___25 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___25 *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___114 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info___25 *ip6_prohibit_entry;
	struct rt6_info___25 *ip6_blk_hole_entry;
	struct fib6_table___25 *fib6_local_tbl;
	struct fib_rules_ops___83 *fib6_rules_ops;
	struct sock___83 **icmp_sk;
	struct sock___83 *ndisc_sk;
	struct sock___83 *tcp_sk;
	struct sock___83 *igmp_sk;
	struct sock___83 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___83 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___84 *notifier_ops;
	struct fib_notifier_ops___84 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___84 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___83 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct nf_hook_entries___18;

struct netns_nf___19 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_queue_handler *queue_handler;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header *nf_log_dir_header;
	struct nf_hook_entries___18 *hooks_ipv4[5];
	struct nf_hook_entries___18 *hooks_ipv6[5];
	struct nf_hook_entries___18 *hooks_arp[3];
	struct nf_hook_entries___18 *hooks_bridge[5];
	bool defrag_ipv4;
	bool defrag_ipv6;
};

struct netns_nf_frag___103 {
	struct netns_frags___103 frags;
};

struct netns_xfrm___114 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___83 *nlsk;
	struct sock___83 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___114 xfrm4_dst_ops;
	struct dst_ops___114 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___93;

struct net___114 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___323 *user_ns;
	struct ucounts___323 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___29 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___83 *rtnl;
	struct sock___83 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___103 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___103 ipv4;
	struct netns_ipv6___114 ipv6;
	struct netns_sctp___84 sctp;
	struct netns_nf___19 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___103 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___83 *nfnl;
	struct sock___83 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___114 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___83 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___93 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kernfs_root___452;

struct kernfs_elem_dir___452 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___452 *root;
};

struct kernfs_syscall_ops___452;

struct kernfs_root___452 {
	struct kernfs_node___453 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___452 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___452 {
	struct kernfs_node___453 *target_kn;
};

struct kernfs_ops___452;

struct kernfs_elem_attr___452 {
	const struct kernfs_ops___452 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___453 *notify_next;
};

struct kernfs_node___453 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___453 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___452 dir;
		struct kernfs_elem_symlink___452 symlink;
		struct kernfs_elem_attr___452 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___452;

struct kernfs_ops___452 {
	int (*open)(struct kernfs_open_file___452 *);
	void (*release)(struct kernfs_open_file___452 *);
	int (*seq_show)(struct seq_file___397 *, void *);
	void * (*seq_start)(struct seq_file___397 *, loff_t *);
	void * (*seq_next)(struct seq_file___397 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___397 *, void *);
	ssize_t (*read)(struct kernfs_open_file___452 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___452 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___452 *, struct vm_area_struct___459 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___452 *, struct poll_table_struct___297 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___452 {
	int (*remount_fs)(struct kernfs_root___452 *, int *, char *);
	int (*show_options)(struct seq_file___397 *, struct kernfs_root___452 *);
	int (*mkdir)(struct kernfs_node___453 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___453 *);
	int (*rename)(struct kernfs_node___453 *, struct kernfs_node___453 *, const char *);
	int (*show_path)(struct seq_file___397 *, struct kernfs_node___453 *, struct kernfs_root___452 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___452 {
	struct kernfs_node___453 *kn;
	struct file___458 *file;
	struct seq_file___397 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___446 *vm_ops;
};

struct kobj_ns_type_operations___83 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___83 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___422;

struct attribute_group___423 {
	const char *name;
	umode_t (*is_visible)(struct kobject___446 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___446 *, struct bin_attribute___422 *, int);
	struct attribute **attrs;
	struct bin_attribute___422 **bin_attrs;
};

struct bin_attribute___422 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___458 *, struct kobject___446 *, struct bin_attribute___422 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___458 *, struct kobject___446 *, struct bin_attribute___422 *, char *, loff_t, size_t);
	int (*mmap)(struct file___458 *, struct kobject___446 *, struct bin_attribute___422 *, struct vm_area_struct___459 *);
};

struct sysfs_ops___445 {
	ssize_t (*show)(struct kobject___446 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___446 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___445;

struct kset___445 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___446 kobj;
	const struct kset_uevent_ops___445 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___445 {
	void (*release)(struct kobject___446 *);
	const struct sysfs_ops___445 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___83 * (*child_ns_type)(struct kobject___446 *);
	const void * (*namespace)(struct kobject___446 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___445 {
	int (* const filter)(struct kset___445 *, struct kobject___446 *);
	const char * (* const name)(struct kset___445 *, struct kobject___446 *);
	int (* const uevent)(struct kset___445 *, struct kobject___446 *, struct kobj_uevent_env *);
};

struct kobj_attribute___436 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___446 *, struct kobj_attribute___436 *, char *);
	ssize_t (*store)(struct kobject___446 *, struct kobj_attribute___436 *, const char *, size_t);
};

struct dev_pm_ops___426 {
	int (*prepare)(struct device___426 *);
	void (*complete)(struct device___426 *);
	int (*suspend)(struct device___426 *);
	int (*resume)(struct device___426 *);
	int (*freeze)(struct device___426 *);
	int (*thaw)(struct device___426 *);
	int (*poweroff)(struct device___426 *);
	int (*restore)(struct device___426 *);
	int (*suspend_late)(struct device___426 *);
	int (*resume_early)(struct device___426 *);
	int (*freeze_late)(struct device___426 *);
	int (*thaw_early)(struct device___426 *);
	int (*poweroff_late)(struct device___426 *);
	int (*restore_early)(struct device___426 *);
	int (*suspend_noirq)(struct device___426 *);
	int (*resume_noirq)(struct device___426 *);
	int (*freeze_noirq)(struct device___426 *);
	int (*thaw_noirq)(struct device___426 *);
	int (*poweroff_noirq)(struct device___426 *);
	int (*restore_noirq)(struct device___426 *);
	int (*runtime_suspend)(struct device___426 *);
	int (*runtime_resume)(struct device___426 *);
	int (*runtime_idle)(struct device___426 *);
};

struct dev_pm_info___426 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___426 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___426;

struct bus_type___426;

struct device_driver___426;

struct dev_pm_domain___426;

struct dma_map_ops___198;

struct fwnode_handle___346;

struct class___426;

struct device___426 {
	struct device___426 *parent;
	struct device_private *p;
	struct kobject___446 kobj;
	const char *init_name;
	const struct device_type___426 *type;
	struct mutex mutex;
	struct bus_type___426 *bus;
	struct device_driver___426 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___426 power;
	struct dev_pm_domain___426 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___198 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___346 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___426 *class;
	const struct attribute_group___423 **groups;
	void (*release)(struct device___426 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___426 {
	struct dev_pm_ops___426 ops;
	void (*detach)(struct device___426 *, bool);
	int (*activate)(struct device___426 *);
	void (*sync)(struct device___426 *);
	void (*dismiss)(struct device___426 *);
};

struct bus_type___426 {
	const char *name;
	const char *dev_name;
	struct device___426 *dev_root;
	const struct attribute_group___423 **bus_groups;
	const struct attribute_group___423 **dev_groups;
	const struct attribute_group___423 **drv_groups;
	int (*match)(struct device___426 *, struct device_driver___426 *);
	int (*uevent)(struct device___426 *, struct kobj_uevent_env *);
	int (*probe)(struct device___426 *);
	int (*remove)(struct device___426 *);
	void (*shutdown)(struct device___426 *);
	int (*online)(struct device___426 *);
	int (*offline)(struct device___426 *);
	int (*suspend)(struct device___426 *, pm_message_t);
	int (*resume)(struct device___426 *);
	int (*num_vf)(struct device___426 *);
	int (*dma_configure)(struct device___426 *);
	const struct dev_pm_ops___426 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___426 {
	const char *name;
	struct bus_type___426 *bus;
	struct module___384 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___426 *);
	int (*remove)(struct device___426 *);
	void (*shutdown)(struct device___426 *);
	int (*suspend)(struct device___426 *, pm_message_t);
	int (*resume)(struct device___426 *);
	const struct attribute_group___423 **groups;
	const struct dev_pm_ops___426 *pm;
	void (*coredump)(struct device___426 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___426 {
	const char *name;
	const struct attribute_group___423 **groups;
	int (*uevent)(struct device___426 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___426 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___426 *);
	const struct dev_pm_ops___426 *pm;
};

struct class___426 {
	const char *name;
	struct module___384 *owner;
	const struct attribute_group___423 **class_groups;
	const struct attribute_group___423 **dev_groups;
	struct kobject___446 *dev_kobj;
	int (*dev_uevent)(struct device___426 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___426 *, umode_t *);
	void (*class_release)(struct class___426 *);
	void (*dev_release)(struct device___426 *);
	int (*shutdown_pre)(struct device___426 *);
	const struct kobj_ns_type_operations___83 *ns_type;
	const void * (*namespace)(struct device___426 *);
	const struct dev_pm_ops___426 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___198 {
	void * (*alloc)(struct device___426 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___426 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___426 *, struct vm_area_struct___459 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___426 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___426 *, struct page___459 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___426 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___426 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___426 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___426 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___426 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___426 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___426 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___426 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___426 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___426 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___426 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___426 *, u64);
	u64 (*get_required_mask)(struct device___426 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___346;

struct fwnode_handle___346 {
	struct fwnode_handle___346 *secondary;
	const struct fwnode_operations___346 *ops;
};

typedef void compound_page_dtor___446(struct page___459 *);

struct fwnode_reference_args___346;

struct fwnode_endpoint___346;

struct fwnode_operations___346 {
	struct fwnode_handle___346 * (*get)(struct fwnode_handle___346 *);
	void (*put)(struct fwnode_handle___346 *);
	bool (*device_is_available)(const struct fwnode_handle___346 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___346 *, const struct device___426 *);
	bool (*property_present)(const struct fwnode_handle___346 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___346 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___346 *, const char *, const char **, size_t);
	struct fwnode_handle___346 * (*get_parent)(const struct fwnode_handle___346 *);
	struct fwnode_handle___346 * (*get_next_child_node)(const struct fwnode_handle___346 *, struct fwnode_handle___346 *);
	struct fwnode_handle___346 * (*get_named_child_node)(const struct fwnode_handle___346 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___346 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___346 *);
	struct fwnode_handle___346 * (*graph_get_next_endpoint)(const struct fwnode_handle___346 *, struct fwnode_handle___346 *);
	struct fwnode_handle___346 * (*graph_get_remote_endpoint)(const struct fwnode_handle___346 *);
	struct fwnode_handle___346 * (*graph_get_port_parent)(struct fwnode_handle___346 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___346 *, struct fwnode_endpoint___346 *);
};

struct fwnode_endpoint___346 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___346 *local_fwnode;
};

struct fwnode_reference_args___346 {
	struct fwnode_handle___346 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___139;

struct pipe_buffer___139 {
	struct page___459 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___139 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___139 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___139 *, struct pipe_buffer___139 *);
	void (*release)(struct pipe_inode_info___139 *, struct pipe_buffer___139 *);
	int (*steal)(struct pipe_inode_info___139 *, struct pipe_buffer___139 *);
	union {
		bool (*get)(struct pipe_inode_info___139 *, struct pipe_buffer___139 *);
		struct {
			void (*get)(struct pipe_inode_info___139 *, struct pipe_buffer___139 *);
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
};

struct nf_bridge_info___103 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___103 = 0,
		BRNF_PROTO_8021Q___103 = 1,
		BRNF_PROTO_PPPOE___103 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___103 *physindev;
	struct net_device___103 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___103(struct sk_buff___104 **);

struct net_device_ops___103;

struct ethtool_ops___103;

struct l3mdev_ops___83;

struct ndisc_ops___54;

struct xfrmdev_ops___103;

struct tlsdev_ops___103;

struct header_ops___103;

struct inet6_dev___54;

struct netdev_rx_queue___103;

struct mini_Qdisc___95;

struct netdev_queue___103;

struct Qdisc___95;

struct rtnl_link_ops___95;

struct dcbnl_rtnl_ops___103;

struct net_device___103 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___103 *netdev_ops;
	const struct ethtool_ops___103 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___83 *l3mdev_ops;
	const struct ndisc_ops___54 *ndisc_ops;
	const struct xfrmdev_ops___103 *xfrmdev_ops;
	const struct tlsdev_ops___103 *tlsdev_ops;
	const struct header_ops___103 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___445 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___54 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___103 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___93 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___103 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___95 *miniq_ingress;
	struct netdev_queue___103 *ingress_queue;
	struct nf_hook_entries___18 *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___103 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___95 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___95 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___103 = 0,
		NETREG_REGISTERED___103 = 1,
		NETREG_UNREGISTERING___103 = 2,
		NETREG_UNREGISTERED___103 = 3,
		NETREG_RELEASED___103 = 4,
		NETREG_DUMMY___103 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___103 = 0,
		RTNL_LINK_INITIALIZING___103 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___103 *);
	struct netpoll_info *npinfo;
	possible_net_t___105 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___426 dev;
	const struct attribute_group___423 *sysfs_groups[4];
	const struct attribute_group___423 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___95 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___103 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct xfrm_state___20;

struct sec_path___20 {
	refcount_t refcnt;
	int len;
	int olen;
	struct xfrm_state___20 *xvec[6];
	struct xfrm_offload ovec[1];
};

struct sk_buff_fclones___3 {
	struct sk_buff___104 skb1;
	struct sk_buff___104 skb2;
	refcount_t fclone_ref;
};

struct ethtool_ops___103 {
	int (*get_settings)(struct net_device___103 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___103 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___103 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___103 *);
	void (*get_regs)(struct net_device___103 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___103 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___103 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___103 *);
	void (*set_msglevel)(struct net_device___103 *, u32);
	int (*nway_reset)(struct net_device___103 *);
	u32 (*get_link)(struct net_device___103 *);
	int (*get_eeprom_len)(struct net_device___103 *);
	int (*get_eeprom)(struct net_device___103 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___103 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___103 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___103 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___103 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___103 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___103 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___103 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___103 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___103 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___103 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___103 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___103 *);
	void (*complete)(struct net_device___103 *);
	u32 (*get_priv_flags)(struct net_device___103 *);
	int (*set_priv_flags)(struct net_device___103 *, u32);
	int (*get_sset_count)(struct net_device___103 *, int);
	int (*get_rxnfc)(struct net_device___103 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___103 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___103 *, struct ethtool_flash *);
	int (*reset)(struct net_device___103 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___103 *);
	u32 (*get_rxfh_indir_size)(struct net_device___103 *);
	int (*get_rxfh)(struct net_device___103 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___103 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___103 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___103 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___103 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___103 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___103 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___103 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___103 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___103 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___103 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___103 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___103 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___103 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___103 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___103 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___103 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___103 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___103 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___103 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___103 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___103 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	int (*get_fecparam)(struct net_device___103 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___103 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___103 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___103 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___103 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___103;

struct inet_frags___103 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___103 *, const void *);
	void (*destructor)(struct inet_frag_queue___103 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___103 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___104 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___104 *fragments_tail;
	struct sk_buff___104 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___103 *net;
	struct callback_head rcu;
};

struct ip_ra_chain___49 {
	struct ip_ra_chain___49 *next;
	struct sock___83 *sk;
	union {
		void (*destructor)(struct sock___83 *);
		struct sock___83 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___83;

struct fib_lookup_arg___83;

struct fib_rules_ops___83 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___83 *, struct flowi *, int, struct fib_lookup_arg___83 *);
	bool (*suppress)(struct fib_rule___83 *, struct fib_lookup_arg___83 *);
	int (*match)(struct fib_rule___83 *, struct flowi *, int);
	int (*configure)(struct fib_rule___83 *, struct sk_buff___104 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___83 *);
	int (*compare)(struct fib_rule___83 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___83 *, struct sk_buff___104 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___83 *);
	void (*flush_cache)(struct fib_rules_ops___83 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___384 *owner;
	struct net___114 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___84 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___114 *);
	int (*fib_dump)(struct net___114 *, struct notifier_block *);
	struct module___384 *owner;
	struct callback_head rcu;
};

struct dst_entry___83 {
	struct net_device___103 *dev;
	struct dst_ops___114 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state___20 *xfrm;
	int (*input)(struct sk_buff___104 *);
	int (*output)(struct net___114 *, struct sock___83 *, struct sk_buff___104 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___83;

struct neigh_parms___83;

struct neigh_ops___83;

struct neighbour___83 {
	struct neighbour___83 *next;
	struct neigh_table___83 *tbl;
	struct neigh_parms___83 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___103 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___83 *, struct sk_buff___104 *);
	const struct neigh_ops___83 *ops;
	struct callback_head rcu;
	struct net_device___103 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct fib6_nh___25 {
	struct in6_addr nh_gw;
	struct net_device___103 *nh_dev;
	struct lwtunnel_state *nh_lwtstate;
	unsigned int nh_flags;
	atomic_t nh_upper_bound;
	int nh_weight;
};

struct fib6_node___25;

struct fib6_info___25 {
	struct fib6_table___25 *fib6_table;
	struct fib6_info___25 *fib6_next;
	struct fib6_node___25 *fib6_node;
	struct list_head fib6_siblings;
	unsigned int fib6_nsiblings;
	atomic_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	struct rt6_info___25 **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
	long unsigned int last_probe;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 exception_bucket_flushed: 1;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 dst_host: 1;
	u8 fib6_destroying: 1;
	u8 unused: 2;
	struct fib6_nh___25 fib6_nh;
	struct callback_head rcu;
};

struct rt6_info___25 {
	struct dst_entry___83 dst;
	struct fib6_info___25 *from;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___54 *rt6i_idev;
	u32 rt6i_flags;
	struct rt6key rt6i_prefsrc;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct fib6_node___25 {
	struct fib6_node___25 *parent;
	struct fib6_node___25 *left;
	struct fib6_node___25 *right;
	struct fib6_info___25 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info___25 *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table___25 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node___25 tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

struct nf_hook_state___18;

typedef unsigned int nf_hookfn___18(void *, struct sk_buff___104 *, const struct nf_hook_state___18 *);

struct nf_hook_entry___18 {
	nf_hookfn___18 *hook;
	void *priv;
};

struct nf_hook_entries___18 {
	u16 num_hook_entries;
	struct nf_hook_entry___18 hooks[0];
};

struct ucounts___323 {
	struct hlist_node node;
	struct user_namespace___323 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_prog_aux___96;

struct bpf_prog___93 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___96 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

typedef int (*key_restrict_link_func_t___427)(struct key___426 *, const struct key_type *, const union key_payload *, struct key___426 *);

struct key_restriction___426;

struct key___426 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___460 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___426 *restrict_link;
};

struct key_restriction___426 {
	key_restrict_link_func_t___427 check;
	struct key___426 *key;
	struct key_type *keytype;
};

struct seq_operations___397 {
	void * (*start)(struct seq_file___397 *, loff_t *);
	void (*stop)(struct seq_file___397 *, void *);
	void * (*next)(struct seq_file___397 *, void *, loff_t *);
	int (*show)(struct seq_file___397 *, void *);
};

struct pernet_operations___104 {
	struct list_head list;
	int (*init)(struct net___114 *);
	void (*exit)(struct net___114 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___103 {
	int (*ieee_getets)(struct net_device___103 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___103 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___103 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___103 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___103 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___103 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___103 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___103 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___103 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___103 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___103 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___103 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___103 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___103 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___103 *);
	u8 (*setstate)(struct net_device___103 *, u8);
	void (*getpermhwaddr)(struct net_device___103 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___103 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___103 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___103 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___103 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___103 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___103 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___103 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___103 *, int, u8 *);
	void (*setpfccfg)(struct net_device___103 *, int, u8);
	void (*getpfccfg)(struct net_device___103 *, int, u8 *);
	u8 (*setall)(struct net_device___103 *);
	u8 (*getcap)(struct net_device___103 *, int, u8 *);
	int (*getnumtcs)(struct net_device___103 *, int, u8 *);
	int (*setnumtcs)(struct net_device___103 *, int, u8);
	u8 (*getpfcstate)(struct net_device___103 *);
	void (*setpfcstate)(struct net_device___103 *, u8);
	void (*getbcncfg)(struct net_device___103 *, int, u32 *);
	void (*setbcncfg)(struct net_device___103 *, int, u32);
	void (*getbcnrp)(struct net_device___103 *, int, u8 *);
	void (*setbcnrp)(struct net_device___103 *, int, u8);
	int (*setapp)(struct net_device___103 *, u8, u16, u8);
	int (*getapp)(struct net_device___103 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___103 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___103 *, int, u8);
	u8 (*getdcbx)(struct net_device___103 *);
	u8 (*setdcbx)(struct net_device___103 *, u8);
	int (*peer_getappinfo)(struct net_device___103 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___103 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___103 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___103 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___103 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___103 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___307 {
	refcount_t count;
	struct ns_common___29 ns;
	struct user_namespace___323 *user_ns;
	struct ucounts___323 *ucounts;
	struct css_set___307 *root_cset;
};

struct bpf_map___308;

struct bpf_map_ops___307 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___308 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___308 *, struct file___458 *);
	void (*map_free)(struct bpf_map___308 *);
	int (*map_get_next_key)(struct bpf_map___308 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___308 *);
	void * (*map_lookup_elem)(struct bpf_map___308 *, void *);
	int (*map_update_elem)(struct bpf_map___308 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___308 *, void *);
	int (*map_push_elem)(struct bpf_map___308 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___308 *, void *);
	int (*map_peek_elem)(struct bpf_map___308 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___308 *, struct file___458 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___308 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___308 *, void *, struct seq_file___397 *);
	int (*map_check_btf)(const struct bpf_map___308 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___308 {
	const struct bpf_map_ops___307 *ops;
	struct bpf_map___308 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___426 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___103;

struct bpf_map_dev_ops___103 {
	int (*map_get_next_key)(struct bpf_offloaded_map___103 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___103 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___103 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___103 *, void *);
};

struct bpf_offloaded_map___103 {
	struct bpf_map___308 map;
	struct net_device___103 *netdev;
	const struct bpf_map_dev_ops___103 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___93 {
	int (*test_run)(struct bpf_prog___93 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___93 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___93 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___93 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___93 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___93 *, u32 *);
};

struct bpf_prog_offload_ops___93 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___93 *);
	int (*translate)(struct bpf_prog___93 *);
	void (*destroy)(struct bpf_prog___93 *);
};

struct bpf_prog_offload___93 {
	struct bpf_prog___93 *prog;
	struct net_device___103 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___93 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___96 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___93 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___93 *ops;
	struct bpf_map___308 **used_maps;
	struct bpf_prog___93 *prog;
	struct user_struct___426 *user;
	u64 load_time;
	struct bpf_map___308 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___93 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___93 {
	struct bpf_prog___93 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___93 {
	struct callback_head rcu;
	struct bpf_prog_array_item___93 items[0];
};

struct cgroup_bpf___93 {
	struct bpf_prog_array___93 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___93 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___308;

typedef void (*kthread_work_func_t___308)(struct kthread_work___308 *);

struct kthread_worker___308;

struct kthread_work___308 {
	struct list_head node;
	kthread_work_func_t___308 func;
	struct kthread_worker___308 *worker;
	int canceling;
};

struct kthread_worker___308 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___460 *task;
	struct kthread_work___308 *current_work;
};

struct kthread_delayed_work___307 {
	struct kthread_work___308 work;
	struct timer_list timer;
};

struct psi_group___307 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___308 *poll_kworker;
	struct kthread_delayed_work___307 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___307;

struct cgroup_rstat_cpu___307;

struct cgroup___307 {
	struct cgroup_subsys_state___307 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___453 *kn;
	struct cgroup_file___307 procs_file;
	struct cgroup_file___307 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___307 *subsys[13];
	struct cgroup_root___307 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___307 *dom_cgrp;
	struct cgroup_rstat_cpu___307 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___93 bpf;
	atomic_t congestion_count;
	struct cgroup___307 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___307 psi;
	int ancestor_ids[0];
};

struct cftype___307;

struct cgroup_subsys___307 {
	struct cgroup_subsys_state___307 * (*css_alloc)(struct cgroup_subsys_state___307 *);
	int (*css_online)(struct cgroup_subsys_state___307 *);
	void (*css_offline)(struct cgroup_subsys_state___307 *);
	void (*css_released)(struct cgroup_subsys_state___307 *);
	void (*css_free)(struct cgroup_subsys_state___307 *);
	void (*css_reset)(struct cgroup_subsys_state___307 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___307 *, int);
	int (*css_extra_stat_show)(struct seq_file___397 *, struct cgroup_subsys_state___307 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___460 *);
	void (*cancel_fork)(struct task_struct___460 *);
	void (*fork)(struct task_struct___460 *);
	void (*exit)(struct task_struct___460 *);
	void (*free)(struct task_struct___460 *);
	void (*bind)(struct cgroup_subsys_state___307 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___307 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___307 *dfl_cftypes;
	struct cftype___307 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___307 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___307 *updated_children;
	struct cgroup___307 *updated_next;
};

struct cgroup_root___307 {
	struct kernfs_root___452 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___307 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___307 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___307 *ss;
	struct list_head node;
	struct kernfs_ops___452 *kf_ops;
	int (*open)(struct kernfs_open_file___452 *);
	void (*release)(struct kernfs_open_file___452 *);
	u64 (*read_u64)(struct cgroup_subsys_state___307 *, struct cftype___307 *);
	s64 (*read_s64)(struct cgroup_subsys_state___307 *, struct cftype___307 *);
	int (*seq_show)(struct seq_file___397 *, void *);
	void * (*seq_start)(struct seq_file___397 *, loff_t *);
	void * (*seq_next)(struct seq_file___397 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___397 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___307 *, struct cftype___307 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___307 *, struct cftype___307 *, s64);
	ssize_t (*write)(struct kernfs_open_file___452 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___452 *, struct poll_table_struct___297 *);
};

struct xdp_rxq_info___103 {
	struct net_device___103 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___103 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___103 *dev_rx;
};

struct netlink_callback___105 {
	struct sk_buff___104 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___105 *);
	int (*dump)(struct sk_buff___104 *, struct netlink_callback___105 *);
	int (*done)(struct netlink_callback___105 *);
	void *data;
	struct module___384 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___103 {
	int (*create)(struct sk_buff___104 *, struct net_device___103 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___104 *, unsigned char *);
	int (*cache)(const struct neighbour___83 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___103 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___103 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___103 *, int);
	int poll_owner;
	struct net_device___103 *dev;
	struct sk_buff___104 *gro_list;
	struct sk_buff___104 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___103 {
	struct net_device___103 *dev;
	struct Qdisc___95 *qdisc;
	struct Qdisc___95 *qdisc_sleeping;
	struct kobject___446 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___103 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___95 {
	struct sk_buff___104 *head;
	struct sk_buff___104 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___95;

struct Qdisc___95 {
	int (*enqueue)(struct sk_buff___104 *, struct Qdisc___95 *, struct sk_buff___104 **);
	struct sk_buff___104 * (*dequeue)(struct Qdisc___95 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___95 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___103 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___103 gso_skb;
	struct qdisc_skb_head___95 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___95 *next_sched;
	struct sk_buff_head___103 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___103 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___446 kobj;
	struct net_device___103 *dev;
	long: 64;
	struct xdp_rxq_info___103 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___103)(struct net_device___103 *, struct sk_buff___104 *, struct net_device___103 *);

struct netdev_bpf___103 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___93 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___93 *prog;
			const struct bpf_prog_offload_ops___93 *ops;
		} verifier;
		struct {
			struct bpf_prog___93 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___103 *offmap;
		};
		struct {
			struct xdp_umem___3 *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___103 {
	int (*xdo_dev_state_add)(struct xfrm_state___20 *);
	void (*xdo_dev_state_delete)(struct xfrm_state___20 *);
	void (*xdo_dev_state_free)(struct xfrm_state___20 *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___104 *, struct xfrm_state___20 *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state___20 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct xfrm_state_offload___20 {
	struct net_device___103 *dev;
	long unsigned int offload_handle;
	unsigned int num_exthdrs;
	u8 flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct xfrm_replay___20;

struct xfrm_type___20;

struct xfrm_mode___20;

struct xfrm_type_offload___20;

struct xfrm_state___20 {
	possible_net_t___105 xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	refcount_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
		u32 output_mark;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	const char *geniv;
	struct xfrm_encap_tmpl *encap;
	xfrm_address_t *coaddr;
	struct xfrm_state___20 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	const struct xfrm_replay___20 *repl;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct tasklet_hrtimer mtimer;
	struct xfrm_state_offload___20 xso;
	long int saved_tmo;
	long unsigned int lastused;
	struct page_frag___459 xfrag;
	const struct xfrm_type___20 *type;
	struct xfrm_mode___20 *inner_mode;
	struct xfrm_mode___20 *inner_mode_iaf;
	struct xfrm_mode___20 *outer_mode;
	const struct xfrm_type_offload___20 *type_offload;
	struct xfrm_sec_ctx___2 *security;
	void *data;
	u32 output_mark_mask;
	u32 if_id;
};

struct tlsdev_ops___103 {
	int (*tls_dev_add)(struct net_device___103 *, struct sock___83 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___103 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___103 *, struct sock___83 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___103 {
	int (*ndo_init)(struct net_device___103 *);
	void (*ndo_uninit)(struct net_device___103 *);
	int (*ndo_open)(struct net_device___103 *);
	int (*ndo_stop)(struct net_device___103 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___104 *, struct net_device___103 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___104 *, struct net_device___103 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___103 *, struct sk_buff___104 *, struct net_device___103 *, select_queue_fallback_t___103);
	void (*ndo_change_rx_flags)(struct net_device___103 *, int);
	void (*ndo_set_rx_mode)(struct net_device___103 *);
	int (*ndo_set_mac_address)(struct net_device___103 *, void *);
	int (*ndo_validate_addr)(struct net_device___103 *);
	int (*ndo_do_ioctl)(struct net_device___103 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___103 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___103 *, int);
	int (*ndo_neigh_setup)(struct net_device___103 *, struct neigh_parms___83 *);
	void (*ndo_tx_timeout)(struct net_device___103 *);
	void (*ndo_get_stats64)(struct net_device___103 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___103 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___103 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___103 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___103 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___103 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___103 *);
	int (*ndo_netpoll_setup)(struct net_device___103 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___103 *);
	int (*ndo_set_vf_mac)(struct net_device___103 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___103 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___103 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___103 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___103 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___103 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___103 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___103 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___103 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___103 *, int, struct sk_buff___104 *);
	int (*ndo_set_vf_guid)(struct net_device___103 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___103 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___103 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___103 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___103 *, const struct sk_buff___104 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___103 *, struct net_device___103 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___103 *, struct net_device___103 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___103 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___103 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___103 *, struct neighbour___83 *);
	void (*ndo_neigh_destroy)(struct net_device___103 *, struct neighbour___83 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___103 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___103 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___103 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___104 *, struct netlink_callback___105 *, struct net_device___103 *, struct net_device___103 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___103 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___103 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___104 *, u32, u32, struct net_device___103 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___103 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___103 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___103 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___103 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___103 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___103 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___103 *, struct net_device___103 *);
	void (*ndo_dfwd_del_station)(struct net_device___103 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___103 *);
	int (*ndo_set_tx_maxrate)(struct net_device___103 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___103 *);
	int (*ndo_change_proto_down)(struct net_device___103 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___103 *, struct sk_buff___104 *);
	void (*ndo_set_rx_headroom)(struct net_device___103 *, int);
	int (*ndo_bpf)(struct net_device___103 *, struct netdev_bpf___103 *);
	int (*ndo_xdp_xmit)(struct net_device___103 *, int, struct xdp_frame___103 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___103 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___103 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___83 {
	possible_net_t___105 net;
	struct net_device___103 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___83 *);
	void (*neigh_cleanup)(struct neighbour___83 *);
	struct neigh_table___83 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___83 {
	u32 (*l3mdev_fib_table)(const struct net_device___103 *);
	struct sk_buff___104 * (*l3mdev_l3_rcv)(struct net_device___103 *, struct sk_buff___104 *, u16);
	struct sk_buff___104 * (*l3mdev_l3_out)(struct net_device___103 *, struct sock___83 *, struct sk_buff___104 *, u16);
	struct dst_entry___83 * (*l3mdev_link_scope_lookup)(const struct net_device___103 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct ndisc_ops___54 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___103 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___103 *, struct neighbour___83 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___103 *, u8, struct neighbour___83 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___103 *, struct sk_buff___104 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___114 *, struct net_device___103 *, const struct prefix_info *, struct inet6_dev___54 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___54;

struct ifacaddr6___25;

struct inet6_dev___54 {
	struct net_device___103 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___54 *mc_list;
	struct ifmcaddr6___54 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___25 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	u8 rndid[8];
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___83 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
};

struct tcf_proto___95;

struct mini_Qdisc___95 {
	struct tcf_proto___95 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___95 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___103 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___114 *, struct net_device___103 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___103 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___103 *, struct list_head *);
	size_t (*get_size)(const struct net_device___103 *);
	int (*fill_info)(struct sk_buff___104 *, const struct net_device___103 *);
	size_t (*get_xstats_size)(const struct net_device___103 *);
	int (*fill_xstats)(struct sk_buff___104 *, const struct net_device___103 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___103 *, struct net_device___103 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___103 *, const struct net_device___103 *);
	int (*fill_slave_info)(struct sk_buff___104 *, const struct net_device___103 *, const struct net_device___103 *);
	struct net___114 * (*get_link_net)(const struct net_device___103 *);
	size_t (*get_linkxstats_size)(const struct net_device___103 *, int);
	int (*fill_linkxstats)(struct sk_buff___104 *, const struct net_device___103 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___103 {
	struct list_head poll_list;
	struct sk_buff_head___103 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___103 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___95 *output_queue;
	struct Qdisc___95 **output_queue_tailp;
	struct sk_buff___104 *completion_queue;
	struct sk_buff_head___103 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___103 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___103 input_pkt_queue;
	struct napi_struct___103 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct nf_hook_state___18 {
	unsigned int hook;
	u_int8_t pf;
	struct net_device___103 *in;
	struct net_device___103 *out;
	struct sock___83 *sk;
	struct net___114 *net;
	int (*okfn)(struct net___114 *, struct sock___83 *, struct sk_buff___104 *);
};

struct nf_nat_hook___18 {
	int (*parse_nat_setup)(struct nf_conn *, enum nf_nat_manip_type, const struct nlattr *);
	void (*decode_session)(struct sk_buff___104 *, struct flowi *);
	unsigned int (*manip_pkt)(struct sk_buff___104 *, struct nf_conn *, enum nf_nat_manip_type, enum ip_conntrack_dir);
};

struct nf_ct_hook___18 {
	int (*update)(struct net___114 *, struct sk_buff___104 *);
	void (*destroy)(struct nf_conntrack *);
	bool (*get_tuple_skb)(struct nf_conntrack_tuple *, const struct sk_buff___104 *);
};

struct nfnl_ct_hook___18 {
	struct nf_conn * (*get_ct)(const struct sk_buff___104 *, enum ip_conntrack_info *);
	size_t (*build_size)(const struct nf_conn *);
	int (*build)(struct sk_buff___104 *, struct nf_conn *, enum ip_conntrack_info, u_int16_t, u_int16_t);
	int (*parse)(const struct nlattr *, struct nf_conn *);
	int (*attach_expect)(const struct nlattr *, struct nf_conn *, u32, u32);
	void (*seq_adjust)(struct sk_buff___104 *, struct nf_conn *, enum ip_conntrack_info, s32);
};

struct kernel_param_ops___384 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___384 *);
	int (*get)(char *, const struct kernel_param___384 *);
	void (*free)(void *);
};

struct kparam_array___384;

struct kernel_param___384 {
	const char *name;
	struct module___384 *mod;
	const struct kernel_param_ops___384 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___384 *arr;
	};
};

struct kparam_array___384 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___384 *ops;
	void *elem;
};

struct module_attribute___384 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___384 *, struct module_kobject___384 *, char *);
	ssize_t (*store)(struct module_attribute___384 *, struct module_kobject___384 *, const char *, size_t);
	void (*setup)(struct module___384 *, const char *);
	int (*test)(struct module___384 *);
	void (*free)(struct module___384 *);
};

struct node___230 {
	struct device___426 dev;
};

struct pneigh_entry___83;

struct neigh_hash_table___83;

struct neigh_table___83 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___103 *, __u32 *);
	bool (*key_eq)(const struct neighbour___83 *, const void *);
	int (*constructor)(struct neighbour___83 *);
	int (*pconstructor)(struct pneigh_entry___83 *);
	void (*pdestructor)(struct pneigh_entry___83 *);
	void (*proxy_redo)(struct sk_buff___104 *);
	char *id;
	struct neigh_parms___83 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___103 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___83 *nht;
	struct pneigh_entry___83 **phash_buckets;
};

struct neigh_ops___83 {
	int family;
	void (*solicit)(struct neighbour___83 *, struct sk_buff___104 *);
	void (*error_report)(struct neighbour___83 *, struct sk_buff___104 *);
	int (*output)(struct neighbour___83 *, struct sk_buff___104 *);
	int (*connected_output)(struct neighbour___83 *, struct sk_buff___104 *);
};

struct pneigh_entry___83 {
	struct pneigh_entry___83 *next;
	possible_net_t___105 net;
	struct net_device___103 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___83 {
	struct neighbour___83 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct bdi_writeback_congested___248 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___248 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___248 {
	struct bio___248 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___250 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___250 bip_inline_vecs[0];
};

struct bio_set___248 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___248 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___191 {
	struct mem_cgroup___191 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___191 {
	struct lruvec___459 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___191 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___191 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct gnet_dump___95 {
	spinlock_t *lock;
	struct sk_buff___104 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___95;

struct Qdisc_ops___95 {
	struct Qdisc_ops___95 *next;
	const struct Qdisc_class_ops___95 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___104 *, struct Qdisc___95 *, struct sk_buff___104 **);
	struct sk_buff___104 * (*dequeue)(struct Qdisc___95 *);
	struct sk_buff___104 * (*peek)(struct Qdisc___95 *);
	int (*init)(struct Qdisc___95 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___95 *);
	void (*destroy)(struct Qdisc___95 *);
	int (*change)(struct Qdisc___95 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___95 *);
	int (*change_tx_queue_len)(struct Qdisc___95 *, unsigned int);
	int (*dump)(struct Qdisc___95 *, struct sk_buff___104 *);
	int (*dump_stats)(struct Qdisc___95 *, struct gnet_dump___95 *);
	void (*ingress_block_set)(struct Qdisc___95 *, u32);
	void (*egress_block_set)(struct Qdisc___95 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___95 *);
	u32 (*egress_block_get)(struct Qdisc___95 *);
	struct module___384 *owner;
};

struct tcf_block___95;

struct Qdisc_class_ops___95 {
	unsigned int flags;
	struct netdev_queue___103 * (*select_queue)(struct Qdisc___95 *, struct tcmsg *);
	int (*graft)(struct Qdisc___95 *, long unsigned int, struct Qdisc___95 *, struct Qdisc___95 **, struct netlink_ext_ack *);
	struct Qdisc___95 * (*leaf)(struct Qdisc___95 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___95 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___95 *, u32);
	int (*change)(struct Qdisc___95 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___95 *, long unsigned int);
	void (*walk)(struct Qdisc___95 *, struct qdisc_walker *);
	struct tcf_block___95 * (*tcf_block)(struct Qdisc___95 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___95 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___95 *, long unsigned int);
	int (*dump)(struct Qdisc___95 *, long unsigned int, struct sk_buff___104 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___95 *, long unsigned int, struct gnet_dump___95 *);
};

struct tcf_chain___95;

struct tcf_block___95 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___114 *net;
	struct Qdisc___95 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___95 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___95;

struct tcf_proto_ops___95;

struct tcf_proto___95 {
	struct tcf_proto___95 *next;
	void *root;
	int (*classify)(struct sk_buff___104 *, const struct tcf_proto___95 *, struct tcf_result___95 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___95 *ops;
	struct tcf_chain___95 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___95 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___95 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___95 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___104 *, const struct tcf_proto___95 *, struct tcf_result___95 *);
	int (*init)(struct tcf_proto___95 *);
	void (*destroy)(struct tcf_proto___95 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___95 *, u32);
	void (*put)(struct tcf_proto___95 *, void *);
	int (*change)(struct net___114 *, struct sk_buff___104 *, struct tcf_proto___95 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___95 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___95 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___95 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___114 *, struct tcf_chain___95 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___114 *, struct tcf_proto___95 *, void *, struct sk_buff___104 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___104 *, struct net___114 *, void *);
	struct module___384 *owner;
	int flags;
};

struct tcf_chain___95 {
	struct mutex filter_chain_lock;
	struct tcf_proto___95 *filter_chain;
	struct list_head list;
	struct tcf_block___95 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___95 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___83 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___93 *prog;
};

struct bpf_redirect_info___93 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___308 *map;
	struct bpf_map___308 *map_to_flush;
	u32 kern_flags;
};

struct fib_rule___83 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___83 *ctarget;
	struct net___114 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___83 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___83 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___66;

struct timewait_sock_ops___62;

struct proto___83 {
	void (*close)(struct sock___83 *, long int);
	int (*pre_connect)(struct sock___83 *, struct sockaddr *, int);
	int (*connect)(struct sock___83 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___83 *, int);
	struct sock___83 * (*accept)(struct sock___83 *, int, int *, bool);
	int (*ioctl)(struct sock___83 *, int, long unsigned int);
	int (*init)(struct sock___83 *);
	void (*destroy)(struct sock___83 *);
	void (*shutdown)(struct sock___83 *, int);
	int (*setsockopt)(struct sock___83 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___83 *, int, int, char *, int *);
	void (*keepalive)(struct sock___83 *, int);
	int (*sendmsg)(struct sock___83 *, struct msghdr___86 *, size_t);
	int (*recvmsg)(struct sock___83 *, struct msghdr___86 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___83 *, struct page___459 *, int, size_t, int);
	int (*bind)(struct sock___83 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___83 *, struct sk_buff___104 *);
	void (*release_cb)(struct sock___83 *);
	int (*hash)(struct sock___83 *);
	void (*unhash)(struct sock___83 *);
	void (*rehash)(struct sock___83 *);
	int (*get_port)(struct sock___83 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___83 *);
	bool (*stream_memory_read)(const struct sock___83 *);
	void (*enter_memory_pressure)(struct sock___83 *);
	void (*leave_memory_pressure)(struct sock___83 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___66 *rsk_prot;
	struct timewait_sock_ops___62 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___384 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___83 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct xfrm_policy_queue___20 {
	struct sk_buff_head___103 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___20 {
	possible_net_t___105 xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	refcount_t refcnt;
	struct timer_list timer;
	atomic_t genid;
	u32 priority;
	u32 index;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___20 polq;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx___2 *security;
	struct xfrm_tmpl xfrm_vec[6];
	struct callback_head rcu;
	u32 if_id;
};

struct request_sock___67;

struct request_sock_ops___66 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___83 *, struct request_sock___67 *);
	void (*send_ack)(const struct sock___83 *, struct sk_buff___104 *, struct request_sock___67 *);
	void (*send_reset)(const struct sock___83 *, struct sk_buff___104 *);
	void (*destructor)(struct request_sock___67 *);
	void (*syn_ack_timeout)(const struct request_sock___67 *);
};

struct timewait_sock_ops___62 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___83 *, struct sock___83 *, void *);
	void (*twsk_destructor)(struct sock___83 *);
};

struct request_sock___67 {
	struct sock_common___83 __req_common;
	struct request_sock___67 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___66 *rsk_ops;
	struct sock___83 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___54 {
	struct in6_addr mca_addr;
	struct inet6_dev___54 *idev;
	struct ifmcaddr6___54 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___25 {
	struct in6_addr aca_addr;
	struct fib6_info___25 *aca_rt;
	struct ifacaddr6___25 *aca_next;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct ip6_ra_chain___54 {
	struct ip6_ra_chain___54 *next;
	struct sock___83 *sk;
	int sel;
	void (*destructor)(struct sock___83 *);
};

struct rtable___19 {
	struct dst_entry___83 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	__be32 rt_gateway;
	u32 rt_mtu_locked: 1;
	u32 rt_pmtu: 31;
	struct list_head rt_uncached;
	struct uncached_list *rt_uncached_list;
};

struct xfrm_replay___20 {
	void (*advance)(struct xfrm_state___20 *, __be32);
	int (*check)(struct xfrm_state___20 *, struct sk_buff___104 *, __be32);
	int (*recheck)(struct xfrm_state___20 *, struct sk_buff___104 *, __be32);
	void (*notify)(struct xfrm_state___20 *, int);
	int (*overflow)(struct xfrm_state___20 *, struct sk_buff___104 *);
};

struct xfrm_type___20 {
	char *description;
	struct module___384 *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___20 *);
	void (*destructor)(struct xfrm_state___20 *);
	int (*input)(struct xfrm_state___20 *, struct sk_buff___104 *);
	int (*output)(struct xfrm_state___20 *, struct sk_buff___104 *);
	int (*reject)(struct xfrm_state___20 *, struct sk_buff___104 *, const struct flowi *);
	int (*hdr_offset)(struct xfrm_state___20 *, struct sk_buff___104 *, u8 **);
	u32 (*get_mtu)(struct xfrm_state___20 *, int);
};

struct xfrm_state_afinfo___20;

struct xfrm_mode___20 {
	int (*input2)(struct xfrm_state___20 *, struct sk_buff___104 *);
	int (*input)(struct xfrm_state___20 *, struct sk_buff___104 *);
	int (*output2)(struct xfrm_state___20 *, struct sk_buff___104 *);
	int (*output)(struct xfrm_state___20 *, struct sk_buff___104 *);
	struct sk_buff___104 * (*gso_segment)(struct xfrm_state___20 *, struct sk_buff___104 *, netdev_features_t);
	void (*xmit)(struct xfrm_state___20 *, struct sk_buff___104 *);
	struct xfrm_state_afinfo___20 *afinfo;
	struct module___384 *owner;
	unsigned int encap;
	int flags;
};

struct xfrm_type_offload___20 {
	char *description;
	struct module___384 *owner;
	u8 proto;
	void (*encap)(struct xfrm_state___20 *, struct sk_buff___104 *);
	int (*input_tail)(struct xfrm_state___20 *, struct sk_buff___104 *);
	int (*xmit)(struct xfrm_state___20 *, struct sk_buff___104 *, netdev_features_t);
};

enum {
	XFRM_STATE_VOID = 0,
	XFRM_STATE_ACQ = 1,
	XFRM_STATE_VALID = 2,
	XFRM_STATE_ERROR = 3,
	XFRM_STATE_EXPIRED = 4,
	XFRM_STATE_DEAD = 5,
};

struct xfrm_if;

struct xfrm_if_cb {
	struct xfrm_if * (*decode_session)(struct sk_buff___104 *, short unsigned int);
};

struct xfrm_if_parms {
	char name[16];
	int link;
	u32 if_id;
};

struct xfrm_if {
	struct xfrm_if *next;
	struct net_device___103 *dev;
	struct net_device___103 *phydev;
	struct net___114 *net;
	struct xfrm_if_parms p;
	struct gro_cells gro_cells;
};

struct xfrm_dst___6;

struct xfrm_policy_afinfo___2 {
	struct dst_ops___114 *dst_ops;
	struct dst_entry___83 * (*dst_lookup)(struct net___114 *, int, int, const xfrm_address_t *, const xfrm_address_t *, u32);
	int (*get_saddr)(struct net___114 *, int, xfrm_address_t *, xfrm_address_t *, u32);
	void (*decode_session)(struct sk_buff___104 *, struct flowi *, int);
	int (*get_tos)(const struct flowi *);
	int (*init_path)(struct xfrm_dst___6 *, struct dst_entry___83 *, int);
	int (*fill_dst)(struct xfrm_dst___6 *, struct net_device___103 *, const struct flowi *);
	struct dst_entry___83 * (*blackhole_route)(struct net___114 *, struct dst_entry___83 *);
};

struct xfrm_dst___6 {
	union {
		struct dst_entry___83 dst;
		struct rtable___19 rt;
		struct rt6_info___25 rt6;
	} u;
	struct dst_entry___83 *route;
	struct dst_entry___83 *child;
	struct dst_entry___83 *path;
	struct xfrm_policy___20 *pols[2];
	int num_pols;
	int num_xfrms;
	u32 xfrm_genid;
	u32 policy_genid;
	u32 route_mtu_cached;
	u32 child_mtu_cached;
	u32 route_cookie;
	u32 path_cookie;
};

struct xfrm_state_afinfo___20 {
	unsigned int family;
	unsigned int proto;
	__be16 eth_proto;
	struct module___384 *owner;
	const struct xfrm_type___20 *type_map[256];
	const struct xfrm_type_offload___20 *type_offload_map[256];
	struct xfrm_mode___20 *mode_map[5];
	int (*init_flags)(struct xfrm_state___20 *);
	void (*init_tempsel)(struct xfrm_selector *, const struct flowi *);
	void (*init_temprop)(struct xfrm_state___20 *, const struct xfrm_tmpl *, const xfrm_address_t *, const xfrm_address_t *);
	int (*tmpl_sort)(struct xfrm_tmpl **, struct xfrm_tmpl **, int);
	int (*state_sort)(struct xfrm_state___20 **, struct xfrm_state___20 **, int);
	int (*output)(struct net___114 *, struct sock___83 *, struct sk_buff___104 *);
	int (*output_finish)(struct sock___83 *, struct sk_buff___104 *);
	int (*extract_input)(struct xfrm_state___20 *, struct sk_buff___104 *);
	int (*extract_output)(struct xfrm_state___20 *, struct sk_buff___104 *);
	int (*transport_finish)(struct sk_buff___104 *, int);
	void (*local_error)(struct sk_buff___104 *, u32);
};

struct xfrm_policy_walk {
	struct xfrm_policy_walk_entry walk;
	u8 type;
	u32 seq;
};

struct xfrm_kmaddress {
	xfrm_address_t local;
	xfrm_address_t remote;
	u32 reserved;
	u16 family;
};

struct xfrm_migrate {
	xfrm_address_t old_daddr;
	xfrm_address_t old_saddr;
	xfrm_address_t new_daddr;
	xfrm_address_t new_saddr;
	u8 proto;
	u8 mode;
	u16 reserved;
	u32 reqid;
	u16 old_family;
	u16 new_family;
};

struct xfrmk_spdinfo {
	u32 incnt;
	u32 outcnt;
	u32 fwdcnt;
	u32 inscnt;
	u32 outscnt;
	u32 fwdscnt;
	u32 spdhcnt;
	u32 spdhmcnt;
};

struct xfrm_flo {
	struct dst_entry___83 *dst_orig;
	u8 flags;
};

struct module___385;

struct file___459;

struct kiocb___459;

struct iov_iter___226;

struct poll_table_struct___298;

struct vm_area_struct___460;

struct inode___459;

struct file_lock___459;

struct page___460;

struct pipe_inode_info___140;

struct seq_file___398;

struct file_operations___459 {
	struct module___385 *owner;
	loff_t (*llseek)(struct file___459 *, loff_t, int);
	ssize_t (*read)(struct file___459 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___459 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___459 *, struct iov_iter___226 *);
	ssize_t (*write_iter)(struct kiocb___459 *, struct iov_iter___226 *);
	int (*iopoll)(struct kiocb___459 *, bool);
	int (*iterate)(struct file___459 *, struct dir_context *);
	int (*iterate_shared)(struct file___459 *, struct dir_context *);
	__poll_t (*poll)(struct file___459 *, struct poll_table_struct___298 *);
	long int (*unlocked_ioctl)(struct file___459 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___459 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___459 *, struct vm_area_struct___460 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___459 *, struct file___459 *);
	int (*flush)(struct file___459 *, fl_owner_t);
	int (*release)(struct inode___459 *, struct file___459 *);
	int (*fsync)(struct file___459 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___459 *, int);
	int (*lock)(struct file___459 *, int, struct file_lock___459 *);
	ssize_t (*sendpage)(struct file___459 *, struct page___460 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___459 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___459 *, int, struct file_lock___459 *);
	ssize_t (*splice_write)(struct pipe_inode_info___140 *, struct file___459 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___459 *, loff_t *, struct pipe_inode_info___140 *, size_t, unsigned int);
	int (*setlease)(struct file___459 *, long int, struct file_lock___459 **, void **);
	long int (*fallocate)(struct file___459 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___398 *, struct file___459 *);
	ssize_t (*copy_file_range)(struct file___459 *, loff_t, struct file___459 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___459 *, loff_t, struct file___459 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___459 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___460 {
	u64 seqnum;
	struct vm_area_struct___460 *vmas[4];
};

struct page_frag___460 {
	struct page___460 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___460;

struct mem_cgroup___192;

struct pid___257;

struct cred___427;

struct nsproxy___354;

struct signal_struct___334;

struct bio_list___249;

struct backing_dev_info___249;

struct css_set___308;

struct vm_struct___363;

struct task_struct___461 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___461 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___460 *mm;
	struct mm_struct___460 *active_mm;
	struct vmacache___460 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___461 *real_parent;
	struct task_struct___461 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___461 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___192 *active_memcg;
	long int rh_reserved2;
	struct pid___257 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___257 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___257 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___427 *ptracer_cred;
	const struct cred___427 *real_cred;
	const struct cred___427 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___354 *nsproxy;
	struct signal_struct___334 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___461 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___249 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___249 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___308 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___140 *splice_pipe;
	struct page_frag___460 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___192 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___461 *oom_reaper_list;
	struct vm_struct___363 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___156 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct secondary_data___461 {
	void *stack;
	struct task_struct___461 *task;
	long int status;
};

enum xfrm_ae_ftype_t {
	XFRM_AE_UNSPEC = 0,
	XFRM_AE_RTHR = 1,
	XFRM_AE_RVAL = 2,
	XFRM_AE_LVAL = 4,
	XFRM_AE_ETHR = 8,
	XFRM_AE_CR = 16,
	XFRM_AE_CE = 32,
	XFRM_AE_CU = 64,
	__XFRM_AE_MAX = 65,
};

enum xfrm_nlgroups {
	XFRMNLGRP_NONE = 0,
	XFRMNLGRP_ACQUIRE = 1,
	XFRMNLGRP_EXPIRE = 2,
	XFRMNLGRP_SA = 3,
	XFRMNLGRP_POLICY = 4,
	XFRMNLGRP_AEVENTS = 5,
	XFRMNLGRP_REPORT = 6,
	XFRMNLGRP_MIGRATE = 7,
	XFRMNLGRP_MAPPING = 8,
	__XFRMNLGRP_MAX = 9,
};

typedef struct page___460 *pgtable_t___460;

struct address_space___459;

struct dev_pagemap___447;

struct page___460 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___459 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___460 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___460 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___460 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___447 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___192 *mem_cgroup;
};

struct pglist_data___460;

struct lruvec___460 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___460 *pgdat;
};

struct zone___460 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___460 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___460 {
	struct zone___460 *zone;
	int zone_idx;
};

struct zonelist___460 {
	struct zoneref___460 _zonerefs[25];
};

struct pglist_data___460 {
	struct zone___460 node_zones[3];
	struct zonelist___460 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___461 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___461 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___460 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___461 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___461 *owner;
};

struct blocking_notifier_head___460 {
	struct rw_semaphore___461 rwsem;
	struct notifier_block *head;
};

struct cgroup___308;

struct cgroup_subsys___308;

struct cgroup_subsys_state___308 {
	struct cgroup___308 *cgroup;
	struct cgroup_subsys___308 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___308 *parent;
};

struct kernfs_node___454;

struct cgroup_file___308 {
	struct kernfs_node___454 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___192;

struct mem_cgroup___192 {
	struct cgroup_subsys_state___308 css;
	struct mem_cgroup_id___16 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___308 events_file;
	struct cgroup_file___308 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___461 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___192 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___257;

struct upid___257 {
	int nr;
	struct pid_namespace___257 *ns;
};

struct dentry___459;

struct user_namespace___324;

struct ucounts___324;

struct pid_namespace___257 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___461 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___257 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___459 *proc_self;
	struct dentry___459 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___324 *user_ns;
	struct ucounts___324 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___29 ns;
};

struct pid___257 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___257 numbers[1];
};

struct key___427;

struct user_namespace___324 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___324 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___29 ns;
	long unsigned int flags;
	struct key___427 *persistent_keyring_register;
	struct rw_semaphore___461 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___324 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct user_struct___427 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___427 *uid_keyring;
	struct key___427 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___447;

struct vm_area_struct___460 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___460 *vm_next;
	struct vm_area_struct___460 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___460 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___447 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___459 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___460;

struct mm_struct___460 {
	struct {
		struct vm_area_struct___460 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___459 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___461 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___460 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___461 *owner;
		struct user_namespace___324 *user_ns;
		struct file___459 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___460 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___427 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___427 *session_keyring;
	struct key___427 *process_keyring;
	struct key___427 *thread_keyring;
	struct key___427 *request_key_auth;
	void *security;
	struct user_struct___427 *user;
	struct user_namespace___324 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___115;

struct cgroup_namespace___308;

struct nsproxy___354 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___257 *pid_ns_for_children;
	struct net___115 *net_ns;
	struct cgroup_namespace___308 *cgroup_ns;
};

struct signal_struct___334 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___461 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___461 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___257 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___257 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___460 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___257 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___249;

struct bio_list___249 {
	struct bio___249 *head;
	struct bio___249 *tail;
};

struct bdi_writeback_congested___249;

struct bdi_writeback___249 {
	struct backing_dev_info___249 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___249 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___308 *memcg_css;
	struct cgroup_subsys_state___308 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___427;

struct backing_dev_info___249 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___249 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___427 *dev;
	struct device___427 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___459 *debug_dir;
	struct dentry___459 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___308 {
	struct cgroup_subsys_state___308 *subsys[13];
	refcount_t refcount;
	struct css_set___308 *dom_cset;
	struct cgroup___308 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___308 *mg_src_cgrp;
	struct cgroup___308 *mg_dst_cgrp;
	struct css_set___308 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___459;

struct pipe_buffer___140;

struct pipe_inode_info___140 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___460 *tmp_page;
	struct fasync_struct___459 *fasync_readers;
	struct fasync_struct___459 *fasync_writers;
	struct pipe_buffer___140 *bufs;
	struct user_struct___427 *user;
};

struct vm_struct___363 {
	struct vm_struct___363 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___460 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___346 {
	struct task_struct___461 task;
	long unsigned int stack[8192];
};

struct address_space_operations___459;

struct address_space___459 {
	struct inode___459 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___461 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___459 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___447)(struct vm_area_struct___460 *, long unsigned int, const struct page___460 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___447)(struct page___460 *, void *);

struct dev_pagemap___447 {
	dev_page_fault_t___447 page_fault;
	dev_page_free_t___447 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___427 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___460 {
	struct vfsmount *mnt;
	struct dentry___459 *dentry;
};

struct fown_struct___257 {
	rwlock_t lock;
	struct pid___257 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___459 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___460 f_path;
	struct inode___459 *f_inode;
	const struct file_operations___459 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___257 f_owner;
	const struct cred___427 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___459 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___447;

struct vm_operations_struct___447 {
	void (*open)(struct vm_area_struct___460 *);
	void (*close)(struct vm_area_struct___460 *);
	int (*split)(struct vm_area_struct___460 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___460 *);
	vm_fault_t (*fault)(struct vm_fault___447 *);
	vm_fault_t (*huge_fault)(struct vm_fault___447 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___447 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___460 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___447 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___447 *);
	int (*access)(struct vm_area_struct___460 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___460 *);
	int (*set_policy)(struct vm_area_struct___460 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___460 *, long unsigned int);
	struct page___460 * (*find_special_page)(struct vm_area_struct___460 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___460 {
	struct task_struct___461 *task;
	struct core_thread___460 *next;
};

struct core_state___460 {
	atomic_t nr_threads;
	struct core_thread___460 dumper;
	struct completion startup;
};

struct vm_fault___447 {
	struct vm_area_struct___460 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___460 *cow_page;
	struct mem_cgroup___192 *memcg;
	struct page___460 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___460 prealloc_pte;
};

struct kset___446;

struct kobj_type___446;

struct kobject___447 {
	const char *name;
	struct list_head entry;
	struct kobject___447 *parent;
	struct kset___446 *kset;
	struct kobj_type___446 *ktype;
	struct kernfs_node___454 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___385 {
	struct kobject___447 kobj;
	struct module___385 *mod;
	struct kobject___447 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___385 {
	struct module___385 *mod;
	struct latch_tree_node node;
};

struct module_layout___385 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___385 mtn;
};

struct module_attribute___385;

struct kernel_param___385;

struct module___385 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___385 mkobj;
	struct module_attribute___385 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___447 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___385 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___385 core_layout;
	struct module_layout___385 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide53;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide54;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bio_vec___251 {
	struct page___460 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___226 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___251 *bvec;
		struct pipe_inode_info___140 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct msghdr___87 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___226 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___459 *msg_iocb;
};

struct kiocb___459 {
	struct file___459 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___459 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dentry_operations___459;

struct super_block___459;

struct dentry___459 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___459 *d_parent;
	struct qstr d_name;
	struct inode___459 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___459 *d_op;
	struct super_block___459 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___459;

struct block_device___459;

struct inode___459 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___459 *i_op;
	struct super_block___459 *i_sb;
	struct address_space___459 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___461 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___249 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___459 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___459 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___140 *i_pipe;
		struct block_device___459 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___459 {
	int (*d_revalidate)(struct dentry___459 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___459 *, unsigned int);
	int (*d_hash)(const struct dentry___459 *, struct qstr *);
	int (*d_compare)(const struct dentry___459 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___459 *);
	int (*d_init)(struct dentry___459 *);
	void (*d_release)(struct dentry___459 *);
	void (*d_prune)(struct dentry___459 *);
	void (*d_iput)(struct dentry___459 *, struct inode___459 *);
	char * (*d_dname)(struct dentry___459 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___460 *);
	int (*d_manage)(const struct path___460 *, bool);
	struct dentry___459 * (*d_real)(struct dentry___459 *, const struct inode___459 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___459;

struct mem_dqinfo___459 {
	struct quota_format_type___459 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___459;

struct quota_info___459 {
	unsigned int flags;
	struct rw_semaphore___461 dqio_sem;
	struct inode___459 *files[3];
	struct mem_dqinfo___459 info[3];
	const struct quota_format_ops___459 *ops[3];
};

struct rcuwait___459 {
	struct task_struct___461 *task;
};

struct percpu_rw_semaphore___459 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___461 rw_sem;
	struct rcuwait___459 writer;
	int readers_block;
};

struct sb_writers___459 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___459 rw_sem[3];
};

struct shrink_control___192;

struct shrinker___192 {
	long unsigned int (*count_objects)(struct shrinker___192 *, struct shrink_control___192 *);
	long unsigned int (*scan_objects)(struct shrinker___192 *, struct shrink_control___192 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___459;

struct super_operations___459;

struct dquot_operations___459;

struct quotactl_ops___459;

struct super_block___459 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___459 *s_type;
	const struct super_operations___459 *s_op;
	const struct dquot_operations___459 *dq_op;
	const struct quotactl_ops___459 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___459 *s_root;
	struct rw_semaphore___461 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___459 *s_bdev;
	struct backing_dev_info___249 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___459 s_dquot;
	struct sb_writers___459 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___459 *s_d_op;
	int cleancache_poolid;
	struct shrinker___192 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___324 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___192 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___192 *memcg;
};

struct iattr___459 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___459 *ia_file;
};

struct dquot___459 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___459 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___459 {
	int qf_fmt_id;
	const struct quota_format_ops___459 *qf_ops;
	struct module___385 *qf_owner;
	struct quota_format_type___459 *qf_next;
};

struct quota_format_ops___459 {
	int (*check_quota_file)(struct super_block___459 *, int);
	int (*read_file_info)(struct super_block___459 *, int);
	int (*write_file_info)(struct super_block___459 *, int);
	int (*free_file_info)(struct super_block___459 *, int);
	int (*read_dqblk)(struct dquot___459 *);
	int (*commit_dqblk)(struct dquot___459 *);
	int (*release_dqblk)(struct dquot___459 *);
	int (*get_next_id)(struct super_block___459 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___459 {
	int (*write_dquot)(struct dquot___459 *);
	struct dquot___459 * (*alloc_dquot)(struct super_block___459 *, int);
	void (*destroy_dquot)(struct dquot___459 *);
	int (*acquire_dquot)(struct dquot___459 *);
	int (*release_dquot)(struct dquot___459 *);
	int (*mark_dirty)(struct dquot___459 *);
	int (*write_info)(struct super_block___459 *, int);
	qsize_t * (*get_reserved_space)(struct inode___459 *);
	int (*get_projid)(struct inode___459 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___459 *, qsize_t *);
	int (*get_next_id)(struct super_block___459 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___459 {
	int (*quota_on)(struct super_block___459 *, int, int, const struct path___460 *);
	int (*quota_off)(struct super_block___459 *, int);
	int (*quota_enable)(struct super_block___459 *, unsigned int);
	int (*quota_disable)(struct super_block___459 *, unsigned int);
	int (*quota_sync)(struct super_block___459 *, int);
	int (*set_info)(struct super_block___459 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___459 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___459 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___459 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___459 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___459 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___212;

struct address_space_operations___459 {
	int (*writepage)(struct page___460 *, struct writeback_control___212 *);
	int (*readpage)(struct file___459 *, struct page___460 *);
	int (*writepages)(struct address_space___459 *, struct writeback_control___212 *);
	int (*set_page_dirty)(struct page___460 *);
	int (*readpages)(struct file___459 *, struct address_space___459 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___459 *, struct address_space___459 *, loff_t, unsigned int, unsigned int, struct page___460 **, void **);
	int (*write_end)(struct file___459 *, struct address_space___459 *, loff_t, unsigned int, unsigned int, struct page___460 *, void *);
	sector_t (*bmap)(struct address_space___459 *, sector_t);
	void (*invalidatepage)(struct page___460 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___460 *, gfp_t);
	void (*freepage)(struct page___460 *);
	ssize_t (*direct_IO)(struct kiocb___459 *, struct iov_iter___226 *);
	int (*migratepage)(struct address_space___459 *, struct page___460 *, struct page___460 *, enum migrate_mode);
	bool (*isolate_page)(struct page___460 *, isolate_mode_t);
	void (*putback_page)(struct page___460 *);
	int (*launder_page)(struct page___460 *);
	int (*is_partially_uptodate)(struct page___460 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___460 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___459 *, struct page___460 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___459 *, sector_t *);
	void (*swap_deactivate)(struct file___459 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___212 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___249 *wb;
	struct inode___459 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___459 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___459 *bd_inode;
	struct super_block___459 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___459 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___249 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___459 {
	struct dentry___459 * (*lookup)(struct inode___459 *, struct dentry___459 *, unsigned int);
	const char * (*get_link)(struct dentry___459 *, struct inode___459 *, struct delayed_call *);
	int (*permission)(struct inode___459 *, int);
	struct posix_acl * (*get_acl)(struct inode___459 *, int);
	int (*readlink)(struct dentry___459 *, char *, int);
	int (*create)(struct inode___459 *, struct dentry___459 *, umode_t, bool);
	int (*link)(struct dentry___459 *, struct inode___459 *, struct dentry___459 *);
	int (*unlink)(struct inode___459 *, struct dentry___459 *);
	int (*symlink)(struct inode___459 *, struct dentry___459 *, const char *);
	int (*mkdir)(struct inode___459 *, struct dentry___459 *, umode_t);
	int (*rmdir)(struct inode___459 *, struct dentry___459 *);
	int (*mknod)(struct inode___459 *, struct dentry___459 *, umode_t, dev_t);
	int (*rename)(struct inode___459 *, struct dentry___459 *, struct inode___459 *, struct dentry___459 *, unsigned int);
	int (*setattr)(struct dentry___459 *, struct iattr___459 *);
	int (*getattr)(const struct path___460 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___459 *, char *, size_t);
	int (*fiemap)(struct inode___459 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___459 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___459 *, struct dentry___459 *, struct file___459 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___459 *, struct dentry___459 *, umode_t);
	int (*set_acl)(struct inode___459 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___459 {
	void (*fl_copy_lock)(struct file_lock___459 *, struct file_lock___459 *);
	void (*fl_release_private)(struct file_lock___459 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___459;

struct file_lock___459 {
	struct file_lock___459 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___459 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___459 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___459 *fl_ops;
	const struct lock_manager_operations___459 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___459 {
	int (*lm_compare_owner)(struct file_lock___459 *, struct file_lock___459 *);
	long unsigned int (*lm_owner_key)(struct file_lock___459 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___459 *);
	int (*lm_grant)(struct file_lock___459 *, int);
	bool (*lm_break)(struct file_lock___459 *);
	int (*lm_change)(struct file_lock___459 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___459 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___459 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___459 *fa_next;
	struct file___459 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___459 {
	const char *name;
	int fs_flags;
	struct dentry___459 * (*mount)(struct file_system_type___459 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___459 *);
	struct module___385 *owner;
	struct file_system_type___459 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___459 {
	struct inode___459 * (*alloc_inode)(struct super_block___459 *);
	void (*destroy_inode)(struct inode___459 *);
	void (*dirty_inode)(struct inode___459 *, int);
	int (*write_inode)(struct inode___459 *, struct writeback_control___212 *);
	int (*drop_inode)(struct inode___459 *);
	void (*evict_inode)(struct inode___459 *);
	void (*put_super)(struct super_block___459 *);
	int (*sync_fs)(struct super_block___459 *, int);
	int (*freeze_super)(struct super_block___459 *);
	int (*freeze_fs)(struct super_block___459 *);
	int (*thaw_super)(struct super_block___459 *);
	int (*unfreeze_fs)(struct super_block___459 *);
	int (*statfs)(struct dentry___459 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___459 *, int *, char *);
	void (*umount_begin)(struct super_block___459 *);
	int (*show_options)(struct seq_file___398 *, struct dentry___459 *);
	int (*show_devname)(struct seq_file___398 *, struct dentry___459 *);
	int (*show_path)(struct seq_file___398 *, struct dentry___459 *);
	int (*show_stats)(struct seq_file___398 *, struct dentry___459 *);
	ssize_t (*quota_read)(struct super_block___459 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___459 *, int, const char *, size_t, loff_t);
	struct dquot___459 ** (*get_dquots)(struct inode___459 *);
	int (*bdev_try_to_free_page)(struct super_block___459 *, struct page___460 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___459 *, struct shrink_control___192 *);
	long int (*free_cached_objects)(struct super_block___459 *, struct shrink_control___192 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___308)(struct file___459 *, wait_queue_head_t *, struct poll_table_struct___298 *);

struct poll_table_struct___298 {
	poll_queue_proc___308 _qproc;
	__poll_t _key;
};

struct seq_operations___398;

struct seq_file___398 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___398 *op;
	int poll_event;
	const struct file___459 *file;
	void *private;
};

typedef void bio_end_io_t___249(struct bio___249 *);

struct bio_integrity_payload___249;

struct bio_set___249;

struct bio___249 {
	struct bio___249 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___249 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___249 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___251 *bi_io_vec;
	struct bio_set___249 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___251 bi_inline_vecs[0];
};

struct socket_wq___85 {
	wait_queue_head_t wait;
	struct fasync_struct___459 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct sock___84;

struct proto_ops___85;

struct socket___86 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___85 *wq;
	struct file___459 *file;
	struct sock___84 *sk;
	const struct proto_ops___85 *ops;
};

typedef struct {
	struct net___115 *net;
} possible_net_t___106;

struct proto___84;

struct sock_common___84 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___84 *skc_prot;
	possible_net_t___106 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___84 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___105;

struct sk_buff_head___104 {
	struct sk_buff___105 *next;
	struct sk_buff___105 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___84;

struct xfrm_policy___21;

struct dst_entry___84;

struct net_device___104;

struct sock___84 {
	struct sock_common___84 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___104 sk_error_queue;
	struct sk_buff_head___104 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___105 *head;
		struct sk_buff___105 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___84 *sk_filter;
	union {
		struct socket_wq___85 *sk_wq;
		struct socket_wq___85 *sk_wq_raw;
	};
	struct xfrm_policy___21 *sk_policy[2];
	struct dst_entry___84 *sk_rx_dst;
	struct dst_entry___84 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___105 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___104 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___460 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___84 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___257 *sk_peer_pid;
	const struct cred___427 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___86 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___192 *sk_memcg;
	void (*sk_state_change)(struct sock___84 *);
	void (*sk_data_ready)(struct sock___84 *);
	void (*sk_write_space)(struct sock___84 *);
	void (*sk_error_report)(struct sock___84 *);
	int (*sk_backlog_rcv)(struct sock___84 *, struct sk_buff___105 *);
	struct sk_buff___105 * (*sk_validate_xmit_skb)(struct sock___84 *, struct net_device___104 *, struct sk_buff___105 *);
	void (*sk_destruct)(struct sock___84 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

typedef int (*sk_read_actor_t___84)(read_descriptor_t *, struct sk_buff___105 *, unsigned int, size_t);

struct proto_ops___85 {
	int family;
	struct module___385 *owner;
	int (*release)(struct socket___86 *);
	int (*bind)(struct socket___86 *, struct sockaddr *, int);
	int (*connect)(struct socket___86 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___86 *, struct socket___86 *);
	int (*accept)(struct socket___86 *, struct socket___86 *, int, bool);
	int (*getname)(struct socket___86 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___459 *, struct socket___86 *, struct poll_table_struct___298 *);
	int (*ioctl)(struct socket___86 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___86 *, int);
	int (*shutdown)(struct socket___86 *, int);
	int (*setsockopt)(struct socket___86 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___86 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___86 *, struct msghdr___87 *, size_t);
	int (*recvmsg)(struct socket___86 *, struct msghdr___87 *, size_t, int);
	int (*mmap)(struct file___459 *, struct socket___86 *, struct vm_area_struct___460 *);
	ssize_t (*sendpage)(struct socket___86 *, struct page___460 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___86 *, loff_t *, struct pipe_inode_info___140 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___84 *, int);
	int (*peek_len)(struct socket___86 *);
	int (*read_sock)(struct sock___84 *, read_descriptor_t *, sk_read_actor_t___84);
	int (*sendpage_locked)(struct sock___84 *, struct page___460 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___84 *, struct msghdr___87 *, size_t);
	int (*set_rcvlowat)(struct sock___84 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct sec_path___21;

struct nf_bridge_info___104;

struct sk_buff___105 {
	union {
		struct {
			struct sk_buff___105 *next;
			struct sk_buff___105 *prev;
			union {
				struct net_device___104 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___84 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___105 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path___21 *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___104 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___104;

struct netns_frags___104 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___104 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ip_ra_chain___50;

struct fib_rules_ops___84;

struct fib_notifier_ops___85;

struct netns_ipv4___104 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___50 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___84 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___84 *fibnl;
	struct sock___84 **icmp_sk;
	struct sock___84 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___84 **tcp_sk;
	struct netns_frags___104 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___84 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___85 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___85 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___84;

struct dst_ops___115 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___115 *);
	struct dst_entry___84 * (*check)(struct dst_entry___84 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___84 *);
	unsigned int (*mtu)(const struct dst_entry___84 *);
	u32 * (*cow_metrics)(struct dst_entry___84 *, long unsigned int);
	void (*destroy)(struct dst_entry___84 *);
	void (*ifdown)(struct dst_entry___84 *, struct net_device___104 *, int);
	struct dst_entry___84 * (*negative_advice)(struct dst_entry___84 *);
	void (*link_failure)(struct sk_buff___105 *);
	void (*update_pmtu)(struct dst_entry___84 *, struct sock___84 *, struct sk_buff___105 *, u32);
	void (*redirect)(struct dst_entry___84 *, struct sock___84 *, struct sk_buff___105 *);
	int (*local_out)(struct net___115 *, struct sock___84 *, struct sk_buff___105 *);
	struct neighbour___84 * (*neigh_lookup)(const struct dst_entry___84 *, struct sk_buff___105 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___84 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_info___26;

struct rt6_info___26;

struct fib6_table___26;

struct netns_ipv6___115 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___104 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info___26 *fib6_null_entry;
	struct rt6_info___26 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___26 *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___115 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info___26 *ip6_prohibit_entry;
	struct rt6_info___26 *ip6_blk_hole_entry;
	struct fib6_table___26 *fib6_local_tbl;
	struct fib_rules_ops___84 *fib6_rules_ops;
	struct sock___84 **icmp_sk;
	struct sock___84 *ndisc_sk;
	struct sock___84 *tcp_sk;
	struct sock___84 *igmp_sk;
	struct sock___84 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___84 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___85 *notifier_ops;
	struct fib_notifier_ops___85 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___85 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___84 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___104 {
	struct netns_frags___104 frags;
};

struct netns_xfrm___115 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___84 *nlsk;
	struct sock___84 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___115 xfrm4_dst_ops;
	struct dst_ops___115 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___94;

struct net___115 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___324 *user_ns;
	struct ucounts___324 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___29 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___84 *rtnl;
	struct sock___84 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___104 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___104 ipv4;
	struct netns_ipv6___115 ipv6;
	struct netns_sctp___85 sctp;
	struct netns_nf___19 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___104 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___84 *nfnl;
	struct sock___84 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___115 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___84 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___94 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kernfs_root___453;

struct kernfs_elem_dir___453 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___453 *root;
};

struct kernfs_syscall_ops___453;

struct kernfs_root___453 {
	struct kernfs_node___454 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___453 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___453 {
	struct kernfs_node___454 *target_kn;
};

struct kernfs_ops___453;

struct kernfs_elem_attr___453 {
	const struct kernfs_ops___453 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___454 *notify_next;
};

struct kernfs_node___454 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___454 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___453 dir;
		struct kernfs_elem_symlink___453 symlink;
		struct kernfs_elem_attr___453 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___453;

struct kernfs_ops___453 {
	int (*open)(struct kernfs_open_file___453 *);
	void (*release)(struct kernfs_open_file___453 *);
	int (*seq_show)(struct seq_file___398 *, void *);
	void * (*seq_start)(struct seq_file___398 *, loff_t *);
	void * (*seq_next)(struct seq_file___398 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___398 *, void *);
	ssize_t (*read)(struct kernfs_open_file___453 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___453 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___453 *, struct vm_area_struct___460 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___453 *, struct poll_table_struct___298 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___453 {
	int (*remount_fs)(struct kernfs_root___453 *, int *, char *);
	int (*show_options)(struct seq_file___398 *, struct kernfs_root___453 *);
	int (*mkdir)(struct kernfs_node___454 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___454 *);
	int (*rename)(struct kernfs_node___454 *, struct kernfs_node___454 *, const char *);
	int (*show_path)(struct seq_file___398 *, struct kernfs_node___454 *, struct kernfs_root___453 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___453 {
	struct kernfs_node___454 *kn;
	struct file___459 *file;
	struct seq_file___398 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___447 *vm_ops;
};

struct kobj_ns_type_operations___84 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___84 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___423;

struct attribute_group___424 {
	const char *name;
	umode_t (*is_visible)(struct kobject___447 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___447 *, struct bin_attribute___423 *, int);
	struct attribute **attrs;
	struct bin_attribute___423 **bin_attrs;
};

struct bin_attribute___423 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___459 *, struct kobject___447 *, struct bin_attribute___423 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___459 *, struct kobject___447 *, struct bin_attribute___423 *, char *, loff_t, size_t);
	int (*mmap)(struct file___459 *, struct kobject___447 *, struct bin_attribute___423 *, struct vm_area_struct___460 *);
};

struct sysfs_ops___446 {
	ssize_t (*show)(struct kobject___447 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___447 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___446;

struct kset___446 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___447 kobj;
	const struct kset_uevent_ops___446 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___446 {
	void (*release)(struct kobject___447 *);
	const struct sysfs_ops___446 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___84 * (*child_ns_type)(struct kobject___447 *);
	const void * (*namespace)(struct kobject___447 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___446 {
	int (* const filter)(struct kset___446 *, struct kobject___447 *);
	const char * (* const name)(struct kset___446 *, struct kobject___447 *);
	int (* const uevent)(struct kset___446 *, struct kobject___447 *, struct kobj_uevent_env *);
};

struct kobj_attribute___437 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___447 *, struct kobj_attribute___437 *, char *);
	ssize_t (*store)(struct kobject___447 *, struct kobj_attribute___437 *, const char *, size_t);
};

struct dev_pm_ops___427 {
	int (*prepare)(struct device___427 *);
	void (*complete)(struct device___427 *);
	int (*suspend)(struct device___427 *);
	int (*resume)(struct device___427 *);
	int (*freeze)(struct device___427 *);
	int (*thaw)(struct device___427 *);
	int (*poweroff)(struct device___427 *);
	int (*restore)(struct device___427 *);
	int (*suspend_late)(struct device___427 *);
	int (*resume_early)(struct device___427 *);
	int (*freeze_late)(struct device___427 *);
	int (*thaw_early)(struct device___427 *);
	int (*poweroff_late)(struct device___427 *);
	int (*restore_early)(struct device___427 *);
	int (*suspend_noirq)(struct device___427 *);
	int (*resume_noirq)(struct device___427 *);
	int (*freeze_noirq)(struct device___427 *);
	int (*thaw_noirq)(struct device___427 *);
	int (*poweroff_noirq)(struct device___427 *);
	int (*restore_noirq)(struct device___427 *);
	int (*runtime_suspend)(struct device___427 *);
	int (*runtime_resume)(struct device___427 *);
	int (*runtime_idle)(struct device___427 *);
};

struct dev_pm_info___427 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___427 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___427;

struct bus_type___427;

struct device_driver___427;

struct dev_pm_domain___427;

struct dma_map_ops___199;

struct fwnode_handle___347;

struct class___427;

struct device___427 {
	struct device___427 *parent;
	struct device_private *p;
	struct kobject___447 kobj;
	const char *init_name;
	const struct device_type___427 *type;
	struct mutex mutex;
	struct bus_type___427 *bus;
	struct device_driver___427 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___427 power;
	struct dev_pm_domain___427 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___199 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___347 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___427 *class;
	const struct attribute_group___424 **groups;
	void (*release)(struct device___427 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___427 {
	struct dev_pm_ops___427 ops;
	void (*detach)(struct device___427 *, bool);
	int (*activate)(struct device___427 *);
	void (*sync)(struct device___427 *);
	void (*dismiss)(struct device___427 *);
};

struct bus_type___427 {
	const char *name;
	const char *dev_name;
	struct device___427 *dev_root;
	const struct attribute_group___424 **bus_groups;
	const struct attribute_group___424 **dev_groups;
	const struct attribute_group___424 **drv_groups;
	int (*match)(struct device___427 *, struct device_driver___427 *);
	int (*uevent)(struct device___427 *, struct kobj_uevent_env *);
	int (*probe)(struct device___427 *);
	int (*remove)(struct device___427 *);
	void (*shutdown)(struct device___427 *);
	int (*online)(struct device___427 *);
	int (*offline)(struct device___427 *);
	int (*suspend)(struct device___427 *, pm_message_t);
	int (*resume)(struct device___427 *);
	int (*num_vf)(struct device___427 *);
	int (*dma_configure)(struct device___427 *);
	const struct dev_pm_ops___427 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___427 {
	const char *name;
	struct bus_type___427 *bus;
	struct module___385 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___427 *);
	int (*remove)(struct device___427 *);
	void (*shutdown)(struct device___427 *);
	int (*suspend)(struct device___427 *, pm_message_t);
	int (*resume)(struct device___427 *);
	const struct attribute_group___424 **groups;
	const struct dev_pm_ops___427 *pm;
	void (*coredump)(struct device___427 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___427 {
	const char *name;
	const struct attribute_group___424 **groups;
	int (*uevent)(struct device___427 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___427 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___427 *);
	const struct dev_pm_ops___427 *pm;
};

struct class___427 {
	const char *name;
	struct module___385 *owner;
	const struct attribute_group___424 **class_groups;
	const struct attribute_group___424 **dev_groups;
	struct kobject___447 *dev_kobj;
	int (*dev_uevent)(struct device___427 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___427 *, umode_t *);
	void (*class_release)(struct class___427 *);
	void (*dev_release)(struct device___427 *);
	int (*shutdown_pre)(struct device___427 *);
	const struct kobj_ns_type_operations___84 *ns_type;
	const void * (*namespace)(struct device___427 *);
	const struct dev_pm_ops___427 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___199 {
	void * (*alloc)(struct device___427 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___427 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___427 *, struct vm_area_struct___460 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___427 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___427 *, struct page___460 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___427 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___427 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___427 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___427 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___427 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___427 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___427 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___427 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___427 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___427 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___427 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___427 *, u64);
	u64 (*get_required_mask)(struct device___427 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___347;

struct fwnode_handle___347 {
	struct fwnode_handle___347 *secondary;
	const struct fwnode_operations___347 *ops;
};

typedef void compound_page_dtor___447(struct page___460 *);

struct fwnode_reference_args___347;

struct fwnode_endpoint___347;

struct fwnode_operations___347 {
	struct fwnode_handle___347 * (*get)(struct fwnode_handle___347 *);
	void (*put)(struct fwnode_handle___347 *);
	bool (*device_is_available)(const struct fwnode_handle___347 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___347 *, const struct device___427 *);
	bool (*property_present)(const struct fwnode_handle___347 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___347 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___347 *, const char *, const char **, size_t);
	struct fwnode_handle___347 * (*get_parent)(const struct fwnode_handle___347 *);
	struct fwnode_handle___347 * (*get_next_child_node)(const struct fwnode_handle___347 *, struct fwnode_handle___347 *);
	struct fwnode_handle___347 * (*get_named_child_node)(const struct fwnode_handle___347 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___347 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___347 *);
	struct fwnode_handle___347 * (*graph_get_next_endpoint)(const struct fwnode_handle___347 *, struct fwnode_handle___347 *);
	struct fwnode_handle___347 * (*graph_get_remote_endpoint)(const struct fwnode_handle___347 *);
	struct fwnode_handle___347 * (*graph_get_port_parent)(struct fwnode_handle___347 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___347 *, struct fwnode_endpoint___347 *);
};

struct fwnode_endpoint___347 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___347 *local_fwnode;
};

struct fwnode_reference_args___347 {
	struct fwnode_handle___347 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___140;

struct pipe_buffer___140 {
	struct page___460 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___140 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___140 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___140 *, struct pipe_buffer___140 *);
	void (*release)(struct pipe_inode_info___140 *, struct pipe_buffer___140 *);
	int (*steal)(struct pipe_inode_info___140 *, struct pipe_buffer___140 *);
	union {
		bool (*get)(struct pipe_inode_info___140 *, struct pipe_buffer___140 *);
		struct {
			void (*get)(struct pipe_inode_info___140 *, struct pipe_buffer___140 *);
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
};

struct nf_bridge_info___104 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___104 = 0,
		BRNF_PROTO_8021Q___104 = 1,
		BRNF_PROTO_PPPOE___104 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___104 *physindev;
	struct net_device___104 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___104(struct sk_buff___105 **);

struct net_device_ops___104;

struct ethtool_ops___104;

struct l3mdev_ops___84;

struct ndisc_ops___55;

struct xfrmdev_ops___104;

struct tlsdev_ops___104;

struct header_ops___104;

struct inet6_dev___55;

struct netdev_rx_queue___104;

struct mini_Qdisc___96;

struct netdev_queue___104;

struct Qdisc___96;

struct rtnl_link_ops___96;

struct dcbnl_rtnl_ops___104;

struct net_device___104 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___104 *netdev_ops;
	const struct ethtool_ops___104 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___84 *l3mdev_ops;
	const struct ndisc_ops___55 *ndisc_ops;
	const struct xfrmdev_ops___104 *xfrmdev_ops;
	const struct tlsdev_ops___104 *tlsdev_ops;
	const struct header_ops___104 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___446 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___55 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___104 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___94 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___104 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___96 *miniq_ingress;
	struct netdev_queue___104 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___104 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___96 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___96 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___104 = 0,
		NETREG_REGISTERED___104 = 1,
		NETREG_UNREGISTERING___104 = 2,
		NETREG_UNREGISTERED___104 = 3,
		NETREG_RELEASED___104 = 4,
		NETREG_DUMMY___104 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___104 = 0,
		RTNL_LINK_INITIALIZING___104 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___104 *);
	struct netpoll_info *npinfo;
	possible_net_t___106 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___427 dev;
	const struct attribute_group___424 *sysfs_groups[4];
	const struct attribute_group___424 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___96 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___104 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct xfrm_state___21;

struct sec_path___21 {
	refcount_t refcnt;
	int len;
	int olen;
	struct xfrm_state___21 *xvec[6];
	struct xfrm_offload ovec[1];
};

typedef int (*key_restrict_link_func_t___428)(struct key___427 *, const struct key_type *, const union key_payload *, struct key___427 *);

struct key_restriction___427;

struct key___427 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___461 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___427 *restrict_link;
};

struct key_restriction___427 {
	key_restrict_link_func_t___428 check;
	struct key___427 *key;
	struct key_type *keytype;
};

struct cgroup_namespace___308 {
	refcount_t count;
	struct ns_common___29 ns;
	struct user_namespace___324 *user_ns;
	struct ucounts___324 *ucounts;
	struct css_set___308 *root_cset;
};

struct ucounts___324 {
	struct hlist_node node;
	struct user_namespace___324 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct ethtool_ops___104 {
	int (*get_settings)(struct net_device___104 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___104 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___104 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___104 *);
	void (*get_regs)(struct net_device___104 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___104 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___104 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___104 *);
	void (*set_msglevel)(struct net_device___104 *, u32);
	int (*nway_reset)(struct net_device___104 *);
	u32 (*get_link)(struct net_device___104 *);
	int (*get_eeprom_len)(struct net_device___104 *);
	int (*get_eeprom)(struct net_device___104 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___104 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___104 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___104 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___104 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___104 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___104 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___104 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___104 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___104 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___104 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___104 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___104 *);
	void (*complete)(struct net_device___104 *);
	u32 (*get_priv_flags)(struct net_device___104 *);
	int (*set_priv_flags)(struct net_device___104 *, u32);
	int (*get_sset_count)(struct net_device___104 *, int);
	int (*get_rxnfc)(struct net_device___104 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___104 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___104 *, struct ethtool_flash *);
	int (*reset)(struct net_device___104 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___104 *);
	u32 (*get_rxfh_indir_size)(struct net_device___104 *);
	int (*get_rxfh)(struct net_device___104 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___104 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___104 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___104 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___104 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___104 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___104 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___104 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___104 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___104 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___104 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___104 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___104 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___104 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___104 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___104 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___104 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___104 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___104 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___104 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___104 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___104 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	int (*get_fecparam)(struct net_device___104 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___104 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___104 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___104 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___104 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___104;

struct inet_frags___104 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___104 *, const void *);
	void (*destructor)(struct inet_frag_queue___104 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___104 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___105 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___105 *fragments_tail;
	struct sk_buff___105 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___104 *net;
	struct callback_head rcu;
};

struct ip_ra_chain___50 {
	struct ip_ra_chain___50 *next;
	struct sock___84 *sk;
	union {
		void (*destructor)(struct sock___84 *);
		struct sock___84 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___84;

struct fib_lookup_arg___84;

struct fib_rules_ops___84 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___84 *, struct flowi *, int, struct fib_lookup_arg___84 *);
	bool (*suppress)(struct fib_rule___84 *, struct fib_lookup_arg___84 *);
	int (*match)(struct fib_rule___84 *, struct flowi *, int);
	int (*configure)(struct fib_rule___84 *, struct sk_buff___105 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___84 *);
	int (*compare)(struct fib_rule___84 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___84 *, struct sk_buff___105 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___84 *);
	void (*flush_cache)(struct fib_rules_ops___84 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___385 *owner;
	struct net___115 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___85 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___115 *);
	int (*fib_dump)(struct net___115 *, struct notifier_block *);
	struct module___385 *owner;
	struct callback_head rcu;
};

struct dst_entry___84 {
	struct net_device___104 *dev;
	struct dst_ops___115 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state___21 *xfrm;
	int (*input)(struct sk_buff___105 *);
	int (*output)(struct net___115 *, struct sock___84 *, struct sk_buff___105 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___84;

struct neigh_parms___84;

struct neigh_ops___84;

struct neighbour___84 {
	struct neighbour___84 *next;
	struct neigh_table___84 *tbl;
	struct neigh_parms___84 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___104 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___84 *, struct sk_buff___105 *);
	const struct neigh_ops___84 *ops;
	struct callback_head rcu;
	struct net_device___104 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct fib6_nh___26 {
	struct in6_addr nh_gw;
	struct net_device___104 *nh_dev;
	struct lwtunnel_state *nh_lwtstate;
	unsigned int nh_flags;
	atomic_t nh_upper_bound;
	int nh_weight;
};

struct fib6_node___26;

struct fib6_info___26 {
	struct fib6_table___26 *fib6_table;
	struct fib6_info___26 *fib6_next;
	struct fib6_node___26 *fib6_node;
	struct list_head fib6_siblings;
	unsigned int fib6_nsiblings;
	atomic_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	struct rt6_info___26 **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
	long unsigned int last_probe;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 exception_bucket_flushed: 1;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 dst_host: 1;
	u8 fib6_destroying: 1;
	u8 unused: 2;
	struct fib6_nh___26 fib6_nh;
	struct callback_head rcu;
};

struct rt6_info___26 {
	struct dst_entry___84 dst;
	struct fib6_info___26 *from;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___55 *rt6i_idev;
	u32 rt6i_flags;
	struct rt6key rt6i_prefsrc;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct fib6_node___26 {
	struct fib6_node___26 *parent;
	struct fib6_node___26 *left;
	struct fib6_node___26 *right;
	struct fib6_info___26 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info___26 *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table___26 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node___26 tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

struct bpf_prog_aux___97;

struct bpf_prog___94 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___97 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

struct seq_operations___398 {
	void * (*start)(struct seq_file___398 *, loff_t *);
	void (*stop)(struct seq_file___398 *, void *);
	void * (*next)(struct seq_file___398 *, void *, loff_t *);
	int (*show)(struct seq_file___398 *, void *);
};

struct pernet_operations___105 {
	struct list_head list;
	int (*init)(struct net___115 *);
	void (*exit)(struct net___115 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___104 {
	int (*ieee_getets)(struct net_device___104 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___104 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___104 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___104 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___104 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___104 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___104 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___104 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___104 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___104 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___104 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___104 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___104 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___104 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___104 *);
	u8 (*setstate)(struct net_device___104 *, u8);
	void (*getpermhwaddr)(struct net_device___104 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___104 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___104 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___104 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___104 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___104 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___104 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___104 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___104 *, int, u8 *);
	void (*setpfccfg)(struct net_device___104 *, int, u8);
	void (*getpfccfg)(struct net_device___104 *, int, u8 *);
	u8 (*setall)(struct net_device___104 *);
	u8 (*getcap)(struct net_device___104 *, int, u8 *);
	int (*getnumtcs)(struct net_device___104 *, int, u8 *);
	int (*setnumtcs)(struct net_device___104 *, int, u8);
	u8 (*getpfcstate)(struct net_device___104 *);
	void (*setpfcstate)(struct net_device___104 *, u8);
	void (*getbcncfg)(struct net_device___104 *, int, u32 *);
	void (*setbcncfg)(struct net_device___104 *, int, u32);
	void (*getbcnrp)(struct net_device___104 *, int, u8 *);
	void (*setbcnrp)(struct net_device___104 *, int, u8);
	int (*setapp)(struct net_device___104 *, u8, u16, u8);
	int (*getapp)(struct net_device___104 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___104 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___104 *, int, u8);
	u8 (*getdcbx)(struct net_device___104 *);
	u8 (*setdcbx)(struct net_device___104 *, u8);
	int (*peer_getappinfo)(struct net_device___104 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___104 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___104 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___104 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___104 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___104 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct bpf_map___309;

struct bpf_map_ops___308 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___309 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___309 *, struct file___459 *);
	void (*map_free)(struct bpf_map___309 *);
	int (*map_get_next_key)(struct bpf_map___309 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___309 *);
	void * (*map_lookup_elem)(struct bpf_map___309 *, void *);
	int (*map_update_elem)(struct bpf_map___309 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___309 *, void *);
	int (*map_push_elem)(struct bpf_map___309 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___309 *, void *);
	int (*map_peek_elem)(struct bpf_map___309 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___309 *, struct file___459 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___309 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___309 *, void *, struct seq_file___398 *);
	int (*map_check_btf)(const struct bpf_map___309 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___309 {
	const struct bpf_map_ops___308 *ops;
	struct bpf_map___309 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___427 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___104;

struct bpf_map_dev_ops___104 {
	int (*map_get_next_key)(struct bpf_offloaded_map___104 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___104 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___104 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___104 *, void *);
};

struct bpf_offloaded_map___104 {
	struct bpf_map___309 map;
	struct net_device___104 *netdev;
	const struct bpf_map_dev_ops___104 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___94 {
	int (*test_run)(struct bpf_prog___94 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___94 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___94 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___94 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___94 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___94 *, u32 *);
};

struct bpf_prog_offload_ops___94 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___94 *);
	int (*translate)(struct bpf_prog___94 *);
	void (*destroy)(struct bpf_prog___94 *);
};

struct bpf_prog_offload___94 {
	struct bpf_prog___94 *prog;
	struct net_device___104 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___94 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___97 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___94 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___94 *ops;
	struct bpf_map___309 **used_maps;
	struct bpf_prog___94 *prog;
	struct user_struct___427 *user;
	u64 load_time;
	struct bpf_map___309 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___94 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___94 {
	struct bpf_prog___94 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___94 {
	struct callback_head rcu;
	struct bpf_prog_array_item___94 items[0];
};

struct cgroup_bpf___94 {
	struct bpf_prog_array___94 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___94 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___309;

typedef void (*kthread_work_func_t___309)(struct kthread_work___309 *);

struct kthread_worker___309;

struct kthread_work___309 {
	struct list_head node;
	kthread_work_func_t___309 func;
	struct kthread_worker___309 *worker;
	int canceling;
};

struct kthread_worker___309 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___461 *task;
	struct kthread_work___309 *current_work;
};

struct kthread_delayed_work___308 {
	struct kthread_work___309 work;
	struct timer_list timer;
};

struct psi_group___308 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___309 *poll_kworker;
	struct kthread_delayed_work___308 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___308;

struct cgroup_rstat_cpu___308;

struct cgroup___308 {
	struct cgroup_subsys_state___308 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___454 *kn;
	struct cgroup_file___308 procs_file;
	struct cgroup_file___308 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___308 *subsys[13];
	struct cgroup_root___308 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___308 *dom_cgrp;
	struct cgroup_rstat_cpu___308 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___94 bpf;
	atomic_t congestion_count;
	struct cgroup___308 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___308 psi;
	int ancestor_ids[0];
};

struct cftype___308;

struct cgroup_subsys___308 {
	struct cgroup_subsys_state___308 * (*css_alloc)(struct cgroup_subsys_state___308 *);
	int (*css_online)(struct cgroup_subsys_state___308 *);
	void (*css_offline)(struct cgroup_subsys_state___308 *);
	void (*css_released)(struct cgroup_subsys_state___308 *);
	void (*css_free)(struct cgroup_subsys_state___308 *);
	void (*css_reset)(struct cgroup_subsys_state___308 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___308 *, int);
	int (*css_extra_stat_show)(struct seq_file___398 *, struct cgroup_subsys_state___308 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___461 *);
	void (*cancel_fork)(struct task_struct___461 *);
	void (*fork)(struct task_struct___461 *);
	void (*exit)(struct task_struct___461 *);
	void (*free)(struct task_struct___461 *);
	void (*bind)(struct cgroup_subsys_state___308 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___308 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___308 *dfl_cftypes;
	struct cftype___308 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___308 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___308 *updated_children;
	struct cgroup___308 *updated_next;
};

struct cgroup_root___308 {
	struct kernfs_root___453 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___308 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___308 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___308 *ss;
	struct list_head node;
	struct kernfs_ops___453 *kf_ops;
	int (*open)(struct kernfs_open_file___453 *);
	void (*release)(struct kernfs_open_file___453 *);
	u64 (*read_u64)(struct cgroup_subsys_state___308 *, struct cftype___308 *);
	s64 (*read_s64)(struct cgroup_subsys_state___308 *, struct cftype___308 *);
	int (*seq_show)(struct seq_file___398 *, void *);
	void * (*seq_start)(struct seq_file___398 *, loff_t *);
	void * (*seq_next)(struct seq_file___398 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___398 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___308 *, struct cftype___308 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___308 *, struct cftype___308 *, s64);
	ssize_t (*write)(struct kernfs_open_file___453 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___453 *, struct poll_table_struct___298 *);
};

struct xdp_rxq_info___104 {
	struct net_device___104 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___104 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___104 *dev_rx;
};

struct netlink_callback___106 {
	struct sk_buff___105 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___106 *);
	int (*dump)(struct sk_buff___105 *, struct netlink_callback___106 *);
	int (*done)(struct netlink_callback___106 *);
	void *data;
	struct module___385 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___104 {
	int (*create)(struct sk_buff___105 *, struct net_device___104 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___105 *, unsigned char *);
	int (*cache)(const struct neighbour___84 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___104 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___104 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___104 *, int);
	int poll_owner;
	struct net_device___104 *dev;
	struct sk_buff___105 *gro_list;
	struct sk_buff___105 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___104 {
	struct net_device___104 *dev;
	struct Qdisc___96 *qdisc;
	struct Qdisc___96 *qdisc_sleeping;
	struct kobject___447 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___104 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___96 {
	struct sk_buff___105 *head;
	struct sk_buff___105 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___96;

struct Qdisc___96 {
	int (*enqueue)(struct sk_buff___105 *, struct Qdisc___96 *, struct sk_buff___105 **);
	struct sk_buff___105 * (*dequeue)(struct Qdisc___96 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___96 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___104 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___104 gso_skb;
	struct qdisc_skb_head___96 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___96 *next_sched;
	struct sk_buff_head___104 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___104 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___447 kobj;
	struct net_device___104 *dev;
	long: 64;
	struct xdp_rxq_info___104 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___104)(struct net_device___104 *, struct sk_buff___105 *, struct net_device___104 *);

struct netdev_bpf___104 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___94 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___94 *prog;
			const struct bpf_prog_offload_ops___94 *ops;
		} verifier;
		struct {
			struct bpf_prog___94 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___104 *offmap;
		};
		struct {
			struct xdp_umem___3 *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___104 {
	int (*xdo_dev_state_add)(struct xfrm_state___21 *);
	void (*xdo_dev_state_delete)(struct xfrm_state___21 *);
	void (*xdo_dev_state_free)(struct xfrm_state___21 *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___105 *, struct xfrm_state___21 *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state___21 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct xfrm_state_offload___21 {
	struct net_device___104 *dev;
	long unsigned int offload_handle;
	unsigned int num_exthdrs;
	u8 flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct xfrm_replay___21;

struct xfrm_type___21;

struct xfrm_mode___21;

struct xfrm_type_offload___21;

struct xfrm_state___21 {
	possible_net_t___106 xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	refcount_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
		u32 output_mark;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	const char *geniv;
	struct xfrm_encap_tmpl *encap;
	xfrm_address_t *coaddr;
	struct xfrm_state___21 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	const struct xfrm_replay___21 *repl;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct tasklet_hrtimer mtimer;
	struct xfrm_state_offload___21 xso;
	long int saved_tmo;
	long unsigned int lastused;
	struct page_frag___460 xfrag;
	const struct xfrm_type___21 *type;
	struct xfrm_mode___21 *inner_mode;
	struct xfrm_mode___21 *inner_mode_iaf;
	struct xfrm_mode___21 *outer_mode;
	const struct xfrm_type_offload___21 *type_offload;
	struct xfrm_sec_ctx___2 *security;
	void *data;
	u32 output_mark_mask;
	u32 if_id;
};

struct tlsdev_ops___104 {
	int (*tls_dev_add)(struct net_device___104 *, struct sock___84 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___104 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___104 *, struct sock___84 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___104 {
	int (*ndo_init)(struct net_device___104 *);
	void (*ndo_uninit)(struct net_device___104 *);
	int (*ndo_open)(struct net_device___104 *);
	int (*ndo_stop)(struct net_device___104 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___105 *, struct net_device___104 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___105 *, struct net_device___104 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___104 *, struct sk_buff___105 *, struct net_device___104 *, select_queue_fallback_t___104);
	void (*ndo_change_rx_flags)(struct net_device___104 *, int);
	void (*ndo_set_rx_mode)(struct net_device___104 *);
	int (*ndo_set_mac_address)(struct net_device___104 *, void *);
	int (*ndo_validate_addr)(struct net_device___104 *);
	int (*ndo_do_ioctl)(struct net_device___104 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___104 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___104 *, int);
	int (*ndo_neigh_setup)(struct net_device___104 *, struct neigh_parms___84 *);
	void (*ndo_tx_timeout)(struct net_device___104 *);
	void (*ndo_get_stats64)(struct net_device___104 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___104 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___104 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___104 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___104 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___104 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___104 *);
	int (*ndo_netpoll_setup)(struct net_device___104 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___104 *);
	int (*ndo_set_vf_mac)(struct net_device___104 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___104 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___104 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___104 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___104 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___104 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___104 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___104 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___104 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___104 *, int, struct sk_buff___105 *);
	int (*ndo_set_vf_guid)(struct net_device___104 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___104 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___104 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___104 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___104 *, const struct sk_buff___105 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___104 *, struct net_device___104 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___104 *, struct net_device___104 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___104 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___104 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___104 *, struct neighbour___84 *);
	void (*ndo_neigh_destroy)(struct net_device___104 *, struct neighbour___84 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___104 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___104 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___104 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___105 *, struct netlink_callback___106 *, struct net_device___104 *, struct net_device___104 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___104 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___104 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___105 *, u32, u32, struct net_device___104 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___104 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___104 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___104 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___104 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___104 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___104 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___104 *, struct net_device___104 *);
	void (*ndo_dfwd_del_station)(struct net_device___104 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___104 *);
	int (*ndo_set_tx_maxrate)(struct net_device___104 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___104 *);
	int (*ndo_change_proto_down)(struct net_device___104 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___104 *, struct sk_buff___105 *);
	void (*ndo_set_rx_headroom)(struct net_device___104 *, int);
	int (*ndo_bpf)(struct net_device___104 *, struct netdev_bpf___104 *);
	int (*ndo_xdp_xmit)(struct net_device___104 *, int, struct xdp_frame___104 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___104 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___104 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___84 {
	possible_net_t___106 net;
	struct net_device___104 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___84 *);
	void (*neigh_cleanup)(struct neighbour___84 *);
	struct neigh_table___84 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___84 {
	u32 (*l3mdev_fib_table)(const struct net_device___104 *);
	struct sk_buff___105 * (*l3mdev_l3_rcv)(struct net_device___104 *, struct sk_buff___105 *, u16);
	struct sk_buff___105 * (*l3mdev_l3_out)(struct net_device___104 *, struct sock___84 *, struct sk_buff___105 *, u16);
	struct dst_entry___84 * (*l3mdev_link_scope_lookup)(const struct net_device___104 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct ndisc_ops___55 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___104 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___104 *, struct neighbour___84 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___104 *, u8, struct neighbour___84 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___104 *, struct sk_buff___105 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___115 *, struct net_device___104 *, const struct prefix_info *, struct inet6_dev___55 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___55;

struct ifacaddr6___26;

struct inet6_dev___55 {
	struct net_device___104 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___55 *mc_list;
	struct ifmcaddr6___55 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___26 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	u8 rndid[8];
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___84 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
};

struct tcf_proto___96;

struct mini_Qdisc___96 {
	struct tcf_proto___96 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___96 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___104 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___115 *, struct net_device___104 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___104 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___104 *, struct list_head *);
	size_t (*get_size)(const struct net_device___104 *);
	int (*fill_info)(struct sk_buff___105 *, const struct net_device___104 *);
	size_t (*get_xstats_size)(const struct net_device___104 *);
	int (*fill_xstats)(struct sk_buff___105 *, const struct net_device___104 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___104 *, struct net_device___104 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___104 *, const struct net_device___104 *);
	int (*fill_slave_info)(struct sk_buff___105 *, const struct net_device___104 *, const struct net_device___104 *);
	struct net___115 * (*get_link_net)(const struct net_device___104 *);
	size_t (*get_linkxstats_size)(const struct net_device___104 *, int);
	int (*fill_linkxstats)(struct sk_buff___105 *, const struct net_device___104 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___104 {
	struct list_head poll_list;
	struct sk_buff_head___104 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___104 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___96 *output_queue;
	struct Qdisc___96 **output_queue_tailp;
	struct sk_buff___105 *completion_queue;
	struct sk_buff_head___104 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___104 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___104 input_pkt_queue;
	struct napi_struct___104 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bdi_writeback_congested___249 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___249 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___249 {
	struct bio___249 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___251 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___251 bip_inline_vecs[0];
};

struct bio_set___249 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___249 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___192 {
	struct mem_cgroup___192 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___192 {
	struct lruvec___460 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___192 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___192 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct kernel_param_ops___385 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___385 *);
	int (*get)(char *, const struct kernel_param___385 *);
	void (*free)(void *);
};

struct kparam_array___385;

struct kernel_param___385 {
	const char *name;
	struct module___385 *mod;
	const struct kernel_param_ops___385 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___385 *arr;
	};
};

struct kparam_array___385 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___385 *ops;
	void *elem;
};

struct module_attribute___385 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___385 *, struct module_kobject___385 *, char *);
	ssize_t (*store)(struct module_attribute___385 *, struct module_kobject___385 *, const char *, size_t);
	void (*setup)(struct module___385 *, const char *);
	int (*test)(struct module___385 *);
	void (*free)(struct module___385 *);
};

struct gnet_dump___96 {
	spinlock_t *lock;
	struct sk_buff___105 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___96;

struct Qdisc_ops___96 {
	struct Qdisc_ops___96 *next;
	const struct Qdisc_class_ops___96 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___105 *, struct Qdisc___96 *, struct sk_buff___105 **);
	struct sk_buff___105 * (*dequeue)(struct Qdisc___96 *);
	struct sk_buff___105 * (*peek)(struct Qdisc___96 *);
	int (*init)(struct Qdisc___96 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___96 *);
	void (*destroy)(struct Qdisc___96 *);
	int (*change)(struct Qdisc___96 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___96 *);
	int (*change_tx_queue_len)(struct Qdisc___96 *, unsigned int);
	int (*dump)(struct Qdisc___96 *, struct sk_buff___105 *);
	int (*dump_stats)(struct Qdisc___96 *, struct gnet_dump___96 *);
	void (*ingress_block_set)(struct Qdisc___96 *, u32);
	void (*egress_block_set)(struct Qdisc___96 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___96 *);
	u32 (*egress_block_get)(struct Qdisc___96 *);
	struct module___385 *owner;
};

struct tcf_block___96;

struct Qdisc_class_ops___96 {
	unsigned int flags;
	struct netdev_queue___104 * (*select_queue)(struct Qdisc___96 *, struct tcmsg *);
	int (*graft)(struct Qdisc___96 *, long unsigned int, struct Qdisc___96 *, struct Qdisc___96 **, struct netlink_ext_ack *);
	struct Qdisc___96 * (*leaf)(struct Qdisc___96 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___96 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___96 *, u32);
	int (*change)(struct Qdisc___96 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___96 *, long unsigned int);
	void (*walk)(struct Qdisc___96 *, struct qdisc_walker *);
	struct tcf_block___96 * (*tcf_block)(struct Qdisc___96 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___96 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___96 *, long unsigned int);
	int (*dump)(struct Qdisc___96 *, long unsigned int, struct sk_buff___105 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___96 *, long unsigned int, struct gnet_dump___96 *);
};

struct tcf_chain___96;

struct tcf_block___96 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___115 *net;
	struct Qdisc___96 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___96 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___96;

struct tcf_proto_ops___96;

struct tcf_proto___96 {
	struct tcf_proto___96 *next;
	void *root;
	int (*classify)(struct sk_buff___105 *, const struct tcf_proto___96 *, struct tcf_result___96 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___96 *ops;
	struct tcf_chain___96 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___96 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___96 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___96 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___105 *, const struct tcf_proto___96 *, struct tcf_result___96 *);
	int (*init)(struct tcf_proto___96 *);
	void (*destroy)(struct tcf_proto___96 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___96 *, u32);
	void (*put)(struct tcf_proto___96 *, void *);
	int (*change)(struct net___115 *, struct sk_buff___105 *, struct tcf_proto___96 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___96 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___96 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___96 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___115 *, struct tcf_chain___96 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___115 *, struct tcf_proto___96 *, void *, struct sk_buff___105 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___105 *, struct net___115 *, void *);
	struct module___385 *owner;
	int flags;
};

struct tcf_chain___96 {
	struct mutex filter_chain_lock;
	struct tcf_proto___96 *filter_chain;
	struct list_head list;
	struct tcf_block___96 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___96 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___84 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___94 *prog;
};

struct bpf_redirect_info___94 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___309 *map;
	struct bpf_map___309 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___84;

struct neigh_hash_table___84;

struct neigh_table___84 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___104 *, __u32 *);
	bool (*key_eq)(const struct neighbour___84 *, const void *);
	int (*constructor)(struct neighbour___84 *);
	int (*pconstructor)(struct pneigh_entry___84 *);
	void (*pdestructor)(struct pneigh_entry___84 *);
	void (*proxy_redo)(struct sk_buff___105 *);
	char *id;
	struct neigh_parms___84 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___104 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___84 *nht;
	struct pneigh_entry___84 **phash_buckets;
};

struct neigh_ops___84 {
	int family;
	void (*solicit)(struct neighbour___84 *, struct sk_buff___105 *);
	void (*error_report)(struct neighbour___84 *, struct sk_buff___105 *);
	int (*output)(struct neighbour___84 *, struct sk_buff___105 *);
	int (*connected_output)(struct neighbour___84 *, struct sk_buff___105 *);
};

struct pneigh_entry___84 {
	struct pneigh_entry___84 *next;
	possible_net_t___106 net;
	struct net_device___104 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___84 {
	struct neighbour___84 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___84 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___84 *ctarget;
	struct net___115 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___84 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___84 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___67;

struct timewait_sock_ops___63;

struct proto___84 {
	void (*close)(struct sock___84 *, long int);
	int (*pre_connect)(struct sock___84 *, struct sockaddr *, int);
	int (*connect)(struct sock___84 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___84 *, int);
	struct sock___84 * (*accept)(struct sock___84 *, int, int *, bool);
	int (*ioctl)(struct sock___84 *, int, long unsigned int);
	int (*init)(struct sock___84 *);
	void (*destroy)(struct sock___84 *);
	void (*shutdown)(struct sock___84 *, int);
	int (*setsockopt)(struct sock___84 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___84 *, int, int, char *, int *);
	void (*keepalive)(struct sock___84 *, int);
	int (*sendmsg)(struct sock___84 *, struct msghdr___87 *, size_t);
	int (*recvmsg)(struct sock___84 *, struct msghdr___87 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___84 *, struct page___460 *, int, size_t, int);
	int (*bind)(struct sock___84 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___84 *, struct sk_buff___105 *);
	void (*release_cb)(struct sock___84 *);
	int (*hash)(struct sock___84 *);
	void (*unhash)(struct sock___84 *);
	void (*rehash)(struct sock___84 *);
	int (*get_port)(struct sock___84 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___84 *);
	bool (*stream_memory_read)(const struct sock___84 *);
	void (*enter_memory_pressure)(struct sock___84 *);
	void (*leave_memory_pressure)(struct sock___84 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___67 *rsk_prot;
	struct timewait_sock_ops___63 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___385 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___84 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct xfrm_policy_queue___21 {
	struct sk_buff_head___104 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___21 {
	possible_net_t___106 xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	refcount_t refcnt;
	struct timer_list timer;
	atomic_t genid;
	u32 priority;
	u32 index;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___21 polq;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx___2 *security;
	struct xfrm_tmpl xfrm_vec[6];
	struct callback_head rcu;
	u32 if_id;
};

struct request_sock___68;

struct request_sock_ops___67 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___84 *, struct request_sock___68 *);
	void (*send_ack)(const struct sock___84 *, struct sk_buff___105 *, struct request_sock___68 *);
	void (*send_reset)(const struct sock___84 *, struct sk_buff___105 *);
	void (*destructor)(struct request_sock___68 *);
	void (*syn_ack_timeout)(const struct request_sock___68 *);
};

struct timewait_sock_ops___63 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___84 *, struct sock___84 *, void *);
	void (*twsk_destructor)(struct sock___84 *);
};

struct request_sock___68 {
	struct sock_common___84 __req_common;
	struct request_sock___68 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___67 *rsk_ops;
	struct sock___84 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___55 {
	struct in6_addr mca_addr;
	struct inet6_dev___55 *idev;
	struct ifmcaddr6___55 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___26 {
	struct in6_addr aca_addr;
	struct fib6_info___26 *aca_rt;
	struct ifacaddr6___26 *aca_next;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct ip6_ra_chain___55 {
	struct ip6_ra_chain___55 *next;
	struct sock___84 *sk;
	int sel;
	void (*destructor)(struct sock___84 *);
};

struct xfrm_replay___21 {
	void (*advance)(struct xfrm_state___21 *, __be32);
	int (*check)(struct xfrm_state___21 *, struct sk_buff___105 *, __be32);
	int (*recheck)(struct xfrm_state___21 *, struct sk_buff___105 *, __be32);
	void (*notify)(struct xfrm_state___21 *, int);
	int (*overflow)(struct xfrm_state___21 *, struct sk_buff___105 *);
};

struct xfrm_type___21 {
	char *description;
	struct module___385 *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___21 *);
	void (*destructor)(struct xfrm_state___21 *);
	int (*input)(struct xfrm_state___21 *, struct sk_buff___105 *);
	int (*output)(struct xfrm_state___21 *, struct sk_buff___105 *);
	int (*reject)(struct xfrm_state___21 *, struct sk_buff___105 *, const struct flowi *);
	int (*hdr_offset)(struct xfrm_state___21 *, struct sk_buff___105 *, u8 **);
	u32 (*get_mtu)(struct xfrm_state___21 *, int);
};

struct xfrm_state_afinfo___21;

struct xfrm_mode___21 {
	int (*input2)(struct xfrm_state___21 *, struct sk_buff___105 *);
	int (*input)(struct xfrm_state___21 *, struct sk_buff___105 *);
	int (*output2)(struct xfrm_state___21 *, struct sk_buff___105 *);
	int (*output)(struct xfrm_state___21 *, struct sk_buff___105 *);
	struct sk_buff___105 * (*gso_segment)(struct xfrm_state___21 *, struct sk_buff___105 *, netdev_features_t);
	void (*xmit)(struct xfrm_state___21 *, struct sk_buff___105 *);
	struct xfrm_state_afinfo___21 *afinfo;
	struct module___385 *owner;
	unsigned int encap;
	int flags;
};

struct xfrm_type_offload___21 {
	char *description;
	struct module___385 *owner;
	u8 proto;
	void (*encap)(struct xfrm_state___21 *, struct sk_buff___105 *);
	int (*input_tail)(struct xfrm_state___21 *, struct sk_buff___105 *);
	int (*xmit)(struct xfrm_state___21 *, struct sk_buff___105 *, netdev_features_t);
};

struct km_event {
	union {
		u32 hard;
		u32 proto;
		u32 byid;
		u32 aevent;
		u32 type;
	} data;
	u32 seq;
	u32 portid;
	u32 event;
	struct net___115 *net;
};

struct xfrm_state_afinfo___21 {
	unsigned int family;
	unsigned int proto;
	__be16 eth_proto;
	struct module___385 *owner;
	const struct xfrm_type___21 *type_map[256];
	const struct xfrm_type_offload___21 *type_offload_map[256];
	struct xfrm_mode___21 *mode_map[5];
	int (*init_flags)(struct xfrm_state___21 *);
	void (*init_tempsel)(struct xfrm_selector *, const struct flowi *);
	void (*init_temprop)(struct xfrm_state___21 *, const struct xfrm_tmpl *, const xfrm_address_t *, const xfrm_address_t *);
	int (*tmpl_sort)(struct xfrm_tmpl **, struct xfrm_tmpl **, int);
	int (*state_sort)(struct xfrm_state___21 **, struct xfrm_state___21 **, int);
	int (*output)(struct net___115 *, struct sock___84 *, struct sk_buff___105 *);
	int (*output_finish)(struct sock___84 *, struct sk_buff___105 *);
	int (*extract_input)(struct xfrm_state___21 *, struct sk_buff___105 *);
	int (*extract_output)(struct xfrm_state___21 *, struct sk_buff___105 *);
	int (*transport_finish)(struct sk_buff___105 *, int);
	void (*local_error)(struct sk_buff___105 *, u32);
};

enum {
	XFRM_MODE_FLAG_TUNNEL = 1,
};

struct xfrm_mgr {
	struct list_head list;
	int (*notify)(struct xfrm_state___21 *, const struct km_event *);
	int (*acquire)(struct xfrm_state___21 *, struct xfrm_tmpl *, struct xfrm_policy___21 *);
	struct xfrm_policy___21 * (*compile_policy)(struct sock___84 *, int, u8 *, int, int *);
	int (*new_mapping)(struct xfrm_state___21 *, xfrm_address_t *, __be16);
	int (*notify_policy)(struct xfrm_policy___21 *, int, const struct km_event *);
	int (*report)(struct net___115 *, u8, struct xfrm_selector *, xfrm_address_t *);
	int (*migrate)(const struct xfrm_selector *, u8, u8, const struct xfrm_migrate *, int, const struct xfrm_kmaddress *, const struct xfrm_encap_tmpl *);
	bool (*is_alive)(const struct km_event *);
};

struct xfrmk_sadinfo {
	u32 sadhcnt;
	u32 sadhmcnt;
	u32 sadcnt;
};

struct xfrm_input_afinfo___2 {
	unsigned int family;
	int (*callback)(struct sk_buff___85 *, u8, int);
};

struct ip_tunnel_6rd_parm {
	struct in6_addr prefix;
	__be32 relay_prefix;
	u16 prefixlen;
	u16 relay_prefixlen;
};

struct ip_tunnel_prl_entry;

struct ip_tunnel {
	struct ip_tunnel *next;
	struct hlist_node hash_node;
	struct net_device___84 *dev;
	struct net___95 *net;
	long unsigned int err_time;
	int err_count;
	u32 i_seqno;
	u32 o_seqno;
	int tun_hlen;
	u32 index;
	u8 erspan_ver;
	u8 dir;
	u16 hwid;
	struct dst_cache dst_cache;
	struct ip_tunnel_parm parms;
	int mlink;
	int encap_hlen;
	int hlen;
	struct ip_tunnel_encap encap;
	struct ip_tunnel_6rd_parm ip6rd;
	struct ip_tunnel_prl_entry *prl;
	unsigned int prl_count;
	unsigned int ip_tnl_net_id;
	struct gro_cells gro_cells;
	__u32 fwmark;
	bool collect_md;
	bool ignore_df;
};

struct __ip6_tnl_parm {
	char name[16];
	int link;
	__u8 proto;
	__u8 encap_limit;
	__u8 hop_limit;
	bool collect_md;
	__be32 flowinfo;
	__u32 flags;
	struct in6_addr laddr;
	struct in6_addr raddr;
	__be16 i_flags;
	__be16 o_flags;
	__be32 i_key;
	__be32 o_key;
	__u32 fwmark;
	__u32 index;
	__u8 erspan_ver;
	__u8 dir;
	__u16 hwid;
};

struct ip6_tnl {
	struct ip6_tnl *next;
	struct net_device___84 *dev;
	struct net___95 *net;
	struct __ip6_tnl_parm parms;
	struct flowi fl;
	struct dst_cache dst_cache;
	struct gro_cells gro_cells;
	int err_count;
	long unsigned int err_time;
	__u32 i_seqno;
	__u32 o_seqno;
	int hlen;
	int tun_hlen;
	int encap_hlen;
	struct ip_tunnel_encap encap;
	int mlink;
};

struct xfrm_skb_cb {
	struct xfrm_tunnel_skb_cb header;
	union {
		struct {
			__u32 low;
			__u32 hi;
		} output;
		struct {
			__be32 low;
			__be32 hi;
		} input;
	} seq;
};

struct ip_tunnel_prl_entry {
	struct ip_tunnel_prl_entry *next;
	__be32 addr;
	u16 flags;
	struct callback_head callback_head;
};

struct ip6_tnl_encap_ops___2 {
	size_t (*encap_hlen)(struct ip_tunnel_encap *);
	int (*build_header)(struct sk_buff___85 *, struct ip_tunnel_encap *, u8 *, struct flowi6 *);
};

struct xfrm_trans_tasklet {
	struct tasklet_struct tasklet;
	struct sk_buff_head___84 queue;
};

struct xfrm_trans_cb {
	union {
		struct inet_skb_parm h4;
		struct inet6_skb_parm h6;
	} header;
	int (*finish)(struct net___95 *, struct sock___65 *, struct sk_buff___85 *);
};

struct skb_frag_struct___29 {
	struct {
		struct page___460 *p;
	} page;
	__u32 page_offset;
	__u32 size;
};

typedef struct skb_frag_struct___29 skb_frag_t___29;

struct skb_shared_info___29 {
	__u8 __unused;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___105 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___29 frags[16];
};

struct xfrm_user_offload {
	int ifindex;
	__u8 flags;
};

struct netdev_notifier_info___11 {
	struct net_device___88 *dev;
	struct netlink_ext_ack *extack;
};

struct module___386;

struct file___460;

struct kiocb___460;

struct iov_iter___227;

struct poll_table_struct___299;

struct vm_area_struct___461;

struct inode___460;

struct file_lock___460;

struct page___461;

struct pipe_inode_info___141;

struct seq_file___399;

struct file_operations___460 {
	struct module___386 *owner;
	loff_t (*llseek)(struct file___460 *, loff_t, int);
	ssize_t (*read)(struct file___460 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___460 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___460 *, struct iov_iter___227 *);
	ssize_t (*write_iter)(struct kiocb___460 *, struct iov_iter___227 *);
	int (*iopoll)(struct kiocb___460 *, bool);
	int (*iterate)(struct file___460 *, struct dir_context *);
	int (*iterate_shared)(struct file___460 *, struct dir_context *);
	__poll_t (*poll)(struct file___460 *, struct poll_table_struct___299 *);
	long int (*unlocked_ioctl)(struct file___460 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___460 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___460 *, struct vm_area_struct___461 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___460 *, struct file___460 *);
	int (*flush)(struct file___460 *, fl_owner_t);
	int (*release)(struct inode___460 *, struct file___460 *);
	int (*fsync)(struct file___460 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___460 *, int);
	int (*lock)(struct file___460 *, int, struct file_lock___460 *);
	ssize_t (*sendpage)(struct file___460 *, struct page___461 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___460 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___460 *, int, struct file_lock___460 *);
	ssize_t (*splice_write)(struct pipe_inode_info___141 *, struct file___460 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___460 *, loff_t *, struct pipe_inode_info___141 *, size_t, unsigned int);
	int (*setlease)(struct file___460 *, long int, struct file_lock___460 **, void **);
	long int (*fallocate)(struct file___460 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___399 *, struct file___460 *);
	ssize_t (*copy_file_range)(struct file___460 *, loff_t, struct file___460 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___460 *, loff_t, struct file___460 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___460 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___461 {
	u64 seqnum;
	struct vm_area_struct___461 *vmas[4];
};

struct page_frag___461 {
	struct page___461 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___461;

struct mem_cgroup___193;

struct pid___258;

struct cred___428;

struct nsproxy___355;

struct signal_struct___335;

struct bio_list___250;

struct backing_dev_info___250;

struct css_set___309;

struct vm_struct___364;

struct task_struct___462 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___462 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___461 *mm;
	struct mm_struct___461 *active_mm;
	struct vmacache___461 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___462 *real_parent;
	struct task_struct___462 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___462 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___193 *active_memcg;
	long int rh_reserved2;
	struct pid___258 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___258 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___258 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___428 *ptracer_cred;
	const struct cred___428 *real_cred;
	const struct cred___428 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___355 *nsproxy;
	struct signal_struct___335 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___462 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___250 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___250 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___309 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___141 *splice_pipe;
	struct page_frag___461 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___193 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___462 *oom_reaper_list;
	struct vm_struct___364 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___156 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___461 *pgtable_t___461;

struct address_space___460;

struct dev_pagemap___448;

struct page___461 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___460 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___461 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___461 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___461 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___448 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___193 *mem_cgroup;
};

struct pglist_data___461;

struct lruvec___461 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___461 *pgdat;
};

struct zone___461 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___461 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___461 {
	struct zone___461 *zone;
	int zone_idx;
};

struct zonelist___461 {
	struct zoneref___461 _zonerefs[25];
};

struct pglist_data___461 {
	struct zone___461 node_zones[3];
	struct zonelist___461 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___462 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___462 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___461 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___462 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___462 *owner;
};

struct secondary_data___462 {
	void *stack;
	struct task_struct___462 *task;
	long int status;
};

struct blocking_notifier_head___461 {
	struct rw_semaphore___462 rwsem;
	struct notifier_block *head;
};

struct cgroup___309;

struct cgroup_subsys___309;

struct cgroup_subsys_state___309 {
	struct cgroup___309 *cgroup;
	struct cgroup_subsys___309 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___309 *parent;
};

struct kernfs_node___455;

struct cgroup_file___309 {
	struct kernfs_node___455 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___193;

struct mem_cgroup___193 {
	struct cgroup_subsys_state___309 css;
	struct mem_cgroup_id___13 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___309 events_file;
	struct cgroup_file___309 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___462 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___193 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___258;

struct upid___258 {
	int nr;
	struct pid_namespace___258 *ns;
};

struct dentry___460;

struct user_namespace___325;

struct ucounts___325;

struct pid_namespace___258 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___462 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___258 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___460 *proc_self;
	struct dentry___460 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___325 *user_ns;
	struct ucounts___325 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___29 ns;
};

struct pid___258 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___258 numbers[1];
};

struct key___428;

struct user_namespace___325 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___325 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___29 ns;
	long unsigned int flags;
	struct key___428 *persistent_keyring_register;
	struct rw_semaphore___462 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___325 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct user_struct___428 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___428 *uid_keyring;
	struct key___428 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___448;

struct vm_area_struct___461 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___461 *vm_next;
	struct vm_area_struct___461 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___461 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___448 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___460 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___461;

struct mm_struct___461 {
	struct {
		struct vm_area_struct___461 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___460 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___462 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___461 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___462 *owner;
		struct user_namespace___325 *user_ns;
		struct file___460 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___461 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___428 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___428 *session_keyring;
	struct key___428 *process_keyring;
	struct key___428 *thread_keyring;
	struct key___428 *request_key_auth;
	void *security;
	struct user_struct___428 *user;
	struct user_namespace___325 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___116;

struct cgroup_namespace___309;

struct nsproxy___355 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___258 *pid_ns_for_children;
	struct net___116 *net_ns;
	struct cgroup_namespace___309 *cgroup_ns;
};

struct signal_struct___335 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___462 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___462 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___258 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___258 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___461 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___258 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___250;

struct bio_list___250 {
	struct bio___250 *head;
	struct bio___250 *tail;
};

struct bdi_writeback_congested___250;

struct bdi_writeback___250 {
	struct backing_dev_info___250 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___250 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___309 *memcg_css;
	struct cgroup_subsys_state___309 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___428;

struct backing_dev_info___250 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___250 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___428 *dev;
	struct device___428 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___460 *debug_dir;
	struct dentry___460 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___309 {
	struct cgroup_subsys_state___309 *subsys[13];
	refcount_t refcount;
	struct css_set___309 *dom_cset;
	struct cgroup___309 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___309 *mg_src_cgrp;
	struct cgroup___309 *mg_dst_cgrp;
	struct css_set___309 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___460;

struct pipe_buffer___141;

struct pipe_inode_info___141 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___461 *tmp_page;
	struct fasync_struct___460 *fasync_readers;
	struct fasync_struct___460 *fasync_writers;
	struct pipe_buffer___141 *bufs;
	struct user_struct___428 *user;
};

struct vm_struct___364 {
	struct vm_struct___364 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___461 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___347 {
	struct task_struct___462 task;
	long unsigned int stack[8192];
};

struct address_space_operations___460;

struct address_space___460 {
	struct inode___460 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___462 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___460 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___448)(struct vm_area_struct___461 *, long unsigned int, const struct page___461 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___448)(struct page___461 *, void *);

struct dev_pagemap___448 {
	dev_page_fault_t___448 page_fault;
	dev_page_free_t___448 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___428 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___461 {
	struct vfsmount *mnt;
	struct dentry___460 *dentry;
};

struct fown_struct___258 {
	rwlock_t lock;
	struct pid___258 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___460 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___461 f_path;
	struct inode___460 *f_inode;
	const struct file_operations___460 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___258 f_owner;
	const struct cred___428 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___460 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___448;

struct vm_operations_struct___448 {
	void (*open)(struct vm_area_struct___461 *);
	void (*close)(struct vm_area_struct___461 *);
	int (*split)(struct vm_area_struct___461 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___461 *);
	vm_fault_t (*fault)(struct vm_fault___448 *);
	vm_fault_t (*huge_fault)(struct vm_fault___448 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___448 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___461 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___448 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___448 *);
	int (*access)(struct vm_area_struct___461 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___461 *);
	int (*set_policy)(struct vm_area_struct___461 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___461 *, long unsigned int);
	struct page___461 * (*find_special_page)(struct vm_area_struct___461 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___461 {
	struct task_struct___462 *task;
	struct core_thread___461 *next;
};

struct core_state___461 {
	atomic_t nr_threads;
	struct core_thread___461 dumper;
	struct completion startup;
};

struct vm_fault___448 {
	struct vm_area_struct___461 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___461 *cow_page;
	struct mem_cgroup___193 *memcg;
	struct page___461 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___461 prealloc_pte;
};

struct kset___447;

struct kobj_type___447;

struct kobject___448 {
	const char *name;
	struct list_head entry;
	struct kobject___448 *parent;
	struct kset___447 *kset;
	struct kobj_type___447 *ktype;
	struct kernfs_node___455 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___386 {
	struct kobject___448 kobj;
	struct module___386 *mod;
	struct kobject___448 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___386 {
	struct module___386 *mod;
	struct latch_tree_node node;
};

struct module_layout___386 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___386 mtn;
};

struct module_attribute___386;

struct kernel_param___386;

struct module___386 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___386 mkobj;
	struct module_attribute___386 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___448 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___386 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___386 core_layout;
	struct module_layout___386 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kernfs_root___454;

struct kernfs_elem_dir___454 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___454 *root;
};

struct kernfs_syscall_ops___454;

struct kernfs_root___454 {
	struct kernfs_node___455 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___454 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___454 {
	struct kernfs_node___455 *target_kn;
};

struct kernfs_ops___454;

struct kernfs_elem_attr___454 {
	const struct kernfs_ops___454 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___455 *notify_next;
};

struct kernfs_node___455 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___455 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___454 dir;
		struct kernfs_elem_symlink___454 symlink;
		struct kernfs_elem_attr___454 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___454;

struct kernfs_ops___454 {
	int (*open)(struct kernfs_open_file___454 *);
	void (*release)(struct kernfs_open_file___454 *);
	int (*seq_show)(struct seq_file___399 *, void *);
	void * (*seq_start)(struct seq_file___399 *, loff_t *);
	void * (*seq_next)(struct seq_file___399 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___399 *, void *);
	ssize_t (*read)(struct kernfs_open_file___454 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___454 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___454 *, struct vm_area_struct___461 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___454 *, struct poll_table_struct___299 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___454 {
	int (*remount_fs)(struct kernfs_root___454 *, int *, char *);
	int (*show_options)(struct seq_file___399 *, struct kernfs_root___454 *);
	int (*mkdir)(struct kernfs_node___455 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___455 *);
	int (*rename)(struct kernfs_node___455 *, struct kernfs_node___455 *, const char *);
	int (*show_path)(struct seq_file___399 *, struct kernfs_node___455 *, struct kernfs_root___454 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___399;

struct seq_file___399 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___399 *op;
	int poll_event;
	const struct file___460 *file;
	void *private;
};

struct kernfs_open_file___454 {
	struct kernfs_node___455 *kn;
	struct file___460 *file;
	struct seq_file___399 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___448 *vm_ops;
};

typedef void (*poll_queue_proc___309)(struct file___460 *, wait_queue_head_t *, struct poll_table_struct___299 *);

struct poll_table_struct___299 {
	poll_queue_proc___309 _qproc;
	__poll_t _key;
};

struct sock___85;

struct kobj_ns_type_operations___85 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___85 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___116 *net;
} possible_net_t___107;

struct proto___85;

struct sock_common___85 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___85 *skc_prot;
	possible_net_t___107 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___85 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___106;

struct sk_buff_head___105 {
	struct sk_buff___106 *next;
	struct sk_buff___106 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___85;

struct socket_wq___86;

struct xfrm_policy___22;

struct dst_entry___85;

struct socket___87;

struct net_device___105;

struct sock___85 {
	struct sock_common___85 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___105 sk_error_queue;
	struct sk_buff_head___105 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___106 *head;
		struct sk_buff___106 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___85 *sk_filter;
	union {
		struct socket_wq___86 *sk_wq;
		struct socket_wq___86 *sk_wq_raw;
	};
	struct xfrm_policy___22 *sk_policy[2];
	struct dst_entry___85 *sk_rx_dst;
	struct dst_entry___85 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___106 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___105 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___461 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___85 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___258 *sk_peer_pid;
	const struct cred___428 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___87 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___193 *sk_memcg;
	void (*sk_state_change)(struct sock___85 *);
	void (*sk_data_ready)(struct sock___85 *);
	void (*sk_write_space)(struct sock___85 *);
	void (*sk_error_report)(struct sock___85 *);
	int (*sk_backlog_rcv)(struct sock___85 *, struct sk_buff___106 *);
	struct sk_buff___106 * (*sk_validate_xmit_skb)(struct sock___85 *, struct net_device___105 *, struct sk_buff___106 *);
	void (*sk_destruct)(struct sock___85 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct bin_attribute___424;

struct attribute_group___425 {
	const char *name;
	umode_t (*is_visible)(struct kobject___448 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___448 *, struct bin_attribute___424 *, int);
	struct attribute **attrs;
	struct bin_attribute___424 **bin_attrs;
};

struct bin_attribute___424 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___460 *, struct kobject___448 *, struct bin_attribute___424 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___460 *, struct kobject___448 *, struct bin_attribute___424 *, char *, loff_t, size_t);
	int (*mmap)(struct file___460 *, struct kobject___448 *, struct bin_attribute___424 *, struct vm_area_struct___461 *);
};

struct sysfs_ops___447 {
	ssize_t (*show)(struct kobject___448 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___448 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___447;

struct kset___447 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___448 kobj;
	const struct kset_uevent_ops___447 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___447 {
	void (*release)(struct kobject___448 *);
	const struct sysfs_ops___447 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___85 * (*child_ns_type)(struct kobject___448 *);
	const void * (*namespace)(struct kobject___448 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___447 {
	int (* const filter)(struct kset___447 *, struct kobject___448 *);
	const char * (* const name)(struct kset___447 *, struct kobject___448 *);
	int (* const uevent)(struct kset___447 *, struct kobject___448 *, struct kobj_uevent_env *);
};

struct kobj_attribute___438 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___448 *, struct kobj_attribute___438 *, char *);
	ssize_t (*store)(struct kobject___448 *, struct kobj_attribute___438 *, const char *, size_t);
};

struct kernel_param_ops___386 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___386 *);
	int (*get)(char *, const struct kernel_param___386 *);
	void (*free)(void *);
};

struct kparam_array___386;

struct kernel_param___386 {
	const char *name;
	struct module___386 *mod;
	const struct kernel_param_ops___386 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___386 *arr;
	};
};

struct kparam_array___386 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___386 *ops;
	void *elem;
};

struct module_attribute___386 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___386 *, struct module_kobject___386 *, char *);
	ssize_t (*store)(struct module_attribute___386 *, struct module_kobject___386 *, const char *, size_t);
	void (*setup)(struct module___386 *, const char *);
	int (*test)(struct module___386 *);
	void (*free)(struct module___386 *);
};

struct sadb_alg {
	__u8 sadb_alg_id;
	__u8 sadb_alg_ivlen;
	__u16 sadb_alg_minbits;
	__u16 sadb_alg_maxbits;
	__u16 sadb_alg_reserved;
};

struct shrink_control___193 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___193 *memcg;
};

struct shrinker___193 {
	long unsigned int (*count_objects)(struct shrinker___193 *, struct shrink_control___193 *);
	long unsigned int (*scan_objects)(struct shrinker___193 *, struct shrink_control___193 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct dev_pm_info___428 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___428 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___428;

struct bus_type___428;

struct device_driver___428;

struct dev_pm_domain___428;

struct dma_map_ops___200;

struct fwnode_handle___348;

struct class___428;

struct device___428 {
	struct device___428 *parent;
	struct device_private *p;
	struct kobject___448 kobj;
	const char *init_name;
	const struct device_type___428 *type;
	struct mutex mutex;
	struct bus_type___428 *bus;
	struct device_driver___428 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___428 power;
	struct dev_pm_domain___428 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___200 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___348 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___428 *class;
	const struct attribute_group___425 **groups;
	void (*release)(struct device___428 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___460;

struct super_block___460;

struct dentry___460 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___460 *d_parent;
	struct qstr d_name;
	struct inode___460 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___460 *d_op;
	struct super_block___460 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___460;

struct block_device___460;

struct inode___460 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___460 *i_op;
	struct super_block___460 *i_sb;
	struct address_space___460 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___462 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___250 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___460 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___460 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___141 *i_pipe;
		struct block_device___460 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___460 {
	int (*d_revalidate)(struct dentry___460 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___460 *, unsigned int);
	int (*d_hash)(const struct dentry___460 *, struct qstr *);
	int (*d_compare)(const struct dentry___460 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___460 *);
	int (*d_init)(struct dentry___460 *);
	void (*d_release)(struct dentry___460 *);
	void (*d_prune)(struct dentry___460 *);
	void (*d_iput)(struct dentry___460 *, struct inode___460 *);
	char * (*d_dname)(struct dentry___460 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___461 *);
	int (*d_manage)(const struct path___461 *, bool);
	struct dentry___460 * (*d_real)(struct dentry___460 *, const struct inode___460 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___460;

struct mem_dqinfo___460 {
	struct quota_format_type___460 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___460;

struct quota_info___460 {
	unsigned int flags;
	struct rw_semaphore___462 dqio_sem;
	struct inode___460 *files[3];
	struct mem_dqinfo___460 info[3];
	const struct quota_format_ops___460 *ops[3];
};

struct rcuwait___460 {
	struct task_struct___462 *task;
};

struct percpu_rw_semaphore___460 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___462 rw_sem;
	struct rcuwait___460 writer;
	int readers_block;
};

struct sb_writers___460 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___460 rw_sem[3];
};

struct file_system_type___460;

struct super_operations___460;

struct dquot_operations___460;

struct quotactl_ops___460;

struct super_block___460 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___460 *s_type;
	const struct super_operations___460 *s_op;
	const struct dquot_operations___460 *dq_op;
	const struct quotactl_ops___460 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___460 *s_root;
	struct rw_semaphore___462 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___460 *s_bdev;
	struct backing_dev_info___250 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___460 s_dquot;
	struct sb_writers___460 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___460 *s_d_op;
	int cleancache_poolid;
	struct shrinker___193 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___325 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___460 {
	struct file___460 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___460 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___460 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___460 *ia_file;
};

struct dquot___460 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___460 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___460 {
	int qf_fmt_id;
	const struct quota_format_ops___460 *qf_ops;
	struct module___386 *qf_owner;
	struct quota_format_type___460 *qf_next;
};

struct quota_format_ops___460 {
	int (*check_quota_file)(struct super_block___460 *, int);
	int (*read_file_info)(struct super_block___460 *, int);
	int (*write_file_info)(struct super_block___460 *, int);
	int (*free_file_info)(struct super_block___460 *, int);
	int (*read_dqblk)(struct dquot___460 *);
	int (*commit_dqblk)(struct dquot___460 *);
	int (*release_dqblk)(struct dquot___460 *);
	int (*get_next_id)(struct super_block___460 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___460 {
	int (*write_dquot)(struct dquot___460 *);
	struct dquot___460 * (*alloc_dquot)(struct super_block___460 *, int);
	void (*destroy_dquot)(struct dquot___460 *);
	int (*acquire_dquot)(struct dquot___460 *);
	int (*release_dquot)(struct dquot___460 *);
	int (*mark_dirty)(struct dquot___460 *);
	int (*write_info)(struct super_block___460 *, int);
	qsize_t * (*get_reserved_space)(struct inode___460 *);
	int (*get_projid)(struct inode___460 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___460 *, qsize_t *);
	int (*get_next_id)(struct super_block___460 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___460 {
	int (*quota_on)(struct super_block___460 *, int, int, const struct path___461 *);
	int (*quota_off)(struct super_block___460 *, int);
	int (*quota_enable)(struct super_block___460 *, unsigned int);
	int (*quota_disable)(struct super_block___460 *, unsigned int);
	int (*quota_sync)(struct super_block___460 *, int);
	int (*set_info)(struct super_block___460 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___460 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___460 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___460 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___460 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___460 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___213;

struct address_space_operations___460 {
	int (*writepage)(struct page___461 *, struct writeback_control___213 *);
	int (*readpage)(struct file___460 *, struct page___461 *);
	int (*writepages)(struct address_space___460 *, struct writeback_control___213 *);
	int (*set_page_dirty)(struct page___461 *);
	int (*readpages)(struct file___460 *, struct address_space___460 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___460 *, struct address_space___460 *, loff_t, unsigned int, unsigned int, struct page___461 **, void **);
	int (*write_end)(struct file___460 *, struct address_space___460 *, loff_t, unsigned int, unsigned int, struct page___461 *, void *);
	sector_t (*bmap)(struct address_space___460 *, sector_t);
	void (*invalidatepage)(struct page___461 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___461 *, gfp_t);
	void (*freepage)(struct page___461 *);
	ssize_t (*direct_IO)(struct kiocb___460 *, struct iov_iter___227 *);
	int (*migratepage)(struct address_space___460 *, struct page___461 *, struct page___461 *, enum migrate_mode);
	bool (*isolate_page)(struct page___461 *, isolate_mode_t);
	void (*putback_page)(struct page___461 *);
	int (*launder_page)(struct page___461 *);
	int (*is_partially_uptodate)(struct page___461 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___461 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___460 *, struct page___461 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___460 *, sector_t *);
	void (*swap_deactivate)(struct file___460 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___213 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___250 *wb;
	struct inode___460 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___252;

struct iov_iter___227 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___252 *bvec;
		struct pipe_inode_info___141 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___460 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___460 *bd_inode;
	struct super_block___460 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___460 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___250 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___460 {
	struct dentry___460 * (*lookup)(struct inode___460 *, struct dentry___460 *, unsigned int);
	const char * (*get_link)(struct dentry___460 *, struct inode___460 *, struct delayed_call *);
	int (*permission)(struct inode___460 *, int);
	struct posix_acl * (*get_acl)(struct inode___460 *, int);
	int (*readlink)(struct dentry___460 *, char *, int);
	int (*create)(struct inode___460 *, struct dentry___460 *, umode_t, bool);
	int (*link)(struct dentry___460 *, struct inode___460 *, struct dentry___460 *);
	int (*unlink)(struct inode___460 *, struct dentry___460 *);
	int (*symlink)(struct inode___460 *, struct dentry___460 *, const char *);
	int (*mkdir)(struct inode___460 *, struct dentry___460 *, umode_t);
	int (*rmdir)(struct inode___460 *, struct dentry___460 *);
	int (*mknod)(struct inode___460 *, struct dentry___460 *, umode_t, dev_t);
	int (*rename)(struct inode___460 *, struct dentry___460 *, struct inode___460 *, struct dentry___460 *, unsigned int);
	int (*setattr)(struct dentry___460 *, struct iattr___460 *);
	int (*getattr)(const struct path___461 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___460 *, char *, size_t);
	int (*fiemap)(struct inode___460 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___460 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___460 *, struct dentry___460 *, struct file___460 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___460 *, struct dentry___460 *, umode_t);
	int (*set_acl)(struct inode___460 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___460 {
	void (*fl_copy_lock)(struct file_lock___460 *, struct file_lock___460 *);
	void (*fl_release_private)(struct file_lock___460 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___460;

struct file_lock___460 {
	struct file_lock___460 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___460 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___460 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___460 *fl_ops;
	const struct lock_manager_operations___460 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___460 {
	int (*lm_compare_owner)(struct file_lock___460 *, struct file_lock___460 *);
	long unsigned int (*lm_owner_key)(struct file_lock___460 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___460 *);
	int (*lm_grant)(struct file_lock___460 *, int);
	bool (*lm_break)(struct file_lock___460 *);
	int (*lm_change)(struct file_lock___460 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___460 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___460 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___460 *fa_next;
	struct file___460 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___460 {
	const char *name;
	int fs_flags;
	struct dentry___460 * (*mount)(struct file_system_type___460 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___460 *);
	struct module___386 *owner;
	struct file_system_type___460 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___460 {
	struct inode___460 * (*alloc_inode)(struct super_block___460 *);
	void (*destroy_inode)(struct inode___460 *);
	void (*dirty_inode)(struct inode___460 *, int);
	int (*write_inode)(struct inode___460 *, struct writeback_control___213 *);
	int (*drop_inode)(struct inode___460 *);
	void (*evict_inode)(struct inode___460 *);
	void (*put_super)(struct super_block___460 *);
	int (*sync_fs)(struct super_block___460 *, int);
	int (*freeze_super)(struct super_block___460 *);
	int (*freeze_fs)(struct super_block___460 *);
	int (*thaw_super)(struct super_block___460 *);
	int (*unfreeze_fs)(struct super_block___460 *);
	int (*statfs)(struct dentry___460 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___460 *, int *, char *);
	void (*umount_begin)(struct super_block___460 *);
	int (*show_options)(struct seq_file___399 *, struct dentry___460 *);
	int (*show_devname)(struct seq_file___399 *, struct dentry___460 *);
	int (*show_path)(struct seq_file___399 *, struct dentry___460 *);
	int (*show_stats)(struct seq_file___399 *, struct dentry___460 *);
	ssize_t (*quota_read)(struct super_block___460 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___460 *, int, const char *, size_t, loff_t);
	struct dquot___460 ** (*get_dquots)(struct inode___460 *);
	int (*bdev_try_to_free_page)(struct super_block___460 *, struct page___461 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___460 *, struct shrink_control___193 *);
	long int (*free_cached_objects)(struct super_block___460 *, struct shrink_control___193 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___250(struct bio___250 *);

struct bio_vec___252 {
	struct page___461 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___250;

struct bio_set___250;

struct bio___250 {
	struct bio___250 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___250 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___250 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___252 *bi_io_vec;
	struct bio_set___250 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___252 bi_inline_vecs[0];
};

typedef void compound_page_dtor___448(struct page___461 *);

struct fwnode_operations___348;

struct fwnode_handle___348 {
	struct fwnode_handle___348 *secondary;
	const struct fwnode_operations___348 *ops;
};

struct fwnode_reference_args___348;

struct fwnode_endpoint___348;

struct fwnode_operations___348 {
	struct fwnode_handle___348 * (*get)(struct fwnode_handle___348 *);
	void (*put)(struct fwnode_handle___348 *);
	bool (*device_is_available)(const struct fwnode_handle___348 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___348 *, const struct device___428 *);
	bool (*property_present)(const struct fwnode_handle___348 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___348 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___348 *, const char *, const char **, size_t);
	struct fwnode_handle___348 * (*get_parent)(const struct fwnode_handle___348 *);
	struct fwnode_handle___348 * (*get_next_child_node)(const struct fwnode_handle___348 *, struct fwnode_handle___348 *);
	struct fwnode_handle___348 * (*get_named_child_node)(const struct fwnode_handle___348 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___348 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___348 *);
	struct fwnode_handle___348 * (*graph_get_next_endpoint)(const struct fwnode_handle___348 *, struct fwnode_handle___348 *);
	struct fwnode_handle___348 * (*graph_get_remote_endpoint)(const struct fwnode_handle___348 *);
	struct fwnode_handle___348 * (*graph_get_port_parent)(struct fwnode_handle___348 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___348 *, struct fwnode_endpoint___348 *);
};

struct fwnode_endpoint___348 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___348 *local_fwnode;
};

struct fwnode_reference_args___348 {
	struct fwnode_handle___348 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct msghdr___88 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___227 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___460 *msg_iocb;
};

struct socket_wq___86 {
	wait_queue_head_t wait;
	struct fasync_struct___460 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___86;

struct socket___87 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___86 *wq;
	struct file___460 *file;
	struct sock___85 *sk;
	const struct proto_ops___86 *ops;
};

typedef int (*sk_read_actor_t___85)(read_descriptor_t *, struct sk_buff___106 *, unsigned int, size_t);

struct proto_ops___86 {
	int family;
	struct module___386 *owner;
	int (*release)(struct socket___87 *);
	int (*bind)(struct socket___87 *, struct sockaddr *, int);
	int (*connect)(struct socket___87 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___87 *, struct socket___87 *);
	int (*accept)(struct socket___87 *, struct socket___87 *, int, bool);
	int (*getname)(struct socket___87 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___460 *, struct socket___87 *, struct poll_table_struct___299 *);
	int (*ioctl)(struct socket___87 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___87 *, int);
	int (*shutdown)(struct socket___87 *, int);
	int (*setsockopt)(struct socket___87 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___87 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___87 *, struct msghdr___88 *, size_t);
	int (*recvmsg)(struct socket___87 *, struct msghdr___88 *, size_t, int);
	int (*mmap)(struct file___460 *, struct socket___87 *, struct vm_area_struct___461 *);
	ssize_t (*sendpage)(struct socket___87 *, struct page___461 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___87 *, loff_t *, struct pipe_inode_info___141 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___85 *, int);
	int (*peek_len)(struct socket___87 *);
	int (*read_sock)(struct sock___85 *, read_descriptor_t *, sk_read_actor_t___85);
	int (*sendpage_locked)(struct sock___85 *, struct page___461 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___85 *, struct msghdr___88 *, size_t);
	int (*set_rcvlowat)(struct sock___85 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct sec_path___22;

struct nf_bridge_info___105;

struct sk_buff___106 {
	union {
		struct {
			struct sk_buff___106 *next;
			struct sk_buff___106 *prev;
			union {
				struct net_device___105 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___85 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___106 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path___22 *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___105 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___105;

struct netns_frags___105 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___105 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ip_ra_chain___51;

struct fib_rules_ops___85;

struct fib_notifier_ops___86;

struct netns_ipv4___105 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___51 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___85 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___85 *fibnl;
	struct sock___85 **icmp_sk;
	struct sock___85 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___85 **tcp_sk;
	struct netns_frags___105 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___85 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___86 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___86 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___85;

struct dst_ops___116 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___116 *);
	struct dst_entry___85 * (*check)(struct dst_entry___85 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___85 *);
	unsigned int (*mtu)(const struct dst_entry___85 *);
	u32 * (*cow_metrics)(struct dst_entry___85 *, long unsigned int);
	void (*destroy)(struct dst_entry___85 *);
	void (*ifdown)(struct dst_entry___85 *, struct net_device___105 *, int);
	struct dst_entry___85 * (*negative_advice)(struct dst_entry___85 *);
	void (*link_failure)(struct sk_buff___106 *);
	void (*update_pmtu)(struct dst_entry___85 *, struct sock___85 *, struct sk_buff___106 *, u32);
	void (*redirect)(struct dst_entry___85 *, struct sock___85 *, struct sk_buff___106 *);
	int (*local_out)(struct net___116 *, struct sock___85 *, struct sk_buff___106 *);
	struct neighbour___85 * (*neigh_lookup)(const struct dst_entry___85 *, struct sk_buff___106 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___85 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_info___27;

struct rt6_info___27;

struct fib6_table___27;

struct netns_ipv6___116 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___105 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info___27 *fib6_null_entry;
	struct rt6_info___27 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___27 *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___116 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info___27 *ip6_prohibit_entry;
	struct rt6_info___27 *ip6_blk_hole_entry;
	struct fib6_table___27 *fib6_local_tbl;
	struct fib_rules_ops___85 *fib6_rules_ops;
	struct sock___85 **icmp_sk;
	struct sock___85 *ndisc_sk;
	struct sock___85 *tcp_sk;
	struct sock___85 *igmp_sk;
	struct sock___85 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___85 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___86 *notifier_ops;
	struct fib_notifier_ops___86 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___86 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___85 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___105 {
	struct netns_frags___105 frags;
};

struct netns_xfrm___116 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___85 *nlsk;
	struct sock___85 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___116 xfrm4_dst_ops;
	struct dst_ops___116 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___95;

struct net___116 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___325 *user_ns;
	struct ucounts___325 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___29 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___85 *rtnl;
	struct sock___85 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___105 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___105 ipv4;
	struct netns_ipv6___116 ipv6;
	struct netns_sctp___86 sctp;
	struct netns_nf___19 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___105 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___85 *nfnl;
	struct sock___85 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___116 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___85 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___95 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___428 {
	int (*prepare)(struct device___428 *);
	void (*complete)(struct device___428 *);
	int (*suspend)(struct device___428 *);
	int (*resume)(struct device___428 *);
	int (*freeze)(struct device___428 *);
	int (*thaw)(struct device___428 *);
	int (*poweroff)(struct device___428 *);
	int (*restore)(struct device___428 *);
	int (*suspend_late)(struct device___428 *);
	int (*resume_early)(struct device___428 *);
	int (*freeze_late)(struct device___428 *);
	int (*thaw_early)(struct device___428 *);
	int (*poweroff_late)(struct device___428 *);
	int (*restore_early)(struct device___428 *);
	int (*suspend_noirq)(struct device___428 *);
	int (*resume_noirq)(struct device___428 *);
	int (*freeze_noirq)(struct device___428 *);
	int (*thaw_noirq)(struct device___428 *);
	int (*poweroff_noirq)(struct device___428 *);
	int (*restore_noirq)(struct device___428 *);
	int (*runtime_suspend)(struct device___428 *);
	int (*runtime_resume)(struct device___428 *);
	int (*runtime_idle)(struct device___428 *);
};

struct dev_pm_domain___428 {
	struct dev_pm_ops___428 ops;
	void (*detach)(struct device___428 *, bool);
	int (*activate)(struct device___428 *);
	void (*sync)(struct device___428 *);
	void (*dismiss)(struct device___428 *);
};

struct bus_type___428 {
	const char *name;
	const char *dev_name;
	struct device___428 *dev_root;
	const struct attribute_group___425 **bus_groups;
	const struct attribute_group___425 **dev_groups;
	const struct attribute_group___425 **drv_groups;
	int (*match)(struct device___428 *, struct device_driver___428 *);
	int (*uevent)(struct device___428 *, struct kobj_uevent_env *);
	int (*probe)(struct device___428 *);
	int (*remove)(struct device___428 *);
	void (*shutdown)(struct device___428 *);
	int (*online)(struct device___428 *);
	int (*offline)(struct device___428 *);
	int (*suspend)(struct device___428 *, pm_message_t);
	int (*resume)(struct device___428 *);
	int (*num_vf)(struct device___428 *);
	int (*dma_configure)(struct device___428 *);
	const struct dev_pm_ops___428 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___428 {
	const char *name;
	struct bus_type___428 *bus;
	struct module___386 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___428 *);
	int (*remove)(struct device___428 *);
	void (*shutdown)(struct device___428 *);
	int (*suspend)(struct device___428 *, pm_message_t);
	int (*resume)(struct device___428 *);
	const struct attribute_group___425 **groups;
	const struct dev_pm_ops___428 *pm;
	void (*coredump)(struct device___428 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___428 {
	const char *name;
	const struct attribute_group___425 **groups;
	int (*uevent)(struct device___428 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___428 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___428 *);
	const struct dev_pm_ops___428 *pm;
};

struct class___428 {
	const char *name;
	struct module___386 *owner;
	const struct attribute_group___425 **class_groups;
	const struct attribute_group___425 **dev_groups;
	struct kobject___448 *dev_kobj;
	int (*dev_uevent)(struct device___428 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___428 *, umode_t *);
	void (*class_release)(struct class___428 *);
	void (*dev_release)(struct device___428 *);
	int (*shutdown_pre)(struct device___428 *);
	const struct kobj_ns_type_operations___85 *ns_type;
	const void * (*namespace)(struct device___428 *);
	const struct dev_pm_ops___428 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___200 {
	void * (*alloc)(struct device___428 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___428 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___428 *, struct vm_area_struct___461 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___428 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___428 *, struct page___461 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___428 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___428 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___428 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___428 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___428 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___428 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___428 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___428 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___428 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___428 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___428 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___428 *, u64);
	u64 (*get_required_mask)(struct device___428 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct pipe_buf_operations___141;

struct pipe_buffer___141 {
	struct page___461 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___141 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___141 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___141 *, struct pipe_buffer___141 *);
	void (*release)(struct pipe_inode_info___141 *, struct pipe_buffer___141 *);
	int (*steal)(struct pipe_inode_info___141 *, struct pipe_buffer___141 *);
	union {
		bool (*get)(struct pipe_inode_info___141 *, struct pipe_buffer___141 *);
		struct {
			void (*get)(struct pipe_inode_info___141 *, struct pipe_buffer___141 *);
		} __UNIQUE_ID_rh_kabi_hide21;
		union {		};
	};
};

struct nf_bridge_info___105 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___105 = 0,
		BRNF_PROTO_8021Q___105 = 1,
		BRNF_PROTO_PPPOE___105 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___105 *physindev;
	struct net_device___105 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___105(struct sk_buff___106 **);

struct net_device_ops___105;

struct ethtool_ops___105;

struct l3mdev_ops___85;

struct ndisc_ops___56;

struct xfrmdev_ops___105;

struct tlsdev_ops___105;

struct header_ops___105;

struct inet6_dev___56;

struct netdev_rx_queue___105;

struct mini_Qdisc___97;

struct netdev_queue___105;

struct Qdisc___97;

struct rtnl_link_ops___97;

struct dcbnl_rtnl_ops___105;

struct net_device___105 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___105 *netdev_ops;
	const struct ethtool_ops___105 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___85 *l3mdev_ops;
	const struct ndisc_ops___56 *ndisc_ops;
	const struct xfrmdev_ops___105 *xfrmdev_ops;
	const struct tlsdev_ops___105 *tlsdev_ops;
	const struct header_ops___105 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___447 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___56 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___105 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___95 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___105 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___97 *miniq_ingress;
	struct netdev_queue___105 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___105 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___97 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___97 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___105 = 0,
		NETREG_REGISTERED___105 = 1,
		NETREG_UNREGISTERING___105 = 2,
		NETREG_UNREGISTERED___105 = 3,
		NETREG_RELEASED___105 = 4,
		NETREG_DUMMY___105 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___105 = 0,
		RTNL_LINK_INITIALIZING___105 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___105 *);
	struct netpoll_info *npinfo;
	possible_net_t___107 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___428 dev;
	const struct attribute_group___425 *sysfs_groups[4];
	const struct attribute_group___425 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___97 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___105 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide35;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct xfrm_state___22;

struct sec_path___22 {
	refcount_t refcnt;
	int len;
	int olen;
	struct xfrm_state___22 *xvec[6];
	struct xfrm_offload ovec[1];
};

typedef int (*key_restrict_link_func_t___429)(struct key___428 *, const struct key_type *, const union key_payload *, struct key___428 *);

struct key_restriction___428;

struct key___428 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___462 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___428 *restrict_link;
};

struct key_restriction___428 {
	key_restrict_link_func_t___429 check;
	struct key___428 *key;
	struct key_type *keytype;
};

struct cgroup_namespace___309 {
	refcount_t count;
	struct ns_common___29 ns;
	struct user_namespace___325 *user_ns;
	struct ucounts___325 *ucounts;
	struct css_set___309 *root_cset;
};

struct ucounts___325 {
	struct hlist_node node;
	struct user_namespace___325 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct ethtool_ops___105 {
	int (*get_settings)(struct net_device___105 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___105 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___105 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___105 *);
	void (*get_regs)(struct net_device___105 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___105 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___105 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___105 *);
	void (*set_msglevel)(struct net_device___105 *, u32);
	int (*nway_reset)(struct net_device___105 *);
	u32 (*get_link)(struct net_device___105 *);
	int (*get_eeprom_len)(struct net_device___105 *);
	int (*get_eeprom)(struct net_device___105 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___105 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___105 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___105 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___105 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___105 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___105 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___105 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___105 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___105 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___105 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___105 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___105 *);
	void (*complete)(struct net_device___105 *);
	u32 (*get_priv_flags)(struct net_device___105 *);
	int (*set_priv_flags)(struct net_device___105 *, u32);
	int (*get_sset_count)(struct net_device___105 *, int);
	int (*get_rxnfc)(struct net_device___105 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___105 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___105 *, struct ethtool_flash *);
	int (*reset)(struct net_device___105 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___105 *);
	u32 (*get_rxfh_indir_size)(struct net_device___105 *);
	int (*get_rxfh)(struct net_device___105 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___105 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___105 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___105 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___105 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___105 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___105 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___105 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___105 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___105 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___105 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___105 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___105 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___105 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___105 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___105 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___105 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___105 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___105 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___105 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___105 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___105 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	int (*get_fecparam)(struct net_device___105 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___105 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___105 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___105 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___105 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___105;

struct inet_frags___105 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___105 *, const void *);
	void (*destructor)(struct inet_frag_queue___105 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___105 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___106 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___106 *fragments_tail;
	struct sk_buff___106 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___105 *net;
	struct callback_head rcu;
};

struct ip_ra_chain___51 {
	struct ip_ra_chain___51 *next;
	struct sock___85 *sk;
	union {
		void (*destructor)(struct sock___85 *);
		struct sock___85 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___85;

struct fib_lookup_arg___85;

struct fib_rules_ops___85 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___85 *, struct flowi *, int, struct fib_lookup_arg___85 *);
	bool (*suppress)(struct fib_rule___85 *, struct fib_lookup_arg___85 *);
	int (*match)(struct fib_rule___85 *, struct flowi *, int);
	int (*configure)(struct fib_rule___85 *, struct sk_buff___106 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___85 *);
	int (*compare)(struct fib_rule___85 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___85 *, struct sk_buff___106 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___85 *);
	void (*flush_cache)(struct fib_rules_ops___85 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___386 *owner;
	struct net___116 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___86 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___116 *);
	int (*fib_dump)(struct net___116 *, struct notifier_block *);
	struct module___386 *owner;
	struct callback_head rcu;
};

struct dst_entry___85 {
	struct net_device___105 *dev;
	struct dst_ops___116 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state___22 *xfrm;
	int (*input)(struct sk_buff___106 *);
	int (*output)(struct net___116 *, struct sock___85 *, struct sk_buff___106 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___85;

struct neigh_parms___85;

struct neigh_ops___85;

struct neighbour___85 {
	struct neighbour___85 *next;
	struct neigh_table___85 *tbl;
	struct neigh_parms___85 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___105 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___85 *, struct sk_buff___106 *);
	const struct neigh_ops___85 *ops;
	struct callback_head rcu;
	struct net_device___105 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct fib6_nh___27 {
	struct in6_addr nh_gw;
	struct net_device___105 *nh_dev;
	struct lwtunnel_state *nh_lwtstate;
	unsigned int nh_flags;
	atomic_t nh_upper_bound;
	int nh_weight;
};

struct fib6_node___27;

struct fib6_info___27 {
	struct fib6_table___27 *fib6_table;
	struct fib6_info___27 *fib6_next;
	struct fib6_node___27 *fib6_node;
	struct list_head fib6_siblings;
	unsigned int fib6_nsiblings;
	atomic_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	struct rt6_info___27 **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
	long unsigned int last_probe;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 exception_bucket_flushed: 1;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 dst_host: 1;
	u8 fib6_destroying: 1;
	u8 unused: 2;
	struct fib6_nh___27 fib6_nh;
	struct callback_head rcu;
};

struct rt6_info___27 {
	struct dst_entry___85 dst;
	struct fib6_info___27 *from;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___56 *rt6i_idev;
	u32 rt6i_flags;
	struct rt6key rt6i_prefsrc;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct fib6_node___27 {
	struct fib6_node___27 *parent;
	struct fib6_node___27 *left;
	struct fib6_node___27 *right;
	struct fib6_info___27 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info___27 *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table___27 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node___27 tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

struct bpf_prog_aux___98;

struct bpf_prog___95 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___98 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

struct seq_operations___399 {
	void * (*start)(struct seq_file___399 *, loff_t *);
	void (*stop)(struct seq_file___399 *, void *);
	void * (*next)(struct seq_file___399 *, void *, loff_t *);
	int (*show)(struct seq_file___399 *, void *);
};

struct pernet_operations___106 {
	struct list_head list;
	int (*init)(struct net___116 *);
	void (*exit)(struct net___116 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___105 {
	int (*ieee_getets)(struct net_device___105 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___105 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___105 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___105 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___105 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___105 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___105 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___105 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___105 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___105 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___105 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___105 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___105 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___105 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___105 *);
	u8 (*setstate)(struct net_device___105 *, u8);
	void (*getpermhwaddr)(struct net_device___105 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___105 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___105 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___105 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___105 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___105 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___105 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___105 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___105 *, int, u8 *);
	void (*setpfccfg)(struct net_device___105 *, int, u8);
	void (*getpfccfg)(struct net_device___105 *, int, u8 *);
	u8 (*setall)(struct net_device___105 *);
	u8 (*getcap)(struct net_device___105 *, int, u8 *);
	int (*getnumtcs)(struct net_device___105 *, int, u8 *);
	int (*setnumtcs)(struct net_device___105 *, int, u8);
	u8 (*getpfcstate)(struct net_device___105 *);
	void (*setpfcstate)(struct net_device___105 *, u8);
	void (*getbcncfg)(struct net_device___105 *, int, u32 *);
	void (*setbcncfg)(struct net_device___105 *, int, u32);
	void (*getbcnrp)(struct net_device___105 *, int, u8 *);
	void (*setbcnrp)(struct net_device___105 *, int, u8);
	int (*setapp)(struct net_device___105 *, u8, u16, u8);
	int (*getapp)(struct net_device___105 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___105 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___105 *, int, u8);
	u8 (*getdcbx)(struct net_device___105 *);
	u8 (*setdcbx)(struct net_device___105 *, u8);
	int (*peer_getappinfo)(struct net_device___105 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___105 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___105 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___105 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___105 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___105 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct bpf_map___310;

struct bpf_map_ops___309 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___310 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___310 *, struct file___460 *);
	void (*map_free)(struct bpf_map___310 *);
	int (*map_get_next_key)(struct bpf_map___310 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___310 *);
	void * (*map_lookup_elem)(struct bpf_map___310 *, void *);
	int (*map_update_elem)(struct bpf_map___310 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___310 *, void *);
	int (*map_push_elem)(struct bpf_map___310 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___310 *, void *);
	int (*map_peek_elem)(struct bpf_map___310 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___310 *, struct file___460 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___310 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___310 *, void *, struct seq_file___399 *);
	int (*map_check_btf)(const struct bpf_map___310 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___310 {
	const struct bpf_map_ops___309 *ops;
	struct bpf_map___310 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___428 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___105;

struct bpf_map_dev_ops___105 {
	int (*map_get_next_key)(struct bpf_offloaded_map___105 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___105 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___105 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___105 *, void *);
};

struct bpf_offloaded_map___105 {
	struct bpf_map___310 map;
	struct net_device___105 *netdev;
	const struct bpf_map_dev_ops___105 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___95 {
	int (*test_run)(struct bpf_prog___95 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___95 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___95 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___95 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___95 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___95 *, u32 *);
};

struct bpf_prog_offload_ops___95 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___95 *);
	int (*translate)(struct bpf_prog___95 *);
	void (*destroy)(struct bpf_prog___95 *);
};

struct bpf_prog_offload___95 {
	struct bpf_prog___95 *prog;
	struct net_device___105 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___95 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___98 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___95 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___95 *ops;
	struct bpf_map___310 **used_maps;
	struct bpf_prog___95 *prog;
	struct user_struct___428 *user;
	u64 load_time;
	struct bpf_map___310 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___95 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___95 {
	struct bpf_prog___95 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___95 {
	struct callback_head rcu;
	struct bpf_prog_array_item___95 items[0];
};

struct cgroup_bpf___95 {
	struct bpf_prog_array___95 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___95 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___310;

typedef void (*kthread_work_func_t___310)(struct kthread_work___310 *);

struct kthread_worker___310;

struct kthread_work___310 {
	struct list_head node;
	kthread_work_func_t___310 func;
	struct kthread_worker___310 *worker;
	int canceling;
};

struct kthread_worker___310 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___462 *task;
	struct kthread_work___310 *current_work;
};

struct kthread_delayed_work___309 {
	struct kthread_work___310 work;
	struct timer_list timer;
};

struct psi_group___309 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___310 *poll_kworker;
	struct kthread_delayed_work___309 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___309;

struct cgroup_rstat_cpu___309;

struct cgroup___309 {
	struct cgroup_subsys_state___309 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___455 *kn;
	struct cgroup_file___309 procs_file;
	struct cgroup_file___309 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___309 *subsys[13];
	struct cgroup_root___309 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___309 *dom_cgrp;
	struct cgroup_rstat_cpu___309 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___95 bpf;
	atomic_t congestion_count;
	struct cgroup___309 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___309 psi;
	int ancestor_ids[0];
};

struct cftype___309;

struct cgroup_subsys___309 {
	struct cgroup_subsys_state___309 * (*css_alloc)(struct cgroup_subsys_state___309 *);
	int (*css_online)(struct cgroup_subsys_state___309 *);
	void (*css_offline)(struct cgroup_subsys_state___309 *);
	void (*css_released)(struct cgroup_subsys_state___309 *);
	void (*css_free)(struct cgroup_subsys_state___309 *);
	void (*css_reset)(struct cgroup_subsys_state___309 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___309 *, int);
	int (*css_extra_stat_show)(struct seq_file___399 *, struct cgroup_subsys_state___309 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___462 *);
	void (*cancel_fork)(struct task_struct___462 *);
	void (*fork)(struct task_struct___462 *);
	void (*exit)(struct task_struct___462 *);
	void (*free)(struct task_struct___462 *);
	void (*bind)(struct cgroup_subsys_state___309 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___309 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___309 *dfl_cftypes;
	struct cftype___309 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___309 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___309 *updated_children;
	struct cgroup___309 *updated_next;
};

struct cgroup_root___309 {
	struct kernfs_root___454 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___309 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___309 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___309 *ss;
	struct list_head node;
	struct kernfs_ops___454 *kf_ops;
	int (*open)(struct kernfs_open_file___454 *);
	void (*release)(struct kernfs_open_file___454 *);
	u64 (*read_u64)(struct cgroup_subsys_state___309 *, struct cftype___309 *);
	s64 (*read_s64)(struct cgroup_subsys_state___309 *, struct cftype___309 *);
	int (*seq_show)(struct seq_file___399 *, void *);
	void * (*seq_start)(struct seq_file___399 *, loff_t *);
	void * (*seq_next)(struct seq_file___399 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___399 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___309 *, struct cftype___309 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___309 *, struct cftype___309 *, s64);
	ssize_t (*write)(struct kernfs_open_file___454 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___454 *, struct poll_table_struct___299 *);
};

struct xdp_rxq_info___105 {
	struct net_device___105 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___105 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___105 *dev_rx;
};

struct netlink_callback___107 {
	struct sk_buff___106 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___107 *);
	int (*dump)(struct sk_buff___106 *, struct netlink_callback___107 *);
	int (*done)(struct netlink_callback___107 *);
	void *data;
	struct module___386 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___105 {
	int (*create)(struct sk_buff___106 *, struct net_device___105 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___106 *, unsigned char *);
	int (*cache)(const struct neighbour___85 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___105 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___105 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___105 *, int);
	int poll_owner;
	struct net_device___105 *dev;
	struct sk_buff___106 *gro_list;
	struct sk_buff___106 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___105 {
	struct net_device___105 *dev;
	struct Qdisc___97 *qdisc;
	struct Qdisc___97 *qdisc_sleeping;
	struct kobject___448 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___105 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem___3 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___97 {
	struct sk_buff___106 *head;
	struct sk_buff___106 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___97;

struct Qdisc___97 {
	int (*enqueue)(struct sk_buff___106 *, struct Qdisc___97 *, struct sk_buff___106 **);
	struct sk_buff___106 * (*dequeue)(struct Qdisc___97 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___97 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___105 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___105 gso_skb;
	struct qdisc_skb_head___97 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___97 *next_sched;
	struct sk_buff_head___105 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___105 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___448 kobj;
	struct net_device___105 *dev;
	long: 64;
	struct xdp_rxq_info___105 xdp_rxq;
	union {
		struct xdp_umem___3 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___105)(struct net_device___105 *, struct sk_buff___106 *, struct net_device___105 *);

struct netdev_bpf___105 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___95 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___95 *prog;
			const struct bpf_prog_offload_ops___95 *ops;
		} verifier;
		struct {
			struct bpf_prog___95 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___105 *offmap;
		};
		struct {
			struct xdp_umem___3 *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___105 {
	int (*xdo_dev_state_add)(struct xfrm_state___22 *);
	void (*xdo_dev_state_delete)(struct xfrm_state___22 *);
	void (*xdo_dev_state_free)(struct xfrm_state___22 *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___106 *, struct xfrm_state___22 *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state___22 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct xfrm_state_offload___22 {
	struct net_device___105 *dev;
	long unsigned int offload_handle;
	unsigned int num_exthdrs;
	u8 flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct xfrm_replay___22;

struct xfrm_type___22;

struct xfrm_mode___22;

struct xfrm_type_offload___22;

struct xfrm_state___22 {
	possible_net_t___107 xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	refcount_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
		u32 output_mark;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	const char *geniv;
	struct xfrm_encap_tmpl *encap;
	xfrm_address_t *coaddr;
	struct xfrm_state___22 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	const struct xfrm_replay___22 *repl;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct tasklet_hrtimer mtimer;
	struct xfrm_state_offload___22 xso;
	long int saved_tmo;
	long unsigned int lastused;
	struct page_frag___461 xfrag;
	const struct xfrm_type___22 *type;
	struct xfrm_mode___22 *inner_mode;
	struct xfrm_mode___22 *inner_mode_iaf;
	struct xfrm_mode___22 *outer_mode;
	const struct xfrm_type_offload___22 *type_offload;
	struct xfrm_sec_ctx___2 *security;
	void *data;
	u32 output_mark_mask;
	u32 if_id;
};

struct tlsdev_ops___105 {
	int (*tls_dev_add)(struct net_device___105 *, struct sock___85 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___105 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___105 *, struct sock___85 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___105 {
	int (*ndo_init)(struct net_device___105 *);
	void (*ndo_uninit)(struct net_device___105 *);
	int (*ndo_open)(struct net_device___105 *);
	int (*ndo_stop)(struct net_device___105 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___106 *, struct net_device___105 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___106 *, struct net_device___105 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___105 *, struct sk_buff___106 *, struct net_device___105 *, select_queue_fallback_t___105);
	void (*ndo_change_rx_flags)(struct net_device___105 *, int);
	void (*ndo_set_rx_mode)(struct net_device___105 *);
	int (*ndo_set_mac_address)(struct net_device___105 *, void *);
	int (*ndo_validate_addr)(struct net_device___105 *);
	int (*ndo_do_ioctl)(struct net_device___105 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___105 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___105 *, int);
	int (*ndo_neigh_setup)(struct net_device___105 *, struct neigh_parms___85 *);
	void (*ndo_tx_timeout)(struct net_device___105 *);
	void (*ndo_get_stats64)(struct net_device___105 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___105 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___105 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___105 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___105 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___105 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___105 *);
	int (*ndo_netpoll_setup)(struct net_device___105 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___105 *);
	int (*ndo_set_vf_mac)(struct net_device___105 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___105 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___105 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___105 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___105 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___105 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___105 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___105 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___105 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___105 *, int, struct sk_buff___106 *);
	int (*ndo_set_vf_guid)(struct net_device___105 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___105 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___105 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___105 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___105 *, const struct sk_buff___106 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___105 *, struct net_device___105 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___105 *, struct net_device___105 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___105 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___105 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___105 *, struct neighbour___85 *);
	void (*ndo_neigh_destroy)(struct net_device___105 *, struct neighbour___85 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___105 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___105 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___105 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___106 *, struct netlink_callback___107 *, struct net_device___105 *, struct net_device___105 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___105 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___105 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___106 *, u32, u32, struct net_device___105 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___105 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___105 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___105 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___105 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___105 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___105 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___105 *, struct net_device___105 *);
	void (*ndo_dfwd_del_station)(struct net_device___105 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___105 *);
	int (*ndo_set_tx_maxrate)(struct net_device___105 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___105 *);
	int (*ndo_change_proto_down)(struct net_device___105 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___105 *, struct sk_buff___106 *);
	void (*ndo_set_rx_headroom)(struct net_device___105 *, int);
	int (*ndo_bpf)(struct net_device___105 *, struct netdev_bpf___105 *);
	int (*ndo_xdp_xmit)(struct net_device___105 *, int, struct xdp_frame___105 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___105 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___105 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___85 {
	possible_net_t___107 net;
	struct net_device___105 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___85 *);
	void (*neigh_cleanup)(struct neighbour___85 *);
	struct neigh_table___85 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___85 {
	u32 (*l3mdev_fib_table)(const struct net_device___105 *);
	struct sk_buff___106 * (*l3mdev_l3_rcv)(struct net_device___105 *, struct sk_buff___106 *, u16);
	struct sk_buff___106 * (*l3mdev_l3_out)(struct net_device___105 *, struct sock___85 *, struct sk_buff___106 *, u16);
	struct dst_entry___85 * (*l3mdev_link_scope_lookup)(const struct net_device___105 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct ndisc_ops___56 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___105 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___105 *, struct neighbour___85 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___105 *, u8, struct neighbour___85 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___105 *, struct sk_buff___106 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___116 *, struct net_device___105 *, const struct prefix_info *, struct inet6_dev___56 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___56;

struct ifacaddr6___27;

struct inet6_dev___56 {
	struct net_device___105 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___56 *mc_list;
	struct ifmcaddr6___56 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___27 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	u8 rndid[8];
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___85 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
};

struct tcf_proto___97;

struct mini_Qdisc___97 {
	struct tcf_proto___97 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___97 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___105 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___116 *, struct net_device___105 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___105 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___105 *, struct list_head *);
	size_t (*get_size)(const struct net_device___105 *);
	int (*fill_info)(struct sk_buff___106 *, const struct net_device___105 *);
	size_t (*get_xstats_size)(const struct net_device___105 *);
	int (*fill_xstats)(struct sk_buff___106 *, const struct net_device___105 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___105 *, struct net_device___105 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___105 *, const struct net_device___105 *);
	int (*fill_slave_info)(struct sk_buff___106 *, const struct net_device___105 *, const struct net_device___105 *);
	struct net___116 * (*get_link_net)(const struct net_device___105 *);
	size_t (*get_linkxstats_size)(const struct net_device___105 *, int);
	int (*fill_linkxstats)(struct sk_buff___106 *, const struct net_device___105 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___105 {
	struct list_head poll_list;
	struct sk_buff_head___105 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___105 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___97 *output_queue;
	struct Qdisc___97 **output_queue_tailp;
	struct sk_buff___106 *completion_queue;
	struct sk_buff_head___105 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___105 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___105 input_pkt_queue;
	struct napi_struct___105 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bdi_writeback_congested___250 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___250 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___250 {
	struct bio___250 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___252 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___252 bip_inline_vecs[0];
};

struct bio_set___250 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___250 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___193 {
	struct mem_cgroup___193 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___193 {
	struct lruvec___461 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___193 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___193 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct gnet_dump___97 {
	spinlock_t *lock;
	struct sk_buff___106 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___97;

struct Qdisc_ops___97 {
	struct Qdisc_ops___97 *next;
	const struct Qdisc_class_ops___97 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___106 *, struct Qdisc___97 *, struct sk_buff___106 **);
	struct sk_buff___106 * (*dequeue)(struct Qdisc___97 *);
	struct sk_buff___106 * (*peek)(struct Qdisc___97 *);
	int (*init)(struct Qdisc___97 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___97 *);
	void (*destroy)(struct Qdisc___97 *);
	int (*change)(struct Qdisc___97 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___97 *);
	int (*change_tx_queue_len)(struct Qdisc___97 *, unsigned int);
	int (*dump)(struct Qdisc___97 *, struct sk_buff___106 *);
	int (*dump_stats)(struct Qdisc___97 *, struct gnet_dump___97 *);
	void (*ingress_block_set)(struct Qdisc___97 *, u32);
	void (*egress_block_set)(struct Qdisc___97 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___97 *);
	u32 (*egress_block_get)(struct Qdisc___97 *);
	struct module___386 *owner;
};

struct tcf_block___97;

struct Qdisc_class_ops___97 {
	unsigned int flags;
	struct netdev_queue___105 * (*select_queue)(struct Qdisc___97 *, struct tcmsg *);
	int (*graft)(struct Qdisc___97 *, long unsigned int, struct Qdisc___97 *, struct Qdisc___97 **, struct netlink_ext_ack *);
	struct Qdisc___97 * (*leaf)(struct Qdisc___97 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___97 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___97 *, u32);
	int (*change)(struct Qdisc___97 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___97 *, long unsigned int);
	void (*walk)(struct Qdisc___97 *, struct qdisc_walker *);
	struct tcf_block___97 * (*tcf_block)(struct Qdisc___97 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___97 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___97 *, long unsigned int);
	int (*dump)(struct Qdisc___97 *, long unsigned int, struct sk_buff___106 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___97 *, long unsigned int, struct gnet_dump___97 *);
};

struct tcf_chain___97;

struct tcf_block___97 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___116 *net;
	struct Qdisc___97 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___97 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___97;

struct tcf_proto_ops___97;

struct tcf_proto___97 {
	struct tcf_proto___97 *next;
	void *root;
	int (*classify)(struct sk_buff___106 *, const struct tcf_proto___97 *, struct tcf_result___97 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___97 *ops;
	struct tcf_chain___97 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___97 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___97 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___97 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___106 *, const struct tcf_proto___97 *, struct tcf_result___97 *);
	int (*init)(struct tcf_proto___97 *);
	void (*destroy)(struct tcf_proto___97 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___97 *, u32);
	void (*put)(struct tcf_proto___97 *, void *);
	int (*change)(struct net___116 *, struct sk_buff___106 *, struct tcf_proto___97 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___97 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___97 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___97 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___116 *, struct tcf_chain___97 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___116 *, struct tcf_proto___97 *, void *, struct sk_buff___106 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___106 *, struct net___116 *, void *);
	struct module___386 *owner;
	int flags;
};

struct tcf_chain___97 {
	struct mutex filter_chain_lock;
	struct tcf_proto___97 *filter_chain;
	struct list_head list;
	struct tcf_block___97 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___97 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___85 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___95 *prog;
};

struct bpf_redirect_info___95 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___310 *map;
	struct bpf_map___310 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___85;

struct neigh_hash_table___85;

struct neigh_table___85 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___105 *, __u32 *);
	bool (*key_eq)(const struct neighbour___85 *, const void *);
	int (*constructor)(struct neighbour___85 *);
	int (*pconstructor)(struct pneigh_entry___85 *);
	void (*pdestructor)(struct pneigh_entry___85 *);
	void (*proxy_redo)(struct sk_buff___106 *);
	char *id;
	struct neigh_parms___85 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___105 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___85 *nht;
	struct pneigh_entry___85 **phash_buckets;
};

struct neigh_ops___85 {
	int family;
	void (*solicit)(struct neighbour___85 *, struct sk_buff___106 *);
	void (*error_report)(struct neighbour___85 *, struct sk_buff___106 *);
	int (*output)(struct neighbour___85 *, struct sk_buff___106 *);
	int (*connected_output)(struct neighbour___85 *, struct sk_buff___106 *);
};

struct pneigh_entry___85 {
	struct pneigh_entry___85 *next;
	possible_net_t___107 net;
	struct net_device___105 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___85 {
	struct neighbour___85 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___85 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___85 *ctarget;
	struct net___116 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___85 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___85 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___68;

struct timewait_sock_ops___64;

struct proto___85 {
	void (*close)(struct sock___85 *, long int);
	int (*pre_connect)(struct sock___85 *, struct sockaddr *, int);
	int (*connect)(struct sock___85 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___85 *, int);
	struct sock___85 * (*accept)(struct sock___85 *, int, int *, bool);
	int (*ioctl)(struct sock___85 *, int, long unsigned int);
	int (*init)(struct sock___85 *);
	void (*destroy)(struct sock___85 *);
	void (*shutdown)(struct sock___85 *, int);
	int (*setsockopt)(struct sock___85 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___85 *, int, int, char *, int *);
	void (*keepalive)(struct sock___85 *, int);
	int (*sendmsg)(struct sock___85 *, struct msghdr___88 *, size_t);
	int (*recvmsg)(struct sock___85 *, struct msghdr___88 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___85 *, struct page___461 *, int, size_t, int);
	int (*bind)(struct sock___85 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___85 *, struct sk_buff___106 *);
	void (*release_cb)(struct sock___85 *);
	int (*hash)(struct sock___85 *);
	void (*unhash)(struct sock___85 *);
	void (*rehash)(struct sock___85 *);
	int (*get_port)(struct sock___85 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___85 *);
	bool (*stream_memory_read)(const struct sock___85 *);
	void (*enter_memory_pressure)(struct sock___85 *);
	void (*leave_memory_pressure)(struct sock___85 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___68 *rsk_prot;
	struct timewait_sock_ops___64 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___386 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___85 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct xfrm_policy_queue___22 {
	struct sk_buff_head___105 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___22 {
	possible_net_t___107 xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	refcount_t refcnt;
	struct timer_list timer;
	atomic_t genid;
	u32 priority;
	u32 index;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___22 polq;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx___2 *security;
	struct xfrm_tmpl xfrm_vec[6];
	struct callback_head rcu;
	u32 if_id;
};

struct request_sock___69;

struct request_sock_ops___68 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___85 *, struct request_sock___69 *);
	void (*send_ack)(const struct sock___85 *, struct sk_buff___106 *, struct request_sock___69 *);
	void (*send_reset)(const struct sock___85 *, struct sk_buff___106 *);
	void (*destructor)(struct request_sock___69 *);
	void (*syn_ack_timeout)(const struct request_sock___69 *);
};

struct timewait_sock_ops___64 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___85 *, struct sock___85 *, void *);
	void (*twsk_destructor)(struct sock___85 *);
};

struct request_sock___69 {
	struct sock_common___85 __req_common;
	struct request_sock___69 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___68 *rsk_ops;
	struct sock___85 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___56 {
	struct in6_addr mca_addr;
	struct inet6_dev___56 *idev;
	struct ifmcaddr6___56 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___27 {
	struct in6_addr aca_addr;
	struct fib6_info___27 *aca_rt;
	struct ifacaddr6___27 *aca_next;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct ip6_ra_chain___56 {
	struct ip6_ra_chain___56 *next;
	struct sock___85 *sk;
	int sel;
	void (*destructor)(struct sock___85 *);
};

struct xfrm_replay___22 {
	void (*advance)(struct xfrm_state___22 *, __be32);
	int (*check)(struct xfrm_state___22 *, struct sk_buff___106 *, __be32);
	int (*recheck)(struct xfrm_state___22 *, struct sk_buff___106 *, __be32);
	void (*notify)(struct xfrm_state___22 *, int);
	int (*overflow)(struct xfrm_state___22 *, struct sk_buff___106 *);
};

struct xfrm_type___22 {
	char *description;
	struct module___386 *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___22 *);
	void (*destructor)(struct xfrm_state___22 *);
	int (*input)(struct xfrm_state___22 *, struct sk_buff___106 *);
	int (*output)(struct xfrm_state___22 *, struct sk_buff___106 *);
	int (*reject)(struct xfrm_state___22 *, struct sk_buff___106 *, const struct flowi *);
	int (*hdr_offset)(struct xfrm_state___22 *, struct sk_buff___106 *, u8 **);
	u32 (*get_mtu)(struct xfrm_state___22 *, int);
};

struct xfrm_state_afinfo___22;

struct xfrm_mode___22 {
	int (*input2)(struct xfrm_state___22 *, struct sk_buff___106 *);
	int (*input)(struct xfrm_state___22 *, struct sk_buff___106 *);
	int (*output2)(struct xfrm_state___22 *, struct sk_buff___106 *);
	int (*output)(struct xfrm_state___22 *, struct sk_buff___106 *);
	struct sk_buff___106 * (*gso_segment)(struct xfrm_state___22 *, struct sk_buff___106 *, netdev_features_t);
	void (*xmit)(struct xfrm_state___22 *, struct sk_buff___106 *);
	struct xfrm_state_afinfo___22 *afinfo;
	struct module___386 *owner;
	unsigned int encap;
	int flags;
};

struct xfrm_type_offload___22 {
	char *description;
	struct module___386 *owner;
	u8 proto;
	void (*encap)(struct xfrm_state___22 *, struct sk_buff___106 *);
	int (*input_tail)(struct xfrm_state___22 *, struct sk_buff___106 *);
	int (*xmit)(struct xfrm_state___22 *, struct sk_buff___106 *, netdev_features_t);
};

struct xfrm_state_afinfo___22 {
	unsigned int family;
	unsigned int proto;
	__be16 eth_proto;
	struct module___386 *owner;
	const struct xfrm_type___22 *type_map[256];
	const struct xfrm_type_offload___22 *type_offload_map[256];
	struct xfrm_mode___22 *mode_map[5];
	int (*init_flags)(struct xfrm_state___22 *);
	void (*init_tempsel)(struct xfrm_selector *, const struct flowi *);
	void (*init_temprop)(struct xfrm_state___22 *, const struct xfrm_tmpl *, const xfrm_address_t *, const xfrm_address_t *);
	int (*tmpl_sort)(struct xfrm_tmpl **, struct xfrm_tmpl **, int);
	int (*state_sort)(struct xfrm_state___22 **, struct xfrm_state___22 **, int);
	int (*output)(struct net___116 *, struct sock___85 *, struct sk_buff___106 *);
	int (*output_finish)(struct sock___85 *, struct sk_buff___106 *);
	int (*extract_input)(struct xfrm_state___22 *, struct sk_buff___106 *);
	int (*extract_output)(struct xfrm_state___22 *, struct sk_buff___106 *);
	int (*transport_finish)(struct sk_buff___106 *, int);
	void (*local_error)(struct sk_buff___106 *, u32);
};

struct xfrm_algo_aead_info {
	char *geniv;
	u16 icv_truncbits;
};

struct xfrm_algo_auth_info {
	u16 icv_truncbits;
	u16 icv_fullbits;
};

struct xfrm_algo_encr_info {
	char *geniv;
	u16 blockbits;
	u16 defkeybits;
};

struct xfrm_algo_comp_info {
	u16 threshold;
};

struct xfrm_algo_desc {
	char *name;
	char *compat;
	u8 available: 1;
	u8 pfkey_supported: 1;
	union {
		struct xfrm_algo_aead_info aead;
		struct xfrm_algo_auth_info auth;
		struct xfrm_algo_encr_info encr;
		struct xfrm_algo_comp_info comp;
	} uinfo;
	struct sadb_alg desc;
};

struct xfrm_algo_list {
	struct xfrm_algo_desc *algs;
	int entries;
	u32 type;
	u32 mask;
};

struct xfrm_aead_name {
	const char *name;
	int icvbits;
};

enum {
	XFRM_SHARE_ANY = 0,
	XFRM_SHARE_SESSION = 1,
	XFRM_SHARE_USER = 2,
	XFRM_SHARE_UNIQUE = 3,
};

struct xfrm_user_tmpl {
	struct xfrm_id id;
	__u16 family;
	xfrm_address_t saddr;
	__u32 reqid;
	__u8 mode;
	__u8 share;
	__u8 optional;
	__u32 aalgos;
	__u32 ealgos;
	__u32 calgos;
};

struct xfrm_userpolicy_type {
	__u8 type;
	__u16 reserved1;
	__u8 reserved2;
};

enum xfrm_attr_type_t {
	XFRMA_UNSPEC = 0,
	XFRMA_ALG_AUTH = 1,
	XFRMA_ALG_CRYPT = 2,
	XFRMA_ALG_COMP = 3,
	XFRMA_ENCAP = 4,
	XFRMA_TMPL = 5,
	XFRMA_SA = 6,
	XFRMA_POLICY = 7,
	XFRMA_SEC_CTX = 8,
	XFRMA_LTIME_VAL = 9,
	XFRMA_REPLAY_VAL = 10,
	XFRMA_REPLAY_THRESH = 11,
	XFRMA_ETIMER_THRESH = 12,
	XFRMA_SRCADDR = 13,
	XFRMA_COADDR = 14,
	XFRMA_LASTUSED = 15,
	XFRMA_POLICY_TYPE = 16,
	XFRMA_MIGRATE = 17,
	XFRMA_ALG_AEAD = 18,
	XFRMA_KMADDRESS = 19,
	XFRMA_ALG_AUTH_TRUNC = 20,
	XFRMA_MARK = 21,
	XFRMA_TFCPAD = 22,
	XFRMA_REPLAY_ESN_VAL = 23,
	XFRMA_SA_EXTRA_FLAGS = 24,
	XFRMA_PROTO = 25,
	XFRMA_ADDRESS_FILTER = 26,
	XFRMA_PAD = 27,
	XFRMA_OFFLOAD_DEV = 28,
	XFRMA_SET_MARK = 29,
	XFRMA_SET_MARK_MASK = 30,
	XFRMA_IF_ID = 31,
	__XFRMA_MAX = 32,
};

enum xfrm_sadattr_type_t {
	XFRMA_SAD_UNSPEC = 0,
	XFRMA_SAD_CNT = 1,
	XFRMA_SAD_HINFO = 2,
	__XFRMA_SAD_MAX = 3,
};

struct xfrmu_sadhinfo {
	__u32 sadhcnt;
	__u32 sadhmcnt;
};

enum xfrm_spdattr_type_t {
	XFRMA_SPD_UNSPEC = 0,
	XFRMA_SPD_INFO = 1,
	XFRMA_SPD_HINFO = 2,
	XFRMA_SPD_IPV4_HTHRESH = 3,
	XFRMA_SPD_IPV6_HTHRESH = 4,
	__XFRMA_SPD_MAX = 5,
};

struct xfrmu_spdinfo {
	__u32 incnt;
	__u32 outcnt;
	__u32 fwdcnt;
	__u32 inscnt;
	__u32 outscnt;
	__u32 fwdscnt;
};

struct xfrmu_spdhinfo {
	__u32 spdhcnt;
	__u32 spdhmcnt;
};

struct xfrmu_spdhthresh {
	__u8 lbits;
	__u8 rbits;
};

struct xfrm_usersa_info {
	struct xfrm_selector sel;
	struct xfrm_id id;
	xfrm_address_t saddr;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_stats stats;
	__u32 seq;
	__u32 reqid;
	__u16 family;
	__u8 mode;
	__u8 replay_window;
	__u8 flags;
};

struct xfrm_usersa_id {
	xfrm_address_t daddr;
	__be32 spi;
	__u16 family;
	__u8 proto;
};

struct xfrm_aevent_id {
	struct xfrm_usersa_id sa_id;
	xfrm_address_t saddr;
	__u32 flags;
	__u32 reqid;
};

struct xfrm_userspi_info {
	struct xfrm_usersa_info info;
	__u32 min;
	__u32 max;
};

struct xfrm_userpolicy_info {
	struct xfrm_selector sel;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	__u32 priority;
	__u32 index;
	__u8 dir;
	__u8 action;
	__u8 flags;
	__u8 share;
};

struct xfrm_userpolicy_id {
	struct xfrm_selector sel;
	__u32 index;
	__u8 dir;
};

struct xfrm_user_acquire {
	struct xfrm_id id;
	xfrm_address_t saddr;
	struct xfrm_selector sel;
	struct xfrm_userpolicy_info policy;
	__u32 aalgos;
	__u32 ealgos;
	__u32 calgos;
	__u32 seq;
};

struct xfrm_user_expire {
	struct xfrm_usersa_info state;
	__u8 hard;
};

struct xfrm_user_polexpire {
	struct xfrm_userpolicy_info pol;
	__u8 hard;
};

struct xfrm_usersa_flush {
	__u8 proto;
};

struct xfrm_user_report {
	__u8 proto;
	struct xfrm_selector sel;
};

struct xfrm_user_kmaddress {
	xfrm_address_t local;
	xfrm_address_t remote;
	__u32 reserved;
	__u16 family;
};

struct xfrm_user_migrate {
	xfrm_address_t old_daddr;
	xfrm_address_t old_saddr;
	xfrm_address_t new_daddr;
	xfrm_address_t new_saddr;
	__u8 proto;
	__u8 mode;
	__u16 reserved;
	__u32 reqid;
	__u16 old_family;
	__u16 new_family;
};

struct xfrm_user_mapping {
	struct xfrm_usersa_id id;
	__u32 reqid;
	xfrm_address_t old_saddr;
	xfrm_address_t new_saddr;
	__be16 old_sport;
	__be16 new_sport;
};

struct netlink_skb_parms___19 {
	struct scm_creds creds;
	__u32 portid;
	__u32 dst_group;
	__u32 flags;
	struct sock___67 *sk;
	bool nsid_is_set;
	int nsid;
};

struct netlink_kernel_cfg___8 {
	unsigned int groups;
	unsigned int flags;
	void (*input)(struct sk_buff___87 *);
	struct mutex *cb_mutex;
	int (*bind)(struct net___97 *, int);
	void (*unbind)(struct net___97 *, int);
	bool (*compare)(struct net___97 *, struct sock___67 *);
};

struct netlink_dump_control___3 {
	int (*start)(struct netlink_callback___88 *);
	int (*dump)(struct sk_buff___87 *, struct netlink_callback___88 *);
	int (*done)(struct netlink_callback___88 *);
	void *data;
	struct module___368 *module;
	u16 min_dump_alloc;
};

struct km_event___2 {
	union {
		u32 hard;
		u32 proto;
		u32 byid;
		u32 aevent;
		u32 type;
	} data;
	u32 seq;
	u32 portid;
	u32 event;
	struct net___97 *net;
};

struct xfrm_mgr___2 {
	struct list_head list;
	int (*notify)(struct xfrm_state___10 *, const struct km_event___2 *);
	int (*acquire)(struct xfrm_state___10 *, struct xfrm_tmpl *, struct xfrm_policy___10 *);
	struct xfrm_policy___10 * (*compile_policy)(struct sock___67 *, int, u8 *, int, int *);
	int (*new_mapping)(struct xfrm_state___10 *, xfrm_address_t *, __be16);
	int (*notify_policy)(struct xfrm_policy___10 *, int, const struct km_event___2 *);
	int (*report)(struct net___97 *, u8, struct xfrm_selector *, xfrm_address_t *);
	int (*migrate)(const struct xfrm_selector *, u8, u8, const struct xfrm_migrate *, int, const struct xfrm_kmaddress *, const struct xfrm_encap_tmpl *);
	bool (*is_alive)(const struct km_event___2 *);
};

struct xfrm_dump_info {
	struct sk_buff___87 *in_skb;
	struct sk_buff___87 *out_skb;
	u32 nlmsg_seq;
	u16 nlmsg_flags;
};

struct xfrm_link {
	int (*doit)(struct sk_buff___87 *, struct nlmsghdr *, struct nlattr **);
	int (*start)(struct netlink_callback___88 *);
	int (*dump)(struct sk_buff___87 *, struct netlink_callback___88 *);
	int (*done)(struct netlink_callback___88 *);
	const struct nla_policy *nla_pol;
	int nla_max;
};

struct module___387;

struct file___461;

struct kiocb___461;

struct iov_iter___228;

struct poll_table_struct___300;

struct vm_area_struct___462;

struct inode___461;

struct file_lock___461;

struct page___462;

struct pipe_inode_info___142;

struct seq_file___400;

struct file_operations___461 {
	struct module___387 *owner;
	loff_t (*llseek)(struct file___461 *, loff_t, int);
	ssize_t (*read)(struct file___461 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___461 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___461 *, struct iov_iter___228 *);
	ssize_t (*write_iter)(struct kiocb___461 *, struct iov_iter___228 *);
	int (*iopoll)(struct kiocb___461 *, bool);
	int (*iterate)(struct file___461 *, struct dir_context *);
	int (*iterate_shared)(struct file___461 *, struct dir_context *);
	__poll_t (*poll)(struct file___461 *, struct poll_table_struct___300 *);
	long int (*unlocked_ioctl)(struct file___461 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___461 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___461 *, struct vm_area_struct___462 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___461 *, struct file___461 *);
	int (*flush)(struct file___461 *, fl_owner_t);
	int (*release)(struct inode___461 *, struct file___461 *);
	int (*fsync)(struct file___461 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___461 *, int);
	int (*lock)(struct file___461 *, int, struct file_lock___461 *);
	ssize_t (*sendpage)(struct file___461 *, struct page___462 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___461 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___461 *, int, struct file_lock___461 *);
	ssize_t (*splice_write)(struct pipe_inode_info___142 *, struct file___461 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___461 *, loff_t *, struct pipe_inode_info___142 *, size_t, unsigned int);
	int (*setlease)(struct file___461 *, long int, struct file_lock___461 **, void **);
	long int (*fallocate)(struct file___461 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___400 *, struct file___461 *);
	ssize_t (*copy_file_range)(struct file___461 *, loff_t, struct file___461 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___461 *, loff_t, struct file___461 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___461 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___462 {
	u64 seqnum;
	struct vm_area_struct___462 *vmas[4];
};

struct page_frag___462 {
	struct page___462 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___462;

struct mem_cgroup___194;

struct cred___429;

struct nsproxy___356;

struct signal_struct___336;

struct bio_list___251;

struct backing_dev_info___251;

struct css_set___310;

struct vm_struct___365;

struct task_struct___463 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___463 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___462 *mm;
	struct mm_struct___462 *active_mm;
	struct vmacache___462 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___463 *real_parent;
	struct task_struct___463 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___463 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___194 *active_memcg;
	long int rh_reserved2;
	struct pid___258 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___258 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___258 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___429 *ptracer_cred;
	const struct cred___429 *real_cred;
	const struct cred___429 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___356 *nsproxy;
	struct signal_struct___336 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___463 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___251 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___251 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___310 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___142 *splice_pipe;
	struct page_frag___462 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___194 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___463 *oom_reaper_list;
	struct vm_struct___365 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___156 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rw_semaphore___463 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___463 *owner;
};

struct key___429;

struct ucounts___326;

struct user_namespace___326 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___326 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___29 ns;
	long unsigned int flags;
	struct key___429 *persistent_keyring_register;
	struct rw_semaphore___463 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___326 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___462 *pgtable_t___462;

struct address_space___461;

struct dev_pagemap___449;

struct page___462 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___461 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___462 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___462 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___462 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___449 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___194 *mem_cgroup;
};

struct pglist_data___462;

struct lruvec___462 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___462 *pgdat;
};

struct zone___462 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___462 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___462 {
	struct zone___462 *zone;
	int zone_idx;
};

struct zonelist___462 {
	struct zoneref___462 _zonerefs[25];
};

struct pglist_data___462 {
	struct zone___462 node_zones[3];
	struct zonelist___462 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___463 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___463 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___462 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___463 {
	void *stack;
	struct task_struct___463 *task;
	long int status;
};

struct blocking_notifier_head___462 {
	struct rw_semaphore___463 rwsem;
	struct notifier_block *head;
};

struct vfsmount___73;

struct dentry___461;

struct path___462 {
	struct vfsmount___73 *mnt;
	struct dentry___461 *dentry;
};

struct file___461 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___462 f_path;
	struct inode___461 *f_inode;
	const struct file_operations___461 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___258 f_owner;
	const struct cred___429 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___461 *f_mapping;
	errseq_t f_wb_err;
};

struct user_struct___429;

struct cred___429 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___429 *session_keyring;
	struct key___429 *process_keyring;
	struct key___429 *thread_keyring;
	struct key___429 *request_key_auth;
	void *security;
	struct user_struct___429 *user;
	struct user_namespace___326 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___455;

struct kernfs_elem_dir___455 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___455 *root;
};

struct kernfs_node___456;

struct kernfs_syscall_ops___455;

struct kernfs_root___455 {
	struct kernfs_node___456 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___455 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___455 {
	struct kernfs_node___456 *target_kn;
};

struct kernfs_ops___455;

struct kernfs_elem_attr___455 {
	const struct kernfs_ops___455 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___456 *notify_next;
};

struct kernfs_node___456 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___456 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___455 dir;
		struct kernfs_elem_symlink___455 symlink;
		struct kernfs_elem_attr___455 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___455;

struct kernfs_ops___455 {
	int (*open)(struct kernfs_open_file___455 *);
	void (*release)(struct kernfs_open_file___455 *);
	int (*seq_show)(struct seq_file___400 *, void *);
	void * (*seq_start)(struct seq_file___400 *, loff_t *);
	void * (*seq_next)(struct seq_file___400 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___400 *, void *);
	ssize_t (*read)(struct kernfs_open_file___455 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___455 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___455 *, struct vm_area_struct___462 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___455 *, struct poll_table_struct___300 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___455 {
	int (*remount_fs)(struct kernfs_root___455 *, int *, char *);
	int (*show_options)(struct seq_file___400 *, struct kernfs_root___455 *);
	int (*mkdir)(struct kernfs_node___456 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___456 *);
	int (*rename)(struct kernfs_node___456 *, struct kernfs_node___456 *, const char *);
	int (*show_path)(struct seq_file___400 *, struct kernfs_node___456 *, struct kernfs_root___455 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___400;

struct seq_file___400 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___400 *op;
	int poll_event;
	const struct file___461 *file;
	void *private;
};

struct vm_operations_struct___449;

struct kernfs_open_file___455 {
	struct kernfs_node___456 *kn;
	struct file___461 *file;
	struct seq_file___400 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___449 *vm_ops;
};

struct vm_fault___449;

struct vm_operations_struct___449 {
	void (*open)(struct vm_area_struct___462 *);
	void (*close)(struct vm_area_struct___462 *);
	int (*split)(struct vm_area_struct___462 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___462 *);
	vm_fault_t (*fault)(struct vm_fault___449 *);
	vm_fault_t (*huge_fault)(struct vm_fault___449 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___449 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___462 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___449 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___449 *);
	int (*access)(struct vm_area_struct___462 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___462 *);
	int (*set_policy)(struct vm_area_struct___462 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___462 *, long unsigned int);
	struct page___462 * (*find_special_page)(struct vm_area_struct___462 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___310)(struct file___461 *, wait_queue_head_t *, struct poll_table_struct___300 *);

struct poll_table_struct___300 {
	poll_queue_proc___310 _qproc;
	__poll_t _key;
};

struct vm_area_struct___462 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___462 *vm_next;
	struct vm_area_struct___462 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___462 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___449 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___461 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sock___86;

struct kobj_ns_type_operations___86 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___86 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct net___117;

typedef struct {
	struct net___117 *net;
} possible_net_t___108;

struct proto___86;

struct sock_common___86 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___86 *skc_prot;
	possible_net_t___108 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___86 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___107;

struct sk_buff_head___106 {
	struct sk_buff___107 *next;
	struct sk_buff___107 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___86;

struct socket_wq___87;

struct dst_entry___86;

struct socket___88;

struct net_device___106;

struct sock___86 {
	struct sock_common___86 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___106 sk_error_queue;
	struct sk_buff_head___106 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___107 *head;
		struct sk_buff___107 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___86 *sk_filter;
	union {
		struct socket_wq___87 *sk_wq;
		struct socket_wq___87 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___86 *sk_rx_dst;
	struct dst_entry___86 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___107 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___106 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___462 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___86 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___258 *sk_peer_pid;
	const struct cred___429 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___88 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___194 *sk_memcg;
	void (*sk_state_change)(struct sock___86 *);
	void (*sk_data_ready)(struct sock___86 *);
	void (*sk_write_space)(struct sock___86 *);
	void (*sk_error_report)(struct sock___86 *);
	int (*sk_backlog_rcv)(struct sock___86 *, struct sk_buff___107 *);
	struct sk_buff___107 * (*sk_validate_xmit_skb)(struct sock___86 *, struct net_device___106 *, struct sk_buff___107 *);
	void (*sk_destruct)(struct sock___86 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kobject___449;

struct bin_attribute___425;

struct attribute_group___426 {
	const char *name;
	umode_t (*is_visible)(struct kobject___449 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___449 *, struct bin_attribute___425 *, int);
	struct attribute **attrs;
	struct bin_attribute___425 **bin_attrs;
};

struct kset___448;

struct kobj_type___448;

struct kobject___449 {
	const char *name;
	struct list_head entry;
	struct kobject___449 *parent;
	struct kset___448 *kset;
	struct kobj_type___448 *ktype;
	struct kernfs_node___456 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___425 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___461 *, struct kobject___449 *, struct bin_attribute___425 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___461 *, struct kobject___449 *, struct bin_attribute___425 *, char *, loff_t, size_t);
	int (*mmap)(struct file___461 *, struct kobject___449 *, struct bin_attribute___425 *, struct vm_area_struct___462 *);
};

struct sysfs_ops___448 {
	ssize_t (*show)(struct kobject___449 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___449 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___448;

struct kset___448 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___449 kobj;
	const struct kset_uevent_ops___448 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___448 {
	void (*release)(struct kobject___449 *);
	const struct sysfs_ops___448 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___86 * (*child_ns_type)(struct kobject___449 *);
	const void * (*namespace)(struct kobject___449 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___448 {
	int (* const filter)(struct kset___448 *, struct kobject___449 *);
	const char * (* const name)(struct kset___448 *, struct kobject___449 *);
	int (* const uevent)(struct kset___448 *, struct kobject___449 *, struct kobj_uevent_env *);
};

struct kobj_attribute___439 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___449 *, struct kobj_attribute___439 *, char *);
	ssize_t (*store)(struct kobject___449 *, struct kobj_attribute___439 *, const char *, size_t);
};

struct kernel_param___387;

struct kernel_param_ops___387 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___387 *);
	int (*get)(char *, const struct kernel_param___387 *);
	void (*free)(void *);
};

struct kparam_array___387;

struct kernel_param___387 {
	const char *name;
	struct module___387 *mod;
	const struct kernel_param_ops___387 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___387 *arr;
	};
};

struct kparam_array___387 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___387 *ops;
	void *elem;
};

struct module_kobject___387 {
	struct kobject___449 kobj;
	struct module___387 *mod;
	struct kobject___449 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___387 {
	struct module___387 *mod;
	struct latch_tree_node node;
};

struct module_layout___387 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___387 mtn;
};

struct module_attribute___387;

struct module___387 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___387 mkobj;
	struct module_attribute___387 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___449 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___387 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___387 core_layout;
	struct module_layout___387 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___387 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___387 *, struct module_kobject___387 *, char *);
	ssize_t (*store)(struct module_attribute___387 *, struct module_kobject___387 *, const char *, size_t);
	void (*setup)(struct module___387 *, const char *);
	int (*test)(struct module___387 *);
	void (*free)(struct module___387 *);
};

struct user_struct___429 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___429 *uid_keyring;
	struct key___429 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___462;

struct mm_struct___462 {
	struct {
		struct vm_area_struct___462 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___461 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___463 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___462 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___463 *owner;
		struct user_namespace___326 *user_ns;
		struct file___461 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___462 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup___310;

struct cgroup_subsys___310;

struct cgroup_subsys_state___310 {
	struct cgroup___310 *cgroup;
	struct cgroup_subsys___310 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___310 *parent;
};

struct cgroup_file___310 {
	struct kernfs_node___456 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___194;

struct mem_cgroup___194 {
	struct cgroup_subsys_state___310 css;
	struct mem_cgroup_id___14 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___310 events_file;
	struct cgroup_file___310 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___463 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___194 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cgroup_namespace___310;

struct nsproxy___356 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net___117 *net_ns;
	struct cgroup_namespace___310 *cgroup_ns;
};

struct signal_struct___336 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___463 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___463 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___258 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___258 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___462 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___258 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___251;

struct bio_list___251 {
	struct bio___251 *head;
	struct bio___251 *tail;
};

struct bdi_writeback_congested___251;

struct bdi_writeback___251 {
	struct backing_dev_info___251 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___251 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___310 *memcg_css;
	struct cgroup_subsys_state___310 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___429;

struct backing_dev_info___251 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___251 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___429 *dev;
	struct device___429 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___461 *debug_dir;
	struct dentry___461 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___310 {
	struct cgroup_subsys_state___310 *subsys[13];
	refcount_t refcount;
	struct css_set___310 *dom_cset;
	struct cgroup___310 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___310 *mg_src_cgrp;
	struct cgroup___310 *mg_dst_cgrp;
	struct css_set___310 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___461;

struct pipe_buffer___142;

struct pipe_inode_info___142 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___462 *tmp_page;
	struct fasync_struct___461 *fasync_readers;
	struct fasync_struct___461 *fasync_writers;
	struct pipe_buffer___142 *bufs;
	struct user_struct___429 *user;
};

struct vm_struct___365 {
	struct vm_struct___365 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___462 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___348 {
	struct task_struct___463 task;
	long unsigned int stack[8192];
};

typedef int (*key_restrict_link_func_t___430)(struct key___429 *, const struct key_type *, const union key_payload *, struct key___429 *);

struct key_restriction___429;

struct key___429 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___463 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___429 *restrict_link;
};

struct key_restriction___429 {
	key_restrict_link_func_t___430 check;
	struct key___429 *key;
	struct key_type *keytype;
};

struct dentry_operations___461;

struct super_block___461;

struct dentry___461 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___461 *d_parent;
	struct qstr d_name;
	struct inode___461 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___461 *d_op;
	struct super_block___461 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___461;

struct address_space___461 {
	struct inode___461 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___463 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___461 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___461;

struct block_device___461;

struct inode___461 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___461 *i_op;
	struct super_block___461 *i_sb;
	struct address_space___461 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___463 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___251 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___461 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___461 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___142 *i_pipe;
		struct block_device___461 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___461 {
	int (*d_revalidate)(struct dentry___461 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___461 *, unsigned int);
	int (*d_hash)(const struct dentry___461 *, struct qstr *);
	int (*d_compare)(const struct dentry___461 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___461 *);
	int (*d_init)(struct dentry___461 *);
	void (*d_release)(struct dentry___461 *);
	void (*d_prune)(struct dentry___461 *);
	void (*d_iput)(struct dentry___461 *, struct inode___461 *);
	char * (*d_dname)(struct dentry___461 *, char *, int);
	struct vfsmount___73 * (*d_automount)(struct path___462 *);
	int (*d_manage)(const struct path___462 *, bool);
	struct dentry___461 * (*d_real)(struct dentry___461 *, const struct inode___461 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___461;

struct mem_dqinfo___461 {
	struct quota_format_type___461 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___461;

struct quota_info___461 {
	unsigned int flags;
	struct rw_semaphore___463 dqio_sem;
	struct inode___461 *files[3];
	struct mem_dqinfo___461 info[3];
	const struct quota_format_ops___461 *ops[3];
};

struct rcuwait___461 {
	struct task_struct___463 *task;
};

struct percpu_rw_semaphore___461 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___463 rw_sem;
	struct rcuwait___461 writer;
	int readers_block;
};

struct sb_writers___461 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___461 rw_sem[3];
};

struct shrink_control___194;

struct shrinker___194 {
	long unsigned int (*count_objects)(struct shrinker___194 *, struct shrink_control___194 *);
	long unsigned int (*scan_objects)(struct shrinker___194 *, struct shrink_control___194 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___461;

struct super_operations___461;

struct dquot_operations___461;

struct quotactl_ops___461;

struct super_block___461 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___461 *s_type;
	const struct super_operations___461 *s_op;
	const struct dquot_operations___461 *dq_op;
	const struct quotactl_ops___461 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___461 *s_root;
	struct rw_semaphore___463 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___461 *s_bdev;
	struct backing_dev_info___251 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___461 s_dquot;
	struct sb_writers___461 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___461 *s_d_op;
	int cleancache_poolid;
	struct shrinker___194 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___326 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___73 {
	struct dentry___461 *mnt_root;
	struct super_block___461 *mnt_sb;
	int mnt_flags;
};

typedef int (*dev_page_fault_t___449)(struct vm_area_struct___462 *, long unsigned int, const struct page___462 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___449)(struct page___462 *, void *);

struct dev_pagemap___449 {
	dev_page_fault_t___449 page_fault;
	dev_page_free_t___449 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___429 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___462 {
	struct task_struct___463 *task;
	struct core_thread___462 *next;
};

struct core_state___462 {
	atomic_t nr_threads;
	struct core_thread___462 dumper;
	struct completion startup;
};

struct vm_fault___449 {
	struct vm_area_struct___462 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___462 *cow_page;
	struct mem_cgroup___194 *memcg;
	struct page___462 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___462 prealloc_pte;
};

struct bio_vec___253 {
	struct page___462 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___228 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___253 *bvec;
		struct pipe_inode_info___142 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct msghdr___89 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___228 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___461 *msg_iocb;
};

struct kiocb___461 {
	struct file___461 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___461 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct shrink_control___194 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___194 *memcg;
};

struct iattr___461 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___461 *ia_file;
};

struct dquot___461 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___461 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___461 {
	int qf_fmt_id;
	const struct quota_format_ops___461 *qf_ops;
	struct module___387 *qf_owner;
	struct quota_format_type___461 *qf_next;
};

struct quota_format_ops___461 {
	int (*check_quota_file)(struct super_block___461 *, int);
	int (*read_file_info)(struct super_block___461 *, int);
	int (*write_file_info)(struct super_block___461 *, int);
	int (*free_file_info)(struct super_block___461 *, int);
	int (*read_dqblk)(struct dquot___461 *);
	int (*commit_dqblk)(struct dquot___461 *);
	int (*release_dqblk)(struct dquot___461 *);
	int (*get_next_id)(struct super_block___461 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___461 {
	int (*write_dquot)(struct dquot___461 *);
	struct dquot___461 * (*alloc_dquot)(struct super_block___461 *, int);
	void (*destroy_dquot)(struct dquot___461 *);
	int (*acquire_dquot)(struct dquot___461 *);
	int (*release_dquot)(struct dquot___461 *);
	int (*mark_dirty)(struct dquot___461 *);
	int (*write_info)(struct super_block___461 *, int);
	qsize_t * (*get_reserved_space)(struct inode___461 *);
	int (*get_projid)(struct inode___461 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___461 *, qsize_t *);
	int (*get_next_id)(struct super_block___461 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___461 {
	int (*quota_on)(struct super_block___461 *, int, int, const struct path___462 *);
	int (*quota_off)(struct super_block___461 *, int);
	int (*quota_enable)(struct super_block___461 *, unsigned int);
	int (*quota_disable)(struct super_block___461 *, unsigned int);
	int (*quota_sync)(struct super_block___461 *, int);
	int (*set_info)(struct super_block___461 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___461 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___461 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___461 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___461 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___461 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___214;

struct address_space_operations___461 {
	int (*writepage)(struct page___462 *, struct writeback_control___214 *);
	int (*readpage)(struct file___461 *, struct page___462 *);
	int (*writepages)(struct address_space___461 *, struct writeback_control___214 *);
	int (*set_page_dirty)(struct page___462 *);
	int (*readpages)(struct file___461 *, struct address_space___461 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___461 *, struct address_space___461 *, loff_t, unsigned int, unsigned int, struct page___462 **, void **);
	int (*write_end)(struct file___461 *, struct address_space___461 *, loff_t, unsigned int, unsigned int, struct page___462 *, void *);
	sector_t (*bmap)(struct address_space___461 *, sector_t);
	void (*invalidatepage)(struct page___462 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___462 *, gfp_t);
	void (*freepage)(struct page___462 *);
	ssize_t (*direct_IO)(struct kiocb___461 *, struct iov_iter___228 *);
	int (*migratepage)(struct address_space___461 *, struct page___462 *, struct page___462 *, enum migrate_mode);
	bool (*isolate_page)(struct page___462 *, isolate_mode_t);
	void (*putback_page)(struct page___462 *);
	int (*launder_page)(struct page___462 *);
	int (*is_partially_uptodate)(struct page___462 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___462 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___461 *, struct page___462 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___461 *, sector_t *);
	void (*swap_deactivate)(struct file___461 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___214 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___251 *wb;
	struct inode___461 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___461 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___461 *bd_inode;
	struct super_block___461 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___461 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___251 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___461 {
	struct dentry___461 * (*lookup)(struct inode___461 *, struct dentry___461 *, unsigned int);
	const char * (*get_link)(struct dentry___461 *, struct inode___461 *, struct delayed_call *);
	int (*permission)(struct inode___461 *, int);
	struct posix_acl * (*get_acl)(struct inode___461 *, int);
	int (*readlink)(struct dentry___461 *, char *, int);
	int (*create)(struct inode___461 *, struct dentry___461 *, umode_t, bool);
	int (*link)(struct dentry___461 *, struct inode___461 *, struct dentry___461 *);
	int (*unlink)(struct inode___461 *, struct dentry___461 *);
	int (*symlink)(struct inode___461 *, struct dentry___461 *, const char *);
	int (*mkdir)(struct inode___461 *, struct dentry___461 *, umode_t);
	int (*rmdir)(struct inode___461 *, struct dentry___461 *);
	int (*mknod)(struct inode___461 *, struct dentry___461 *, umode_t, dev_t);
	int (*rename)(struct inode___461 *, struct dentry___461 *, struct inode___461 *, struct dentry___461 *, unsigned int);
	int (*setattr)(struct dentry___461 *, struct iattr___461 *);
	int (*getattr)(const struct path___462 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___461 *, char *, size_t);
	int (*fiemap)(struct inode___461 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___461 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___461 *, struct dentry___461 *, struct file___461 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___461 *, struct dentry___461 *, umode_t);
	int (*set_acl)(struct inode___461 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___461 {
	void (*fl_copy_lock)(struct file_lock___461 *, struct file_lock___461 *);
	void (*fl_release_private)(struct file_lock___461 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___461;

struct file_lock___461 {
	struct file_lock___461 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___461 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___461 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___461 *fl_ops;
	const struct lock_manager_operations___461 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___461 {
	int (*lm_compare_owner)(struct file_lock___461 *, struct file_lock___461 *);
	long unsigned int (*lm_owner_key)(struct file_lock___461 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___461 *);
	int (*lm_grant)(struct file_lock___461 *, int);
	bool (*lm_break)(struct file_lock___461 *);
	int (*lm_change)(struct file_lock___461 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___461 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___461 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___461 *fa_next;
	struct file___461 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___461 {
	const char *name;
	int fs_flags;
	struct dentry___461 * (*mount)(struct file_system_type___461 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___461 *);
	struct module___387 *owner;
	struct file_system_type___461 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___461 {
	struct inode___461 * (*alloc_inode)(struct super_block___461 *);
	void (*destroy_inode)(struct inode___461 *);
	void (*dirty_inode)(struct inode___461 *, int);
	int (*write_inode)(struct inode___461 *, struct writeback_control___214 *);
	int (*drop_inode)(struct inode___461 *);
	void (*evict_inode)(struct inode___461 *);
	void (*put_super)(struct super_block___461 *);
	int (*sync_fs)(struct super_block___461 *, int);
	int (*freeze_super)(struct super_block___461 *);
	int (*freeze_fs)(struct super_block___461 *);
	int (*thaw_super)(struct super_block___461 *);
	int (*unfreeze_fs)(struct super_block___461 *);
	int (*statfs)(struct dentry___461 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___461 *, int *, char *);
	void (*umount_begin)(struct super_block___461 *);
	int (*show_options)(struct seq_file___400 *, struct dentry___461 *);
	int (*show_devname)(struct seq_file___400 *, struct dentry___461 *);
	int (*show_path)(struct seq_file___400 *, struct dentry___461 *);
	int (*show_stats)(struct seq_file___400 *, struct dentry___461 *);
	ssize_t (*quota_read)(struct super_block___461 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___461 *, int, const char *, size_t, loff_t);
	struct dquot___461 ** (*get_dquots)(struct inode___461 *);
	int (*bdev_try_to_free_page)(struct super_block___461 *, struct page___462 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___461 *, struct shrink_control___194 *);
	long int (*free_cached_objects)(struct super_block___461 *, struct shrink_control___194 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___251(struct bio___251 *);

struct bio_integrity_payload___251;

struct bio_set___251;

struct bio___251 {
	struct bio___251 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___251 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___251 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___253 *bi_io_vec;
	struct bio_set___251 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___253 bi_inline_vecs[0];
};

struct socket_wq___87 {
	wait_queue_head_t wait;
	struct fasync_struct___461 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___87;

struct socket___88 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___87 *wq;
	struct file___461 *file;
	struct sock___86 *sk;
	const struct proto_ops___87 *ops;
};

typedef int (*sk_read_actor_t___86)(read_descriptor_t *, struct sk_buff___107 *, unsigned int, size_t);

struct proto_ops___87 {
	int family;
	struct module___387 *owner;
	int (*release)(struct socket___88 *);
	int (*bind)(struct socket___88 *, struct sockaddr *, int);
	int (*connect)(struct socket___88 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___88 *, struct socket___88 *);
	int (*accept)(struct socket___88 *, struct socket___88 *, int, bool);
	int (*getname)(struct socket___88 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___461 *, struct socket___88 *, struct poll_table_struct___300 *);
	int (*ioctl)(struct socket___88 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___88 *, int);
	int (*shutdown)(struct socket___88 *, int);
	int (*setsockopt)(struct socket___88 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___88 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___88 *, struct msghdr___89 *, size_t);
	int (*recvmsg)(struct socket___88 *, struct msghdr___89 *, size_t, int);
	int (*mmap)(struct file___461 *, struct socket___88 *, struct vm_area_struct___462 *);
	ssize_t (*sendpage)(struct socket___88 *, struct page___462 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___88 *, loff_t *, struct pipe_inode_info___142 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___86 *, int);
	int (*peek_len)(struct socket___88 *);
	int (*read_sock)(struct sock___86 *, read_descriptor_t *, sk_read_actor_t___86);
	int (*sendpage_locked)(struct sock___86 *, struct page___462 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___86 *, struct msghdr___89 *, size_t);
	int (*set_rcvlowat)(struct sock___86 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct nf_bridge_info___106;

struct sk_buff___107 {
	union {
		struct {
			struct sk_buff___107 *next;
			struct sk_buff___107 *prev;
			union {
				struct net_device___106 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___86 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___107 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___106 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct net_proto_family___5 {
	int family;
	int (*create)(struct net___117 *, struct socket___88 *, int, int);
	struct module___387 *owner;
};

struct inet_frags___106;

struct netns_frags___106 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___106 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_rules_ops___86;

struct fib_notifier_ops___87;

struct netns_ipv4___106 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___86 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___86 *fibnl;
	struct sock___86 **icmp_sk;
	struct sock___86 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___86 **tcp_sk;
	struct netns_frags___106 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___86 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___87 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___87 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___86;

struct dst_ops___117 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___117 *);
	struct dst_entry___86 * (*check)(struct dst_entry___86 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___86 *);
	unsigned int (*mtu)(const struct dst_entry___86 *);
	u32 * (*cow_metrics)(struct dst_entry___86 *, long unsigned int);
	void (*destroy)(struct dst_entry___86 *);
	void (*ifdown)(struct dst_entry___86 *, struct net_device___106 *, int);
	struct dst_entry___86 * (*negative_advice)(struct dst_entry___86 *);
	void (*link_failure)(struct sk_buff___107 *);
	void (*update_pmtu)(struct dst_entry___86 *, struct sock___86 *, struct sk_buff___107 *, u32);
	void (*redirect)(struct dst_entry___86 *, struct sock___86 *, struct sk_buff___107 *);
	int (*local_out)(struct net___117 *, struct sock___86 *, struct sk_buff___107 *);
	struct neighbour___86 * (*neigh_lookup)(const struct dst_entry___86 *, struct sk_buff___107 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___86 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___117 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___106 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___117 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___86 *fib6_rules_ops;
	struct sock___86 **icmp_sk;
	struct sock___86 *ndisc_sk;
	struct sock___86 *tcp_sk;
	struct sock___86 *igmp_sk;
	struct sock___86 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___86 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___87 *notifier_ops;
	struct fib_notifier_ops___87 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___87 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___86 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___106 {
	struct netns_frags___106 frags;
};

struct netns_xfrm___117 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___86 *nlsk;
	struct sock___86 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___117 xfrm4_dst_ops;
	struct dst_ops___117 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___96;

struct net___117 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___326 *user_ns;
	struct ucounts___326 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___29 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___86 *rtnl;
	struct sock___86 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___106 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___106 ipv4;
	struct netns_ipv6___117 ipv6;
	struct netns_sctp___87 sctp;
	struct netns_nf___19 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___106 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___86 *nfnl;
	struct sock___86 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___117 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___86 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___96 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___429 {
	int (*prepare)(struct device___429 *);
	void (*complete)(struct device___429 *);
	int (*suspend)(struct device___429 *);
	int (*resume)(struct device___429 *);
	int (*freeze)(struct device___429 *);
	int (*thaw)(struct device___429 *);
	int (*poweroff)(struct device___429 *);
	int (*restore)(struct device___429 *);
	int (*suspend_late)(struct device___429 *);
	int (*resume_early)(struct device___429 *);
	int (*freeze_late)(struct device___429 *);
	int (*thaw_early)(struct device___429 *);
	int (*poweroff_late)(struct device___429 *);
	int (*restore_early)(struct device___429 *);
	int (*suspend_noirq)(struct device___429 *);
	int (*resume_noirq)(struct device___429 *);
	int (*freeze_noirq)(struct device___429 *);
	int (*thaw_noirq)(struct device___429 *);
	int (*poweroff_noirq)(struct device___429 *);
	int (*restore_noirq)(struct device___429 *);
	int (*runtime_suspend)(struct device___429 *);
	int (*runtime_resume)(struct device___429 *);
	int (*runtime_idle)(struct device___429 *);
};

struct dev_pm_info___429 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___429 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___429;

struct bus_type___429;

struct device_driver___429;

struct dev_pm_domain___429;

struct dma_map_ops___201;

struct fwnode_handle___349;

struct class___429;

struct device___429 {
	struct device___429 *parent;
	struct device_private *p;
	struct kobject___449 kobj;
	const char *init_name;
	const struct device_type___429 *type;
	struct mutex mutex;
	struct bus_type___429 *bus;
	struct device_driver___429 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___429 power;
	struct dev_pm_domain___429 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___201 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___349 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___429 *class;
	const struct attribute_group___426 **groups;
	void (*release)(struct device___429 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___429 {
	struct dev_pm_ops___429 ops;
	void (*detach)(struct device___429 *, bool);
	int (*activate)(struct device___429 *);
	void (*sync)(struct device___429 *);
	void (*dismiss)(struct device___429 *);
};

struct bus_type___429 {
	const char *name;
	const char *dev_name;
	struct device___429 *dev_root;
	const struct attribute_group___426 **bus_groups;
	const struct attribute_group___426 **dev_groups;
	const struct attribute_group___426 **drv_groups;
	int (*match)(struct device___429 *, struct device_driver___429 *);
	int (*uevent)(struct device___429 *, struct kobj_uevent_env *);
	int (*probe)(struct device___429 *);
	int (*remove)(struct device___429 *);
	void (*shutdown)(struct device___429 *);
	int (*online)(struct device___429 *);
	int (*offline)(struct device___429 *);
	int (*suspend)(struct device___429 *, pm_message_t);
	int (*resume)(struct device___429 *);
	int (*num_vf)(struct device___429 *);
	int (*dma_configure)(struct device___429 *);
	const struct dev_pm_ops___429 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___429 {
	const char *name;
	struct bus_type___429 *bus;
	struct module___387 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___429 *);
	int (*remove)(struct device___429 *);
	void (*shutdown)(struct device___429 *);
	int (*suspend)(struct device___429 *, pm_message_t);
	int (*resume)(struct device___429 *);
	const struct attribute_group___426 **groups;
	const struct dev_pm_ops___429 *pm;
	void (*coredump)(struct device___429 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___429 {
	const char *name;
	const struct attribute_group___426 **groups;
	int (*uevent)(struct device___429 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___429 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___429 *);
	const struct dev_pm_ops___429 *pm;
};

struct class___429 {
	const char *name;
	struct module___387 *owner;
	const struct attribute_group___426 **class_groups;
	const struct attribute_group___426 **dev_groups;
	struct kobject___449 *dev_kobj;
	int (*dev_uevent)(struct device___429 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___429 *, umode_t *);
	void (*class_release)(struct class___429 *);
	void (*dev_release)(struct device___429 *);
	int (*shutdown_pre)(struct device___429 *);
	const struct kobj_ns_type_operations___86 *ns_type;
	const void * (*namespace)(struct device___429 *);
	const struct dev_pm_ops___429 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___201 {
	void * (*alloc)(struct device___429 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___429 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___429 *, struct vm_area_struct___462 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___429 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___429 *, struct page___462 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___429 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___429 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___429 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___429 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___429 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___429 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide21;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___429 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___429 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___429 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___429 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___429 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___429 *, u64);
	u64 (*get_required_mask)(struct device___429 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___349;

struct fwnode_handle___349 {
	struct fwnode_handle___349 *secondary;
	const struct fwnode_operations___349 *ops;
};

typedef void compound_page_dtor___449(struct page___462 *);

struct fwnode_reference_args___349;

struct fwnode_endpoint___349;

struct fwnode_operations___349 {
	struct fwnode_handle___349 * (*get)(struct fwnode_handle___349 *);
	void (*put)(struct fwnode_handle___349 *);
	bool (*device_is_available)(const struct fwnode_handle___349 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___349 *, const struct device___429 *);
	bool (*property_present)(const struct fwnode_handle___349 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___349 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___349 *, const char *, const char **, size_t);
	struct fwnode_handle___349 * (*get_parent)(const struct fwnode_handle___349 *);
	struct fwnode_handle___349 * (*get_next_child_node)(const struct fwnode_handle___349 *, struct fwnode_handle___349 *);
	struct fwnode_handle___349 * (*get_named_child_node)(const struct fwnode_handle___349 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___349 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___349 *);
	struct fwnode_handle___349 * (*graph_get_next_endpoint)(const struct fwnode_handle___349 *, struct fwnode_handle___349 *);
	struct fwnode_handle___349 * (*graph_get_remote_endpoint)(const struct fwnode_handle___349 *);
	struct fwnode_handle___349 * (*graph_get_port_parent)(struct fwnode_handle___349 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___349 *, struct fwnode_endpoint___349 *);
};

struct fwnode_endpoint___349 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___349 *local_fwnode;
};

struct fwnode_reference_args___349 {
	struct fwnode_handle___349 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___142;

struct pipe_buffer___142 {
	struct page___462 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___142 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___142 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___142 *, struct pipe_buffer___142 *);
	void (*release)(struct pipe_inode_info___142 *, struct pipe_buffer___142 *);
	int (*steal)(struct pipe_inode_info___142 *, struct pipe_buffer___142 *);
	union {
		bool (*get)(struct pipe_inode_info___142 *, struct pipe_buffer___142 *);
		struct {
			void (*get)(struct pipe_inode_info___142 *, struct pipe_buffer___142 *);
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
};

struct nf_bridge_info___106 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___106 = 0,
		BRNF_PROTO_8021Q___106 = 1,
		BRNF_PROTO_PPPOE___106 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___106 *physindev;
	struct net_device___106 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___106(struct sk_buff___107 **);

struct net_device_ops___106;

struct ethtool_ops___106;

struct l3mdev_ops___86;

struct xfrmdev_ops___106;

struct tlsdev_ops___106;

struct header_ops___106;

struct netdev_rx_queue___106;

struct mini_Qdisc___98;

struct netdev_queue___106;

struct Qdisc___98;

struct rtnl_link_ops___98;

struct dcbnl_rtnl_ops___106;

struct net_device___106 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___106 *netdev_ops;
	const struct ethtool_ops___106 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___86 *l3mdev_ops;
	const struct ndisc_ops___2 *ndisc_ops;
	const struct xfrmdev_ops___106 *xfrmdev_ops;
	const struct tlsdev_ops___106 *tlsdev_ops;
	const struct header_ops___106 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___448 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___2 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___106 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___96 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___106 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___98 *miniq_ingress;
	struct netdev_queue___106 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___106 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___98 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___98 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___106 = 0,
		NETREG_REGISTERED___106 = 1,
		NETREG_UNREGISTERING___106 = 2,
		NETREG_UNREGISTERED___106 = 3,
		NETREG_RELEASED___106 = 4,
		NETREG_DUMMY___106 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___106 = 0,
		RTNL_LINK_INITIALIZING___106 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___106 *);
	struct netpoll_info *npinfo;
	possible_net_t___108 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___429 dev;
	const struct attribute_group___426 *sysfs_groups[4];
	const struct attribute_group___426 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___98 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___106 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide37;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct ethtool_ops___106 {
	int (*get_settings)(struct net_device___106 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___106 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___106 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___106 *);
	void (*get_regs)(struct net_device___106 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___106 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___106 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___106 *);
	void (*set_msglevel)(struct net_device___106 *, u32);
	int (*nway_reset)(struct net_device___106 *);
	u32 (*get_link)(struct net_device___106 *);
	int (*get_eeprom_len)(struct net_device___106 *);
	int (*get_eeprom)(struct net_device___106 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___106 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___106 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___106 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___106 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___106 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___106 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___106 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___106 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___106 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___106 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___106 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___106 *);
	void (*complete)(struct net_device___106 *);
	u32 (*get_priv_flags)(struct net_device___106 *);
	int (*set_priv_flags)(struct net_device___106 *, u32);
	int (*get_sset_count)(struct net_device___106 *, int);
	int (*get_rxnfc)(struct net_device___106 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___106 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___106 *, struct ethtool_flash *);
	int (*reset)(struct net_device___106 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___106 *);
	u32 (*get_rxfh_indir_size)(struct net_device___106 *);
	int (*get_rxfh)(struct net_device___106 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___106 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___106 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___106 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___106 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___106 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___106 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___106 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___106 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___106 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___106 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___106 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___106 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___106 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___106 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___106 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___106 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___106 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___106 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___106 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___106 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___106 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	int (*get_fecparam)(struct net_device___106 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___106 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___106 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___106 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___106 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___106;

struct inet_frags___106 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___106 *, const void *);
	void (*destructor)(struct inet_frag_queue___106 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___106 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___107 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___107 *fragments_tail;
	struct sk_buff___107 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___106 *net;
	struct callback_head rcu;
};

struct fib_rule___86;

struct fib_lookup_arg___86;

struct fib_rules_ops___86 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___86 *, struct flowi *, int, struct fib_lookup_arg___86 *);
	bool (*suppress)(struct fib_rule___86 *, struct fib_lookup_arg___86 *);
	int (*match)(struct fib_rule___86 *, struct flowi *, int);
	int (*configure)(struct fib_rule___86 *, struct sk_buff___107 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___86 *);
	int (*compare)(struct fib_rule___86 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___86 *, struct sk_buff___107 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___86 *);
	void (*flush_cache)(struct fib_rules_ops___86 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___387 *owner;
	struct net___117 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___87 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___117 *);
	int (*fib_dump)(struct net___117 *, struct notifier_block *);
	struct module___387 *owner;
	struct callback_head rcu;
};

struct dst_entry___86 {
	struct net_device___106 *dev;
	struct dst_ops___117 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___107 *);
	int (*output)(struct net___117 *, struct sock___86 *, struct sk_buff___107 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___86;

struct neigh_parms___86;

struct neigh_ops___86;

struct neighbour___86 {
	struct neighbour___86 *next;
	struct neigh_table___86 *tbl;
	struct neigh_parms___86 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___106 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___86 *, struct sk_buff___107 *);
	const struct neigh_ops___86 *ops;
	struct callback_head rcu;
	struct net_device___106 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct ucounts___326 {
	struct hlist_node node;
	struct user_namespace___326 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_prog_aux___99;

struct bpf_prog___96 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___99 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

struct seq_operations___400 {
	void * (*start)(struct seq_file___400 *, loff_t *);
	void (*stop)(struct seq_file___400 *, void *);
	void * (*next)(struct seq_file___400 *, void *, loff_t *);
	int (*show)(struct seq_file___400 *, void *);
};

struct seq_net_private___12 {
	struct net___117 *net;
};

struct pernet_operations___107 {
	struct list_head list;
	int (*init)(struct net___117 *);
	void (*exit)(struct net___117 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___106 {
	int (*ieee_getets)(struct net_device___106 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___106 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___106 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___106 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___106 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___106 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___106 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___106 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___106 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___106 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___106 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___106 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___106 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___106 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___106 *);
	u8 (*setstate)(struct net_device___106 *, u8);
	void (*getpermhwaddr)(struct net_device___106 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___106 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___106 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___106 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___106 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___106 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___106 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___106 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___106 *, int, u8 *);
	void (*setpfccfg)(struct net_device___106 *, int, u8);
	void (*getpfccfg)(struct net_device___106 *, int, u8 *);
	u8 (*setall)(struct net_device___106 *);
	u8 (*getcap)(struct net_device___106 *, int, u8 *);
	int (*getnumtcs)(struct net_device___106 *, int, u8 *);
	int (*setnumtcs)(struct net_device___106 *, int, u8);
	u8 (*getpfcstate)(struct net_device___106 *);
	void (*setpfcstate)(struct net_device___106 *, u8);
	void (*getbcncfg)(struct net_device___106 *, int, u32 *);
	void (*setbcncfg)(struct net_device___106 *, int, u32);
	void (*getbcnrp)(struct net_device___106 *, int, u8 *);
	void (*setbcnrp)(struct net_device___106 *, int, u8);
	int (*setapp)(struct net_device___106 *, u8, u16, u8);
	int (*getapp)(struct net_device___106 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___106 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___106 *, int, u8);
	u8 (*getdcbx)(struct net_device___106 *);
	u8 (*setdcbx)(struct net_device___106 *, u8);
	int (*peer_getappinfo)(struct net_device___106 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___106 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___106 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___106 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___106 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___106 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___310 {
	refcount_t count;
	struct ns_common___29 ns;
	struct user_namespace___326 *user_ns;
	struct ucounts___326 *ucounts;
	struct css_set___310 *root_cset;
};

struct bpf_map___311;

struct bpf_map_ops___310 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___311 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___311 *, struct file___461 *);
	void (*map_free)(struct bpf_map___311 *);
	int (*map_get_next_key)(struct bpf_map___311 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___311 *);
	void * (*map_lookup_elem)(struct bpf_map___311 *, void *);
	int (*map_update_elem)(struct bpf_map___311 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___311 *, void *);
	int (*map_push_elem)(struct bpf_map___311 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___311 *, void *);
	int (*map_peek_elem)(struct bpf_map___311 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___311 *, struct file___461 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___311 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___311 *, void *, struct seq_file___400 *);
	int (*map_check_btf)(const struct bpf_map___311 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___311 {
	const struct bpf_map_ops___310 *ops;
	struct bpf_map___311 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___429 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___106;

struct bpf_map_dev_ops___106 {
	int (*map_get_next_key)(struct bpf_offloaded_map___106 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___106 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___106 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___106 *, void *);
};

struct bpf_offloaded_map___106 {
	struct bpf_map___311 map;
	struct net_device___106 *netdev;
	const struct bpf_map_dev_ops___106 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___96 {
	int (*test_run)(struct bpf_prog___96 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___96 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___96 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___96 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___96 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___96 *, u32 *);
};

struct bpf_prog_offload_ops___96 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___96 *);
	int (*translate)(struct bpf_prog___96 *);
	void (*destroy)(struct bpf_prog___96 *);
};

struct bpf_prog_offload___96 {
	struct bpf_prog___96 *prog;
	struct net_device___106 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___96 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___99 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___96 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___96 *ops;
	struct bpf_map___311 **used_maps;
	struct bpf_prog___96 *prog;
	struct user_struct___429 *user;
	u64 load_time;
	struct bpf_map___311 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___96 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___96 {
	struct bpf_prog___96 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___96 {
	struct callback_head rcu;
	struct bpf_prog_array_item___96 items[0];
};

struct cgroup_bpf___96 {
	struct bpf_prog_array___96 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___96 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___311;

typedef void (*kthread_work_func_t___311)(struct kthread_work___311 *);

struct kthread_worker___311;

struct kthread_work___311 {
	struct list_head node;
	kthread_work_func_t___311 func;
	struct kthread_worker___311 *worker;
	int canceling;
};

struct kthread_worker___311 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___463 *task;
	struct kthread_work___311 *current_work;
};

struct kthread_delayed_work___310 {
	struct kthread_work___311 work;
	struct timer_list timer;
};

struct psi_group___310 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___311 *poll_kworker;
	struct kthread_delayed_work___310 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___310;

struct cgroup_rstat_cpu___310;

struct cgroup___310 {
	struct cgroup_subsys_state___310 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___456 *kn;
	struct cgroup_file___310 procs_file;
	struct cgroup_file___310 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___310 *subsys[13];
	struct cgroup_root___310 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___310 *dom_cgrp;
	struct cgroup_rstat_cpu___310 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___96 bpf;
	atomic_t congestion_count;
	struct cgroup___310 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___310 psi;
	int ancestor_ids[0];
};

struct cftype___310;

struct cgroup_subsys___310 {
	struct cgroup_subsys_state___310 * (*css_alloc)(struct cgroup_subsys_state___310 *);
	int (*css_online)(struct cgroup_subsys_state___310 *);
	void (*css_offline)(struct cgroup_subsys_state___310 *);
	void (*css_released)(struct cgroup_subsys_state___310 *);
	void (*css_free)(struct cgroup_subsys_state___310 *);
	void (*css_reset)(struct cgroup_subsys_state___310 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___310 *, int);
	int (*css_extra_stat_show)(struct seq_file___400 *, struct cgroup_subsys_state___310 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___463 *);
	void (*cancel_fork)(struct task_struct___463 *);
	void (*fork)(struct task_struct___463 *);
	void (*exit)(struct task_struct___463 *);
	void (*free)(struct task_struct___463 *);
	void (*bind)(struct cgroup_subsys_state___310 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___310 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___310 *dfl_cftypes;
	struct cftype___310 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___310 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___310 *updated_children;
	struct cgroup___310 *updated_next;
};

struct cgroup_root___310 {
	struct kernfs_root___455 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___310 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___310 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___310 *ss;
	struct list_head node;
	struct kernfs_ops___455 *kf_ops;
	int (*open)(struct kernfs_open_file___455 *);
	void (*release)(struct kernfs_open_file___455 *);
	u64 (*read_u64)(struct cgroup_subsys_state___310 *, struct cftype___310 *);
	s64 (*read_s64)(struct cgroup_subsys_state___310 *, struct cftype___310 *);
	int (*seq_show)(struct seq_file___400 *, void *);
	void * (*seq_start)(struct seq_file___400 *, loff_t *);
	void * (*seq_next)(struct seq_file___400 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___400 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___310 *, struct cftype___310 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___310 *, struct cftype___310 *, s64);
	ssize_t (*write)(struct kernfs_open_file___455 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___455 *, struct poll_table_struct___300 *);
};

struct xdp_rxq_info___106 {
	struct net_device___106 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___106 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___106 *dev_rx;
};

struct scm_fp_list___2 {
	short int count;
	short int max;
	struct user_struct___429 *user;
	struct file___461 *fp[253];
};

struct scm_cookie___2 {
	struct pid___258 *pid;
	struct scm_fp_list___2 *fp;
	struct scm_creds creds;
	u32 secid;
};

struct netlink_callback___108 {
	struct sk_buff___107 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___108 *);
	int (*dump)(struct sk_buff___107 *, struct netlink_callback___108 *);
	int (*done)(struct netlink_callback___108 *);
	void *data;
	struct module___387 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___106 {
	int (*create)(struct sk_buff___107 *, struct net_device___106 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___107 *, unsigned char *);
	int (*cache)(const struct neighbour___86 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___106 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___106 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___106 *, int);
	int poll_owner;
	struct net_device___106 *dev;
	struct sk_buff___107 *gro_list;
	struct sk_buff___107 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___106 {
	struct net_device___106 *dev;
	struct Qdisc___98 *qdisc;
	struct Qdisc___98 *qdisc_sleeping;
	struct kobject___449 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___106 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___98 {
	struct sk_buff___107 *head;
	struct sk_buff___107 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___98;

struct Qdisc___98 {
	int (*enqueue)(struct sk_buff___107 *, struct Qdisc___98 *, struct sk_buff___107 **);
	struct sk_buff___107 * (*dequeue)(struct Qdisc___98 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___98 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___106 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___106 gso_skb;
	struct qdisc_skb_head___98 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___98 *next_sched;
	struct sk_buff_head___106 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___106 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___449 kobj;
	struct net_device___106 *dev;
	long: 64;
	struct xdp_rxq_info___106 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___106)(struct net_device___106 *, struct sk_buff___107 *, struct net_device___106 *);

struct netdev_bpf___106 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___96 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___96 *prog;
			const struct bpf_prog_offload_ops___96 *ops;
		} verifier;
		struct {
			struct bpf_prog___96 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___106 *offmap;
		};
		struct {
			struct xdp_umem___3 *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___106 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___107 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___106 {
	int (*tls_dev_add)(struct net_device___106 *, struct sock___86 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___106 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___106 *, struct sock___86 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___106 {
	int (*ndo_init)(struct net_device___106 *);
	void (*ndo_uninit)(struct net_device___106 *);
	int (*ndo_open)(struct net_device___106 *);
	int (*ndo_stop)(struct net_device___106 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___107 *, struct net_device___106 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___107 *, struct net_device___106 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___106 *, struct sk_buff___107 *, struct net_device___106 *, select_queue_fallback_t___106);
	void (*ndo_change_rx_flags)(struct net_device___106 *, int);
	void (*ndo_set_rx_mode)(struct net_device___106 *);
	int (*ndo_set_mac_address)(struct net_device___106 *, void *);
	int (*ndo_validate_addr)(struct net_device___106 *);
	int (*ndo_do_ioctl)(struct net_device___106 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___106 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___106 *, int);
	int (*ndo_neigh_setup)(struct net_device___106 *, struct neigh_parms___86 *);
	void (*ndo_tx_timeout)(struct net_device___106 *);
	void (*ndo_get_stats64)(struct net_device___106 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___106 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___106 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___106 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___106 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___106 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___106 *);
	int (*ndo_netpoll_setup)(struct net_device___106 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___106 *);
	int (*ndo_set_vf_mac)(struct net_device___106 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___106 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___106 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___106 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___106 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___106 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___106 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___106 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___106 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___106 *, int, struct sk_buff___107 *);
	int (*ndo_set_vf_guid)(struct net_device___106 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___106 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___106 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___106 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___106 *, const struct sk_buff___107 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___106 *, struct net_device___106 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___106 *, struct net_device___106 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___106 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___106 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___106 *, struct neighbour___86 *);
	void (*ndo_neigh_destroy)(struct net_device___106 *, struct neighbour___86 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___106 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___106 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___106 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___107 *, struct netlink_callback___108 *, struct net_device___106 *, struct net_device___106 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___106 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___106 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide35;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___107 *, u32, u32, struct net_device___106 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___106 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___106 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___106 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___106 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___106 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___106 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___106 *, struct net_device___106 *);
	void (*ndo_dfwd_del_station)(struct net_device___106 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___106 *);
	int (*ndo_set_tx_maxrate)(struct net_device___106 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___106 *);
	int (*ndo_change_proto_down)(struct net_device___106 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___106 *, struct sk_buff___107 *);
	void (*ndo_set_rx_headroom)(struct net_device___106 *, int);
	int (*ndo_bpf)(struct net_device___106 *, struct netdev_bpf___106 *);
	int (*ndo_xdp_xmit)(struct net_device___106 *, int, struct xdp_frame___106 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___106 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___106 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide36;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___86 {
	possible_net_t___108 net;
	struct net_device___106 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___86 *);
	void (*neigh_cleanup)(struct neighbour___86 *);
	struct neigh_table___86 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___86 {
	u32 (*l3mdev_fib_table)(const struct net_device___106 *);
	struct sk_buff___107 * (*l3mdev_l3_rcv)(struct net_device___106 *, struct sk_buff___107 *, u16);
	struct sk_buff___107 * (*l3mdev_l3_out)(struct net_device___106 *, struct sock___86 *, struct sk_buff___107 *, u16);
	struct dst_entry___86 * (*l3mdev_link_scope_lookup)(const struct net_device___106 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct tcf_proto___98;

struct mini_Qdisc___98 {
	struct tcf_proto___98 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___98 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___106 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___117 *, struct net_device___106 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___106 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___106 *, struct list_head *);
	size_t (*get_size)(const struct net_device___106 *);
	int (*fill_info)(struct sk_buff___107 *, const struct net_device___106 *);
	size_t (*get_xstats_size)(const struct net_device___106 *);
	int (*fill_xstats)(struct sk_buff___107 *, const struct net_device___106 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___106 *, struct net_device___106 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___106 *, const struct net_device___106 *);
	int (*fill_slave_info)(struct sk_buff___107 *, const struct net_device___106 *, const struct net_device___106 *);
	struct net___117 * (*get_link_net)(const struct net_device___106 *);
	size_t (*get_linkxstats_size)(const struct net_device___106 *, int);
	int (*fill_linkxstats)(struct sk_buff___107 *, const struct net_device___106 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___106 {
	struct list_head poll_list;
	struct sk_buff_head___106 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___106 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___98 *output_queue;
	struct Qdisc___98 **output_queue_tailp;
	struct sk_buff___107 *completion_queue;
	struct sk_buff_head___106 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___106 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___106 input_pkt_queue;
	struct napi_struct___106 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bdi_writeback_congested___251 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___251 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___251 {
	struct bio___251 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___253 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___253 bip_inline_vecs[0];
};

struct bio_set___251 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___251 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___194 {
	struct mem_cgroup___194 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___194 {
	struct lruvec___462 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___194 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___194 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct gnet_dump___98 {
	spinlock_t *lock;
	struct sk_buff___107 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___98;

struct Qdisc_ops___98 {
	struct Qdisc_ops___98 *next;
	const struct Qdisc_class_ops___98 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___107 *, struct Qdisc___98 *, struct sk_buff___107 **);
	struct sk_buff___107 * (*dequeue)(struct Qdisc___98 *);
	struct sk_buff___107 * (*peek)(struct Qdisc___98 *);
	int (*init)(struct Qdisc___98 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___98 *);
	void (*destroy)(struct Qdisc___98 *);
	int (*change)(struct Qdisc___98 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___98 *);
	int (*change_tx_queue_len)(struct Qdisc___98 *, unsigned int);
	int (*dump)(struct Qdisc___98 *, struct sk_buff___107 *);
	int (*dump_stats)(struct Qdisc___98 *, struct gnet_dump___98 *);
	void (*ingress_block_set)(struct Qdisc___98 *, u32);
	void (*egress_block_set)(struct Qdisc___98 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___98 *);
	u32 (*egress_block_get)(struct Qdisc___98 *);
	struct module___387 *owner;
};

struct tcf_block___98;

struct Qdisc_class_ops___98 {
	unsigned int flags;
	struct netdev_queue___106 * (*select_queue)(struct Qdisc___98 *, struct tcmsg *);
	int (*graft)(struct Qdisc___98 *, long unsigned int, struct Qdisc___98 *, struct Qdisc___98 **, struct netlink_ext_ack *);
	struct Qdisc___98 * (*leaf)(struct Qdisc___98 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___98 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___98 *, u32);
	int (*change)(struct Qdisc___98 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___98 *, long unsigned int);
	void (*walk)(struct Qdisc___98 *, struct qdisc_walker *);
	struct tcf_block___98 * (*tcf_block)(struct Qdisc___98 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___98 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___98 *, long unsigned int);
	int (*dump)(struct Qdisc___98 *, long unsigned int, struct sk_buff___107 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___98 *, long unsigned int, struct gnet_dump___98 *);
};

struct tcf_chain___98;

struct tcf_block___98 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___117 *net;
	struct Qdisc___98 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___98 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___98;

struct tcf_proto_ops___98;

struct tcf_proto___98 {
	struct tcf_proto___98 *next;
	void *root;
	int (*classify)(struct sk_buff___107 *, const struct tcf_proto___98 *, struct tcf_result___98 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___98 *ops;
	struct tcf_chain___98 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___98 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___98 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___98 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___107 *, const struct tcf_proto___98 *, struct tcf_result___98 *);
	int (*init)(struct tcf_proto___98 *);
	void (*destroy)(struct tcf_proto___98 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___98 *, u32);
	void (*put)(struct tcf_proto___98 *, void *);
	int (*change)(struct net___117 *, struct sk_buff___107 *, struct tcf_proto___98 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___98 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___98 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___98 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___117 *, struct tcf_chain___98 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___117 *, struct tcf_proto___98 *, void *, struct sk_buff___107 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___107 *, struct net___117 *, void *);
	struct module___387 *owner;
	int flags;
};

struct tcf_chain___98 {
	struct mutex filter_chain_lock;
	struct tcf_proto___98 *filter_chain;
	struct list_head list;
	struct tcf_block___98 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___98 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___86 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___96 *prog;
};

struct bpf_redirect_info___96 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___311 *map;
	struct bpf_map___311 *map_to_flush;
	u32 kern_flags;
};

typedef struct poll_table_struct___300 poll_table___45;

struct pneigh_entry___86;

struct neigh_hash_table___86;

struct neigh_table___86 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___106 *, __u32 *);
	bool (*key_eq)(const struct neighbour___86 *, const void *);
	int (*constructor)(struct neighbour___86 *);
	int (*pconstructor)(struct pneigh_entry___86 *);
	void (*pdestructor)(struct pneigh_entry___86 *);
	void (*proxy_redo)(struct sk_buff___107 *);
	char *id;
	struct neigh_parms___86 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___106 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___86 *nht;
	struct pneigh_entry___86 **phash_buckets;
};

struct neigh_ops___86 {
	int family;
	void (*solicit)(struct neighbour___86 *, struct sk_buff___107 *);
	void (*error_report)(struct neighbour___86 *, struct sk_buff___107 *);
	int (*output)(struct neighbour___86 *, struct sk_buff___107 *);
	int (*connected_output)(struct neighbour___86 *, struct sk_buff___107 *);
};

struct pneigh_entry___86 {
	struct pneigh_entry___86 *next;
	possible_net_t___108 net;
	struct net_device___106 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___86 {
	struct neighbour___86 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___86 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___86 *ctarget;
	struct net___117 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___86 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___86 *rule;
	u32 table;
	int flags;
};

struct proto___86 {
	void (*close)(struct sock___86 *, long int);
	int (*pre_connect)(struct sock___86 *, struct sockaddr *, int);
	int (*connect)(struct sock___86 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___86 *, int);
	struct sock___86 * (*accept)(struct sock___86 *, int, int *, bool);
	int (*ioctl)(struct sock___86 *, int, long unsigned int);
	int (*init)(struct sock___86 *);
	void (*destroy)(struct sock___86 *);
	void (*shutdown)(struct sock___86 *, int);
	int (*setsockopt)(struct sock___86 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___86 *, int, int, char *, int *);
	void (*keepalive)(struct sock___86 *, int);
	int (*sendmsg)(struct sock___86 *, struct msghdr___89 *, size_t);
	int (*recvmsg)(struct sock___86 *, struct msghdr___89 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___86 *, struct page___462 *, int, size_t, int);
	int (*bind)(struct sock___86 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___86 *, struct sk_buff___107 *);
	void (*release_cb)(struct sock___86 *);
	int (*hash)(struct sock___86 *);
	void (*unhash)(struct sock___86 *);
	void (*rehash)(struct sock___86 *);
	int (*get_port)(struct sock___86 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___86 *);
	bool (*stream_memory_read)(const struct sock___86 *);
	void (*enter_memory_pressure)(struct sock___86 *);
	void (*leave_memory_pressure)(struct sock___86 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___3 *rsk_prot;
	struct timewait_sock_ops___3 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___387 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___86 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct socket_alloc___6 {
	struct socket___88 socket;
	struct inode___461 vfs_inode;
};

struct unix_skb_parms {
	struct pid___258 *pid;
	kuid_t uid;
	kgid_t gid;
	struct scm_fp_list___2 *fp;
	u32 secid;
	u32 consumed;
};

struct unix_sock___2 {
	struct sock___86 sk;
	struct unix_address *addr;
	struct path___462 path;
	struct mutex iolock;
	struct mutex bindlock;
	struct sock___86 *peer;
	struct list_head link;
	atomic_long_t inflight;
	spinlock_t lock;
	long unsigned int gc_flags;
	struct socket_wq___87 peer_wq;
	wait_queue_entry_t peer_wake;
	long: 64;
	long: 64;
	long: 64;
};

struct unix_stream_read_state {
	int (*recv_actor)(struct sk_buff___107 *, int, int, struct unix_stream_read_state *);
	struct socket___88 *socket;
	struct msghdr___89 *msg;
	struct pipe_inode_info___142 *pipe;
	size_t size;
	int flags;
	unsigned int splice_flags;
};

struct scm_fp_list___3 {
	short int count;
	short int max;
	struct user_struct___423 *user;
	struct file___455 *fp[253];
};

struct unix_skb_parms___2 {
	struct pid___253 *pid;
	kuid_t uid;
	kgid_t gid;
	struct scm_fp_list___3 *fp;
	u32 secid;
	u32 consumed;
};

struct net_proto_family___6 {
	int family;
	int (*create)(struct net___95 *, struct socket___66 *, int, int);
	struct module___366 *owner;
};

struct nf_ipv6_ops___7 {
	int (*chk_addr)(struct net___95 *, const struct in6_addr *, const struct net_device___84 *, int);
	void (*route_input)(struct sk_buff___85 *);
	int (*fragment)(struct net___95 *, struct sock___65 *, struct sk_buff___85 *, int (*)(struct net___95 *, struct sock___65 *, struct sk_buff___85 *));
	__sum16 (*checksum)(struct sk_buff___85 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___85 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___95 *, struct dst_entry___64 **, struct flowi *, bool);
	int (*reroute)(struct sk_buff___85 *, const struct nf_queue_entry___2 *);
};

struct inet_protosw___3 {
	struct list_head list;
	short unsigned int type;
	short unsigned int protocol;
	struct proto___64 *prot;
	const struct proto_ops___65 *ops;
	unsigned char flags;
};

struct ac6_iter_state {
	struct seq_net_private___7 p;
	struct net_device___84 *dev;
	struct inet6_dev___35 *idev;
};

struct mmpin___6 {
	struct user_struct___419 *user;
	unsigned int num_pg;
};

struct ubuf_info___6 {
	void (*callback)(struct ubuf_info___6 *, bool);
	union {
		struct {
			long unsigned int desc;
			void *ctx;
		};
		struct {
			u32 id;
			u16 len;
			u16 zerocopy: 1;
			u32 bytelen;
		};
	};
	refcount_t refcnt;
	struct mmpin___6 mmp;
};

struct inet_cork___23 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___76 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
	__u16 gso_size;
	u64 transmit_time;
};

struct inet_cork_full___23 {
	struct inet_cork___23 base;
	struct flowi fl;
};

struct ipv6_pinfo___23;

struct inet_sock___23 {
	struct sock___76 sk;
	struct ipv6_pinfo___23 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	__be16 inet_sport;
	__u16 inet_id;
	struct ip_options_rcu *inet_opt;
	int rx_dst_ifindex;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 bind_address_no_port: 1;
	__u8 defer_connect: 1;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___23 cork;
};

struct ipv6_fl_socklist___22;

struct ipv6_pinfo___23 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
			__u16 recvfragsize: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 repflow: 1;
	__u16 pmtudisc: 3;
	__u16 padding: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u16 autoflowlabel: 1;
	__u16 autoflowlabel_set: 1;
	__u8 min_hopcount;
	__u8 tclass;
	__be32 rcv_flowinfo;
	__u32 dst_cookie;
	__u32 rx_dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___22 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___97 *pktoptions;
	struct sk_buff___97 *rxpmtu;
	struct inet6_cork cork;
};

struct nf_ipv6_ops___8 {
	int (*chk_addr)(struct net___107 *, const struct in6_addr *, const struct net_device___96 *, int);
	void (*route_input)(struct sk_buff___97 *);
	int (*fragment)(struct net___107 *, struct sock___76 *, struct sk_buff___97 *, int (*)(struct net___107 *, struct sock___76 *, struct sk_buff___97 *));
	__sum16 (*checksum)(struct sk_buff___97 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___97 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___107 *, struct dst_entry___76 **, struct flowi *, bool);
	int (*reroute)(struct sk_buff___97 *, const struct nf_queue_entry___2 *);
};

struct ip6_flowlabel___22;

struct ipv6_fl_socklist___22 {
	struct ipv6_fl_socklist___22 *next;
	struct ip6_flowlabel___22 *fl;
	struct callback_head rcu;
};

struct inet6_ifaddr___2 {
	struct in6_addr addr;
	__u32 prefix_len;
	__u32 rt_priority;
	__u32 valid_lft;
	__u32 prefered_lft;
	refcount_t refcnt;
	spinlock_t lock;
	int state;
	__u32 flags;
	__u8 dad_probes;
	__u8 stable_privacy_retry;
	__u16 scope;
	__u64 dad_nonce;
	long unsigned int cstamp;
	long unsigned int tstamp;
	struct delayed_work dad_work;
	struct inet6_dev___47 *idev;
	struct fib6_info___21 *rt;
	struct hlist_node addr_lst;
	struct list_head if_list;
	struct list_head tmp_list;
	struct inet6_ifaddr___2 *ifpub;
	int regen_count;
	bool tokenized;
	struct callback_head rcu;
	struct in6_addr peer_addr;
};

struct ip6_flowlabel___22 {
	struct ip6_flowlabel___22 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___252 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___107 *fl_net;
};

struct ipcm6_cookie {
	__s16 hlimit;
	__s16 tclass;
	__s8 dontfrag;
	struct ipv6_txoptions *opt;
	__u16 gso_size;
};

struct packet_type___5 {
	__be16 type;
	struct net_device___96 *dev;
	int (*func)(struct sk_buff___97 *, struct net_device___96 *, struct packet_type___5 *, struct net_device___96 *);
	bool (*id_match)(struct packet_type___5 *, struct sock___76 *);
	void *af_packet_priv;
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inet_connection_sock_af_ops___14 {
	int (*queue_xmit)(struct sock___76 *, struct sk_buff___97 *, struct flowi *);
	void (*send_check)(struct sock___76 *, struct sk_buff___97 *);
	int (*rebuild_header)(struct sock___76 *);
	void (*sk_rx_dst_set)(struct sock___76 *, const struct sk_buff___97 *);
	int (*conn_request)(struct sock___76 *, struct sk_buff___97 *);
	struct sock___76 * (*syn_recv_sock)(const struct sock___76 *, struct sk_buff___97 *, struct request_sock___60 *, struct dst_entry___76 *, struct request_sock___60 *, bool *);
	u16 net_header_len;
	u16 net_frag_header_len;
	u16 sockaddr_len;
	int (*setsockopt)(struct sock___76 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___76 *, int, int, char *, int *);
	void (*addr2sockaddr)(struct sock___76 *, struct sockaddr *);
	void (*mtu_reduced)(struct sock___76 *);
};

struct module___388;

struct file___462;

struct kiocb___462;

struct iov_iter___229;

struct poll_table_struct___301;

struct vm_area_struct___463;

struct inode___462;

struct file_lock___462;

struct page___463;

struct pipe_inode_info___143;

struct seq_file___401;

struct file_operations___462 {
	struct module___388 *owner;
	loff_t (*llseek)(struct file___462 *, loff_t, int);
	ssize_t (*read)(struct file___462 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___462 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___462 *, struct iov_iter___229 *);
	ssize_t (*write_iter)(struct kiocb___462 *, struct iov_iter___229 *);
	int (*iopoll)(struct kiocb___462 *, bool);
	int (*iterate)(struct file___462 *, struct dir_context *);
	int (*iterate_shared)(struct file___462 *, struct dir_context *);
	__poll_t (*poll)(struct file___462 *, struct poll_table_struct___301 *);
	long int (*unlocked_ioctl)(struct file___462 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___462 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___462 *, struct vm_area_struct___463 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___462 *, struct file___462 *);
	int (*flush)(struct file___462 *, fl_owner_t);
	int (*release)(struct inode___462 *, struct file___462 *);
	int (*fsync)(struct file___462 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___462 *, int);
	int (*lock)(struct file___462 *, int, struct file_lock___462 *);
	ssize_t (*sendpage)(struct file___462 *, struct page___463 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___462 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___462 *, int, struct file_lock___462 *);
	ssize_t (*splice_write)(struct pipe_inode_info___143 *, struct file___462 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___462 *, loff_t *, struct pipe_inode_info___143 *, size_t, unsigned int);
	int (*setlease)(struct file___462 *, long int, struct file_lock___462 **, void **);
	long int (*fallocate)(struct file___462 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___401 *, struct file___462 *);
	ssize_t (*copy_file_range)(struct file___462 *, loff_t, struct file___462 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___462 *, loff_t, struct file___462 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___462 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___463 {
	u64 seqnum;
	struct vm_area_struct___463 *vmas[4];
};

struct page_frag___463 {
	struct page___463 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___463;

struct mem_cgroup___195;

struct cred___430;

struct nsproxy___357;

struct signal_struct___337;

struct bio_list___252;

struct backing_dev_info___252;

struct css_set___311;

struct vm_struct___366;

struct task_struct___464 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___464 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___463 *mm;
	struct mm_struct___463 *active_mm;
	struct vmacache___463 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___464 *real_parent;
	struct task_struct___464 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___464 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___195 *active_memcg;
	long int rh_reserved2;
	struct pid___258 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___258 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___258 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___430 *ptracer_cred;
	const struct cred___430 *real_cred;
	const struct cred___430 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___357 *nsproxy;
	struct signal_struct___337 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___464 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___252 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___252 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___311 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___143 *splice_pipe;
	struct page_frag___463 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___195 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___464 *oom_reaper_list;
	struct vm_struct___366 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___156 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct key___430;

struct user_struct___430 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___430 *uid_keyring;
	struct key___430 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct rw_semaphore___464 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___464 *owner;
};

struct ucounts___327;

struct user_namespace___327 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___327 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___29 ns;
	long unsigned int flags;
	struct key___430 *persistent_keyring_register;
	struct rw_semaphore___464 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___327 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct secondary_data___464 {
	void *stack;
	struct task_struct___464 *task;
	long int status;
};

typedef struct page___463 *pgtable_t___463;

struct address_space___462;

struct dev_pagemap___450;

struct page___463 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___462 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___463 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___463 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___463 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___450 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___195 *mem_cgroup;
};

struct vm_operations_struct___450;

struct vm_area_struct___463 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___463 *vm_next;
	struct vm_area_struct___463 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___463 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___450 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___462 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___463;

struct mm_struct___463 {
	struct {
		struct vm_area_struct___463 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___462 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___464 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___463 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___464 *owner;
		struct user_namespace___327 *user_ns;
		struct file___462 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___463 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup___311;

struct cgroup_subsys___311;

struct cgroup_subsys_state___311 {
	struct cgroup___311 *cgroup;
	struct cgroup_subsys___311 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___311 *parent;
};

struct kernfs_node___457;

struct cgroup_file___311 {
	struct kernfs_node___457 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___195;

struct mem_cgroup___195 {
	struct cgroup_subsys_state___311 css;
	struct mem_cgroup_id___16 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___311 events_file;
	struct cgroup_file___311 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___464 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___195 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cred___430 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___430 *session_keyring;
	struct key___430 *process_keyring;
	struct key___430 *thread_keyring;
	struct key___430 *request_key_auth;
	void *security;
	struct user_struct___430 *user;
	struct user_namespace___327 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___118;

struct cgroup_namespace___311;

struct nsproxy___357 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net___118 *net_ns;
	struct cgroup_namespace___311 *cgroup_ns;
};

struct signal_struct___337 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___464 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___464 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___258 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___258 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___463 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___258 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___252;

struct bio_list___252 {
	struct bio___252 *head;
	struct bio___252 *tail;
};

struct bdi_writeback_congested___252;

struct bdi_writeback___252 {
	struct backing_dev_info___252 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___252 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___311 *memcg_css;
	struct cgroup_subsys_state___311 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___430;

struct dentry___462;

struct backing_dev_info___252 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___252 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___430 *dev;
	struct device___430 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___462 *debug_dir;
	struct dentry___462 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___311 {
	struct cgroup_subsys_state___311 *subsys[13];
	refcount_t refcount;
	struct css_set___311 *dom_cset;
	struct cgroup___311 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___311 *mg_src_cgrp;
	struct cgroup___311 *mg_dst_cgrp;
	struct css_set___311 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___462;

struct pipe_buffer___143;

struct pipe_inode_info___143 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___463 *tmp_page;
	struct fasync_struct___462 *fasync_readers;
	struct fasync_struct___462 *fasync_writers;
	struct pipe_buffer___143 *bufs;
	struct user_struct___430 *user;
};

struct vm_struct___366 {
	struct vm_struct___366 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___463 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___349 {
	struct task_struct___464 task;
	long unsigned int stack[8192];
};

typedef int (*key_restrict_link_func_t___431)(struct key___430 *, const struct key_type *, const union key_payload *, struct key___430 *);

struct key_restriction___430;

struct key___430 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___464 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___430 *restrict_link;
};

struct key_restriction___430 {
	key_restrict_link_func_t___431 check;
	struct key___430 *key;
	struct key_type *keytype;
};

struct pglist_data___463;

struct lruvec___463 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___463 *pgdat;
};

struct zone___463 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___463 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___463 {
	struct zone___463 *zone;
	int zone_idx;
};

struct zonelist___463 {
	struct zoneref___463 _zonerefs[25];
};

struct pglist_data___463 {
	struct zone___463 node_zones[3];
	struct zonelist___463 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___464 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___464 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___463 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___463 {
	struct rw_semaphore___464 rwsem;
	struct notifier_block *head;
};

struct address_space_operations___462;

struct address_space___462 {
	struct inode___462 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___464 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___462 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___450)(struct vm_area_struct___463 *, long unsigned int, const struct page___463 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___450)(struct page___463 *, void *);

struct dev_pagemap___450 {
	dev_page_fault_t___450 page_fault;
	dev_page_free_t___450 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___430 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___463 {
	struct vfsmount *mnt;
	struct dentry___462 *dentry;
};

struct file___462 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___463 f_path;
	struct inode___462 *f_inode;
	const struct file_operations___462 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___258 f_owner;
	const struct cred___430 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___462 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___450;

struct vm_operations_struct___450 {
	void (*open)(struct vm_area_struct___463 *);
	void (*close)(struct vm_area_struct___463 *);
	int (*split)(struct vm_area_struct___463 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___463 *);
	vm_fault_t (*fault)(struct vm_fault___450 *);
	vm_fault_t (*huge_fault)(struct vm_fault___450 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___450 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___463 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___450 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___450 *);
	int (*access)(struct vm_area_struct___463 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___463 *);
	int (*set_policy)(struct vm_area_struct___463 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___463 *, long unsigned int);
	struct page___463 * (*find_special_page)(struct vm_area_struct___463 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___463 {
	struct task_struct___464 *task;
	struct core_thread___463 *next;
};

struct core_state___463 {
	atomic_t nr_threads;
	struct core_thread___463 dumper;
	struct completion startup;
};

struct vm_fault___450 {
	struct vm_area_struct___463 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___463 *cow_page;
	struct mem_cgroup___195 *memcg;
	struct page___463 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___463 prealloc_pte;
};

struct crypto_async_request___41;

typedef void (*crypto_completion_t___41)(struct crypto_async_request___41 *, int);

struct crypto_tfm___41;

struct crypto_async_request___41 {
	struct list_head list;
	crypto_completion_t___41 complete;
	void *data;
	struct crypto_tfm___41 *tfm;
	u32 flags;
};

struct crypto_ablkcipher___41;

struct ablkcipher_request___41;

struct ablkcipher_tfm___41 {
	int (*setkey)(struct crypto_ablkcipher___41 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___41 *);
	int (*decrypt)(struct ablkcipher_request___41 *);
	struct crypto_ablkcipher___41 *base;
	unsigned int ivsize;
	unsigned int reqsize;
};

struct blkcipher_desc___41;

struct blkcipher_tfm___41 {
	void *iv;
	int (*setkey)(struct crypto_tfm___41 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___41 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___41 *, struct scatterlist *, struct scatterlist *, unsigned int);
};

struct cipher_tfm___41 {
	int (*cit_setkey)(struct crypto_tfm___41 *, const u8 *, unsigned int);
	void (*cit_encrypt_one)(struct crypto_tfm___41 *, u8 *, const u8 *);
	void (*cit_decrypt_one)(struct crypto_tfm___41 *, u8 *, const u8 *);
};

struct compress_tfm___41 {
	int (*cot_compress)(struct crypto_tfm___41 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*cot_decompress)(struct crypto_tfm___41 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___41;

struct crypto_tfm___41 {
	u32 crt_flags;
	union {
		struct ablkcipher_tfm___41 ablkcipher;
		struct blkcipher_tfm___41 blkcipher;
		struct cipher_tfm___41 cipher;
		struct compress_tfm___41 compress;
	} crt_u;
	void (*exit)(struct crypto_tfm___41 *);
	struct crypto_alg___41 *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct ablkcipher_request___41 {
	struct crypto_async_request___41 base;
	unsigned int nbytes;
	void *info;
	struct scatterlist *src;
	struct scatterlist *dst;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_blkcipher___41;

struct blkcipher_desc___41 {
	struct crypto_blkcipher___41 *tfm;
	void *info;
	u32 flags;
};

struct crypto_blkcipher___41 {
	struct crypto_tfm___41 base;
};

struct ablkcipher_alg___41 {
	int (*setkey)(struct crypto_ablkcipher___41 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___41 *);
	int (*decrypt)(struct ablkcipher_request___41 *);
	int (*givencrypt)(struct skcipher_givcrypt_request *);
	int (*givdecrypt)(struct skcipher_givcrypt_request *);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct crypto_ablkcipher___41 {
	struct crypto_tfm___41 base;
};

struct blkcipher_alg___41 {
	int (*setkey)(struct crypto_tfm___41 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___41 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___41 *, struct scatterlist *, struct scatterlist *, unsigned int);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct cipher_alg___41 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___41 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___41 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___41 *, u8 *, const u8 *);
};

struct compress_alg___41 {
	int (*coa_compress)(struct crypto_tfm___41 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___41 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___41 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type *cra_type;
	union {
		struct ablkcipher_alg___41 ablkcipher;
		struct blkcipher_alg___41 blkcipher;
		struct cipher_alg___41 cipher;
		struct compress_alg___41 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___41 *);
	void (*cra_exit)(struct crypto_tfm___41 *);
	void (*cra_destroy)(struct crypto_alg___41 *);
	struct module___388 *cra_module;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___449;

struct kobj_type___449;

struct kobject___450 {
	const char *name;
	struct list_head entry;
	struct kobject___450 *parent;
	struct kset___449 *kset;
	struct kobj_type___449 *ktype;
	struct kernfs_node___457 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___388 {
	struct kobject___450 kobj;
	struct module___388 *mod;
	struct kobject___450 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___388 {
	struct module___388 *mod;
	struct latch_tree_node node;
};

struct module_layout___388 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___388 mtn;
};

struct module_attribute___388;

struct kernel_param___388;

struct module___388 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___388 mkobj;
	struct module_attribute___388 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___450 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___388 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___388 core_layout;
	struct module_layout___388 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide53;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide54;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct crypto_cipher___25 {
	struct crypto_tfm___41 base;
};

struct bio_vec___254 {
	struct page___463 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___229 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___254 *bvec;
		struct pipe_inode_info___143 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct msghdr___90 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___229 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___462 *msg_iocb;
};

struct kiocb___462 {
	struct file___462 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___462 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dentry_operations___462;

struct super_block___462;

struct dentry___462 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___462 *d_parent;
	struct qstr d_name;
	struct inode___462 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___462 *d_op;
	struct super_block___462 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___462;

struct block_device___462;

struct inode___462 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___462 *i_op;
	struct super_block___462 *i_sb;
	struct address_space___462 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___464 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___252 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___462 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___462 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___143 *i_pipe;
		struct block_device___462 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___462 {
	int (*d_revalidate)(struct dentry___462 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___462 *, unsigned int);
	int (*d_hash)(const struct dentry___462 *, struct qstr *);
	int (*d_compare)(const struct dentry___462 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___462 *);
	int (*d_init)(struct dentry___462 *);
	void (*d_release)(struct dentry___462 *);
	void (*d_prune)(struct dentry___462 *);
	void (*d_iput)(struct dentry___462 *, struct inode___462 *);
	char * (*d_dname)(struct dentry___462 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___463 *);
	int (*d_manage)(const struct path___463 *, bool);
	struct dentry___462 * (*d_real)(struct dentry___462 *, const struct inode___462 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___462;

struct mem_dqinfo___462 {
	struct quota_format_type___462 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___462;

struct quota_info___462 {
	unsigned int flags;
	struct rw_semaphore___464 dqio_sem;
	struct inode___462 *files[3];
	struct mem_dqinfo___462 info[3];
	const struct quota_format_ops___462 *ops[3];
};

struct rcuwait___462 {
	struct task_struct___464 *task;
};

struct percpu_rw_semaphore___462 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___464 rw_sem;
	struct rcuwait___462 writer;
	int readers_block;
};

struct sb_writers___462 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___462 rw_sem[3];
};

struct shrink_control___195;

struct shrinker___195 {
	long unsigned int (*count_objects)(struct shrinker___195 *, struct shrink_control___195 *);
	long unsigned int (*scan_objects)(struct shrinker___195 *, struct shrink_control___195 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___462;

struct super_operations___462;

struct dquot_operations___462;

struct quotactl_ops___462;

struct super_block___462 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___462 *s_type;
	const struct super_operations___462 *s_op;
	const struct dquot_operations___462 *dq_op;
	const struct quotactl_ops___462 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___462 *s_root;
	struct rw_semaphore___464 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___462 *s_bdev;
	struct backing_dev_info___252 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___462 s_dquot;
	struct sb_writers___462 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___462 *s_d_op;
	int cleancache_poolid;
	struct shrinker___195 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___327 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___195 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___195 *memcg;
};

struct iattr___462 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___462 *ia_file;
};

struct dquot___462 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___462 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___462 {
	int qf_fmt_id;
	const struct quota_format_ops___462 *qf_ops;
	struct module___388 *qf_owner;
	struct quota_format_type___462 *qf_next;
};

struct quota_format_ops___462 {
	int (*check_quota_file)(struct super_block___462 *, int);
	int (*read_file_info)(struct super_block___462 *, int);
	int (*write_file_info)(struct super_block___462 *, int);
	int (*free_file_info)(struct super_block___462 *, int);
	int (*read_dqblk)(struct dquot___462 *);
	int (*commit_dqblk)(struct dquot___462 *);
	int (*release_dqblk)(struct dquot___462 *);
	int (*get_next_id)(struct super_block___462 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___462 {
	int (*write_dquot)(struct dquot___462 *);
	struct dquot___462 * (*alloc_dquot)(struct super_block___462 *, int);
	void (*destroy_dquot)(struct dquot___462 *);
	int (*acquire_dquot)(struct dquot___462 *);
	int (*release_dquot)(struct dquot___462 *);
	int (*mark_dirty)(struct dquot___462 *);
	int (*write_info)(struct super_block___462 *, int);
	qsize_t * (*get_reserved_space)(struct inode___462 *);
	int (*get_projid)(struct inode___462 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___462 *, qsize_t *);
	int (*get_next_id)(struct super_block___462 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___462 {
	int (*quota_on)(struct super_block___462 *, int, int, const struct path___463 *);
	int (*quota_off)(struct super_block___462 *, int);
	int (*quota_enable)(struct super_block___462 *, unsigned int);
	int (*quota_disable)(struct super_block___462 *, unsigned int);
	int (*quota_sync)(struct super_block___462 *, int);
	int (*set_info)(struct super_block___462 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___462 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___462 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___462 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___462 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___462 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___215;

struct address_space_operations___462 {
	int (*writepage)(struct page___463 *, struct writeback_control___215 *);
	int (*readpage)(struct file___462 *, struct page___463 *);
	int (*writepages)(struct address_space___462 *, struct writeback_control___215 *);
	int (*set_page_dirty)(struct page___463 *);
	int (*readpages)(struct file___462 *, struct address_space___462 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___462 *, struct address_space___462 *, loff_t, unsigned int, unsigned int, struct page___463 **, void **);
	int (*write_end)(struct file___462 *, struct address_space___462 *, loff_t, unsigned int, unsigned int, struct page___463 *, void *);
	sector_t (*bmap)(struct address_space___462 *, sector_t);
	void (*invalidatepage)(struct page___463 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___463 *, gfp_t);
	void (*freepage)(struct page___463 *);
	ssize_t (*direct_IO)(struct kiocb___462 *, struct iov_iter___229 *);
	int (*migratepage)(struct address_space___462 *, struct page___463 *, struct page___463 *, enum migrate_mode);
	bool (*isolate_page)(struct page___463 *, isolate_mode_t);
	void (*putback_page)(struct page___463 *);
	int (*launder_page)(struct page___463 *);
	int (*is_partially_uptodate)(struct page___463 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___463 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___462 *, struct page___463 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___462 *, sector_t *);
	void (*swap_deactivate)(struct file___462 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___215 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___252 *wb;
	struct inode___462 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___462 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___462 *bd_inode;
	struct super_block___462 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___462 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___252 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___462 {
	struct dentry___462 * (*lookup)(struct inode___462 *, struct dentry___462 *, unsigned int);
	const char * (*get_link)(struct dentry___462 *, struct inode___462 *, struct delayed_call *);
	int (*permission)(struct inode___462 *, int);
	struct posix_acl * (*get_acl)(struct inode___462 *, int);
	int (*readlink)(struct dentry___462 *, char *, int);
	int (*create)(struct inode___462 *, struct dentry___462 *, umode_t, bool);
	int (*link)(struct dentry___462 *, struct inode___462 *, struct dentry___462 *);
	int (*unlink)(struct inode___462 *, struct dentry___462 *);
	int (*symlink)(struct inode___462 *, struct dentry___462 *, const char *);
	int (*mkdir)(struct inode___462 *, struct dentry___462 *, umode_t);
	int (*rmdir)(struct inode___462 *, struct dentry___462 *);
	int (*mknod)(struct inode___462 *, struct dentry___462 *, umode_t, dev_t);
	int (*rename)(struct inode___462 *, struct dentry___462 *, struct inode___462 *, struct dentry___462 *, unsigned int);
	int (*setattr)(struct dentry___462 *, struct iattr___462 *);
	int (*getattr)(const struct path___463 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___462 *, char *, size_t);
	int (*fiemap)(struct inode___462 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___462 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___462 *, struct dentry___462 *, struct file___462 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___462 *, struct dentry___462 *, umode_t);
	int (*set_acl)(struct inode___462 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___462 {
	void (*fl_copy_lock)(struct file_lock___462 *, struct file_lock___462 *);
	void (*fl_release_private)(struct file_lock___462 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___462;

struct file_lock___462 {
	struct file_lock___462 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___462 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___462 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___462 *fl_ops;
	const struct lock_manager_operations___462 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___462 {
	int (*lm_compare_owner)(struct file_lock___462 *, struct file_lock___462 *);
	long unsigned int (*lm_owner_key)(struct file_lock___462 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___462 *);
	int (*lm_grant)(struct file_lock___462 *, int);
	bool (*lm_break)(struct file_lock___462 *);
	int (*lm_change)(struct file_lock___462 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___462 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___462 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___462 *fa_next;
	struct file___462 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___462 {
	const char *name;
	int fs_flags;
	struct dentry___462 * (*mount)(struct file_system_type___462 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___462 *);
	struct module___388 *owner;
	struct file_system_type___462 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___462 {
	struct inode___462 * (*alloc_inode)(struct super_block___462 *);
	void (*destroy_inode)(struct inode___462 *);
	void (*dirty_inode)(struct inode___462 *, int);
	int (*write_inode)(struct inode___462 *, struct writeback_control___215 *);
	int (*drop_inode)(struct inode___462 *);
	void (*evict_inode)(struct inode___462 *);
	void (*put_super)(struct super_block___462 *);
	int (*sync_fs)(struct super_block___462 *, int);
	int (*freeze_super)(struct super_block___462 *);
	int (*freeze_fs)(struct super_block___462 *);
	int (*thaw_super)(struct super_block___462 *);
	int (*unfreeze_fs)(struct super_block___462 *);
	int (*statfs)(struct dentry___462 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___462 *, int *, char *);
	void (*umount_begin)(struct super_block___462 *);
	int (*show_options)(struct seq_file___401 *, struct dentry___462 *);
	int (*show_devname)(struct seq_file___401 *, struct dentry___462 *);
	int (*show_path)(struct seq_file___401 *, struct dentry___462 *);
	int (*show_stats)(struct seq_file___401 *, struct dentry___462 *);
	ssize_t (*quota_read)(struct super_block___462 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___462 *, int, const char *, size_t, loff_t);
	struct dquot___462 ** (*get_dquots)(struct inode___462 *);
	int (*bdev_try_to_free_page)(struct super_block___462 *, struct page___463 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___462 *, struct shrink_control___195 *);
	long int (*free_cached_objects)(struct super_block___462 *, struct shrink_control___195 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___311)(struct file___462 *, wait_queue_head_t *, struct poll_table_struct___301 *);

struct poll_table_struct___301 {
	poll_queue_proc___311 _qproc;
	__poll_t _key;
};

struct seq_operations___401;

struct seq_file___401 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___401 *op;
	int poll_event;
	const struct file___462 *file;
	void *private;
};

typedef void bio_end_io_t___252(struct bio___252 *);

struct bio_integrity_payload___252;

struct bio_set___252;

struct bio___252 {
	struct bio___252 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___252 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___252 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___254 *bi_io_vec;
	struct bio_set___252 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___254 bi_inline_vecs[0];
};

struct socket_wq___88 {
	wait_queue_head_t wait;
	struct fasync_struct___462 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct sock___87;

struct proto_ops___88;

struct socket___89 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___88 *wq;
	struct file___462 *file;
	struct sock___87 *sk;
	const struct proto_ops___88 *ops;
};

typedef struct {
	struct net___118 *net;
} possible_net_t___109;

struct proto___87;

struct sock_common___87 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___87 *skc_prot;
	possible_net_t___109 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___87 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___108;

struct sk_buff_head___107 {
	struct sk_buff___108 *next;
	struct sk_buff___108 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___87;

struct dst_entry___87;

struct net_device___107;

struct sock___87 {
	struct sock_common___87 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___107 sk_error_queue;
	struct sk_buff_head___107 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___108 *head;
		struct sk_buff___108 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___87 *sk_filter;
	union {
		struct socket_wq___88 *sk_wq;
		struct socket_wq___88 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___87 *sk_rx_dst;
	struct dst_entry___87 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___108 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___107 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___463 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___87 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___258 *sk_peer_pid;
	const struct cred___430 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___89 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___195 *sk_memcg;
	void (*sk_state_change)(struct sock___87 *);
	void (*sk_data_ready)(struct sock___87 *);
	void (*sk_write_space)(struct sock___87 *);
	void (*sk_error_report)(struct sock___87 *);
	int (*sk_backlog_rcv)(struct sock___87 *, struct sk_buff___108 *);
	struct sk_buff___108 * (*sk_validate_xmit_skb)(struct sock___87 *, struct net_device___107 *, struct sk_buff___108 *);
	void (*sk_destruct)(struct sock___87 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

typedef int (*sk_read_actor_t___87)(read_descriptor_t *, struct sk_buff___108 *, unsigned int, size_t);

struct proto_ops___88 {
	int family;
	struct module___388 *owner;
	int (*release)(struct socket___89 *);
	int (*bind)(struct socket___89 *, struct sockaddr *, int);
	int (*connect)(struct socket___89 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___89 *, struct socket___89 *);
	int (*accept)(struct socket___89 *, struct socket___89 *, int, bool);
	int (*getname)(struct socket___89 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___462 *, struct socket___89 *, struct poll_table_struct___301 *);
	int (*ioctl)(struct socket___89 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___89 *, int);
	int (*shutdown)(struct socket___89 *, int);
	int (*setsockopt)(struct socket___89 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___89 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___89 *, struct msghdr___90 *, size_t);
	int (*recvmsg)(struct socket___89 *, struct msghdr___90 *, size_t, int);
	int (*mmap)(struct file___462 *, struct socket___89 *, struct vm_area_struct___463 *);
	ssize_t (*sendpage)(struct socket___89 *, struct page___463 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___89 *, loff_t *, struct pipe_inode_info___143 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___87 *, int);
	int (*peek_len)(struct socket___89 *);
	int (*read_sock)(struct sock___87 *, read_descriptor_t *, sk_read_actor_t___87);
	int (*sendpage_locked)(struct sock___87 *, struct page___463 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___87 *, struct msghdr___90 *, size_t);
	int (*set_rcvlowat)(struct sock___87 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct nf_bridge_info___107;

struct sk_buff___108 {
	union {
		struct {
			struct sk_buff___108 *next;
			struct sk_buff___108 *prev;
			union {
				struct net_device___107 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___87 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___108 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___107 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___107;

struct netns_frags___107 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___107 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ip_ra_chain___52;

struct fib_rules_ops___87;

struct tcp_congestion_ops___22;

struct tcp_fastopen_context___22;

struct fib_notifier_ops___88;

struct netns_ipv4___107 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___52 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___87 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___87 *fibnl;
	struct sock___87 **icmp_sk;
	struct sock___87 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___87 **tcp_sk;
	struct netns_frags___107 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops___22 *tcp_congestion_control;
	struct tcp_fastopen_context___22 *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___87 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___88 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___88 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___87;

struct dst_ops___118 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___118 *);
	struct dst_entry___87 * (*check)(struct dst_entry___87 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___87 *);
	unsigned int (*mtu)(const struct dst_entry___87 *);
	u32 * (*cow_metrics)(struct dst_entry___87 *, long unsigned int);
	void (*destroy)(struct dst_entry___87 *);
	void (*ifdown)(struct dst_entry___87 *, struct net_device___107 *, int);
	struct dst_entry___87 * (*negative_advice)(struct dst_entry___87 *);
	void (*link_failure)(struct sk_buff___108 *);
	void (*update_pmtu)(struct dst_entry___87 *, struct sock___87 *, struct sk_buff___108 *, u32);
	void (*redirect)(struct dst_entry___87 *, struct sock___87 *, struct sk_buff___108 *);
	int (*local_out)(struct net___118 *, struct sock___87 *, struct sk_buff___108 *);
	struct neighbour___87 * (*neigh_lookup)(const struct dst_entry___87 *, struct sk_buff___108 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___87 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_info___28;

struct rt6_info___28;

struct fib6_table___28;

struct netns_ipv6___118 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___107 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info___28 *fib6_null_entry;
	struct rt6_info___28 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___28 *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___118 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info___28 *ip6_prohibit_entry;
	struct rt6_info___28 *ip6_blk_hole_entry;
	struct fib6_table___28 *fib6_local_tbl;
	struct fib_rules_ops___87 *fib6_rules_ops;
	struct sock___87 **icmp_sk;
	struct sock___87 *ndisc_sk;
	struct sock___87 *tcp_sk;
	struct sock___87 *igmp_sk;
	struct sock___87 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___87 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___88 *notifier_ops;
	struct fib_notifier_ops___88 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___88 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___87 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___107 {
	struct netns_frags___107 frags;
};

struct netns_xfrm___118 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___87 *nlsk;
	struct sock___87 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___118 xfrm4_dst_ops;
	struct dst_ops___118 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___97;

struct net___118 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___327 *user_ns;
	struct ucounts___327 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___29 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___87 *rtnl;
	struct sock___87 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___107 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___107 ipv4;
	struct netns_ipv6___118 ipv6;
	struct netns_sctp___88 sctp;
	struct netns_nf___19 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___107 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___87 *nfnl;
	struct sock___87 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___118 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___87 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___97 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct inet_frag_queue___107;

struct inet_frags___107 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___107 *, const void *);
	void (*destructor)(struct inet_frag_queue___107 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___107 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___108 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___108 *fragments_tail;
	struct sk_buff___108 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___107 *net;
	struct callback_head rcu;
};

struct ip_ra_chain___52 {
	struct ip_ra_chain___52 *next;
	struct sock___87 *sk;
	union {
		void (*destructor)(struct sock___87 *);
		struct sock___87 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___87;

struct fib_lookup_arg___87;

struct fib_rules_ops___87 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___87 *, struct flowi *, int, struct fib_lookup_arg___87 *);
	bool (*suppress)(struct fib_rule___87 *, struct fib_lookup_arg___87 *);
	int (*match)(struct fib_rule___87 *, struct flowi *, int);
	int (*configure)(struct fib_rule___87 *, struct sk_buff___108 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___87 *);
	int (*compare)(struct fib_rule___87 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___87 *, struct sk_buff___108 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___87 *);
	void (*flush_cache)(struct fib_rules_ops___87 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___388 *owner;
	struct net___118 *fro_net;
	struct callback_head rcu;
};

struct tcp_congestion_ops___22 {
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___87 *);
	void (*release)(struct sock___87 *);
	u32 (*ssthresh)(struct sock___87 *);
	void (*cong_avoid)(struct sock___87 *, u32, u32);
	void (*set_state)(struct sock___87 *, u8);
	void (*cwnd_event)(struct sock___87 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___87 *, u32);
	u32 (*undo_cwnd)(struct sock___87 *);
	void (*pkts_acked)(struct sock___87 *, const struct ack_sample *);
	u32 (*min_tso_segs)(struct sock___87 *);
	u32 (*sndbuf_expand)(struct sock___87 *);
	void (*cong_control)(struct sock___87 *, const struct rate_sample *);
	size_t (*get_info)(struct sock___87 *, u32, int *, union tcp_cc_info *);
	char name[16];
	struct module___388 *owner;
};

struct tcp_fastopen_context___22 {
	struct crypto_cipher___25 *tfm;
	__u8 key[16];
	struct callback_head rcu;
};

struct fib_notifier_ops___88 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___118 *);
	int (*fib_dump)(struct net___118 *, struct notifier_block *);
	struct module___388 *owner;
	struct callback_head rcu;
};

struct lwtunnel_state___12;

struct dst_entry___87 {
	struct net_device___107 *dev;
	struct dst_ops___118 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___108 *);
	int (*output)(struct net___118 *, struct sock___87 *, struct sk_buff___108 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___12 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

typedef rx_handler_result_t rx_handler_func_t___107(struct sk_buff___108 **);

struct dev_pm_info___430 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___430 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___430;

struct bus_type___430;

struct device_driver___430;

struct dev_pm_domain___430;

struct dma_map_ops___202;

struct fwnode_handle___350;

struct class___430;

struct attribute_group___427;

struct device___430 {
	struct device___430 *parent;
	struct device_private *p;
	struct kobject___450 kobj;
	const char *init_name;
	const struct device_type___430 *type;
	struct mutex mutex;
	struct bus_type___430 *bus;
	struct device_driver___430 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___430 power;
	struct dev_pm_domain___430 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___202 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___350 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___430 *class;
	const struct attribute_group___427 **groups;
	void (*release)(struct device___430 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct net_device_ops___107;

struct ethtool_ops___107;

struct l3mdev_ops___87;

struct ndisc_ops___57;

struct xfrmdev_ops___107;

struct tlsdev_ops___107;

struct header_ops___107;

struct in_device___15;

struct inet6_dev___57;

struct wpan_dev___2;

struct netdev_rx_queue___107;

struct mini_Qdisc___99;

struct netdev_queue___107;

struct Qdisc___99;

struct rtnl_link_ops___99;

struct dcbnl_rtnl_ops___107;

struct net_device___107 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___107 *netdev_ops;
	const struct ethtool_ops___107 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___87 *l3mdev_ops;
	const struct ndisc_ops___57 *ndisc_ops;
	const struct xfrmdev_ops___107 *xfrmdev_ops;
	const struct tlsdev_ops___107 *tlsdev_ops;
	const struct header_ops___107 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___449 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device___15 *ip_ptr;
	struct inet6_dev___57 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev___2 *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___107 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___97 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___107 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___99 *miniq_ingress;
	struct netdev_queue___107 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___107 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___99 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___99 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___107 = 0,
		NETREG_REGISTERED___107 = 1,
		NETREG_UNREGISTERING___107 = 2,
		NETREG_UNREGISTERED___107 = 3,
		NETREG_RELEASED___107 = 4,
		NETREG_DUMMY___107 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___107 = 0,
		RTNL_LINK_INITIALIZING___107 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___107 *);
	struct netpoll_info *npinfo;
	possible_net_t___109 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___430 dev;
	const struct attribute_group___427 *sysfs_groups[4];
	const struct attribute_group___427 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___99 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___107 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct neigh_table___87;

struct neigh_parms___87;

struct neigh_ops___87;

struct neighbour___87 {
	struct neighbour___87 *next;
	struct neigh_table___87 *tbl;
	struct neigh_parms___87 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___107 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___87 *, struct sk_buff___108 *);
	const struct neigh_ops___87 *ops;
	struct callback_head rcu;
	struct net_device___107 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct fib6_nh___28 {
	struct in6_addr nh_gw;
	struct net_device___107 *nh_dev;
	struct lwtunnel_state___12 *nh_lwtstate;
	unsigned int nh_flags;
	atomic_t nh_upper_bound;
	int nh_weight;
};

struct fib6_node___28;

struct fib6_info___28 {
	struct fib6_table___28 *fib6_table;
	struct fib6_info___28 *fib6_next;
	struct fib6_node___28 *fib6_node;
	struct list_head fib6_siblings;
	unsigned int fib6_nsiblings;
	atomic_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	struct rt6_info___28 **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
	long unsigned int last_probe;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 exception_bucket_flushed: 1;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 dst_host: 1;
	u8 fib6_destroying: 1;
	u8 unused: 2;
	struct fib6_nh___28 fib6_nh;
	struct callback_head rcu;
};

struct rt6_info___28 {
	struct dst_entry___87 dst;
	struct fib6_info___28 *from;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___57 *rt6i_idev;
	u32 rt6i_flags;
	struct rt6key rt6i_prefsrc;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct fib6_node___28 {
	struct fib6_node___28 *parent;
	struct fib6_node___28 *left;
	struct fib6_node___28 *right;
	struct fib6_info___28 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info___28 *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table___28 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node___28 tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

struct kernfs_root___456;

struct kernfs_elem_dir___456 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___456 *root;
};

struct kernfs_syscall_ops___456;

struct kernfs_root___456 {
	struct kernfs_node___457 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___456 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___456 {
	struct kernfs_node___457 *target_kn;
};

struct kernfs_ops___456;

struct kernfs_elem_attr___456 {
	const struct kernfs_ops___456 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___457 *notify_next;
};

struct kernfs_node___457 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___457 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___456 dir;
		struct kernfs_elem_symlink___456 symlink;
		struct kernfs_elem_attr___456 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___456;

struct kernfs_ops___456 {
	int (*open)(struct kernfs_open_file___456 *);
	void (*release)(struct kernfs_open_file___456 *);
	int (*seq_show)(struct seq_file___401 *, void *);
	void * (*seq_start)(struct seq_file___401 *, loff_t *);
	void * (*seq_next)(struct seq_file___401 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___401 *, void *);
	ssize_t (*read)(struct kernfs_open_file___456 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___456 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___456 *, struct vm_area_struct___463 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___456 *, struct poll_table_struct___301 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___456 {
	int (*remount_fs)(struct kernfs_root___456 *, int *, char *);
	int (*show_options)(struct seq_file___401 *, struct kernfs_root___456 *);
	int (*mkdir)(struct kernfs_node___457 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___457 *);
	int (*rename)(struct kernfs_node___457 *, struct kernfs_node___457 *, const char *);
	int (*show_path)(struct seq_file___401 *, struct kernfs_node___457 *, struct kernfs_root___456 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___456 {
	struct kernfs_node___457 *kn;
	struct file___462 *file;
	struct seq_file___401 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___450 *vm_ops;
};

struct kobj_ns_type_operations___87 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___87 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___426;

struct attribute_group___427 {
	const char *name;
	umode_t (*is_visible)(struct kobject___450 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___450 *, struct bin_attribute___426 *, int);
	struct attribute **attrs;
	struct bin_attribute___426 **bin_attrs;
};

struct bin_attribute___426 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___462 *, struct kobject___450 *, struct bin_attribute___426 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___462 *, struct kobject___450 *, struct bin_attribute___426 *, char *, loff_t, size_t);
	int (*mmap)(struct file___462 *, struct kobject___450 *, struct bin_attribute___426 *, struct vm_area_struct___463 *);
};

struct sysfs_ops___449 {
	ssize_t (*show)(struct kobject___450 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___450 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___449;

struct kset___449 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___450 kobj;
	const struct kset_uevent_ops___449 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___449 {
	void (*release)(struct kobject___450 *);
	const struct sysfs_ops___449 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___87 * (*child_ns_type)(struct kobject___450 *);
	const void * (*namespace)(struct kobject___450 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___449 {
	int (* const filter)(struct kset___449 *, struct kobject___450 *);
	const char * (* const name)(struct kset___449 *, struct kobject___450 *);
	int (* const uevent)(struct kset___449 *, struct kobject___450 *, struct kobj_uevent_env *);
};

struct kobj_attribute___440 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___450 *, struct kobj_attribute___440 *, char *);
	ssize_t (*store)(struct kobject___450 *, struct kobj_attribute___440 *, const char *, size_t);
};

struct dev_pm_ops___430 {
	int (*prepare)(struct device___430 *);
	void (*complete)(struct device___430 *);
	int (*suspend)(struct device___430 *);
	int (*resume)(struct device___430 *);
	int (*freeze)(struct device___430 *);
	int (*thaw)(struct device___430 *);
	int (*poweroff)(struct device___430 *);
	int (*restore)(struct device___430 *);
	int (*suspend_late)(struct device___430 *);
	int (*resume_early)(struct device___430 *);
	int (*freeze_late)(struct device___430 *);
	int (*thaw_early)(struct device___430 *);
	int (*poweroff_late)(struct device___430 *);
	int (*restore_early)(struct device___430 *);
	int (*suspend_noirq)(struct device___430 *);
	int (*resume_noirq)(struct device___430 *);
	int (*freeze_noirq)(struct device___430 *);
	int (*thaw_noirq)(struct device___430 *);
	int (*poweroff_noirq)(struct device___430 *);
	int (*restore_noirq)(struct device___430 *);
	int (*runtime_suspend)(struct device___430 *);
	int (*runtime_resume)(struct device___430 *);
	int (*runtime_idle)(struct device___430 *);
};

struct dev_pm_domain___430 {
	struct dev_pm_ops___430 ops;
	void (*detach)(struct device___430 *, bool);
	int (*activate)(struct device___430 *);
	void (*sync)(struct device___430 *);
	void (*dismiss)(struct device___430 *);
};

struct bus_type___430 {
	const char *name;
	const char *dev_name;
	struct device___430 *dev_root;
	const struct attribute_group___427 **bus_groups;
	const struct attribute_group___427 **dev_groups;
	const struct attribute_group___427 **drv_groups;
	int (*match)(struct device___430 *, struct device_driver___430 *);
	int (*uevent)(struct device___430 *, struct kobj_uevent_env *);
	int (*probe)(struct device___430 *);
	int (*remove)(struct device___430 *);
	void (*shutdown)(struct device___430 *);
	int (*online)(struct device___430 *);
	int (*offline)(struct device___430 *);
	int (*suspend)(struct device___430 *, pm_message_t);
	int (*resume)(struct device___430 *);
	int (*num_vf)(struct device___430 *);
	int (*dma_configure)(struct device___430 *);
	const struct dev_pm_ops___430 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___430 {
	const char *name;
	struct bus_type___430 *bus;
	struct module___388 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___430 *);
	int (*remove)(struct device___430 *);
	void (*shutdown)(struct device___430 *);
	int (*suspend)(struct device___430 *, pm_message_t);
	int (*resume)(struct device___430 *);
	const struct attribute_group___427 **groups;
	const struct dev_pm_ops___430 *pm;
	void (*coredump)(struct device___430 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___430 {
	const char *name;
	const struct attribute_group___427 **groups;
	int (*uevent)(struct device___430 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___430 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___430 *);
	const struct dev_pm_ops___430 *pm;
};

struct class___430 {
	const char *name;
	struct module___388 *owner;
	const struct attribute_group___427 **class_groups;
	const struct attribute_group___427 **dev_groups;
	struct kobject___450 *dev_kobj;
	int (*dev_uevent)(struct device___430 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___430 *, umode_t *);
	void (*class_release)(struct class___430 *);
	void (*dev_release)(struct device___430 *);
	int (*shutdown_pre)(struct device___430 *);
	const struct kobj_ns_type_operations___87 *ns_type;
	const void * (*namespace)(struct device___430 *);
	const struct dev_pm_ops___430 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___202 {
	void * (*alloc)(struct device___430 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___430 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___430 *, struct vm_area_struct___463 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___430 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___430 *, struct page___463 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___430 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___430 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___430 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___430 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___430 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___430 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___430 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___430 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___430 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___430 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___430 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___430 *, u64);
	u64 (*get_required_mask)(struct device___430 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___350;

struct fwnode_handle___350 {
	struct fwnode_handle___350 *secondary;
	const struct fwnode_operations___350 *ops;
};

typedef void compound_page_dtor___450(struct page___463 *);

struct fwnode_reference_args___350;

struct fwnode_endpoint___350;

struct fwnode_operations___350 {
	struct fwnode_handle___350 * (*get)(struct fwnode_handle___350 *);
	void (*put)(struct fwnode_handle___350 *);
	bool (*device_is_available)(const struct fwnode_handle___350 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___350 *, const struct device___430 *);
	bool (*property_present)(const struct fwnode_handle___350 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___350 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___350 *, const char *, const char **, size_t);
	struct fwnode_handle___350 * (*get_parent)(const struct fwnode_handle___350 *);
	struct fwnode_handle___350 * (*get_next_child_node)(const struct fwnode_handle___350 *, struct fwnode_handle___350 *);
	struct fwnode_handle___350 * (*get_named_child_node)(const struct fwnode_handle___350 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___350 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___350 *);
	struct fwnode_handle___350 * (*graph_get_next_endpoint)(const struct fwnode_handle___350 *, struct fwnode_handle___350 *);
	struct fwnode_handle___350 * (*graph_get_remote_endpoint)(const struct fwnode_handle___350 *);
	struct fwnode_handle___350 * (*graph_get_port_parent)(struct fwnode_handle___350 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___350 *, struct fwnode_endpoint___350 *);
};

struct fwnode_endpoint___350 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___350 *local_fwnode;
};

struct fwnode_reference_args___350 {
	struct fwnode_handle___350 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___143;

struct pipe_buffer___143 {
	struct page___463 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___143 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___143 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___143 *, struct pipe_buffer___143 *);
	void (*release)(struct pipe_inode_info___143 *, struct pipe_buffer___143 *);
	int (*steal)(struct pipe_inode_info___143 *, struct pipe_buffer___143 *);
	union {
		bool (*get)(struct pipe_inode_info___143 *, struct pipe_buffer___143 *);
		struct {
			void (*get)(struct pipe_inode_info___143 *, struct pipe_buffer___143 *);
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
};

struct nf_bridge_info___107 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___107 = 0,
		BRNF_PROTO_8021Q___107 = 1,
		BRNF_PROTO_PPPOE___107 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___107 *physindev;
	struct net_device___107 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

struct ucounts___327 {
	struct hlist_node node;
	struct user_namespace___327 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_prog_aux___100;

struct bpf_prog___97 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___100 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

struct seq_operations___401 {
	void * (*start)(struct seq_file___401 *, loff_t *);
	void (*stop)(struct seq_file___401 *, void *);
	void * (*next)(struct seq_file___401 *, void *, loff_t *);
	int (*show)(struct seq_file___401 *, void *);
};

struct seq_net_private___13 {
	struct net___118 *net;
};

struct pernet_operations___108 {
	struct list_head list;
	int (*init)(struct net___118 *);
	void (*exit)(struct net___118 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct ethtool_ops___107 {
	int (*get_settings)(struct net_device___107 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___107 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___107 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___107 *);
	void (*get_regs)(struct net_device___107 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___107 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___107 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___107 *);
	void (*set_msglevel)(struct net_device___107 *, u32);
	int (*nway_reset)(struct net_device___107 *);
	u32 (*get_link)(struct net_device___107 *);
	int (*get_eeprom_len)(struct net_device___107 *);
	int (*get_eeprom)(struct net_device___107 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___107 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___107 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___107 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___107 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___107 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___107 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___107 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___107 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___107 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___107 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___107 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___107 *);
	void (*complete)(struct net_device___107 *);
	u32 (*get_priv_flags)(struct net_device___107 *);
	int (*set_priv_flags)(struct net_device___107 *, u32);
	int (*get_sset_count)(struct net_device___107 *, int);
	int (*get_rxnfc)(struct net_device___107 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___107 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___107 *, struct ethtool_flash *);
	int (*reset)(struct net_device___107 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___107 *);
	u32 (*get_rxfh_indir_size)(struct net_device___107 *);
	int (*get_rxfh)(struct net_device___107 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___107 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___107 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___107 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___107 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___107 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___107 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___107 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___107 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___107 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___107 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___107 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___107 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___107 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___107 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___107 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___107 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___107 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___107 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___107 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___107 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___107 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	int (*get_fecparam)(struct net_device___107 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___107 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___107 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___107 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___107 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct dcbnl_rtnl_ops___107 {
	int (*ieee_getets)(struct net_device___107 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___107 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___107 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___107 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___107 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___107 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___107 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___107 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___107 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___107 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___107 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___107 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___107 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___107 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___107 *);
	u8 (*setstate)(struct net_device___107 *, u8);
	void (*getpermhwaddr)(struct net_device___107 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___107 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___107 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___107 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___107 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___107 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___107 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___107 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___107 *, int, u8 *);
	void (*setpfccfg)(struct net_device___107 *, int, u8);
	void (*getpfccfg)(struct net_device___107 *, int, u8 *);
	u8 (*setall)(struct net_device___107 *);
	u8 (*getcap)(struct net_device___107 *, int, u8 *);
	int (*getnumtcs)(struct net_device___107 *, int, u8 *);
	int (*setnumtcs)(struct net_device___107 *, int, u8);
	u8 (*getpfcstate)(struct net_device___107 *);
	void (*setpfcstate)(struct net_device___107 *, u8);
	void (*getbcncfg)(struct net_device___107 *, int, u32 *);
	void (*setbcncfg)(struct net_device___107 *, int, u32);
	void (*getbcnrp)(struct net_device___107 *, int, u8 *);
	void (*setbcnrp)(struct net_device___107 *, int, u8);
	int (*setapp)(struct net_device___107 *, u8, u16, u8);
	int (*getapp)(struct net_device___107 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___107 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___107 *, int, u8);
	u8 (*getdcbx)(struct net_device___107 *);
	u8 (*setdcbx)(struct net_device___107 *, u8);
	int (*peer_getappinfo)(struct net_device___107 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___107 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___107 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___107 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___107 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___107 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___311 {
	refcount_t count;
	struct ns_common___29 ns;
	struct user_namespace___327 *user_ns;
	struct ucounts___327 *ucounts;
	struct css_set___311 *root_cset;
};

struct bpf_map___312;

struct bpf_map_ops___311 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___312 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___312 *, struct file___462 *);
	void (*map_free)(struct bpf_map___312 *);
	int (*map_get_next_key)(struct bpf_map___312 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___312 *);
	void * (*map_lookup_elem)(struct bpf_map___312 *, void *);
	int (*map_update_elem)(struct bpf_map___312 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___312 *, void *);
	int (*map_push_elem)(struct bpf_map___312 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___312 *, void *);
	int (*map_peek_elem)(struct bpf_map___312 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___312 *, struct file___462 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___312 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___312 *, void *, struct seq_file___401 *);
	int (*map_check_btf)(const struct bpf_map___312 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___312 {
	const struct bpf_map_ops___311 *ops;
	struct bpf_map___312 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___430 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___107;

struct bpf_map_dev_ops___107 {
	int (*map_get_next_key)(struct bpf_offloaded_map___107 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___107 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___107 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___107 *, void *);
};

struct bpf_offloaded_map___107 {
	struct bpf_map___312 map;
	struct net_device___107 *netdev;
	const struct bpf_map_dev_ops___107 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___97 {
	int (*test_run)(struct bpf_prog___97 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___97 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___97 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___97 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___97 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___97 *, u32 *);
};

struct bpf_prog_offload_ops___97 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___97 *);
	int (*translate)(struct bpf_prog___97 *);
	void (*destroy)(struct bpf_prog___97 *);
};

struct bpf_prog_offload___97 {
	struct bpf_prog___97 *prog;
	struct net_device___107 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___97 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___100 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___97 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___97 *ops;
	struct bpf_map___312 **used_maps;
	struct bpf_prog___97 *prog;
	struct user_struct___430 *user;
	u64 load_time;
	struct bpf_map___312 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___97 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___97 {
	struct bpf_prog___97 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___97 {
	struct callback_head rcu;
	struct bpf_prog_array_item___97 items[0];
};

struct cgroup_bpf___97 {
	struct bpf_prog_array___97 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___97 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___312;

typedef void (*kthread_work_func_t___312)(struct kthread_work___312 *);

struct kthread_worker___312;

struct kthread_work___312 {
	struct list_head node;
	kthread_work_func_t___312 func;
	struct kthread_worker___312 *worker;
	int canceling;
};

struct kthread_worker___312 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___464 *task;
	struct kthread_work___312 *current_work;
};

struct kthread_delayed_work___311 {
	struct kthread_work___312 work;
	struct timer_list timer;
};

struct psi_group___311 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___312 *poll_kworker;
	struct kthread_delayed_work___311 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___311;

struct cgroup_rstat_cpu___311;

struct cgroup___311 {
	struct cgroup_subsys_state___311 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___457 *kn;
	struct cgroup_file___311 procs_file;
	struct cgroup_file___311 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___311 *subsys[13];
	struct cgroup_root___311 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___311 *dom_cgrp;
	struct cgroup_rstat_cpu___311 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___97 bpf;
	atomic_t congestion_count;
	struct cgroup___311 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___311 psi;
	int ancestor_ids[0];
};

struct cftype___311;

struct cgroup_subsys___311 {
	struct cgroup_subsys_state___311 * (*css_alloc)(struct cgroup_subsys_state___311 *);
	int (*css_online)(struct cgroup_subsys_state___311 *);
	void (*css_offline)(struct cgroup_subsys_state___311 *);
	void (*css_released)(struct cgroup_subsys_state___311 *);
	void (*css_free)(struct cgroup_subsys_state___311 *);
	void (*css_reset)(struct cgroup_subsys_state___311 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___311 *, int);
	int (*css_extra_stat_show)(struct seq_file___401 *, struct cgroup_subsys_state___311 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___464 *);
	void (*cancel_fork)(struct task_struct___464 *);
	void (*fork)(struct task_struct___464 *);
	void (*exit)(struct task_struct___464 *);
	void (*free)(struct task_struct___464 *);
	void (*bind)(struct cgroup_subsys_state___311 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___311 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___311 *dfl_cftypes;
	struct cftype___311 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___311 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___311 *updated_children;
	struct cgroup___311 *updated_next;
};

struct cgroup_root___311 {
	struct kernfs_root___456 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___311 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___311 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___311 *ss;
	struct list_head node;
	struct kernfs_ops___456 *kf_ops;
	int (*open)(struct kernfs_open_file___456 *);
	void (*release)(struct kernfs_open_file___456 *);
	u64 (*read_u64)(struct cgroup_subsys_state___311 *, struct cftype___311 *);
	s64 (*read_s64)(struct cgroup_subsys_state___311 *, struct cftype___311 *);
	int (*seq_show)(struct seq_file___401 *, void *);
	void * (*seq_start)(struct seq_file___401 *, loff_t *);
	void * (*seq_next)(struct seq_file___401 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___401 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___311 *, struct cftype___311 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___311 *, struct cftype___311 *, s64);
	ssize_t (*write)(struct kernfs_open_file___456 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___456 *, struct poll_table_struct___301 *);
};

struct xdp_rxq_info___107 {
	struct net_device___107 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___107 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___107 *dev_rx;
};

struct netlink_skb_parms___20 {
	struct scm_creds creds;
	__u32 portid;
	__u32 dst_group;
	__u32 flags;
	struct sock___87 *sk;
	bool nsid_is_set;
	int nsid;
};

struct netlink_callback___109 {
	struct sk_buff___108 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___109 *);
	int (*dump)(struct sk_buff___108 *, struct netlink_callback___109 *);
	int (*done)(struct netlink_callback___109 *);
	void *data;
	struct module___388 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

enum {
	IFLA_INET6_UNSPEC = 0,
	IFLA_INET6_FLAGS = 1,
	IFLA_INET6_CONF = 2,
	IFLA_INET6_STATS = 3,
	IFLA_INET6_MCAST = 4,
	IFLA_INET6_CACHEINFO = 5,
	IFLA_INET6_ICMP6STATS = 6,
	IFLA_INET6_TOKEN = 7,
	IFLA_INET6_ADDR_GEN_MODE = 8,
	__IFLA_INET6_MAX = 9,
};

enum in6_addr_gen_mode {
	IN6_ADDR_GEN_MODE_EUI64 = 0,
	IN6_ADDR_GEN_MODE_NONE = 1,
	IN6_ADDR_GEN_MODE_STABLE_PRIVACY = 2,
	IN6_ADDR_GEN_MODE_RANDOM = 3,
};

struct ifla_cacheinfo {
	__u32 max_reasm_len;
	__u32 tstamp;
	__u32 reachable_time;
	__u32 retrans_time;
};

struct header_ops___107 {
	int (*create)(struct sk_buff___108 *, struct net_device___107 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___108 *, unsigned char *);
	int (*cache)(const struct neighbour___87 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___107 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___107 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___107 *, int);
	int poll_owner;
	struct net_device___107 *dev;
	struct sk_buff___108 *gro_list;
	struct sk_buff___108 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___107 {
	struct net_device___107 *dev;
	struct Qdisc___99 *qdisc;
	struct Qdisc___99 *qdisc_sleeping;
	struct kobject___450 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___107 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___99 {
	struct sk_buff___108 *head;
	struct sk_buff___108 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___99;

struct Qdisc___99 {
	int (*enqueue)(struct sk_buff___108 *, struct Qdisc___99 *, struct sk_buff___108 **);
	struct sk_buff___108 * (*dequeue)(struct Qdisc___99 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___99 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___107 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___107 gso_skb;
	struct qdisc_skb_head___99 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___99 *next_sched;
	struct sk_buff_head___107 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___107 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___450 kobj;
	struct net_device___107 *dev;
	long: 64;
	struct xdp_rxq_info___107 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___107)(struct net_device___107 *, struct sk_buff___108 *, struct net_device___107 *);

struct netdev_bpf___107 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___97 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___97 *prog;
			const struct bpf_prog_offload_ops___97 *ops;
		} verifier;
		struct {
			struct bpf_prog___97 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___107 *offmap;
		};
		struct {
			struct xdp_umem___3 *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___107 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___108 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___107 {
	int (*tls_dev_add)(struct net_device___107 *, struct sock___87 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___107 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___107 *, struct sock___87 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___107 {
	int (*ndo_init)(struct net_device___107 *);
	void (*ndo_uninit)(struct net_device___107 *);
	int (*ndo_open)(struct net_device___107 *);
	int (*ndo_stop)(struct net_device___107 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___108 *, struct net_device___107 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___108 *, struct net_device___107 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___107 *, struct sk_buff___108 *, struct net_device___107 *, select_queue_fallback_t___107);
	void (*ndo_change_rx_flags)(struct net_device___107 *, int);
	void (*ndo_set_rx_mode)(struct net_device___107 *);
	int (*ndo_set_mac_address)(struct net_device___107 *, void *);
	int (*ndo_validate_addr)(struct net_device___107 *);
	int (*ndo_do_ioctl)(struct net_device___107 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___107 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___107 *, int);
	int (*ndo_neigh_setup)(struct net_device___107 *, struct neigh_parms___87 *);
	void (*ndo_tx_timeout)(struct net_device___107 *);
	void (*ndo_get_stats64)(struct net_device___107 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___107 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___107 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___107 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___107 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___107 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___107 *);
	int (*ndo_netpoll_setup)(struct net_device___107 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___107 *);
	int (*ndo_set_vf_mac)(struct net_device___107 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___107 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___107 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___107 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___107 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___107 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___107 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___107 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___107 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___107 *, int, struct sk_buff___108 *);
	int (*ndo_set_vf_guid)(struct net_device___107 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___107 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___107 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___107 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___107 *, const struct sk_buff___108 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___107 *, struct net_device___107 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___107 *, struct net_device___107 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___107 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___107 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___107 *, struct neighbour___87 *);
	void (*ndo_neigh_destroy)(struct net_device___107 *, struct neighbour___87 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___107 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___107 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___107 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___108 *, struct netlink_callback___109 *, struct net_device___107 *, struct net_device___107 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___107 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___107 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___108 *, u32, u32, struct net_device___107 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___107 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___107 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___107 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___107 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___107 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___107 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___107 *, struct net_device___107 *);
	void (*ndo_dfwd_del_station)(struct net_device___107 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___107 *);
	int (*ndo_set_tx_maxrate)(struct net_device___107 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___107 *);
	int (*ndo_change_proto_down)(struct net_device___107 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___107 *, struct sk_buff___108 *);
	void (*ndo_set_rx_headroom)(struct net_device___107 *, int);
	int (*ndo_bpf)(struct net_device___107 *, struct netdev_bpf___107 *);
	int (*ndo_xdp_xmit)(struct net_device___107 *, int, struct xdp_frame___107 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___107 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___107 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___87 {
	possible_net_t___109 net;
	struct net_device___107 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___87 *);
	void (*neigh_cleanup)(struct neighbour___87 *);
	struct neigh_table___87 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___87 {
	u32 (*l3mdev_fib_table)(const struct net_device___107 *);
	struct sk_buff___108 * (*l3mdev_l3_rcv)(struct net_device___107 *, struct sk_buff___108 *, u16);
	struct sk_buff___108 * (*l3mdev_l3_out)(struct net_device___107 *, struct sock___87 *, struct sk_buff___108 *, u16);
	struct dst_entry___87 * (*l3mdev_link_scope_lookup)(const struct net_device___107 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct ndisc_ops___57 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___107 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___107 *, struct neighbour___87 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___107 *, u8, struct neighbour___87 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___107 *, struct sk_buff___108 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___118 *, struct net_device___107 *, const struct prefix_info *, struct inet6_dev___57 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct in_ifaddr___15;

struct in_device___15 {
	struct net_device___107 *dev;
	refcount_t refcnt;
	int dead;
	struct in_ifaddr___15 *ifa_list;
	struct ip_mc_list *mc_list;
	struct ip_mc_list **mc_hash;
	int mc_count;
	spinlock_t mc_tomb_lock;
	struct ip_mc_list *mc_tomb;
	long unsigned int mr_v1_seen;
	long unsigned int mr_v2_seen;
	long unsigned int mr_maxdelay;
	long unsigned int mr_qi;
	long unsigned int mr_qri;
	unsigned char mr_qrv;
	unsigned char mr_gq_running;
	unsigned char mr_ifc_count;
	struct timer_list mr_gq_timer;
	struct timer_list mr_ifc_timer;
	struct neigh_parms___87 *arp_parms;
	struct ipv4_devconf cnf;
	struct callback_head callback_head;
};

struct ifmcaddr6___57;

struct ifacaddr6___28;

struct inet6_dev___57 {
	struct net_device___107 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___57 *mc_list;
	struct ifmcaddr6___57 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___28 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	u8 rndid[8];
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___87 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
};

struct wpan_phy;

struct wpan_dev_header_ops;

struct wpan_dev___2 {
	struct wpan_phy *wpan_phy;
	int iftype;
	struct list_head list;
	struct net_device___107 *netdev;
	const struct wpan_dev_header_ops *header_ops;
	struct net_device___107 *lowpan_dev;
	u32 identifier;
	__le16 pan_id;
	__le16 short_addr;
	__le64 extended_addr;
	atomic_t bsn;
	atomic_t dsn;
	u8 min_be;
	u8 max_be;
	u8 csma_retries;
	s8 frame_retries;
	bool lbt;
	bool promiscuous_mode;
	bool ackreq;
};

struct tcf_proto___99;

struct mini_Qdisc___99 {
	struct tcf_proto___99 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___99 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___107 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___118 *, struct net_device___107 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___107 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___107 *, struct list_head *);
	size_t (*get_size)(const struct net_device___107 *);
	int (*fill_info)(struct sk_buff___108 *, const struct net_device___107 *);
	size_t (*get_xstats_size)(const struct net_device___107 *);
	int (*fill_xstats)(struct sk_buff___108 *, const struct net_device___107 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___107 *, struct net_device___107 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___107 *, const struct net_device___107 *);
	int (*fill_slave_info)(struct sk_buff___108 *, const struct net_device___107 *, const struct net_device___107 *);
	struct net___118 * (*get_link_net)(const struct net_device___107 *);
	size_t (*get_linkxstats_size)(const struct net_device___107 *, int);
	int (*fill_linkxstats)(struct sk_buff___108 *, const struct net_device___107 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct offload_callbacks___18 {
	struct sk_buff___108 * (*gso_segment)(struct sk_buff___108 *, netdev_features_t);
	struct sk_buff___108 ** (*gro_receive)(struct sk_buff___108 **, struct sk_buff___108 *);
	int (*gro_complete)(struct sk_buff___108 *, int);
};

struct netdev_notifier_info___12 {
	struct net_device___107 *dev;
	struct netlink_ext_ack *extack;
};

struct netdev_notifier_change_info___3 {
	struct netdev_notifier_info___12 info;
	unsigned int flags_changed;
};

struct netdev_notifier_changeupper_info___3 {
	struct netdev_notifier_info___12 info;
	struct net_device___107 *upper_dev;
	bool master;
	bool linking;
	void *upper_info;
};

struct softnet_data___107 {
	struct list_head poll_list;
	struct sk_buff_head___107 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___107 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___99 *output_queue;
	struct Qdisc___99 **output_queue_tailp;
	struct sk_buff___108 *completion_queue;
	struct sk_buff_head___107 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___107 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___107 input_pkt_queue;
	struct napi_struct___107 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct prefixmsg {
	unsigned char prefix_family;
	unsigned char prefix_pad1;
	short unsigned int prefix_pad2;
	int prefix_ifindex;
	unsigned char prefix_type;
	unsigned char prefix_len;
	unsigned char prefix_flags;
	unsigned char prefix_pad3;
};

enum {
	PREFIX_UNSPEC = 0,
	PREFIX_ADDRESS = 1,
	PREFIX_CACHEINFO = 2,
	__PREFIX_MAX = 3,
};

struct prefix_cacheinfo {
	__u32 preferred_time;
	__u32 valid_time;
};

struct in_ifaddr___15 {
	struct hlist_node hash;
	struct in_ifaddr___15 *ifa_next;
	struct in_device___15 *ifa_dev;
	struct callback_head callback_head;
	__be32 ifa_local;
	__be32 ifa_address;
	__be32 ifa_mask;
	__u32 ifa_rt_priority;
	__be32 ifa_broadcast;
	unsigned char ifa_scope;
	unsigned char ifa_prefixlen;
	__u32 ifa_flags;
	char ifa_label[16];
	__u32 ifa_valid_lft;
	__u32 ifa_preferred_lft;
	long unsigned int ifa_cstamp;
	long unsigned int ifa_tstamp;
};

struct bdi_writeback_congested___252 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___252 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___252 {
	struct bio___252 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___254 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___254 bip_inline_vecs[0];
};

struct bio_set___252 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___252 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___195 {
	struct mem_cgroup___195 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___195 {
	struct lruvec___463 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___195 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___195 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct kernel_param_ops___388 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___388 *);
	int (*get)(char *, const struct kernel_param___388 *);
	void (*free)(void *);
};

struct kparam_array___388;

struct kernel_param___388 {
	const char *name;
	struct module___388 *mod;
	const struct kernel_param_ops___388 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___388 *arr;
	};
};

struct kparam_array___388 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___388 *ops;
	void *elem;
};

struct module_attribute___388 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___388 *, struct module_kobject___388 *, char *);
	ssize_t (*store)(struct module_attribute___388 *, struct module_kobject___388 *, const char *, size_t);
	void (*setup)(struct module___388 *, const char *);
	int (*test)(struct module___388 *);
	void (*free)(struct module___388 *);
};

struct gnet_dump___99 {
	spinlock_t *lock;
	struct sk_buff___108 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct nl_info___3 {
	struct nlmsghdr *nlh;
	struct net___118 *nl_net;
	u32 portid;
	bool skip_notify;
};

struct rtnl_af_ops___3 {
	struct list_head list;
	int family;
	int (*fill_link_af)(struct sk_buff___108 *, const struct net_device___107 *, u32);
	size_t (*get_link_af_size)(const struct net_device___107 *, u32);
	int (*validate_link_af)(const struct net_device___107 *, const struct nlattr *);
	int (*set_link_af)(struct net_device___107 *, const struct nlattr *);
	int (*fill_stats_af)(struct sk_buff___108 *, const struct net_device___107 *);
	size_t (*get_stats_af_size)(const struct net_device___107 *);
};

struct Qdisc_class_ops___99;

struct Qdisc_ops___99 {
	struct Qdisc_ops___99 *next;
	const struct Qdisc_class_ops___99 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___108 *, struct Qdisc___99 *, struct sk_buff___108 **);
	struct sk_buff___108 * (*dequeue)(struct Qdisc___99 *);
	struct sk_buff___108 * (*peek)(struct Qdisc___99 *);
	int (*init)(struct Qdisc___99 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___99 *);
	void (*destroy)(struct Qdisc___99 *);
	int (*change)(struct Qdisc___99 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___99 *);
	int (*change_tx_queue_len)(struct Qdisc___99 *, unsigned int);
	int (*dump)(struct Qdisc___99 *, struct sk_buff___108 *);
	int (*dump_stats)(struct Qdisc___99 *, struct gnet_dump___99 *);
	void (*ingress_block_set)(struct Qdisc___99 *, u32);
	void (*egress_block_set)(struct Qdisc___99 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___99 *);
	u32 (*egress_block_get)(struct Qdisc___99 *);
	struct module___388 *owner;
};

struct qdisc_walker___14;

struct tcf_block___99;

struct Qdisc_class_ops___99 {
	unsigned int flags;
	struct netdev_queue___107 * (*select_queue)(struct Qdisc___99 *, struct tcmsg *);
	int (*graft)(struct Qdisc___99 *, long unsigned int, struct Qdisc___99 *, struct Qdisc___99 **, struct netlink_ext_ack *);
	struct Qdisc___99 * (*leaf)(struct Qdisc___99 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___99 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___99 *, u32);
	int (*change)(struct Qdisc___99 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___99 *, long unsigned int);
	void (*walk)(struct Qdisc___99 *, struct qdisc_walker___14 *);
	struct tcf_block___99 * (*tcf_block)(struct Qdisc___99 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___99 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___99 *, long unsigned int);
	int (*dump)(struct Qdisc___99 *, long unsigned int, struct sk_buff___108 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___99 *, long unsigned int, struct gnet_dump___99 *);
};

struct qdisc_walker___14 {
	int stop;
	int skip;
	int count;
	int (*fn)(struct Qdisc___99 *, long unsigned int, struct qdisc_walker___14 *);
};

struct tcf_chain___99;

struct tcf_block___99 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___118 *net;
	struct Qdisc___99 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___99 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___99;

struct tcf_proto_ops___99;

struct tcf_proto___99 {
	struct tcf_proto___99 *next;
	void *root;
	int (*classify)(struct sk_buff___108 *, const struct tcf_proto___99 *, struct tcf_result___99 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___99 *ops;
	struct tcf_chain___99 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___99 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___99 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___99 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___108 *, const struct tcf_proto___99 *, struct tcf_result___99 *);
	int (*init)(struct tcf_proto___99 *);
	void (*destroy)(struct tcf_proto___99 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___99 *, u32);
	void (*put)(struct tcf_proto___99 *, void *);
	int (*change)(struct net___118 *, struct sk_buff___108 *, struct tcf_proto___99 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___99 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___99 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___99 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___118 *, struct tcf_chain___99 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___118 *, struct tcf_proto___99 *, void *, struct sk_buff___108 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___108 *, struct net___118 *, void *);
	struct module___388 *owner;
	int flags;
};

struct tcf_chain___99 {
	struct mutex filter_chain_lock;
	struct tcf_proto___99 *filter_chain;
	struct list_head list;
	struct tcf_block___99 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___99 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___87 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___97 *prog;
};

struct bpf_redirect_info___97 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___312 *map;
	struct bpf_map___312 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___87;

struct neigh_hash_table___87;

struct neigh_table___87 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___107 *, __u32 *);
	bool (*key_eq)(const struct neighbour___87 *, const void *);
	int (*constructor)(struct neighbour___87 *);
	int (*pconstructor)(struct pneigh_entry___87 *);
	void (*pdestructor)(struct pneigh_entry___87 *);
	void (*proxy_redo)(struct sk_buff___108 *);
	char *id;
	struct neigh_parms___87 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___107 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___87 *nht;
	struct pneigh_entry___87 **phash_buckets;
};

struct neigh_ops___87 {
	int family;
	void (*solicit)(struct neighbour___87 *, struct sk_buff___108 *);
	void (*error_report)(struct neighbour___87 *, struct sk_buff___108 *);
	int (*output)(struct neighbour___87 *, struct sk_buff___108 *);
	int (*connected_output)(struct neighbour___87 *, struct sk_buff___108 *);
};

struct pneigh_entry___87 {
	struct pneigh_entry___87 *next;
	possible_net_t___109 net;
	struct net_device___107 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___87 {
	struct neighbour___87 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___12 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___118 *, struct sock___87 *, struct sk_buff___108 *);
	int (*orig_input)(struct sk_buff___108 *);
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	__u8 data[0];
};

struct fib_rule___87 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___87 *ctarget;
	struct net___118 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___87 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___87 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___69;

struct timewait_sock_ops___65;

struct proto___87 {
	void (*close)(struct sock___87 *, long int);
	int (*pre_connect)(struct sock___87 *, struct sockaddr *, int);
	int (*connect)(struct sock___87 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___87 *, int);
	struct sock___87 * (*accept)(struct sock___87 *, int, int *, bool);
	int (*ioctl)(struct sock___87 *, int, long unsigned int);
	int (*init)(struct sock___87 *);
	void (*destroy)(struct sock___87 *);
	void (*shutdown)(struct sock___87 *, int);
	int (*setsockopt)(struct sock___87 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___87 *, int, int, char *, int *);
	void (*keepalive)(struct sock___87 *, int);
	int (*sendmsg)(struct sock___87 *, struct msghdr___90 *, size_t);
	int (*recvmsg)(struct sock___87 *, struct msghdr___90 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___87 *, struct page___463 *, int, size_t, int);
	int (*bind)(struct sock___87 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___87 *, struct sk_buff___108 *);
	void (*release_cb)(struct sock___87 *);
	int (*hash)(struct sock___87 *);
	void (*unhash)(struct sock___87 *);
	void (*rehash)(struct sock___87 *);
	int (*get_port)(struct sock___87 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___87 *);
	bool (*stream_memory_read)(const struct sock___87 *);
	void (*enter_memory_pressure)(struct sock___87 *);
	void (*leave_memory_pressure)(struct sock___87 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___69 *rsk_prot;
	struct timewait_sock_ops___65 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___388 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___87 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct request_sock___70;

struct request_sock_ops___69 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___87 *, struct request_sock___70 *);
	void (*send_ack)(const struct sock___87 *, struct sk_buff___108 *, struct request_sock___70 *);
	void (*send_reset)(const struct sock___87 *, struct sk_buff___108 *);
	void (*destructor)(struct request_sock___70 *);
	void (*syn_ack_timeout)(const struct request_sock___70 *);
};

struct timewait_sock_ops___65 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___87 *, struct sock___87 *, void *);
	void (*twsk_destructor)(struct sock___87 *);
};

struct in6_ifreq {
	struct in6_addr ifr6_addr;
	__u32 ifr6_prefixlen;
	int ifr6_ifindex;
};

enum {
	DEVCONF_FORWARDING = 0,
	DEVCONF_HOPLIMIT = 1,
	DEVCONF_MTU6 = 2,
	DEVCONF_ACCEPT_RA = 3,
	DEVCONF_ACCEPT_REDIRECTS = 4,
	DEVCONF_AUTOCONF = 5,
	DEVCONF_DAD_TRANSMITS = 6,
	DEVCONF_RTR_SOLICITS = 7,
	DEVCONF_RTR_SOLICIT_INTERVAL = 8,
	DEVCONF_RTR_SOLICIT_DELAY = 9,
	DEVCONF_USE_TEMPADDR = 10,
	DEVCONF_TEMP_VALID_LFT = 11,
	DEVCONF_TEMP_PREFERED_LFT = 12,
	DEVCONF_REGEN_MAX_RETRY = 13,
	DEVCONF_MAX_DESYNC_FACTOR = 14,
	DEVCONF_MAX_ADDRESSES = 15,
	DEVCONF_FORCE_MLD_VERSION = 16,
	DEVCONF_ACCEPT_RA_DEFRTR = 17,
	DEVCONF_ACCEPT_RA_PINFO = 18,
	DEVCONF_ACCEPT_RA_RTR_PREF = 19,
	DEVCONF_RTR_PROBE_INTERVAL = 20,
	DEVCONF_ACCEPT_RA_RT_INFO_MAX_PLEN = 21,
	DEVCONF_PROXY_NDP = 22,
	DEVCONF_OPTIMISTIC_DAD = 23,
	DEVCONF_ACCEPT_SOURCE_ROUTE = 24,
	DEVCONF_MC_FORWARDING = 25,
	DEVCONF_DISABLE_IPV6 = 26,
	DEVCONF_ACCEPT_DAD = 27,
	DEVCONF_FORCE_TLLAO = 28,
	DEVCONF_NDISC_NOTIFY = 29,
	DEVCONF_MLDV1_UNSOLICITED_REPORT_INTERVAL = 30,
	DEVCONF_MLDV2_UNSOLICITED_REPORT_INTERVAL = 31,
	DEVCONF_SUPPRESS_FRAG_NDISC = 32,
	DEVCONF_ACCEPT_RA_FROM_LOCAL = 33,
	DEVCONF_USE_OPTIMISTIC = 34,
	DEVCONF_ACCEPT_RA_MTU = 35,
	DEVCONF_STABLE_SECRET = 36,
	DEVCONF_USE_OIF_ADDRS_ONLY = 37,
	DEVCONF_ACCEPT_RA_MIN_HOP_LIMIT = 38,
	DEVCONF_IGNORE_ROUTES_WITH_LINKDOWN = 39,
	DEVCONF_DROP_UNICAST_IN_L2_MULTICAST = 40,
	DEVCONF_DROP_UNSOLICITED_NA = 41,
	DEVCONF_KEEP_ADDR_ON_DOWN = 42,
	DEVCONF_RTR_SOLICIT_MAX_INTERVAL = 43,
	DEVCONF_SEG6_ENABLED = 44,
	DEVCONF_SEG6_REQUIRE_HMAC = 45,
	DEVCONF_ENHANCED_DAD = 46,
	DEVCONF_ADDR_GEN_MODE = 47,
	DEVCONF_DISABLE_POLICY = 48,
	DEVCONF_ACCEPT_RA_RT_INFO_MIN_PLEN = 49,
	DEVCONF_NDISC_TCLASS = 50,
	DEVCONF_MAX = 51,
};

struct request_sock___70 {
	struct sock_common___87 __req_common;
	struct request_sock___70 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___69 *rsk_ops;
	struct sock___87 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

enum {
	INET6_IFADDR_STATE_PREDAD = 0,
	INET6_IFADDR_STATE_DAD = 1,
	INET6_IFADDR_STATE_POSTDAD = 2,
	INET6_IFADDR_STATE_ERRDAD = 3,
	INET6_IFADDR_STATE_DEAD = 4,
};

struct inet6_ifaddr___3 {
	struct in6_addr addr;
	__u32 prefix_len;
	__u32 rt_priority;
	__u32 valid_lft;
	__u32 prefered_lft;
	refcount_t refcnt;
	spinlock_t lock;
	int state;
	__u32 flags;
	__u8 dad_probes;
	__u8 stable_privacy_retry;
	__u16 scope;
	__u64 dad_nonce;
	long unsigned int cstamp;
	long unsigned int tstamp;
	struct delayed_work dad_work;
	struct inet6_dev___57 *idev;
	struct fib6_info___28 *rt;
	struct hlist_node addr_lst;
	struct list_head if_list;
	struct list_head tmp_list;
	struct inet6_ifaddr___3 *ifpub;
	int regen_count;
	bool tokenized;
	struct callback_head rcu;
	struct in6_addr peer_addr;
};

struct ifmcaddr6___57 {
	struct in6_addr mca_addr;
	struct inet6_dev___57 *idev;
	struct ifmcaddr6___57 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___28 {
	struct in6_addr aca_addr;
	struct fib6_info___28 *aca_rt;
	struct ifacaddr6___28 *aca_next;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct ip6_ra_chain___57 {
	struct ip6_ra_chain___57 *next;
	struct sock___87 *sk;
	int sel;
	void (*destructor)(struct sock___87 *);
};

enum nl802154_cca_modes {
	__NL802154_CCA_INVALID = 0,
	NL802154_CCA_ENERGY = 1,
	NL802154_CCA_CARRIER = 2,
	NL802154_CCA_ENERGY_CARRIER = 3,
	NL802154_CCA_ALOHA = 4,
	NL802154_CCA_UWB_SHR = 5,
	NL802154_CCA_UWB_MULTIPLEXED = 6,
	__NL802154_CCA_ATTR_AFTER_LAST = 7,
	NL802154_CCA_ATTR_MAX = 6,
};

enum nl802154_cca_opts {
	NL802154_CCA_OPT_ENERGY_CARRIER_AND = 0,
	NL802154_CCA_OPT_ENERGY_CARRIER_OR = 1,
	__NL802154_CCA_OPT_ATTR_AFTER_LAST = 2,
	NL802154_CCA_OPT_ATTR_MAX = 1,
};

enum nl802154_supported_bool_states {
	NL802154_SUPPORTED_BOOL_FALSE = 0,
	NL802154_SUPPORTED_BOOL_TRUE = 1,
	__NL802154_SUPPORTED_BOOL_INVALD = 2,
	NL802154_SUPPORTED_BOOL_BOTH = 3,
	__NL802154_SUPPORTED_BOOL_AFTER_LAST = 4,
	NL802154_SUPPORTED_BOOL_MAX = 3,
};

struct wpan_phy_supported {
	u32 channels[32];
	u32 cca_modes;
	u32 cca_opts;
	u32 iftypes;
	enum nl802154_supported_bool_states lbt;
	u8 min_minbe;
	u8 max_minbe;
	u8 min_maxbe;
	u8 max_maxbe;
	u8 min_csma_backoffs;
	u8 max_csma_backoffs;
	s8 min_frame_retries;
	s8 max_frame_retries;
	size_t tx_powers_size;
	size_t cca_ed_levels_size;
	const s32 *tx_powers;
	const s32 *cca_ed_levels;
};

struct wpan_phy_cca {
	enum nl802154_cca_modes mode;
	enum nl802154_cca_opts opt;
};

struct wpan_phy {
	const void *privid;
	u32 flags;
	u8 current_channel;
	u8 current_page;
	struct wpan_phy_supported supported;
	s32 transmit_power;
	struct wpan_phy_cca cca;
	__le64 perm_extended_addr;
	s32 cca_ed_level;
	u8 symbol_duration;
	u16 lifs_period;
	u16 sifs_period;
	struct device___430 dev;
	possible_net_t___109 _net;
	long: 64;
	long: 64;
	long: 64;
	char priv[0];
};

struct ieee802154_addr {
	u8 mode;
	__le16 pan_id;
	union {
		__le16 short_addr;
		__le64 extended_addr;
	};
};

struct wpan_dev_header_ops {
	int (*create)(struct sk_buff___108 *, struct net_device___107 *, const struct ieee802154_addr *, const struct ieee802154_addr *, unsigned int);
};

union fwnet_hwaddr {
	u8 u[16];
	struct {
		__be64 uniq_id;
		u8 max_rec;
		u8 sspd;
		__be16 fifo_hi;
		__be32 fifo_lo;
	} uc;
};

struct net_protocol___16 {
	int (*early_demux)(struct sk_buff___108 *);
	int (*early_demux_handler)(struct sk_buff___108 *);
	int (*handler)(struct sk_buff___108 *);
	void (*err_handler)(struct sk_buff___108 *, u32);
	unsigned int no_policy: 1;
	unsigned int netns_ok: 1;
	unsigned int icmp_strict_tag_validation: 1;
};

struct inet6_protocol___16 {
	void (*early_demux)(struct sk_buff___108 *);
	void (*early_demux_handler)(struct sk_buff___108 *);
	int (*handler)(struct sk_buff___108 *);
	void (*err_handler)(struct sk_buff___108 *, struct inet6_skb_parm *, u8, u8, int, __be32);
	unsigned int flags;
};

struct net_offload___16 {
	struct offload_callbacks___18 callbacks;
	unsigned int flags;
};

struct in6_validator_info {
	struct in6_addr i6vi_addr;
	struct inet6_dev___57 *i6vi_dev;
	struct netlink_ext_ack *extack;
};

struct ifa6_config {
	const struct in6_addr *pfx;
	unsigned int plen;
	const struct in6_addr *peer_pfx;
	u32 rt_priority;
	u32 ifa_flags;
	u32 preferred_lft;
	u32 valid_lft;
	u16 scope;
};

struct ipv6_stub___17 {
	int (*ipv6_sock_mc_join)(struct sock___87 *, int, const struct in6_addr *);
	int (*ipv6_sock_mc_drop)(struct sock___87 *, int, const struct in6_addr *);
	int (*ipv6_dst_lookup)(struct net___118 *, struct sock___87 *, struct dst_entry___87 **, struct flowi6 *);
	struct fib6_table___28 * (*fib6_get_table)(struct net___118 *, u32);
	struct fib6_info___28 * (*fib6_lookup)(struct net___118 *, int, struct flowi6 *, int);
	struct fib6_info___28 * (*fib6_table_lookup)(struct net___118 *, struct fib6_table___28 *, int, struct flowi6 *, int);
	struct fib6_info___28 * (*fib6_multipath_select)(const struct net___118 *, struct fib6_info___28 *, struct flowi6 *, int, const struct sk_buff___108 *, int);
	u32 (*ip6_mtu_from_fib6)(struct fib6_info___28 *, struct in6_addr *, struct in6_addr *);
	void (*udpv6_encap_enable)();
	void (*ndisc_send_na)(struct net_device___107 *, const struct in6_addr *, const struct in6_addr *, bool, bool, bool, bool);
	struct neigh_table___87 *nd_tbl;
};

struct ipv6_bpf_stub___17 {
	int (*inet6_bind)(struct sock___87 *, struct sockaddr *, int, bool, bool);
	struct sock___87 * (*udp6_lib_lookup)(struct net___118 *, const struct in6_addr *, __be16, const struct in6_addr *, __be16, int, int, struct udp_table *, struct sk_buff___108 *);
};

struct fib6_config {
	u32 fc_table;
	u32 fc_metric;
	int fc_dst_len;
	int fc_src_len;
	int fc_ifindex;
	u32 fc_flags;
	u32 fc_protocol;
	u16 fc_type;
	u16 fc_delete_all_nh: 1;
	u16 __unused: 15;
	struct in6_addr fc_dst;
	struct in6_addr fc_src;
	struct in6_addr fc_prefsrc;
	struct in6_addr fc_gateway;
	long unsigned int fc_expires;
	struct nlattr *fc_mx;
	int fc_mx_len;
	int fc_mp_len;
	struct nlattr *fc_mp;
	struct nl_info___3 fc_nlinfo;
	struct nlattr *fc_encap;
	u16 fc_encap_type;
};

enum cleanup_prefix_rt_t {
	CLEANUP_PREFIX_RT_NOP = 0,
	CLEANUP_PREFIX_RT_DEL = 1,
	CLEANUP_PREFIX_RT_EXPIRE = 2,
};

enum {
	IPV6_SADDR_RULE_INIT = 0,
	IPV6_SADDR_RULE_LOCAL = 1,
	IPV6_SADDR_RULE_SCOPE = 2,
	IPV6_SADDR_RULE_PREFERRED = 3,
	IPV6_SADDR_RULE_OIF = 4,
	IPV6_SADDR_RULE_LABEL = 5,
	IPV6_SADDR_RULE_PRIVACY = 6,
	IPV6_SADDR_RULE_ORCHID = 7,
	IPV6_SADDR_RULE_PREFIX = 8,
	IPV6_SADDR_RULE_NOT_OPTIMISTIC = 9,
	IPV6_SADDR_RULE_MAX = 10,
};

struct ipv6_saddr_score {
	int rule;
	int addr_type;
	struct inet6_ifaddr___3 *ifa;
	long unsigned int scorebits[1];
	int scopedist;
	int matchlen;
};

struct ipv6_saddr_dst {
	const struct in6_addr *addr;
	int ifindex;
	int scope;
	int label;
	unsigned int prefs;
};

struct if6_iter_state {
	struct seq_net_private___13 p;
	int bucket;
	int offset;
};

enum addr_type_t {
	UNICAST_ADDR = 0,
	MULTICAST_ADDR = 1,
	ANYCAST_ADDR = 2,
};

struct inet6_fill_args {
	u32 portid;
	u32 seq;
	int event;
	unsigned int flags;
	int netnsid;
	int ifindex;
	enum addr_type_t type;
};

enum {
	DAD_PROCESS = 0,
	DAD_BEGIN = 1,
	DAD_ABORT = 2,
};

struct ifaddrlblmsg {
	__u8 ifal_family;
	__u8 __ifal_reserved;
	__u8 ifal_prefixlen;
	__u8 ifal_flags;
	__u32 ifal_index;
	__u32 ifal_seq;
};

enum {
	IFAL_ADDRESS = 1,
	IFAL_LABEL = 2,
	__IFAL_MAX = 3,
};

struct ip6addrlbl_entry {
	struct in6_addr prefix;
	int prefixlen;
	int ifindex;
	int addrtype;
	u32 label;
	struct hlist_node list;
	struct callback_head rcu;
};

struct ip6addrlbl_init_table {
	const struct in6_addr *prefix;
	int prefixlen;
	u32 label;
};

struct module___389;

struct file___463;

struct kiocb___463;

struct iov_iter___230;

struct poll_table_struct___302;

struct vm_area_struct___464;

struct inode___463;

struct file_lock___463;

struct page___464;

struct pipe_inode_info___144;

struct seq_file___402;

struct file_operations___463 {
	struct module___389 *owner;
	loff_t (*llseek)(struct file___463 *, loff_t, int);
	ssize_t (*read)(struct file___463 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___463 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___463 *, struct iov_iter___230 *);
	ssize_t (*write_iter)(struct kiocb___463 *, struct iov_iter___230 *);
	int (*iopoll)(struct kiocb___463 *, bool);
	int (*iterate)(struct file___463 *, struct dir_context *);
	int (*iterate_shared)(struct file___463 *, struct dir_context *);
	__poll_t (*poll)(struct file___463 *, struct poll_table_struct___302 *);
	long int (*unlocked_ioctl)(struct file___463 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___463 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___463 *, struct vm_area_struct___464 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___463 *, struct file___463 *);
	int (*flush)(struct file___463 *, fl_owner_t);
	int (*release)(struct inode___463 *, struct file___463 *);
	int (*fsync)(struct file___463 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___463 *, int);
	int (*lock)(struct file___463 *, int, struct file_lock___463 *);
	ssize_t (*sendpage)(struct file___463 *, struct page___464 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___463 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___463 *, int, struct file_lock___463 *);
	ssize_t (*splice_write)(struct pipe_inode_info___144 *, struct file___463 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___463 *, loff_t *, struct pipe_inode_info___144 *, size_t, unsigned int);
	int (*setlease)(struct file___463 *, long int, struct file_lock___463 **, void **);
	long int (*fallocate)(struct file___463 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___402 *, struct file___463 *);
	ssize_t (*copy_file_range)(struct file___463 *, loff_t, struct file___463 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___463 *, loff_t, struct file___463 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___463 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___464 {
	u64 seqnum;
	struct vm_area_struct___464 *vmas[4];
};

struct page_frag___464 {
	struct page___464 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___157;

struct debug_info___157 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___157 *hbp_break[16];
	struct perf_event___157 *hbp_watch[16];
};

struct thread_struct___157 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___157 debug;
	long: 64;
};

struct mm_struct___464;

struct mem_cgroup___196;

struct pid___259;

struct cred___431;

struct nsproxy___358;

struct signal_struct___338;

struct bio_list___253;

struct backing_dev_info___253;

struct css_set___312;

struct perf_event_context___157;

struct vm_struct___367;

struct task_struct___465 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___465 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___464 *mm;
	struct mm_struct___464 *active_mm;
	struct vmacache___464 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___465 *real_parent;
	struct task_struct___465 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___465 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___196 *active_memcg;
	long int rh_reserved2;
	struct pid___259 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___259 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___259 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___431 *ptracer_cred;
	const struct cred___431 *real_cred;
	const struct cred___431 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___358 *nsproxy;
	struct signal_struct___338 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___465 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___253 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___253 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___312 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___157 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___144 *splice_pipe;
	struct page_frag___464 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___196 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___465 *oom_reaper_list;
	struct vm_struct___367 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___157 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___157 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___465 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	u64 last_period;
	local64_t period_left;
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___157)(struct perf_event___157 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___157;

struct fasync_struct___463;

struct pid_namespace___259;

struct bpf_prog___98;

struct trace_event_call___148;

struct perf_cgroup___157;

struct perf_event___157 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___157 *group_leader;
	struct pmu___157 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	u64 shadow_ctx_time;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___157 hw;
	struct perf_event_context___157 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___157 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___465 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct ring_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___463 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	long unsigned int *addr_filters_offs;
	long unsigned int addr_filters_gen;
	void (*destroy)(struct perf_event___157 *);
	struct callback_head callback_head;
	struct pid_namespace___259 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___157 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___157 orig_overflow_handler;
	struct bpf_prog___98 *prog;
	struct trace_event_call___148 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___157 *cgrp;
	struct list_head sb_list;
};

typedef struct page___464 *pgtable_t___464;

struct address_space___463;

struct dev_pagemap___451;

struct page___464 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___463 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___464 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___464 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___464 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___451 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___196 *mem_cgroup;
};

struct pglist_data___464;

struct lruvec___464 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___464 *pgdat;
};

struct zone___464 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___464 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___464 {
	struct zone___464 *zone;
	int zone_idx;
};

struct zonelist___464 {
	struct zoneref___464 _zonerefs[25];
};

struct pglist_data___464 {
	struct zone___464 node_zones[3];
	struct zonelist___464 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___465 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___465 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___464 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___465 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___465 *owner;
};

struct secondary_data___465 {
	void *stack;
	struct task_struct___465 *task;
	long int status;
};

struct blocking_notifier_head___464 {
	struct rw_semaphore___465 rwsem;
	struct notifier_block *head;
};

struct cgroup___312;

struct cgroup_subsys___312;

struct cgroup_subsys_state___312 {
	struct cgroup___312 *cgroup;
	struct cgroup_subsys___312 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___312 *parent;
};

struct kernfs_node___458;

struct cgroup_file___312 {
	struct kernfs_node___458 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___196;

struct mem_cgroup___196 {
	struct cgroup_subsys_state___312 css;
	struct mem_cgroup_id___16 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___312 events_file;
	struct cgroup_file___312 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___465 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___196 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct upid___259 {
	int nr;
	struct pid_namespace___259 *ns;
};

struct dentry___463;

struct user_namespace___328;

struct ucounts___328;

struct pid_namespace___259 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___465 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___259 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___463 *proc_self;
	struct dentry___463 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___328 *user_ns;
	struct ucounts___328 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___29 ns;
};

struct pid___259 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___259 numbers[1];
};

struct key___431;

struct user_namespace___328 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___328 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___29 ns;
	long unsigned int flags;
	struct key___431 *persistent_keyring_register;
	struct rw_semaphore___465 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___328 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct user_struct___431 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___431 *uid_keyring;
	struct key___431 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___451;

struct vm_area_struct___464 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___464 *vm_next;
	struct vm_area_struct___464 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___464 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___451 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___463 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___464;

struct mm_struct___464 {
	struct {
		struct vm_area_struct___464 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___463 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___465 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___464 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___465 *owner;
		struct user_namespace___328 *user_ns;
		struct file___463 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___464 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___431 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___431 *session_keyring;
	struct key___431 *process_keyring;
	struct key___431 *thread_keyring;
	struct key___431 *request_key_auth;
	void *security;
	struct user_struct___431 *user;
	struct user_namespace___328 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___119;

struct cgroup_namespace___312;

struct nsproxy___358 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___259 *pid_ns_for_children;
	struct net___119 *net_ns;
	struct cgroup_namespace___312 *cgroup_ns;
};

struct signal_struct___338 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___465 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___465 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___259 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___259 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___464 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___259 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___253;

struct bio_list___253 {
	struct bio___253 *head;
	struct bio___253 *tail;
};

struct bdi_writeback_congested___253;

struct bdi_writeback___253 {
	struct backing_dev_info___253 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___253 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___312 *memcg_css;
	struct cgroup_subsys_state___312 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___431;

struct backing_dev_info___253 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___253 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___431 *dev;
	struct device___431 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___463 *debug_dir;
	struct dentry___463 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___312 {
	struct cgroup_subsys_state___312 *subsys[13];
	refcount_t refcount;
	struct css_set___312 *dom_cset;
	struct cgroup___312 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___312 *mg_src_cgrp;
	struct cgroup___312 *mg_dst_cgrp;
	struct css_set___312 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___157 {
	struct pmu___157 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	atomic_t refcount;
	struct task_struct___465 *task;
	u64 time;
	u64 timestamp;
	struct perf_event_context___157 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___144;

struct pipe_inode_info___144 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___464 *tmp_page;
	struct fasync_struct___463 *fasync_readers;
	struct fasync_struct___463 *fasync_writers;
	struct pipe_buffer___144 *bufs;
	struct user_struct___431 *user;
};

struct vm_struct___367 {
	struct vm_struct___367 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___464 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___350 {
	struct task_struct___465 task;
	long unsigned int stack[8192];
};

struct address_space_operations___463;

struct address_space___463 {
	struct inode___463 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___465 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___463 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___451)(struct vm_area_struct___464 *, long unsigned int, const struct page___464 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___451)(struct page___464 *, void *);

struct dev_pagemap___451 {
	dev_page_fault_t___451 page_fault;
	dev_page_free_t___451 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___431 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___464 {
	struct vfsmount *mnt;
	struct dentry___463 *dentry;
};

struct fown_struct___259 {
	rwlock_t lock;
	struct pid___259 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___463 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___464 f_path;
	struct inode___463 *f_inode;
	const struct file_operations___463 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___259 f_owner;
	const struct cred___431 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___463 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___451;

struct vm_operations_struct___451 {
	void (*open)(struct vm_area_struct___464 *);
	void (*close)(struct vm_area_struct___464 *);
	int (*split)(struct vm_area_struct___464 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___464 *);
	vm_fault_t (*fault)(struct vm_fault___451 *);
	vm_fault_t (*huge_fault)(struct vm_fault___451 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___451 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___464 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___451 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___451 *);
	int (*access)(struct vm_area_struct___464 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___464 *);
	int (*set_policy)(struct vm_area_struct___464 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___464 *, long unsigned int);
	struct page___464 * (*find_special_page)(struct vm_area_struct___464 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___464 {
	struct task_struct___465 *task;
	struct core_thread___464 *next;
};

struct core_state___464 {
	atomic_t nr_threads;
	struct core_thread___464 dumper;
	struct completion startup;
};

struct vm_fault___451 {
	struct vm_area_struct___464 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___464 *cow_page;
	struct mem_cgroup___196 *memcg;
	struct page___464 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___464 prealloc_pte;
};

struct crypto_async_request___42;

typedef void (*crypto_completion_t___42)(struct crypto_async_request___42 *, int);

struct crypto_tfm___42;

struct crypto_async_request___42 {
	struct list_head list;
	crypto_completion_t___42 complete;
	void *data;
	struct crypto_tfm___42 *tfm;
	u32 flags;
};

struct crypto_ablkcipher___42;

struct ablkcipher_request___42;

struct ablkcipher_tfm___42 {
	int (*setkey)(struct crypto_ablkcipher___42 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___42 *);
	int (*decrypt)(struct ablkcipher_request___42 *);
	struct crypto_ablkcipher___42 *base;
	unsigned int ivsize;
	unsigned int reqsize;
};

struct blkcipher_desc___42;

struct blkcipher_tfm___42 {
	void *iv;
	int (*setkey)(struct crypto_tfm___42 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___42 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___42 *, struct scatterlist *, struct scatterlist *, unsigned int);
};

struct cipher_tfm___42 {
	int (*cit_setkey)(struct crypto_tfm___42 *, const u8 *, unsigned int);
	void (*cit_encrypt_one)(struct crypto_tfm___42 *, u8 *, const u8 *);
	void (*cit_decrypt_one)(struct crypto_tfm___42 *, u8 *, const u8 *);
};

struct compress_tfm___42 {
	int (*cot_compress)(struct crypto_tfm___42 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*cot_decompress)(struct crypto_tfm___42 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___42;

struct crypto_tfm___42 {
	u32 crt_flags;
	union {
		struct ablkcipher_tfm___42 ablkcipher;
		struct blkcipher_tfm___42 blkcipher;
		struct cipher_tfm___42 cipher;
		struct compress_tfm___42 compress;
	} crt_u;
	void (*exit)(struct crypto_tfm___42 *);
	struct crypto_alg___42 *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct ablkcipher_request___42 {
	struct crypto_async_request___42 base;
	unsigned int nbytes;
	void *info;
	struct scatterlist *src;
	struct scatterlist *dst;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_blkcipher___42;

struct blkcipher_desc___42 {
	struct crypto_blkcipher___42 *tfm;
	void *info;
	u32 flags;
};

struct crypto_blkcipher___42 {
	struct crypto_tfm___42 base;
};

struct ablkcipher_alg___42 {
	int (*setkey)(struct crypto_ablkcipher___42 *, const u8 *, unsigned int);
	int (*encrypt)(struct ablkcipher_request___42 *);
	int (*decrypt)(struct ablkcipher_request___42 *);
	int (*givencrypt)(struct skcipher_givcrypt_request *);
	int (*givdecrypt)(struct skcipher_givcrypt_request *);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct crypto_ablkcipher___42 {
	struct crypto_tfm___42 base;
};

struct blkcipher_alg___42 {
	int (*setkey)(struct crypto_tfm___42 *, const u8 *, unsigned int);
	int (*encrypt)(struct blkcipher_desc___42 *, struct scatterlist *, struct scatterlist *, unsigned int);
	int (*decrypt)(struct blkcipher_desc___42 *, struct scatterlist *, struct scatterlist *, unsigned int);
	const char *geniv;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

struct cipher_alg___42 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___42 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___42 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___42 *, u8 *, const u8 *);
};

struct compress_alg___42 {
	int (*coa_compress)(struct crypto_tfm___42 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___42 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___42 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type *cra_type;
	union {
		struct ablkcipher_alg___42 ablkcipher;
		struct blkcipher_alg___42 blkcipher;
		struct cipher_alg___42 cipher;
		struct compress_alg___42 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___42 *);
	void (*cra_exit)(struct crypto_tfm___42 *);
	void (*cra_destroy)(struct crypto_alg___42 *);
	struct module___389 *cra_module;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___450;

struct kobj_type___450;

struct kobject___451 {
	const char *name;
	struct list_head entry;
	struct kobject___451 *parent;
	struct kset___450 *kset;
	struct kobj_type___450 *ktype;
	struct kernfs_node___458 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___389 {
	struct kobject___451 kobj;
	struct module___389 *mod;
	struct kobject___451 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___389 {
	struct module___389 *mod;
	struct latch_tree_node node;
};

struct module_layout___389 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___389 mtn;
};

struct module_attribute___389;

struct kernel_param___389;

struct module___389 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___389 mkobj;
	struct module_attribute___389 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___451 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___389 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___389 core_layout;
	struct module_layout___389 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___148 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide53;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide54;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct crypto_cipher___26 {
	struct crypto_tfm___42 base;
};

struct bio_vec___255 {
	struct page___464 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___230 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___255 *bvec;
		struct pipe_inode_info___144 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct msghdr___91 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___230 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___463 *msg_iocb;
};

struct kiocb___463 {
	struct file___463 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___463 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dentry_operations___463;

struct super_block___463;

struct dentry___463 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___463 *d_parent;
	struct qstr d_name;
	struct inode___463 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___463 *d_op;
	struct super_block___463 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___463;

struct block_device___463;

struct inode___463 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___463 *i_op;
	struct super_block___463 *i_sb;
	struct address_space___463 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___465 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___253 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___463 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___463 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___144 *i_pipe;
		struct block_device___463 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___463 {
	int (*d_revalidate)(struct dentry___463 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___463 *, unsigned int);
	int (*d_hash)(const struct dentry___463 *, struct qstr *);
	int (*d_compare)(const struct dentry___463 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___463 *);
	int (*d_init)(struct dentry___463 *);
	void (*d_release)(struct dentry___463 *);
	void (*d_prune)(struct dentry___463 *);
	void (*d_iput)(struct dentry___463 *, struct inode___463 *);
	char * (*d_dname)(struct dentry___463 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___464 *);
	int (*d_manage)(const struct path___464 *, bool);
	struct dentry___463 * (*d_real)(struct dentry___463 *, const struct inode___463 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___463;

struct mem_dqinfo___463 {
	struct quota_format_type___463 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___463;

struct quota_info___463 {
	unsigned int flags;
	struct rw_semaphore___465 dqio_sem;
	struct inode___463 *files[3];
	struct mem_dqinfo___463 info[3];
	const struct quota_format_ops___463 *ops[3];
};

struct rcuwait___463 {
	struct task_struct___465 *task;
};

struct percpu_rw_semaphore___463 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___465 rw_sem;
	struct rcuwait___463 writer;
	int readers_block;
};

struct sb_writers___463 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___463 rw_sem[3];
};

struct shrink_control___196;

struct shrinker___196 {
	long unsigned int (*count_objects)(struct shrinker___196 *, struct shrink_control___196 *);
	long unsigned int (*scan_objects)(struct shrinker___196 *, struct shrink_control___196 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___463;

struct super_operations___463;

struct dquot_operations___463;

struct quotactl_ops___463;

struct super_block___463 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___463 *s_type;
	const struct super_operations___463 *s_op;
	const struct dquot_operations___463 *dq_op;
	const struct quotactl_ops___463 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___463 *s_root;
	struct rw_semaphore___465 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___463 *s_bdev;
	struct backing_dev_info___253 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___463 s_dquot;
	struct sb_writers___463 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___463 *s_d_op;
	int cleancache_poolid;
	struct shrinker___196 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___328 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___196 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___196 *memcg;
};

struct iattr___463 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___463 *ia_file;
};

struct dquot___463 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___463 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___463 {
	int qf_fmt_id;
	const struct quota_format_ops___463 *qf_ops;
	struct module___389 *qf_owner;
	struct quota_format_type___463 *qf_next;
};

struct quota_format_ops___463 {
	int (*check_quota_file)(struct super_block___463 *, int);
	int (*read_file_info)(struct super_block___463 *, int);
	int (*write_file_info)(struct super_block___463 *, int);
	int (*free_file_info)(struct super_block___463 *, int);
	int (*read_dqblk)(struct dquot___463 *);
	int (*commit_dqblk)(struct dquot___463 *);
	int (*release_dqblk)(struct dquot___463 *);
	int (*get_next_id)(struct super_block___463 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___463 {
	int (*write_dquot)(struct dquot___463 *);
	struct dquot___463 * (*alloc_dquot)(struct super_block___463 *, int);
	void (*destroy_dquot)(struct dquot___463 *);
	int (*acquire_dquot)(struct dquot___463 *);
	int (*release_dquot)(struct dquot___463 *);
	int (*mark_dirty)(struct dquot___463 *);
	int (*write_info)(struct super_block___463 *, int);
	qsize_t * (*get_reserved_space)(struct inode___463 *);
	int (*get_projid)(struct inode___463 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___463 *, qsize_t *);
	int (*get_next_id)(struct super_block___463 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___463 {
	int (*quota_on)(struct super_block___463 *, int, int, const struct path___464 *);
	int (*quota_off)(struct super_block___463 *, int);
	int (*quota_enable)(struct super_block___463 *, unsigned int);
	int (*quota_disable)(struct super_block___463 *, unsigned int);
	int (*quota_sync)(struct super_block___463 *, int);
	int (*set_info)(struct super_block___463 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___463 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___463 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___463 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___463 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___463 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___216;

struct address_space_operations___463 {
	int (*writepage)(struct page___464 *, struct writeback_control___216 *);
	int (*readpage)(struct file___463 *, struct page___464 *);
	int (*writepages)(struct address_space___463 *, struct writeback_control___216 *);
	int (*set_page_dirty)(struct page___464 *);
	int (*readpages)(struct file___463 *, struct address_space___463 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___463 *, struct address_space___463 *, loff_t, unsigned int, unsigned int, struct page___464 **, void **);
	int (*write_end)(struct file___463 *, struct address_space___463 *, loff_t, unsigned int, unsigned int, struct page___464 *, void *);
	sector_t (*bmap)(struct address_space___463 *, sector_t);
	void (*invalidatepage)(struct page___464 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___464 *, gfp_t);
	void (*freepage)(struct page___464 *);
	ssize_t (*direct_IO)(struct kiocb___463 *, struct iov_iter___230 *);
	int (*migratepage)(struct address_space___463 *, struct page___464 *, struct page___464 *, enum migrate_mode);
	bool (*isolate_page)(struct page___464 *, isolate_mode_t);
	void (*putback_page)(struct page___464 *);
	int (*launder_page)(struct page___464 *);
	int (*is_partially_uptodate)(struct page___464 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___464 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___463 *, struct page___464 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___463 *, sector_t *);
	void (*swap_deactivate)(struct file___463 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___216 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___253 *wb;
	struct inode___463 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___463 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___463 *bd_inode;
	struct super_block___463 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___463 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___253 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___463 {
	struct dentry___463 * (*lookup)(struct inode___463 *, struct dentry___463 *, unsigned int);
	const char * (*get_link)(struct dentry___463 *, struct inode___463 *, struct delayed_call *);
	int (*permission)(struct inode___463 *, int);
	struct posix_acl * (*get_acl)(struct inode___463 *, int);
	int (*readlink)(struct dentry___463 *, char *, int);
	int (*create)(struct inode___463 *, struct dentry___463 *, umode_t, bool);
	int (*link)(struct dentry___463 *, struct inode___463 *, struct dentry___463 *);
	int (*unlink)(struct inode___463 *, struct dentry___463 *);
	int (*symlink)(struct inode___463 *, struct dentry___463 *, const char *);
	int (*mkdir)(struct inode___463 *, struct dentry___463 *, umode_t);
	int (*rmdir)(struct inode___463 *, struct dentry___463 *);
	int (*mknod)(struct inode___463 *, struct dentry___463 *, umode_t, dev_t);
	int (*rename)(struct inode___463 *, struct dentry___463 *, struct inode___463 *, struct dentry___463 *, unsigned int);
	int (*setattr)(struct dentry___463 *, struct iattr___463 *);
	int (*getattr)(const struct path___464 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___463 *, char *, size_t);
	int (*fiemap)(struct inode___463 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___463 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___463 *, struct dentry___463 *, struct file___463 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___463 *, struct dentry___463 *, umode_t);
	int (*set_acl)(struct inode___463 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___463 {
	void (*fl_copy_lock)(struct file_lock___463 *, struct file_lock___463 *);
	void (*fl_release_private)(struct file_lock___463 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___463;

struct file_lock___463 {
	struct file_lock___463 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___463 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___463 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___463 *fl_ops;
	const struct lock_manager_operations___463 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___463 {
	int (*lm_compare_owner)(struct file_lock___463 *, struct file_lock___463 *);
	long unsigned int (*lm_owner_key)(struct file_lock___463 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___463 *);
	int (*lm_grant)(struct file_lock___463 *, int);
	bool (*lm_break)(struct file_lock___463 *);
	int (*lm_change)(struct file_lock___463 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___463 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___463 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___463 *fa_next;
	struct file___463 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___463 {
	const char *name;
	int fs_flags;
	struct dentry___463 * (*mount)(struct file_system_type___463 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___463 *);
	struct module___389 *owner;
	struct file_system_type___463 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___463 {
	struct inode___463 * (*alloc_inode)(struct super_block___463 *);
	void (*destroy_inode)(struct inode___463 *);
	void (*dirty_inode)(struct inode___463 *, int);
	int (*write_inode)(struct inode___463 *, struct writeback_control___216 *);
	int (*drop_inode)(struct inode___463 *);
	void (*evict_inode)(struct inode___463 *);
	void (*put_super)(struct super_block___463 *);
	int (*sync_fs)(struct super_block___463 *, int);
	int (*freeze_super)(struct super_block___463 *);
	int (*freeze_fs)(struct super_block___463 *);
	int (*thaw_super)(struct super_block___463 *);
	int (*unfreeze_fs)(struct super_block___463 *);
	int (*statfs)(struct dentry___463 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___463 *, int *, char *);
	void (*umount_begin)(struct super_block___463 *);
	int (*show_options)(struct seq_file___402 *, struct dentry___463 *);
	int (*show_devname)(struct seq_file___402 *, struct dentry___463 *);
	int (*show_path)(struct seq_file___402 *, struct dentry___463 *);
	int (*show_stats)(struct seq_file___402 *, struct dentry___463 *);
	ssize_t (*quota_read)(struct super_block___463 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___463 *, int, const char *, size_t, loff_t);
	struct dquot___463 ** (*get_dquots)(struct inode___463 *);
	int (*bdev_try_to_free_page)(struct super_block___463 *, struct page___464 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___463 *, struct shrink_control___196 *);
	long int (*free_cached_objects)(struct super_block___463 *, struct shrink_control___196 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___312)(struct file___463 *, wait_queue_head_t *, struct poll_table_struct___302 *);

struct poll_table_struct___302 {
	poll_queue_proc___312 _qproc;
	__poll_t _key;
};

struct seq_operations___402;

struct seq_file___402 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___402 *op;
	int poll_event;
	const struct file___463 *file;
	void *private;
};

typedef void bio_end_io_t___253(struct bio___253 *);

struct bio_integrity_payload___253;

struct bio_set___253;

struct bio___253 {
	struct bio___253 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___253 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___253 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___255 *bi_io_vec;
	struct bio_set___253 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___255 bi_inline_vecs[0];
};

struct socket_wq___89 {
	wait_queue_head_t wait;
	struct fasync_struct___463 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct sock___88;

struct proto_ops___89;

struct socket___90 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___89 *wq;
	struct file___463 *file;
	struct sock___88 *sk;
	const struct proto_ops___89 *ops;
};

typedef struct {
	struct net___119 *net;
} possible_net_t___110;

struct proto___88;

struct sock_common___88 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___88 *skc_prot;
	possible_net_t___110 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___88 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___109;

struct sk_buff_head___108 {
	struct sk_buff___109 *next;
	struct sk_buff___109 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___88;

struct xfrm_policy___23;

struct dst_entry___88;

struct net_device___108;

struct sock___88 {
	struct sock_common___88 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___108 sk_error_queue;
	struct sk_buff_head___108 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___109 *head;
		struct sk_buff___109 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___88 *sk_filter;
	union {
		struct socket_wq___89 *sk_wq;
		struct socket_wq___89 *sk_wq_raw;
	};
	struct xfrm_policy___23 *sk_policy[2];
	struct dst_entry___88 *sk_rx_dst;
	struct dst_entry___88 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___109 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___108 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___464 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___88 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___259 *sk_peer_pid;
	const struct cred___431 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___90 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___196 *sk_memcg;
	void (*sk_state_change)(struct sock___88 *);
	void (*sk_data_ready)(struct sock___88 *);
	void (*sk_write_space)(struct sock___88 *);
	void (*sk_error_report)(struct sock___88 *);
	int (*sk_backlog_rcv)(struct sock___88 *, struct sk_buff___109 *);
	struct sk_buff___109 * (*sk_validate_xmit_skb)(struct sock___88 *, struct net_device___108 *, struct sk_buff___109 *);
	void (*sk_destruct)(struct sock___88 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

typedef int (*sk_read_actor_t___88)(read_descriptor_t *, struct sk_buff___109 *, unsigned int, size_t);

struct proto_ops___89 {
	int family;
	struct module___389 *owner;
	int (*release)(struct socket___90 *);
	int (*bind)(struct socket___90 *, struct sockaddr *, int);
	int (*connect)(struct socket___90 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___90 *, struct socket___90 *);
	int (*accept)(struct socket___90 *, struct socket___90 *, int, bool);
	int (*getname)(struct socket___90 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___463 *, struct socket___90 *, struct poll_table_struct___302 *);
	int (*ioctl)(struct socket___90 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___90 *, int);
	int (*shutdown)(struct socket___90 *, int);
	int (*setsockopt)(struct socket___90 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___90 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___90 *, struct msghdr___91 *, size_t);
	int (*recvmsg)(struct socket___90 *, struct msghdr___91 *, size_t, int);
	int (*mmap)(struct file___463 *, struct socket___90 *, struct vm_area_struct___464 *);
	ssize_t (*sendpage)(struct socket___90 *, struct page___464 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___90 *, loff_t *, struct pipe_inode_info___144 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___88 *, int);
	int (*peek_len)(struct socket___90 *);
	int (*read_sock)(struct sock___88 *, read_descriptor_t *, sk_read_actor_t___88);
	int (*sendpage_locked)(struct sock___88 *, struct page___464 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___88 *, struct msghdr___91 *, size_t);
	int (*set_rcvlowat)(struct sock___88 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct sec_path___23;

struct nf_bridge_info___108;

struct sk_buff___109 {
	union {
		struct {
			struct sk_buff___109 *next;
			struct sk_buff___109 *prev;
			union {
				struct net_device___108 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___88 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___109 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path___23 *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___108 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___108;

struct netns_frags___108 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___108 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ip_ra_chain___53;

struct fib_rules_ops___88;

struct tcp_congestion_ops___23;

struct tcp_fastopen_context___23;

struct fib_notifier_ops___89;

struct netns_ipv4___108 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___53 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___88 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___88 *fibnl;
	struct sock___88 **icmp_sk;
	struct sock___88 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___88 **tcp_sk;
	struct netns_frags___108 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops___23 *tcp_congestion_control;
	struct tcp_fastopen_context___23 *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___88 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___89 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___89 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___88;

struct dst_ops___119 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___119 *);
	struct dst_entry___88 * (*check)(struct dst_entry___88 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___88 *);
	unsigned int (*mtu)(const struct dst_entry___88 *);
	u32 * (*cow_metrics)(struct dst_entry___88 *, long unsigned int);
	void (*destroy)(struct dst_entry___88 *);
	void (*ifdown)(struct dst_entry___88 *, struct net_device___108 *, int);
	struct dst_entry___88 * (*negative_advice)(struct dst_entry___88 *);
	void (*link_failure)(struct sk_buff___109 *);
	void (*update_pmtu)(struct dst_entry___88 *, struct sock___88 *, struct sk_buff___109 *, u32);
	void (*redirect)(struct dst_entry___88 *, struct sock___88 *, struct sk_buff___109 *);
	int (*local_out)(struct net___119 *, struct sock___88 *, struct sk_buff___109 *);
	struct neighbour___88 * (*neigh_lookup)(const struct dst_entry___88 *, struct sk_buff___109 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___88 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_info___29;

struct rt6_info___29;

struct fib6_table___29;

struct netns_ipv6___119 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___108 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info___29 *fib6_null_entry;
	struct rt6_info___29 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___29 *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___119 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info___29 *ip6_prohibit_entry;
	struct rt6_info___29 *ip6_blk_hole_entry;
	struct fib6_table___29 *fib6_local_tbl;
	struct fib_rules_ops___88 *fib6_rules_ops;
	struct sock___88 **icmp_sk;
	struct sock___88 *ndisc_sk;
	struct sock___88 *tcp_sk;
	struct sock___88 *igmp_sk;
	struct sock___88 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___88 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___89 *notifier_ops;
	struct fib_notifier_ops___89 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___89 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___88 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___108 {
	struct netns_frags___108 frags;
};

struct netns_xfrm___119 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___88 *nlsk;
	struct sock___88 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___119 xfrm4_dst_ops;
	struct dst_ops___119 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct net___119 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___328 *user_ns;
	struct ucounts___328 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___29 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___88 *rtnl;
	struct sock___88 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___108 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___108 ipv4;
	struct netns_ipv6___119 ipv6;
	struct netns_sctp___89 sctp;
	struct netns_nf___19 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___108 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___88 *nfnl;
	struct sock___88 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___119 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___88 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___98 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kernfs_root___457;

struct kernfs_elem_dir___457 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___457 *root;
};

struct kernfs_syscall_ops___457;

struct kernfs_root___457 {
	struct kernfs_node___458 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___457 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___457 {
	struct kernfs_node___458 *target_kn;
};

struct kernfs_ops___457;

struct kernfs_elem_attr___457 {
	const struct kernfs_ops___457 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___458 *notify_next;
};

struct kernfs_node___458 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___458 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___457 dir;
		struct kernfs_elem_symlink___457 symlink;
		struct kernfs_elem_attr___457 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___457;

struct kernfs_ops___457 {
	int (*open)(struct kernfs_open_file___457 *);
	void (*release)(struct kernfs_open_file___457 *);
	int (*seq_show)(struct seq_file___402 *, void *);
	void * (*seq_start)(struct seq_file___402 *, loff_t *);
	void * (*seq_next)(struct seq_file___402 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___402 *, void *);
	ssize_t (*read)(struct kernfs_open_file___457 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___457 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___457 *, struct vm_area_struct___464 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___457 *, struct poll_table_struct___302 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___457 {
	int (*remount_fs)(struct kernfs_root___457 *, int *, char *);
	int (*show_options)(struct seq_file___402 *, struct kernfs_root___457 *);
	int (*mkdir)(struct kernfs_node___458 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___458 *);
	int (*rename)(struct kernfs_node___458 *, struct kernfs_node___458 *, const char *);
	int (*show_path)(struct seq_file___402 *, struct kernfs_node___458 *, struct kernfs_root___457 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___457 {
	struct kernfs_node___458 *kn;
	struct file___463 *file;
	struct seq_file___402 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___451 *vm_ops;
};

struct kobj_ns_type_operations___88 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___88 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___427;

struct attribute_group___428 {
	const char *name;
	umode_t (*is_visible)(struct kobject___451 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___451 *, struct bin_attribute___427 *, int);
	struct attribute **attrs;
	struct bin_attribute___427 **bin_attrs;
};

struct bin_attribute___427 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___463 *, struct kobject___451 *, struct bin_attribute___427 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___463 *, struct kobject___451 *, struct bin_attribute___427 *, char *, loff_t, size_t);
	int (*mmap)(struct file___463 *, struct kobject___451 *, struct bin_attribute___427 *, struct vm_area_struct___464 *);
};

struct sysfs_ops___450 {
	ssize_t (*show)(struct kobject___451 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___451 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___450;

struct kset___450 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___451 kobj;
	const struct kset_uevent_ops___450 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___450 {
	void (*release)(struct kobject___451 *);
	const struct sysfs_ops___450 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___88 * (*child_ns_type)(struct kobject___451 *);
	const void * (*namespace)(struct kobject___451 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___450 {
	int (* const filter)(struct kset___450 *, struct kobject___451 *);
	const char * (* const name)(struct kset___450 *, struct kobject___451 *);
	int (* const uevent)(struct kset___450 *, struct kobject___451 *, struct kobj_uevent_env *);
};

struct kobj_attribute___441 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___451 *, struct kobj_attribute___441 *, char *);
	ssize_t (*store)(struct kobject___451 *, struct kobj_attribute___441 *, const char *, size_t);
};

struct dev_pm_ops___431 {
	int (*prepare)(struct device___431 *);
	void (*complete)(struct device___431 *);
	int (*suspend)(struct device___431 *);
	int (*resume)(struct device___431 *);
	int (*freeze)(struct device___431 *);
	int (*thaw)(struct device___431 *);
	int (*poweroff)(struct device___431 *);
	int (*restore)(struct device___431 *);
	int (*suspend_late)(struct device___431 *);
	int (*resume_early)(struct device___431 *);
	int (*freeze_late)(struct device___431 *);
	int (*thaw_early)(struct device___431 *);
	int (*poweroff_late)(struct device___431 *);
	int (*restore_early)(struct device___431 *);
	int (*suspend_noirq)(struct device___431 *);
	int (*resume_noirq)(struct device___431 *);
	int (*freeze_noirq)(struct device___431 *);
	int (*thaw_noirq)(struct device___431 *);
	int (*poweroff_noirq)(struct device___431 *);
	int (*restore_noirq)(struct device___431 *);
	int (*runtime_suspend)(struct device___431 *);
	int (*runtime_resume)(struct device___431 *);
	int (*runtime_idle)(struct device___431 *);
};

struct dev_pm_info___431 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___431 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___431;

struct bus_type___431;

struct device_driver___431;

struct dev_pm_domain___431;

struct dma_map_ops___203;

struct fwnode_handle___351;

struct class___431;

struct device___431 {
	struct device___431 *parent;
	struct device_private *p;
	struct kobject___451 kobj;
	const char *init_name;
	const struct device_type___431 *type;
	struct mutex mutex;
	struct bus_type___431 *bus;
	struct device_driver___431 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___431 power;
	struct dev_pm_domain___431 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___203 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___351 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___431 *class;
	const struct attribute_group___428 **groups;
	void (*release)(struct device___431 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___431 {
	struct dev_pm_ops___431 ops;
	void (*detach)(struct device___431 *, bool);
	int (*activate)(struct device___431 *);
	void (*sync)(struct device___431 *);
	void (*dismiss)(struct device___431 *);
};

struct bus_type___431 {
	const char *name;
	const char *dev_name;
	struct device___431 *dev_root;
	const struct attribute_group___428 **bus_groups;
	const struct attribute_group___428 **dev_groups;
	const struct attribute_group___428 **drv_groups;
	int (*match)(struct device___431 *, struct device_driver___431 *);
	int (*uevent)(struct device___431 *, struct kobj_uevent_env *);
	int (*probe)(struct device___431 *);
	int (*remove)(struct device___431 *);
	void (*shutdown)(struct device___431 *);
	int (*online)(struct device___431 *);
	int (*offline)(struct device___431 *);
	int (*suspend)(struct device___431 *, pm_message_t);
	int (*resume)(struct device___431 *);
	int (*num_vf)(struct device___431 *);
	int (*dma_configure)(struct device___431 *);
	const struct dev_pm_ops___431 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___431 {
	const char *name;
	struct bus_type___431 *bus;
	struct module___389 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___431 *);
	int (*remove)(struct device___431 *);
	void (*shutdown)(struct device___431 *);
	int (*suspend)(struct device___431 *, pm_message_t);
	int (*resume)(struct device___431 *);
	const struct attribute_group___428 **groups;
	const struct dev_pm_ops___431 *pm;
	void (*coredump)(struct device___431 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___431 {
	const char *name;
	const struct attribute_group___428 **groups;
	int (*uevent)(struct device___431 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___431 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___431 *);
	const struct dev_pm_ops___431 *pm;
};

struct class___431 {
	const char *name;
	struct module___389 *owner;
	const struct attribute_group___428 **class_groups;
	const struct attribute_group___428 **dev_groups;
	struct kobject___451 *dev_kobj;
	int (*dev_uevent)(struct device___431 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___431 *, umode_t *);
	void (*class_release)(struct class___431 *);
	void (*dev_release)(struct device___431 *);
	int (*shutdown_pre)(struct device___431 *);
	const struct kobj_ns_type_operations___88 *ns_type;
	const void * (*namespace)(struct device___431 *);
	const struct dev_pm_ops___431 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___203 {
	void * (*alloc)(struct device___431 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___431 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___431 *, struct vm_area_struct___464 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___431 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___431 *, struct page___464 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___431 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___431 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___431 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___431 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___431 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___431 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___431 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___431 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___431 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___431 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___431 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___431 *, u64);
	u64 (*get_required_mask)(struct device___431 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___351;

struct fwnode_handle___351 {
	struct fwnode_handle___351 *secondary;
	const struct fwnode_operations___351 *ops;
};

typedef void compound_page_dtor___451(struct page___464 *);

struct fwnode_reference_args___351;

struct fwnode_endpoint___351;

struct fwnode_operations___351 {
	struct fwnode_handle___351 * (*get)(struct fwnode_handle___351 *);
	void (*put)(struct fwnode_handle___351 *);
	bool (*device_is_available)(const struct fwnode_handle___351 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___351 *, const struct device___431 *);
	bool (*property_present)(const struct fwnode_handle___351 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___351 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___351 *, const char *, const char **, size_t);
	struct fwnode_handle___351 * (*get_parent)(const struct fwnode_handle___351 *);
	struct fwnode_handle___351 * (*get_next_child_node)(const struct fwnode_handle___351 *, struct fwnode_handle___351 *);
	struct fwnode_handle___351 * (*get_named_child_node)(const struct fwnode_handle___351 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___351 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___351 *);
	struct fwnode_handle___351 * (*graph_get_next_endpoint)(const struct fwnode_handle___351 *, struct fwnode_handle___351 *);
	struct fwnode_handle___351 * (*graph_get_remote_endpoint)(const struct fwnode_handle___351 *);
	struct fwnode_handle___351 * (*graph_get_port_parent)(struct fwnode_handle___351 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___351 *, struct fwnode_endpoint___351 *);
};

struct fwnode_endpoint___351 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___351 *local_fwnode;
};

struct fwnode_reference_args___351 {
	struct fwnode_handle___351 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___144;

struct pipe_buffer___144 {
	struct page___464 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___144 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___144 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___144 *, struct pipe_buffer___144 *);
	void (*release)(struct pipe_inode_info___144 *, struct pipe_buffer___144 *);
	int (*steal)(struct pipe_inode_info___144 *, struct pipe_buffer___144 *);
	union {
		bool (*get)(struct pipe_inode_info___144 *, struct pipe_buffer___144 *);
		struct {
			void (*get)(struct pipe_inode_info___144 *, struct pipe_buffer___144 *);
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
};

struct nf_bridge_info___108 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___108 = 0,
		BRNF_PROTO_8021Q___108 = 1,
		BRNF_PROTO_PPPOE___108 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___108 *physindev;
	struct net_device___108 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___108(struct sk_buff___109 **);

struct net_device_ops___108;

struct ethtool_ops___108;

struct l3mdev_ops___88;

struct ndisc_ops___58;

struct xfrmdev_ops___108;

struct tlsdev_ops___108;

struct header_ops___108;

struct inet6_dev___58;

struct netdev_rx_queue___108;

struct mini_Qdisc___100;

struct netdev_queue___108;

struct Qdisc___100;

struct rtnl_link_ops___100;

struct dcbnl_rtnl_ops___108;

struct net_device___108 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___108 *netdev_ops;
	const struct ethtool_ops___108 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___88 *l3mdev_ops;
	const struct ndisc_ops___58 *ndisc_ops;
	const struct xfrmdev_ops___108 *xfrmdev_ops;
	const struct tlsdev_ops___108 *tlsdev_ops;
	const struct header_ops___108 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___450 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___58 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___108 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___98 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___108 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___100 *miniq_ingress;
	struct netdev_queue___108 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___108 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___100 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___100 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___108 = 0,
		NETREG_REGISTERED___108 = 1,
		NETREG_UNREGISTERING___108 = 2,
		NETREG_UNREGISTERED___108 = 3,
		NETREG_RELEASED___108 = 4,
		NETREG_DUMMY___108 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___108 = 0,
		RTNL_LINK_INITIALIZING___108 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___108 *);
	struct netpoll_info *npinfo;
	possible_net_t___110 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___431 dev;
	const struct attribute_group___428 *sysfs_groups[4];
	const struct attribute_group___428 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___100 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___108 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct xfrm_state___23;

struct sec_path___23 {
	refcount_t refcnt;
	int len;
	int olen;
	struct xfrm_state___23 *xvec[6];
	struct xfrm_offload ovec[1];
};

struct ethtool_ops___108 {
	int (*get_settings)(struct net_device___108 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___108 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___108 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___108 *);
	void (*get_regs)(struct net_device___108 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___108 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___108 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___108 *);
	void (*set_msglevel)(struct net_device___108 *, u32);
	int (*nway_reset)(struct net_device___108 *);
	u32 (*get_link)(struct net_device___108 *);
	int (*get_eeprom_len)(struct net_device___108 *);
	int (*get_eeprom)(struct net_device___108 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___108 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___108 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___108 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___108 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___108 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___108 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___108 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___108 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___108 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___108 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___108 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___108 *);
	void (*complete)(struct net_device___108 *);
	u32 (*get_priv_flags)(struct net_device___108 *);
	int (*set_priv_flags)(struct net_device___108 *, u32);
	int (*get_sset_count)(struct net_device___108 *, int);
	int (*get_rxnfc)(struct net_device___108 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___108 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___108 *, struct ethtool_flash *);
	int (*reset)(struct net_device___108 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___108 *);
	u32 (*get_rxfh_indir_size)(struct net_device___108 *);
	int (*get_rxfh)(struct net_device___108 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___108 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___108 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___108 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___108 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___108 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___108 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___108 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___108 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___108 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___108 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___108 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___108 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___108 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___108 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___108 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___108 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___108 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___108 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___108 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___108 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___108 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	int (*get_fecparam)(struct net_device___108 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___108 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___108 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___108 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___108 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___108;

struct inet_frags___108 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___108 *, const void *);
	void (*destructor)(struct inet_frag_queue___108 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___108 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___109 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___109 *fragments_tail;
	struct sk_buff___109 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___108 *net;
	struct callback_head rcu;
};

struct ip_ra_chain___53 {
	struct ip_ra_chain___53 *next;
	struct sock___88 *sk;
	union {
		void (*destructor)(struct sock___88 *);
		struct sock___88 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___88;

struct fib_lookup_arg___88;

struct fib_rules_ops___88 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___88 *, struct flowi *, int, struct fib_lookup_arg___88 *);
	bool (*suppress)(struct fib_rule___88 *, struct fib_lookup_arg___88 *);
	int (*match)(struct fib_rule___88 *, struct flowi *, int);
	int (*configure)(struct fib_rule___88 *, struct sk_buff___109 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___88 *);
	int (*compare)(struct fib_rule___88 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___88 *, struct sk_buff___109 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___88 *);
	void (*flush_cache)(struct fib_rules_ops___88 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___389 *owner;
	struct net___119 *fro_net;
	struct callback_head rcu;
};

struct tcp_congestion_ops___23 {
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___88 *);
	void (*release)(struct sock___88 *);
	u32 (*ssthresh)(struct sock___88 *);
	void (*cong_avoid)(struct sock___88 *, u32, u32);
	void (*set_state)(struct sock___88 *, u8);
	void (*cwnd_event)(struct sock___88 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___88 *, u32);
	u32 (*undo_cwnd)(struct sock___88 *);
	void (*pkts_acked)(struct sock___88 *, const struct ack_sample *);
	u32 (*min_tso_segs)(struct sock___88 *);
	u32 (*sndbuf_expand)(struct sock___88 *);
	void (*cong_control)(struct sock___88 *, const struct rate_sample *);
	size_t (*get_info)(struct sock___88 *, u32, int *, union tcp_cc_info *);
	char name[16];
	struct module___389 *owner;
};

struct tcp_fastopen_context___23 {
	struct crypto_cipher___26 *tfm;
	__u8 key[16];
	struct callback_head rcu;
};

struct fib_notifier_ops___89 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___119 *);
	int (*fib_dump)(struct net___119 *, struct notifier_block *);
	struct module___389 *owner;
	struct callback_head rcu;
};

struct lwtunnel_state___13;

struct dst_entry___88 {
	struct net_device___108 *dev;
	struct dst_ops___119 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state___23 *xfrm;
	int (*input)(struct sk_buff___109 *);
	int (*output)(struct net___119 *, struct sock___88 *, struct sk_buff___109 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___13 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___88;

struct neigh_parms___88;

struct neigh_ops___88;

struct neighbour___88 {
	struct neighbour___88 *next;
	struct neigh_table___88 *tbl;
	struct neigh_parms___88 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___108 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___88 *, struct sk_buff___109 *);
	const struct neigh_ops___88 *ops;
	struct callback_head rcu;
	struct net_device___108 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct fib6_nh___29 {
	struct in6_addr nh_gw;
	struct net_device___108 *nh_dev;
	struct lwtunnel_state___13 *nh_lwtstate;
	unsigned int nh_flags;
	atomic_t nh_upper_bound;
	int nh_weight;
};

struct fib6_node___29;

struct fib6_info___29 {
	struct fib6_table___29 *fib6_table;
	struct fib6_info___29 *fib6_next;
	struct fib6_node___29 *fib6_node;
	struct list_head fib6_siblings;
	unsigned int fib6_nsiblings;
	atomic_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	struct rt6_info___29 **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
	long unsigned int last_probe;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 exception_bucket_flushed: 1;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 dst_host: 1;
	u8 fib6_destroying: 1;
	u8 unused: 2;
	struct fib6_nh___29 fib6_nh;
	struct callback_head rcu;
};

struct rt6_info___29 {
	struct dst_entry___88 dst;
	struct fib6_info___29 *from;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___58 *rt6i_idev;
	u32 rt6i_flags;
	struct rt6key rt6i_prefsrc;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct fib6_node___29 {
	struct fib6_node___29 *parent;
	struct fib6_node___29 *left;
	struct fib6_node___29 *right;
	struct fib6_info___29 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info___29 *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table___29 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node___29 tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

struct ucounts___328 {
	struct hlist_node node;
	struct user_namespace___328 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_prog_aux___101;

struct bpf_prog___98 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___101 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

typedef int (*key_restrict_link_func_t___432)(struct key___431 *, const struct key_type *, const union key_payload *, struct key___431 *);

struct key_restriction___431;

struct key___431 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___465 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___431 *restrict_link;
};

struct key_restriction___431 {
	key_restrict_link_func_t___432 check;
	struct key___431 *key;
	struct key_type *keytype;
};

struct seq_operations___402 {
	void * (*start)(struct seq_file___402 *, loff_t *);
	void (*stop)(struct seq_file___402 *, void *);
	void * (*next)(struct seq_file___402 *, void *, loff_t *);
	int (*show)(struct seq_file___402 *, void *);
};

struct pernet_operations___109 {
	struct list_head list;
	int (*init)(struct net___119 *);
	void (*exit)(struct net___119 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___108 {
	int (*ieee_getets)(struct net_device___108 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___108 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___108 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___108 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___108 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___108 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___108 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___108 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___108 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___108 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___108 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___108 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___108 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___108 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___108 *);
	u8 (*setstate)(struct net_device___108 *, u8);
	void (*getpermhwaddr)(struct net_device___108 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___108 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___108 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___108 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___108 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___108 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___108 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___108 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___108 *, int, u8 *);
	void (*setpfccfg)(struct net_device___108 *, int, u8);
	void (*getpfccfg)(struct net_device___108 *, int, u8 *);
	u8 (*setall)(struct net_device___108 *);
	u8 (*getcap)(struct net_device___108 *, int, u8 *);
	int (*getnumtcs)(struct net_device___108 *, int, u8 *);
	int (*setnumtcs)(struct net_device___108 *, int, u8);
	u8 (*getpfcstate)(struct net_device___108 *);
	void (*setpfcstate)(struct net_device___108 *, u8);
	void (*getbcncfg)(struct net_device___108 *, int, u32 *);
	void (*setbcncfg)(struct net_device___108 *, int, u32);
	void (*getbcnrp)(struct net_device___108 *, int, u8 *);
	void (*setbcnrp)(struct net_device___108 *, int, u8);
	int (*setapp)(struct net_device___108 *, u8, u16, u8);
	int (*getapp)(struct net_device___108 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___108 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___108 *, int, u8);
	u8 (*getdcbx)(struct net_device___108 *);
	u8 (*setdcbx)(struct net_device___108 *, u8);
	int (*peer_getappinfo)(struct net_device___108 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___108 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___108 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___108 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___108 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___108 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___312 {
	refcount_t count;
	struct ns_common___29 ns;
	struct user_namespace___328 *user_ns;
	struct ucounts___328 *ucounts;
	struct css_set___312 *root_cset;
};

struct bpf_map___313;

struct bpf_map_ops___312 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___313 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___313 *, struct file___463 *);
	void (*map_free)(struct bpf_map___313 *);
	int (*map_get_next_key)(struct bpf_map___313 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___313 *);
	void * (*map_lookup_elem)(struct bpf_map___313 *, void *);
	int (*map_update_elem)(struct bpf_map___313 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___313 *, void *);
	int (*map_push_elem)(struct bpf_map___313 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___313 *, void *);
	int (*map_peek_elem)(struct bpf_map___313 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___313 *, struct file___463 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___313 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___313 *, void *, struct seq_file___402 *);
	int (*map_check_btf)(const struct bpf_map___313 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___313 {
	const struct bpf_map_ops___312 *ops;
	struct bpf_map___313 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___431 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___108;

struct bpf_map_dev_ops___108 {
	int (*map_get_next_key)(struct bpf_offloaded_map___108 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___108 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___108 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___108 *, void *);
};

struct bpf_offloaded_map___108 {
	struct bpf_map___313 map;
	struct net_device___108 *netdev;
	const struct bpf_map_dev_ops___108 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___98 {
	int (*test_run)(struct bpf_prog___98 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___98 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___98 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___98 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___98 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___98 *, u32 *);
};

struct bpf_prog_offload_ops___98 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___98 *);
	int (*translate)(struct bpf_prog___98 *);
	void (*destroy)(struct bpf_prog___98 *);
};

struct bpf_prog_offload___98 {
	struct bpf_prog___98 *prog;
	struct net_device___108 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___98 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___101 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___98 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___98 *ops;
	struct bpf_map___313 **used_maps;
	struct bpf_prog___98 *prog;
	struct user_struct___431 *user;
	u64 load_time;
	struct bpf_map___313 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___98 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___98 {
	struct bpf_prog___98 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___98 {
	struct callback_head rcu;
	struct bpf_prog_array_item___98 items[0];
};

struct cgroup_bpf___98 {
	struct bpf_prog_array___98 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___98 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___313;

typedef void (*kthread_work_func_t___313)(struct kthread_work___313 *);

struct kthread_worker___313;

struct kthread_work___313 {
	struct list_head node;
	kthread_work_func_t___313 func;
	struct kthread_worker___313 *worker;
	int canceling;
};

struct kthread_worker___313 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___465 *task;
	struct kthread_work___313 *current_work;
};

struct kthread_delayed_work___312 {
	struct kthread_work___313 work;
	struct timer_list timer;
};

struct psi_group___312 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___313 *poll_kworker;
	struct kthread_delayed_work___312 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___312;

struct cgroup_rstat_cpu___312;

struct cgroup___312 {
	struct cgroup_subsys_state___312 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___458 *kn;
	struct cgroup_file___312 procs_file;
	struct cgroup_file___312 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___312 *subsys[13];
	struct cgroup_root___312 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___312 *dom_cgrp;
	struct cgroup_rstat_cpu___312 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___98 bpf;
	atomic_t congestion_count;
	struct cgroup___312 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___312 psi;
	int ancestor_ids[0];
};

struct cftype___312;

struct cgroup_subsys___312 {
	struct cgroup_subsys_state___312 * (*css_alloc)(struct cgroup_subsys_state___312 *);
	int (*css_online)(struct cgroup_subsys_state___312 *);
	void (*css_offline)(struct cgroup_subsys_state___312 *);
	void (*css_released)(struct cgroup_subsys_state___312 *);
	void (*css_free)(struct cgroup_subsys_state___312 *);
	void (*css_reset)(struct cgroup_subsys_state___312 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___312 *, int);
	int (*css_extra_stat_show)(struct seq_file___402 *, struct cgroup_subsys_state___312 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___465 *);
	void (*cancel_fork)(struct task_struct___465 *);
	void (*fork)(struct task_struct___465 *);
	void (*exit)(struct task_struct___465 *);
	void (*free)(struct task_struct___465 *);
	void (*bind)(struct cgroup_subsys_state___312 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___312 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___312 *dfl_cftypes;
	struct cftype___312 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___312 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___312 *updated_children;
	struct cgroup___312 *updated_next;
};

struct cgroup_root___312 {
	struct kernfs_root___457 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___312 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___312 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___312 *ss;
	struct list_head node;
	struct kernfs_ops___457 *kf_ops;
	int (*open)(struct kernfs_open_file___457 *);
	void (*release)(struct kernfs_open_file___457 *);
	u64 (*read_u64)(struct cgroup_subsys_state___312 *, struct cftype___312 *);
	s64 (*read_s64)(struct cgroup_subsys_state___312 *, struct cftype___312 *);
	int (*seq_show)(struct seq_file___402 *, void *);
	void * (*seq_start)(struct seq_file___402 *, loff_t *);
	void * (*seq_next)(struct seq_file___402 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___402 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___312 *, struct cftype___312 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___312 *, struct cftype___312 *, s64);
	ssize_t (*write)(struct kernfs_open_file___457 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___457 *, struct poll_table_struct___302 *);
};

struct xdp_rxq_info___108 {
	struct net_device___108 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___108 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___108 *dev_rx;
};

struct netlink_skb_parms___21 {
	struct scm_creds creds;
	__u32 portid;
	__u32 dst_group;
	__u32 flags;
	struct sock___88 *sk;
	bool nsid_is_set;
	int nsid;
};

struct netlink_callback___110 {
	struct sk_buff___109 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___110 *);
	int (*dump)(struct sk_buff___109 *, struct netlink_callback___110 *);
	int (*done)(struct netlink_callback___110 *);
	void *data;
	struct module___389 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___108 {
	int (*create)(struct sk_buff___109 *, struct net_device___108 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___109 *, unsigned char *);
	int (*cache)(const struct neighbour___88 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___108 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___108 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___108 *, int);
	int poll_owner;
	struct net_device___108 *dev;
	struct sk_buff___109 *gro_list;
	struct sk_buff___109 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___108 {
	struct net_device___108 *dev;
	struct Qdisc___100 *qdisc;
	struct Qdisc___100 *qdisc_sleeping;
	struct kobject___451 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___108 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___100 {
	struct sk_buff___109 *head;
	struct sk_buff___109 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___100;

struct Qdisc___100 {
	int (*enqueue)(struct sk_buff___109 *, struct Qdisc___100 *, struct sk_buff___109 **);
	struct sk_buff___109 * (*dequeue)(struct Qdisc___100 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___100 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___108 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___108 gso_skb;
	struct qdisc_skb_head___100 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___100 *next_sched;
	struct sk_buff_head___108 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___108 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___451 kobj;
	struct net_device___108 *dev;
	long: 64;
	struct xdp_rxq_info___108 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___108)(struct net_device___108 *, struct sk_buff___109 *, struct net_device___108 *);

struct netdev_bpf___108 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___98 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___98 *prog;
			const struct bpf_prog_offload_ops___98 *ops;
		} verifier;
		struct {
			struct bpf_prog___98 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___108 *offmap;
		};
		struct {
			struct xdp_umem___3 *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___108 {
	int (*xdo_dev_state_add)(struct xfrm_state___23 *);
	void (*xdo_dev_state_delete)(struct xfrm_state___23 *);
	void (*xdo_dev_state_free)(struct xfrm_state___23 *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___109 *, struct xfrm_state___23 *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state___23 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct xfrm_state_offload___23 {
	struct net_device___108 *dev;
	long unsigned int offload_handle;
	unsigned int num_exthdrs;
	u8 flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct xfrm_replay___23;

struct xfrm_type___23;

struct xfrm_mode___23;

struct xfrm_type_offload___23;

struct xfrm_state___23 {
	possible_net_t___110 xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	refcount_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
		u32 output_mark;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	const char *geniv;
	struct xfrm_encap_tmpl *encap;
	xfrm_address_t *coaddr;
	struct xfrm_state___23 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	const struct xfrm_replay___23 *repl;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct tasklet_hrtimer mtimer;
	struct xfrm_state_offload___23 xso;
	long int saved_tmo;
	long unsigned int lastused;
	struct page_frag___464 xfrag;
	const struct xfrm_type___23 *type;
	struct xfrm_mode___23 *inner_mode;
	struct xfrm_mode___23 *inner_mode_iaf;
	struct xfrm_mode___23 *outer_mode;
	const struct xfrm_type_offload___23 *type_offload;
	struct xfrm_sec_ctx___2 *security;
	void *data;
	u32 output_mark_mask;
	u32 if_id;
};

struct tlsdev_ops___108 {
	int (*tls_dev_add)(struct net_device___108 *, struct sock___88 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___108 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___108 *, struct sock___88 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___108 {
	int (*ndo_init)(struct net_device___108 *);
	void (*ndo_uninit)(struct net_device___108 *);
	int (*ndo_open)(struct net_device___108 *);
	int (*ndo_stop)(struct net_device___108 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___109 *, struct net_device___108 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___109 *, struct net_device___108 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___108 *, struct sk_buff___109 *, struct net_device___108 *, select_queue_fallback_t___108);
	void (*ndo_change_rx_flags)(struct net_device___108 *, int);
	void (*ndo_set_rx_mode)(struct net_device___108 *);
	int (*ndo_set_mac_address)(struct net_device___108 *, void *);
	int (*ndo_validate_addr)(struct net_device___108 *);
	int (*ndo_do_ioctl)(struct net_device___108 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___108 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___108 *, int);
	int (*ndo_neigh_setup)(struct net_device___108 *, struct neigh_parms___88 *);
	void (*ndo_tx_timeout)(struct net_device___108 *);
	void (*ndo_get_stats64)(struct net_device___108 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___108 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___108 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___108 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___108 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___108 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___108 *);
	int (*ndo_netpoll_setup)(struct net_device___108 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___108 *);
	int (*ndo_set_vf_mac)(struct net_device___108 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___108 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___108 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___108 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___108 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___108 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___108 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___108 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___108 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___108 *, int, struct sk_buff___109 *);
	int (*ndo_set_vf_guid)(struct net_device___108 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___108 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___108 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___108 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___108 *, const struct sk_buff___109 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___108 *, struct net_device___108 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___108 *, struct net_device___108 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___108 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___108 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___108 *, struct neighbour___88 *);
	void (*ndo_neigh_destroy)(struct net_device___108 *, struct neighbour___88 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___108 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___108 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___108 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___109 *, struct netlink_callback___110 *, struct net_device___108 *, struct net_device___108 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___108 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___108 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___109 *, u32, u32, struct net_device___108 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___108 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___108 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___108 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___108 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___108 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___108 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___108 *, struct net_device___108 *);
	void (*ndo_dfwd_del_station)(struct net_device___108 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___108 *);
	int (*ndo_set_tx_maxrate)(struct net_device___108 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___108 *);
	int (*ndo_change_proto_down)(struct net_device___108 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___108 *, struct sk_buff___109 *);
	void (*ndo_set_rx_headroom)(struct net_device___108 *, int);
	int (*ndo_bpf)(struct net_device___108 *, struct netdev_bpf___108 *);
	int (*ndo_xdp_xmit)(struct net_device___108 *, int, struct xdp_frame___108 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___108 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___108 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___88 {
	possible_net_t___110 net;
	struct net_device___108 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___88 *);
	void (*neigh_cleanup)(struct neighbour___88 *);
	struct neigh_table___88 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___88 {
	u32 (*l3mdev_fib_table)(const struct net_device___108 *);
	struct sk_buff___109 * (*l3mdev_l3_rcv)(struct net_device___108 *, struct sk_buff___109 *, u16);
	struct sk_buff___109 * (*l3mdev_l3_out)(struct net_device___108 *, struct sock___88 *, struct sk_buff___109 *, u16);
	struct dst_entry___88 * (*l3mdev_link_scope_lookup)(const struct net_device___108 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct ndisc_ops___58 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___108 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___108 *, struct neighbour___88 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___108 *, u8, struct neighbour___88 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___108 *, struct sk_buff___109 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___119 *, struct net_device___108 *, const struct prefix_info *, struct inet6_dev___58 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___58;

struct ifacaddr6___29;

struct inet6_dev___58 {
	struct net_device___108 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___58 *mc_list;
	struct ifmcaddr6___58 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___29 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	u8 rndid[8];
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___88 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
};

struct tcf_proto___100;

struct mini_Qdisc___100 {
	struct tcf_proto___100 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___100 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___108 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___119 *, struct net_device___108 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___108 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___108 *, struct list_head *);
	size_t (*get_size)(const struct net_device___108 *);
	int (*fill_info)(struct sk_buff___109 *, const struct net_device___108 *);
	size_t (*get_xstats_size)(const struct net_device___108 *);
	int (*fill_xstats)(struct sk_buff___109 *, const struct net_device___108 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___108 *, struct net_device___108 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___108 *, const struct net_device___108 *);
	int (*fill_slave_info)(struct sk_buff___109 *, const struct net_device___108 *, const struct net_device___108 *);
	struct net___119 * (*get_link_net)(const struct net_device___108 *);
	size_t (*get_linkxstats_size)(const struct net_device___108 *, int);
	int (*fill_linkxstats)(struct sk_buff___109 *, const struct net_device___108 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct netdev_notifier_info___13 {
	struct net_device___108 *dev;
	struct netlink_ext_ack *extack;
};

struct softnet_data___108 {
	struct list_head poll_list;
	struct sk_buff_head___108 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___108 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___100 *output_queue;
	struct Qdisc___100 **output_queue_tailp;
	struct sk_buff___109 *completion_queue;
	struct sk_buff_head___108 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___108 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___108 input_pkt_queue;
	struct napi_struct___108 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bdi_writeback_congested___253 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___253 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___253 {
	struct bio___253 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___255 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___255 bip_inline_vecs[0];
};

struct bio_set___253 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___253 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___196 {
	struct mem_cgroup___196 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___196 {
	struct lruvec___464 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___196 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___196 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct kernel_param_ops___389 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___389 *);
	int (*get)(char *, const struct kernel_param___389 *);
	void (*free)(void *);
};

struct kparam_array___389;

struct kernel_param___389 {
	const char *name;
	struct module___389 *mod;
	const struct kernel_param_ops___389 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___389 *arr;
	};
};

struct kparam_array___389 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___389 *ops;
	void *elem;
};

struct module_attribute___389 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___389 *, struct module_kobject___389 *, char *);
	ssize_t (*store)(struct module_attribute___389 *, struct module_kobject___389 *, const char *, size_t);
	void (*setup)(struct module___389 *, const char *);
	int (*test)(struct module___389 *);
	void (*free)(struct module___389 *);
};

struct trace_event_class___148;

struct trace_event_call___148 {
	struct list_head list;
	struct trace_event_class___148 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___13 event;
	char *print_fmt;
	struct event_filter *filter;
	void *mod;
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___98 *prog_array;
	int (*perf_perm)(struct trace_event_call___148 *, struct perf_event___157 *);
};

struct gnet_dump___100 {
	spinlock_t *lock;
	struct sk_buff___109 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct nl_info___4 {
	struct nlmsghdr *nlh;
	struct net___119 *nl_net;
	u32 portid;
	bool skip_notify;
};

struct Qdisc_class_ops___100;

struct Qdisc_ops___100 {
	struct Qdisc_ops___100 *next;
	const struct Qdisc_class_ops___100 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___109 *, struct Qdisc___100 *, struct sk_buff___109 **);
	struct sk_buff___109 * (*dequeue)(struct Qdisc___100 *);
	struct sk_buff___109 * (*peek)(struct Qdisc___100 *);
	int (*init)(struct Qdisc___100 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___100 *);
	void (*destroy)(struct Qdisc___100 *);
	int (*change)(struct Qdisc___100 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___100 *);
	int (*change_tx_queue_len)(struct Qdisc___100 *, unsigned int);
	int (*dump)(struct Qdisc___100 *, struct sk_buff___109 *);
	int (*dump_stats)(struct Qdisc___100 *, struct gnet_dump___100 *);
	void (*ingress_block_set)(struct Qdisc___100 *, u32);
	void (*egress_block_set)(struct Qdisc___100 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___100 *);
	u32 (*egress_block_get)(struct Qdisc___100 *);
	struct module___389 *owner;
};

struct tcf_block___100;

struct Qdisc_class_ops___100 {
	unsigned int flags;
	struct netdev_queue___108 * (*select_queue)(struct Qdisc___100 *, struct tcmsg *);
	int (*graft)(struct Qdisc___100 *, long unsigned int, struct Qdisc___100 *, struct Qdisc___100 **, struct netlink_ext_ack *);
	struct Qdisc___100 * (*leaf)(struct Qdisc___100 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___100 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___100 *, u32);
	int (*change)(struct Qdisc___100 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___100 *, long unsigned int);
	void (*walk)(struct Qdisc___100 *, struct qdisc_walker *);
	struct tcf_block___100 * (*tcf_block)(struct Qdisc___100 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___100 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___100 *, long unsigned int);
	int (*dump)(struct Qdisc___100 *, long unsigned int, struct sk_buff___109 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___100 *, long unsigned int, struct gnet_dump___100 *);
};

struct tcf_chain___100;

struct tcf_block___100 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___119 *net;
	struct Qdisc___100 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___100 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___100;

struct tcf_proto_ops___100;

struct tcf_proto___100 {
	struct tcf_proto___100 *next;
	void *root;
	int (*classify)(struct sk_buff___109 *, const struct tcf_proto___100 *, struct tcf_result___100 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___100 *ops;
	struct tcf_chain___100 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___100 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___100 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___100 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___109 *, const struct tcf_proto___100 *, struct tcf_result___100 *);
	int (*init)(struct tcf_proto___100 *);
	void (*destroy)(struct tcf_proto___100 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___100 *, u32);
	void (*put)(struct tcf_proto___100 *, void *);
	int (*change)(struct net___119 *, struct sk_buff___109 *, struct tcf_proto___100 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___100 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___100 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___100 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___119 *, struct tcf_chain___100 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___119 *, struct tcf_proto___100 *, void *, struct sk_buff___109 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___109 *, struct net___119 *, void *);
	struct module___389 *owner;
	int flags;
};

struct tcf_chain___100 {
	struct mutex filter_chain_lock;
	struct tcf_proto___100 *filter_chain;
	struct list_head list;
	struct tcf_block___100 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___100 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___88 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___98 *prog;
};

struct bpf_redirect_info___98 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___313 *map;
	struct bpf_map___313 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___88;

struct neigh_hash_table___88;

struct neigh_table___88 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___108 *, __u32 *);
	bool (*key_eq)(const struct neighbour___88 *, const void *);
	int (*constructor)(struct neighbour___88 *);
	int (*pconstructor)(struct pneigh_entry___88 *);
	void (*pdestructor)(struct pneigh_entry___88 *);
	void (*proxy_redo)(struct sk_buff___109 *);
	char *id;
	struct neigh_parms___88 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___108 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___88 *nht;
	struct pneigh_entry___88 **phash_buckets;
};

struct neigh_ops___88 {
	int family;
	void (*solicit)(struct neighbour___88 *, struct sk_buff___109 *);
	void (*error_report)(struct neighbour___88 *, struct sk_buff___109 *);
	int (*output)(struct neighbour___88 *, struct sk_buff___109 *);
	int (*connected_output)(struct neighbour___88 *, struct sk_buff___109 *);
};

struct pneigh_entry___88 {
	struct pneigh_entry___88 *next;
	possible_net_t___110 net;
	struct net_device___108 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___88 {
	struct neighbour___88 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___13 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___119 *, struct sock___88 *, struct sk_buff___109 *);
	int (*orig_input)(struct sk_buff___109 *);
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	__u8 data[0];
};

struct fib_rule___88 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___88 *ctarget;
	struct net___119 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___88 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___88 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___70;

struct timewait_sock_ops___66;

struct proto___88 {
	void (*close)(struct sock___88 *, long int);
	int (*pre_connect)(struct sock___88 *, struct sockaddr *, int);
	int (*connect)(struct sock___88 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___88 *, int);
	struct sock___88 * (*accept)(struct sock___88 *, int, int *, bool);
	int (*ioctl)(struct sock___88 *, int, long unsigned int);
	int (*init)(struct sock___88 *);
	void (*destroy)(struct sock___88 *);
	void (*shutdown)(struct sock___88 *, int);
	int (*setsockopt)(struct sock___88 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___88 *, int, int, char *, int *);
	void (*keepalive)(struct sock___88 *, int);
	int (*sendmsg)(struct sock___88 *, struct msghdr___91 *, size_t);
	int (*recvmsg)(struct sock___88 *, struct msghdr___91 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___88 *, struct page___464 *, int, size_t, int);
	int (*bind)(struct sock___88 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___88 *, struct sk_buff___109 *);
	void (*release_cb)(struct sock___88 *);
	int (*hash)(struct sock___88 *);
	void (*unhash)(struct sock___88 *);
	void (*rehash)(struct sock___88 *);
	int (*get_port)(struct sock___88 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___88 *);
	bool (*stream_memory_read)(const struct sock___88 *);
	void (*enter_memory_pressure)(struct sock___88 *);
	void (*leave_memory_pressure)(struct sock___88 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___70 *rsk_prot;
	struct timewait_sock_ops___66 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___389 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___88 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct xfrm_policy_queue___23 {
	struct sk_buff_head___108 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___23 {
	possible_net_t___110 xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	refcount_t refcnt;
	struct timer_list timer;
	atomic_t genid;
	u32 priority;
	u32 index;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___23 polq;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx___2 *security;
	struct xfrm_tmpl xfrm_vec[6];
	struct callback_head rcu;
	u32 if_id;
};

struct request_sock___71;

struct request_sock_ops___70 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___88 *, struct request_sock___71 *);
	void (*send_ack)(const struct sock___88 *, struct sk_buff___109 *, struct request_sock___71 *);
	void (*send_reset)(const struct sock___88 *, struct sk_buff___109 *);
	void (*destructor)(struct request_sock___71 *);
	void (*syn_ack_timeout)(const struct request_sock___71 *);
};

struct timewait_sock_ops___66 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___88 *, struct sock___88 *, void *);
	void (*twsk_destructor)(struct sock___88 *);
};

struct request_sock___71 {
	struct sock_common___88 __req_common;
	struct request_sock___71 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___70 *rsk_ops;
	struct sock___88 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct inet_cork___24 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___88 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
	__u16 gso_size;
	u64 transmit_time;
};

struct inet_cork_full___24 {
	struct inet_cork___24 base;
	struct flowi fl;
};

struct ipv6_pinfo___24;

struct inet_sock___24 {
	struct sock___88 sk;
	struct ipv6_pinfo___24 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	__be16 inet_sport;
	__u16 inet_id;
	struct ip_options_rcu *inet_opt;
	int rx_dst_ifindex;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 bind_address_no_port: 1;
	__u8 defer_connect: 1;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___24 cork;
};

struct ipv6_fl_socklist___23;

struct ipv6_pinfo___24 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
			__u16 recvfragsize: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 repflow: 1;
	__u16 pmtudisc: 3;
	__u16 padding: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u16 autoflowlabel: 1;
	__u16 autoflowlabel_set: 1;
	__u8 min_hopcount;
	__u8 tclass;
	__be32 rcv_flowinfo;
	__u32 dst_cookie;
	__u32 rx_dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___23 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___109 *pktoptions;
	struct sk_buff___109 *rxpmtu;
	struct inet6_cork cork;
};

struct ip6_flowlabel___23;

struct ipv6_fl_socklist___23 {
	struct ipv6_fl_socklist___23 *next;
	struct ip6_flowlabel___23 *fl;
	struct callback_head rcu;
};

struct inet6_ifaddr___4 {
	struct in6_addr addr;
	__u32 prefix_len;
	__u32 rt_priority;
	__u32 valid_lft;
	__u32 prefered_lft;
	refcount_t refcnt;
	spinlock_t lock;
	int state;
	__u32 flags;
	__u8 dad_probes;
	__u8 stable_privacy_retry;
	__u16 scope;
	__u64 dad_nonce;
	long unsigned int cstamp;
	long unsigned int tstamp;
	struct delayed_work dad_work;
	struct inet6_dev___58 *idev;
	struct fib6_info___29 *rt;
	struct hlist_node addr_lst;
	struct list_head if_list;
	struct list_head tmp_list;
	struct inet6_ifaddr___4 *ifpub;
	int regen_count;
	bool tokenized;
	struct callback_head rcu;
	struct in6_addr peer_addr;
};

struct ifmcaddr6___58 {
	struct in6_addr mca_addr;
	struct inet6_dev___58 *idev;
	struct ifmcaddr6___58 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___29 {
	struct in6_addr aca_addr;
	struct fib6_info___29 *aca_rt;
	struct ifacaddr6___29 *aca_next;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct rd_msg {
	struct icmp6hdr icmph;
	struct in6_addr target;
	struct in6_addr dest;
	__u8 opt[0];
};

struct ip6_ra_chain___58 {
	struct ip6_ra_chain___58 *next;
	struct sock___88 *sk;
	int sel;
	void (*destructor)(struct sock___88 *);
};

struct ip6_flowlabel___23 {
	struct ip6_flowlabel___23 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___259 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___119 *fl_net;
};

struct fib_dump_filter___5 {
	u32 table_id;
	bool filter_set;
	bool dump_all_families;
	bool dump_routes;
	bool dump_exceptions;
	unsigned char protocol;
	unsigned char rt_type;
	unsigned int flags;
	struct net_device___108 *dev;
};

struct in6_rtmsg {
	struct in6_addr rtmsg_dst;
	struct in6_addr rtmsg_src;
	struct in6_addr rtmsg_gateway;
	__u32 rtmsg_type;
	__u16 rtmsg_dst_len;
	__u16 rtmsg_src_len;
	__u32 rtmsg_metric;
	long unsigned int rtmsg_info;
	__u32 rtmsg_flags;
	int rtmsg_ifindex;
};

struct fib6_config___2 {
	u32 fc_table;
	u32 fc_metric;
	int fc_dst_len;
	int fc_src_len;
	int fc_ifindex;
	u32 fc_flags;
	u32 fc_protocol;
	u16 fc_type;
	u16 fc_delete_all_nh: 1;
	u16 __unused: 15;
	struct in6_addr fc_dst;
	struct in6_addr fc_src;
	struct in6_addr fc_prefsrc;
	struct in6_addr fc_gateway;
	long unsigned int fc_expires;
	struct nlattr *fc_mx;
	int fc_mx_len;
	int fc_mp_len;
	struct nlattr *fc_mp;
	struct nl_info___4 fc_nlinfo;
	struct nlattr *fc_encap;
	u16 fc_encap_type;
};

struct fib6_gc_args {
	int timeout;
	int more;
};

struct rt6_exception {
	struct hlist_node hlist;
	struct rt6_info___29 *rt6i;
	long unsigned int stamp;
	struct callback_head rcu;
};

struct route_info {
	__u8 type;
	__u8 length;
	__u8 prefix_len;
	__u8 reserved_l: 3;
	__u8 route_pref: 2;
	__u8 reserved_h: 3;
	__be32 lifetime;
	__u8 prefix[0];
};

struct ipv6_stub___18 {
	int (*ipv6_sock_mc_join)(struct sock___88 *, int, const struct in6_addr *);
	int (*ipv6_sock_mc_drop)(struct sock___88 *, int, const struct in6_addr *);
	int (*ipv6_dst_lookup)(struct net___119 *, struct sock___88 *, struct dst_entry___88 **, struct flowi6 *);
	struct fib6_table___29 * (*fib6_get_table)(struct net___119 *, u32);
	struct fib6_info___29 * (*fib6_lookup)(struct net___119 *, int, struct flowi6 *, int);
	struct fib6_info___29 * (*fib6_table_lookup)(struct net___119 *, struct fib6_table___29 *, int, struct flowi6 *, int);
	struct fib6_info___29 * (*fib6_multipath_select)(const struct net___119 *, struct fib6_info___29 *, struct flowi6 *, int, const struct sk_buff___109 *, int);
	u32 (*ip6_mtu_from_fib6)(struct fib6_info___29 *, struct in6_addr *, struct in6_addr *);
	void (*udpv6_encap_enable)();
	void (*ndisc_send_na)(struct net_device___108 *, const struct in6_addr *, const struct in6_addr *, bool, bool, bool, bool);
	struct neigh_table___88 *nd_tbl;
};

struct ipv6_bpf_stub___18 {
	int (*inet6_bind)(struct sock___88 *, struct sockaddr *, int, bool, bool);
	struct sock___88 * (*udp6_lib_lookup)(struct net___119 *, const struct in6_addr *, __be16, const struct in6_addr *, __be16, int, int, struct udp_table *, struct sk_buff___109 *);
};

struct rt6_rtnl_dump_arg {
	struct sk_buff___109 *skb;
	struct netlink_callback___110 *cb;
	struct net___119 *net;
	struct fib_dump_filter___5 filter;
};

struct ip_tunnel_encap_ops___11 {
	size_t (*encap_hlen)(struct ip_tunnel_encap *);
	int (*build_header)(struct sk_buff___109 *, struct ip_tunnel_encap *, u8 *, struct flowi4 *);
};

struct hw_port_info___8 {
	struct net_device___108 *lower_dev;
	u32 port_id;
};

struct metadata_dst___8 {
	struct dst_entry___88 dst;
	enum metadata_type type;
	union {
		struct ip_tunnel_info tun_info;
		struct hw_port_info___8 port_info;
	} u;
};

struct xfrm_replay___23 {
	void (*advance)(struct xfrm_state___23 *, __be32);
	int (*check)(struct xfrm_state___23 *, struct sk_buff___109 *, __be32);
	int (*recheck)(struct xfrm_state___23 *, struct sk_buff___109 *, __be32);
	void (*notify)(struct xfrm_state___23 *, int);
	int (*overflow)(struct xfrm_state___23 *, struct sk_buff___109 *);
};

struct xfrm_type___23 {
	char *description;
	struct module___389 *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___23 *);
	void (*destructor)(struct xfrm_state___23 *);
	int (*input)(struct xfrm_state___23 *, struct sk_buff___109 *);
	int (*output)(struct xfrm_state___23 *, struct sk_buff___109 *);
	int (*reject)(struct xfrm_state___23 *, struct sk_buff___109 *, const struct flowi *);
	int (*hdr_offset)(struct xfrm_state___23 *, struct sk_buff___109 *, u8 **);
	u32 (*get_mtu)(struct xfrm_state___23 *, int);
};

struct xfrm_state_afinfo___23;

struct xfrm_mode___23 {
	int (*input2)(struct xfrm_state___23 *, struct sk_buff___109 *);
	int (*input)(struct xfrm_state___23 *, struct sk_buff___109 *);
	int (*output2)(struct xfrm_state___23 *, struct sk_buff___109 *);
	int (*output)(struct xfrm_state___23 *, struct sk_buff___109 *);
	struct sk_buff___109 * (*gso_segment)(struct xfrm_state___23 *, struct sk_buff___109 *, netdev_features_t);
	void (*xmit)(struct xfrm_state___23 *, struct sk_buff___109 *);
	struct xfrm_state_afinfo___23 *afinfo;
	struct module___389 *owner;
	unsigned int encap;
	int flags;
};

struct xfrm_type_offload___23 {
	char *description;
	struct module___389 *owner;
	u8 proto;
	void (*encap)(struct xfrm_state___23 *, struct sk_buff___109 *);
	int (*input_tail)(struct xfrm_state___23 *, struct sk_buff___109 *);
	int (*xmit)(struct xfrm_state___23 *, struct sk_buff___109 *, netdev_features_t);
};

struct xfrm_state_afinfo___23 {
	unsigned int family;
	unsigned int proto;
	__be16 eth_proto;
	struct module___389 *owner;
	const struct xfrm_type___23 *type_map[256];
	const struct xfrm_type_offload___23 *type_offload_map[256];
	struct xfrm_mode___23 *mode_map[5];
	int (*init_flags)(struct xfrm_state___23 *);
	void (*init_tempsel)(struct xfrm_selector *, const struct flowi *);
	void (*init_temprop)(struct xfrm_state___23 *, const struct xfrm_tmpl *, const xfrm_address_t *, const xfrm_address_t *);
	int (*tmpl_sort)(struct xfrm_tmpl **, struct xfrm_tmpl **, int);
	int (*state_sort)(struct xfrm_state___23 **, struct xfrm_state___23 **, int);
	int (*output)(struct net___119 *, struct sock___88 *, struct sk_buff___109 *);
	int (*output_finish)(struct sock___88 *, struct sk_buff___109 *);
	int (*extract_input)(struct xfrm_state___23 *, struct sk_buff___109 *);
	int (*extract_output)(struct xfrm_state___23 *, struct sk_buff___109 *);
	int (*transport_finish)(struct sk_buff___109 *, int);
	void (*local_error)(struct sk_buff___109 *, u32);
};

struct netevent_redirect {
	struct dst_entry___88 *old;
	struct dst_entry___88 *new;
	struct neighbour___88 *neigh;
	const void *daddr;
};

struct node___231 {
	struct device___431 dev;
};

struct perf_cpu_context___157;

struct pmu___157 {
	struct list_head entry;
	struct module___389 *module;
	struct device___431 *dev;
	const struct attribute_group___428 **attr_groups;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___157 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___157 *);
	void (*pmu_disable)(struct pmu___157 *);
	int (*event_init)(struct perf_event___157 *);
	void (*event_mapped)(struct perf_event___157 *, struct mm_struct___464 *);
	void (*event_unmapped)(struct perf_event___157 *, struct mm_struct___464 *);
	int (*add)(struct perf_event___157 *, int);
	void (*del)(struct perf_event___157 *, int);
	void (*start)(struct perf_event___157 *, int);
	void (*stop)(struct perf_event___157 *, int);
	void (*read)(struct perf_event___157 *);
	void (*start_txn)(struct pmu___157 *, unsigned int);
	int (*commit_txn)(struct pmu___157 *);
	void (*cancel_txn)(struct pmu___157 *);
	int (*event_idx)(struct perf_event___157 *);
	void (*sched_task)(struct perf_event_context___157 *, bool);
	size_t task_ctx_size;
	void * (*setup_aux)(int, void **, int, bool);
	void (*free_aux)(void *);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___157 *);
	int (*filter_match)(struct perf_event___157 *);
	int (*check_period)(struct perf_event___157 *, u64);
};

struct perf_cpu_context___157 {
	struct perf_event_context___157 ctx;
	struct perf_event_context___157 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___157 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
};

struct perf_cgroup___157 {
	struct cgroup_subsys_state___312 css;
	struct perf_cgroup_info *info;
};

struct trace_event_class___148 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___148 *, enum trace_reg, void *);
	int (*define_fields)(struct trace_event_call___148 *);
	struct list_head * (*get_fields)(struct trace_event_call___148 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___148 *);
};

struct trace_event_file___64;

struct trace_event_buffer___56 {
	struct ring_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___64 *trace_file;
	void *entry;
	long unsigned int flags;
	int pc;
};

struct trace_event_file___64 {
	struct list_head list;
	struct trace_event_call___148 *event_call;
	struct event_filter *filter;
	struct dentry___463 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_fib6_table_lookup {
	struct trace_entry ent;
	u32 tb_id;
	int err;
	int oif;
	int iif;
	__u8 tos;
	__u8 scope;
	__u8 flags;
	__u8 src[16];
	__u8 dst[16];
	u16 sport;
	u16 dport;
	u8 proto;
	u8 rt_type;
	u32 __data_loc_name;
	__u8 gw[16];
	char __data[0];
};

struct trace_event_data_offsets_fib6_table_lookup {
	u32 name;
};

enum rt6_nud_state {
	RT6_NUD_FAIL_HARD = 4294967293,
	RT6_NUD_FAIL_PROBE = 4294967294,
	RT6_NUD_FAIL_DO_RR = 4294967295,
	RT6_NUD_SUCCEED = 1,
};

struct __rt6_probe_work {
	struct work_struct work;
	struct in6_addr target;
	struct net_device___108 *dev;
};

struct ip6rd_flowi {
	struct flowi6 fl6;
	struct in6_addr gateway;
};

struct arg_dev_net_ip {
	struct net_device___108 *dev;
	struct net___119 *net;
	struct in6_addr *addr;
};

struct arg_netdev_event {
	const struct net_device___108 *dev;
	union {
		unsigned int nh_flags;
		long unsigned int event;
	};
};

struct rt6_mtu_change_arg {
	struct net_device___108 *dev;
	unsigned int mtu;
};

struct rt6_nh {
	struct fib6_info___29 *fib6_info;
	struct fib6_config___2 r_cfg;
	struct list_head next;
};

struct fib_notifier_info___6 {
	struct net___119 *net;
	int family;
	struct netlink_ext_ack *extack;
};

enum fib6_walk_state {
	FWS_L = 0,
	FWS_R = 1,
	FWS_C = 2,
	FWS_U = 3,
};

struct fib6_walker {
	struct list_head lh;
	struct fib6_node___29 *root;
	struct fib6_node___29 *node;
	struct fib6_info___29 *leaf;
	enum fib6_walk_state state;
	unsigned int skip;
	unsigned int count;
	unsigned int skip_in_node;
	int (*func)(struct fib6_walker *);
	void *args;
};

struct fib6_entry_notifier_info {
	struct fib_notifier_info___6 info;
	struct fib6_info___29 *rt;
};

struct ipv6_route_iter {
	struct seq_net_private___8 p;
	struct fib6_walker w;
	loff_t skip;
	struct fib6_table___29 *tbl;
	int sernum;
};

struct fib6_cleaner {
	struct fib6_walker w;
	struct net___119 *net;
	int (*func)(struct fib6_info___29 *, void *);
	int sernum;
	void *arg;
};

enum {
	FIB6_NO_SERNUM_CHANGE = 0,
};

struct fib6_dump_arg {
	struct net___119 *net;
	struct notifier_block *nb;
};

struct lookup_args {
	int offset;
	const struct in6_addr *addr;
};

struct ipv6_mreq {
	struct in6_addr ipv6mr_multiaddr;
	int ipv6mr_ifindex;
};

struct in6_flowlabel_req {
	struct in6_addr flr_dst;
	__be32 flr_label;
	__u8 flr_action;
	__u8 flr_share;
	__u16 flr_flags;
	__u16 flr_expires;
	__u16 flr_linger;
	__u32 __flr_pad;
};

struct ip6_mtuinfo {
	struct sockaddr_in6 ip6m_addr;
	__u32 ip6m_mtu;
};

struct module___390;

struct file___464;

struct kiocb___464;

struct iov_iter___231;

struct poll_table_struct___303;

struct vm_area_struct___465;

struct inode___464;

struct file_lock___464;

struct page___465;

struct pipe_inode_info___145;

struct seq_file___403;

struct file_operations___464 {
	struct module___390 *owner;
	loff_t (*llseek)(struct file___464 *, loff_t, int);
	ssize_t (*read)(struct file___464 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___464 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___464 *, struct iov_iter___231 *);
	ssize_t (*write_iter)(struct kiocb___464 *, struct iov_iter___231 *);
	int (*iopoll)(struct kiocb___464 *, bool);
	int (*iterate)(struct file___464 *, struct dir_context *);
	int (*iterate_shared)(struct file___464 *, struct dir_context *);
	__poll_t (*poll)(struct file___464 *, struct poll_table_struct___303 *);
	long int (*unlocked_ioctl)(struct file___464 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___464 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___464 *, struct vm_area_struct___465 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___464 *, struct file___464 *);
	int (*flush)(struct file___464 *, fl_owner_t);
	int (*release)(struct inode___464 *, struct file___464 *);
	int (*fsync)(struct file___464 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___464 *, int);
	int (*lock)(struct file___464 *, int, struct file_lock___464 *);
	ssize_t (*sendpage)(struct file___464 *, struct page___465 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___464 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___464 *, int, struct file_lock___464 *);
	ssize_t (*splice_write)(struct pipe_inode_info___145 *, struct file___464 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___464 *, loff_t *, struct pipe_inode_info___145 *, size_t, unsigned int);
	int (*setlease)(struct file___464 *, long int, struct file_lock___464 **, void **);
	long int (*fallocate)(struct file___464 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___403 *, struct file___464 *);
	ssize_t (*copy_file_range)(struct file___464 *, loff_t, struct file___464 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___464 *, loff_t, struct file___464 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___464 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___465 {
	u64 seqnum;
	struct vm_area_struct___465 *vmas[4];
};

struct page_frag___465 {
	struct page___465 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___465;

struct mem_cgroup___197;

struct cred___432;

struct nsproxy___359;

struct signal_struct___339;

struct bio_list___254;

struct backing_dev_info___254;

struct css_set___313;

struct vm_struct___368;

struct task_struct___466 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___466 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___465 *mm;
	struct mm_struct___465 *active_mm;
	struct vmacache___465 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___466 *real_parent;
	struct task_struct___466 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___466 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___197 *active_memcg;
	long int rh_reserved2;
	struct pid___259 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___259 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___259 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___432 *ptracer_cred;
	const struct cred___432 *real_cred;
	const struct cred___432 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___359 *nsproxy;
	struct signal_struct___339 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___466 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___254 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___254 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___313 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___145 *splice_pipe;
	struct page_frag___465 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___197 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___466 *oom_reaper_list;
	struct vm_struct___368 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___157 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rw_semaphore___466 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___466 *owner;
};

struct key___432;

struct ucounts___329;

struct user_namespace___329 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___329 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___29 ns;
	long unsigned int flags;
	struct key___432 *persistent_keyring_register;
	struct rw_semaphore___466 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___329 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___465 *pgtable_t___465;

struct address_space___464;

struct dev_pagemap___452;

struct page___465 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___464 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___465 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___465 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___465 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___452 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___197 *mem_cgroup;
};

struct pglist_data___465;

struct lruvec___465 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___465 *pgdat;
};

struct zone___465 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___465 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___465 {
	struct zone___465 *zone;
	int zone_idx;
};

struct zonelist___465 {
	struct zoneref___465 _zonerefs[25];
};

struct pglist_data___465 {
	struct zone___465 node_zones[3];
	struct zonelist___465 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___466 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___466 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___465 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___466 {
	void *stack;
	struct task_struct___466 *task;
	long int status;
};

struct blocking_notifier_head___465 {
	struct rw_semaphore___466 rwsem;
	struct notifier_block *head;
};

struct dentry___464;

struct path___465 {
	struct vfsmount *mnt;
	struct dentry___464 *dentry;
};

struct file___464 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___465 f_path;
	struct inode___464 *f_inode;
	const struct file_operations___464 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___259 f_owner;
	const struct cred___432 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___464 *f_mapping;
	errseq_t f_wb_err;
};

struct user_struct___432;

struct cred___432 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___432 *session_keyring;
	struct key___432 *process_keyring;
	struct key___432 *thread_keyring;
	struct key___432 *request_key_auth;
	void *security;
	struct user_struct___432 *user;
	struct user_namespace___329 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___458;

struct kernfs_elem_dir___458 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___458 *root;
};

struct kernfs_node___459;

struct kernfs_syscall_ops___458;

struct kernfs_root___458 {
	struct kernfs_node___459 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___458 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___458 {
	struct kernfs_node___459 *target_kn;
};

struct kernfs_ops___458;

struct kernfs_elem_attr___458 {
	const struct kernfs_ops___458 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___459 *notify_next;
};

struct kernfs_node___459 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___459 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___458 dir;
		struct kernfs_elem_symlink___458 symlink;
		struct kernfs_elem_attr___458 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___458;

struct kernfs_ops___458 {
	int (*open)(struct kernfs_open_file___458 *);
	void (*release)(struct kernfs_open_file___458 *);
	int (*seq_show)(struct seq_file___403 *, void *);
	void * (*seq_start)(struct seq_file___403 *, loff_t *);
	void * (*seq_next)(struct seq_file___403 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___403 *, void *);
	ssize_t (*read)(struct kernfs_open_file___458 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___458 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___458 *, struct vm_area_struct___465 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___458 *, struct poll_table_struct___303 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___458 {
	int (*remount_fs)(struct kernfs_root___458 *, int *, char *);
	int (*show_options)(struct seq_file___403 *, struct kernfs_root___458 *);
	int (*mkdir)(struct kernfs_node___459 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___459 *);
	int (*rename)(struct kernfs_node___459 *, struct kernfs_node___459 *, const char *);
	int (*show_path)(struct seq_file___403 *, struct kernfs_node___459 *, struct kernfs_root___458 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___403;

struct seq_file___403 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___403 *op;
	int poll_event;
	const struct file___464 *file;
	void *private;
};

struct vm_operations_struct___452;

struct kernfs_open_file___458 {
	struct kernfs_node___459 *kn;
	struct file___464 *file;
	struct seq_file___403 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___452 *vm_ops;
};

struct vm_fault___452;

struct vm_operations_struct___452 {
	void (*open)(struct vm_area_struct___465 *);
	void (*close)(struct vm_area_struct___465 *);
	int (*split)(struct vm_area_struct___465 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___465 *);
	vm_fault_t (*fault)(struct vm_fault___452 *);
	vm_fault_t (*huge_fault)(struct vm_fault___452 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___452 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___465 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___452 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___452 *);
	int (*access)(struct vm_area_struct___465 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___465 *);
	int (*set_policy)(struct vm_area_struct___465 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___465 *, long unsigned int);
	struct page___465 * (*find_special_page)(struct vm_area_struct___465 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___313)(struct file___464 *, wait_queue_head_t *, struct poll_table_struct___303 *);

struct poll_table_struct___303 {
	poll_queue_proc___313 _qproc;
	__poll_t _key;
};

struct vm_area_struct___465 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___465 *vm_next;
	struct vm_area_struct___465 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___465 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___452 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___464 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sock___89;

struct kobj_ns_type_operations___89 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___89 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct net___120;

typedef struct {
	struct net___120 *net;
} possible_net_t___111;

struct proto___89;

struct sock_common___89 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___89 *skc_prot;
	possible_net_t___111 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___89 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___110;

struct sk_buff_head___109 {
	struct sk_buff___110 *next;
	struct sk_buff___110 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___89;

struct socket_wq___90;

struct dst_entry___89;

struct socket___91;

struct net_device___109;

struct sock___89 {
	struct sock_common___89 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___109 sk_error_queue;
	struct sk_buff_head___109 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___110 *head;
		struct sk_buff___110 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___89 *sk_filter;
	union {
		struct socket_wq___90 *sk_wq;
		struct socket_wq___90 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___89 *sk_rx_dst;
	struct dst_entry___89 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___110 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___109 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___465 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___89 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___259 *sk_peer_pid;
	const struct cred___432 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___91 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___197 *sk_memcg;
	void (*sk_state_change)(struct sock___89 *);
	void (*sk_data_ready)(struct sock___89 *);
	void (*sk_write_space)(struct sock___89 *);
	void (*sk_error_report)(struct sock___89 *);
	int (*sk_backlog_rcv)(struct sock___89 *, struct sk_buff___110 *);
	struct sk_buff___110 * (*sk_validate_xmit_skb)(struct sock___89 *, struct net_device___109 *, struct sk_buff___110 *);
	void (*sk_destruct)(struct sock___89 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kobject___452;

struct bin_attribute___428;

struct attribute_group___429 {
	const char *name;
	umode_t (*is_visible)(struct kobject___452 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___452 *, struct bin_attribute___428 *, int);
	struct attribute **attrs;
	struct bin_attribute___428 **bin_attrs;
};

struct kset___451;

struct kobj_type___451;

struct kobject___452 {
	const char *name;
	struct list_head entry;
	struct kobject___452 *parent;
	struct kset___451 *kset;
	struct kobj_type___451 *ktype;
	struct kernfs_node___459 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___428 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___464 *, struct kobject___452 *, struct bin_attribute___428 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___464 *, struct kobject___452 *, struct bin_attribute___428 *, char *, loff_t, size_t);
	int (*mmap)(struct file___464 *, struct kobject___452 *, struct bin_attribute___428 *, struct vm_area_struct___465 *);
};

struct sysfs_ops___451 {
	ssize_t (*show)(struct kobject___452 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___452 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___451;

struct kset___451 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___452 kobj;
	const struct kset_uevent_ops___451 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___451 {
	void (*release)(struct kobject___452 *);
	const struct sysfs_ops___451 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___89 * (*child_ns_type)(struct kobject___452 *);
	const void * (*namespace)(struct kobject___452 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___451 {
	int (* const filter)(struct kset___451 *, struct kobject___452 *);
	const char * (* const name)(struct kset___451 *, struct kobject___452 *);
	int (* const uevent)(struct kset___451 *, struct kobject___452 *, struct kobj_uevent_env *);
};

struct kobj_attribute___442 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___452 *, struct kobj_attribute___442 *, char *);
	ssize_t (*store)(struct kobject___452 *, struct kobj_attribute___442 *, const char *, size_t);
};

struct kernel_param___390;

struct kernel_param_ops___390 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___390 *);
	int (*get)(char *, const struct kernel_param___390 *);
	void (*free)(void *);
};

struct kparam_array___390;

struct kernel_param___390 {
	const char *name;
	struct module___390 *mod;
	const struct kernel_param_ops___390 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___390 *arr;
	};
};

struct kparam_array___390 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___390 *ops;
	void *elem;
};

struct module_kobject___390 {
	struct kobject___452 kobj;
	struct module___390 *mod;
	struct kobject___452 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___390 {
	struct module___390 *mod;
	struct latch_tree_node node;
};

struct module_layout___390 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___390 mtn;
};

struct module_attribute___390;

struct module___390 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___390 mkobj;
	struct module_attribute___390 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___452 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___390 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___390 core_layout;
	struct module_layout___390 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___390 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___390 *, struct module_kobject___390 *, char *);
	ssize_t (*store)(struct module_attribute___390 *, struct module_kobject___390 *, const char *, size_t);
	void (*setup)(struct module___390 *, const char *);
	int (*test)(struct module___390 *);
	void (*free)(struct module___390 *);
};

struct cgroup___313;

struct cgroup_subsys___313;

struct cgroup_subsys_state___313 {
	struct cgroup___313 *cgroup;
	struct cgroup_subsys___313 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___313 *parent;
};

struct cgroup_file___313 {
	struct kernfs_node___459 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___197;

struct mem_cgroup___197 {
	struct cgroup_subsys_state___313 css;
	struct mem_cgroup_id___13 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___313 events_file;
	struct cgroup_file___313 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___466 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___197 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct user_struct___432 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___432 *uid_keyring;
	struct key___432 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___465;

struct mm_struct___465 {
	struct {
		struct vm_area_struct___465 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___464 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___466 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___465 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___466 *owner;
		struct user_namespace___329 *user_ns;
		struct file___464 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___465 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___313;

struct nsproxy___359 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net___120 *net_ns;
	struct cgroup_namespace___313 *cgroup_ns;
};

struct signal_struct___339 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___466 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___466 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___259 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___259 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___465 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___259 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___254;

struct bio_list___254 {
	struct bio___254 *head;
	struct bio___254 *tail;
};

struct bdi_writeback_congested___254;

struct bdi_writeback___254 {
	struct backing_dev_info___254 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___254 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___313 *memcg_css;
	struct cgroup_subsys_state___313 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___432;

struct backing_dev_info___254 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___254 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___432 *dev;
	struct device___432 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___464 *debug_dir;
	struct dentry___464 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___313 {
	struct cgroup_subsys_state___313 *subsys[13];
	refcount_t refcount;
	struct css_set___313 *dom_cset;
	struct cgroup___313 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___313 *mg_src_cgrp;
	struct cgroup___313 *mg_dst_cgrp;
	struct css_set___313 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___464;

struct pipe_buffer___145;

struct pipe_inode_info___145 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___465 *tmp_page;
	struct fasync_struct___464 *fasync_readers;
	struct fasync_struct___464 *fasync_writers;
	struct pipe_buffer___145 *bufs;
	struct user_struct___432 *user;
};

struct vm_struct___368 {
	struct vm_struct___368 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___465 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___351 {
	struct task_struct___466 task;
	long unsigned int stack[8192];
};

struct address_space_operations___464;

struct address_space___464 {
	struct inode___464 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___466 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___464 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___452)(struct vm_area_struct___465 *, long unsigned int, const struct page___465 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___452)(struct page___465 *, void *);

struct dev_pagemap___452 {
	dev_page_fault_t___452 page_fault;
	dev_page_free_t___452 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___432 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___465 {
	struct task_struct___466 *task;
	struct core_thread___465 *next;
};

struct core_state___465 {
	atomic_t nr_threads;
	struct core_thread___465 dumper;
	struct completion startup;
};

struct vm_fault___452 {
	struct vm_area_struct___465 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___465 *cow_page;
	struct mem_cgroup___197 *memcg;
	struct page___465 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___465 prealloc_pte;
};

struct bio_vec___256 {
	struct page___465 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___231 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___256 *bvec;
		struct pipe_inode_info___145 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct msghdr___92 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___231 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___464 *msg_iocb;
};

struct kiocb___464 {
	struct file___464 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___464 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dentry_operations___464;

struct super_block___464;

struct dentry___464 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___464 *d_parent;
	struct qstr d_name;
	struct inode___464 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___464 *d_op;
	struct super_block___464 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___464;

struct block_device___464;

struct inode___464 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___464 *i_op;
	struct super_block___464 *i_sb;
	struct address_space___464 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___466 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___254 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___464 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___464 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___145 *i_pipe;
		struct block_device___464 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___464 {
	int (*d_revalidate)(struct dentry___464 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___464 *, unsigned int);
	int (*d_hash)(const struct dentry___464 *, struct qstr *);
	int (*d_compare)(const struct dentry___464 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___464 *);
	int (*d_init)(struct dentry___464 *);
	void (*d_release)(struct dentry___464 *);
	void (*d_prune)(struct dentry___464 *);
	void (*d_iput)(struct dentry___464 *, struct inode___464 *);
	char * (*d_dname)(struct dentry___464 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___465 *);
	int (*d_manage)(const struct path___465 *, bool);
	struct dentry___464 * (*d_real)(struct dentry___464 *, const struct inode___464 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___464;

struct mem_dqinfo___464 {
	struct quota_format_type___464 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___464;

struct quota_info___464 {
	unsigned int flags;
	struct rw_semaphore___466 dqio_sem;
	struct inode___464 *files[3];
	struct mem_dqinfo___464 info[3];
	const struct quota_format_ops___464 *ops[3];
};

struct rcuwait___464 {
	struct task_struct___466 *task;
};

struct percpu_rw_semaphore___464 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___466 rw_sem;
	struct rcuwait___464 writer;
	int readers_block;
};

struct sb_writers___464 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___464 rw_sem[3];
};

struct shrink_control___197;

struct shrinker___197 {
	long unsigned int (*count_objects)(struct shrinker___197 *, struct shrink_control___197 *);
	long unsigned int (*scan_objects)(struct shrinker___197 *, struct shrink_control___197 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___464;

struct super_operations___464;

struct dquot_operations___464;

struct quotactl_ops___464;

struct super_block___464 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___464 *s_type;
	const struct super_operations___464 *s_op;
	const struct dquot_operations___464 *dq_op;
	const struct quotactl_ops___464 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___464 *s_root;
	struct rw_semaphore___466 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___464 *s_bdev;
	struct backing_dev_info___254 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___464 s_dquot;
	struct sb_writers___464 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___464 *s_d_op;
	int cleancache_poolid;
	struct shrinker___197 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___329 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___197 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___197 *memcg;
};

struct iattr___464 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___464 *ia_file;
};

struct dquot___464 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___464 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___464 {
	int qf_fmt_id;
	const struct quota_format_ops___464 *qf_ops;
	struct module___390 *qf_owner;
	struct quota_format_type___464 *qf_next;
};

struct quota_format_ops___464 {
	int (*check_quota_file)(struct super_block___464 *, int);
	int (*read_file_info)(struct super_block___464 *, int);
	int (*write_file_info)(struct super_block___464 *, int);
	int (*free_file_info)(struct super_block___464 *, int);
	int (*read_dqblk)(struct dquot___464 *);
	int (*commit_dqblk)(struct dquot___464 *);
	int (*release_dqblk)(struct dquot___464 *);
	int (*get_next_id)(struct super_block___464 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___464 {
	int (*write_dquot)(struct dquot___464 *);
	struct dquot___464 * (*alloc_dquot)(struct super_block___464 *, int);
	void (*destroy_dquot)(struct dquot___464 *);
	int (*acquire_dquot)(struct dquot___464 *);
	int (*release_dquot)(struct dquot___464 *);
	int (*mark_dirty)(struct dquot___464 *);
	int (*write_info)(struct super_block___464 *, int);
	qsize_t * (*get_reserved_space)(struct inode___464 *);
	int (*get_projid)(struct inode___464 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___464 *, qsize_t *);
	int (*get_next_id)(struct super_block___464 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___464 {
	int (*quota_on)(struct super_block___464 *, int, int, const struct path___465 *);
	int (*quota_off)(struct super_block___464 *, int);
	int (*quota_enable)(struct super_block___464 *, unsigned int);
	int (*quota_disable)(struct super_block___464 *, unsigned int);
	int (*quota_sync)(struct super_block___464 *, int);
	int (*set_info)(struct super_block___464 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___464 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___464 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___464 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___464 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___464 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___217;

struct address_space_operations___464 {
	int (*writepage)(struct page___465 *, struct writeback_control___217 *);
	int (*readpage)(struct file___464 *, struct page___465 *);
	int (*writepages)(struct address_space___464 *, struct writeback_control___217 *);
	int (*set_page_dirty)(struct page___465 *);
	int (*readpages)(struct file___464 *, struct address_space___464 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___464 *, struct address_space___464 *, loff_t, unsigned int, unsigned int, struct page___465 **, void **);
	int (*write_end)(struct file___464 *, struct address_space___464 *, loff_t, unsigned int, unsigned int, struct page___465 *, void *);
	sector_t (*bmap)(struct address_space___464 *, sector_t);
	void (*invalidatepage)(struct page___465 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___465 *, gfp_t);
	void (*freepage)(struct page___465 *);
	ssize_t (*direct_IO)(struct kiocb___464 *, struct iov_iter___231 *);
	int (*migratepage)(struct address_space___464 *, struct page___465 *, struct page___465 *, enum migrate_mode);
	bool (*isolate_page)(struct page___465 *, isolate_mode_t);
	void (*putback_page)(struct page___465 *);
	int (*launder_page)(struct page___465 *);
	int (*is_partially_uptodate)(struct page___465 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___465 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___464 *, struct page___465 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___464 *, sector_t *);
	void (*swap_deactivate)(struct file___464 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___217 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___254 *wb;
	struct inode___464 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___464 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___464 *bd_inode;
	struct super_block___464 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___464 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___254 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___464 {
	struct dentry___464 * (*lookup)(struct inode___464 *, struct dentry___464 *, unsigned int);
	const char * (*get_link)(struct dentry___464 *, struct inode___464 *, struct delayed_call *);
	int (*permission)(struct inode___464 *, int);
	struct posix_acl * (*get_acl)(struct inode___464 *, int);
	int (*readlink)(struct dentry___464 *, char *, int);
	int (*create)(struct inode___464 *, struct dentry___464 *, umode_t, bool);
	int (*link)(struct dentry___464 *, struct inode___464 *, struct dentry___464 *);
	int (*unlink)(struct inode___464 *, struct dentry___464 *);
	int (*symlink)(struct inode___464 *, struct dentry___464 *, const char *);
	int (*mkdir)(struct inode___464 *, struct dentry___464 *, umode_t);
	int (*rmdir)(struct inode___464 *, struct dentry___464 *);
	int (*mknod)(struct inode___464 *, struct dentry___464 *, umode_t, dev_t);
	int (*rename)(struct inode___464 *, struct dentry___464 *, struct inode___464 *, struct dentry___464 *, unsigned int);
	int (*setattr)(struct dentry___464 *, struct iattr___464 *);
	int (*getattr)(const struct path___465 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___464 *, char *, size_t);
	int (*fiemap)(struct inode___464 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___464 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___464 *, struct dentry___464 *, struct file___464 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___464 *, struct dentry___464 *, umode_t);
	int (*set_acl)(struct inode___464 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___464 {
	void (*fl_copy_lock)(struct file_lock___464 *, struct file_lock___464 *);
	void (*fl_release_private)(struct file_lock___464 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___464;

struct file_lock___464 {
	struct file_lock___464 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___464 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___464 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___464 *fl_ops;
	const struct lock_manager_operations___464 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___464 {
	int (*lm_compare_owner)(struct file_lock___464 *, struct file_lock___464 *);
	long unsigned int (*lm_owner_key)(struct file_lock___464 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___464 *);
	int (*lm_grant)(struct file_lock___464 *, int);
	bool (*lm_break)(struct file_lock___464 *);
	int (*lm_change)(struct file_lock___464 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___464 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___464 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___464 *fa_next;
	struct file___464 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___464 {
	const char *name;
	int fs_flags;
	struct dentry___464 * (*mount)(struct file_system_type___464 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___464 *);
	struct module___390 *owner;
	struct file_system_type___464 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___464 {
	struct inode___464 * (*alloc_inode)(struct super_block___464 *);
	void (*destroy_inode)(struct inode___464 *);
	void (*dirty_inode)(struct inode___464 *, int);
	int (*write_inode)(struct inode___464 *, struct writeback_control___217 *);
	int (*drop_inode)(struct inode___464 *);
	void (*evict_inode)(struct inode___464 *);
	void (*put_super)(struct super_block___464 *);
	int (*sync_fs)(struct super_block___464 *, int);
	int (*freeze_super)(struct super_block___464 *);
	int (*freeze_fs)(struct super_block___464 *);
	int (*thaw_super)(struct super_block___464 *);
	int (*unfreeze_fs)(struct super_block___464 *);
	int (*statfs)(struct dentry___464 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___464 *, int *, char *);
	void (*umount_begin)(struct super_block___464 *);
	int (*show_options)(struct seq_file___403 *, struct dentry___464 *);
	int (*show_devname)(struct seq_file___403 *, struct dentry___464 *);
	int (*show_path)(struct seq_file___403 *, struct dentry___464 *);
	int (*show_stats)(struct seq_file___403 *, struct dentry___464 *);
	ssize_t (*quota_read)(struct super_block___464 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___464 *, int, const char *, size_t, loff_t);
	struct dquot___464 ** (*get_dquots)(struct inode___464 *);
	int (*bdev_try_to_free_page)(struct super_block___464 *, struct page___465 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___464 *, struct shrink_control___197 *);
	long int (*free_cached_objects)(struct super_block___464 *, struct shrink_control___197 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___254(struct bio___254 *);

struct bio_integrity_payload___254;

struct bio_set___254;

struct bio___254 {
	struct bio___254 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___254 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___254 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___256 *bi_io_vec;
	struct bio_set___254 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___256 bi_inline_vecs[0];
};

struct socket_wq___90 {
	wait_queue_head_t wait;
	struct fasync_struct___464 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___90;

struct socket___91 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___90 *wq;
	struct file___464 *file;
	struct sock___89 *sk;
	const struct proto_ops___90 *ops;
};

typedef int (*sk_read_actor_t___89)(read_descriptor_t *, struct sk_buff___110 *, unsigned int, size_t);

struct proto_ops___90 {
	int family;
	struct module___390 *owner;
	int (*release)(struct socket___91 *);
	int (*bind)(struct socket___91 *, struct sockaddr *, int);
	int (*connect)(struct socket___91 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___91 *, struct socket___91 *);
	int (*accept)(struct socket___91 *, struct socket___91 *, int, bool);
	int (*getname)(struct socket___91 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___464 *, struct socket___91 *, struct poll_table_struct___303 *);
	int (*ioctl)(struct socket___91 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___91 *, int);
	int (*shutdown)(struct socket___91 *, int);
	int (*setsockopt)(struct socket___91 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___91 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___91 *, struct msghdr___92 *, size_t);
	int (*recvmsg)(struct socket___91 *, struct msghdr___92 *, size_t, int);
	int (*mmap)(struct file___464 *, struct socket___91 *, struct vm_area_struct___465 *);
	ssize_t (*sendpage)(struct socket___91 *, struct page___465 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___91 *, loff_t *, struct pipe_inode_info___145 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___89 *, int);
	int (*peek_len)(struct socket___91 *);
	int (*read_sock)(struct sock___89 *, read_descriptor_t *, sk_read_actor_t___89);
	int (*sendpage_locked)(struct sock___89 *, struct page___465 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___89 *, struct msghdr___92 *, size_t);
	int (*set_rcvlowat)(struct sock___89 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct nf_bridge_info___109;

struct sk_buff___110 {
	union {
		struct {
			struct sk_buff___110 *next;
			struct sk_buff___110 *prev;
			union {
				struct net_device___109 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___89 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___110 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___109 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___109;

struct netns_frags___109 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___109 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ip_ra_chain___54;

struct fib_rules_ops___89;

struct fib_notifier_ops___90;

struct netns_ipv4___109 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___54 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___89 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___89 *fibnl;
	struct sock___89 **icmp_sk;
	struct sock___89 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___89 **tcp_sk;
	struct netns_frags___109 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___89 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___90 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___90 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___89;

struct dst_ops___120 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___120 *);
	struct dst_entry___89 * (*check)(struct dst_entry___89 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___89 *);
	unsigned int (*mtu)(const struct dst_entry___89 *);
	u32 * (*cow_metrics)(struct dst_entry___89 *, long unsigned int);
	void (*destroy)(struct dst_entry___89 *);
	void (*ifdown)(struct dst_entry___89 *, struct net_device___109 *, int);
	struct dst_entry___89 * (*negative_advice)(struct dst_entry___89 *);
	void (*link_failure)(struct sk_buff___110 *);
	void (*update_pmtu)(struct dst_entry___89 *, struct sock___89 *, struct sk_buff___110 *, u32);
	void (*redirect)(struct dst_entry___89 *, struct sock___89 *, struct sk_buff___110 *);
	int (*local_out)(struct net___120 *, struct sock___89 *, struct sk_buff___110 *);
	struct neighbour___89 * (*neigh_lookup)(const struct dst_entry___89 *, struct sk_buff___110 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___89 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_info___30;

struct rt6_info___30;

struct fib6_table___30;

struct netns_ipv6___120 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___109 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info___30 *fib6_null_entry;
	struct rt6_info___30 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___30 *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___120 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info___30 *ip6_prohibit_entry;
	struct rt6_info___30 *ip6_blk_hole_entry;
	struct fib6_table___30 *fib6_local_tbl;
	struct fib_rules_ops___89 *fib6_rules_ops;
	struct sock___89 **icmp_sk;
	struct sock___89 *ndisc_sk;
	struct sock___89 *tcp_sk;
	struct sock___89 *igmp_sk;
	struct sock___89 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___89 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___90 *notifier_ops;
	struct fib_notifier_ops___90 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___90 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___89 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct nf_hook_entries___19;

struct netns_nf___20 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_queue_handler *queue_handler;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header *nf_log_dir_header;
	struct nf_hook_entries___19 *hooks_ipv4[5];
	struct nf_hook_entries___19 *hooks_ipv6[5];
	struct nf_hook_entries___19 *hooks_arp[3];
	struct nf_hook_entries___19 *hooks_bridge[5];
	bool defrag_ipv4;
	bool defrag_ipv6;
};

struct netns_nf_frag___109 {
	struct netns_frags___109 frags;
};

struct netns_xfrm___120 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___89 *nlsk;
	struct sock___89 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___120 xfrm4_dst_ops;
	struct dst_ops___120 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___99;

struct net___120 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___329 *user_ns;
	struct ucounts___329 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___29 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___89 *rtnl;
	struct sock___89 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___109 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___109 ipv4;
	struct netns_ipv6___120 ipv6;
	struct netns_sctp___90 sctp;
	struct netns_nf___20 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___109 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___89 *nfnl;
	struct sock___89 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___120 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___89 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___99 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___432 {
	int (*prepare)(struct device___432 *);
	void (*complete)(struct device___432 *);
	int (*suspend)(struct device___432 *);
	int (*resume)(struct device___432 *);
	int (*freeze)(struct device___432 *);
	int (*thaw)(struct device___432 *);
	int (*poweroff)(struct device___432 *);
	int (*restore)(struct device___432 *);
	int (*suspend_late)(struct device___432 *);
	int (*resume_early)(struct device___432 *);
	int (*freeze_late)(struct device___432 *);
	int (*thaw_early)(struct device___432 *);
	int (*poweroff_late)(struct device___432 *);
	int (*restore_early)(struct device___432 *);
	int (*suspend_noirq)(struct device___432 *);
	int (*resume_noirq)(struct device___432 *);
	int (*freeze_noirq)(struct device___432 *);
	int (*thaw_noirq)(struct device___432 *);
	int (*poweroff_noirq)(struct device___432 *);
	int (*restore_noirq)(struct device___432 *);
	int (*runtime_suspend)(struct device___432 *);
	int (*runtime_resume)(struct device___432 *);
	int (*runtime_idle)(struct device___432 *);
};

struct dev_pm_info___432 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___432 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___432;

struct bus_type___432;

struct device_driver___432;

struct dev_pm_domain___432;

struct dma_map_ops___204;

struct fwnode_handle___352;

struct class___432;

struct device___432 {
	struct device___432 *parent;
	struct device_private *p;
	struct kobject___452 kobj;
	const char *init_name;
	const struct device_type___432 *type;
	struct mutex mutex;
	struct bus_type___432 *bus;
	struct device_driver___432 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___432 power;
	struct dev_pm_domain___432 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___204 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___352 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___432 *class;
	const struct attribute_group___429 **groups;
	void (*release)(struct device___432 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___432 {
	struct dev_pm_ops___432 ops;
	void (*detach)(struct device___432 *, bool);
	int (*activate)(struct device___432 *);
	void (*sync)(struct device___432 *);
	void (*dismiss)(struct device___432 *);
};

struct bus_type___432 {
	const char *name;
	const char *dev_name;
	struct device___432 *dev_root;
	const struct attribute_group___429 **bus_groups;
	const struct attribute_group___429 **dev_groups;
	const struct attribute_group___429 **drv_groups;
	int (*match)(struct device___432 *, struct device_driver___432 *);
	int (*uevent)(struct device___432 *, struct kobj_uevent_env *);
	int (*probe)(struct device___432 *);
	int (*remove)(struct device___432 *);
	void (*shutdown)(struct device___432 *);
	int (*online)(struct device___432 *);
	int (*offline)(struct device___432 *);
	int (*suspend)(struct device___432 *, pm_message_t);
	int (*resume)(struct device___432 *);
	int (*num_vf)(struct device___432 *);
	int (*dma_configure)(struct device___432 *);
	const struct dev_pm_ops___432 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___432 {
	const char *name;
	struct bus_type___432 *bus;
	struct module___390 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___432 *);
	int (*remove)(struct device___432 *);
	void (*shutdown)(struct device___432 *);
	int (*suspend)(struct device___432 *, pm_message_t);
	int (*resume)(struct device___432 *);
	const struct attribute_group___429 **groups;
	const struct dev_pm_ops___432 *pm;
	void (*coredump)(struct device___432 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___432 {
	const char *name;
	const struct attribute_group___429 **groups;
	int (*uevent)(struct device___432 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___432 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___432 *);
	const struct dev_pm_ops___432 *pm;
};

struct class___432 {
	const char *name;
	struct module___390 *owner;
	const struct attribute_group___429 **class_groups;
	const struct attribute_group___429 **dev_groups;
	struct kobject___452 *dev_kobj;
	int (*dev_uevent)(struct device___432 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___432 *, umode_t *);
	void (*class_release)(struct class___432 *);
	void (*dev_release)(struct device___432 *);
	int (*shutdown_pre)(struct device___432 *);
	const struct kobj_ns_type_operations___89 *ns_type;
	const void * (*namespace)(struct device___432 *);
	const struct dev_pm_ops___432 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___204 {
	void * (*alloc)(struct device___432 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___432 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___432 *, struct vm_area_struct___465 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___432 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___432 *, struct page___465 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___432 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___432 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___432 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___432 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___432 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___432 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___432 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___432 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___432 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___432 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___432 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___432 *, u64);
	u64 (*get_required_mask)(struct device___432 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___352;

struct fwnode_handle___352 {
	struct fwnode_handle___352 *secondary;
	const struct fwnode_operations___352 *ops;
};

typedef void compound_page_dtor___452(struct page___465 *);

struct fwnode_reference_args___352;

struct fwnode_endpoint___352;

struct fwnode_operations___352 {
	struct fwnode_handle___352 * (*get)(struct fwnode_handle___352 *);
	void (*put)(struct fwnode_handle___352 *);
	bool (*device_is_available)(const struct fwnode_handle___352 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___352 *, const struct device___432 *);
	bool (*property_present)(const struct fwnode_handle___352 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___352 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___352 *, const char *, const char **, size_t);
	struct fwnode_handle___352 * (*get_parent)(const struct fwnode_handle___352 *);
	struct fwnode_handle___352 * (*get_next_child_node)(const struct fwnode_handle___352 *, struct fwnode_handle___352 *);
	struct fwnode_handle___352 * (*get_named_child_node)(const struct fwnode_handle___352 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___352 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___352 *);
	struct fwnode_handle___352 * (*graph_get_next_endpoint)(const struct fwnode_handle___352 *, struct fwnode_handle___352 *);
	struct fwnode_handle___352 * (*graph_get_remote_endpoint)(const struct fwnode_handle___352 *);
	struct fwnode_handle___352 * (*graph_get_port_parent)(struct fwnode_handle___352 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___352 *, struct fwnode_endpoint___352 *);
};

struct fwnode_endpoint___352 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___352 *local_fwnode;
};

struct fwnode_reference_args___352 {
	struct fwnode_handle___352 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___145;

struct pipe_buffer___145 {
	struct page___465 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___145 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___145 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___145 *, struct pipe_buffer___145 *);
	void (*release)(struct pipe_inode_info___145 *, struct pipe_buffer___145 *);
	int (*steal)(struct pipe_inode_info___145 *, struct pipe_buffer___145 *);
	union {
		bool (*get)(struct pipe_inode_info___145 *, struct pipe_buffer___145 *);
		struct {
			void (*get)(struct pipe_inode_info___145 *, struct pipe_buffer___145 *);
		} __UNIQUE_ID_rh_kabi_hide21;
		union {		};
	};
};

struct nf_bridge_info___109 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___109 = 0,
		BRNF_PROTO_8021Q___109 = 1,
		BRNF_PROTO_PPPOE___109 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___109 *physindev;
	struct net_device___109 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___109(struct sk_buff___110 **);

struct net_device_ops___109;

struct ethtool_ops___109;

struct l3mdev_ops___89;

struct ndisc_ops___59;

struct xfrmdev_ops___109;

struct tlsdev_ops___109;

struct header_ops___109;

struct inet6_dev___59;

struct netdev_rx_queue___109;

struct mini_Qdisc___101;

struct netdev_queue___109;

struct Qdisc___101;

struct rtnl_link_ops___101;

struct dcbnl_rtnl_ops___109;

struct net_device___109 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___109 *netdev_ops;
	const struct ethtool_ops___109 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___89 *l3mdev_ops;
	const struct ndisc_ops___59 *ndisc_ops;
	const struct xfrmdev_ops___109 *xfrmdev_ops;
	const struct tlsdev_ops___109 *tlsdev_ops;
	const struct header_ops___109 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___451 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___59 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___109 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___99 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___109 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___101 *miniq_ingress;
	struct netdev_queue___109 *ingress_queue;
	struct nf_hook_entries___19 *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___109 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___101 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___101 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___109 = 0,
		NETREG_REGISTERED___109 = 1,
		NETREG_UNREGISTERING___109 = 2,
		NETREG_UNREGISTERED___109 = 3,
		NETREG_RELEASED___109 = 4,
		NETREG_DUMMY___109 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___109 = 0,
		RTNL_LINK_INITIALIZING___109 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___109 *);
	struct netpoll_info *npinfo;
	possible_net_t___111 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___432 dev;
	const struct attribute_group___429 *sysfs_groups[4];
	const struct attribute_group___429 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___101 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___109 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide35;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

typedef int (*key_restrict_link_func_t___433)(struct key___432 *, const struct key_type *, const union key_payload *, struct key___432 *);

struct key_restriction___432;

struct key___432 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___466 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___432 *restrict_link;
};

struct key_restriction___432 {
	key_restrict_link_func_t___433 check;
	struct key___432 *key;
	struct key_type *keytype;
};

struct cgroup_namespace___313 {
	refcount_t count;
	struct ns_common___29 ns;
	struct user_namespace___329 *user_ns;
	struct ucounts___329 *ucounts;
	struct css_set___313 *root_cset;
};

struct netlink_callback___111 {
	struct sk_buff___110 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___111 *);
	int (*dump)(struct sk_buff___110 *, struct netlink_callback___111 *);
	int (*done)(struct netlink_callback___111 *);
	void *data;
	struct module___390 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct ethtool_ops___109 {
	int (*get_settings)(struct net_device___109 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___109 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___109 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___109 *);
	void (*get_regs)(struct net_device___109 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___109 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___109 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___109 *);
	void (*set_msglevel)(struct net_device___109 *, u32);
	int (*nway_reset)(struct net_device___109 *);
	u32 (*get_link)(struct net_device___109 *);
	int (*get_eeprom_len)(struct net_device___109 *);
	int (*get_eeprom)(struct net_device___109 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___109 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___109 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___109 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___109 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___109 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___109 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___109 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___109 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___109 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___109 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___109 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___109 *);
	void (*complete)(struct net_device___109 *);
	u32 (*get_priv_flags)(struct net_device___109 *);
	int (*set_priv_flags)(struct net_device___109 *, u32);
	int (*get_sset_count)(struct net_device___109 *, int);
	int (*get_rxnfc)(struct net_device___109 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___109 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___109 *, struct ethtool_flash *);
	int (*reset)(struct net_device___109 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___109 *);
	u32 (*get_rxfh_indir_size)(struct net_device___109 *);
	int (*get_rxfh)(struct net_device___109 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___109 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___109 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___109 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___109 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___109 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___109 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___109 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___109 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___109 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___109 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___109 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___109 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___109 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___109 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___109 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___109 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___109 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___109 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___109 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___109 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___109 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	int (*get_fecparam)(struct net_device___109 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___109 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___109 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___109 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___109 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___109;

struct inet_frags___109 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___109 *, const void *);
	void (*destructor)(struct inet_frag_queue___109 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___109 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___110 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___110 *fragments_tail;
	struct sk_buff___110 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___109 *net;
	struct callback_head rcu;
};

struct ip_ra_chain___54 {
	struct ip_ra_chain___54 *next;
	struct sock___89 *sk;
	union {
		void (*destructor)(struct sock___89 *);
		struct sock___89 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___89;

struct fib_lookup_arg___89;

struct fib_rules_ops___89 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___89 *, struct flowi *, int, struct fib_lookup_arg___89 *);
	bool (*suppress)(struct fib_rule___89 *, struct fib_lookup_arg___89 *);
	int (*match)(struct fib_rule___89 *, struct flowi *, int);
	int (*configure)(struct fib_rule___89 *, struct sk_buff___110 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___89 *);
	int (*compare)(struct fib_rule___89 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___89 *, struct sk_buff___110 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___89 *);
	void (*flush_cache)(struct fib_rules_ops___89 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___390 *owner;
	struct net___120 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___90 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___120 *);
	int (*fib_dump)(struct net___120 *, struct notifier_block *);
	struct module___390 *owner;
	struct callback_head rcu;
};

struct lwtunnel_state___14;

struct dst_entry___89 {
	struct net_device___109 *dev;
	struct dst_ops___120 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___110 *);
	int (*output)(struct net___120 *, struct sock___89 *, struct sk_buff___110 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___14 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___89;

struct neigh_parms___89;

struct neigh_ops___89;

struct neighbour___89 {
	struct neighbour___89 *next;
	struct neigh_table___89 *tbl;
	struct neigh_parms___89 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___109 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___89 *, struct sk_buff___110 *);
	const struct neigh_ops___89 *ops;
	struct callback_head rcu;
	struct net_device___109 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct fib6_nh___30 {
	struct in6_addr nh_gw;
	struct net_device___109 *nh_dev;
	struct lwtunnel_state___14 *nh_lwtstate;
	unsigned int nh_flags;
	atomic_t nh_upper_bound;
	int nh_weight;
};

struct fib6_node___30;

struct fib6_info___30 {
	struct fib6_table___30 *fib6_table;
	struct fib6_info___30 *fib6_next;
	struct fib6_node___30 *fib6_node;
	struct list_head fib6_siblings;
	unsigned int fib6_nsiblings;
	atomic_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	struct rt6_info___30 **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
	long unsigned int last_probe;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 exception_bucket_flushed: 1;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 dst_host: 1;
	u8 fib6_destroying: 1;
	u8 unused: 2;
	struct fib6_nh___30 fib6_nh;
	struct callback_head rcu;
};

struct rt6_info___30 {
	struct dst_entry___89 dst;
	struct fib6_info___30 *from;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___59 *rt6i_idev;
	u32 rt6i_flags;
	struct rt6key rt6i_prefsrc;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct fib6_node___30 {
	struct fib6_node___30 *parent;
	struct fib6_node___30 *left;
	struct fib6_node___30 *right;
	struct fib6_info___30 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info___30 *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table___30 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node___30 tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

struct nf_hook_state___19;

typedef unsigned int nf_hookfn___19(void *, struct sk_buff___110 *, const struct nf_hook_state___19 *);

struct nf_hook_entry___19 {
	nf_hookfn___19 *hook;
	void *priv;
};

struct nf_hook_entries___19 {
	u16 num_hook_entries;
	struct nf_hook_entry___19 hooks[0];
};

struct ucounts___329 {
	struct hlist_node node;
	struct user_namespace___329 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_prog_aux___102;

struct bpf_prog___99 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___102 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

struct seq_operations___403 {
	void * (*start)(struct seq_file___403 *, loff_t *);
	void (*stop)(struct seq_file___403 *, void *);
	void * (*next)(struct seq_file___403 *, void *, loff_t *);
	int (*show)(struct seq_file___403 *, void *);
};

struct pernet_operations___110 {
	struct list_head list;
	int (*init)(struct net___120 *);
	void (*exit)(struct net___120 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___109 {
	int (*ieee_getets)(struct net_device___109 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___109 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___109 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___109 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___109 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___109 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___109 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___109 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___109 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___109 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___109 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___109 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___109 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___109 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___109 *);
	u8 (*setstate)(struct net_device___109 *, u8);
	void (*getpermhwaddr)(struct net_device___109 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___109 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___109 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___109 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___109 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___109 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___109 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___109 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___109 *, int, u8 *);
	void (*setpfccfg)(struct net_device___109 *, int, u8);
	void (*getpfccfg)(struct net_device___109 *, int, u8 *);
	u8 (*setall)(struct net_device___109 *);
	u8 (*getcap)(struct net_device___109 *, int, u8 *);
	int (*getnumtcs)(struct net_device___109 *, int, u8 *);
	int (*setnumtcs)(struct net_device___109 *, int, u8);
	u8 (*getpfcstate)(struct net_device___109 *);
	void (*setpfcstate)(struct net_device___109 *, u8);
	void (*getbcncfg)(struct net_device___109 *, int, u32 *);
	void (*setbcncfg)(struct net_device___109 *, int, u32);
	void (*getbcnrp)(struct net_device___109 *, int, u8 *);
	void (*setbcnrp)(struct net_device___109 *, int, u8);
	int (*setapp)(struct net_device___109 *, u8, u16, u8);
	int (*getapp)(struct net_device___109 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___109 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___109 *, int, u8);
	u8 (*getdcbx)(struct net_device___109 *);
	u8 (*setdcbx)(struct net_device___109 *, u8);
	int (*peer_getappinfo)(struct net_device___109 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___109 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___109 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___109 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___109 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___109 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct bpf_map___314;

struct bpf_map_ops___313 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___314 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___314 *, struct file___464 *);
	void (*map_free)(struct bpf_map___314 *);
	int (*map_get_next_key)(struct bpf_map___314 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___314 *);
	void * (*map_lookup_elem)(struct bpf_map___314 *, void *);
	int (*map_update_elem)(struct bpf_map___314 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___314 *, void *);
	int (*map_push_elem)(struct bpf_map___314 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___314 *, void *);
	int (*map_peek_elem)(struct bpf_map___314 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___314 *, struct file___464 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___314 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___314 *, void *, struct seq_file___403 *);
	int (*map_check_btf)(const struct bpf_map___314 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___314 {
	const struct bpf_map_ops___313 *ops;
	struct bpf_map___314 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___432 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___109;

struct bpf_map_dev_ops___109 {
	int (*map_get_next_key)(struct bpf_offloaded_map___109 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___109 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___109 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___109 *, void *);
};

struct bpf_offloaded_map___109 {
	struct bpf_map___314 map;
	struct net_device___109 *netdev;
	const struct bpf_map_dev_ops___109 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___99 {
	int (*test_run)(struct bpf_prog___99 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___99 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___99 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___99 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___99 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___99 *, u32 *);
};

struct bpf_prog_offload_ops___99 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___99 *);
	int (*translate)(struct bpf_prog___99 *);
	void (*destroy)(struct bpf_prog___99 *);
};

struct bpf_prog_offload___99 {
	struct bpf_prog___99 *prog;
	struct net_device___109 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___99 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___102 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___99 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___99 *ops;
	struct bpf_map___314 **used_maps;
	struct bpf_prog___99 *prog;
	struct user_struct___432 *user;
	u64 load_time;
	struct bpf_map___314 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___99 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___99 {
	struct bpf_prog___99 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___99 {
	struct callback_head rcu;
	struct bpf_prog_array_item___99 items[0];
};

struct cgroup_bpf___99 {
	struct bpf_prog_array___99 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___99 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___314;

typedef void (*kthread_work_func_t___314)(struct kthread_work___314 *);

struct kthread_worker___314;

struct kthread_work___314 {
	struct list_head node;
	kthread_work_func_t___314 func;
	struct kthread_worker___314 *worker;
	int canceling;
};

struct kthread_worker___314 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___466 *task;
	struct kthread_work___314 *current_work;
};

struct kthread_delayed_work___313 {
	struct kthread_work___314 work;
	struct timer_list timer;
};

struct psi_group___313 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___314 *poll_kworker;
	struct kthread_delayed_work___313 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___313;

struct cgroup_rstat_cpu___313;

struct cgroup___313 {
	struct cgroup_subsys_state___313 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___459 *kn;
	struct cgroup_file___313 procs_file;
	struct cgroup_file___313 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___313 *subsys[13];
	struct cgroup_root___313 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___313 *dom_cgrp;
	struct cgroup_rstat_cpu___313 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___99 bpf;
	atomic_t congestion_count;
	struct cgroup___313 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___313 psi;
	int ancestor_ids[0];
};

struct cftype___313;

struct cgroup_subsys___313 {
	struct cgroup_subsys_state___313 * (*css_alloc)(struct cgroup_subsys_state___313 *);
	int (*css_online)(struct cgroup_subsys_state___313 *);
	void (*css_offline)(struct cgroup_subsys_state___313 *);
	void (*css_released)(struct cgroup_subsys_state___313 *);
	void (*css_free)(struct cgroup_subsys_state___313 *);
	void (*css_reset)(struct cgroup_subsys_state___313 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___313 *, int);
	int (*css_extra_stat_show)(struct seq_file___403 *, struct cgroup_subsys_state___313 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___466 *);
	void (*cancel_fork)(struct task_struct___466 *);
	void (*fork)(struct task_struct___466 *);
	void (*exit)(struct task_struct___466 *);
	void (*free)(struct task_struct___466 *);
	void (*bind)(struct cgroup_subsys_state___313 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___313 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___313 *dfl_cftypes;
	struct cftype___313 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___313 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___313 *updated_children;
	struct cgroup___313 *updated_next;
};

struct cgroup_root___313 {
	struct kernfs_root___458 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___313 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___313 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___313 *ss;
	struct list_head node;
	struct kernfs_ops___458 *kf_ops;
	int (*open)(struct kernfs_open_file___458 *);
	void (*release)(struct kernfs_open_file___458 *);
	u64 (*read_u64)(struct cgroup_subsys_state___313 *, struct cftype___313 *);
	s64 (*read_s64)(struct cgroup_subsys_state___313 *, struct cftype___313 *);
	int (*seq_show)(struct seq_file___403 *, void *);
	void * (*seq_start)(struct seq_file___403 *, loff_t *);
	void * (*seq_next)(struct seq_file___403 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___403 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___313 *, struct cftype___313 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___313 *, struct cftype___313 *, s64);
	ssize_t (*write)(struct kernfs_open_file___458 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___458 *, struct poll_table_struct___303 *);
};

struct xdp_rxq_info___109 {
	struct net_device___109 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___109 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___109 *dev_rx;
};

struct header_ops___109 {
	int (*create)(struct sk_buff___110 *, struct net_device___109 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___110 *, unsigned char *);
	int (*cache)(const struct neighbour___89 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___109 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___109 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___109 *, int);
	int poll_owner;
	struct net_device___109 *dev;
	struct sk_buff___110 *gro_list;
	struct sk_buff___110 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___109 {
	struct net_device___109 *dev;
	struct Qdisc___101 *qdisc;
	struct Qdisc___101 *qdisc_sleeping;
	struct kobject___452 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___109 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem___3 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___101 {
	struct sk_buff___110 *head;
	struct sk_buff___110 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___101;

struct Qdisc___101 {
	int (*enqueue)(struct sk_buff___110 *, struct Qdisc___101 *, struct sk_buff___110 **);
	struct sk_buff___110 * (*dequeue)(struct Qdisc___101 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___101 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___109 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___109 gso_skb;
	struct qdisc_skb_head___101 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___101 *next_sched;
	struct sk_buff_head___109 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___109 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___452 kobj;
	struct net_device___109 *dev;
	long: 64;
	struct xdp_rxq_info___109 xdp_rxq;
	union {
		struct xdp_umem___3 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___109)(struct net_device___109 *, struct sk_buff___110 *, struct net_device___109 *);

struct netdev_bpf___109 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___99 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___99 *prog;
			const struct bpf_prog_offload_ops___99 *ops;
		} verifier;
		struct {
			struct bpf_prog___99 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___109 *offmap;
		};
		struct {
			struct xdp_umem___3 *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___109 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___110 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___109 {
	int (*tls_dev_add)(struct net_device___109 *, struct sock___89 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___109 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___109 *, struct sock___89 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___109 {
	int (*ndo_init)(struct net_device___109 *);
	void (*ndo_uninit)(struct net_device___109 *);
	int (*ndo_open)(struct net_device___109 *);
	int (*ndo_stop)(struct net_device___109 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___110 *, struct net_device___109 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___110 *, struct net_device___109 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___109 *, struct sk_buff___110 *, struct net_device___109 *, select_queue_fallback_t___109);
	void (*ndo_change_rx_flags)(struct net_device___109 *, int);
	void (*ndo_set_rx_mode)(struct net_device___109 *);
	int (*ndo_set_mac_address)(struct net_device___109 *, void *);
	int (*ndo_validate_addr)(struct net_device___109 *);
	int (*ndo_do_ioctl)(struct net_device___109 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___109 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___109 *, int);
	int (*ndo_neigh_setup)(struct net_device___109 *, struct neigh_parms___89 *);
	void (*ndo_tx_timeout)(struct net_device___109 *);
	void (*ndo_get_stats64)(struct net_device___109 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___109 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___109 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___109 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___109 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___109 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___109 *);
	int (*ndo_netpoll_setup)(struct net_device___109 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___109 *);
	int (*ndo_set_vf_mac)(struct net_device___109 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___109 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___109 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___109 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___109 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___109 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___109 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___109 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___109 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___109 *, int, struct sk_buff___110 *);
	int (*ndo_set_vf_guid)(struct net_device___109 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___109 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___109 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___109 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___109 *, const struct sk_buff___110 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___109 *, struct net_device___109 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___109 *, struct net_device___109 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___109 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___109 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___109 *, struct neighbour___89 *);
	void (*ndo_neigh_destroy)(struct net_device___109 *, struct neighbour___89 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___109 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___109 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___109 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___110 *, struct netlink_callback___111 *, struct net_device___109 *, struct net_device___109 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___109 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___109 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___110 *, u32, u32, struct net_device___109 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___109 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___109 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___109 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___109 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___109 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___109 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___109 *, struct net_device___109 *);
	void (*ndo_dfwd_del_station)(struct net_device___109 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___109 *);
	int (*ndo_set_tx_maxrate)(struct net_device___109 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___109 *);
	int (*ndo_change_proto_down)(struct net_device___109 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___109 *, struct sk_buff___110 *);
	void (*ndo_set_rx_headroom)(struct net_device___109 *, int);
	int (*ndo_bpf)(struct net_device___109 *, struct netdev_bpf___109 *);
	int (*ndo_xdp_xmit)(struct net_device___109 *, int, struct xdp_frame___109 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___109 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___109 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___89 {
	possible_net_t___111 net;
	struct net_device___109 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___89 *);
	void (*neigh_cleanup)(struct neighbour___89 *);
	struct neigh_table___89 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___89 {
	u32 (*l3mdev_fib_table)(const struct net_device___109 *);
	struct sk_buff___110 * (*l3mdev_l3_rcv)(struct net_device___109 *, struct sk_buff___110 *, u16);
	struct sk_buff___110 * (*l3mdev_l3_out)(struct net_device___109 *, struct sock___89 *, struct sk_buff___110 *, u16);
	struct dst_entry___89 * (*l3mdev_link_scope_lookup)(const struct net_device___109 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct ndisc_ops___59 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___109 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___109 *, struct neighbour___89 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___109 *, u8, struct neighbour___89 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___109 *, struct sk_buff___110 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___120 *, struct net_device___109 *, const struct prefix_info *, struct inet6_dev___59 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___59;

struct ifacaddr6___30;

struct inet6_dev___59 {
	struct net_device___109 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___59 *mc_list;
	struct ifmcaddr6___59 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___30 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	u8 rndid[8];
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___89 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
};

struct tcf_proto___101;

struct mini_Qdisc___101 {
	struct tcf_proto___101 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___101 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___109 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___120 *, struct net_device___109 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___109 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___109 *, struct list_head *);
	size_t (*get_size)(const struct net_device___109 *);
	int (*fill_info)(struct sk_buff___110 *, const struct net_device___109 *);
	size_t (*get_xstats_size)(const struct net_device___109 *);
	int (*fill_xstats)(struct sk_buff___110 *, const struct net_device___109 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___109 *, struct net_device___109 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___109 *, const struct net_device___109 *);
	int (*fill_slave_info)(struct sk_buff___110 *, const struct net_device___109 *, const struct net_device___109 *);
	struct net___120 * (*get_link_net)(const struct net_device___109 *);
	size_t (*get_linkxstats_size)(const struct net_device___109 *, int);
	int (*fill_linkxstats)(struct sk_buff___110 *, const struct net_device___109 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct offload_callbacks___19 {
	struct sk_buff___110 * (*gso_segment)(struct sk_buff___110 *, netdev_features_t);
	struct sk_buff___110 ** (*gro_receive)(struct sk_buff___110 **, struct sk_buff___110 *);
	int (*gro_complete)(struct sk_buff___110 *, int);
};

struct netdev_notifier_info___14 {
	struct net_device___109 *dev;
	struct netlink_ext_ack *extack;
};

struct netdev_notifier_change_info___4 {
	struct netdev_notifier_info___14 info;
	unsigned int flags_changed;
};

struct softnet_data___109 {
	struct list_head poll_list;
	struct sk_buff_head___109 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___109 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___101 *output_queue;
	struct Qdisc___101 **output_queue_tailp;
	struct sk_buff___110 *completion_queue;
	struct sk_buff_head___109 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___109 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___109 input_pkt_queue;
	struct napi_struct___109 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bdi_writeback_congested___254 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___254 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___254 {
	struct bio___254 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___256 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___256 bip_inline_vecs[0];
};

struct bio_set___254 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___254 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___197 {
	struct mem_cgroup___197 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___197 {
	struct lruvec___465 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___197 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___197 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct nduseroptmsg {
	unsigned char nduseropt_family;
	unsigned char nduseropt_pad1;
	short unsigned int nduseropt_opts_len;
	int nduseropt_ifindex;
	__u8 nduseropt_icmp_type;
	__u8 nduseropt_icmp_code;
	short unsigned int nduseropt_pad2;
	unsigned int nduseropt_pad3;
};

enum {
	NDUSEROPT_UNSPEC = 0,
	NDUSEROPT_SRCADDR = 1,
	__NDUSEROPT_MAX = 2,
};

struct gnet_dump___101 {
	spinlock_t *lock;
	struct sk_buff___110 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___101;

struct Qdisc_ops___101 {
	struct Qdisc_ops___101 *next;
	const struct Qdisc_class_ops___101 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___110 *, struct Qdisc___101 *, struct sk_buff___110 **);
	struct sk_buff___110 * (*dequeue)(struct Qdisc___101 *);
	struct sk_buff___110 * (*peek)(struct Qdisc___101 *);
	int (*init)(struct Qdisc___101 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___101 *);
	void (*destroy)(struct Qdisc___101 *);
	int (*change)(struct Qdisc___101 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___101 *);
	int (*change_tx_queue_len)(struct Qdisc___101 *, unsigned int);
	int (*dump)(struct Qdisc___101 *, struct sk_buff___110 *);
	int (*dump_stats)(struct Qdisc___101 *, struct gnet_dump___101 *);
	void (*ingress_block_set)(struct Qdisc___101 *, u32);
	void (*egress_block_set)(struct Qdisc___101 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___101 *);
	u32 (*egress_block_get)(struct Qdisc___101 *);
	struct module___390 *owner;
};

struct tcf_block___101;

struct Qdisc_class_ops___101 {
	unsigned int flags;
	struct netdev_queue___109 * (*select_queue)(struct Qdisc___101 *, struct tcmsg *);
	int (*graft)(struct Qdisc___101 *, long unsigned int, struct Qdisc___101 *, struct Qdisc___101 **, struct netlink_ext_ack *);
	struct Qdisc___101 * (*leaf)(struct Qdisc___101 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___101 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___101 *, u32);
	int (*change)(struct Qdisc___101 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___101 *, long unsigned int);
	void (*walk)(struct Qdisc___101 *, struct qdisc_walker *);
	struct tcf_block___101 * (*tcf_block)(struct Qdisc___101 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___101 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___101 *, long unsigned int);
	int (*dump)(struct Qdisc___101 *, long unsigned int, struct sk_buff___110 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___101 *, long unsigned int, struct gnet_dump___101 *);
};

struct tcf_chain___101;

struct tcf_block___101 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___120 *net;
	struct Qdisc___101 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___101 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___101;

struct tcf_proto_ops___101;

struct tcf_proto___101 {
	struct tcf_proto___101 *next;
	void *root;
	int (*classify)(struct sk_buff___110 *, const struct tcf_proto___101 *, struct tcf_result___101 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___101 *ops;
	struct tcf_chain___101 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___101 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___101 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___101 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___110 *, const struct tcf_proto___101 *, struct tcf_result___101 *);
	int (*init)(struct tcf_proto___101 *);
	void (*destroy)(struct tcf_proto___101 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___101 *, u32);
	void (*put)(struct tcf_proto___101 *, void *);
	int (*change)(struct net___120 *, struct sk_buff___110 *, struct tcf_proto___101 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___101 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___101 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___101 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___120 *, struct tcf_chain___101 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___120 *, struct tcf_proto___101 *, void *, struct sk_buff___110 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___110 *, struct net___120 *, void *);
	struct module___390 *owner;
	int flags;
};

struct tcf_chain___101 {
	struct mutex filter_chain_lock;
	struct tcf_proto___101 *filter_chain;
	struct list_head list;
	struct tcf_block___101 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___101 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___89 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___99 *prog;
};

struct bpf_redirect_info___99 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___314 *map;
	struct bpf_map___314 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___89;

struct neigh_hash_table___89;

struct neigh_table___89 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___109 *, __u32 *);
	bool (*key_eq)(const struct neighbour___89 *, const void *);
	int (*constructor)(struct neighbour___89 *);
	int (*pconstructor)(struct pneigh_entry___89 *);
	void (*pdestructor)(struct pneigh_entry___89 *);
	void (*proxy_redo)(struct sk_buff___110 *);
	char *id;
	struct neigh_parms___89 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___109 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___89 *nht;
	struct pneigh_entry___89 **phash_buckets;
};

struct neigh_ops___89 {
	int family;
	void (*solicit)(struct neighbour___89 *, struct sk_buff___110 *);
	void (*error_report)(struct neighbour___89 *, struct sk_buff___110 *);
	int (*output)(struct neighbour___89 *, struct sk_buff___110 *);
	int (*connected_output)(struct neighbour___89 *, struct sk_buff___110 *);
};

struct pneigh_entry___89 {
	struct pneigh_entry___89 *next;
	possible_net_t___111 net;
	struct net_device___109 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___89 {
	struct neighbour___89 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___14 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___120 *, struct sock___89 *, struct sk_buff___110 *);
	int (*orig_input)(struct sk_buff___110 *);
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	__u8 data[0];
};

struct fib_rule___89 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___89 *ctarget;
	struct net___120 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___89 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___89 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___71;

struct timewait_sock_ops___67;

struct proto___89 {
	void (*close)(struct sock___89 *, long int);
	int (*pre_connect)(struct sock___89 *, struct sockaddr *, int);
	int (*connect)(struct sock___89 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___89 *, int);
	struct sock___89 * (*accept)(struct sock___89 *, int, int *, bool);
	int (*ioctl)(struct sock___89 *, int, long unsigned int);
	int (*init)(struct sock___89 *);
	void (*destroy)(struct sock___89 *);
	void (*shutdown)(struct sock___89 *, int);
	int (*setsockopt)(struct sock___89 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___89 *, int, int, char *, int *);
	void (*keepalive)(struct sock___89 *, int);
	int (*sendmsg)(struct sock___89 *, struct msghdr___92 *, size_t);
	int (*recvmsg)(struct sock___89 *, struct msghdr___92 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___89 *, struct page___465 *, int, size_t, int);
	int (*bind)(struct sock___89 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___89 *, struct sk_buff___110 *);
	void (*release_cb)(struct sock___89 *);
	int (*hash)(struct sock___89 *);
	void (*unhash)(struct sock___89 *);
	void (*rehash)(struct sock___89 *);
	int (*get_port)(struct sock___89 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___89 *);
	bool (*stream_memory_read)(const struct sock___89 *);
	void (*enter_memory_pressure)(struct sock___89 *);
	void (*leave_memory_pressure)(struct sock___89 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___71 *rsk_prot;
	struct timewait_sock_ops___67 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___390 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___89 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct request_sock___72;

struct request_sock_ops___71 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___89 *, struct request_sock___72 *);
	void (*send_ack)(const struct sock___89 *, struct sk_buff___110 *, struct request_sock___72 *);
	void (*send_reset)(const struct sock___89 *, struct sk_buff___110 *);
	void (*destructor)(struct request_sock___72 *);
	void (*syn_ack_timeout)(const struct request_sock___72 *);
};

struct timewait_sock_ops___67 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___89 *, struct sock___89 *, void *);
	void (*twsk_destructor)(struct sock___89 *);
};

struct request_sock___72 {
	struct sock_common___89 __req_common;
	struct request_sock___72 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___71 *rsk_ops;
	struct sock___89 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct inet_cork___25 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___89 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
	__u16 gso_size;
	u64 transmit_time;
};

struct inet_cork_full___25 {
	struct inet_cork___25 base;
	struct flowi fl;
};

struct ipv6_pinfo___25;

struct inet_sock___25 {
	struct sock___89 sk;
	struct ipv6_pinfo___25 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	__be16 inet_sport;
	__u16 inet_id;
	struct ip_options_rcu *inet_opt;
	int rx_dst_ifindex;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 bind_address_no_port: 1;
	__u8 defer_connect: 1;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___25 cork;
};

struct ipv6_fl_socklist___24;

struct ipv6_pinfo___25 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
			__u16 recvfragsize: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 repflow: 1;
	__u16 pmtudisc: 3;
	__u16 padding: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u16 autoflowlabel: 1;
	__u16 autoflowlabel_set: 1;
	__u8 min_hopcount;
	__u8 tclass;
	__be32 rcv_flowinfo;
	__u32 dst_cookie;
	__u32 rx_dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___24 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___110 *pktoptions;
	struct sk_buff___110 *rxpmtu;
	struct inet6_cork cork;
};

struct ip6_flowlabel___24;

struct ipv6_fl_socklist___24 {
	struct ipv6_fl_socklist___24 *next;
	struct ip6_flowlabel___24 *fl;
	struct callback_head rcu;
};

struct inet6_ifaddr___5 {
	struct in6_addr addr;
	__u32 prefix_len;
	__u32 rt_priority;
	__u32 valid_lft;
	__u32 prefered_lft;
	refcount_t refcnt;
	spinlock_t lock;
	int state;
	__u32 flags;
	__u8 dad_probes;
	__u8 stable_privacy_retry;
	__u16 scope;
	__u64 dad_nonce;
	long unsigned int cstamp;
	long unsigned int tstamp;
	struct delayed_work dad_work;
	struct inet6_dev___59 *idev;
	struct fib6_info___30 *rt;
	struct hlist_node addr_lst;
	struct list_head if_list;
	struct list_head tmp_list;
	struct inet6_ifaddr___5 *ifpub;
	int regen_count;
	bool tokenized;
	struct callback_head rcu;
	struct in6_addr peer_addr;
};

struct ifmcaddr6___59 {
	struct in6_addr mca_addr;
	struct inet6_dev___59 *idev;
	struct ifmcaddr6___59 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___30 {
	struct in6_addr aca_addr;
	struct fib6_info___30 *aca_rt;
	struct ifacaddr6___30 *aca_next;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct nd_msg {
	struct icmp6hdr icmph;
	struct in6_addr target;
	__u8 opt[0];
};

struct rs_msg {
	struct icmp6hdr icmph;
	__u8 opt[0];
};

struct ra_msg {
	struct icmp6hdr icmph;
	__be32 reachable_time;
	__be32 retrans_timer;
};

struct ip6_ra_chain___59 {
	struct ip6_ra_chain___59 *next;
	struct sock___89 *sk;
	int sel;
	void (*destructor)(struct sock___89 *);
};

struct ip6_flowlabel___24 {
	struct ip6_flowlabel___24 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___259 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___120 *fl_net;
};

struct net_protocol___17 {
	int (*early_demux)(struct sk_buff___110 *);
	int (*early_demux_handler)(struct sk_buff___110 *);
	int (*handler)(struct sk_buff___110 *);
	void (*err_handler)(struct sk_buff___110 *, u32);
	unsigned int no_policy: 1;
	unsigned int netns_ok: 1;
	unsigned int icmp_strict_tag_validation: 1;
};

struct inet6_protocol___17 {
	void (*early_demux)(struct sk_buff___110 *);
	void (*early_demux_handler)(struct sk_buff___110 *);
	int (*handler)(struct sk_buff___110 *);
	void (*err_handler)(struct sk_buff___110 *, struct inet6_skb_parm *, u8, u8, int, __be32);
	unsigned int flags;
};

struct net_offload___17 {
	struct offload_callbacks___19 callbacks;
	unsigned int flags;
};

struct ipv6_stub___19 {
	int (*ipv6_sock_mc_join)(struct sock___89 *, int, const struct in6_addr *);
	int (*ipv6_sock_mc_drop)(struct sock___89 *, int, const struct in6_addr *);
	int (*ipv6_dst_lookup)(struct net___120 *, struct sock___89 *, struct dst_entry___89 **, struct flowi6 *);
	struct fib6_table___30 * (*fib6_get_table)(struct net___120 *, u32);
	struct fib6_info___30 * (*fib6_lookup)(struct net___120 *, int, struct flowi6 *, int);
	struct fib6_info___30 * (*fib6_table_lookup)(struct net___120 *, struct fib6_table___30 *, int, struct flowi6 *, int);
	struct fib6_info___30 * (*fib6_multipath_select)(const struct net___120 *, struct fib6_info___30 *, struct flowi6 *, int, const struct sk_buff___110 *, int);
	u32 (*ip6_mtu_from_fib6)(struct fib6_info___30 *, struct in6_addr *, struct in6_addr *);
	void (*udpv6_encap_enable)();
	void (*ndisc_send_na)(struct net_device___109 *, const struct in6_addr *, const struct in6_addr *, bool, bool, bool, bool);
	struct neigh_table___89 *nd_tbl;
};

struct ipv6_bpf_stub___19 {
	int (*inet6_bind)(struct sock___89 *, struct sockaddr *, int, bool, bool);
	struct sock___89 * (*udp6_lib_lookup)(struct net___120 *, const struct in6_addr *, __be16, const struct in6_addr *, __be16, int, int, struct udp_table *, struct sk_buff___110 *);
};

struct nf_hook_state___19 {
	unsigned int hook;
	u_int8_t pf;
	struct net_device___109 *in;
	struct net_device___109 *out;
	struct sock___89 *sk;
	struct net___120 *net;
	int (*okfn)(struct net___120 *, struct sock___89 *, struct sk_buff___110 *);
};

struct nf_nat_hook___19 {
	int (*parse_nat_setup)(struct nf_conn *, enum nf_nat_manip_type, const struct nlattr *);
	void (*decode_session)(struct sk_buff___110 *, struct flowi *);
	unsigned int (*manip_pkt)(struct sk_buff___110 *, struct nf_conn *, enum nf_nat_manip_type, enum ip_conntrack_dir);
};

struct nf_ct_hook___19 {
	int (*update)(struct net___120 *, struct sk_buff___110 *);
	void (*destroy)(struct nf_conntrack *);
	bool (*get_tuple_skb)(struct nf_conntrack_tuple *, const struct sk_buff___110 *);
};

struct nfnl_ct_hook___19 {
	struct nf_conn * (*get_ct)(const struct sk_buff___110 *, enum ip_conntrack_info *);
	size_t (*build_size)(const struct nf_conn *);
	int (*build)(struct sk_buff___110 *, struct nf_conn *, enum ip_conntrack_info, u_int16_t, u_int16_t);
	int (*parse)(const struct nlattr *, struct nf_conn *);
	int (*attach_expect)(const struct nlattr *, struct nf_conn *, u32, u32);
	void (*seq_adjust)(struct sk_buff___110 *, struct nf_conn *, enum ip_conntrack_info, s32);
};

struct nf_ipv6_ops___9 {
	int (*chk_addr)(struct net___120 *, const struct in6_addr *, const struct net_device___109 *, int);
	void (*route_input)(struct sk_buff___110 *);
	int (*fragment)(struct net___120 *, struct sock___89 *, struct sk_buff___110 *, int (*)(struct net___120 *, struct sock___89 *, struct sk_buff___110 *));
	__sum16 (*checksum)(struct sk_buff___110 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___110 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___120 *, struct dst_entry___89 **, struct flowi *, bool);
	int (*reroute)(struct sk_buff___110 *, const struct nf_queue_entry___2 *);
};

struct module___391;

struct file___465;

struct kiocb___465;

struct iov_iter___232;

struct poll_table_struct___304;

struct vm_area_struct___466;

struct inode___465;

struct file_lock___465;

struct page___466;

struct pipe_inode_info___146;

struct seq_file___404;

struct file_operations___465 {
	struct module___391 *owner;
	loff_t (*llseek)(struct file___465 *, loff_t, int);
	ssize_t (*read)(struct file___465 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___465 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___465 *, struct iov_iter___232 *);
	ssize_t (*write_iter)(struct kiocb___465 *, struct iov_iter___232 *);
	int (*iopoll)(struct kiocb___465 *, bool);
	int (*iterate)(struct file___465 *, struct dir_context *);
	int (*iterate_shared)(struct file___465 *, struct dir_context *);
	__poll_t (*poll)(struct file___465 *, struct poll_table_struct___304 *);
	long int (*unlocked_ioctl)(struct file___465 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___465 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___465 *, struct vm_area_struct___466 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___465 *, struct file___465 *);
	int (*flush)(struct file___465 *, fl_owner_t);
	int (*release)(struct inode___465 *, struct file___465 *);
	int (*fsync)(struct file___465 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___465 *, int);
	int (*lock)(struct file___465 *, int, struct file_lock___465 *);
	ssize_t (*sendpage)(struct file___465 *, struct page___466 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___465 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___465 *, int, struct file_lock___465 *);
	ssize_t (*splice_write)(struct pipe_inode_info___146 *, struct file___465 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___465 *, loff_t *, struct pipe_inode_info___146 *, size_t, unsigned int);
	int (*setlease)(struct file___465 *, long int, struct file_lock___465 **, void **);
	long int (*fallocate)(struct file___465 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___404 *, struct file___465 *);
	ssize_t (*copy_file_range)(struct file___465 *, loff_t, struct file___465 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___465 *, loff_t, struct file___465 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___465 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___466 {
	u64 seqnum;
	struct vm_area_struct___466 *vmas[4];
};

struct page_frag___466 {
	struct page___466 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___466;

struct mem_cgroup___198;

struct pid___260;

struct cred___433;

struct nsproxy___360;

struct signal_struct___340;

struct bio_list___255;

struct backing_dev_info___255;

struct css_set___314;

struct vm_struct___369;

struct task_struct___467 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___467 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___466 *mm;
	struct mm_struct___466 *active_mm;
	struct vmacache___466 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___467 *real_parent;
	struct task_struct___467 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___467 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___198 *active_memcg;
	long int rh_reserved2;
	struct pid___260 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___260 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___260 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___433 *ptracer_cred;
	const struct cred___433 *real_cred;
	const struct cred___433 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___360 *nsproxy;
	struct signal_struct___340 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___467 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___255 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___255 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___314 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___146 *splice_pipe;
	struct page_frag___466 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___198 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___467 *oom_reaper_list;
	struct vm_struct___369 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___157 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___466 *pgtable_t___466;

struct address_space___465;

struct dev_pagemap___453;

struct page___466 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___465 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___466 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___466 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___466 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___453 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___198 *mem_cgroup;
};

struct pglist_data___466;

struct lruvec___466 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___466 *pgdat;
};

struct zone___466 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___466 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___466 {
	struct zone___466 *zone;
	int zone_idx;
};

struct zonelist___466 {
	struct zoneref___466 _zonerefs[25];
};

struct pglist_data___466 {
	struct zone___466 node_zones[3];
	struct zonelist___466 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___467 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___467 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___466 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___467 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___467 *owner;
};

struct secondary_data___467 {
	void *stack;
	struct task_struct___467 *task;
	long int status;
};

struct blocking_notifier_head___466 {
	struct rw_semaphore___467 rwsem;
	struct notifier_block *head;
};

struct cgroup___314;

struct cgroup_subsys___314;

struct cgroup_subsys_state___314 {
	struct cgroup___314 *cgroup;
	struct cgroup_subsys___314 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___314 *parent;
};

struct kernfs_node___460;

struct cgroup_file___314 {
	struct kernfs_node___460 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___198;

struct mem_cgroup___198 {
	struct cgroup_subsys_state___314 css;
	struct mem_cgroup_id___16 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___314 events_file;
	struct cgroup_file___314 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___467 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___198 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___260;

struct upid___260 {
	int nr;
	struct pid_namespace___260 *ns;
};

struct dentry___465;

struct user_namespace___330;

struct ucounts___330;

struct pid_namespace___260 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___467 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___260 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___465 *proc_self;
	struct dentry___465 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___330 *user_ns;
	struct ucounts___330 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___29 ns;
};

struct pid___260 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___260 numbers[1];
};

struct key___433;

struct user_namespace___330 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___330 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___29 ns;
	long unsigned int flags;
	struct key___433 *persistent_keyring_register;
	struct rw_semaphore___467 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___330 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct user_struct___433 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___433 *uid_keyring;
	struct key___433 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___453;

struct vm_area_struct___466 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___466 *vm_next;
	struct vm_area_struct___466 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___466 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___453 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___465 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___466;

struct mm_struct___466 {
	struct {
		struct vm_area_struct___466 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___465 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___467 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___466 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___467 *owner;
		struct user_namespace___330 *user_ns;
		struct file___465 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___466 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___433 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___433 *session_keyring;
	struct key___433 *process_keyring;
	struct key___433 *thread_keyring;
	struct key___433 *request_key_auth;
	void *security;
	struct user_struct___433 *user;
	struct user_namespace___330 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___121;

struct cgroup_namespace___314;

struct nsproxy___360 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___260 *pid_ns_for_children;
	struct net___121 *net_ns;
	struct cgroup_namespace___314 *cgroup_ns;
};

struct signal_struct___340 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___467 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___467 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___260 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___260 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___466 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___260 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___255;

struct bio_list___255 {
	struct bio___255 *head;
	struct bio___255 *tail;
};

struct bdi_writeback_congested___255;

struct bdi_writeback___255 {
	struct backing_dev_info___255 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___255 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___314 *memcg_css;
	struct cgroup_subsys_state___314 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___433;

struct backing_dev_info___255 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___255 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___433 *dev;
	struct device___433 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___465 *debug_dir;
	struct dentry___465 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___314 {
	struct cgroup_subsys_state___314 *subsys[13];
	refcount_t refcount;
	struct css_set___314 *dom_cset;
	struct cgroup___314 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___314 *mg_src_cgrp;
	struct cgroup___314 *mg_dst_cgrp;
	struct css_set___314 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___465;

struct pipe_buffer___146;

struct pipe_inode_info___146 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___466 *tmp_page;
	struct fasync_struct___465 *fasync_readers;
	struct fasync_struct___465 *fasync_writers;
	struct pipe_buffer___146 *bufs;
	struct user_struct___433 *user;
};

struct vm_struct___369 {
	struct vm_struct___369 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___466 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___352 {
	struct task_struct___467 task;
	long unsigned int stack[8192];
};

struct address_space_operations___465;

struct address_space___465 {
	struct inode___465 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___467 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___465 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___453)(struct vm_area_struct___466 *, long unsigned int, const struct page___466 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___453)(struct page___466 *, void *);

struct dev_pagemap___453 {
	dev_page_fault_t___453 page_fault;
	dev_page_free_t___453 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___433 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___466 {
	struct vfsmount *mnt;
	struct dentry___465 *dentry;
};

struct fown_struct___260 {
	rwlock_t lock;
	struct pid___260 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___465 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___466 f_path;
	struct inode___465 *f_inode;
	const struct file_operations___465 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___260 f_owner;
	const struct cred___433 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___465 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___453;

struct vm_operations_struct___453 {
	void (*open)(struct vm_area_struct___466 *);
	void (*close)(struct vm_area_struct___466 *);
	int (*split)(struct vm_area_struct___466 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___466 *);
	vm_fault_t (*fault)(struct vm_fault___453 *);
	vm_fault_t (*huge_fault)(struct vm_fault___453 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___453 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___466 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___453 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___453 *);
	int (*access)(struct vm_area_struct___466 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___466 *);
	int (*set_policy)(struct vm_area_struct___466 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___466 *, long unsigned int);
	struct page___466 * (*find_special_page)(struct vm_area_struct___466 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___466 {
	struct task_struct___467 *task;
	struct core_thread___466 *next;
};

struct core_state___466 {
	atomic_t nr_threads;
	struct core_thread___466 dumper;
	struct completion startup;
};

struct vm_fault___453 {
	struct vm_area_struct___466 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___466 *cow_page;
	struct mem_cgroup___198 *memcg;
	struct page___466 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___466 prealloc_pte;
};

struct kset___452;

struct kobj_type___452;

struct kobject___453 {
	const char *name;
	struct list_head entry;
	struct kobject___453 *parent;
	struct kset___452 *kset;
	struct kobj_type___452 *ktype;
	struct kernfs_node___460 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___391 {
	struct kobject___453 kobj;
	struct module___391 *mod;
	struct kobject___453 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___391 {
	struct module___391 *mod;
	struct latch_tree_node node;
};

struct module_layout___391 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___391 mtn;
};

struct module_attribute___391;

struct kernel_param___391;

struct module___391 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___391 mkobj;
	struct module_attribute___391 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___453 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___391 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___391 core_layout;
	struct module_layout___391 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide53;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide54;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bio_vec___257 {
	struct page___466 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___232 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___257 *bvec;
		struct pipe_inode_info___146 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct msghdr___93 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___232 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___465 *msg_iocb;
};

struct kiocb___465 {
	struct file___465 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___465 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dentry_operations___465;

struct super_block___465;

struct dentry___465 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___465 *d_parent;
	struct qstr d_name;
	struct inode___465 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___465 *d_op;
	struct super_block___465 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___465;

struct block_device___465;

struct inode___465 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___465 *i_op;
	struct super_block___465 *i_sb;
	struct address_space___465 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___467 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___255 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___465 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___465 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___146 *i_pipe;
		struct block_device___465 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___465 {
	int (*d_revalidate)(struct dentry___465 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___465 *, unsigned int);
	int (*d_hash)(const struct dentry___465 *, struct qstr *);
	int (*d_compare)(const struct dentry___465 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___465 *);
	int (*d_init)(struct dentry___465 *);
	void (*d_release)(struct dentry___465 *);
	void (*d_prune)(struct dentry___465 *);
	void (*d_iput)(struct dentry___465 *, struct inode___465 *);
	char * (*d_dname)(struct dentry___465 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___466 *);
	int (*d_manage)(const struct path___466 *, bool);
	struct dentry___465 * (*d_real)(struct dentry___465 *, const struct inode___465 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___465;

struct mem_dqinfo___465 {
	struct quota_format_type___465 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___465;

struct quota_info___465 {
	unsigned int flags;
	struct rw_semaphore___467 dqio_sem;
	struct inode___465 *files[3];
	struct mem_dqinfo___465 info[3];
	const struct quota_format_ops___465 *ops[3];
};

struct rcuwait___465 {
	struct task_struct___467 *task;
};

struct percpu_rw_semaphore___465 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___467 rw_sem;
	struct rcuwait___465 writer;
	int readers_block;
};

struct sb_writers___465 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___465 rw_sem[3];
};

struct shrink_control___198;

struct shrinker___198 {
	long unsigned int (*count_objects)(struct shrinker___198 *, struct shrink_control___198 *);
	long unsigned int (*scan_objects)(struct shrinker___198 *, struct shrink_control___198 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___465;

struct super_operations___465;

struct dquot_operations___465;

struct quotactl_ops___465;

struct super_block___465 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___465 *s_type;
	const struct super_operations___465 *s_op;
	const struct dquot_operations___465 *dq_op;
	const struct quotactl_ops___465 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___465 *s_root;
	struct rw_semaphore___467 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___465 *s_bdev;
	struct backing_dev_info___255 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___465 s_dquot;
	struct sb_writers___465 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___465 *s_d_op;
	int cleancache_poolid;
	struct shrinker___198 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___330 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___198 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___198 *memcg;
};

struct iattr___465 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___465 *ia_file;
};

struct dquot___465 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___465 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___465 {
	int qf_fmt_id;
	const struct quota_format_ops___465 *qf_ops;
	struct module___391 *qf_owner;
	struct quota_format_type___465 *qf_next;
};

struct quota_format_ops___465 {
	int (*check_quota_file)(struct super_block___465 *, int);
	int (*read_file_info)(struct super_block___465 *, int);
	int (*write_file_info)(struct super_block___465 *, int);
	int (*free_file_info)(struct super_block___465 *, int);
	int (*read_dqblk)(struct dquot___465 *);
	int (*commit_dqblk)(struct dquot___465 *);
	int (*release_dqblk)(struct dquot___465 *);
	int (*get_next_id)(struct super_block___465 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___465 {
	int (*write_dquot)(struct dquot___465 *);
	struct dquot___465 * (*alloc_dquot)(struct super_block___465 *, int);
	void (*destroy_dquot)(struct dquot___465 *);
	int (*acquire_dquot)(struct dquot___465 *);
	int (*release_dquot)(struct dquot___465 *);
	int (*mark_dirty)(struct dquot___465 *);
	int (*write_info)(struct super_block___465 *, int);
	qsize_t * (*get_reserved_space)(struct inode___465 *);
	int (*get_projid)(struct inode___465 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___465 *, qsize_t *);
	int (*get_next_id)(struct super_block___465 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___465 {
	int (*quota_on)(struct super_block___465 *, int, int, const struct path___466 *);
	int (*quota_off)(struct super_block___465 *, int);
	int (*quota_enable)(struct super_block___465 *, unsigned int);
	int (*quota_disable)(struct super_block___465 *, unsigned int);
	int (*quota_sync)(struct super_block___465 *, int);
	int (*set_info)(struct super_block___465 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___465 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___465 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___465 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___465 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___465 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___218;

struct address_space_operations___465 {
	int (*writepage)(struct page___466 *, struct writeback_control___218 *);
	int (*readpage)(struct file___465 *, struct page___466 *);
	int (*writepages)(struct address_space___465 *, struct writeback_control___218 *);
	int (*set_page_dirty)(struct page___466 *);
	int (*readpages)(struct file___465 *, struct address_space___465 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___465 *, struct address_space___465 *, loff_t, unsigned int, unsigned int, struct page___466 **, void **);
	int (*write_end)(struct file___465 *, struct address_space___465 *, loff_t, unsigned int, unsigned int, struct page___466 *, void *);
	sector_t (*bmap)(struct address_space___465 *, sector_t);
	void (*invalidatepage)(struct page___466 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___466 *, gfp_t);
	void (*freepage)(struct page___466 *);
	ssize_t (*direct_IO)(struct kiocb___465 *, struct iov_iter___232 *);
	int (*migratepage)(struct address_space___465 *, struct page___466 *, struct page___466 *, enum migrate_mode);
	bool (*isolate_page)(struct page___466 *, isolate_mode_t);
	void (*putback_page)(struct page___466 *);
	int (*launder_page)(struct page___466 *);
	int (*is_partially_uptodate)(struct page___466 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___466 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___465 *, struct page___466 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___465 *, sector_t *);
	void (*swap_deactivate)(struct file___465 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___218 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___255 *wb;
	struct inode___465 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___465 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___465 *bd_inode;
	struct super_block___465 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___465 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___255 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___465 {
	struct dentry___465 * (*lookup)(struct inode___465 *, struct dentry___465 *, unsigned int);
	const char * (*get_link)(struct dentry___465 *, struct inode___465 *, struct delayed_call *);
	int (*permission)(struct inode___465 *, int);
	struct posix_acl * (*get_acl)(struct inode___465 *, int);
	int (*readlink)(struct dentry___465 *, char *, int);
	int (*create)(struct inode___465 *, struct dentry___465 *, umode_t, bool);
	int (*link)(struct dentry___465 *, struct inode___465 *, struct dentry___465 *);
	int (*unlink)(struct inode___465 *, struct dentry___465 *);
	int (*symlink)(struct inode___465 *, struct dentry___465 *, const char *);
	int (*mkdir)(struct inode___465 *, struct dentry___465 *, umode_t);
	int (*rmdir)(struct inode___465 *, struct dentry___465 *);
	int (*mknod)(struct inode___465 *, struct dentry___465 *, umode_t, dev_t);
	int (*rename)(struct inode___465 *, struct dentry___465 *, struct inode___465 *, struct dentry___465 *, unsigned int);
	int (*setattr)(struct dentry___465 *, struct iattr___465 *);
	int (*getattr)(const struct path___466 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___465 *, char *, size_t);
	int (*fiemap)(struct inode___465 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___465 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___465 *, struct dentry___465 *, struct file___465 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___465 *, struct dentry___465 *, umode_t);
	int (*set_acl)(struct inode___465 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___465 {
	void (*fl_copy_lock)(struct file_lock___465 *, struct file_lock___465 *);
	void (*fl_release_private)(struct file_lock___465 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___465;

struct file_lock___465 {
	struct file_lock___465 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___465 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___465 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___465 *fl_ops;
	const struct lock_manager_operations___465 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___465 {
	int (*lm_compare_owner)(struct file_lock___465 *, struct file_lock___465 *);
	long unsigned int (*lm_owner_key)(struct file_lock___465 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___465 *);
	int (*lm_grant)(struct file_lock___465 *, int);
	bool (*lm_break)(struct file_lock___465 *);
	int (*lm_change)(struct file_lock___465 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___465 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___465 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___465 *fa_next;
	struct file___465 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___465 {
	const char *name;
	int fs_flags;
	struct dentry___465 * (*mount)(struct file_system_type___465 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___465 *);
	struct module___391 *owner;
	struct file_system_type___465 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___465 {
	struct inode___465 * (*alloc_inode)(struct super_block___465 *);
	void (*destroy_inode)(struct inode___465 *);
	void (*dirty_inode)(struct inode___465 *, int);
	int (*write_inode)(struct inode___465 *, struct writeback_control___218 *);
	int (*drop_inode)(struct inode___465 *);
	void (*evict_inode)(struct inode___465 *);
	void (*put_super)(struct super_block___465 *);
	int (*sync_fs)(struct super_block___465 *, int);
	int (*freeze_super)(struct super_block___465 *);
	int (*freeze_fs)(struct super_block___465 *);
	int (*thaw_super)(struct super_block___465 *);
	int (*unfreeze_fs)(struct super_block___465 *);
	int (*statfs)(struct dentry___465 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___465 *, int *, char *);
	void (*umount_begin)(struct super_block___465 *);
	int (*show_options)(struct seq_file___404 *, struct dentry___465 *);
	int (*show_devname)(struct seq_file___404 *, struct dentry___465 *);
	int (*show_path)(struct seq_file___404 *, struct dentry___465 *);
	int (*show_stats)(struct seq_file___404 *, struct dentry___465 *);
	ssize_t (*quota_read)(struct super_block___465 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___465 *, int, const char *, size_t, loff_t);
	struct dquot___465 ** (*get_dquots)(struct inode___465 *);
	int (*bdev_try_to_free_page)(struct super_block___465 *, struct page___466 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___465 *, struct shrink_control___198 *);
	long int (*free_cached_objects)(struct super_block___465 *, struct shrink_control___198 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___314)(struct file___465 *, wait_queue_head_t *, struct poll_table_struct___304 *);

struct poll_table_struct___304 {
	poll_queue_proc___314 _qproc;
	__poll_t _key;
};

struct seq_operations___404;

struct seq_file___404 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___404 *op;
	int poll_event;
	const struct file___465 *file;
	void *private;
};

typedef void bio_end_io_t___255(struct bio___255 *);

struct bio_integrity_payload___255;

struct bio_set___255;

struct bio___255 {
	struct bio___255 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___255 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___255 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___257 *bi_io_vec;
	struct bio_set___255 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___257 bi_inline_vecs[0];
};

struct socket_wq___91 {
	wait_queue_head_t wait;
	struct fasync_struct___465 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct sock___90;

struct proto_ops___91;

struct socket___92 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___91 *wq;
	struct file___465 *file;
	struct sock___90 *sk;
	const struct proto_ops___91 *ops;
};

typedef struct {
	struct net___121 *net;
} possible_net_t___112;

struct proto___90;

struct sock_common___90 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___90 *skc_prot;
	possible_net_t___112 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___90 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___111;

struct sk_buff_head___110 {
	struct sk_buff___111 *next;
	struct sk_buff___111 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___90;

struct xfrm_policy___24;

struct dst_entry___90;

struct net_device___110;

struct sock_reuseport___8;

struct sock___90 {
	struct sock_common___90 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___110 sk_error_queue;
	struct sk_buff_head___110 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___111 *head;
		struct sk_buff___111 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___90 *sk_filter;
	union {
		struct socket_wq___91 *sk_wq;
		struct socket_wq___91 *sk_wq_raw;
	};
	struct xfrm_policy___24 *sk_policy[2];
	struct dst_entry___90 *sk_rx_dst;
	struct dst_entry___90 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___111 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___110 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___466 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___90 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___260 *sk_peer_pid;
	const struct cred___433 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___92 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___198 *sk_memcg;
	void (*sk_state_change)(struct sock___90 *);
	void (*sk_data_ready)(struct sock___90 *);
	void (*sk_write_space)(struct sock___90 *);
	void (*sk_error_report)(struct sock___90 *);
	int (*sk_backlog_rcv)(struct sock___90 *, struct sk_buff___111 *);
	struct sk_buff___111 * (*sk_validate_xmit_skb)(struct sock___90 *, struct net_device___110 *, struct sk_buff___111 *);
	void (*sk_destruct)(struct sock___90 *);
	struct sock_reuseport___8 *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

typedef int (*sk_read_actor_t___90)(read_descriptor_t *, struct sk_buff___111 *, unsigned int, size_t);

struct proto_ops___91 {
	int family;
	struct module___391 *owner;
	int (*release)(struct socket___92 *);
	int (*bind)(struct socket___92 *, struct sockaddr *, int);
	int (*connect)(struct socket___92 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___92 *, struct socket___92 *);
	int (*accept)(struct socket___92 *, struct socket___92 *, int, bool);
	int (*getname)(struct socket___92 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___465 *, struct socket___92 *, struct poll_table_struct___304 *);
	int (*ioctl)(struct socket___92 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___92 *, int);
	int (*shutdown)(struct socket___92 *, int);
	int (*setsockopt)(struct socket___92 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___92 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___92 *, struct msghdr___93 *, size_t);
	int (*recvmsg)(struct socket___92 *, struct msghdr___93 *, size_t, int);
	int (*mmap)(struct file___465 *, struct socket___92 *, struct vm_area_struct___466 *);
	ssize_t (*sendpage)(struct socket___92 *, struct page___466 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___92 *, loff_t *, struct pipe_inode_info___146 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___90 *, int);
	int (*peek_len)(struct socket___92 *);
	int (*read_sock)(struct sock___90 *, read_descriptor_t *, sk_read_actor_t___90);
	int (*sendpage_locked)(struct sock___90 *, struct page___466 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___90 *, struct msghdr___93 *, size_t);
	int (*set_rcvlowat)(struct sock___90 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct sec_path___24;

struct nf_bridge_info___110;

struct sk_buff___111 {
	union {
		struct {
			struct sk_buff___111 *next;
			struct sk_buff___111 *prev;
			union {
				struct net_device___110 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___90 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___111 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path___24 *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___110 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___110;

struct netns_frags___110 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___110 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ip_ra_chain___55;

struct fib_rules_ops___90;

struct fib_notifier_ops___91;

struct netns_ipv4___110 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___55 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___90 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___90 *fibnl;
	struct sock___90 **icmp_sk;
	struct sock___90 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___90 **tcp_sk;
	struct netns_frags___110 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___90 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___91 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___91 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___90;

struct dst_ops___121 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___121 *);
	struct dst_entry___90 * (*check)(struct dst_entry___90 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___90 *);
	unsigned int (*mtu)(const struct dst_entry___90 *);
	u32 * (*cow_metrics)(struct dst_entry___90 *, long unsigned int);
	void (*destroy)(struct dst_entry___90 *);
	void (*ifdown)(struct dst_entry___90 *, struct net_device___110 *, int);
	struct dst_entry___90 * (*negative_advice)(struct dst_entry___90 *);
	void (*link_failure)(struct sk_buff___111 *);
	void (*update_pmtu)(struct dst_entry___90 *, struct sock___90 *, struct sk_buff___111 *, u32);
	void (*redirect)(struct dst_entry___90 *, struct sock___90 *, struct sk_buff___111 *);
	int (*local_out)(struct net___121 *, struct sock___90 *, struct sk_buff___111 *);
	struct neighbour___90 * (*neigh_lookup)(const struct dst_entry___90 *, struct sk_buff___111 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___90 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_info___31;

struct rt6_info___31;

struct fib6_table___31;

struct netns_ipv6___121 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___110 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info___31 *fib6_null_entry;
	struct rt6_info___31 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___31 *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___121 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info___31 *ip6_prohibit_entry;
	struct rt6_info___31 *ip6_blk_hole_entry;
	struct fib6_table___31 *fib6_local_tbl;
	struct fib_rules_ops___90 *fib6_rules_ops;
	struct sock___90 **icmp_sk;
	struct sock___90 *ndisc_sk;
	struct sock___90 *tcp_sk;
	struct sock___90 *igmp_sk;
	struct sock___90 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___90 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___91 *notifier_ops;
	struct fib_notifier_ops___91 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___91 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___90 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___110 {
	struct netns_frags___110 frags;
};

struct netns_xfrm___121 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___90 *nlsk;
	struct sock___90 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___121 xfrm4_dst_ops;
	struct dst_ops___121 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___100;

struct net___121 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___330 *user_ns;
	struct ucounts___330 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___29 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___90 *rtnl;
	struct sock___90 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___110 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___110 ipv4;
	struct netns_ipv6___121 ipv6;
	struct netns_sctp___91 sctp;
	struct netns_nf___20 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___110 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___90 *nfnl;
	struct sock___90 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___121 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___90 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___100 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kernfs_root___459;

struct kernfs_elem_dir___459 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___459 *root;
};

struct kernfs_syscall_ops___459;

struct kernfs_root___459 {
	struct kernfs_node___460 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___459 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___459 {
	struct kernfs_node___460 *target_kn;
};

struct kernfs_ops___459;

struct kernfs_elem_attr___459 {
	const struct kernfs_ops___459 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___460 *notify_next;
};

struct kernfs_node___460 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___460 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___459 dir;
		struct kernfs_elem_symlink___459 symlink;
		struct kernfs_elem_attr___459 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___459;

struct kernfs_ops___459 {
	int (*open)(struct kernfs_open_file___459 *);
	void (*release)(struct kernfs_open_file___459 *);
	int (*seq_show)(struct seq_file___404 *, void *);
	void * (*seq_start)(struct seq_file___404 *, loff_t *);
	void * (*seq_next)(struct seq_file___404 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___404 *, void *);
	ssize_t (*read)(struct kernfs_open_file___459 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___459 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___459 *, struct vm_area_struct___466 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___459 *, struct poll_table_struct___304 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___459 {
	int (*remount_fs)(struct kernfs_root___459 *, int *, char *);
	int (*show_options)(struct seq_file___404 *, struct kernfs_root___459 *);
	int (*mkdir)(struct kernfs_node___460 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___460 *);
	int (*rename)(struct kernfs_node___460 *, struct kernfs_node___460 *, const char *);
	int (*show_path)(struct seq_file___404 *, struct kernfs_node___460 *, struct kernfs_root___459 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___459 {
	struct kernfs_node___460 *kn;
	struct file___465 *file;
	struct seq_file___404 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___453 *vm_ops;
};

struct kobj_ns_type_operations___90 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___90 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___429;

struct attribute_group___430 {
	const char *name;
	umode_t (*is_visible)(struct kobject___453 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___453 *, struct bin_attribute___429 *, int);
	struct attribute **attrs;
	struct bin_attribute___429 **bin_attrs;
};

struct bin_attribute___429 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___465 *, struct kobject___453 *, struct bin_attribute___429 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___465 *, struct kobject___453 *, struct bin_attribute___429 *, char *, loff_t, size_t);
	int (*mmap)(struct file___465 *, struct kobject___453 *, struct bin_attribute___429 *, struct vm_area_struct___466 *);
};

struct sysfs_ops___452 {
	ssize_t (*show)(struct kobject___453 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___453 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___452;

struct kset___452 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___453 kobj;
	const struct kset_uevent_ops___452 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___452 {
	void (*release)(struct kobject___453 *);
	const struct sysfs_ops___452 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___90 * (*child_ns_type)(struct kobject___453 *);
	const void * (*namespace)(struct kobject___453 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___452 {
	int (* const filter)(struct kset___452 *, struct kobject___453 *);
	const char * (* const name)(struct kset___452 *, struct kobject___453 *);
	int (* const uevent)(struct kset___452 *, struct kobject___453 *, struct kobj_uevent_env *);
};

struct kobj_attribute___443 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___453 *, struct kobj_attribute___443 *, char *);
	ssize_t (*store)(struct kobject___453 *, struct kobj_attribute___443 *, const char *, size_t);
};

struct dev_pm_ops___433 {
	int (*prepare)(struct device___433 *);
	void (*complete)(struct device___433 *);
	int (*suspend)(struct device___433 *);
	int (*resume)(struct device___433 *);
	int (*freeze)(struct device___433 *);
	int (*thaw)(struct device___433 *);
	int (*poweroff)(struct device___433 *);
	int (*restore)(struct device___433 *);
	int (*suspend_late)(struct device___433 *);
	int (*resume_early)(struct device___433 *);
	int (*freeze_late)(struct device___433 *);
	int (*thaw_early)(struct device___433 *);
	int (*poweroff_late)(struct device___433 *);
	int (*restore_early)(struct device___433 *);
	int (*suspend_noirq)(struct device___433 *);
	int (*resume_noirq)(struct device___433 *);
	int (*freeze_noirq)(struct device___433 *);
	int (*thaw_noirq)(struct device___433 *);
	int (*poweroff_noirq)(struct device___433 *);
	int (*restore_noirq)(struct device___433 *);
	int (*runtime_suspend)(struct device___433 *);
	int (*runtime_resume)(struct device___433 *);
	int (*runtime_idle)(struct device___433 *);
};

struct dev_pm_info___433 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___433 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___433;

struct bus_type___433;

struct device_driver___433;

struct dev_pm_domain___433;

struct dma_map_ops___205;

struct fwnode_handle___353;

struct class___433;

struct device___433 {
	struct device___433 *parent;
	struct device_private *p;
	struct kobject___453 kobj;
	const char *init_name;
	const struct device_type___433 *type;
	struct mutex mutex;
	struct bus_type___433 *bus;
	struct device_driver___433 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___433 power;
	struct dev_pm_domain___433 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___205 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___353 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___433 *class;
	const struct attribute_group___430 **groups;
	void (*release)(struct device___433 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___433 {
	struct dev_pm_ops___433 ops;
	void (*detach)(struct device___433 *, bool);
	int (*activate)(struct device___433 *);
	void (*sync)(struct device___433 *);
	void (*dismiss)(struct device___433 *);
};

struct bus_type___433 {
	const char *name;
	const char *dev_name;
	struct device___433 *dev_root;
	const struct attribute_group___430 **bus_groups;
	const struct attribute_group___430 **dev_groups;
	const struct attribute_group___430 **drv_groups;
	int (*match)(struct device___433 *, struct device_driver___433 *);
	int (*uevent)(struct device___433 *, struct kobj_uevent_env *);
	int (*probe)(struct device___433 *);
	int (*remove)(struct device___433 *);
	void (*shutdown)(struct device___433 *);
	int (*online)(struct device___433 *);
	int (*offline)(struct device___433 *);
	int (*suspend)(struct device___433 *, pm_message_t);
	int (*resume)(struct device___433 *);
	int (*num_vf)(struct device___433 *);
	int (*dma_configure)(struct device___433 *);
	const struct dev_pm_ops___433 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___433 {
	const char *name;
	struct bus_type___433 *bus;
	struct module___391 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___433 *);
	int (*remove)(struct device___433 *);
	void (*shutdown)(struct device___433 *);
	int (*suspend)(struct device___433 *, pm_message_t);
	int (*resume)(struct device___433 *);
	const struct attribute_group___430 **groups;
	const struct dev_pm_ops___433 *pm;
	void (*coredump)(struct device___433 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___433 {
	const char *name;
	const struct attribute_group___430 **groups;
	int (*uevent)(struct device___433 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___433 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___433 *);
	const struct dev_pm_ops___433 *pm;
};

struct class___433 {
	const char *name;
	struct module___391 *owner;
	const struct attribute_group___430 **class_groups;
	const struct attribute_group___430 **dev_groups;
	struct kobject___453 *dev_kobj;
	int (*dev_uevent)(struct device___433 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___433 *, umode_t *);
	void (*class_release)(struct class___433 *);
	void (*dev_release)(struct device___433 *);
	int (*shutdown_pre)(struct device___433 *);
	const struct kobj_ns_type_operations___90 *ns_type;
	const void * (*namespace)(struct device___433 *);
	const struct dev_pm_ops___433 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___205 {
	void * (*alloc)(struct device___433 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___433 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___433 *, struct vm_area_struct___466 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___433 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___433 *, struct page___466 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___433 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___433 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___433 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___433 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___433 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___433 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___433 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___433 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___433 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___433 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___433 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___433 *, u64);
	u64 (*get_required_mask)(struct device___433 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___353;

struct fwnode_handle___353 {
	struct fwnode_handle___353 *secondary;
	const struct fwnode_operations___353 *ops;
};

typedef void compound_page_dtor___453(struct page___466 *);

struct fwnode_reference_args___353;

struct fwnode_endpoint___353;

struct fwnode_operations___353 {
	struct fwnode_handle___353 * (*get)(struct fwnode_handle___353 *);
	void (*put)(struct fwnode_handle___353 *);
	bool (*device_is_available)(const struct fwnode_handle___353 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___353 *, const struct device___433 *);
	bool (*property_present)(const struct fwnode_handle___353 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___353 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___353 *, const char *, const char **, size_t);
	struct fwnode_handle___353 * (*get_parent)(const struct fwnode_handle___353 *);
	struct fwnode_handle___353 * (*get_next_child_node)(const struct fwnode_handle___353 *, struct fwnode_handle___353 *);
	struct fwnode_handle___353 * (*get_named_child_node)(const struct fwnode_handle___353 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___353 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___353 *);
	struct fwnode_handle___353 * (*graph_get_next_endpoint)(const struct fwnode_handle___353 *, struct fwnode_handle___353 *);
	struct fwnode_handle___353 * (*graph_get_remote_endpoint)(const struct fwnode_handle___353 *);
	struct fwnode_handle___353 * (*graph_get_port_parent)(struct fwnode_handle___353 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___353 *, struct fwnode_endpoint___353 *);
};

struct fwnode_endpoint___353 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___353 *local_fwnode;
};

struct fwnode_reference_args___353 {
	struct fwnode_handle___353 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___146;

struct pipe_buffer___146 {
	struct page___466 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___146 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___146 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___146 *, struct pipe_buffer___146 *);
	void (*release)(struct pipe_inode_info___146 *, struct pipe_buffer___146 *);
	int (*steal)(struct pipe_inode_info___146 *, struct pipe_buffer___146 *);
	union {
		bool (*get)(struct pipe_inode_info___146 *, struct pipe_buffer___146 *);
		struct {
			void (*get)(struct pipe_inode_info___146 *, struct pipe_buffer___146 *);
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
};

struct nf_bridge_info___110 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___110 = 0,
		BRNF_PROTO_8021Q___110 = 1,
		BRNF_PROTO_PPPOE___110 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___110 *physindev;
	struct net_device___110 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___110(struct sk_buff___111 **);

struct net_device_ops___110;

struct ethtool_ops___110;

struct l3mdev_ops___90;

struct ndisc_ops___60;

struct xfrmdev_ops___110;

struct tlsdev_ops___110;

struct header_ops___110;

struct inet6_dev___60;

struct netdev_rx_queue___110;

struct mini_Qdisc___102;

struct netdev_queue___110;

struct Qdisc___102;

struct rtnl_link_ops___102;

struct dcbnl_rtnl_ops___110;

struct net_device___110 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___110 *netdev_ops;
	const struct ethtool_ops___110 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___90 *l3mdev_ops;
	const struct ndisc_ops___60 *ndisc_ops;
	const struct xfrmdev_ops___110 *xfrmdev_ops;
	const struct tlsdev_ops___110 *tlsdev_ops;
	const struct header_ops___110 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___452 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___60 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___110 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___100 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___110 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___102 *miniq_ingress;
	struct netdev_queue___110 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___110 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___102 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___102 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___110 = 0,
		NETREG_REGISTERED___110 = 1,
		NETREG_UNREGISTERING___110 = 2,
		NETREG_UNREGISTERED___110 = 3,
		NETREG_RELEASED___110 = 4,
		NETREG_DUMMY___110 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___110 = 0,
		RTNL_LINK_INITIALIZING___110 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___110 *);
	struct netpoll_info *npinfo;
	possible_net_t___112 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___433 dev;
	const struct attribute_group___430 *sysfs_groups[4];
	const struct attribute_group___430 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___102 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___110 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct skb_frag_struct___30 {
	struct {
		struct page___466 *p;
	} page;
	__u32 page_offset;
	__u32 size;
};

typedef struct skb_frag_struct___30 skb_frag_t___30;

struct skb_shared_info___30 {
	__u8 __unused;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___111 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___30 frags[16];
};

struct xfrm_state___24;

struct sec_path___24 {
	refcount_t refcnt;
	int len;
	int olen;
	struct xfrm_state___24 *xvec[6];
	struct xfrm_offload ovec[1];
};

struct ethtool_ops___110 {
	int (*get_settings)(struct net_device___110 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___110 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___110 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___110 *);
	void (*get_regs)(struct net_device___110 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___110 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___110 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___110 *);
	void (*set_msglevel)(struct net_device___110 *, u32);
	int (*nway_reset)(struct net_device___110 *);
	u32 (*get_link)(struct net_device___110 *);
	int (*get_eeprom_len)(struct net_device___110 *);
	int (*get_eeprom)(struct net_device___110 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___110 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___110 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___110 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___110 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___110 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___110 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___110 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___110 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___110 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___110 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___110 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___110 *);
	void (*complete)(struct net_device___110 *);
	u32 (*get_priv_flags)(struct net_device___110 *);
	int (*set_priv_flags)(struct net_device___110 *, u32);
	int (*get_sset_count)(struct net_device___110 *, int);
	int (*get_rxnfc)(struct net_device___110 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___110 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___110 *, struct ethtool_flash *);
	int (*reset)(struct net_device___110 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___110 *);
	u32 (*get_rxfh_indir_size)(struct net_device___110 *);
	int (*get_rxfh)(struct net_device___110 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___110 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___110 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___110 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___110 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___110 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___110 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___110 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___110 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___110 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___110 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___110 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___110 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___110 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___110 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___110 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___110 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___110 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___110 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___110 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___110 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___110 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	int (*get_fecparam)(struct net_device___110 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___110 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___110 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___110 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___110 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___110;

struct inet_frags___110 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___110 *, const void *);
	void (*destructor)(struct inet_frag_queue___110 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___110 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___111 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___111 *fragments_tail;
	struct sk_buff___111 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___110 *net;
	struct callback_head rcu;
};

struct ip_ra_chain___55 {
	struct ip_ra_chain___55 *next;
	struct sock___90 *sk;
	union {
		void (*destructor)(struct sock___90 *);
		struct sock___90 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___90;

struct fib_lookup_arg___90;

struct fib_rules_ops___90 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___90 *, struct flowi *, int, struct fib_lookup_arg___90 *);
	bool (*suppress)(struct fib_rule___90 *, struct fib_lookup_arg___90 *);
	int (*match)(struct fib_rule___90 *, struct flowi *, int);
	int (*configure)(struct fib_rule___90 *, struct sk_buff___111 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___90 *);
	int (*compare)(struct fib_rule___90 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___90 *, struct sk_buff___111 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___90 *);
	void (*flush_cache)(struct fib_rules_ops___90 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___391 *owner;
	struct net___121 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___91 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___121 *);
	int (*fib_dump)(struct net___121 *, struct notifier_block *);
	struct module___391 *owner;
	struct callback_head rcu;
};

struct lwtunnel_state___15;

struct dst_entry___90 {
	struct net_device___110 *dev;
	struct dst_ops___121 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state___24 *xfrm;
	int (*input)(struct sk_buff___111 *);
	int (*output)(struct net___121 *, struct sock___90 *, struct sk_buff___111 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___15 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___90;

struct neigh_parms___90;

struct neigh_ops___90;

struct neighbour___90 {
	struct neighbour___90 *next;
	struct neigh_table___90 *tbl;
	struct neigh_parms___90 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___110 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___90 *, struct sk_buff___111 *);
	const struct neigh_ops___90 *ops;
	struct callback_head rcu;
	struct net_device___110 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct fib6_nh___31 {
	struct in6_addr nh_gw;
	struct net_device___110 *nh_dev;
	struct lwtunnel_state___15 *nh_lwtstate;
	unsigned int nh_flags;
	atomic_t nh_upper_bound;
	int nh_weight;
};

struct fib6_node___31;

struct fib6_info___31 {
	struct fib6_table___31 *fib6_table;
	struct fib6_info___31 *fib6_next;
	struct fib6_node___31 *fib6_node;
	struct list_head fib6_siblings;
	unsigned int fib6_nsiblings;
	atomic_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	struct rt6_info___31 **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
	long unsigned int last_probe;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 exception_bucket_flushed: 1;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 dst_host: 1;
	u8 fib6_destroying: 1;
	u8 unused: 2;
	struct fib6_nh___31 fib6_nh;
	struct callback_head rcu;
};

struct rt6_info___31 {
	struct dst_entry___90 dst;
	struct fib6_info___31 *from;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___60 *rt6i_idev;
	u32 rt6i_flags;
	struct rt6key rt6i_prefsrc;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct fib6_node___31 {
	struct fib6_node___31 *parent;
	struct fib6_node___31 *left;
	struct fib6_node___31 *right;
	struct fib6_info___31 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info___31 *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table___31 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node___31 tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

struct ucounts___330 {
	struct hlist_node node;
	struct user_namespace___330 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_prog_aux___103;

struct bpf_prog___100 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___103 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

typedef int (*key_restrict_link_func_t___434)(struct key___433 *, const struct key_type *, const union key_payload *, struct key___433 *);

struct key_restriction___433;

struct key___433 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___467 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___433 *restrict_link;
};

struct key_restriction___433 {
	key_restrict_link_func_t___434 check;
	struct key___433 *key;
	struct key_type *keytype;
};

struct seq_operations___404 {
	void * (*start)(struct seq_file___404 *, loff_t *);
	void (*stop)(struct seq_file___404 *, void *);
	void * (*next)(struct seq_file___404 *, void *, loff_t *);
	int (*show)(struct seq_file___404 *, void *);
};

struct seq_net_private___14 {
	struct net___121 *net;
};

struct pernet_operations___111 {
	struct list_head list;
	int (*init)(struct net___121 *);
	void (*exit)(struct net___121 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___110 {
	int (*ieee_getets)(struct net_device___110 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___110 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___110 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___110 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___110 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___110 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___110 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___110 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___110 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___110 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___110 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___110 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___110 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___110 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___110 *);
	u8 (*setstate)(struct net_device___110 *, u8);
	void (*getpermhwaddr)(struct net_device___110 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___110 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___110 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___110 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___110 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___110 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___110 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___110 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___110 *, int, u8 *);
	void (*setpfccfg)(struct net_device___110 *, int, u8);
	void (*getpfccfg)(struct net_device___110 *, int, u8 *);
	u8 (*setall)(struct net_device___110 *);
	u8 (*getcap)(struct net_device___110 *, int, u8 *);
	int (*getnumtcs)(struct net_device___110 *, int, u8 *);
	int (*setnumtcs)(struct net_device___110 *, int, u8);
	u8 (*getpfcstate)(struct net_device___110 *);
	void (*setpfcstate)(struct net_device___110 *, u8);
	void (*getbcncfg)(struct net_device___110 *, int, u32 *);
	void (*setbcncfg)(struct net_device___110 *, int, u32);
	void (*getbcnrp)(struct net_device___110 *, int, u8 *);
	void (*setbcnrp)(struct net_device___110 *, int, u8);
	int (*setapp)(struct net_device___110 *, u8, u16, u8);
	int (*getapp)(struct net_device___110 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___110 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___110 *, int, u8);
	u8 (*getdcbx)(struct net_device___110 *);
	u8 (*setdcbx)(struct net_device___110 *, u8);
	int (*peer_getappinfo)(struct net_device___110 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___110 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___110 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___110 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___110 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___110 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___314 {
	refcount_t count;
	struct ns_common___29 ns;
	struct user_namespace___330 *user_ns;
	struct ucounts___330 *ucounts;
	struct css_set___314 *root_cset;
};

struct bpf_map___315;

struct bpf_map_ops___314 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___315 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___315 *, struct file___465 *);
	void (*map_free)(struct bpf_map___315 *);
	int (*map_get_next_key)(struct bpf_map___315 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___315 *);
	void * (*map_lookup_elem)(struct bpf_map___315 *, void *);
	int (*map_update_elem)(struct bpf_map___315 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___315 *, void *);
	int (*map_push_elem)(struct bpf_map___315 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___315 *, void *);
	int (*map_peek_elem)(struct bpf_map___315 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___315 *, struct file___465 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___315 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___315 *, void *, struct seq_file___404 *);
	int (*map_check_btf)(const struct bpf_map___315 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___315 {
	const struct bpf_map_ops___314 *ops;
	struct bpf_map___315 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___433 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___110;

struct bpf_map_dev_ops___110 {
	int (*map_get_next_key)(struct bpf_offloaded_map___110 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___110 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___110 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___110 *, void *);
};

struct bpf_offloaded_map___110 {
	struct bpf_map___315 map;
	struct net_device___110 *netdev;
	const struct bpf_map_dev_ops___110 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___100 {
	int (*test_run)(struct bpf_prog___100 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___100 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___100 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___100 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___100 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___100 *, u32 *);
};

struct bpf_prog_offload_ops___100 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___100 *);
	int (*translate)(struct bpf_prog___100 *);
	void (*destroy)(struct bpf_prog___100 *);
};

struct bpf_prog_offload___100 {
	struct bpf_prog___100 *prog;
	struct net_device___110 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___100 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___103 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___100 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___100 *ops;
	struct bpf_map___315 **used_maps;
	struct bpf_prog___100 *prog;
	struct user_struct___433 *user;
	u64 load_time;
	struct bpf_map___315 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___100 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___100 {
	struct bpf_prog___100 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___100 {
	struct callback_head rcu;
	struct bpf_prog_array_item___100 items[0];
};

struct cgroup_bpf___100 {
	struct bpf_prog_array___100 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___100 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___315;

typedef void (*kthread_work_func_t___315)(struct kthread_work___315 *);

struct kthread_worker___315;

struct kthread_work___315 {
	struct list_head node;
	kthread_work_func_t___315 func;
	struct kthread_worker___315 *worker;
	int canceling;
};

struct kthread_worker___315 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___467 *task;
	struct kthread_work___315 *current_work;
};

struct kthread_delayed_work___314 {
	struct kthread_work___315 work;
	struct timer_list timer;
};

struct psi_group___314 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___315 *poll_kworker;
	struct kthread_delayed_work___314 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___314;

struct cgroup_rstat_cpu___314;

struct cgroup___314 {
	struct cgroup_subsys_state___314 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___460 *kn;
	struct cgroup_file___314 procs_file;
	struct cgroup_file___314 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___314 *subsys[13];
	struct cgroup_root___314 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___314 *dom_cgrp;
	struct cgroup_rstat_cpu___314 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___100 bpf;
	atomic_t congestion_count;
	struct cgroup___314 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___314 psi;
	int ancestor_ids[0];
};

struct cftype___314;

struct cgroup_subsys___314 {
	struct cgroup_subsys_state___314 * (*css_alloc)(struct cgroup_subsys_state___314 *);
	int (*css_online)(struct cgroup_subsys_state___314 *);
	void (*css_offline)(struct cgroup_subsys_state___314 *);
	void (*css_released)(struct cgroup_subsys_state___314 *);
	void (*css_free)(struct cgroup_subsys_state___314 *);
	void (*css_reset)(struct cgroup_subsys_state___314 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___314 *, int);
	int (*css_extra_stat_show)(struct seq_file___404 *, struct cgroup_subsys_state___314 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___467 *);
	void (*cancel_fork)(struct task_struct___467 *);
	void (*fork)(struct task_struct___467 *);
	void (*exit)(struct task_struct___467 *);
	void (*free)(struct task_struct___467 *);
	void (*bind)(struct cgroup_subsys_state___314 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___314 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___314 *dfl_cftypes;
	struct cftype___314 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___314 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___314 *updated_children;
	struct cgroup___314 *updated_next;
};

struct cgroup_root___314 {
	struct kernfs_root___459 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___314 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___314 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___314 *ss;
	struct list_head node;
	struct kernfs_ops___459 *kf_ops;
	int (*open)(struct kernfs_open_file___459 *);
	void (*release)(struct kernfs_open_file___459 *);
	u64 (*read_u64)(struct cgroup_subsys_state___314 *, struct cftype___314 *);
	s64 (*read_s64)(struct cgroup_subsys_state___314 *, struct cftype___314 *);
	int (*seq_show)(struct seq_file___404 *, void *);
	void * (*seq_start)(struct seq_file___404 *, loff_t *);
	void * (*seq_next)(struct seq_file___404 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___404 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___314 *, struct cftype___314 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___314 *, struct cftype___314 *, s64);
	ssize_t (*write)(struct kernfs_open_file___459 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___459 *, struct poll_table_struct___304 *);
};

struct xdp_rxq_info___110 {
	struct net_device___110 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___110 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___110 *dev_rx;
};

struct netlink_callback___112 {
	struct sk_buff___111 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___112 *);
	int (*dump)(struct sk_buff___111 *, struct netlink_callback___112 *);
	int (*done)(struct netlink_callback___112 *);
	void *data;
	struct module___391 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___110 {
	int (*create)(struct sk_buff___111 *, struct net_device___110 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___111 *, unsigned char *);
	int (*cache)(const struct neighbour___90 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___110 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___110 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___110 *, int);
	int poll_owner;
	struct net_device___110 *dev;
	struct sk_buff___111 *gro_list;
	struct sk_buff___111 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___110 {
	struct net_device___110 *dev;
	struct Qdisc___102 *qdisc;
	struct Qdisc___102 *qdisc_sleeping;
	struct kobject___453 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___110 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___102 {
	struct sk_buff___111 *head;
	struct sk_buff___111 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___102;

struct Qdisc___102 {
	int (*enqueue)(struct sk_buff___111 *, struct Qdisc___102 *, struct sk_buff___111 **);
	struct sk_buff___111 * (*dequeue)(struct Qdisc___102 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___102 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___110 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___110 gso_skb;
	struct qdisc_skb_head___102 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___102 *next_sched;
	struct sk_buff_head___110 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___110 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___453 kobj;
	struct net_device___110 *dev;
	long: 64;
	struct xdp_rxq_info___110 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___110)(struct net_device___110 *, struct sk_buff___111 *, struct net_device___110 *);

struct netdev_bpf___110 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___100 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___100 *prog;
			const struct bpf_prog_offload_ops___100 *ops;
		} verifier;
		struct {
			struct bpf_prog___100 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___110 *offmap;
		};
		struct {
			struct xdp_umem___3 *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___110 {
	int (*xdo_dev_state_add)(struct xfrm_state___24 *);
	void (*xdo_dev_state_delete)(struct xfrm_state___24 *);
	void (*xdo_dev_state_free)(struct xfrm_state___24 *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___111 *, struct xfrm_state___24 *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state___24 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct xfrm_state_offload___24 {
	struct net_device___110 *dev;
	long unsigned int offload_handle;
	unsigned int num_exthdrs;
	u8 flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct xfrm_replay___24;

struct xfrm_type___24;

struct xfrm_mode___24;

struct xfrm_type_offload___24;

struct xfrm_state___24 {
	possible_net_t___112 xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	refcount_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
		u32 output_mark;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	const char *geniv;
	struct xfrm_encap_tmpl *encap;
	xfrm_address_t *coaddr;
	struct xfrm_state___24 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	const struct xfrm_replay___24 *repl;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct tasklet_hrtimer mtimer;
	struct xfrm_state_offload___24 xso;
	long int saved_tmo;
	long unsigned int lastused;
	struct page_frag___466 xfrag;
	const struct xfrm_type___24 *type;
	struct xfrm_mode___24 *inner_mode;
	struct xfrm_mode___24 *inner_mode_iaf;
	struct xfrm_mode___24 *outer_mode;
	const struct xfrm_type_offload___24 *type_offload;
	struct xfrm_sec_ctx___2 *security;
	void *data;
	u32 output_mark_mask;
	u32 if_id;
};

struct tlsdev_ops___110 {
	int (*tls_dev_add)(struct net_device___110 *, struct sock___90 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___110 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___110 *, struct sock___90 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___110 {
	int (*ndo_init)(struct net_device___110 *);
	void (*ndo_uninit)(struct net_device___110 *);
	int (*ndo_open)(struct net_device___110 *);
	int (*ndo_stop)(struct net_device___110 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___111 *, struct net_device___110 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___111 *, struct net_device___110 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___110 *, struct sk_buff___111 *, struct net_device___110 *, select_queue_fallback_t___110);
	void (*ndo_change_rx_flags)(struct net_device___110 *, int);
	void (*ndo_set_rx_mode)(struct net_device___110 *);
	int (*ndo_set_mac_address)(struct net_device___110 *, void *);
	int (*ndo_validate_addr)(struct net_device___110 *);
	int (*ndo_do_ioctl)(struct net_device___110 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___110 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___110 *, int);
	int (*ndo_neigh_setup)(struct net_device___110 *, struct neigh_parms___90 *);
	void (*ndo_tx_timeout)(struct net_device___110 *);
	void (*ndo_get_stats64)(struct net_device___110 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___110 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___110 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___110 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___110 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___110 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___110 *);
	int (*ndo_netpoll_setup)(struct net_device___110 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___110 *);
	int (*ndo_set_vf_mac)(struct net_device___110 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___110 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___110 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___110 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___110 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___110 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___110 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___110 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___110 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___110 *, int, struct sk_buff___111 *);
	int (*ndo_set_vf_guid)(struct net_device___110 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___110 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___110 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___110 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___110 *, const struct sk_buff___111 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___110 *, struct net_device___110 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___110 *, struct net_device___110 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___110 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___110 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___110 *, struct neighbour___90 *);
	void (*ndo_neigh_destroy)(struct net_device___110 *, struct neighbour___90 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___110 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___110 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___110 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___111 *, struct netlink_callback___112 *, struct net_device___110 *, struct net_device___110 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___110 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___110 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___111 *, u32, u32, struct net_device___110 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___110 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___110 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___110 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___110 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___110 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___110 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___110 *, struct net_device___110 *);
	void (*ndo_dfwd_del_station)(struct net_device___110 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___110 *);
	int (*ndo_set_tx_maxrate)(struct net_device___110 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___110 *);
	int (*ndo_change_proto_down)(struct net_device___110 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___110 *, struct sk_buff___111 *);
	void (*ndo_set_rx_headroom)(struct net_device___110 *, int);
	int (*ndo_bpf)(struct net_device___110 *, struct netdev_bpf___110 *);
	int (*ndo_xdp_xmit)(struct net_device___110 *, int, struct xdp_frame___110 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___110 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___110 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___90 {
	possible_net_t___112 net;
	struct net_device___110 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___90 *);
	void (*neigh_cleanup)(struct neighbour___90 *);
	struct neigh_table___90 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___90 {
	u32 (*l3mdev_fib_table)(const struct net_device___110 *);
	struct sk_buff___111 * (*l3mdev_l3_rcv)(struct net_device___110 *, struct sk_buff___111 *, u16);
	struct sk_buff___111 * (*l3mdev_l3_out)(struct net_device___110 *, struct sock___90 *, struct sk_buff___111 *, u16);
	struct dst_entry___90 * (*l3mdev_link_scope_lookup)(const struct net_device___110 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct ndisc_ops___60 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___110 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___110 *, struct neighbour___90 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___110 *, u8, struct neighbour___90 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___110 *, struct sk_buff___111 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___121 *, struct net_device___110 *, const struct prefix_info *, struct inet6_dev___60 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___60;

struct ifacaddr6___31;

struct inet6_dev___60 {
	struct net_device___110 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___60 *mc_list;
	struct ifmcaddr6___60 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___31 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	u8 rndid[8];
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___90 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
};

struct tcf_proto___102;

struct mini_Qdisc___102 {
	struct tcf_proto___102 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___102 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___110 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___121 *, struct net_device___110 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___110 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___110 *, struct list_head *);
	size_t (*get_size)(const struct net_device___110 *);
	int (*fill_info)(struct sk_buff___111 *, const struct net_device___110 *);
	size_t (*get_xstats_size)(const struct net_device___110 *);
	int (*fill_xstats)(struct sk_buff___111 *, const struct net_device___110 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___110 *, struct net_device___110 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___110 *, const struct net_device___110 *);
	int (*fill_slave_info)(struct sk_buff___111 *, const struct net_device___110 *, const struct net_device___110 *);
	struct net___121 * (*get_link_net)(const struct net_device___110 *);
	size_t (*get_linkxstats_size)(const struct net_device___110 *, int);
	int (*fill_linkxstats)(struct sk_buff___111 *, const struct net_device___110 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct offload_callbacks___20 {
	struct sk_buff___111 * (*gso_segment)(struct sk_buff___111 *, netdev_features_t);
	struct sk_buff___111 ** (*gro_receive)(struct sk_buff___111 **, struct sk_buff___111 *);
	int (*gro_complete)(struct sk_buff___111 *, int);
};

struct softnet_data___110 {
	struct list_head poll_list;
	struct sk_buff_head___110 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___110 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___102 *output_queue;
	struct Qdisc___102 **output_queue_tailp;
	struct sk_buff___111 *completion_queue;
	struct sk_buff_head___110 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___110 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___110 input_pkt_queue;
	struct napi_struct___110 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bdi_writeback_congested___255 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___255 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___255 {
	struct bio___255 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___257 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___257 bip_inline_vecs[0];
};

struct bio_set___255 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___255 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___198 {
	struct mem_cgroup___198 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___198 {
	struct lruvec___466 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___198 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___198 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct kernel_param_ops___391 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___391 *);
	int (*get)(char *, const struct kernel_param___391 *);
	void (*free)(void *);
};

struct kparam_array___391;

struct kernel_param___391 {
	const char *name;
	struct module___391 *mod;
	const struct kernel_param_ops___391 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___391 *arr;
	};
};

struct kparam_array___391 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___391 *ops;
	void *elem;
};

struct module_attribute___391 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___391 *, struct module_kobject___391 *, char *);
	ssize_t (*store)(struct module_attribute___391 *, struct module_kobject___391 *, const char *, size_t);
	void (*setup)(struct module___391 *, const char *);
	int (*test)(struct module___391 *);
	void (*free)(struct module___391 *);
};

struct gnet_dump___102 {
	spinlock_t *lock;
	struct sk_buff___111 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___102;

struct Qdisc_ops___102 {
	struct Qdisc_ops___102 *next;
	const struct Qdisc_class_ops___102 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___111 *, struct Qdisc___102 *, struct sk_buff___111 **);
	struct sk_buff___111 * (*dequeue)(struct Qdisc___102 *);
	struct sk_buff___111 * (*peek)(struct Qdisc___102 *);
	int (*init)(struct Qdisc___102 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___102 *);
	void (*destroy)(struct Qdisc___102 *);
	int (*change)(struct Qdisc___102 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___102 *);
	int (*change_tx_queue_len)(struct Qdisc___102 *, unsigned int);
	int (*dump)(struct Qdisc___102 *, struct sk_buff___111 *);
	int (*dump_stats)(struct Qdisc___102 *, struct gnet_dump___102 *);
	void (*ingress_block_set)(struct Qdisc___102 *, u32);
	void (*egress_block_set)(struct Qdisc___102 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___102 *);
	u32 (*egress_block_get)(struct Qdisc___102 *);
	struct module___391 *owner;
};

struct tcf_block___102;

struct Qdisc_class_ops___102 {
	unsigned int flags;
	struct netdev_queue___110 * (*select_queue)(struct Qdisc___102 *, struct tcmsg *);
	int (*graft)(struct Qdisc___102 *, long unsigned int, struct Qdisc___102 *, struct Qdisc___102 **, struct netlink_ext_ack *);
	struct Qdisc___102 * (*leaf)(struct Qdisc___102 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___102 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___102 *, u32);
	int (*change)(struct Qdisc___102 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___102 *, long unsigned int);
	void (*walk)(struct Qdisc___102 *, struct qdisc_walker *);
	struct tcf_block___102 * (*tcf_block)(struct Qdisc___102 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___102 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___102 *, long unsigned int);
	int (*dump)(struct Qdisc___102 *, long unsigned int, struct sk_buff___111 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___102 *, long unsigned int, struct gnet_dump___102 *);
};

struct tcf_chain___102;

struct tcf_block___102 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___121 *net;
	struct Qdisc___102 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___102 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___102;

struct tcf_proto_ops___102;

struct tcf_proto___102 {
	struct tcf_proto___102 *next;
	void *root;
	int (*classify)(struct sk_buff___111 *, const struct tcf_proto___102 *, struct tcf_result___102 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___102 *ops;
	struct tcf_chain___102 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___102 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___102 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___102 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___111 *, const struct tcf_proto___102 *, struct tcf_result___102 *);
	int (*init)(struct tcf_proto___102 *);
	void (*destroy)(struct tcf_proto___102 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___102 *, u32);
	void (*put)(struct tcf_proto___102 *, void *);
	int (*change)(struct net___121 *, struct sk_buff___111 *, struct tcf_proto___102 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___102 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___102 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___102 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___121 *, struct tcf_chain___102 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___121 *, struct tcf_proto___102 *, void *, struct sk_buff___111 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___111 *, struct net___121 *, void *);
	struct module___391 *owner;
	int flags;
};

struct tcf_chain___102 {
	struct mutex filter_chain_lock;
	struct tcf_proto___102 *filter_chain;
	struct list_head list;
	struct tcf_block___102 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___102 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___90 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___100 *prog;
};

struct bpf_redirect_info___100 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___315 *map;
	struct bpf_map___315 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___90;

struct neigh_hash_table___90;

struct neigh_table___90 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___110 *, __u32 *);
	bool (*key_eq)(const struct neighbour___90 *, const void *);
	int (*constructor)(struct neighbour___90 *);
	int (*pconstructor)(struct pneigh_entry___90 *);
	void (*pdestructor)(struct pneigh_entry___90 *);
	void (*proxy_redo)(struct sk_buff___111 *);
	char *id;
	struct neigh_parms___90 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___110 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___90 *nht;
	struct pneigh_entry___90 **phash_buckets;
};

struct neigh_ops___90 {
	int family;
	void (*solicit)(struct neighbour___90 *, struct sk_buff___111 *);
	void (*error_report)(struct neighbour___90 *, struct sk_buff___111 *);
	int (*output)(struct neighbour___90 *, struct sk_buff___111 *);
	int (*connected_output)(struct neighbour___90 *, struct sk_buff___111 *);
};

struct pneigh_entry___90 {
	struct pneigh_entry___90 *next;
	possible_net_t___112 net;
	struct net_device___110 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___90 {
	struct neighbour___90 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___15 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___121 *, struct sock___90 *, struct sk_buff___111 *);
	int (*orig_input)(struct sk_buff___111 *);
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	__u8 data[0];
};

struct fib_rule___90 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___90 *ctarget;
	struct net___121 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___90 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___90 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___72;

struct timewait_sock_ops___68;

struct proto___90 {
	void (*close)(struct sock___90 *, long int);
	int (*pre_connect)(struct sock___90 *, struct sockaddr *, int);
	int (*connect)(struct sock___90 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___90 *, int);
	struct sock___90 * (*accept)(struct sock___90 *, int, int *, bool);
	int (*ioctl)(struct sock___90 *, int, long unsigned int);
	int (*init)(struct sock___90 *);
	void (*destroy)(struct sock___90 *);
	void (*shutdown)(struct sock___90 *, int);
	int (*setsockopt)(struct sock___90 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___90 *, int, int, char *, int *);
	void (*keepalive)(struct sock___90 *, int);
	int (*sendmsg)(struct sock___90 *, struct msghdr___93 *, size_t);
	int (*recvmsg)(struct sock___90 *, struct msghdr___93 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___90 *, struct page___466 *, int, size_t, int);
	int (*bind)(struct sock___90 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___90 *, struct sk_buff___111 *);
	void (*release_cb)(struct sock___90 *);
	int (*hash)(struct sock___90 *);
	void (*unhash)(struct sock___90 *);
	void (*rehash)(struct sock___90 *);
	int (*get_port)(struct sock___90 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___90 *);
	bool (*stream_memory_read)(const struct sock___90 *);
	void (*enter_memory_pressure)(struct sock___90 *);
	void (*leave_memory_pressure)(struct sock___90 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___72 *rsk_prot;
	struct timewait_sock_ops___68 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___391 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___90 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct xfrm_policy_queue___24 {
	struct sk_buff_head___110 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___24 {
	possible_net_t___112 xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	refcount_t refcnt;
	struct timer_list timer;
	atomic_t genid;
	u32 priority;
	u32 index;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___24 polq;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx___2 *security;
	struct xfrm_tmpl xfrm_vec[6];
	struct callback_head rcu;
	u32 if_id;
};

struct sock_reuseport___8 {
	struct callback_head rcu;
	u16 max_socks;
	u16 num_socks;
	unsigned int reuseport_id;
	bool bind_inany;
	struct bpf_prog___100 *prog;
	struct sock___90 *socks[0];
};

struct request_sock___73;

struct request_sock_ops___72 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___90 *, struct request_sock___73 *);
	void (*send_ack)(const struct sock___90 *, struct sk_buff___111 *, struct request_sock___73 *);
	void (*send_reset)(const struct sock___90 *, struct sk_buff___111 *);
	void (*destructor)(struct request_sock___73 *);
	void (*syn_ack_timeout)(const struct request_sock___73 *);
};

struct timewait_sock_ops___68 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___90 *, struct sock___90 *, void *);
	void (*twsk_destructor)(struct sock___90 *);
};

struct request_sock___73 {
	struct sock_common___90 __req_common;
	struct request_sock___73 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___72 *rsk_ops;
	struct sock___90 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct inet_cork___26 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___90 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
	__u16 gso_size;
	u64 transmit_time;
};

struct inet_cork_full___26 {
	struct inet_cork___26 base;
	struct flowi fl;
};

struct ipv6_pinfo___26;

struct inet_sock___26 {
	struct sock___90 sk;
	struct ipv6_pinfo___26 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	__be16 inet_sport;
	__u16 inet_id;
	struct ip_options_rcu *inet_opt;
	int rx_dst_ifindex;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 bind_address_no_port: 1;
	__u8 defer_connect: 1;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___26 cork;
};

struct ipv6_fl_socklist___25;

struct ipv6_pinfo___26 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
			__u16 recvfragsize: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 repflow: 1;
	__u16 pmtudisc: 3;
	__u16 padding: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u16 autoflowlabel: 1;
	__u16 autoflowlabel_set: 1;
	__u8 min_hopcount;
	__u8 tclass;
	__be32 rcv_flowinfo;
	__u32 dst_cookie;
	__u32 rx_dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___25 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___111 *pktoptions;
	struct sk_buff___111 *rxpmtu;
	struct inet6_cork cork;
};

struct inet_connection_sock_af_ops___15 {
	int (*queue_xmit)(struct sock___90 *, struct sk_buff___111 *, struct flowi *);
	void (*send_check)(struct sock___90 *, struct sk_buff___111 *);
	int (*rebuild_header)(struct sock___90 *);
	void (*sk_rx_dst_set)(struct sock___90 *, const struct sk_buff___111 *);
	int (*conn_request)(struct sock___90 *, struct sk_buff___111 *);
	struct sock___90 * (*syn_recv_sock)(const struct sock___90 *, struct sk_buff___111 *, struct request_sock___73 *, struct dst_entry___90 *, struct request_sock___73 *, bool *);
	u16 net_header_len;
	u16 net_frag_header_len;
	u16 sockaddr_len;
	int (*setsockopt)(struct sock___90 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___90 *, int, int, char *, int *);
	void (*addr2sockaddr)(struct sock___90 *, struct sockaddr *);
	void (*mtu_reduced)(struct sock___90 *);
};

struct udp_sock___4 {
	struct inet_sock___26 inet;
	int pending;
	unsigned int corkflag;
	__u8 encap_type;
	unsigned char no_check6_tx: 1;
	unsigned char no_check6_rx: 1;
	__u16 len;
	__u16 gso_size;
	__u16 pcslen;
	__u16 pcrlen;
	__u8 pcflag;
	__u8 unused[3];
	int (*encap_rcv)(struct sock___90 *, struct sk_buff___111 *);
	int (*encap_err_lookup)(struct sock___90 *, struct sk_buff___111 *);
	void (*encap_destroy)(struct sock___90 *);
	struct sk_buff___111 ** (*gro_receive)(struct sock___90 *, struct sk_buff___111 **, struct sk_buff___111 *);
	int (*gro_complete)(struct sock___90 *, struct sk_buff___111 *, int);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___110 reader_queue;
	int forward_deficit;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ip6_flowlabel___25;

struct ipv6_fl_socklist___25 {
	struct ipv6_fl_socklist___25 *next;
	struct ip6_flowlabel___25 *fl;
	struct callback_head rcu;
};

struct ifmcaddr6___60 {
	struct in6_addr mca_addr;
	struct inet6_dev___60 *idev;
	struct ifmcaddr6___60 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___31 {
	struct in6_addr aca_addr;
	struct fib6_info___31 *aca_rt;
	struct ifacaddr6___31 *aca_next;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct ip6_ra_chain___60 {
	struct ip6_ra_chain___60 *next;
	struct sock___90 *sk;
	int sel;
	void (*destructor)(struct sock___90 *);
};

struct ip6_flowlabel___25 {
	struct ip6_flowlabel___25 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___260 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___121 *fl_net;
};

struct ipv6_stub___20 {
	int (*ipv6_sock_mc_join)(struct sock___90 *, int, const struct in6_addr *);
	int (*ipv6_sock_mc_drop)(struct sock___90 *, int, const struct in6_addr *);
	int (*ipv6_dst_lookup)(struct net___121 *, struct sock___90 *, struct dst_entry___90 **, struct flowi6 *);
	struct fib6_table___31 * (*fib6_get_table)(struct net___121 *, u32);
	struct fib6_info___31 * (*fib6_lookup)(struct net___121 *, int, struct flowi6 *, int);
	struct fib6_info___31 * (*fib6_table_lookup)(struct net___121 *, struct fib6_table___31 *, int, struct flowi6 *, int);
	struct fib6_info___31 * (*fib6_multipath_select)(const struct net___121 *, struct fib6_info___31 *, struct flowi6 *, int, const struct sk_buff___111 *, int);
	u32 (*ip6_mtu_from_fib6)(struct fib6_info___31 *, struct in6_addr *, struct in6_addr *);
	void (*udpv6_encap_enable)();
	void (*ndisc_send_na)(struct net_device___110 *, const struct in6_addr *, const struct in6_addr *, bool, bool, bool, bool);
	struct neigh_table___90 *nd_tbl;
};

struct ipv6_bpf_stub___20 {
	int (*inet6_bind)(struct sock___90 *, struct sockaddr *, int, bool, bool);
	struct sock___90 * (*udp6_lib_lookup)(struct net___121 *, const struct in6_addr *, __be16, const struct in6_addr *, __be16, int, int, struct udp_table *, struct sk_buff___111 *);
};

struct net_protocol___18 {
	int (*early_demux)(struct sk_buff___111 *);
	int (*early_demux_handler)(struct sk_buff___111 *);
	int (*handler)(struct sk_buff___111 *);
	void (*err_handler)(struct sk_buff___111 *, u32);
	unsigned int no_policy: 1;
	unsigned int netns_ok: 1;
	unsigned int icmp_strict_tag_validation: 1;
};

struct inet6_protocol___18 {
	void (*early_demux)(struct sk_buff___111 *);
	void (*early_demux_handler)(struct sk_buff___111 *);
	int (*handler)(struct sk_buff___111 *);
	void (*err_handler)(struct sk_buff___111 *, struct inet6_skb_parm *, u8, u8, int, __be32);
	unsigned int flags;
};

struct net_offload___18 {
	struct offload_callbacks___20 callbacks;
	unsigned int flags;
};

struct inet_protosw___4 {
	struct list_head list;
	short unsigned int type;
	short unsigned int protocol;
	struct proto___90 *prot;
	const struct proto_ops___91 *ops;
	unsigned char flags;
};

struct xfrm_replay___24 {
	void (*advance)(struct xfrm_state___24 *, __be32);
	int (*check)(struct xfrm_state___24 *, struct sk_buff___111 *, __be32);
	int (*recheck)(struct xfrm_state___24 *, struct sk_buff___111 *, __be32);
	void (*notify)(struct xfrm_state___24 *, int);
	int (*overflow)(struct xfrm_state___24 *, struct sk_buff___111 *);
};

struct xfrm_type___24 {
	char *description;
	struct module___391 *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___24 *);
	void (*destructor)(struct xfrm_state___24 *);
	int (*input)(struct xfrm_state___24 *, struct sk_buff___111 *);
	int (*output)(struct xfrm_state___24 *, struct sk_buff___111 *);
	int (*reject)(struct xfrm_state___24 *, struct sk_buff___111 *, const struct flowi *);
	int (*hdr_offset)(struct xfrm_state___24 *, struct sk_buff___111 *, u8 **);
	u32 (*get_mtu)(struct xfrm_state___24 *, int);
};

struct xfrm_state_afinfo___24;

struct xfrm_mode___24 {
	int (*input2)(struct xfrm_state___24 *, struct sk_buff___111 *);
	int (*input)(struct xfrm_state___24 *, struct sk_buff___111 *);
	int (*output2)(struct xfrm_state___24 *, struct sk_buff___111 *);
	int (*output)(struct xfrm_state___24 *, struct sk_buff___111 *);
	struct sk_buff___111 * (*gso_segment)(struct xfrm_state___24 *, struct sk_buff___111 *, netdev_features_t);
	void (*xmit)(struct xfrm_state___24 *, struct sk_buff___111 *);
	struct xfrm_state_afinfo___24 *afinfo;
	struct module___391 *owner;
	unsigned int encap;
	int flags;
};

struct xfrm_type_offload___24 {
	char *description;
	struct module___391 *owner;
	u8 proto;
	void (*encap)(struct xfrm_state___24 *, struct sk_buff___111 *);
	int (*input_tail)(struct xfrm_state___24 *, struct sk_buff___111 *);
	int (*xmit)(struct xfrm_state___24 *, struct sk_buff___111 *, netdev_features_t);
};

struct xfrm_state_afinfo___24 {
	unsigned int family;
	unsigned int proto;
	__be16 eth_proto;
	struct module___391 *owner;
	const struct xfrm_type___24 *type_map[256];
	const struct xfrm_type_offload___24 *type_offload_map[256];
	struct xfrm_mode___24 *mode_map[5];
	int (*init_flags)(struct xfrm_state___24 *);
	void (*init_tempsel)(struct xfrm_selector *, const struct flowi *);
	void (*init_temprop)(struct xfrm_state___24 *, const struct xfrm_tmpl *, const xfrm_address_t *, const xfrm_address_t *);
	int (*tmpl_sort)(struct xfrm_tmpl **, struct xfrm_tmpl **, int);
	int (*state_sort)(struct xfrm_state___24 **, struct xfrm_state___24 **, int);
	int (*output)(struct net___121 *, struct sock___90 *, struct sk_buff___111 *);
	int (*output_finish)(struct sock___90 *, struct sk_buff___111 *);
	int (*extract_input)(struct xfrm_state___24 *, struct sk_buff___111 *);
	int (*extract_output)(struct xfrm_state___24 *, struct sk_buff___111 *);
	int (*transport_finish)(struct sk_buff___111 *, int);
	void (*local_error)(struct sk_buff___111 *, u32);
};

struct udp_iter_state___2 {
	struct seq_net_private___14 p;
	int bucket;
};

struct seq_net_private___15 {
	struct net___107 *net;
};

struct icmp6_filter {
	__u32 data[8];
};

struct raw6_sock {
	struct inet_sock___23 inet;
	__u32 checksum;
	__u32 offset;
	struct icmp6_filter filter;
	__u32 ip6mr_table;
	struct ipv6_pinfo___23 inet6;
};

struct inet_protosw___5 {
	struct list_head list;
	short unsigned int type;
	short unsigned int protocol;
	struct proto___76 *prot;
	const struct proto_ops___77 *ops;
	unsigned char flags;
};

struct raw_iter_state___2 {
	struct seq_net_private___15 p;
	int bucket;
};

typedef int mh_filter_t(struct sock___76 *, struct sk_buff___97 *);

struct raw6_frag_vec {
	struct msghdr___79 *msg;
	int hlen;
	char c[4];
};

struct ipv6_destopt_hao {
	__u8 type;
	__u8 length;
	struct in6_addr addr;
} __attribute__((packed));

struct icmpv6_msg {
	struct sk_buff___85 *skb;
	int offset;
	uint8_t type;
};

struct icmp6_err {
	int err;
	int fatal;
};

struct mld_msg {
	struct icmp6hdr mld_hdr;
	struct in6_addr mld_mca;
};

struct mld2_grec {
	__u8 grec_type;
	__u8 grec_auxwords;
	__be16 grec_nsrcs;
	struct in6_addr grec_mca;
	struct in6_addr grec_src[0];
};

struct mld2_report {
	struct icmp6hdr mld2r_hdr;
	struct mld2_grec mld2r_grec[0];
};

struct mld2_query {
	struct icmp6hdr mld2q_hdr;
	struct in6_addr mld2q_mca;
	__u8 mld2q_qrv: 3;
	__u8 mld2q_suppress: 1;
	__u8 mld2q_resv2: 4;
	__u8 mld2q_qqic;
	__be16 mld2q_nsrcs;
	struct in6_addr mld2q_srcs[0];
};

struct igmp6_mc_iter_state {
	struct seq_net_private___7 p;
	struct net_device___84 *dev;
	struct inet6_dev___35 *idev;
};

struct igmp6_mcf_iter_state {
	struct seq_net_private___7 p;
	struct net_device___84 *dev;
	struct inet6_dev___35 *idev;
	struct ifmcaddr6___35 *im;
};

enum ip6_defrag_users {
	IP6_DEFRAG_LOCAL_DELIVER = 0,
	IP6_DEFRAG_CONNTRACK_IN = 1,
	__IP6_DEFRAG_CONNTRACK_IN = 65536,
	IP6_DEFRAG_CONNTRACK_OUT = 65537,
	__IP6_DEFRAG_CONNTRACK_OUT = 131072,
	IP6_DEFRAG_CONNTRACK_BRIDGE_IN = 131073,
	__IP6_DEFRAG_CONNTRACK_BRIDGE_IN = 196608,
};

struct frag_queue {
	struct inet_frag_queue___110 q;
	int iif;
	__u16 nhoffset;
	u8 ecn;
};

struct tcp6_sock {
	struct tcp_sock___8 tcp;
	struct ipv6_pinfo___8 inet6;
};

struct tcp6_pseudohdr {
	struct in6_addr saddr;
	struct in6_addr daddr;
	__be32 len;
	__be32 protocol;
};

struct pingv6_ops___4 {
	int (*ipv6_recv_error)(struct sock___90 *, struct msghdr___93 *, int, int *);
	void (*ip6_datagram_recv_common_ctl)(struct sock___90 *, struct msghdr___93 *, struct sk_buff___111 *);
	void (*ip6_datagram_recv_specific_ctl)(struct sock___90 *, struct msghdr___93 *, struct sk_buff___111 *);
	int (*icmpv6_err_convert)(u8, u8, int *);
	void (*ipv6_icmp_error)(struct sock___90 *, struct sk_buff___111 *, int, __be16, u32, u8 *);
	int (*ipv6_chk_addr)(struct net___121 *, const struct in6_addr *, const struct net_device___110 *, int);
};

struct ping_iter_state___2 {
	struct seq_net_private___15 p;
	int bucket;
	sa_family_t family;
};

struct pingfakehdr___2 {
	struct icmphdr icmph;
	struct msghdr___93 *msg;
	sa_family_t family;
	__wsum wcheck;
};

struct rt0_hdr {
	struct ipv6_rt_hdr rt_hdr;
	__u32 reserved;
	struct in6_addr addr[0];
};

struct tlvtype_proc {
	int type;
	bool (*func)(struct sk_buff___111 *, int);
};

struct ip6fl_iter_state {
	struct seq_net_private___15 p;
	struct pid_namespace___260 *pid_ns;
	int bucket;
};

struct module___392;

struct file___466;

struct kiocb___466;

struct iov_iter___233;

struct poll_table_struct___305;

struct vm_area_struct___467;

struct inode___466;

struct file_lock___466;

struct page___467;

struct pipe_inode_info___147;

struct seq_file___405;

struct file_operations___466 {
	struct module___392 *owner;
	loff_t (*llseek)(struct file___466 *, loff_t, int);
	ssize_t (*read)(struct file___466 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___466 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___466 *, struct iov_iter___233 *);
	ssize_t (*write_iter)(struct kiocb___466 *, struct iov_iter___233 *);
	int (*iopoll)(struct kiocb___466 *, bool);
	int (*iterate)(struct file___466 *, struct dir_context *);
	int (*iterate_shared)(struct file___466 *, struct dir_context *);
	__poll_t (*poll)(struct file___466 *, struct poll_table_struct___305 *);
	long int (*unlocked_ioctl)(struct file___466 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___466 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___466 *, struct vm_area_struct___467 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___466 *, struct file___466 *);
	int (*flush)(struct file___466 *, fl_owner_t);
	int (*release)(struct inode___466 *, struct file___466 *);
	int (*fsync)(struct file___466 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___466 *, int);
	int (*lock)(struct file___466 *, int, struct file_lock___466 *);
	ssize_t (*sendpage)(struct file___466 *, struct page___467 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___466 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___466 *, int, struct file_lock___466 *);
	ssize_t (*splice_write)(struct pipe_inode_info___147 *, struct file___466 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___466 *, loff_t *, struct pipe_inode_info___147 *, size_t, unsigned int);
	int (*setlease)(struct file___466 *, long int, struct file_lock___466 **, void **);
	long int (*fallocate)(struct file___466 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___405 *, struct file___466 *);
	ssize_t (*copy_file_range)(struct file___466 *, loff_t, struct file___466 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___466 *, loff_t, struct file___466 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___466 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___467 {
	u64 seqnum;
	struct vm_area_struct___467 *vmas[4];
};

struct page_frag___467 {
	struct page___467 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___467;

struct mem_cgroup___199;

struct cred___434;

struct nsproxy___361;

struct signal_struct___341;

struct bio_list___256;

struct backing_dev_info___256;

struct css_set___315;

struct vm_struct___370;

struct task_struct___468 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___468 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___467 *mm;
	struct mm_struct___467 *active_mm;
	struct vmacache___467 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___468 *real_parent;
	struct task_struct___468 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___468 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___199 *active_memcg;
	long int rh_reserved2;
	struct pid___260 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___260 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___260 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___434 *ptracer_cred;
	const struct cred___434 *real_cred;
	const struct cred___434 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___361 *nsproxy;
	struct signal_struct___341 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___468 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___256 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___256 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___315 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___147 *splice_pipe;
	struct page_frag___467 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___199 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___468 *oom_reaper_list;
	struct vm_struct___370 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___157 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rw_semaphore___468 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___468 *owner;
};

struct key___434;

struct ucounts___331;

struct user_namespace___331 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___331 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___29 ns;
	long unsigned int flags;
	struct key___434 *persistent_keyring_register;
	struct rw_semaphore___468 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___331 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef struct page___467 *pgtable_t___467;

struct address_space___466;

struct dev_pagemap___454;

struct page___467 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___466 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___467 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___467 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___467 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___454 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___199 *mem_cgroup;
};

struct pglist_data___467;

struct lruvec___467 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___467 *pgdat;
};

struct zone___467 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___467 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___467 {
	struct zone___467 *zone;
	int zone_idx;
};

struct zonelist___467 {
	struct zoneref___467 _zonerefs[25];
};

struct pglist_data___467 {
	struct zone___467 node_zones[3];
	struct zonelist___467 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___468 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___468 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___467 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct secondary_data___468 {
	void *stack;
	struct task_struct___468 *task;
	long int status;
};

struct blocking_notifier_head___467 {
	struct rw_semaphore___468 rwsem;
	struct notifier_block *head;
};

struct dentry___466;

struct path___467 {
	struct vfsmount *mnt;
	struct dentry___466 *dentry;
};

struct file___466 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___467 f_path;
	struct inode___466 *f_inode;
	const struct file_operations___466 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___260 f_owner;
	const struct cred___434 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___466 *f_mapping;
	errseq_t f_wb_err;
};

struct user_struct___434;

struct cred___434 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___434 *session_keyring;
	struct key___434 *process_keyring;
	struct key___434 *thread_keyring;
	struct key___434 *request_key_auth;
	void *security;
	struct user_struct___434 *user;
	struct user_namespace___331 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct kernfs_root___460;

struct kernfs_elem_dir___460 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___460 *root;
};

struct kernfs_node___461;

struct kernfs_syscall_ops___460;

struct kernfs_root___460 {
	struct kernfs_node___461 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___460 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___460 {
	struct kernfs_node___461 *target_kn;
};

struct kernfs_ops___460;

struct kernfs_elem_attr___460 {
	const struct kernfs_ops___460 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___461 *notify_next;
};

struct kernfs_node___461 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___461 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___460 dir;
		struct kernfs_elem_symlink___460 symlink;
		struct kernfs_elem_attr___460 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___460;

struct kernfs_ops___460 {
	int (*open)(struct kernfs_open_file___460 *);
	void (*release)(struct kernfs_open_file___460 *);
	int (*seq_show)(struct seq_file___405 *, void *);
	void * (*seq_start)(struct seq_file___405 *, loff_t *);
	void * (*seq_next)(struct seq_file___405 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___405 *, void *);
	ssize_t (*read)(struct kernfs_open_file___460 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___460 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___460 *, struct vm_area_struct___467 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___460 *, struct poll_table_struct___305 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___460 {
	int (*remount_fs)(struct kernfs_root___460 *, int *, char *);
	int (*show_options)(struct seq_file___405 *, struct kernfs_root___460 *);
	int (*mkdir)(struct kernfs_node___461 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___461 *);
	int (*rename)(struct kernfs_node___461 *, struct kernfs_node___461 *, const char *);
	int (*show_path)(struct seq_file___405 *, struct kernfs_node___461 *, struct kernfs_root___460 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___405;

struct seq_file___405 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___405 *op;
	int poll_event;
	const struct file___466 *file;
	void *private;
};

struct vm_operations_struct___454;

struct kernfs_open_file___460 {
	struct kernfs_node___461 *kn;
	struct file___466 *file;
	struct seq_file___405 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___454 *vm_ops;
};

struct vm_fault___454;

struct vm_operations_struct___454 {
	void (*open)(struct vm_area_struct___467 *);
	void (*close)(struct vm_area_struct___467 *);
	int (*split)(struct vm_area_struct___467 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___467 *);
	vm_fault_t (*fault)(struct vm_fault___454 *);
	vm_fault_t (*huge_fault)(struct vm_fault___454 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___454 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___467 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___454 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___454 *);
	int (*access)(struct vm_area_struct___467 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___467 *);
	int (*set_policy)(struct vm_area_struct___467 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___467 *, long unsigned int);
	struct page___467 * (*find_special_page)(struct vm_area_struct___467 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___315)(struct file___466 *, wait_queue_head_t *, struct poll_table_struct___305 *);

struct poll_table_struct___305 {
	poll_queue_proc___315 _qproc;
	__poll_t _key;
};

struct vm_area_struct___467 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___467 *vm_next;
	struct vm_area_struct___467 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___467 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___454 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___466 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sock___91;

struct kobj_ns_type_operations___91 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___91 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct net___122;

typedef struct {
	struct net___122 *net;
} possible_net_t___113;

struct proto___91;

struct sock_common___91 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___91 *skc_prot;
	possible_net_t___113 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___91 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___112;

struct sk_buff_head___111 {
	struct sk_buff___112 *next;
	struct sk_buff___112 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___91;

struct socket_wq___92;

struct dst_entry___91;

struct socket___93;

struct net_device___111;

struct sock_reuseport___9;

struct sock___91 {
	struct sock_common___91 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___111 sk_error_queue;
	struct sk_buff_head___111 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___112 *head;
		struct sk_buff___112 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___91 *sk_filter;
	union {
		struct socket_wq___92 *sk_wq;
		struct socket_wq___92 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___91 *sk_rx_dst;
	struct dst_entry___91 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___112 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___111 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___467 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___91 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___260 *sk_peer_pid;
	const struct cred___434 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___93 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___199 *sk_memcg;
	void (*sk_state_change)(struct sock___91 *);
	void (*sk_data_ready)(struct sock___91 *);
	void (*sk_write_space)(struct sock___91 *);
	void (*sk_error_report)(struct sock___91 *);
	int (*sk_backlog_rcv)(struct sock___91 *, struct sk_buff___112 *);
	struct sk_buff___112 * (*sk_validate_xmit_skb)(struct sock___91 *, struct net_device___111 *, struct sk_buff___112 *);
	void (*sk_destruct)(struct sock___91 *);
	struct sock_reuseport___9 *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kobject___454;

struct bin_attribute___430;

struct attribute_group___431 {
	const char *name;
	umode_t (*is_visible)(struct kobject___454 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___454 *, struct bin_attribute___430 *, int);
	struct attribute **attrs;
	struct bin_attribute___430 **bin_attrs;
};

struct kset___453;

struct kobj_type___453;

struct kobject___454 {
	const char *name;
	struct list_head entry;
	struct kobject___454 *parent;
	struct kset___453 *kset;
	struct kobj_type___453 *ktype;
	struct kernfs_node___461 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___430 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___466 *, struct kobject___454 *, struct bin_attribute___430 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___466 *, struct kobject___454 *, struct bin_attribute___430 *, char *, loff_t, size_t);
	int (*mmap)(struct file___466 *, struct kobject___454 *, struct bin_attribute___430 *, struct vm_area_struct___467 *);
};

struct sysfs_ops___453 {
	ssize_t (*show)(struct kobject___454 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___454 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___453;

struct kset___453 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___454 kobj;
	const struct kset_uevent_ops___453 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___453 {
	void (*release)(struct kobject___454 *);
	const struct sysfs_ops___453 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___91 * (*child_ns_type)(struct kobject___454 *);
	const void * (*namespace)(struct kobject___454 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___453 {
	int (* const filter)(struct kset___453 *, struct kobject___454 *);
	const char * (* const name)(struct kset___453 *, struct kobject___454 *);
	int (* const uevent)(struct kset___453 *, struct kobject___454 *, struct kobj_uevent_env *);
};

struct kobj_attribute___444 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___454 *, struct kobj_attribute___444 *, char *);
	ssize_t (*store)(struct kobject___454 *, struct kobj_attribute___444 *, const char *, size_t);
};

struct kernel_param___392;

struct kernel_param_ops___392 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___392 *);
	int (*get)(char *, const struct kernel_param___392 *);
	void (*free)(void *);
};

struct kparam_array___392;

struct kernel_param___392 {
	const char *name;
	struct module___392 *mod;
	const struct kernel_param_ops___392 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___392 *arr;
	};
};

struct kparam_array___392 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___392 *ops;
	void *elem;
};

struct module_kobject___392 {
	struct kobject___454 kobj;
	struct module___392 *mod;
	struct kobject___454 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___392 {
	struct module___392 *mod;
	struct latch_tree_node node;
};

struct module_layout___392 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___392 mtn;
};

struct module_attribute___392;

struct module___392 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___392 mkobj;
	struct module_attribute___392 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___454 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___392 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___392 core_layout;
	struct module_layout___392 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___392 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___392 *, struct module_kobject___392 *, char *);
	ssize_t (*store)(struct module_attribute___392 *, struct module_kobject___392 *, const char *, size_t);
	void (*setup)(struct module___392 *, const char *);
	int (*test)(struct module___392 *);
	void (*free)(struct module___392 *);
};

struct cgroup___315;

struct cgroup_subsys___315;

struct cgroup_subsys_state___315 {
	struct cgroup___315 *cgroup;
	struct cgroup_subsys___315 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___315 *parent;
};

struct cgroup_file___315 {
	struct kernfs_node___461 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___199;

struct mem_cgroup___199 {
	struct cgroup_subsys_state___315 css;
	struct mem_cgroup_id___13 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___315 events_file;
	struct cgroup_file___315 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___468 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___199 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct user_struct___434 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___434 *uid_keyring;
	struct key___434 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___467;

struct mm_struct___467 {
	struct {
		struct vm_area_struct___467 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___466 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___468 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___467 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___468 *owner;
		struct user_namespace___331 *user_ns;
		struct file___466 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___467 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___315;

struct nsproxy___361 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net___122 *net_ns;
	struct cgroup_namespace___315 *cgroup_ns;
};

struct signal_struct___341 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___468 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___468 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___260 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___260 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___467 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___260 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___256;

struct bio_list___256 {
	struct bio___256 *head;
	struct bio___256 *tail;
};

struct bdi_writeback_congested___256;

struct bdi_writeback___256 {
	struct backing_dev_info___256 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___256 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___315 *memcg_css;
	struct cgroup_subsys_state___315 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___434;

struct backing_dev_info___256 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___256 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___434 *dev;
	struct device___434 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___466 *debug_dir;
	struct dentry___466 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___315 {
	struct cgroup_subsys_state___315 *subsys[13];
	refcount_t refcount;
	struct css_set___315 *dom_cset;
	struct cgroup___315 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___315 *mg_src_cgrp;
	struct cgroup___315 *mg_dst_cgrp;
	struct css_set___315 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___466;

struct pipe_buffer___147;

struct pipe_inode_info___147 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___467 *tmp_page;
	struct fasync_struct___466 *fasync_readers;
	struct fasync_struct___466 *fasync_writers;
	struct pipe_buffer___147 *bufs;
	struct user_struct___434 *user;
};

struct vm_struct___370 {
	struct vm_struct___370 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___467 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___353 {
	struct task_struct___468 task;
	long unsigned int stack[8192];
};

struct address_space_operations___466;

struct address_space___466 {
	struct inode___466 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___468 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___466 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___454)(struct vm_area_struct___467 *, long unsigned int, const struct page___467 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___454)(struct page___467 *, void *);

struct dev_pagemap___454 {
	dev_page_fault_t___454 page_fault;
	dev_page_free_t___454 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___434 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___467 {
	struct task_struct___468 *task;
	struct core_thread___467 *next;
};

struct core_state___467 {
	atomic_t nr_threads;
	struct core_thread___467 dumper;
	struct completion startup;
};

struct vm_fault___454 {
	struct vm_area_struct___467 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___467 *cow_page;
	struct mem_cgroup___199 *memcg;
	struct page___467 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___467 prealloc_pte;
};

struct bio_vec___258 {
	struct page___467 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___233 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___258 *bvec;
		struct pipe_inode_info___147 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct msghdr___94 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___233 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___466 *msg_iocb;
};

struct kiocb___466 {
	struct file___466 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___466 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dentry_operations___466;

struct super_block___466;

struct dentry___466 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___466 *d_parent;
	struct qstr d_name;
	struct inode___466 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___466 *d_op;
	struct super_block___466 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___466;

struct block_device___466;

struct inode___466 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___466 *i_op;
	struct super_block___466 *i_sb;
	struct address_space___466 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___468 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___256 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___466 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___466 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___147 *i_pipe;
		struct block_device___466 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___466 {
	int (*d_revalidate)(struct dentry___466 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___466 *, unsigned int);
	int (*d_hash)(const struct dentry___466 *, struct qstr *);
	int (*d_compare)(const struct dentry___466 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___466 *);
	int (*d_init)(struct dentry___466 *);
	void (*d_release)(struct dentry___466 *);
	void (*d_prune)(struct dentry___466 *);
	void (*d_iput)(struct dentry___466 *, struct inode___466 *);
	char * (*d_dname)(struct dentry___466 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___467 *);
	int (*d_manage)(const struct path___467 *, bool);
	struct dentry___466 * (*d_real)(struct dentry___466 *, const struct inode___466 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___466;

struct mem_dqinfo___466 {
	struct quota_format_type___466 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___466;

struct quota_info___466 {
	unsigned int flags;
	struct rw_semaphore___468 dqio_sem;
	struct inode___466 *files[3];
	struct mem_dqinfo___466 info[3];
	const struct quota_format_ops___466 *ops[3];
};

struct rcuwait___466 {
	struct task_struct___468 *task;
};

struct percpu_rw_semaphore___466 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___468 rw_sem;
	struct rcuwait___466 writer;
	int readers_block;
};

struct sb_writers___466 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___466 rw_sem[3];
};

struct shrink_control___199;

struct shrinker___199 {
	long unsigned int (*count_objects)(struct shrinker___199 *, struct shrink_control___199 *);
	long unsigned int (*scan_objects)(struct shrinker___199 *, struct shrink_control___199 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___466;

struct super_operations___466;

struct dquot_operations___466;

struct quotactl_ops___466;

struct super_block___466 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___466 *s_type;
	const struct super_operations___466 *s_op;
	const struct dquot_operations___466 *dq_op;
	const struct quotactl_ops___466 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___466 *s_root;
	struct rw_semaphore___468 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___466 *s_bdev;
	struct backing_dev_info___256 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___466 s_dquot;
	struct sb_writers___466 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___466 *s_d_op;
	int cleancache_poolid;
	struct shrinker___199 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___331 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___199 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___199 *memcg;
};

struct iattr___466 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___466 *ia_file;
};

struct dquot___466 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___466 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___466 {
	int qf_fmt_id;
	const struct quota_format_ops___466 *qf_ops;
	struct module___392 *qf_owner;
	struct quota_format_type___466 *qf_next;
};

struct quota_format_ops___466 {
	int (*check_quota_file)(struct super_block___466 *, int);
	int (*read_file_info)(struct super_block___466 *, int);
	int (*write_file_info)(struct super_block___466 *, int);
	int (*free_file_info)(struct super_block___466 *, int);
	int (*read_dqblk)(struct dquot___466 *);
	int (*commit_dqblk)(struct dquot___466 *);
	int (*release_dqblk)(struct dquot___466 *);
	int (*get_next_id)(struct super_block___466 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___466 {
	int (*write_dquot)(struct dquot___466 *);
	struct dquot___466 * (*alloc_dquot)(struct super_block___466 *, int);
	void (*destroy_dquot)(struct dquot___466 *);
	int (*acquire_dquot)(struct dquot___466 *);
	int (*release_dquot)(struct dquot___466 *);
	int (*mark_dirty)(struct dquot___466 *);
	int (*write_info)(struct super_block___466 *, int);
	qsize_t * (*get_reserved_space)(struct inode___466 *);
	int (*get_projid)(struct inode___466 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___466 *, qsize_t *);
	int (*get_next_id)(struct super_block___466 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___466 {
	int (*quota_on)(struct super_block___466 *, int, int, const struct path___467 *);
	int (*quota_off)(struct super_block___466 *, int);
	int (*quota_enable)(struct super_block___466 *, unsigned int);
	int (*quota_disable)(struct super_block___466 *, unsigned int);
	int (*quota_sync)(struct super_block___466 *, int);
	int (*set_info)(struct super_block___466 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___466 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___466 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___466 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___466 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___466 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___219;

struct address_space_operations___466 {
	int (*writepage)(struct page___467 *, struct writeback_control___219 *);
	int (*readpage)(struct file___466 *, struct page___467 *);
	int (*writepages)(struct address_space___466 *, struct writeback_control___219 *);
	int (*set_page_dirty)(struct page___467 *);
	int (*readpages)(struct file___466 *, struct address_space___466 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___466 *, struct address_space___466 *, loff_t, unsigned int, unsigned int, struct page___467 **, void **);
	int (*write_end)(struct file___466 *, struct address_space___466 *, loff_t, unsigned int, unsigned int, struct page___467 *, void *);
	sector_t (*bmap)(struct address_space___466 *, sector_t);
	void (*invalidatepage)(struct page___467 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___467 *, gfp_t);
	void (*freepage)(struct page___467 *);
	ssize_t (*direct_IO)(struct kiocb___466 *, struct iov_iter___233 *);
	int (*migratepage)(struct address_space___466 *, struct page___467 *, struct page___467 *, enum migrate_mode);
	bool (*isolate_page)(struct page___467 *, isolate_mode_t);
	void (*putback_page)(struct page___467 *);
	int (*launder_page)(struct page___467 *);
	int (*is_partially_uptodate)(struct page___467 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___467 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___466 *, struct page___467 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___466 *, sector_t *);
	void (*swap_deactivate)(struct file___466 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___219 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___256 *wb;
	struct inode___466 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___466 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___466 *bd_inode;
	struct super_block___466 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___466 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___256 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___466 {
	struct dentry___466 * (*lookup)(struct inode___466 *, struct dentry___466 *, unsigned int);
	const char * (*get_link)(struct dentry___466 *, struct inode___466 *, struct delayed_call *);
	int (*permission)(struct inode___466 *, int);
	struct posix_acl * (*get_acl)(struct inode___466 *, int);
	int (*readlink)(struct dentry___466 *, char *, int);
	int (*create)(struct inode___466 *, struct dentry___466 *, umode_t, bool);
	int (*link)(struct dentry___466 *, struct inode___466 *, struct dentry___466 *);
	int (*unlink)(struct inode___466 *, struct dentry___466 *);
	int (*symlink)(struct inode___466 *, struct dentry___466 *, const char *);
	int (*mkdir)(struct inode___466 *, struct dentry___466 *, umode_t);
	int (*rmdir)(struct inode___466 *, struct dentry___466 *);
	int (*mknod)(struct inode___466 *, struct dentry___466 *, umode_t, dev_t);
	int (*rename)(struct inode___466 *, struct dentry___466 *, struct inode___466 *, struct dentry___466 *, unsigned int);
	int (*setattr)(struct dentry___466 *, struct iattr___466 *);
	int (*getattr)(const struct path___467 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___466 *, char *, size_t);
	int (*fiemap)(struct inode___466 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___466 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___466 *, struct dentry___466 *, struct file___466 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___466 *, struct dentry___466 *, umode_t);
	int (*set_acl)(struct inode___466 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___466 {
	void (*fl_copy_lock)(struct file_lock___466 *, struct file_lock___466 *);
	void (*fl_release_private)(struct file_lock___466 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___466;

struct file_lock___466 {
	struct file_lock___466 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___466 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___466 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___466 *fl_ops;
	const struct lock_manager_operations___466 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___466 {
	int (*lm_compare_owner)(struct file_lock___466 *, struct file_lock___466 *);
	long unsigned int (*lm_owner_key)(struct file_lock___466 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___466 *);
	int (*lm_grant)(struct file_lock___466 *, int);
	bool (*lm_break)(struct file_lock___466 *);
	int (*lm_change)(struct file_lock___466 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___466 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___466 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___466 *fa_next;
	struct file___466 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___466 {
	const char *name;
	int fs_flags;
	struct dentry___466 * (*mount)(struct file_system_type___466 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___466 *);
	struct module___392 *owner;
	struct file_system_type___466 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___466 {
	struct inode___466 * (*alloc_inode)(struct super_block___466 *);
	void (*destroy_inode)(struct inode___466 *);
	void (*dirty_inode)(struct inode___466 *, int);
	int (*write_inode)(struct inode___466 *, struct writeback_control___219 *);
	int (*drop_inode)(struct inode___466 *);
	void (*evict_inode)(struct inode___466 *);
	void (*put_super)(struct super_block___466 *);
	int (*sync_fs)(struct super_block___466 *, int);
	int (*freeze_super)(struct super_block___466 *);
	int (*freeze_fs)(struct super_block___466 *);
	int (*thaw_super)(struct super_block___466 *);
	int (*unfreeze_fs)(struct super_block___466 *);
	int (*statfs)(struct dentry___466 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___466 *, int *, char *);
	void (*umount_begin)(struct super_block___466 *);
	int (*show_options)(struct seq_file___405 *, struct dentry___466 *);
	int (*show_devname)(struct seq_file___405 *, struct dentry___466 *);
	int (*show_path)(struct seq_file___405 *, struct dentry___466 *);
	int (*show_stats)(struct seq_file___405 *, struct dentry___466 *);
	ssize_t (*quota_read)(struct super_block___466 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___466 *, int, const char *, size_t, loff_t);
	struct dquot___466 ** (*get_dquots)(struct inode___466 *);
	int (*bdev_try_to_free_page)(struct super_block___466 *, struct page___467 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___466 *, struct shrink_control___199 *);
	long int (*free_cached_objects)(struct super_block___466 *, struct shrink_control___199 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___256(struct bio___256 *);

struct bio_integrity_payload___256;

struct bio_set___256;

struct bio___256 {
	struct bio___256 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___256 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___256 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___258 *bi_io_vec;
	struct bio_set___256 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___258 bi_inline_vecs[0];
};

struct socket_wq___92 {
	wait_queue_head_t wait;
	struct fasync_struct___466 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___92;

struct socket___93 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___92 *wq;
	struct file___466 *file;
	struct sock___91 *sk;
	const struct proto_ops___92 *ops;
};

typedef int (*sk_read_actor_t___91)(read_descriptor_t *, struct sk_buff___112 *, unsigned int, size_t);

struct proto_ops___92 {
	int family;
	struct module___392 *owner;
	int (*release)(struct socket___93 *);
	int (*bind)(struct socket___93 *, struct sockaddr *, int);
	int (*connect)(struct socket___93 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___93 *, struct socket___93 *);
	int (*accept)(struct socket___93 *, struct socket___93 *, int, bool);
	int (*getname)(struct socket___93 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___466 *, struct socket___93 *, struct poll_table_struct___305 *);
	int (*ioctl)(struct socket___93 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___93 *, int);
	int (*shutdown)(struct socket___93 *, int);
	int (*setsockopt)(struct socket___93 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___93 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___93 *, struct msghdr___94 *, size_t);
	int (*recvmsg)(struct socket___93 *, struct msghdr___94 *, size_t, int);
	int (*mmap)(struct file___466 *, struct socket___93 *, struct vm_area_struct___467 *);
	ssize_t (*sendpage)(struct socket___93 *, struct page___467 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___93 *, loff_t *, struct pipe_inode_info___147 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___91 *, int);
	int (*peek_len)(struct socket___93 *);
	int (*read_sock)(struct sock___91 *, read_descriptor_t *, sk_read_actor_t___91);
	int (*sendpage_locked)(struct sock___91 *, struct page___467 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___91 *, struct msghdr___94 *, size_t);
	int (*set_rcvlowat)(struct sock___91 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct nf_bridge_info___111;

struct sk_buff___112 {
	union {
		struct {
			struct sk_buff___112 *next;
			struct sk_buff___112 *prev;
			union {
				struct net_device___111 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___91 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___112 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___111 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___111;

struct netns_frags___111 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___111 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_rules_ops___91;

struct fib_notifier_ops___92;

struct netns_ipv4___111 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___91 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___91 *fibnl;
	struct sock___91 **icmp_sk;
	struct sock___91 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___91 **tcp_sk;
	struct netns_frags___111 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___91 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___92 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___92 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___91;

struct dst_ops___122 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___122 *);
	struct dst_entry___91 * (*check)(struct dst_entry___91 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___91 *);
	unsigned int (*mtu)(const struct dst_entry___91 *);
	u32 * (*cow_metrics)(struct dst_entry___91 *, long unsigned int);
	void (*destroy)(struct dst_entry___91 *);
	void (*ifdown)(struct dst_entry___91 *, struct net_device___111 *, int);
	struct dst_entry___91 * (*negative_advice)(struct dst_entry___91 *);
	void (*link_failure)(struct sk_buff___112 *);
	void (*update_pmtu)(struct dst_entry___91 *, struct sock___91 *, struct sk_buff___112 *, u32);
	void (*redirect)(struct dst_entry___91 *, struct sock___91 *, struct sk_buff___112 *);
	int (*local_out)(struct net___122 *, struct sock___91 *, struct sk_buff___112 *);
	struct neighbour___91 * (*neigh_lookup)(const struct dst_entry___91 *, struct sk_buff___112 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___91 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_info___32;

struct rt6_info___32;

struct fib6_table___32;

struct netns_ipv6___122 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___111 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info___32 *fib6_null_entry;
	struct rt6_info___32 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___32 *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___122 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info___32 *ip6_prohibit_entry;
	struct rt6_info___32 *ip6_blk_hole_entry;
	struct fib6_table___32 *fib6_local_tbl;
	struct fib_rules_ops___91 *fib6_rules_ops;
	struct sock___91 **icmp_sk;
	struct sock___91 *ndisc_sk;
	struct sock___91 *tcp_sk;
	struct sock___91 *igmp_sk;
	struct sock___91 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___91 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___92 *notifier_ops;
	struct fib_notifier_ops___92 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___92 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___91 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___111 {
	struct netns_frags___111 frags;
};

struct netns_xfrm___122 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___91 *nlsk;
	struct sock___91 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___122 xfrm4_dst_ops;
	struct dst_ops___122 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___101;

struct net___122 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___331 *user_ns;
	struct ucounts___331 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___29 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___91 *rtnl;
	struct sock___91 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___111 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___111 ipv4;
	struct netns_ipv6___122 ipv6;
	struct netns_sctp___92 sctp;
	struct netns_nf___20 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___111 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___91 *nfnl;
	struct sock___91 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___122 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___91 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___101 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___434 {
	int (*prepare)(struct device___434 *);
	void (*complete)(struct device___434 *);
	int (*suspend)(struct device___434 *);
	int (*resume)(struct device___434 *);
	int (*freeze)(struct device___434 *);
	int (*thaw)(struct device___434 *);
	int (*poweroff)(struct device___434 *);
	int (*restore)(struct device___434 *);
	int (*suspend_late)(struct device___434 *);
	int (*resume_early)(struct device___434 *);
	int (*freeze_late)(struct device___434 *);
	int (*thaw_early)(struct device___434 *);
	int (*poweroff_late)(struct device___434 *);
	int (*restore_early)(struct device___434 *);
	int (*suspend_noirq)(struct device___434 *);
	int (*resume_noirq)(struct device___434 *);
	int (*freeze_noirq)(struct device___434 *);
	int (*thaw_noirq)(struct device___434 *);
	int (*poweroff_noirq)(struct device___434 *);
	int (*restore_noirq)(struct device___434 *);
	int (*runtime_suspend)(struct device___434 *);
	int (*runtime_resume)(struct device___434 *);
	int (*runtime_idle)(struct device___434 *);
};

struct dev_pm_info___434 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___434 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___434;

struct bus_type___434;

struct device_driver___434;

struct dev_pm_domain___434;

struct dma_map_ops___206;

struct fwnode_handle___354;

struct class___434;

struct device___434 {
	struct device___434 *parent;
	struct device_private *p;
	struct kobject___454 kobj;
	const char *init_name;
	const struct device_type___434 *type;
	struct mutex mutex;
	struct bus_type___434 *bus;
	struct device_driver___434 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___434 power;
	struct dev_pm_domain___434 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___206 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___354 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___434 *class;
	const struct attribute_group___431 **groups;
	void (*release)(struct device___434 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___434 {
	struct dev_pm_ops___434 ops;
	void (*detach)(struct device___434 *, bool);
	int (*activate)(struct device___434 *);
	void (*sync)(struct device___434 *);
	void (*dismiss)(struct device___434 *);
};

struct bus_type___434 {
	const char *name;
	const char *dev_name;
	struct device___434 *dev_root;
	const struct attribute_group___431 **bus_groups;
	const struct attribute_group___431 **dev_groups;
	const struct attribute_group___431 **drv_groups;
	int (*match)(struct device___434 *, struct device_driver___434 *);
	int (*uevent)(struct device___434 *, struct kobj_uevent_env *);
	int (*probe)(struct device___434 *);
	int (*remove)(struct device___434 *);
	void (*shutdown)(struct device___434 *);
	int (*online)(struct device___434 *);
	int (*offline)(struct device___434 *);
	int (*suspend)(struct device___434 *, pm_message_t);
	int (*resume)(struct device___434 *);
	int (*num_vf)(struct device___434 *);
	int (*dma_configure)(struct device___434 *);
	const struct dev_pm_ops___434 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___434 {
	const char *name;
	struct bus_type___434 *bus;
	struct module___392 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___434 *);
	int (*remove)(struct device___434 *);
	void (*shutdown)(struct device___434 *);
	int (*suspend)(struct device___434 *, pm_message_t);
	int (*resume)(struct device___434 *);
	const struct attribute_group___431 **groups;
	const struct dev_pm_ops___434 *pm;
	void (*coredump)(struct device___434 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___434 {
	const char *name;
	const struct attribute_group___431 **groups;
	int (*uevent)(struct device___434 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___434 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___434 *);
	const struct dev_pm_ops___434 *pm;
};

struct class___434 {
	const char *name;
	struct module___392 *owner;
	const struct attribute_group___431 **class_groups;
	const struct attribute_group___431 **dev_groups;
	struct kobject___454 *dev_kobj;
	int (*dev_uevent)(struct device___434 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___434 *, umode_t *);
	void (*class_release)(struct class___434 *);
	void (*dev_release)(struct device___434 *);
	int (*shutdown_pre)(struct device___434 *);
	const struct kobj_ns_type_operations___91 *ns_type;
	const void * (*namespace)(struct device___434 *);
	const struct dev_pm_ops___434 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___206 {
	void * (*alloc)(struct device___434 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___434 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___434 *, struct vm_area_struct___467 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___434 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___434 *, struct page___467 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___434 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___434 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___434 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___434 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___434 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___434 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___434 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___434 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___434 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___434 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___434 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___434 *, u64);
	u64 (*get_required_mask)(struct device___434 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___354;

struct fwnode_handle___354 {
	struct fwnode_handle___354 *secondary;
	const struct fwnode_operations___354 *ops;
};

typedef void compound_page_dtor___454(struct page___467 *);

struct fwnode_reference_args___354;

struct fwnode_endpoint___354;

struct fwnode_operations___354 {
	struct fwnode_handle___354 * (*get)(struct fwnode_handle___354 *);
	void (*put)(struct fwnode_handle___354 *);
	bool (*device_is_available)(const struct fwnode_handle___354 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___354 *, const struct device___434 *);
	bool (*property_present)(const struct fwnode_handle___354 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___354 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___354 *, const char *, const char **, size_t);
	struct fwnode_handle___354 * (*get_parent)(const struct fwnode_handle___354 *);
	struct fwnode_handle___354 * (*get_next_child_node)(const struct fwnode_handle___354 *, struct fwnode_handle___354 *);
	struct fwnode_handle___354 * (*get_named_child_node)(const struct fwnode_handle___354 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___354 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___354 *);
	struct fwnode_handle___354 * (*graph_get_next_endpoint)(const struct fwnode_handle___354 *, struct fwnode_handle___354 *);
	struct fwnode_handle___354 * (*graph_get_remote_endpoint)(const struct fwnode_handle___354 *);
	struct fwnode_handle___354 * (*graph_get_port_parent)(struct fwnode_handle___354 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___354 *, struct fwnode_endpoint___354 *);
};

struct fwnode_endpoint___354 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___354 *local_fwnode;
};

struct fwnode_reference_args___354 {
	struct fwnode_handle___354 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___147;

struct pipe_buffer___147 {
	struct page___467 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___147 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___147 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___147 *, struct pipe_buffer___147 *);
	void (*release)(struct pipe_inode_info___147 *, struct pipe_buffer___147 *);
	int (*steal)(struct pipe_inode_info___147 *, struct pipe_buffer___147 *);
	union {
		bool (*get)(struct pipe_inode_info___147 *, struct pipe_buffer___147 *);
		struct {
			void (*get)(struct pipe_inode_info___147 *, struct pipe_buffer___147 *);
		} __UNIQUE_ID_rh_kabi_hide21;
		union {		};
	};
};

struct nf_bridge_info___111 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___111 = 0,
		BRNF_PROTO_8021Q___111 = 1,
		BRNF_PROTO_PPPOE___111 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___111 *physindev;
	struct net_device___111 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___111(struct sk_buff___112 **);

struct net_device_ops___111;

struct ethtool_ops___111;

struct l3mdev_ops___91;

struct ndisc_ops___61;

struct xfrmdev_ops___111;

struct tlsdev_ops___111;

struct header_ops___111;

struct inet6_dev___61;

struct netdev_rx_queue___111;

struct mini_Qdisc___103;

struct netdev_queue___111;

struct Qdisc___103;

struct rtnl_link_ops___103;

struct dcbnl_rtnl_ops___111;

struct net_device___111 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___111 *netdev_ops;
	const struct ethtool_ops___111 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___91 *l3mdev_ops;
	const struct ndisc_ops___61 *ndisc_ops;
	const struct xfrmdev_ops___111 *xfrmdev_ops;
	const struct tlsdev_ops___111 *tlsdev_ops;
	const struct header_ops___111 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___453 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___61 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___111 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___101 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___111 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___103 *miniq_ingress;
	struct netdev_queue___111 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___111 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___103 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___103 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___111 = 0,
		NETREG_REGISTERED___111 = 1,
		NETREG_UNREGISTERING___111 = 2,
		NETREG_UNREGISTERED___111 = 3,
		NETREG_RELEASED___111 = 4,
		NETREG_DUMMY___111 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___111 = 0,
		RTNL_LINK_INITIALIZING___111 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___111 *);
	struct netpoll_info *npinfo;
	possible_net_t___113 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___434 dev;
	const struct attribute_group___431 *sysfs_groups[4];
	const struct attribute_group___431 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___103 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___111 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide35;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct ethtool_ops___111 {
	int (*get_settings)(struct net_device___111 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___111 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___111 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___111 *);
	void (*get_regs)(struct net_device___111 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___111 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___111 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___111 *);
	void (*set_msglevel)(struct net_device___111 *, u32);
	int (*nway_reset)(struct net_device___111 *);
	u32 (*get_link)(struct net_device___111 *);
	int (*get_eeprom_len)(struct net_device___111 *);
	int (*get_eeprom)(struct net_device___111 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___111 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___111 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___111 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___111 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___111 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___111 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___111 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___111 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___111 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___111 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___111 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___111 *);
	void (*complete)(struct net_device___111 *);
	u32 (*get_priv_flags)(struct net_device___111 *);
	int (*set_priv_flags)(struct net_device___111 *, u32);
	int (*get_sset_count)(struct net_device___111 *, int);
	int (*get_rxnfc)(struct net_device___111 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___111 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___111 *, struct ethtool_flash *);
	int (*reset)(struct net_device___111 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___111 *);
	u32 (*get_rxfh_indir_size)(struct net_device___111 *);
	int (*get_rxfh)(struct net_device___111 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___111 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___111 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___111 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___111 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___111 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___111 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___111 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___111 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___111 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___111 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___111 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___111 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___111 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___111 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___111 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___111 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___111 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___111 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___111 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___111 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___111 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	int (*get_fecparam)(struct net_device___111 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___111 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___111 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___111 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___111 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___111;

struct inet_frags___111 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___111 *, const void *);
	void (*destructor)(struct inet_frag_queue___111 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___111 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___112 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___112 *fragments_tail;
	struct sk_buff___112 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___111 *net;
	struct callback_head rcu;
};

struct fib_rule___91;

struct fib_lookup_arg___91;

struct fib_rules_ops___91 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___91 *, struct flowi *, int, struct fib_lookup_arg___91 *);
	bool (*suppress)(struct fib_rule___91 *, struct fib_lookup_arg___91 *);
	int (*match)(struct fib_rule___91 *, struct flowi *, int);
	int (*configure)(struct fib_rule___91 *, struct sk_buff___112 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___91 *);
	int (*compare)(struct fib_rule___91 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___91 *, struct sk_buff___112 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___91 *);
	void (*flush_cache)(struct fib_rules_ops___91 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___392 *owner;
	struct net___122 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___92 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___122 *);
	int (*fib_dump)(struct net___122 *, struct notifier_block *);
	struct module___392 *owner;
	struct callback_head rcu;
};

struct lwtunnel_state___16;

struct dst_entry___91 {
	struct net_device___111 *dev;
	struct dst_ops___122 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___112 *);
	int (*output)(struct net___122 *, struct sock___91 *, struct sk_buff___112 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___16 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___91;

struct neigh_parms___91;

struct neigh_ops___91;

struct neighbour___91 {
	struct neighbour___91 *next;
	struct neigh_table___91 *tbl;
	struct neigh_parms___91 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___111 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___91 *, struct sk_buff___112 *);
	const struct neigh_ops___91 *ops;
	struct callback_head rcu;
	struct net_device___111 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct fib6_nh___32 {
	struct in6_addr nh_gw;
	struct net_device___111 *nh_dev;
	struct lwtunnel_state___16 *nh_lwtstate;
	unsigned int nh_flags;
	atomic_t nh_upper_bound;
	int nh_weight;
};

struct fib6_node___32;

struct fib6_info___32 {
	struct fib6_table___32 *fib6_table;
	struct fib6_info___32 *fib6_next;
	struct fib6_node___32 *fib6_node;
	struct list_head fib6_siblings;
	unsigned int fib6_nsiblings;
	atomic_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	struct rt6_info___32 **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
	long unsigned int last_probe;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 exception_bucket_flushed: 1;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 dst_host: 1;
	u8 fib6_destroying: 1;
	u8 unused: 2;
	struct fib6_nh___32 fib6_nh;
	struct callback_head rcu;
};

struct rt6_info___32 {
	struct dst_entry___91 dst;
	struct fib6_info___32 *from;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___61 *rt6i_idev;
	u32 rt6i_flags;
	struct rt6key rt6i_prefsrc;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct fib6_node___32 {
	struct fib6_node___32 *parent;
	struct fib6_node___32 *left;
	struct fib6_node___32 *right;
	struct fib6_info___32 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info___32 *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table___32 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node___32 tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

struct ucounts___331 {
	struct hlist_node node;
	struct user_namespace___331 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_prog_aux___104;

struct bpf_prog___101 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___104 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

typedef int (*key_restrict_link_func_t___435)(struct key___434 *, const struct key_type *, const union key_payload *, struct key___434 *);

struct key_restriction___434;

struct key___434 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___468 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___434 *restrict_link;
};

struct key_restriction___434 {
	key_restrict_link_func_t___435 check;
	struct key___434 *key;
	struct key_type *keytype;
};

struct seq_operations___405 {
	void * (*start)(struct seq_file___405 *, loff_t *);
	void (*stop)(struct seq_file___405 *, void *);
	void * (*next)(struct seq_file___405 *, void *, loff_t *);
	int (*show)(struct seq_file___405 *, void *);
};

struct pernet_operations___112 {
	struct list_head list;
	int (*init)(struct net___122 *);
	void (*exit)(struct net___122 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___111 {
	int (*ieee_getets)(struct net_device___111 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___111 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___111 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___111 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___111 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___111 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___111 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___111 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___111 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___111 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___111 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___111 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___111 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___111 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___111 *);
	u8 (*setstate)(struct net_device___111 *, u8);
	void (*getpermhwaddr)(struct net_device___111 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___111 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___111 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___111 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___111 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___111 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___111 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___111 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___111 *, int, u8 *);
	void (*setpfccfg)(struct net_device___111 *, int, u8);
	void (*getpfccfg)(struct net_device___111 *, int, u8 *);
	u8 (*setall)(struct net_device___111 *);
	u8 (*getcap)(struct net_device___111 *, int, u8 *);
	int (*getnumtcs)(struct net_device___111 *, int, u8 *);
	int (*setnumtcs)(struct net_device___111 *, int, u8);
	u8 (*getpfcstate)(struct net_device___111 *);
	void (*setpfcstate)(struct net_device___111 *, u8);
	void (*getbcncfg)(struct net_device___111 *, int, u32 *);
	void (*setbcncfg)(struct net_device___111 *, int, u32);
	void (*getbcnrp)(struct net_device___111 *, int, u8 *);
	void (*setbcnrp)(struct net_device___111 *, int, u8);
	int (*setapp)(struct net_device___111 *, u8, u16, u8);
	int (*getapp)(struct net_device___111 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___111 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___111 *, int, u8);
	u8 (*getdcbx)(struct net_device___111 *);
	u8 (*setdcbx)(struct net_device___111 *, u8);
	int (*peer_getappinfo)(struct net_device___111 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___111 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___111 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___111 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___111 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___111 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___315 {
	refcount_t count;
	struct ns_common___29 ns;
	struct user_namespace___331 *user_ns;
	struct ucounts___331 *ucounts;
	struct css_set___315 *root_cset;
};

struct bpf_map___316;

struct bpf_map_ops___315 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___316 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___316 *, struct file___466 *);
	void (*map_free)(struct bpf_map___316 *);
	int (*map_get_next_key)(struct bpf_map___316 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___316 *);
	void * (*map_lookup_elem)(struct bpf_map___316 *, void *);
	int (*map_update_elem)(struct bpf_map___316 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___316 *, void *);
	int (*map_push_elem)(struct bpf_map___316 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___316 *, void *);
	int (*map_peek_elem)(struct bpf_map___316 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___316 *, struct file___466 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___316 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___316 *, void *, struct seq_file___405 *);
	int (*map_check_btf)(const struct bpf_map___316 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___316 {
	const struct bpf_map_ops___315 *ops;
	struct bpf_map___316 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___434 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___111;

struct bpf_map_dev_ops___111 {
	int (*map_get_next_key)(struct bpf_offloaded_map___111 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___111 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___111 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___111 *, void *);
};

struct bpf_offloaded_map___111 {
	struct bpf_map___316 map;
	struct net_device___111 *netdev;
	const struct bpf_map_dev_ops___111 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___101 {
	int (*test_run)(struct bpf_prog___101 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___101 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___101 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___101 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___101 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___101 *, u32 *);
};

struct bpf_prog_offload_ops___101 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___101 *);
	int (*translate)(struct bpf_prog___101 *);
	void (*destroy)(struct bpf_prog___101 *);
};

struct bpf_prog_offload___101 {
	struct bpf_prog___101 *prog;
	struct net_device___111 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___101 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___104 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___101 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___101 *ops;
	struct bpf_map___316 **used_maps;
	struct bpf_prog___101 *prog;
	struct user_struct___434 *user;
	u64 load_time;
	struct bpf_map___316 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___101 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___101 {
	struct bpf_prog___101 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___101 {
	struct callback_head rcu;
	struct bpf_prog_array_item___101 items[0];
};

struct cgroup_bpf___101 {
	struct bpf_prog_array___101 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___101 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___316;

typedef void (*kthread_work_func_t___316)(struct kthread_work___316 *);

struct kthread_worker___316;

struct kthread_work___316 {
	struct list_head node;
	kthread_work_func_t___316 func;
	struct kthread_worker___316 *worker;
	int canceling;
};

struct kthread_worker___316 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___468 *task;
	struct kthread_work___316 *current_work;
};

struct kthread_delayed_work___315 {
	struct kthread_work___316 work;
	struct timer_list timer;
};

struct psi_group___315 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___316 *poll_kworker;
	struct kthread_delayed_work___315 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___315;

struct cgroup_rstat_cpu___315;

struct cgroup___315 {
	struct cgroup_subsys_state___315 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___461 *kn;
	struct cgroup_file___315 procs_file;
	struct cgroup_file___315 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___315 *subsys[13];
	struct cgroup_root___315 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___315 *dom_cgrp;
	struct cgroup_rstat_cpu___315 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___101 bpf;
	atomic_t congestion_count;
	struct cgroup___315 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___315 psi;
	int ancestor_ids[0];
};

struct cftype___315;

struct cgroup_subsys___315 {
	struct cgroup_subsys_state___315 * (*css_alloc)(struct cgroup_subsys_state___315 *);
	int (*css_online)(struct cgroup_subsys_state___315 *);
	void (*css_offline)(struct cgroup_subsys_state___315 *);
	void (*css_released)(struct cgroup_subsys_state___315 *);
	void (*css_free)(struct cgroup_subsys_state___315 *);
	void (*css_reset)(struct cgroup_subsys_state___315 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___315 *, int);
	int (*css_extra_stat_show)(struct seq_file___405 *, struct cgroup_subsys_state___315 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___468 *);
	void (*cancel_fork)(struct task_struct___468 *);
	void (*fork)(struct task_struct___468 *);
	void (*exit)(struct task_struct___468 *);
	void (*free)(struct task_struct___468 *);
	void (*bind)(struct cgroup_subsys_state___315 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___315 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___315 *dfl_cftypes;
	struct cftype___315 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___315 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___315 *updated_children;
	struct cgroup___315 *updated_next;
};

struct cgroup_root___315 {
	struct kernfs_root___460 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___315 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___315 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___315 *ss;
	struct list_head node;
	struct kernfs_ops___460 *kf_ops;
	int (*open)(struct kernfs_open_file___460 *);
	void (*release)(struct kernfs_open_file___460 *);
	u64 (*read_u64)(struct cgroup_subsys_state___315 *, struct cftype___315 *);
	s64 (*read_s64)(struct cgroup_subsys_state___315 *, struct cftype___315 *);
	int (*seq_show)(struct seq_file___405 *, void *);
	void * (*seq_start)(struct seq_file___405 *, loff_t *);
	void * (*seq_next)(struct seq_file___405 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___405 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___315 *, struct cftype___315 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___315 *, struct cftype___315 *, s64);
	ssize_t (*write)(struct kernfs_open_file___460 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___460 *, struct poll_table_struct___305 *);
};

struct xdp_rxq_info___111 {
	struct net_device___111 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___111 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___111 *dev_rx;
};

struct netlink_callback___113 {
	struct sk_buff___112 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___113 *);
	int (*dump)(struct sk_buff___112 *, struct netlink_callback___113 *);
	int (*done)(struct netlink_callback___113 *);
	void *data;
	struct module___392 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___111 {
	int (*create)(struct sk_buff___112 *, struct net_device___111 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___112 *, unsigned char *);
	int (*cache)(const struct neighbour___91 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___111 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___111 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___111 *, int);
	int poll_owner;
	struct net_device___111 *dev;
	struct sk_buff___112 *gro_list;
	struct sk_buff___112 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___111 {
	struct net_device___111 *dev;
	struct Qdisc___103 *qdisc;
	struct Qdisc___103 *qdisc_sleeping;
	struct kobject___454 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___111 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem___3 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___103 {
	struct sk_buff___112 *head;
	struct sk_buff___112 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___103;

struct Qdisc___103 {
	int (*enqueue)(struct sk_buff___112 *, struct Qdisc___103 *, struct sk_buff___112 **);
	struct sk_buff___112 * (*dequeue)(struct Qdisc___103 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___103 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___111 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___111 gso_skb;
	struct qdisc_skb_head___103 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___103 *next_sched;
	struct sk_buff_head___111 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___111 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___454 kobj;
	struct net_device___111 *dev;
	long: 64;
	struct xdp_rxq_info___111 xdp_rxq;
	union {
		struct xdp_umem___3 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___111)(struct net_device___111 *, struct sk_buff___112 *, struct net_device___111 *);

struct netdev_bpf___111 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___101 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___101 *prog;
			const struct bpf_prog_offload_ops___101 *ops;
		} verifier;
		struct {
			struct bpf_prog___101 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___111 *offmap;
		};
		struct {
			struct xdp_umem___3 *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___111 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___112 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___111 {
	int (*tls_dev_add)(struct net_device___111 *, struct sock___91 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___111 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___111 *, struct sock___91 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___111 {
	int (*ndo_init)(struct net_device___111 *);
	void (*ndo_uninit)(struct net_device___111 *);
	int (*ndo_open)(struct net_device___111 *);
	int (*ndo_stop)(struct net_device___111 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___112 *, struct net_device___111 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___112 *, struct net_device___111 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___111 *, struct sk_buff___112 *, struct net_device___111 *, select_queue_fallback_t___111);
	void (*ndo_change_rx_flags)(struct net_device___111 *, int);
	void (*ndo_set_rx_mode)(struct net_device___111 *);
	int (*ndo_set_mac_address)(struct net_device___111 *, void *);
	int (*ndo_validate_addr)(struct net_device___111 *);
	int (*ndo_do_ioctl)(struct net_device___111 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___111 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___111 *, int);
	int (*ndo_neigh_setup)(struct net_device___111 *, struct neigh_parms___91 *);
	void (*ndo_tx_timeout)(struct net_device___111 *);
	void (*ndo_get_stats64)(struct net_device___111 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___111 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___111 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___111 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___111 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___111 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___111 *);
	int (*ndo_netpoll_setup)(struct net_device___111 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___111 *);
	int (*ndo_set_vf_mac)(struct net_device___111 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___111 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___111 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___111 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___111 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___111 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___111 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___111 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___111 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___111 *, int, struct sk_buff___112 *);
	int (*ndo_set_vf_guid)(struct net_device___111 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___111 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___111 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___111 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___111 *, const struct sk_buff___112 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___111 *, struct net_device___111 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___111 *, struct net_device___111 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___111 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___111 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___111 *, struct neighbour___91 *);
	void (*ndo_neigh_destroy)(struct net_device___111 *, struct neighbour___91 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___111 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___111 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___111 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___112 *, struct netlink_callback___113 *, struct net_device___111 *, struct net_device___111 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___111 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___111 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___112 *, u32, u32, struct net_device___111 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___111 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___111 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___111 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___111 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___111 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___111 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___111 *, struct net_device___111 *);
	void (*ndo_dfwd_del_station)(struct net_device___111 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___111 *);
	int (*ndo_set_tx_maxrate)(struct net_device___111 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___111 *);
	int (*ndo_change_proto_down)(struct net_device___111 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___111 *, struct sk_buff___112 *);
	void (*ndo_set_rx_headroom)(struct net_device___111 *, int);
	int (*ndo_bpf)(struct net_device___111 *, struct netdev_bpf___111 *);
	int (*ndo_xdp_xmit)(struct net_device___111 *, int, struct xdp_frame___111 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___111 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___111 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___91 {
	possible_net_t___113 net;
	struct net_device___111 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___91 *);
	void (*neigh_cleanup)(struct neighbour___91 *);
	struct neigh_table___91 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___91 {
	u32 (*l3mdev_fib_table)(const struct net_device___111 *);
	struct sk_buff___112 * (*l3mdev_l3_rcv)(struct net_device___111 *, struct sk_buff___112 *, u16);
	struct sk_buff___112 * (*l3mdev_l3_out)(struct net_device___111 *, struct sock___91 *, struct sk_buff___112 *, u16);
	struct dst_entry___91 * (*l3mdev_link_scope_lookup)(const struct net_device___111 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct ndisc_ops___61 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___111 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___111 *, struct neighbour___91 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___111 *, u8, struct neighbour___91 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___111 *, struct sk_buff___112 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___122 *, struct net_device___111 *, const struct prefix_info *, struct inet6_dev___61 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___61;

struct ifacaddr6___32;

struct inet6_dev___61 {
	struct net_device___111 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___61 *mc_list;
	struct ifmcaddr6___61 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___32 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	u8 rndid[8];
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___91 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
};

struct tcf_proto___103;

struct mini_Qdisc___103 {
	struct tcf_proto___103 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___103 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___111 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___122 *, struct net_device___111 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___111 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___111 *, struct list_head *);
	size_t (*get_size)(const struct net_device___111 *);
	int (*fill_info)(struct sk_buff___112 *, const struct net_device___111 *);
	size_t (*get_xstats_size)(const struct net_device___111 *);
	int (*fill_xstats)(struct sk_buff___112 *, const struct net_device___111 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___111 *, struct net_device___111 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___111 *, const struct net_device___111 *);
	int (*fill_slave_info)(struct sk_buff___112 *, const struct net_device___111 *, const struct net_device___111 *);
	struct net___122 * (*get_link_net)(const struct net_device___111 *);
	size_t (*get_linkxstats_size)(const struct net_device___111 *, int);
	int (*fill_linkxstats)(struct sk_buff___112 *, const struct net_device___111 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___111 {
	struct list_head poll_list;
	struct sk_buff_head___111 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___111 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___103 *output_queue;
	struct Qdisc___103 **output_queue_tailp;
	struct sk_buff___112 *completion_queue;
	struct sk_buff_head___111 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___111 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___111 input_pkt_queue;
	struct napi_struct___111 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bdi_writeback_congested___256 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___256 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___256 {
	struct bio___256 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___258 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___258 bip_inline_vecs[0];
};

struct bio_set___256 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___256 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___199 {
	struct mem_cgroup___199 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___199 {
	struct lruvec___467 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___199 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___199 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct gnet_dump___103 {
	spinlock_t *lock;
	struct sk_buff___112 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___103;

struct Qdisc_ops___103 {
	struct Qdisc_ops___103 *next;
	const struct Qdisc_class_ops___103 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___112 *, struct Qdisc___103 *, struct sk_buff___112 **);
	struct sk_buff___112 * (*dequeue)(struct Qdisc___103 *);
	struct sk_buff___112 * (*peek)(struct Qdisc___103 *);
	int (*init)(struct Qdisc___103 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___103 *);
	void (*destroy)(struct Qdisc___103 *);
	int (*change)(struct Qdisc___103 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___103 *);
	int (*change_tx_queue_len)(struct Qdisc___103 *, unsigned int);
	int (*dump)(struct Qdisc___103 *, struct sk_buff___112 *);
	int (*dump_stats)(struct Qdisc___103 *, struct gnet_dump___103 *);
	void (*ingress_block_set)(struct Qdisc___103 *, u32);
	void (*egress_block_set)(struct Qdisc___103 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___103 *);
	u32 (*egress_block_get)(struct Qdisc___103 *);
	struct module___392 *owner;
};

struct tcf_block___103;

struct Qdisc_class_ops___103 {
	unsigned int flags;
	struct netdev_queue___111 * (*select_queue)(struct Qdisc___103 *, struct tcmsg *);
	int (*graft)(struct Qdisc___103 *, long unsigned int, struct Qdisc___103 *, struct Qdisc___103 **, struct netlink_ext_ack *);
	struct Qdisc___103 * (*leaf)(struct Qdisc___103 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___103 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___103 *, u32);
	int (*change)(struct Qdisc___103 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___103 *, long unsigned int);
	void (*walk)(struct Qdisc___103 *, struct qdisc_walker *);
	struct tcf_block___103 * (*tcf_block)(struct Qdisc___103 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___103 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___103 *, long unsigned int);
	int (*dump)(struct Qdisc___103 *, long unsigned int, struct sk_buff___112 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___103 *, long unsigned int, struct gnet_dump___103 *);
};

struct tcf_chain___103;

struct tcf_block___103 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___122 *net;
	struct Qdisc___103 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___103 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___103;

struct tcf_proto_ops___103;

struct tcf_proto___103 {
	struct tcf_proto___103 *next;
	void *root;
	int (*classify)(struct sk_buff___112 *, const struct tcf_proto___103 *, struct tcf_result___103 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___103 *ops;
	struct tcf_chain___103 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___103 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___103 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___103 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___112 *, const struct tcf_proto___103 *, struct tcf_result___103 *);
	int (*init)(struct tcf_proto___103 *);
	void (*destroy)(struct tcf_proto___103 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___103 *, u32);
	void (*put)(struct tcf_proto___103 *, void *);
	int (*change)(struct net___122 *, struct sk_buff___112 *, struct tcf_proto___103 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___103 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___103 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___103 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___122 *, struct tcf_chain___103 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___122 *, struct tcf_proto___103 *, void *, struct sk_buff___112 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___112 *, struct net___122 *, void *);
	struct module___392 *owner;
	int flags;
};

struct tcf_chain___103 {
	struct mutex filter_chain_lock;
	struct tcf_proto___103 *filter_chain;
	struct list_head list;
	struct tcf_block___103 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___103 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___91 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___101 *prog;
};

struct bpf_redirect_info___101 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___316 *map;
	struct bpf_map___316 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___91;

struct neigh_hash_table___91;

struct neigh_table___91 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___111 *, __u32 *);
	bool (*key_eq)(const struct neighbour___91 *, const void *);
	int (*constructor)(struct neighbour___91 *);
	int (*pconstructor)(struct pneigh_entry___91 *);
	void (*pdestructor)(struct pneigh_entry___91 *);
	void (*proxy_redo)(struct sk_buff___112 *);
	char *id;
	struct neigh_parms___91 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___111 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___91 *nht;
	struct pneigh_entry___91 **phash_buckets;
};

struct neigh_ops___91 {
	int family;
	void (*solicit)(struct neighbour___91 *, struct sk_buff___112 *);
	void (*error_report)(struct neighbour___91 *, struct sk_buff___112 *);
	int (*output)(struct neighbour___91 *, struct sk_buff___112 *);
	int (*connected_output)(struct neighbour___91 *, struct sk_buff___112 *);
};

struct pneigh_entry___91 {
	struct pneigh_entry___91 *next;
	possible_net_t___113 net;
	struct net_device___111 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___91 {
	struct neighbour___91 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___16 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___122 *, struct sock___91 *, struct sk_buff___112 *);
	int (*orig_input)(struct sk_buff___112 *);
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	__u8 data[0];
};

struct fib_rule___91 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___91 *ctarget;
	struct net___122 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___91 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___91 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___73;

struct timewait_sock_ops___69;

struct proto___91 {
	void (*close)(struct sock___91 *, long int);
	int (*pre_connect)(struct sock___91 *, struct sockaddr *, int);
	int (*connect)(struct sock___91 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___91 *, int);
	struct sock___91 * (*accept)(struct sock___91 *, int, int *, bool);
	int (*ioctl)(struct sock___91 *, int, long unsigned int);
	int (*init)(struct sock___91 *);
	void (*destroy)(struct sock___91 *);
	void (*shutdown)(struct sock___91 *, int);
	int (*setsockopt)(struct sock___91 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___91 *, int, int, char *, int *);
	void (*keepalive)(struct sock___91 *, int);
	int (*sendmsg)(struct sock___91 *, struct msghdr___94 *, size_t);
	int (*recvmsg)(struct sock___91 *, struct msghdr___94 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___91 *, struct page___467 *, int, size_t, int);
	int (*bind)(struct sock___91 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___91 *, struct sk_buff___112 *);
	void (*release_cb)(struct sock___91 *);
	int (*hash)(struct sock___91 *);
	void (*unhash)(struct sock___91 *);
	void (*rehash)(struct sock___91 *);
	int (*get_port)(struct sock___91 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___91 *);
	bool (*stream_memory_read)(const struct sock___91 *);
	void (*enter_memory_pressure)(struct sock___91 *);
	void (*leave_memory_pressure)(struct sock___91 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___73 *rsk_prot;
	struct timewait_sock_ops___69 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___392 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___91 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct sock_reuseport___9 {
	struct callback_head rcu;
	u16 max_socks;
	u16 num_socks;
	unsigned int reuseport_id;
	bool bind_inany;
	struct bpf_prog___101 *prog;
	struct sock___91 *socks[0];
};

struct request_sock___74;

struct request_sock_ops___73 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___91 *, struct request_sock___74 *);
	void (*send_ack)(const struct sock___91 *, struct sk_buff___112 *, struct request_sock___74 *);
	void (*send_reset)(const struct sock___91 *, struct sk_buff___112 *);
	void (*destructor)(struct request_sock___74 *);
	void (*syn_ack_timeout)(const struct request_sock___74 *);
};

struct timewait_sock_ops___69 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___91 *, struct sock___91 *, void *);
	void (*twsk_destructor)(struct sock___91 *);
};

struct request_sock___74 {
	struct sock_common___91 __req_common;
	struct request_sock___74 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___73 *rsk_ops;
	struct sock___91 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct inet_request_sock___9 {
	struct request_sock___74 req;
	u16 snd_wscale: 4;
	u16 rcv_wscale: 4;
	u16 tstamp_ok: 1;
	u16 sack_ok: 1;
	u16 wscale_ok: 1;
	u16 ecn_ok: 1;
	u16 acked: 1;
	u16 no_srccheck: 1;
	u16 smc_ok: 1;
	u32 ir_mark;
	union {
		struct ip_options_rcu *ireq_opt;
		struct {
			struct ipv6_txoptions *ipv6_opt;
			struct sk_buff___112 *pktopts;
		};
	};
};

struct inet_cork___27 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___91 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
	__u16 gso_size;
	u64 transmit_time;
};

struct inet_cork_full___27 {
	struct inet_cork___27 base;
	struct flowi fl;
};

struct ipv6_pinfo___27;

struct inet_sock___27 {
	struct sock___91 sk;
	struct ipv6_pinfo___27 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	__be16 inet_sport;
	__u16 inet_id;
	struct ip_options_rcu *inet_opt;
	int rx_dst_ifindex;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 bind_address_no_port: 1;
	__u8 defer_connect: 1;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___27 cork;
};

struct ipv6_fl_socklist___26;

struct ipv6_pinfo___27 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
			__u16 recvfragsize: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 repflow: 1;
	__u16 pmtudisc: 3;
	__u16 padding: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u16 autoflowlabel: 1;
	__u16 autoflowlabel_set: 1;
	__u8 min_hopcount;
	__u8 tclass;
	__be32 rcv_flowinfo;
	__u32 dst_cookie;
	__u32 rx_dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___26 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___112 *pktoptions;
	struct sk_buff___112 *rxpmtu;
	struct inet6_cork cork;
};

struct ip6_flowlabel___26;

struct ipv6_fl_socklist___26 {
	struct ipv6_fl_socklist___26 *next;
	struct ip6_flowlabel___26 *fl;
	struct callback_head rcu;
};

struct ifmcaddr6___61 {
	struct in6_addr mca_addr;
	struct inet6_dev___61 *idev;
	struct ifmcaddr6___61 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___32 {
	struct in6_addr aca_addr;
	struct fib6_info___32 *aca_rt;
	struct ifacaddr6___32 *aca_next;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct ip6_ra_chain___61 {
	struct ip6_ra_chain___61 *next;
	struct sock___91 *sk;
	int sel;
	void (*destructor)(struct sock___91 *);
};

struct ip6_flowlabel___26 {
	struct ip6_flowlabel___26 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___260 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___122 *fl_net;
};

struct ipv6_stub___21 {
	int (*ipv6_sock_mc_join)(struct sock___91 *, int, const struct in6_addr *);
	int (*ipv6_sock_mc_drop)(struct sock___91 *, int, const struct in6_addr *);
	int (*ipv6_dst_lookup)(struct net___122 *, struct sock___91 *, struct dst_entry___91 **, struct flowi6 *);
	struct fib6_table___32 * (*fib6_get_table)(struct net___122 *, u32);
	struct fib6_info___32 * (*fib6_lookup)(struct net___122 *, int, struct flowi6 *, int);
	struct fib6_info___32 * (*fib6_table_lookup)(struct net___122 *, struct fib6_table___32 *, int, struct flowi6 *, int);
	struct fib6_info___32 * (*fib6_multipath_select)(const struct net___122 *, struct fib6_info___32 *, struct flowi6 *, int, const struct sk_buff___112 *, int);
	u32 (*ip6_mtu_from_fib6)(struct fib6_info___32 *, struct in6_addr *, struct in6_addr *);
	void (*udpv6_encap_enable)();
	void (*ndisc_send_na)(struct net_device___111 *, const struct in6_addr *, const struct in6_addr *, bool, bool, bool, bool);
	struct neigh_table___91 *nd_tbl;
};

struct ipv6_bpf_stub___21 {
	int (*inet6_bind)(struct sock___91 *, struct sockaddr *, int, bool, bool);
	struct sock___91 * (*udp6_lib_lookup)(struct net___122 *, const struct in6_addr *, __be16, const struct in6_addr *, __be16, int, int, struct udp_table *, struct sk_buff___112 *);
};

struct sr6_tlv {
	__u8 type;
	__u8 len;
	__u8 data[0];
};

struct genl_ops___6;

struct genl_info___5;

struct genl_family___6 {
	int id;
	unsigned int hdrsize;
	char name[16];
	unsigned int version;
	unsigned int maxattr;
	bool netnsok;
	bool parallel_ops;
	int (*pre_doit)(const struct genl_ops___6 *, struct sk_buff___111 *, struct genl_info___5 *);
	void (*post_doit)(const struct genl_ops___6 *, struct sk_buff___111 *, struct genl_info___5 *);
	int (*mcast_bind)(struct net___121 *, int);
	void (*mcast_unbind)(struct net___121 *, int);
	struct nlattr **attrbuf;
	const struct genl_ops___6 *ops;
	const struct genl_multicast_group *mcgrps;
	unsigned int n_ops;
	unsigned int n_mcgrps;
	unsigned int mcgrp_offset;
	struct module___391 *module;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct genl_ops___6 {
	const struct nla_policy *policy;
	int (*doit)(struct sk_buff___111 *, struct genl_info___5 *);
	int (*start)(struct netlink_callback___112 *);
	int (*dumpit)(struct sk_buff___111 *, struct netlink_callback___112 *);
	int (*done)(struct netlink_callback___112 *);
	u8 cmd;
	u8 internal_flags;
	u8 flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t genl_ops_extended_size_rh;
	struct genl_ops_extended_rh genl_ops_extended_rh;
};

struct genl_info___5 {
	u32 snd_seq;
	u32 snd_portid;
	struct nlmsghdr *nlhdr;
	struct genlmsghdr *genlhdr;
	void *userhdr;
	struct nlattr **attrs;
	possible_net_t___112 _net;
	void *user_ptr[2];
	struct netlink_ext_ack *extack;
};

enum {
	SEG6_ATTR_UNSPEC = 0,
	SEG6_ATTR_DST = 1,
	SEG6_ATTR_DSTLEN = 2,
	SEG6_ATTR_HMACKEYID = 3,
	SEG6_ATTR_SECRET = 4,
	SEG6_ATTR_SECRETLEN = 5,
	SEG6_ATTR_ALGID = 6,
	SEG6_ATTR_HMACINFO = 7,
	__SEG6_ATTR_MAX = 8,
};

enum {
	SEG6_CMD_UNSPEC = 0,
	SEG6_CMD_SETHMAC = 1,
	SEG6_CMD_DUMPHMAC = 2,
	SEG6_CMD_SET_TUNSRC = 3,
	SEG6_CMD_GET_TUNSRC = 4,
	__SEG6_CMD_MAX = 5,
};

struct raw6_sock___2 {
	struct inet_sock___18 inet;
	__u32 checksum;
	__u32 offset;
	struct icmp6_filter filter;
	__u32 ip6mr_table;
	struct ipv6_pinfo___18 inet6;
};

typedef short unsigned int mifi_t;

typedef __u32 if_mask;

struct if_set {
	if_mask ifs_bits[8];
};

struct mif6ctl {
	mifi_t mif6c_mifi;
	unsigned char mif6c_flags;
	unsigned char vifc_threshold;
	__u16 mif6c_pifi;
	unsigned int vifc_rate_limit;
};

struct mf6cctl {
	struct sockaddr_in6 mf6cc_origin;
	struct sockaddr_in6 mf6cc_mcastgrp;
	mifi_t mf6cc_parent;
	struct if_set mf6cc_ifset;
};

struct sioc_sg_req6 {
	struct sockaddr_in6 src;
	struct sockaddr_in6 grp;
	long unsigned int pktcnt;
	long unsigned int bytecnt;
	long unsigned int wrong_if;
};

struct sioc_mif_req6 {
	mifi_t mifi;
	long unsigned int icount;
	long unsigned int ocount;
	long unsigned int ibytes;
	long unsigned int obytes;
};

struct mrt6msg {
	__u8 im6_mbz;
	__u8 im6_msgtype;
	__u16 im6_mif;
	__u32 im6_pad;
	struct in6_addr im6_src;
	struct in6_addr im6_dst;
};

enum {
	IP6MRA_CREPORT_UNSPEC = 0,
	IP6MRA_CREPORT_MSGTYPE = 1,
	IP6MRA_CREPORT_MIF_ID = 2,
	IP6MRA_CREPORT_SRC_ADDR = 3,
	IP6MRA_CREPORT_DST_ADDR = 4,
	IP6MRA_CREPORT_PKT = 5,
	__IP6MRA_CREPORT_MAX = 6,
};

struct mfc6_cache_cmp_arg {
	struct in6_addr mf6c_mcastgrp;
	struct in6_addr mf6c_origin;
};

struct mfc6_cache {
	struct mr_mfc _c;
	union {
		struct {
			struct in6_addr mf6c_mcastgrp;
			struct in6_addr mf6c_origin;
		};
		struct mfc6_cache_cmp_arg cmparg;
	};
};

struct nf_ipv6_ops___10 {
	int (*chk_addr)(struct net___110 *, const struct in6_addr *, const struct net_device___99 *, int);
	void (*route_input)(struct sk_buff___100 *);
	int (*fragment)(struct net___110 *, struct sock___79 *, struct sk_buff___100 *, int (*)(struct net___110 *, struct sock___79 *, struct sk_buff___100 *));
	__sum16 (*checksum)(struct sk_buff___100 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___100 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___110 *, struct dst_entry___79 **, struct flowi *, bool);
	int (*reroute)(struct sk_buff___100 *, const struct nf_queue_entry___2 *);
};

struct ip6mr_result {
	struct mr_table *mrt;
};

struct xfrm_dst___7;

struct xfrm_policy_afinfo___3 {
	struct dst_ops___121 *dst_ops;
	struct dst_entry___90 * (*dst_lookup)(struct net___121 *, int, int, const xfrm_address_t *, const xfrm_address_t *, u32);
	int (*get_saddr)(struct net___121 *, int, xfrm_address_t *, xfrm_address_t *, u32);
	void (*decode_session)(struct sk_buff___111 *, struct flowi *, int);
	int (*get_tos)(const struct flowi *);
	int (*init_path)(struct xfrm_dst___7 *, struct dst_entry___90 *, int);
	int (*fill_dst)(struct xfrm_dst___7 *, struct net_device___110 *, const struct flowi *);
	struct dst_entry___90 * (*blackhole_route)(struct net___121 *, struct dst_entry___90 *);
};

struct xfrm_dst___7 {
	union {
		struct dst_entry___90 dst;
		struct rtable___14 rt;
		struct rt6_info___31 rt6;
	} u;
	struct dst_entry___90 *route;
	struct dst_entry___90 *child;
	struct dst_entry___90 *path;
	struct xfrm_policy___24 *pols[2];
	int num_pols;
	int num_xfrms;
	u32 xfrm_genid;
	u32 policy_genid;
	u32 route_mtu_cached;
	u32 child_mtu_cached;
	u32 route_cookie;
	u32 path_cookie;
};

struct ip6_mh {
	__u8 ip6mh_proto;
	__u8 ip6mh_hdrlen;
	__u8 ip6mh_type;
	__u8 ip6mh_reserved;
	__u16 ip6mh_cksum;
	__u8 data[0];
};

struct module___393;

struct file___467;

struct kiocb___467;

struct iov_iter___234;

struct poll_table_struct___306;

struct vm_area_struct___468;

struct inode___467;

struct file_lock___467;

struct page___468;

struct pipe_inode_info___148;

struct seq_file___406;

struct file_operations___467 {
	struct module___393 *owner;
	loff_t (*llseek)(struct file___467 *, loff_t, int);
	ssize_t (*read)(struct file___467 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___467 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___467 *, struct iov_iter___234 *);
	ssize_t (*write_iter)(struct kiocb___467 *, struct iov_iter___234 *);
	int (*iopoll)(struct kiocb___467 *, bool);
	int (*iterate)(struct file___467 *, struct dir_context *);
	int (*iterate_shared)(struct file___467 *, struct dir_context *);
	__poll_t (*poll)(struct file___467 *, struct poll_table_struct___306 *);
	long int (*unlocked_ioctl)(struct file___467 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___467 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___467 *, struct vm_area_struct___468 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___467 *, struct file___467 *);
	int (*flush)(struct file___467 *, fl_owner_t);
	int (*release)(struct inode___467 *, struct file___467 *);
	int (*fsync)(struct file___467 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___467 *, int);
	int (*lock)(struct file___467 *, int, struct file_lock___467 *);
	ssize_t (*sendpage)(struct file___467 *, struct page___468 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___467 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___467 *, int, struct file_lock___467 *);
	ssize_t (*splice_write)(struct pipe_inode_info___148 *, struct file___467 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___467 *, loff_t *, struct pipe_inode_info___148 *, size_t, unsigned int);
	int (*setlease)(struct file___467 *, long int, struct file_lock___467 **, void **);
	long int (*fallocate)(struct file___467 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___406 *, struct file___467 *);
	ssize_t (*copy_file_range)(struct file___467 *, loff_t, struct file___467 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___467 *, loff_t, struct file___467 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___467 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___468 {
	u64 seqnum;
	struct vm_area_struct___468 *vmas[4];
};

struct page_frag___468 {
	struct page___468 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___468;

struct mem_cgroup___200;

struct pid___261;

struct cred___435;

struct nsproxy___362;

struct signal_struct___342;

struct bio_list___257;

struct backing_dev_info___257;

struct css_set___316;

struct vm_struct___371;

struct task_struct___469 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___469 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___468 *mm;
	struct mm_struct___468 *active_mm;
	struct vmacache___468 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___469 *real_parent;
	struct task_struct___469 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___469 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___200 *active_memcg;
	long int rh_reserved2;
	struct pid___261 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___261 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___261 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___435 *ptracer_cred;
	const struct cred___435 *real_cred;
	const struct cred___435 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___362 *nsproxy;
	struct signal_struct___342 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___469 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___257 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___257 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___316 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___148 *splice_pipe;
	struct page_frag___468 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___200 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___469 *oom_reaper_list;
	struct vm_struct___371 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___157 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___468 *pgtable_t___468;

struct address_space___467;

struct dev_pagemap___455;

struct page___468 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___467 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___468 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___468 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___468 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___455 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___200 *mem_cgroup;
};

struct pglist_data___468;

struct lruvec___468 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___468 *pgdat;
};

struct zone___468 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___468 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___468 {
	struct zone___468 *zone;
	int zone_idx;
};

struct zonelist___468 {
	struct zoneref___468 _zonerefs[25];
};

struct pglist_data___468 {
	struct zone___468 node_zones[3];
	struct zonelist___468 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___469 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___469 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___468 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___469 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___469 *owner;
};

struct secondary_data___469 {
	void *stack;
	struct task_struct___469 *task;
	long int status;
};

struct blocking_notifier_head___468 {
	struct rw_semaphore___469 rwsem;
	struct notifier_block *head;
};

struct cgroup___316;

struct cgroup_subsys___316;

struct cgroup_subsys_state___316 {
	struct cgroup___316 *cgroup;
	struct cgroup_subsys___316 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___316 *parent;
};

struct kernfs_node___462;

struct cgroup_file___316 {
	struct kernfs_node___462 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___200;

struct mem_cgroup___200 {
	struct cgroup_subsys_state___316 css;
	struct mem_cgroup_id___16 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___316 events_file;
	struct cgroup_file___316 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___469 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___200 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___261;

struct upid___261 {
	int nr;
	struct pid_namespace___261 *ns;
};

struct dentry___467;

struct user_namespace___332;

struct ucounts___332;

struct pid_namespace___261 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___469 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___261 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___467 *proc_self;
	struct dentry___467 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___332 *user_ns;
	struct ucounts___332 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___29 ns;
};

struct pid___261 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___261 numbers[1];
};

struct key___435;

struct user_namespace___332 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___332 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___29 ns;
	long unsigned int flags;
	struct key___435 *persistent_keyring_register;
	struct rw_semaphore___469 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___332 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct user_struct___435 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___435 *uid_keyring;
	struct key___435 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___455;

struct vm_area_struct___468 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___468 *vm_next;
	struct vm_area_struct___468 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___468 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___455 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___467 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___468;

struct mm_struct___468 {
	struct {
		struct vm_area_struct___468 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___467 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___469 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___468 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___469 *owner;
		struct user_namespace___332 *user_ns;
		struct file___467 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___468 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___435 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___435 *session_keyring;
	struct key___435 *process_keyring;
	struct key___435 *thread_keyring;
	struct key___435 *request_key_auth;
	void *security;
	struct user_struct___435 *user;
	struct user_namespace___332 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___123;

struct cgroup_namespace___316;

struct nsproxy___362 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___261 *pid_ns_for_children;
	struct net___123 *net_ns;
	struct cgroup_namespace___316 *cgroup_ns;
};

struct signal_struct___342 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___469 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___469 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___261 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___261 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___468 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___261 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___257;

struct bio_list___257 {
	struct bio___257 *head;
	struct bio___257 *tail;
};

struct bdi_writeback_congested___257;

struct bdi_writeback___257 {
	struct backing_dev_info___257 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___257 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___316 *memcg_css;
	struct cgroup_subsys_state___316 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___435;

struct backing_dev_info___257 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___257 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___435 *dev;
	struct device___435 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___467 *debug_dir;
	struct dentry___467 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___316 {
	struct cgroup_subsys_state___316 *subsys[13];
	refcount_t refcount;
	struct css_set___316 *dom_cset;
	struct cgroup___316 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___316 *mg_src_cgrp;
	struct cgroup___316 *mg_dst_cgrp;
	struct css_set___316 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___467;

struct pipe_buffer___148;

struct pipe_inode_info___148 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___468 *tmp_page;
	struct fasync_struct___467 *fasync_readers;
	struct fasync_struct___467 *fasync_writers;
	struct pipe_buffer___148 *bufs;
	struct user_struct___435 *user;
};

struct vm_struct___371 {
	struct vm_struct___371 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___468 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___354 {
	struct task_struct___469 task;
	long unsigned int stack[8192];
};

struct address_space_operations___467;

struct address_space___467 {
	struct inode___467 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___469 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___467 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___455)(struct vm_area_struct___468 *, long unsigned int, const struct page___468 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___455)(struct page___468 *, void *);

struct dev_pagemap___455 {
	dev_page_fault_t___455 page_fault;
	dev_page_free_t___455 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___435 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___468 {
	struct vfsmount *mnt;
	struct dentry___467 *dentry;
};

struct fown_struct___261 {
	rwlock_t lock;
	struct pid___261 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___467 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___468 f_path;
	struct inode___467 *f_inode;
	const struct file_operations___467 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___261 f_owner;
	const struct cred___435 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___467 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___455;

struct vm_operations_struct___455 {
	void (*open)(struct vm_area_struct___468 *);
	void (*close)(struct vm_area_struct___468 *);
	int (*split)(struct vm_area_struct___468 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___468 *);
	vm_fault_t (*fault)(struct vm_fault___455 *);
	vm_fault_t (*huge_fault)(struct vm_fault___455 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___455 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___468 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___455 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___455 *);
	int (*access)(struct vm_area_struct___468 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___468 *);
	int (*set_policy)(struct vm_area_struct___468 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___468 *, long unsigned int);
	struct page___468 * (*find_special_page)(struct vm_area_struct___468 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___468 {
	struct task_struct___469 *task;
	struct core_thread___468 *next;
};

struct core_state___468 {
	atomic_t nr_threads;
	struct core_thread___468 dumper;
	struct completion startup;
};

struct vm_fault___455 {
	struct vm_area_struct___468 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___468 *cow_page;
	struct mem_cgroup___200 *memcg;
	struct page___468 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___468 prealloc_pte;
};

struct kset___454;

struct kobj_type___454;

struct kobject___455 {
	const char *name;
	struct list_head entry;
	struct kobject___455 *parent;
	struct kset___454 *kset;
	struct kobj_type___454 *ktype;
	struct kernfs_node___462 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___393 {
	struct kobject___455 kobj;
	struct module___393 *mod;
	struct kobject___455 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___393 {
	struct module___393 *mod;
	struct latch_tree_node node;
};

struct module_layout___393 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___393 mtn;
};

struct module_attribute___393;

struct kernel_param___393;

struct module___393 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___393 mkobj;
	struct module_attribute___393 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___455 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___393 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___393 core_layout;
	struct module_layout___393 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide53;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide54;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bio_vec___259 {
	struct page___468 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___234 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___259 *bvec;
		struct pipe_inode_info___148 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct msghdr___95 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___234 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___467 *msg_iocb;
};

struct kiocb___467 {
	struct file___467 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___467 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dentry_operations___467;

struct super_block___467;

struct dentry___467 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___467 *d_parent;
	struct qstr d_name;
	struct inode___467 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___467 *d_op;
	struct super_block___467 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___467;

struct block_device___467;

struct inode___467 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___467 *i_op;
	struct super_block___467 *i_sb;
	struct address_space___467 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___469 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___257 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___467 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___467 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___148 *i_pipe;
		struct block_device___467 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___467 {
	int (*d_revalidate)(struct dentry___467 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___467 *, unsigned int);
	int (*d_hash)(const struct dentry___467 *, struct qstr *);
	int (*d_compare)(const struct dentry___467 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___467 *);
	int (*d_init)(struct dentry___467 *);
	void (*d_release)(struct dentry___467 *);
	void (*d_prune)(struct dentry___467 *);
	void (*d_iput)(struct dentry___467 *, struct inode___467 *);
	char * (*d_dname)(struct dentry___467 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___468 *);
	int (*d_manage)(const struct path___468 *, bool);
	struct dentry___467 * (*d_real)(struct dentry___467 *, const struct inode___467 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___467;

struct mem_dqinfo___467 {
	struct quota_format_type___467 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___467;

struct quota_info___467 {
	unsigned int flags;
	struct rw_semaphore___469 dqio_sem;
	struct inode___467 *files[3];
	struct mem_dqinfo___467 info[3];
	const struct quota_format_ops___467 *ops[3];
};

struct rcuwait___467 {
	struct task_struct___469 *task;
};

struct percpu_rw_semaphore___467 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___469 rw_sem;
	struct rcuwait___467 writer;
	int readers_block;
};

struct sb_writers___467 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___467 rw_sem[3];
};

struct shrink_control___200;

struct shrinker___200 {
	long unsigned int (*count_objects)(struct shrinker___200 *, struct shrink_control___200 *);
	long unsigned int (*scan_objects)(struct shrinker___200 *, struct shrink_control___200 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___467;

struct super_operations___467;

struct dquot_operations___467;

struct quotactl_ops___467;

struct super_block___467 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___467 *s_type;
	const struct super_operations___467 *s_op;
	const struct dquot_operations___467 *dq_op;
	const struct quotactl_ops___467 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___467 *s_root;
	struct rw_semaphore___469 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___467 *s_bdev;
	struct backing_dev_info___257 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___467 s_dquot;
	struct sb_writers___467 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___467 *s_d_op;
	int cleancache_poolid;
	struct shrinker___200 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___332 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___200 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___200 *memcg;
};

struct iattr___467 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___467 *ia_file;
};

struct dquot___467 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___467 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___467 {
	int qf_fmt_id;
	const struct quota_format_ops___467 *qf_ops;
	struct module___393 *qf_owner;
	struct quota_format_type___467 *qf_next;
};

struct quota_format_ops___467 {
	int (*check_quota_file)(struct super_block___467 *, int);
	int (*read_file_info)(struct super_block___467 *, int);
	int (*write_file_info)(struct super_block___467 *, int);
	int (*free_file_info)(struct super_block___467 *, int);
	int (*read_dqblk)(struct dquot___467 *);
	int (*commit_dqblk)(struct dquot___467 *);
	int (*release_dqblk)(struct dquot___467 *);
	int (*get_next_id)(struct super_block___467 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___467 {
	int (*write_dquot)(struct dquot___467 *);
	struct dquot___467 * (*alloc_dquot)(struct super_block___467 *, int);
	void (*destroy_dquot)(struct dquot___467 *);
	int (*acquire_dquot)(struct dquot___467 *);
	int (*release_dquot)(struct dquot___467 *);
	int (*mark_dirty)(struct dquot___467 *);
	int (*write_info)(struct super_block___467 *, int);
	qsize_t * (*get_reserved_space)(struct inode___467 *);
	int (*get_projid)(struct inode___467 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___467 *, qsize_t *);
	int (*get_next_id)(struct super_block___467 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___467 {
	int (*quota_on)(struct super_block___467 *, int, int, const struct path___468 *);
	int (*quota_off)(struct super_block___467 *, int);
	int (*quota_enable)(struct super_block___467 *, unsigned int);
	int (*quota_disable)(struct super_block___467 *, unsigned int);
	int (*quota_sync)(struct super_block___467 *, int);
	int (*set_info)(struct super_block___467 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___467 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___467 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___467 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___467 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___467 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___220;

struct address_space_operations___467 {
	int (*writepage)(struct page___468 *, struct writeback_control___220 *);
	int (*readpage)(struct file___467 *, struct page___468 *);
	int (*writepages)(struct address_space___467 *, struct writeback_control___220 *);
	int (*set_page_dirty)(struct page___468 *);
	int (*readpages)(struct file___467 *, struct address_space___467 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___467 *, struct address_space___467 *, loff_t, unsigned int, unsigned int, struct page___468 **, void **);
	int (*write_end)(struct file___467 *, struct address_space___467 *, loff_t, unsigned int, unsigned int, struct page___468 *, void *);
	sector_t (*bmap)(struct address_space___467 *, sector_t);
	void (*invalidatepage)(struct page___468 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___468 *, gfp_t);
	void (*freepage)(struct page___468 *);
	ssize_t (*direct_IO)(struct kiocb___467 *, struct iov_iter___234 *);
	int (*migratepage)(struct address_space___467 *, struct page___468 *, struct page___468 *, enum migrate_mode);
	bool (*isolate_page)(struct page___468 *, isolate_mode_t);
	void (*putback_page)(struct page___468 *);
	int (*launder_page)(struct page___468 *);
	int (*is_partially_uptodate)(struct page___468 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___468 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___467 *, struct page___468 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___467 *, sector_t *);
	void (*swap_deactivate)(struct file___467 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___220 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___257 *wb;
	struct inode___467 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___467 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___467 *bd_inode;
	struct super_block___467 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___467 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___257 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___467 {
	struct dentry___467 * (*lookup)(struct inode___467 *, struct dentry___467 *, unsigned int);
	const char * (*get_link)(struct dentry___467 *, struct inode___467 *, struct delayed_call *);
	int (*permission)(struct inode___467 *, int);
	struct posix_acl * (*get_acl)(struct inode___467 *, int);
	int (*readlink)(struct dentry___467 *, char *, int);
	int (*create)(struct inode___467 *, struct dentry___467 *, umode_t, bool);
	int (*link)(struct dentry___467 *, struct inode___467 *, struct dentry___467 *);
	int (*unlink)(struct inode___467 *, struct dentry___467 *);
	int (*symlink)(struct inode___467 *, struct dentry___467 *, const char *);
	int (*mkdir)(struct inode___467 *, struct dentry___467 *, umode_t);
	int (*rmdir)(struct inode___467 *, struct dentry___467 *);
	int (*mknod)(struct inode___467 *, struct dentry___467 *, umode_t, dev_t);
	int (*rename)(struct inode___467 *, struct dentry___467 *, struct inode___467 *, struct dentry___467 *, unsigned int);
	int (*setattr)(struct dentry___467 *, struct iattr___467 *);
	int (*getattr)(const struct path___468 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___467 *, char *, size_t);
	int (*fiemap)(struct inode___467 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___467 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___467 *, struct dentry___467 *, struct file___467 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___467 *, struct dentry___467 *, umode_t);
	int (*set_acl)(struct inode___467 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___467 {
	void (*fl_copy_lock)(struct file_lock___467 *, struct file_lock___467 *);
	void (*fl_release_private)(struct file_lock___467 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___467;

struct file_lock___467 {
	struct file_lock___467 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___467 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___467 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___467 *fl_ops;
	const struct lock_manager_operations___467 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___467 {
	int (*lm_compare_owner)(struct file_lock___467 *, struct file_lock___467 *);
	long unsigned int (*lm_owner_key)(struct file_lock___467 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___467 *);
	int (*lm_grant)(struct file_lock___467 *, int);
	bool (*lm_break)(struct file_lock___467 *);
	int (*lm_change)(struct file_lock___467 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___467 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___467 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___467 *fa_next;
	struct file___467 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___467 {
	const char *name;
	int fs_flags;
	struct dentry___467 * (*mount)(struct file_system_type___467 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___467 *);
	struct module___393 *owner;
	struct file_system_type___467 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___467 {
	struct inode___467 * (*alloc_inode)(struct super_block___467 *);
	void (*destroy_inode)(struct inode___467 *);
	void (*dirty_inode)(struct inode___467 *, int);
	int (*write_inode)(struct inode___467 *, struct writeback_control___220 *);
	int (*drop_inode)(struct inode___467 *);
	void (*evict_inode)(struct inode___467 *);
	void (*put_super)(struct super_block___467 *);
	int (*sync_fs)(struct super_block___467 *, int);
	int (*freeze_super)(struct super_block___467 *);
	int (*freeze_fs)(struct super_block___467 *);
	int (*thaw_super)(struct super_block___467 *);
	int (*unfreeze_fs)(struct super_block___467 *);
	int (*statfs)(struct dentry___467 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___467 *, int *, char *);
	void (*umount_begin)(struct super_block___467 *);
	int (*show_options)(struct seq_file___406 *, struct dentry___467 *);
	int (*show_devname)(struct seq_file___406 *, struct dentry___467 *);
	int (*show_path)(struct seq_file___406 *, struct dentry___467 *);
	int (*show_stats)(struct seq_file___406 *, struct dentry___467 *);
	ssize_t (*quota_read)(struct super_block___467 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___467 *, int, const char *, size_t, loff_t);
	struct dquot___467 ** (*get_dquots)(struct inode___467 *);
	int (*bdev_try_to_free_page)(struct super_block___467 *, struct page___468 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___467 *, struct shrink_control___200 *);
	long int (*free_cached_objects)(struct super_block___467 *, struct shrink_control___200 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___316)(struct file___467 *, wait_queue_head_t *, struct poll_table_struct___306 *);

struct poll_table_struct___306 {
	poll_queue_proc___316 _qproc;
	__poll_t _key;
};

struct seq_operations___406;

struct seq_file___406 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___406 *op;
	int poll_event;
	const struct file___467 *file;
	void *private;
};

typedef void bio_end_io_t___257(struct bio___257 *);

struct bio_integrity_payload___257;

struct bio_set___257;

struct bio___257 {
	struct bio___257 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___257 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___257 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___259 *bi_io_vec;
	struct bio_set___257 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___259 bi_inline_vecs[0];
};

struct socket_wq___93 {
	wait_queue_head_t wait;
	struct fasync_struct___467 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct sock___92;

struct proto_ops___93;

struct socket___94 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___93 *wq;
	struct file___467 *file;
	struct sock___92 *sk;
	const struct proto_ops___93 *ops;
};

typedef struct {
	struct net___123 *net;
} possible_net_t___114;

struct proto___92;

struct sock_common___92 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___92 *skc_prot;
	possible_net_t___114 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___92 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___113;

struct sk_buff_head___112 {
	struct sk_buff___113 *next;
	struct sk_buff___113 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___92;

struct xfrm_policy___25;

struct dst_entry___92;

struct net_device___112;

struct sock___92 {
	struct sock_common___92 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___112 sk_error_queue;
	struct sk_buff_head___112 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___113 *head;
		struct sk_buff___113 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___92 *sk_filter;
	union {
		struct socket_wq___93 *sk_wq;
		struct socket_wq___93 *sk_wq_raw;
	};
	struct xfrm_policy___25 *sk_policy[2];
	struct dst_entry___92 *sk_rx_dst;
	struct dst_entry___92 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___113 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___112 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___468 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___92 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___261 *sk_peer_pid;
	const struct cred___435 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___94 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___200 *sk_memcg;
	void (*sk_state_change)(struct sock___92 *);
	void (*sk_data_ready)(struct sock___92 *);
	void (*sk_write_space)(struct sock___92 *);
	void (*sk_error_report)(struct sock___92 *);
	int (*sk_backlog_rcv)(struct sock___92 *, struct sk_buff___113 *);
	struct sk_buff___113 * (*sk_validate_xmit_skb)(struct sock___92 *, struct net_device___112 *, struct sk_buff___113 *);
	void (*sk_destruct)(struct sock___92 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

typedef int (*sk_read_actor_t___92)(read_descriptor_t *, struct sk_buff___113 *, unsigned int, size_t);

struct proto_ops___93 {
	int family;
	struct module___393 *owner;
	int (*release)(struct socket___94 *);
	int (*bind)(struct socket___94 *, struct sockaddr *, int);
	int (*connect)(struct socket___94 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___94 *, struct socket___94 *);
	int (*accept)(struct socket___94 *, struct socket___94 *, int, bool);
	int (*getname)(struct socket___94 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___467 *, struct socket___94 *, struct poll_table_struct___306 *);
	int (*ioctl)(struct socket___94 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___94 *, int);
	int (*shutdown)(struct socket___94 *, int);
	int (*setsockopt)(struct socket___94 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___94 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___94 *, struct msghdr___95 *, size_t);
	int (*recvmsg)(struct socket___94 *, struct msghdr___95 *, size_t, int);
	int (*mmap)(struct file___467 *, struct socket___94 *, struct vm_area_struct___468 *);
	ssize_t (*sendpage)(struct socket___94 *, struct page___468 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___94 *, loff_t *, struct pipe_inode_info___148 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___92 *, int);
	int (*peek_len)(struct socket___94 *);
	int (*read_sock)(struct sock___92 *, read_descriptor_t *, sk_read_actor_t___92);
	int (*sendpage_locked)(struct sock___92 *, struct page___468 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___92 *, struct msghdr___95 *, size_t);
	int (*set_rcvlowat)(struct sock___92 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct sec_path___25;

struct nf_bridge_info___112;

struct sk_buff___113 {
	union {
		struct {
			struct sk_buff___113 *next;
			struct sk_buff___113 *prev;
			union {
				struct net_device___112 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___92 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___113 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path___25 *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___112 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___112;

struct netns_frags___112 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___112 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ip_ra_chain___56;

struct fib_rules_ops___92;

struct fib_notifier_ops___93;

struct netns_ipv4___112 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___56 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___92 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___92 *fibnl;
	struct sock___92 **icmp_sk;
	struct sock___92 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___92 **tcp_sk;
	struct netns_frags___112 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___92 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___93 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___93 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___92;

struct dst_ops___123 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___123 *);
	struct dst_entry___92 * (*check)(struct dst_entry___92 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___92 *);
	unsigned int (*mtu)(const struct dst_entry___92 *);
	u32 * (*cow_metrics)(struct dst_entry___92 *, long unsigned int);
	void (*destroy)(struct dst_entry___92 *);
	void (*ifdown)(struct dst_entry___92 *, struct net_device___112 *, int);
	struct dst_entry___92 * (*negative_advice)(struct dst_entry___92 *);
	void (*link_failure)(struct sk_buff___113 *);
	void (*update_pmtu)(struct dst_entry___92 *, struct sock___92 *, struct sk_buff___113 *, u32);
	void (*redirect)(struct dst_entry___92 *, struct sock___92 *, struct sk_buff___113 *);
	int (*local_out)(struct net___123 *, struct sock___92 *, struct sk_buff___113 *);
	struct neighbour___92 * (*neigh_lookup)(const struct dst_entry___92 *, struct sk_buff___113 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___92 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_info___33;

struct rt6_info___33;

struct fib6_table___33;

struct netns_ipv6___123 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___112 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info___33 *fib6_null_entry;
	struct rt6_info___33 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___33 *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___123 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info___33 *ip6_prohibit_entry;
	struct rt6_info___33 *ip6_blk_hole_entry;
	struct fib6_table___33 *fib6_local_tbl;
	struct fib_rules_ops___92 *fib6_rules_ops;
	struct sock___92 **icmp_sk;
	struct sock___92 *ndisc_sk;
	struct sock___92 *tcp_sk;
	struct sock___92 *igmp_sk;
	struct sock___92 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___92 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___93 *notifier_ops;
	struct fib_notifier_ops___93 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___93 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___92 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct nf_hook_entries___20;

struct netns_nf___21 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_queue_handler *queue_handler;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header *nf_log_dir_header;
	struct nf_hook_entries___20 *hooks_ipv4[5];
	struct nf_hook_entries___20 *hooks_ipv6[5];
	struct nf_hook_entries___20 *hooks_arp[3];
	struct nf_hook_entries___20 *hooks_bridge[5];
	bool defrag_ipv4;
	bool defrag_ipv6;
};

struct netns_nf_frag___112 {
	struct netns_frags___112 frags;
};

struct netns_xfrm___123 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___92 *nlsk;
	struct sock___92 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___123 xfrm4_dst_ops;
	struct dst_ops___123 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___102;

struct net___123 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___332 *user_ns;
	struct ucounts___332 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___29 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___92 *rtnl;
	struct sock___92 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___112 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___112 ipv4;
	struct netns_ipv6___123 ipv6;
	struct netns_sctp___93 sctp;
	struct netns_nf___21 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___112 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___92 *nfnl;
	struct sock___92 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___123 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___92 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___102 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kernfs_root___461;

struct kernfs_elem_dir___461 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___461 *root;
};

struct kernfs_syscall_ops___461;

struct kernfs_root___461 {
	struct kernfs_node___462 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___461 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___461 {
	struct kernfs_node___462 *target_kn;
};

struct kernfs_ops___461;

struct kernfs_elem_attr___461 {
	const struct kernfs_ops___461 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___462 *notify_next;
};

struct kernfs_node___462 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___462 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___461 dir;
		struct kernfs_elem_symlink___461 symlink;
		struct kernfs_elem_attr___461 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___461;

struct kernfs_ops___461 {
	int (*open)(struct kernfs_open_file___461 *);
	void (*release)(struct kernfs_open_file___461 *);
	int (*seq_show)(struct seq_file___406 *, void *);
	void * (*seq_start)(struct seq_file___406 *, loff_t *);
	void * (*seq_next)(struct seq_file___406 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___406 *, void *);
	ssize_t (*read)(struct kernfs_open_file___461 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___461 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___461 *, struct vm_area_struct___468 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___461 *, struct poll_table_struct___306 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___461 {
	int (*remount_fs)(struct kernfs_root___461 *, int *, char *);
	int (*show_options)(struct seq_file___406 *, struct kernfs_root___461 *);
	int (*mkdir)(struct kernfs_node___462 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___462 *);
	int (*rename)(struct kernfs_node___462 *, struct kernfs_node___462 *, const char *);
	int (*show_path)(struct seq_file___406 *, struct kernfs_node___462 *, struct kernfs_root___461 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___461 {
	struct kernfs_node___462 *kn;
	struct file___467 *file;
	struct seq_file___406 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___455 *vm_ops;
};

struct kobj_ns_type_operations___92 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___92 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___431;

struct attribute_group___432 {
	const char *name;
	umode_t (*is_visible)(struct kobject___455 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___455 *, struct bin_attribute___431 *, int);
	struct attribute **attrs;
	struct bin_attribute___431 **bin_attrs;
};

struct bin_attribute___431 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___467 *, struct kobject___455 *, struct bin_attribute___431 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___467 *, struct kobject___455 *, struct bin_attribute___431 *, char *, loff_t, size_t);
	int (*mmap)(struct file___467 *, struct kobject___455 *, struct bin_attribute___431 *, struct vm_area_struct___468 *);
};

struct sysfs_ops___454 {
	ssize_t (*show)(struct kobject___455 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___455 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___454;

struct kset___454 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___455 kobj;
	const struct kset_uevent_ops___454 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___454 {
	void (*release)(struct kobject___455 *);
	const struct sysfs_ops___454 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___92 * (*child_ns_type)(struct kobject___455 *);
	const void * (*namespace)(struct kobject___455 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___454 {
	int (* const filter)(struct kset___454 *, struct kobject___455 *);
	const char * (* const name)(struct kset___454 *, struct kobject___455 *);
	int (* const uevent)(struct kset___454 *, struct kobject___455 *, struct kobj_uevent_env *);
};

struct kobj_attribute___445 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___455 *, struct kobj_attribute___445 *, char *);
	ssize_t (*store)(struct kobject___455 *, struct kobj_attribute___445 *, const char *, size_t);
};

struct dev_pm_ops___435 {
	int (*prepare)(struct device___435 *);
	void (*complete)(struct device___435 *);
	int (*suspend)(struct device___435 *);
	int (*resume)(struct device___435 *);
	int (*freeze)(struct device___435 *);
	int (*thaw)(struct device___435 *);
	int (*poweroff)(struct device___435 *);
	int (*restore)(struct device___435 *);
	int (*suspend_late)(struct device___435 *);
	int (*resume_early)(struct device___435 *);
	int (*freeze_late)(struct device___435 *);
	int (*thaw_early)(struct device___435 *);
	int (*poweroff_late)(struct device___435 *);
	int (*restore_early)(struct device___435 *);
	int (*suspend_noirq)(struct device___435 *);
	int (*resume_noirq)(struct device___435 *);
	int (*freeze_noirq)(struct device___435 *);
	int (*thaw_noirq)(struct device___435 *);
	int (*poweroff_noirq)(struct device___435 *);
	int (*restore_noirq)(struct device___435 *);
	int (*runtime_suspend)(struct device___435 *);
	int (*runtime_resume)(struct device___435 *);
	int (*runtime_idle)(struct device___435 *);
};

struct dev_pm_info___435 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___435 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___435;

struct bus_type___435;

struct device_driver___435;

struct dev_pm_domain___435;

struct dma_map_ops___207;

struct fwnode_handle___355;

struct class___435;

struct device___435 {
	struct device___435 *parent;
	struct device_private *p;
	struct kobject___455 kobj;
	const char *init_name;
	const struct device_type___435 *type;
	struct mutex mutex;
	struct bus_type___435 *bus;
	struct device_driver___435 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___435 power;
	struct dev_pm_domain___435 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___207 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___355 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___435 *class;
	const struct attribute_group___432 **groups;
	void (*release)(struct device___435 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___435 {
	struct dev_pm_ops___435 ops;
	void (*detach)(struct device___435 *, bool);
	int (*activate)(struct device___435 *);
	void (*sync)(struct device___435 *);
	void (*dismiss)(struct device___435 *);
};

struct bus_type___435 {
	const char *name;
	const char *dev_name;
	struct device___435 *dev_root;
	const struct attribute_group___432 **bus_groups;
	const struct attribute_group___432 **dev_groups;
	const struct attribute_group___432 **drv_groups;
	int (*match)(struct device___435 *, struct device_driver___435 *);
	int (*uevent)(struct device___435 *, struct kobj_uevent_env *);
	int (*probe)(struct device___435 *);
	int (*remove)(struct device___435 *);
	void (*shutdown)(struct device___435 *);
	int (*online)(struct device___435 *);
	int (*offline)(struct device___435 *);
	int (*suspend)(struct device___435 *, pm_message_t);
	int (*resume)(struct device___435 *);
	int (*num_vf)(struct device___435 *);
	int (*dma_configure)(struct device___435 *);
	const struct dev_pm_ops___435 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___435 {
	const char *name;
	struct bus_type___435 *bus;
	struct module___393 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___435 *);
	int (*remove)(struct device___435 *);
	void (*shutdown)(struct device___435 *);
	int (*suspend)(struct device___435 *, pm_message_t);
	int (*resume)(struct device___435 *);
	const struct attribute_group___432 **groups;
	const struct dev_pm_ops___435 *pm;
	void (*coredump)(struct device___435 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___435 {
	const char *name;
	const struct attribute_group___432 **groups;
	int (*uevent)(struct device___435 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___435 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___435 *);
	const struct dev_pm_ops___435 *pm;
};

struct class___435 {
	const char *name;
	struct module___393 *owner;
	const struct attribute_group___432 **class_groups;
	const struct attribute_group___432 **dev_groups;
	struct kobject___455 *dev_kobj;
	int (*dev_uevent)(struct device___435 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___435 *, umode_t *);
	void (*class_release)(struct class___435 *);
	void (*dev_release)(struct device___435 *);
	int (*shutdown_pre)(struct device___435 *);
	const struct kobj_ns_type_operations___92 *ns_type;
	const void * (*namespace)(struct device___435 *);
	const struct dev_pm_ops___435 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___207 {
	void * (*alloc)(struct device___435 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___435 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___435 *, struct vm_area_struct___468 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___435 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___435 *, struct page___468 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___435 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___435 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___435 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___435 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___435 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___435 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___435 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___435 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___435 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___435 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___435 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___435 *, u64);
	u64 (*get_required_mask)(struct device___435 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___355;

struct fwnode_handle___355 {
	struct fwnode_handle___355 *secondary;
	const struct fwnode_operations___355 *ops;
};

typedef void compound_page_dtor___455(struct page___468 *);

struct fwnode_reference_args___355;

struct fwnode_endpoint___355;

struct fwnode_operations___355 {
	struct fwnode_handle___355 * (*get)(struct fwnode_handle___355 *);
	void (*put)(struct fwnode_handle___355 *);
	bool (*device_is_available)(const struct fwnode_handle___355 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___355 *, const struct device___435 *);
	bool (*property_present)(const struct fwnode_handle___355 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___355 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___355 *, const char *, const char **, size_t);
	struct fwnode_handle___355 * (*get_parent)(const struct fwnode_handle___355 *);
	struct fwnode_handle___355 * (*get_next_child_node)(const struct fwnode_handle___355 *, struct fwnode_handle___355 *);
	struct fwnode_handle___355 * (*get_named_child_node)(const struct fwnode_handle___355 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___355 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___355 *);
	struct fwnode_handle___355 * (*graph_get_next_endpoint)(const struct fwnode_handle___355 *, struct fwnode_handle___355 *);
	struct fwnode_handle___355 * (*graph_get_remote_endpoint)(const struct fwnode_handle___355 *);
	struct fwnode_handle___355 * (*graph_get_port_parent)(struct fwnode_handle___355 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___355 *, struct fwnode_endpoint___355 *);
};

struct fwnode_endpoint___355 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___355 *local_fwnode;
};

struct fwnode_reference_args___355 {
	struct fwnode_handle___355 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___148;

struct pipe_buffer___148 {
	struct page___468 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___148 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___148 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___148 *, struct pipe_buffer___148 *);
	void (*release)(struct pipe_inode_info___148 *, struct pipe_buffer___148 *);
	int (*steal)(struct pipe_inode_info___148 *, struct pipe_buffer___148 *);
	union {
		bool (*get)(struct pipe_inode_info___148 *, struct pipe_buffer___148 *);
		struct {
			void (*get)(struct pipe_inode_info___148 *, struct pipe_buffer___148 *);
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
};

struct nf_bridge_info___112 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___112 = 0,
		BRNF_PROTO_8021Q___112 = 1,
		BRNF_PROTO_PPPOE___112 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___112 *physindev;
	struct net_device___112 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___112(struct sk_buff___113 **);

struct net_device_ops___112;

struct ethtool_ops___112;

struct l3mdev_ops___92;

struct ndisc_ops___62;

struct xfrmdev_ops___112;

struct tlsdev_ops___112;

struct header_ops___112;

struct inet6_dev___62;

struct netdev_rx_queue___112;

struct mini_Qdisc___104;

struct netdev_queue___112;

struct Qdisc___104;

struct rtnl_link_ops___104;

struct dcbnl_rtnl_ops___112;

struct net_device___112 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___112 *netdev_ops;
	const struct ethtool_ops___112 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___92 *l3mdev_ops;
	const struct ndisc_ops___62 *ndisc_ops;
	const struct xfrmdev_ops___112 *xfrmdev_ops;
	const struct tlsdev_ops___112 *tlsdev_ops;
	const struct header_ops___112 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___454 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___62 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___112 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___102 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___112 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___104 *miniq_ingress;
	struct netdev_queue___112 *ingress_queue;
	struct nf_hook_entries___20 *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___112 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___104 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___104 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___112 = 0,
		NETREG_REGISTERED___112 = 1,
		NETREG_UNREGISTERING___112 = 2,
		NETREG_UNREGISTERED___112 = 3,
		NETREG_RELEASED___112 = 4,
		NETREG_DUMMY___112 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___112 = 0,
		RTNL_LINK_INITIALIZING___112 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___112 *);
	struct netpoll_info *npinfo;
	possible_net_t___114 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___435 dev;
	const struct attribute_group___432 *sysfs_groups[4];
	const struct attribute_group___432 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___104 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___112 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct xfrm_state___25;

struct sec_path___25 {
	refcount_t refcnt;
	int len;
	int olen;
	struct xfrm_state___25 *xvec[6];
	struct xfrm_offload ovec[1];
};

typedef int (*key_restrict_link_func_t___436)(struct key___435 *, const struct key_type *, const union key_payload *, struct key___435 *);

struct key_restriction___435;

struct key___435 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___469 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___435 *restrict_link;
};

struct key_restriction___435 {
	key_restrict_link_func_t___436 check;
	struct key___435 *key;
	struct key_type *keytype;
};

struct cgroup_namespace___316 {
	refcount_t count;
	struct ns_common___29 ns;
	struct user_namespace___332 *user_ns;
	struct ucounts___332 *ucounts;
	struct css_set___316 *root_cset;
};

struct ucounts___332 {
	struct hlist_node node;
	struct user_namespace___332 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct ethtool_ops___112 {
	int (*get_settings)(struct net_device___112 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___112 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___112 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___112 *);
	void (*get_regs)(struct net_device___112 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___112 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___112 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___112 *);
	void (*set_msglevel)(struct net_device___112 *, u32);
	int (*nway_reset)(struct net_device___112 *);
	u32 (*get_link)(struct net_device___112 *);
	int (*get_eeprom_len)(struct net_device___112 *);
	int (*get_eeprom)(struct net_device___112 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___112 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___112 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___112 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___112 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___112 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___112 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___112 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___112 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___112 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___112 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___112 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___112 *);
	void (*complete)(struct net_device___112 *);
	u32 (*get_priv_flags)(struct net_device___112 *);
	int (*set_priv_flags)(struct net_device___112 *, u32);
	int (*get_sset_count)(struct net_device___112 *, int);
	int (*get_rxnfc)(struct net_device___112 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___112 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___112 *, struct ethtool_flash *);
	int (*reset)(struct net_device___112 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___112 *);
	u32 (*get_rxfh_indir_size)(struct net_device___112 *);
	int (*get_rxfh)(struct net_device___112 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___112 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___112 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___112 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___112 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___112 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___112 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___112 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___112 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___112 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___112 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___112 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___112 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___112 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___112 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___112 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___112 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___112 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___112 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___112 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___112 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___112 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	int (*get_fecparam)(struct net_device___112 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___112 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___112 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___112 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___112 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___112;

struct inet_frags___112 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___112 *, const void *);
	void (*destructor)(struct inet_frag_queue___112 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___112 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___113 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___113 *fragments_tail;
	struct sk_buff___113 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___112 *net;
	struct callback_head rcu;
};

struct ip_ra_chain___56 {
	struct ip_ra_chain___56 *next;
	struct sock___92 *sk;
	union {
		void (*destructor)(struct sock___92 *);
		struct sock___92 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___92;

struct fib_lookup_arg___92;

struct fib_rules_ops___92 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___92 *, struct flowi *, int, struct fib_lookup_arg___92 *);
	bool (*suppress)(struct fib_rule___92 *, struct fib_lookup_arg___92 *);
	int (*match)(struct fib_rule___92 *, struct flowi *, int);
	int (*configure)(struct fib_rule___92 *, struct sk_buff___113 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___92 *);
	int (*compare)(struct fib_rule___92 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___92 *, struct sk_buff___113 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___92 *);
	void (*flush_cache)(struct fib_rules_ops___92 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___393 *owner;
	struct net___123 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___93 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___123 *);
	int (*fib_dump)(struct net___123 *, struct notifier_block *);
	struct module___393 *owner;
	struct callback_head rcu;
};

struct dst_entry___92 {
	struct net_device___112 *dev;
	struct dst_ops___123 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state___25 *xfrm;
	int (*input)(struct sk_buff___113 *);
	int (*output)(struct net___123 *, struct sock___92 *, struct sk_buff___113 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___92;

struct neigh_parms___92;

struct neigh_ops___92;

struct neighbour___92 {
	struct neighbour___92 *next;
	struct neigh_table___92 *tbl;
	struct neigh_parms___92 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___112 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___92 *, struct sk_buff___113 *);
	const struct neigh_ops___92 *ops;
	struct callback_head rcu;
	struct net_device___112 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct fib6_nh___33 {
	struct in6_addr nh_gw;
	struct net_device___112 *nh_dev;
	struct lwtunnel_state *nh_lwtstate;
	unsigned int nh_flags;
	atomic_t nh_upper_bound;
	int nh_weight;
};

struct fib6_node___33;

struct fib6_info___33 {
	struct fib6_table___33 *fib6_table;
	struct fib6_info___33 *fib6_next;
	struct fib6_node___33 *fib6_node;
	struct list_head fib6_siblings;
	unsigned int fib6_nsiblings;
	atomic_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	struct rt6_info___33 **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
	long unsigned int last_probe;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 exception_bucket_flushed: 1;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 dst_host: 1;
	u8 fib6_destroying: 1;
	u8 unused: 2;
	struct fib6_nh___33 fib6_nh;
	struct callback_head rcu;
};

struct rt6_info___33 {
	struct dst_entry___92 dst;
	struct fib6_info___33 *from;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___62 *rt6i_idev;
	u32 rt6i_flags;
	struct rt6key rt6i_prefsrc;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct fib6_node___33 {
	struct fib6_node___33 *parent;
	struct fib6_node___33 *left;
	struct fib6_node___33 *right;
	struct fib6_info___33 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info___33 *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table___33 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node___33 tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

struct nf_hook_state___20;

typedef unsigned int nf_hookfn___20(void *, struct sk_buff___113 *, const struct nf_hook_state___20 *);

struct nf_hook_entry___20 {
	nf_hookfn___20 *hook;
	void *priv;
};

struct nf_hook_entries___20 {
	u16 num_hook_entries;
	struct nf_hook_entry___20 hooks[0];
};

struct bpf_prog_aux___105;

struct bpf_prog___102 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___105 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

struct seq_operations___406 {
	void * (*start)(struct seq_file___406 *, loff_t *);
	void (*stop)(struct seq_file___406 *, void *);
	void * (*next)(struct seq_file___406 *, void *, loff_t *);
	int (*show)(struct seq_file___406 *, void *);
};

struct pernet_operations___113 {
	struct list_head list;
	int (*init)(struct net___123 *);
	void (*exit)(struct net___123 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___112 {
	int (*ieee_getets)(struct net_device___112 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___112 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___112 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___112 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___112 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___112 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___112 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___112 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___112 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___112 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___112 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___112 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___112 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___112 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___112 *);
	u8 (*setstate)(struct net_device___112 *, u8);
	void (*getpermhwaddr)(struct net_device___112 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___112 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___112 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___112 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___112 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___112 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___112 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___112 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___112 *, int, u8 *);
	void (*setpfccfg)(struct net_device___112 *, int, u8);
	void (*getpfccfg)(struct net_device___112 *, int, u8 *);
	u8 (*setall)(struct net_device___112 *);
	u8 (*getcap)(struct net_device___112 *, int, u8 *);
	int (*getnumtcs)(struct net_device___112 *, int, u8 *);
	int (*setnumtcs)(struct net_device___112 *, int, u8);
	u8 (*getpfcstate)(struct net_device___112 *);
	void (*setpfcstate)(struct net_device___112 *, u8);
	void (*getbcncfg)(struct net_device___112 *, int, u32 *);
	void (*setbcncfg)(struct net_device___112 *, int, u32);
	void (*getbcnrp)(struct net_device___112 *, int, u8 *);
	void (*setbcnrp)(struct net_device___112 *, int, u8);
	int (*setapp)(struct net_device___112 *, u8, u16, u8);
	int (*getapp)(struct net_device___112 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___112 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___112 *, int, u8);
	u8 (*getdcbx)(struct net_device___112 *);
	u8 (*setdcbx)(struct net_device___112 *, u8);
	int (*peer_getappinfo)(struct net_device___112 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___112 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___112 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___112 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___112 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___112 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct bpf_map___317;

struct bpf_map_ops___316 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___317 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___317 *, struct file___467 *);
	void (*map_free)(struct bpf_map___317 *);
	int (*map_get_next_key)(struct bpf_map___317 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___317 *);
	void * (*map_lookup_elem)(struct bpf_map___317 *, void *);
	int (*map_update_elem)(struct bpf_map___317 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___317 *, void *);
	int (*map_push_elem)(struct bpf_map___317 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___317 *, void *);
	int (*map_peek_elem)(struct bpf_map___317 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___317 *, struct file___467 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___317 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___317 *, void *, struct seq_file___406 *);
	int (*map_check_btf)(const struct bpf_map___317 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___317 {
	const struct bpf_map_ops___316 *ops;
	struct bpf_map___317 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___435 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___112;

struct bpf_map_dev_ops___112 {
	int (*map_get_next_key)(struct bpf_offloaded_map___112 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___112 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___112 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___112 *, void *);
};

struct bpf_offloaded_map___112 {
	struct bpf_map___317 map;
	struct net_device___112 *netdev;
	const struct bpf_map_dev_ops___112 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___102 {
	int (*test_run)(struct bpf_prog___102 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___102 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___102 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___102 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___102 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___102 *, u32 *);
};

struct bpf_prog_offload_ops___102 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___102 *);
	int (*translate)(struct bpf_prog___102 *);
	void (*destroy)(struct bpf_prog___102 *);
};

struct bpf_prog_offload___102 {
	struct bpf_prog___102 *prog;
	struct net_device___112 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___102 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___105 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___102 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___102 *ops;
	struct bpf_map___317 **used_maps;
	struct bpf_prog___102 *prog;
	struct user_struct___435 *user;
	u64 load_time;
	struct bpf_map___317 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___102 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___102 {
	struct bpf_prog___102 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___102 {
	struct callback_head rcu;
	struct bpf_prog_array_item___102 items[0];
};

struct cgroup_bpf___102 {
	struct bpf_prog_array___102 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___102 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___317;

typedef void (*kthread_work_func_t___317)(struct kthread_work___317 *);

struct kthread_worker___317;

struct kthread_work___317 {
	struct list_head node;
	kthread_work_func_t___317 func;
	struct kthread_worker___317 *worker;
	int canceling;
};

struct kthread_worker___317 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___469 *task;
	struct kthread_work___317 *current_work;
};

struct kthread_delayed_work___316 {
	struct kthread_work___317 work;
	struct timer_list timer;
};

struct psi_group___316 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___317 *poll_kworker;
	struct kthread_delayed_work___316 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___316;

struct cgroup_rstat_cpu___316;

struct cgroup___316 {
	struct cgroup_subsys_state___316 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___462 *kn;
	struct cgroup_file___316 procs_file;
	struct cgroup_file___316 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___316 *subsys[13];
	struct cgroup_root___316 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___316 *dom_cgrp;
	struct cgroup_rstat_cpu___316 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___102 bpf;
	atomic_t congestion_count;
	struct cgroup___316 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___316 psi;
	int ancestor_ids[0];
};

struct cftype___316;

struct cgroup_subsys___316 {
	struct cgroup_subsys_state___316 * (*css_alloc)(struct cgroup_subsys_state___316 *);
	int (*css_online)(struct cgroup_subsys_state___316 *);
	void (*css_offline)(struct cgroup_subsys_state___316 *);
	void (*css_released)(struct cgroup_subsys_state___316 *);
	void (*css_free)(struct cgroup_subsys_state___316 *);
	void (*css_reset)(struct cgroup_subsys_state___316 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___316 *, int);
	int (*css_extra_stat_show)(struct seq_file___406 *, struct cgroup_subsys_state___316 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___469 *);
	void (*cancel_fork)(struct task_struct___469 *);
	void (*fork)(struct task_struct___469 *);
	void (*exit)(struct task_struct___469 *);
	void (*free)(struct task_struct___469 *);
	void (*bind)(struct cgroup_subsys_state___316 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___316 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___316 *dfl_cftypes;
	struct cftype___316 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___316 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___316 *updated_children;
	struct cgroup___316 *updated_next;
};

struct cgroup_root___316 {
	struct kernfs_root___461 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___316 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___316 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___316 *ss;
	struct list_head node;
	struct kernfs_ops___461 *kf_ops;
	int (*open)(struct kernfs_open_file___461 *);
	void (*release)(struct kernfs_open_file___461 *);
	u64 (*read_u64)(struct cgroup_subsys_state___316 *, struct cftype___316 *);
	s64 (*read_s64)(struct cgroup_subsys_state___316 *, struct cftype___316 *);
	int (*seq_show)(struct seq_file___406 *, void *);
	void * (*seq_start)(struct seq_file___406 *, loff_t *);
	void * (*seq_next)(struct seq_file___406 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___406 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___316 *, struct cftype___316 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___316 *, struct cftype___316 *, s64);
	ssize_t (*write)(struct kernfs_open_file___461 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___461 *, struct poll_table_struct___306 *);
};

struct xdp_rxq_info___112 {
	struct net_device___112 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___112 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___112 *dev_rx;
};

struct netlink_callback___114 {
	struct sk_buff___113 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___114 *);
	int (*dump)(struct sk_buff___113 *, struct netlink_callback___114 *);
	int (*done)(struct netlink_callback___114 *);
	void *data;
	struct module___393 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___112 {
	int (*create)(struct sk_buff___113 *, struct net_device___112 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___113 *, unsigned char *);
	int (*cache)(const struct neighbour___92 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___112 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___112 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___112 *, int);
	int poll_owner;
	struct net_device___112 *dev;
	struct sk_buff___113 *gro_list;
	struct sk_buff___113 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___112 {
	struct net_device___112 *dev;
	struct Qdisc___104 *qdisc;
	struct Qdisc___104 *qdisc_sleeping;
	struct kobject___455 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___112 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___104 {
	struct sk_buff___113 *head;
	struct sk_buff___113 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___104;

struct Qdisc___104 {
	int (*enqueue)(struct sk_buff___113 *, struct Qdisc___104 *, struct sk_buff___113 **);
	struct sk_buff___113 * (*dequeue)(struct Qdisc___104 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___104 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___112 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___112 gso_skb;
	struct qdisc_skb_head___104 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___104 *next_sched;
	struct sk_buff_head___112 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___112 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___455 kobj;
	struct net_device___112 *dev;
	long: 64;
	struct xdp_rxq_info___112 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___112)(struct net_device___112 *, struct sk_buff___113 *, struct net_device___112 *);

struct netdev_bpf___112 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___102 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___102 *prog;
			const struct bpf_prog_offload_ops___102 *ops;
		} verifier;
		struct {
			struct bpf_prog___102 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___112 *offmap;
		};
		struct {
			struct xdp_umem___3 *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___112 {
	int (*xdo_dev_state_add)(struct xfrm_state___25 *);
	void (*xdo_dev_state_delete)(struct xfrm_state___25 *);
	void (*xdo_dev_state_free)(struct xfrm_state___25 *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___113 *, struct xfrm_state___25 *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state___25 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct xfrm_state_offload___25 {
	struct net_device___112 *dev;
	long unsigned int offload_handle;
	unsigned int num_exthdrs;
	u8 flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct xfrm_replay___25;

struct xfrm_type___25;

struct xfrm_mode___25;

struct xfrm_type_offload___25;

struct xfrm_state___25 {
	possible_net_t___114 xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	refcount_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
		u32 output_mark;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	const char *geniv;
	struct xfrm_encap_tmpl *encap;
	xfrm_address_t *coaddr;
	struct xfrm_state___25 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	const struct xfrm_replay___25 *repl;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct tasklet_hrtimer mtimer;
	struct xfrm_state_offload___25 xso;
	long int saved_tmo;
	long unsigned int lastused;
	struct page_frag___468 xfrag;
	const struct xfrm_type___25 *type;
	struct xfrm_mode___25 *inner_mode;
	struct xfrm_mode___25 *inner_mode_iaf;
	struct xfrm_mode___25 *outer_mode;
	const struct xfrm_type_offload___25 *type_offload;
	struct xfrm_sec_ctx___2 *security;
	void *data;
	u32 output_mark_mask;
	u32 if_id;
};

struct tlsdev_ops___112 {
	int (*tls_dev_add)(struct net_device___112 *, struct sock___92 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___112 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___112 *, struct sock___92 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___112 {
	int (*ndo_init)(struct net_device___112 *);
	void (*ndo_uninit)(struct net_device___112 *);
	int (*ndo_open)(struct net_device___112 *);
	int (*ndo_stop)(struct net_device___112 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___113 *, struct net_device___112 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___113 *, struct net_device___112 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___112 *, struct sk_buff___113 *, struct net_device___112 *, select_queue_fallback_t___112);
	void (*ndo_change_rx_flags)(struct net_device___112 *, int);
	void (*ndo_set_rx_mode)(struct net_device___112 *);
	int (*ndo_set_mac_address)(struct net_device___112 *, void *);
	int (*ndo_validate_addr)(struct net_device___112 *);
	int (*ndo_do_ioctl)(struct net_device___112 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___112 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___112 *, int);
	int (*ndo_neigh_setup)(struct net_device___112 *, struct neigh_parms___92 *);
	void (*ndo_tx_timeout)(struct net_device___112 *);
	void (*ndo_get_stats64)(struct net_device___112 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___112 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___112 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___112 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___112 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___112 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___112 *);
	int (*ndo_netpoll_setup)(struct net_device___112 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___112 *);
	int (*ndo_set_vf_mac)(struct net_device___112 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___112 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___112 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___112 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___112 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___112 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___112 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___112 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___112 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___112 *, int, struct sk_buff___113 *);
	int (*ndo_set_vf_guid)(struct net_device___112 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___112 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___112 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___112 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___112 *, const struct sk_buff___113 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___112 *, struct net_device___112 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___112 *, struct net_device___112 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___112 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___112 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___112 *, struct neighbour___92 *);
	void (*ndo_neigh_destroy)(struct net_device___112 *, struct neighbour___92 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___112 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___112 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___112 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___113 *, struct netlink_callback___114 *, struct net_device___112 *, struct net_device___112 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___112 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___112 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___113 *, u32, u32, struct net_device___112 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___112 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___112 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___112 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___112 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___112 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___112 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___112 *, struct net_device___112 *);
	void (*ndo_dfwd_del_station)(struct net_device___112 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___112 *);
	int (*ndo_set_tx_maxrate)(struct net_device___112 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___112 *);
	int (*ndo_change_proto_down)(struct net_device___112 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___112 *, struct sk_buff___113 *);
	void (*ndo_set_rx_headroom)(struct net_device___112 *, int);
	int (*ndo_bpf)(struct net_device___112 *, struct netdev_bpf___112 *);
	int (*ndo_xdp_xmit)(struct net_device___112 *, int, struct xdp_frame___112 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___112 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___112 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___92 {
	possible_net_t___114 net;
	struct net_device___112 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___92 *);
	void (*neigh_cleanup)(struct neighbour___92 *);
	struct neigh_table___92 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___92 {
	u32 (*l3mdev_fib_table)(const struct net_device___112 *);
	struct sk_buff___113 * (*l3mdev_l3_rcv)(struct net_device___112 *, struct sk_buff___113 *, u16);
	struct sk_buff___113 * (*l3mdev_l3_out)(struct net_device___112 *, struct sock___92 *, struct sk_buff___113 *, u16);
	struct dst_entry___92 * (*l3mdev_link_scope_lookup)(const struct net_device___112 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct ndisc_ops___62 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___112 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___112 *, struct neighbour___92 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___112 *, u8, struct neighbour___92 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___112 *, struct sk_buff___113 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___123 *, struct net_device___112 *, const struct prefix_info *, struct inet6_dev___62 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___62;

struct ifacaddr6___33;

struct inet6_dev___62 {
	struct net_device___112 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___62 *mc_list;
	struct ifmcaddr6___62 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___33 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	u8 rndid[8];
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___92 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
};

struct tcf_proto___104;

struct mini_Qdisc___104 {
	struct tcf_proto___104 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___104 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___112 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___123 *, struct net_device___112 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___112 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___112 *, struct list_head *);
	size_t (*get_size)(const struct net_device___112 *);
	int (*fill_info)(struct sk_buff___113 *, const struct net_device___112 *);
	size_t (*get_xstats_size)(const struct net_device___112 *);
	int (*fill_xstats)(struct sk_buff___113 *, const struct net_device___112 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___112 *, struct net_device___112 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___112 *, const struct net_device___112 *);
	int (*fill_slave_info)(struct sk_buff___113 *, const struct net_device___112 *, const struct net_device___112 *);
	struct net___123 * (*get_link_net)(const struct net_device___112 *);
	size_t (*get_linkxstats_size)(const struct net_device___112 *, int);
	int (*fill_linkxstats)(struct sk_buff___113 *, const struct net_device___112 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___112 {
	struct list_head poll_list;
	struct sk_buff_head___112 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___112 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___104 *output_queue;
	struct Qdisc___104 **output_queue_tailp;
	struct sk_buff___113 *completion_queue;
	struct sk_buff_head___112 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___112 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___112 input_pkt_queue;
	struct napi_struct___112 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bdi_writeback_congested___257 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___257 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___257 {
	struct bio___257 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___259 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___259 bip_inline_vecs[0];
};

struct bio_set___257 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___257 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___200 {
	struct mem_cgroup___200 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___200 {
	struct lruvec___468 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___200 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___200 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct kernel_param_ops___393 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___393 *);
	int (*get)(char *, const struct kernel_param___393 *);
	void (*free)(void *);
};

struct kparam_array___393;

struct kernel_param___393 {
	const char *name;
	struct module___393 *mod;
	const struct kernel_param_ops___393 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___393 *arr;
	};
};

struct kparam_array___393 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___393 *ops;
	void *elem;
};

struct module_attribute___393 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___393 *, struct module_kobject___393 *, char *);
	ssize_t (*store)(struct module_attribute___393 *, struct module_kobject___393 *, const char *, size_t);
	void (*setup)(struct module___393 *, const char *);
	int (*test)(struct module___393 *);
	void (*free)(struct module___393 *);
};

struct gnet_dump___104 {
	spinlock_t *lock;
	struct sk_buff___113 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___104;

struct Qdisc_ops___104 {
	struct Qdisc_ops___104 *next;
	const struct Qdisc_class_ops___104 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___113 *, struct Qdisc___104 *, struct sk_buff___113 **);
	struct sk_buff___113 * (*dequeue)(struct Qdisc___104 *);
	struct sk_buff___113 * (*peek)(struct Qdisc___104 *);
	int (*init)(struct Qdisc___104 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___104 *);
	void (*destroy)(struct Qdisc___104 *);
	int (*change)(struct Qdisc___104 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___104 *);
	int (*change_tx_queue_len)(struct Qdisc___104 *, unsigned int);
	int (*dump)(struct Qdisc___104 *, struct sk_buff___113 *);
	int (*dump_stats)(struct Qdisc___104 *, struct gnet_dump___104 *);
	void (*ingress_block_set)(struct Qdisc___104 *, u32);
	void (*egress_block_set)(struct Qdisc___104 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___104 *);
	u32 (*egress_block_get)(struct Qdisc___104 *);
	struct module___393 *owner;
};

struct tcf_block___104;

struct Qdisc_class_ops___104 {
	unsigned int flags;
	struct netdev_queue___112 * (*select_queue)(struct Qdisc___104 *, struct tcmsg *);
	int (*graft)(struct Qdisc___104 *, long unsigned int, struct Qdisc___104 *, struct Qdisc___104 **, struct netlink_ext_ack *);
	struct Qdisc___104 * (*leaf)(struct Qdisc___104 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___104 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___104 *, u32);
	int (*change)(struct Qdisc___104 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___104 *, long unsigned int);
	void (*walk)(struct Qdisc___104 *, struct qdisc_walker *);
	struct tcf_block___104 * (*tcf_block)(struct Qdisc___104 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___104 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___104 *, long unsigned int);
	int (*dump)(struct Qdisc___104 *, long unsigned int, struct sk_buff___113 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___104 *, long unsigned int, struct gnet_dump___104 *);
};

struct tcf_chain___104;

struct tcf_block___104 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___123 *net;
	struct Qdisc___104 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___104 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___104;

struct tcf_proto_ops___104;

struct tcf_proto___104 {
	struct tcf_proto___104 *next;
	void *root;
	int (*classify)(struct sk_buff___113 *, const struct tcf_proto___104 *, struct tcf_result___104 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___104 *ops;
	struct tcf_chain___104 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___104 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___104 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___104 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___113 *, const struct tcf_proto___104 *, struct tcf_result___104 *);
	int (*init)(struct tcf_proto___104 *);
	void (*destroy)(struct tcf_proto___104 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___104 *, u32);
	void (*put)(struct tcf_proto___104 *, void *);
	int (*change)(struct net___123 *, struct sk_buff___113 *, struct tcf_proto___104 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___104 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___104 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___104 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___123 *, struct tcf_chain___104 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___123 *, struct tcf_proto___104 *, void *, struct sk_buff___113 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___113 *, struct net___123 *, void *);
	struct module___393 *owner;
	int flags;
};

struct tcf_chain___104 {
	struct mutex filter_chain_lock;
	struct tcf_proto___104 *filter_chain;
	struct list_head list;
	struct tcf_block___104 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___104 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___92 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___102 *prog;
};

struct bpf_redirect_info___102 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___317 *map;
	struct bpf_map___317 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___92;

struct neigh_hash_table___92;

struct neigh_table___92 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___112 *, __u32 *);
	bool (*key_eq)(const struct neighbour___92 *, const void *);
	int (*constructor)(struct neighbour___92 *);
	int (*pconstructor)(struct pneigh_entry___92 *);
	void (*pdestructor)(struct pneigh_entry___92 *);
	void (*proxy_redo)(struct sk_buff___113 *);
	char *id;
	struct neigh_parms___92 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___112 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___92 *nht;
	struct pneigh_entry___92 **phash_buckets;
};

struct neigh_ops___92 {
	int family;
	void (*solicit)(struct neighbour___92 *, struct sk_buff___113 *);
	void (*error_report)(struct neighbour___92 *, struct sk_buff___113 *);
	int (*output)(struct neighbour___92 *, struct sk_buff___113 *);
	int (*connected_output)(struct neighbour___92 *, struct sk_buff___113 *);
};

struct pneigh_entry___92 {
	struct pneigh_entry___92 *next;
	possible_net_t___114 net;
	struct net_device___112 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___92 {
	struct neighbour___92 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___92 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___92 *ctarget;
	struct net___123 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___92 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___92 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___74;

struct timewait_sock_ops___70;

struct proto___92 {
	void (*close)(struct sock___92 *, long int);
	int (*pre_connect)(struct sock___92 *, struct sockaddr *, int);
	int (*connect)(struct sock___92 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___92 *, int);
	struct sock___92 * (*accept)(struct sock___92 *, int, int *, bool);
	int (*ioctl)(struct sock___92 *, int, long unsigned int);
	int (*init)(struct sock___92 *);
	void (*destroy)(struct sock___92 *);
	void (*shutdown)(struct sock___92 *, int);
	int (*setsockopt)(struct sock___92 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___92 *, int, int, char *, int *);
	void (*keepalive)(struct sock___92 *, int);
	int (*sendmsg)(struct sock___92 *, struct msghdr___95 *, size_t);
	int (*recvmsg)(struct sock___92 *, struct msghdr___95 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___92 *, struct page___468 *, int, size_t, int);
	int (*bind)(struct sock___92 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___92 *, struct sk_buff___113 *);
	void (*release_cb)(struct sock___92 *);
	int (*hash)(struct sock___92 *);
	void (*unhash)(struct sock___92 *);
	void (*rehash)(struct sock___92 *);
	int (*get_port)(struct sock___92 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___92 *);
	bool (*stream_memory_read)(const struct sock___92 *);
	void (*enter_memory_pressure)(struct sock___92 *);
	void (*leave_memory_pressure)(struct sock___92 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___74 *rsk_prot;
	struct timewait_sock_ops___70 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___393 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___92 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct xfrm_policy_queue___25 {
	struct sk_buff_head___112 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___25 {
	possible_net_t___114 xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	refcount_t refcnt;
	struct timer_list timer;
	atomic_t genid;
	u32 priority;
	u32 index;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___25 polq;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx___2 *security;
	struct xfrm_tmpl xfrm_vec[6];
	struct callback_head rcu;
	u32 if_id;
};

struct request_sock___75;

struct request_sock_ops___74 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___92 *, struct request_sock___75 *);
	void (*send_ack)(const struct sock___92 *, struct sk_buff___113 *, struct request_sock___75 *);
	void (*send_reset)(const struct sock___92 *, struct sk_buff___113 *);
	void (*destructor)(struct request_sock___75 *);
	void (*syn_ack_timeout)(const struct request_sock___75 *);
};

struct timewait_sock_ops___70 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___92 *, struct sock___92 *, void *);
	void (*twsk_destructor)(struct sock___92 *);
};

struct request_sock___75 {
	struct sock_common___92 __req_common;
	struct request_sock___75 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___74 *rsk_ops;
	struct sock___92 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___62 {
	struct in6_addr mca_addr;
	struct inet6_dev___62 *idev;
	struct ifmcaddr6___62 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___33 {
	struct in6_addr aca_addr;
	struct fib6_info___33 *aca_rt;
	struct ifacaddr6___33 *aca_next;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct ip6_ra_chain___62 {
	struct ip6_ra_chain___62 *next;
	struct sock___92 *sk;
	int sel;
	void (*destructor)(struct sock___92 *);
};

struct xfrm_replay___25 {
	void (*advance)(struct xfrm_state___25 *, __be32);
	int (*check)(struct xfrm_state___25 *, struct sk_buff___113 *, __be32);
	int (*recheck)(struct xfrm_state___25 *, struct sk_buff___113 *, __be32);
	void (*notify)(struct xfrm_state___25 *, int);
	int (*overflow)(struct xfrm_state___25 *, struct sk_buff___113 *);
};

struct xfrm_type___25 {
	char *description;
	struct module___393 *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___25 *);
	void (*destructor)(struct xfrm_state___25 *);
	int (*input)(struct xfrm_state___25 *, struct sk_buff___113 *);
	int (*output)(struct xfrm_state___25 *, struct sk_buff___113 *);
	int (*reject)(struct xfrm_state___25 *, struct sk_buff___113 *, const struct flowi *);
	int (*hdr_offset)(struct xfrm_state___25 *, struct sk_buff___113 *, u8 **);
	u32 (*get_mtu)(struct xfrm_state___25 *, int);
};

struct xfrm_state_afinfo___25;

struct xfrm_mode___25 {
	int (*input2)(struct xfrm_state___25 *, struct sk_buff___113 *);
	int (*input)(struct xfrm_state___25 *, struct sk_buff___113 *);
	int (*output2)(struct xfrm_state___25 *, struct sk_buff___113 *);
	int (*output)(struct xfrm_state___25 *, struct sk_buff___113 *);
	struct sk_buff___113 * (*gso_segment)(struct xfrm_state___25 *, struct sk_buff___113 *, netdev_features_t);
	void (*xmit)(struct xfrm_state___25 *, struct sk_buff___113 *);
	struct xfrm_state_afinfo___25 *afinfo;
	struct module___393 *owner;
	unsigned int encap;
	int flags;
};

struct xfrm_type_offload___25 {
	char *description;
	struct module___393 *owner;
	u8 proto;
	void (*encap)(struct xfrm_state___25 *, struct sk_buff___113 *);
	int (*input_tail)(struct xfrm_state___25 *, struct sk_buff___113 *);
	int (*xmit)(struct xfrm_state___25 *, struct sk_buff___113 *, netdev_features_t);
};

struct xfrm_state_afinfo___25 {
	unsigned int family;
	unsigned int proto;
	__be16 eth_proto;
	struct module___393 *owner;
	const struct xfrm_type___25 *type_map[256];
	const struct xfrm_type_offload___25 *type_offload_map[256];
	struct xfrm_mode___25 *mode_map[5];
	int (*init_flags)(struct xfrm_state___25 *);
	void (*init_tempsel)(struct xfrm_selector *, const struct flowi *);
	void (*init_temprop)(struct xfrm_state___25 *, const struct xfrm_tmpl *, const xfrm_address_t *, const xfrm_address_t *);
	int (*tmpl_sort)(struct xfrm_tmpl **, struct xfrm_tmpl **, int);
	int (*state_sort)(struct xfrm_state___25 **, struct xfrm_state___25 **, int);
	int (*output)(struct net___123 *, struct sock___92 *, struct sk_buff___113 *);
	int (*output_finish)(struct sock___92 *, struct sk_buff___113 *);
	int (*extract_input)(struct xfrm_state___25 *, struct sk_buff___113 *);
	int (*extract_output)(struct xfrm_state___25 *, struct sk_buff___113 *);
	int (*transport_finish)(struct sk_buff___113 *, int);
	void (*local_error)(struct sk_buff___113 *, u32);
};

struct nf_hook_state___20 {
	unsigned int hook;
	u_int8_t pf;
	struct net_device___112 *in;
	struct net_device___112 *out;
	struct sock___92 *sk;
	struct net___123 *net;
	int (*okfn)(struct net___123 *, struct sock___92 *, struct sk_buff___113 *);
};

struct nf_nat_hook___20 {
	int (*parse_nat_setup)(struct nf_conn *, enum nf_nat_manip_type, const struct nlattr *);
	void (*decode_session)(struct sk_buff___113 *, struct flowi *);
	unsigned int (*manip_pkt)(struct sk_buff___113 *, struct nf_conn *, enum nf_nat_manip_type, enum ip_conntrack_dir);
};

struct nf_ct_hook___20 {
	int (*update)(struct net___123 *, struct sk_buff___113 *);
	void (*destroy)(struct nf_conntrack *);
	bool (*get_tuple_skb)(struct nf_conntrack_tuple *, const struct sk_buff___113 *);
};

struct nfnl_ct_hook___20 {
	struct nf_conn * (*get_ct)(const struct sk_buff___113 *, enum ip_conntrack_info *);
	size_t (*build_size)(const struct nf_conn *);
	int (*build)(struct sk_buff___113 *, struct nf_conn *, enum ip_conntrack_info, u_int16_t, u_int16_t);
	int (*parse)(const struct nlattr *, struct nf_conn *);
	int (*attach_expect)(const struct nlattr *, struct nf_conn *, u32, u32);
	void (*seq_adjust)(struct sk_buff___113 *, struct nf_conn *, enum ip_conntrack_info, s32);
};

struct nf_ipv6_ops___11 {
	int (*chk_addr)(struct net___123 *, const struct in6_addr *, const struct net_device___112 *, int);
	void (*route_input)(struct sk_buff___113 *);
	int (*fragment)(struct net___123 *, struct sock___92 *, struct sk_buff___113 *, int (*)(struct net___123 *, struct sock___92 *, struct sk_buff___113 *));
	__sum16 (*checksum)(struct sk_buff___113 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___113 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___123 *, struct dst_entry___92 **, struct flowi *, bool);
	int (*reroute)(struct sk_buff___113 *, const struct nf_queue_entry___2 *);
};

struct ipv6_stub___22 {
	int (*ipv6_sock_mc_join)(struct sock___92 *, int, const struct in6_addr *);
	int (*ipv6_sock_mc_drop)(struct sock___92 *, int, const struct in6_addr *);
	int (*ipv6_dst_lookup)(struct net___123 *, struct sock___92 *, struct dst_entry___92 **, struct flowi6 *);
	struct fib6_table___33 * (*fib6_get_table)(struct net___123 *, u32);
	struct fib6_info___33 * (*fib6_lookup)(struct net___123 *, int, struct flowi6 *, int);
	struct fib6_info___33 * (*fib6_table_lookup)(struct net___123 *, struct fib6_table___33 *, int, struct flowi6 *, int);
	struct fib6_info___33 * (*fib6_multipath_select)(const struct net___123 *, struct fib6_info___33 *, struct flowi6 *, int, const struct sk_buff___113 *, int);
	u32 (*ip6_mtu_from_fib6)(struct fib6_info___33 *, struct in6_addr *, struct in6_addr *);
	void (*udpv6_encap_enable)();
	void (*ndisc_send_na)(struct net_device___112 *, const struct in6_addr *, const struct in6_addr *, bool, bool, bool, bool);
	struct neigh_table___92 *nd_tbl;
};

struct ipv6_bpf_stub___22 {
	int (*inet6_bind)(struct sock___92 *, struct sockaddr *, int, bool, bool);
	struct sock___92 * (*udp6_lib_lookup)(struct net___123 *, const struct in6_addr *, __be16, const struct in6_addr *, __be16, int, int, struct udp_table *, struct sk_buff___113 *);
};

struct module___394;

struct file___468;

struct kiocb___468;

struct iov_iter___235;

struct poll_table_struct___307;

struct vm_area_struct___469;

struct inode___468;

struct file_lock___468;

struct page___469;

struct pipe_inode_info___149;

struct seq_file___407;

struct file_operations___468 {
	struct module___394 *owner;
	loff_t (*llseek)(struct file___468 *, loff_t, int);
	ssize_t (*read)(struct file___468 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___468 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___468 *, struct iov_iter___235 *);
	ssize_t (*write_iter)(struct kiocb___468 *, struct iov_iter___235 *);
	int (*iopoll)(struct kiocb___468 *, bool);
	int (*iterate)(struct file___468 *, struct dir_context *);
	int (*iterate_shared)(struct file___468 *, struct dir_context *);
	__poll_t (*poll)(struct file___468 *, struct poll_table_struct___307 *);
	long int (*unlocked_ioctl)(struct file___468 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___468 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___468 *, struct vm_area_struct___469 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___468 *, struct file___468 *);
	int (*flush)(struct file___468 *, fl_owner_t);
	int (*release)(struct inode___468 *, struct file___468 *);
	int (*fsync)(struct file___468 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___468 *, int);
	int (*lock)(struct file___468 *, int, struct file_lock___468 *);
	ssize_t (*sendpage)(struct file___468 *, struct page___469 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___468 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___468 *, int, struct file_lock___468 *);
	ssize_t (*splice_write)(struct pipe_inode_info___149 *, struct file___468 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___468 *, loff_t *, struct pipe_inode_info___149 *, size_t, unsigned int);
	int (*setlease)(struct file___468 *, long int, struct file_lock___468 **, void **);
	long int (*fallocate)(struct file___468 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___407 *, struct file___468 *);
	ssize_t (*copy_file_range)(struct file___468 *, loff_t, struct file___468 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___468 *, loff_t, struct file___468 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___468 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___469 {
	u64 seqnum;
	struct vm_area_struct___469 *vmas[4];
};

struct page_frag___469 {
	struct page___469 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___469;

struct mem_cgroup___201;

struct pid___262;

struct cred___436;

struct nsproxy___363;

struct signal_struct___343;

struct bio_list___258;

struct backing_dev_info___258;

struct css_set___317;

struct vm_struct___372;

struct task_struct___470 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___470 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___469 *mm;
	struct mm_struct___469 *active_mm;
	struct vmacache___469 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___470 *real_parent;
	struct task_struct___470 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___470 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___201 *active_memcg;
	long int rh_reserved2;
	struct pid___262 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___262 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___262 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___436 *ptracer_cred;
	const struct cred___436 *real_cred;
	const struct cred___436 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___363 *nsproxy;
	struct signal_struct___343 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___470 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___258 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___258 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___317 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___149 *splice_pipe;
	struct page_frag___469 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___201 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___470 *oom_reaper_list;
	struct vm_struct___372 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___157 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___469 *pgtable_t___469;

struct address_space___468;

struct dev_pagemap___456;

struct page___469 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___468 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___469 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___469 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___469 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___456 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___201 *mem_cgroup;
};

struct pglist_data___469;

struct lruvec___469 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___469 *pgdat;
};

struct zone___469 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___469 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___469 {
	struct zone___469 *zone;
	int zone_idx;
};

struct zonelist___469 {
	struct zoneref___469 _zonerefs[25];
};

struct pglist_data___469 {
	struct zone___469 node_zones[3];
	struct zonelist___469 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___470 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___470 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___469 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___470 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___470 *owner;
};

struct secondary_data___470 {
	void *stack;
	struct task_struct___470 *task;
	long int status;
};

struct blocking_notifier_head___469 {
	struct rw_semaphore___470 rwsem;
	struct notifier_block *head;
};

struct cgroup___317;

struct cgroup_subsys___317;

struct cgroup_subsys_state___317 {
	struct cgroup___317 *cgroup;
	struct cgroup_subsys___317 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___317 *parent;
};

struct kernfs_node___463;

struct cgroup_file___317 {
	struct kernfs_node___463 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___201;

struct mem_cgroup___201 {
	struct cgroup_subsys_state___317 css;
	struct mem_cgroup_id___13 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___317 events_file;
	struct cgroup_file___317 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___470 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___201 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___262;

struct upid___262 {
	int nr;
	struct pid_namespace___262 *ns;
};

struct dentry___468;

struct user_namespace___333;

struct ucounts___333;

struct pid_namespace___262 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___470 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___262 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___468 *proc_self;
	struct dentry___468 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___333 *user_ns;
	struct ucounts___333 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___29 ns;
};

struct pid___262 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___262 numbers[1];
};

struct key___436;

struct user_namespace___333 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___333 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___29 ns;
	long unsigned int flags;
	struct key___436 *persistent_keyring_register;
	struct rw_semaphore___470 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___333 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct user_struct___436 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___436 *uid_keyring;
	struct key___436 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___456;

struct vm_area_struct___469 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___469 *vm_next;
	struct vm_area_struct___469 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___469 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___456 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___468 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___469;

struct mm_struct___469 {
	struct {
		struct vm_area_struct___469 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___468 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___470 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___469 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___470 *owner;
		struct user_namespace___333 *user_ns;
		struct file___468 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___469 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___436 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___436 *session_keyring;
	struct key___436 *process_keyring;
	struct key___436 *thread_keyring;
	struct key___436 *request_key_auth;
	void *security;
	struct user_struct___436 *user;
	struct user_namespace___333 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___124;

struct cgroup_namespace___317;

struct nsproxy___363 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___262 *pid_ns_for_children;
	struct net___124 *net_ns;
	struct cgroup_namespace___317 *cgroup_ns;
};

struct signal_struct___343 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___470 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___470 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___262 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___262 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___469 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___262 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___258;

struct bio_list___258 {
	struct bio___258 *head;
	struct bio___258 *tail;
};

struct bdi_writeback_congested___258;

struct bdi_writeback___258 {
	struct backing_dev_info___258 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___258 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___317 *memcg_css;
	struct cgroup_subsys_state___317 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___436;

struct backing_dev_info___258 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___258 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___436 *dev;
	struct device___436 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___468 *debug_dir;
	struct dentry___468 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___317 {
	struct cgroup_subsys_state___317 *subsys[13];
	refcount_t refcount;
	struct css_set___317 *dom_cset;
	struct cgroup___317 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___317 *mg_src_cgrp;
	struct cgroup___317 *mg_dst_cgrp;
	struct css_set___317 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___468;

struct pipe_buffer___149;

struct pipe_inode_info___149 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___469 *tmp_page;
	struct fasync_struct___468 *fasync_readers;
	struct fasync_struct___468 *fasync_writers;
	struct pipe_buffer___149 *bufs;
	struct user_struct___436 *user;
};

struct vm_struct___372 {
	struct vm_struct___372 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___469 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___355 {
	struct task_struct___470 task;
	long unsigned int stack[8192];
};

struct address_space_operations___468;

struct address_space___468 {
	struct inode___468 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___470 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___468 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___456)(struct vm_area_struct___469 *, long unsigned int, const struct page___469 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___456)(struct page___469 *, void *);

struct dev_pagemap___456 {
	dev_page_fault_t___456 page_fault;
	dev_page_free_t___456 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___436 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___469 {
	struct vfsmount *mnt;
	struct dentry___468 *dentry;
};

struct fown_struct___262 {
	rwlock_t lock;
	struct pid___262 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___468 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___469 f_path;
	struct inode___468 *f_inode;
	const struct file_operations___468 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___262 f_owner;
	const struct cred___436 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___468 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___456;

struct vm_operations_struct___456 {
	void (*open)(struct vm_area_struct___469 *);
	void (*close)(struct vm_area_struct___469 *);
	int (*split)(struct vm_area_struct___469 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___469 *);
	vm_fault_t (*fault)(struct vm_fault___456 *);
	vm_fault_t (*huge_fault)(struct vm_fault___456 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___456 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___469 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___456 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___456 *);
	int (*access)(struct vm_area_struct___469 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___469 *);
	int (*set_policy)(struct vm_area_struct___469 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___469 *, long unsigned int);
	struct page___469 * (*find_special_page)(struct vm_area_struct___469 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___469 {
	struct task_struct___470 *task;
	struct core_thread___469 *next;
};

struct core_state___469 {
	atomic_t nr_threads;
	struct core_thread___469 dumper;
	struct completion startup;
};

struct vm_fault___456 {
	struct vm_area_struct___469 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___469 *cow_page;
	struct mem_cgroup___201 *memcg;
	struct page___469 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___469 prealloc_pte;
};

struct kset___455;

struct kobj_type___455;

struct kobject___456 {
	const char *name;
	struct list_head entry;
	struct kobject___456 *parent;
	struct kset___455 *kset;
	struct kobj_type___455 *ktype;
	struct kernfs_node___463 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___394 {
	struct kobject___456 kobj;
	struct module___394 *mod;
	struct kobject___456 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___394 {
	struct module___394 *mod;
	struct latch_tree_node node;
};

struct module_layout___394 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___394 mtn;
};

struct module_attribute___394;

struct kernel_param___394;

struct module___394 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___394 mkobj;
	struct module_attribute___394 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___456 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___394 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___394 core_layout;
	struct module_layout___394 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bio_vec___260 {
	struct page___469 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___235 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___260 *bvec;
		struct pipe_inode_info___149 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct msghdr___96 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___235 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___468 *msg_iocb;
};

struct kiocb___468 {
	struct file___468 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___468 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dentry_operations___468;

struct super_block___468;

struct dentry___468 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___468 *d_parent;
	struct qstr d_name;
	struct inode___468 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___468 *d_op;
	struct super_block___468 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___468;

struct block_device___468;

struct inode___468 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___468 *i_op;
	struct super_block___468 *i_sb;
	struct address_space___468 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___470 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___258 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___468 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___468 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___149 *i_pipe;
		struct block_device___468 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___468 {
	int (*d_revalidate)(struct dentry___468 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___468 *, unsigned int);
	int (*d_hash)(const struct dentry___468 *, struct qstr *);
	int (*d_compare)(const struct dentry___468 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___468 *);
	int (*d_init)(struct dentry___468 *);
	void (*d_release)(struct dentry___468 *);
	void (*d_prune)(struct dentry___468 *);
	void (*d_iput)(struct dentry___468 *, struct inode___468 *);
	char * (*d_dname)(struct dentry___468 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___469 *);
	int (*d_manage)(const struct path___469 *, bool);
	struct dentry___468 * (*d_real)(struct dentry___468 *, const struct inode___468 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___468;

struct mem_dqinfo___468 {
	struct quota_format_type___468 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___468;

struct quota_info___468 {
	unsigned int flags;
	struct rw_semaphore___470 dqio_sem;
	struct inode___468 *files[3];
	struct mem_dqinfo___468 info[3];
	const struct quota_format_ops___468 *ops[3];
};

struct rcuwait___468 {
	struct task_struct___470 *task;
};

struct percpu_rw_semaphore___468 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___470 rw_sem;
	struct rcuwait___468 writer;
	int readers_block;
};

struct sb_writers___468 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___468 rw_sem[3];
};

struct shrink_control___201;

struct shrinker___201 {
	long unsigned int (*count_objects)(struct shrinker___201 *, struct shrink_control___201 *);
	long unsigned int (*scan_objects)(struct shrinker___201 *, struct shrink_control___201 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___468;

struct super_operations___468;

struct dquot_operations___468;

struct quotactl_ops___468;

struct super_block___468 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___468 *s_type;
	const struct super_operations___468 *s_op;
	const struct dquot_operations___468 *dq_op;
	const struct quotactl_ops___468 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___468 *s_root;
	struct rw_semaphore___470 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___468 *s_bdev;
	struct backing_dev_info___258 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___468 s_dquot;
	struct sb_writers___468 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___468 *s_d_op;
	int cleancache_poolid;
	struct shrinker___201 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___333 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___201 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___201 *memcg;
};

struct iattr___468 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___468 *ia_file;
};

struct dquot___468 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___468 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___468 {
	int qf_fmt_id;
	const struct quota_format_ops___468 *qf_ops;
	struct module___394 *qf_owner;
	struct quota_format_type___468 *qf_next;
};

struct quota_format_ops___468 {
	int (*check_quota_file)(struct super_block___468 *, int);
	int (*read_file_info)(struct super_block___468 *, int);
	int (*write_file_info)(struct super_block___468 *, int);
	int (*free_file_info)(struct super_block___468 *, int);
	int (*read_dqblk)(struct dquot___468 *);
	int (*commit_dqblk)(struct dquot___468 *);
	int (*release_dqblk)(struct dquot___468 *);
	int (*get_next_id)(struct super_block___468 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___468 {
	int (*write_dquot)(struct dquot___468 *);
	struct dquot___468 * (*alloc_dquot)(struct super_block___468 *, int);
	void (*destroy_dquot)(struct dquot___468 *);
	int (*acquire_dquot)(struct dquot___468 *);
	int (*release_dquot)(struct dquot___468 *);
	int (*mark_dirty)(struct dquot___468 *);
	int (*write_info)(struct super_block___468 *, int);
	qsize_t * (*get_reserved_space)(struct inode___468 *);
	int (*get_projid)(struct inode___468 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___468 *, qsize_t *);
	int (*get_next_id)(struct super_block___468 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___468 {
	int (*quota_on)(struct super_block___468 *, int, int, const struct path___469 *);
	int (*quota_off)(struct super_block___468 *, int);
	int (*quota_enable)(struct super_block___468 *, unsigned int);
	int (*quota_disable)(struct super_block___468 *, unsigned int);
	int (*quota_sync)(struct super_block___468 *, int);
	int (*set_info)(struct super_block___468 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___468 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___468 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___468 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___468 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___468 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___221;

struct address_space_operations___468 {
	int (*writepage)(struct page___469 *, struct writeback_control___221 *);
	int (*readpage)(struct file___468 *, struct page___469 *);
	int (*writepages)(struct address_space___468 *, struct writeback_control___221 *);
	int (*set_page_dirty)(struct page___469 *);
	int (*readpages)(struct file___468 *, struct address_space___468 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___468 *, struct address_space___468 *, loff_t, unsigned int, unsigned int, struct page___469 **, void **);
	int (*write_end)(struct file___468 *, struct address_space___468 *, loff_t, unsigned int, unsigned int, struct page___469 *, void *);
	sector_t (*bmap)(struct address_space___468 *, sector_t);
	void (*invalidatepage)(struct page___469 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___469 *, gfp_t);
	void (*freepage)(struct page___469 *);
	ssize_t (*direct_IO)(struct kiocb___468 *, struct iov_iter___235 *);
	int (*migratepage)(struct address_space___468 *, struct page___469 *, struct page___469 *, enum migrate_mode);
	bool (*isolate_page)(struct page___469 *, isolate_mode_t);
	void (*putback_page)(struct page___469 *);
	int (*launder_page)(struct page___469 *);
	int (*is_partially_uptodate)(struct page___469 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___469 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___468 *, struct page___469 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___468 *, sector_t *);
	void (*swap_deactivate)(struct file___468 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___221 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___258 *wb;
	struct inode___468 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___468 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___468 *bd_inode;
	struct super_block___468 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___468 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___258 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___468 {
	struct dentry___468 * (*lookup)(struct inode___468 *, struct dentry___468 *, unsigned int);
	const char * (*get_link)(struct dentry___468 *, struct inode___468 *, struct delayed_call *);
	int (*permission)(struct inode___468 *, int);
	struct posix_acl * (*get_acl)(struct inode___468 *, int);
	int (*readlink)(struct dentry___468 *, char *, int);
	int (*create)(struct inode___468 *, struct dentry___468 *, umode_t, bool);
	int (*link)(struct dentry___468 *, struct inode___468 *, struct dentry___468 *);
	int (*unlink)(struct inode___468 *, struct dentry___468 *);
	int (*symlink)(struct inode___468 *, struct dentry___468 *, const char *);
	int (*mkdir)(struct inode___468 *, struct dentry___468 *, umode_t);
	int (*rmdir)(struct inode___468 *, struct dentry___468 *);
	int (*mknod)(struct inode___468 *, struct dentry___468 *, umode_t, dev_t);
	int (*rename)(struct inode___468 *, struct dentry___468 *, struct inode___468 *, struct dentry___468 *, unsigned int);
	int (*setattr)(struct dentry___468 *, struct iattr___468 *);
	int (*getattr)(const struct path___469 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___468 *, char *, size_t);
	int (*fiemap)(struct inode___468 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___468 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___468 *, struct dentry___468 *, struct file___468 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___468 *, struct dentry___468 *, umode_t);
	int (*set_acl)(struct inode___468 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___468 {
	void (*fl_copy_lock)(struct file_lock___468 *, struct file_lock___468 *);
	void (*fl_release_private)(struct file_lock___468 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___468;

struct file_lock___468 {
	struct file_lock___468 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___468 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___468 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___468 *fl_ops;
	const struct lock_manager_operations___468 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___468 {
	int (*lm_compare_owner)(struct file_lock___468 *, struct file_lock___468 *);
	long unsigned int (*lm_owner_key)(struct file_lock___468 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___468 *);
	int (*lm_grant)(struct file_lock___468 *, int);
	bool (*lm_break)(struct file_lock___468 *);
	int (*lm_change)(struct file_lock___468 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___468 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___468 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___468 *fa_next;
	struct file___468 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___468 {
	const char *name;
	int fs_flags;
	struct dentry___468 * (*mount)(struct file_system_type___468 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___468 *);
	struct module___394 *owner;
	struct file_system_type___468 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___468 {
	struct inode___468 * (*alloc_inode)(struct super_block___468 *);
	void (*destroy_inode)(struct inode___468 *);
	void (*dirty_inode)(struct inode___468 *, int);
	int (*write_inode)(struct inode___468 *, struct writeback_control___221 *);
	int (*drop_inode)(struct inode___468 *);
	void (*evict_inode)(struct inode___468 *);
	void (*put_super)(struct super_block___468 *);
	int (*sync_fs)(struct super_block___468 *, int);
	int (*freeze_super)(struct super_block___468 *);
	int (*freeze_fs)(struct super_block___468 *);
	int (*thaw_super)(struct super_block___468 *);
	int (*unfreeze_fs)(struct super_block___468 *);
	int (*statfs)(struct dentry___468 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___468 *, int *, char *);
	void (*umount_begin)(struct super_block___468 *);
	int (*show_options)(struct seq_file___407 *, struct dentry___468 *);
	int (*show_devname)(struct seq_file___407 *, struct dentry___468 *);
	int (*show_path)(struct seq_file___407 *, struct dentry___468 *);
	int (*show_stats)(struct seq_file___407 *, struct dentry___468 *);
	ssize_t (*quota_read)(struct super_block___468 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___468 *, int, const char *, size_t, loff_t);
	struct dquot___468 ** (*get_dquots)(struct inode___468 *);
	int (*bdev_try_to_free_page)(struct super_block___468 *, struct page___469 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___468 *, struct shrink_control___201 *);
	long int (*free_cached_objects)(struct super_block___468 *, struct shrink_control___201 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___317)(struct file___468 *, wait_queue_head_t *, struct poll_table_struct___307 *);

struct poll_table_struct___307 {
	poll_queue_proc___317 _qproc;
	__poll_t _key;
};

struct seq_operations___407;

struct seq_file___407 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___407 *op;
	int poll_event;
	const struct file___468 *file;
	void *private;
};

typedef void bio_end_io_t___258(struct bio___258 *);

struct bio_integrity_payload___258;

struct bio_set___258;

struct bio___258 {
	struct bio___258 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___258 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___258 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___260 *bi_io_vec;
	struct bio_set___258 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___260 bi_inline_vecs[0];
};

struct socket_wq___94 {
	wait_queue_head_t wait;
	struct fasync_struct___468 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct sock___93;

struct proto_ops___94;

struct socket___95 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___94 *wq;
	struct file___468 *file;
	struct sock___93 *sk;
	const struct proto_ops___94 *ops;
};

typedef struct {
	struct net___124 *net;
} possible_net_t___115;

struct proto___93;

struct sock_common___93 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___93 *skc_prot;
	possible_net_t___115 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___93 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___114;

struct sk_buff_head___113 {
	struct sk_buff___114 *next;
	struct sk_buff___114 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___93;

struct xfrm_policy___26;

struct dst_entry___93;

struct net_device___113;

struct sock___93 {
	struct sock_common___93 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___113 sk_error_queue;
	struct sk_buff_head___113 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___114 *head;
		struct sk_buff___114 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___93 *sk_filter;
	union {
		struct socket_wq___94 *sk_wq;
		struct socket_wq___94 *sk_wq_raw;
	};
	struct xfrm_policy___26 *sk_policy[2];
	struct dst_entry___93 *sk_rx_dst;
	struct dst_entry___93 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___114 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___113 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___469 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___93 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___262 *sk_peer_pid;
	const struct cred___436 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___95 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___201 *sk_memcg;
	void (*sk_state_change)(struct sock___93 *);
	void (*sk_data_ready)(struct sock___93 *);
	void (*sk_write_space)(struct sock___93 *);
	void (*sk_error_report)(struct sock___93 *);
	int (*sk_backlog_rcv)(struct sock___93 *, struct sk_buff___114 *);
	struct sk_buff___114 * (*sk_validate_xmit_skb)(struct sock___93 *, struct net_device___113 *, struct sk_buff___114 *);
	void (*sk_destruct)(struct sock___93 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

typedef int (*sk_read_actor_t___93)(read_descriptor_t *, struct sk_buff___114 *, unsigned int, size_t);

struct proto_ops___94 {
	int family;
	struct module___394 *owner;
	int (*release)(struct socket___95 *);
	int (*bind)(struct socket___95 *, struct sockaddr *, int);
	int (*connect)(struct socket___95 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___95 *, struct socket___95 *);
	int (*accept)(struct socket___95 *, struct socket___95 *, int, bool);
	int (*getname)(struct socket___95 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___468 *, struct socket___95 *, struct poll_table_struct___307 *);
	int (*ioctl)(struct socket___95 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___95 *, int);
	int (*shutdown)(struct socket___95 *, int);
	int (*setsockopt)(struct socket___95 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___95 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___95 *, struct msghdr___96 *, size_t);
	int (*recvmsg)(struct socket___95 *, struct msghdr___96 *, size_t, int);
	int (*mmap)(struct file___468 *, struct socket___95 *, struct vm_area_struct___469 *);
	ssize_t (*sendpage)(struct socket___95 *, struct page___469 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___95 *, loff_t *, struct pipe_inode_info___149 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___93 *, int);
	int (*peek_len)(struct socket___95 *);
	int (*read_sock)(struct sock___93 *, read_descriptor_t *, sk_read_actor_t___93);
	int (*sendpage_locked)(struct sock___93 *, struct page___469 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___93 *, struct msghdr___96 *, size_t);
	int (*set_rcvlowat)(struct sock___93 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct sec_path___26;

struct nf_bridge_info___113;

struct sk_buff___114 {
	union {
		struct {
			struct sk_buff___114 *next;
			struct sk_buff___114 *prev;
			union {
				struct net_device___113 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___93 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___114 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path___26 *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___113 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___113;

struct netns_frags___113 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___113 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ip_ra_chain___57;

struct fib_rules_ops___93;

struct fib_notifier_ops___94;

struct netns_ipv4___113 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___57 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___93 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___93 *fibnl;
	struct sock___93 **icmp_sk;
	struct sock___93 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___93 **tcp_sk;
	struct netns_frags___113 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___93 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___94 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___94 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___93;

struct dst_ops___124 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___124 *);
	struct dst_entry___93 * (*check)(struct dst_entry___93 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___93 *);
	unsigned int (*mtu)(const struct dst_entry___93 *);
	u32 * (*cow_metrics)(struct dst_entry___93 *, long unsigned int);
	void (*destroy)(struct dst_entry___93 *);
	void (*ifdown)(struct dst_entry___93 *, struct net_device___113 *, int);
	struct dst_entry___93 * (*negative_advice)(struct dst_entry___93 *);
	void (*link_failure)(struct sk_buff___114 *);
	void (*update_pmtu)(struct dst_entry___93 *, struct sock___93 *, struct sk_buff___114 *, u32);
	void (*redirect)(struct dst_entry___93 *, struct sock___93 *, struct sk_buff___114 *);
	int (*local_out)(struct net___124 *, struct sock___93 *, struct sk_buff___114 *);
	struct neighbour___93 * (*neigh_lookup)(const struct dst_entry___93 *, struct sk_buff___114 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___93 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_info___34;

struct rt6_info___34;

struct fib6_table___34;

struct netns_ipv6___124 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___113 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info___34 *fib6_null_entry;
	struct rt6_info___34 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___34 *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___124 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info___34 *ip6_prohibit_entry;
	struct rt6_info___34 *ip6_blk_hole_entry;
	struct fib6_table___34 *fib6_local_tbl;
	struct fib_rules_ops___93 *fib6_rules_ops;
	struct sock___93 **icmp_sk;
	struct sock___93 *ndisc_sk;
	struct sock___93 *tcp_sk;
	struct sock___93 *igmp_sk;
	struct sock___93 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___93 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___94 *notifier_ops;
	struct fib_notifier_ops___94 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___94 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___93 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct nf_hook_entries___21;

struct netns_nf___22 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_queue_handler *queue_handler;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header *nf_log_dir_header;
	struct nf_hook_entries___21 *hooks_ipv4[5];
	struct nf_hook_entries___21 *hooks_ipv6[5];
	struct nf_hook_entries___21 *hooks_arp[3];
	struct nf_hook_entries___21 *hooks_bridge[5];
	bool defrag_ipv4;
	bool defrag_ipv6;
};

struct netns_nf_frag___113 {
	struct netns_frags___113 frags;
};

struct netns_xfrm___124 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___93 *nlsk;
	struct sock___93 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___124 xfrm4_dst_ops;
	struct dst_ops___124 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___103;

struct net___124 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___333 *user_ns;
	struct ucounts___333 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___29 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___93 *rtnl;
	struct sock___93 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___113 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___113 ipv4;
	struct netns_ipv6___124 ipv6;
	struct netns_sctp___94 sctp;
	struct netns_nf___22 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___113 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___93 *nfnl;
	struct sock___93 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___124 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___93 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___103 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kernfs_root___462;

struct kernfs_elem_dir___462 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___462 *root;
};

struct kernfs_syscall_ops___462;

struct kernfs_root___462 {
	struct kernfs_node___463 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___462 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___462 {
	struct kernfs_node___463 *target_kn;
};

struct kernfs_ops___462;

struct kernfs_elem_attr___462 {
	const struct kernfs_ops___462 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___463 *notify_next;
};

struct kernfs_node___463 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___463 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___462 dir;
		struct kernfs_elem_symlink___462 symlink;
		struct kernfs_elem_attr___462 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___462;

struct kernfs_ops___462 {
	int (*open)(struct kernfs_open_file___462 *);
	void (*release)(struct kernfs_open_file___462 *);
	int (*seq_show)(struct seq_file___407 *, void *);
	void * (*seq_start)(struct seq_file___407 *, loff_t *);
	void * (*seq_next)(struct seq_file___407 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___407 *, void *);
	ssize_t (*read)(struct kernfs_open_file___462 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___462 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___462 *, struct vm_area_struct___469 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___462 *, struct poll_table_struct___307 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___462 {
	int (*remount_fs)(struct kernfs_root___462 *, int *, char *);
	int (*show_options)(struct seq_file___407 *, struct kernfs_root___462 *);
	int (*mkdir)(struct kernfs_node___463 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___463 *);
	int (*rename)(struct kernfs_node___463 *, struct kernfs_node___463 *, const char *);
	int (*show_path)(struct seq_file___407 *, struct kernfs_node___463 *, struct kernfs_root___462 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___462 {
	struct kernfs_node___463 *kn;
	struct file___468 *file;
	struct seq_file___407 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___456 *vm_ops;
};

struct kobj_ns_type_operations___93 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___93 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___432;

struct attribute_group___433 {
	const char *name;
	umode_t (*is_visible)(struct kobject___456 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___456 *, struct bin_attribute___432 *, int);
	struct attribute **attrs;
	struct bin_attribute___432 **bin_attrs;
};

struct bin_attribute___432 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___468 *, struct kobject___456 *, struct bin_attribute___432 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___468 *, struct kobject___456 *, struct bin_attribute___432 *, char *, loff_t, size_t);
	int (*mmap)(struct file___468 *, struct kobject___456 *, struct bin_attribute___432 *, struct vm_area_struct___469 *);
};

struct sysfs_ops___455 {
	ssize_t (*show)(struct kobject___456 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___456 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___455;

struct kset___455 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___456 kobj;
	const struct kset_uevent_ops___455 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___455 {
	void (*release)(struct kobject___456 *);
	const struct sysfs_ops___455 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___93 * (*child_ns_type)(struct kobject___456 *);
	const void * (*namespace)(struct kobject___456 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___455 {
	int (* const filter)(struct kset___455 *, struct kobject___456 *);
	const char * (* const name)(struct kset___455 *, struct kobject___456 *);
	int (* const uevent)(struct kset___455 *, struct kobject___456 *, struct kobj_uevent_env *);
};

struct kobj_attribute___446 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___456 *, struct kobj_attribute___446 *, char *);
	ssize_t (*store)(struct kobject___456 *, struct kobj_attribute___446 *, const char *, size_t);
};

struct dev_pm_ops___436 {
	int (*prepare)(struct device___436 *);
	void (*complete)(struct device___436 *);
	int (*suspend)(struct device___436 *);
	int (*resume)(struct device___436 *);
	int (*freeze)(struct device___436 *);
	int (*thaw)(struct device___436 *);
	int (*poweroff)(struct device___436 *);
	int (*restore)(struct device___436 *);
	int (*suspend_late)(struct device___436 *);
	int (*resume_early)(struct device___436 *);
	int (*freeze_late)(struct device___436 *);
	int (*thaw_early)(struct device___436 *);
	int (*poweroff_late)(struct device___436 *);
	int (*restore_early)(struct device___436 *);
	int (*suspend_noirq)(struct device___436 *);
	int (*resume_noirq)(struct device___436 *);
	int (*freeze_noirq)(struct device___436 *);
	int (*thaw_noirq)(struct device___436 *);
	int (*poweroff_noirq)(struct device___436 *);
	int (*restore_noirq)(struct device___436 *);
	int (*runtime_suspend)(struct device___436 *);
	int (*runtime_resume)(struct device___436 *);
	int (*runtime_idle)(struct device___436 *);
};

struct dev_pm_info___436 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___436 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___436;

struct bus_type___436;

struct device_driver___436;

struct dev_pm_domain___436;

struct dma_map_ops___208;

struct fwnode_handle___356;

struct class___436;

struct device___436 {
	struct device___436 *parent;
	struct device_private *p;
	struct kobject___456 kobj;
	const char *init_name;
	const struct device_type___436 *type;
	struct mutex mutex;
	struct bus_type___436 *bus;
	struct device_driver___436 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___436 power;
	struct dev_pm_domain___436 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___208 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___356 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___436 *class;
	const struct attribute_group___433 **groups;
	void (*release)(struct device___436 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___436 {
	struct dev_pm_ops___436 ops;
	void (*detach)(struct device___436 *, bool);
	int (*activate)(struct device___436 *);
	void (*sync)(struct device___436 *);
	void (*dismiss)(struct device___436 *);
};

struct bus_type___436 {
	const char *name;
	const char *dev_name;
	struct device___436 *dev_root;
	const struct attribute_group___433 **bus_groups;
	const struct attribute_group___433 **dev_groups;
	const struct attribute_group___433 **drv_groups;
	int (*match)(struct device___436 *, struct device_driver___436 *);
	int (*uevent)(struct device___436 *, struct kobj_uevent_env *);
	int (*probe)(struct device___436 *);
	int (*remove)(struct device___436 *);
	void (*shutdown)(struct device___436 *);
	int (*online)(struct device___436 *);
	int (*offline)(struct device___436 *);
	int (*suspend)(struct device___436 *, pm_message_t);
	int (*resume)(struct device___436 *);
	int (*num_vf)(struct device___436 *);
	int (*dma_configure)(struct device___436 *);
	const struct dev_pm_ops___436 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___436 {
	const char *name;
	struct bus_type___436 *bus;
	struct module___394 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___436 *);
	int (*remove)(struct device___436 *);
	void (*shutdown)(struct device___436 *);
	int (*suspend)(struct device___436 *, pm_message_t);
	int (*resume)(struct device___436 *);
	const struct attribute_group___433 **groups;
	const struct dev_pm_ops___436 *pm;
	void (*coredump)(struct device___436 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___436 {
	const char *name;
	const struct attribute_group___433 **groups;
	int (*uevent)(struct device___436 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___436 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___436 *);
	const struct dev_pm_ops___436 *pm;
};

struct class___436 {
	const char *name;
	struct module___394 *owner;
	const struct attribute_group___433 **class_groups;
	const struct attribute_group___433 **dev_groups;
	struct kobject___456 *dev_kobj;
	int (*dev_uevent)(struct device___436 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___436 *, umode_t *);
	void (*class_release)(struct class___436 *);
	void (*dev_release)(struct device___436 *);
	int (*shutdown_pre)(struct device___436 *);
	const struct kobj_ns_type_operations___93 *ns_type;
	const void * (*namespace)(struct device___436 *);
	const struct dev_pm_ops___436 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___208 {
	void * (*alloc)(struct device___436 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___436 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___436 *, struct vm_area_struct___469 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___436 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___436 *, struct page___469 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___436 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___436 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___436 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___436 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___436 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___436 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___436 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___436 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___436 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___436 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___436 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___436 *, u64);
	u64 (*get_required_mask)(struct device___436 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___356;

struct fwnode_handle___356 {
	struct fwnode_handle___356 *secondary;
	const struct fwnode_operations___356 *ops;
};

typedef void compound_page_dtor___456(struct page___469 *);

struct fwnode_reference_args___356;

struct fwnode_endpoint___356;

struct fwnode_operations___356 {
	struct fwnode_handle___356 * (*get)(struct fwnode_handle___356 *);
	void (*put)(struct fwnode_handle___356 *);
	bool (*device_is_available)(const struct fwnode_handle___356 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___356 *, const struct device___436 *);
	bool (*property_present)(const struct fwnode_handle___356 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___356 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___356 *, const char *, const char **, size_t);
	struct fwnode_handle___356 * (*get_parent)(const struct fwnode_handle___356 *);
	struct fwnode_handle___356 * (*get_next_child_node)(const struct fwnode_handle___356 *, struct fwnode_handle___356 *);
	struct fwnode_handle___356 * (*get_named_child_node)(const struct fwnode_handle___356 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___356 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___356 *);
	struct fwnode_handle___356 * (*graph_get_next_endpoint)(const struct fwnode_handle___356 *, struct fwnode_handle___356 *);
	struct fwnode_handle___356 * (*graph_get_remote_endpoint)(const struct fwnode_handle___356 *);
	struct fwnode_handle___356 * (*graph_get_port_parent)(struct fwnode_handle___356 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___356 *, struct fwnode_endpoint___356 *);
};

struct fwnode_endpoint___356 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___356 *local_fwnode;
};

struct fwnode_reference_args___356 {
	struct fwnode_handle___356 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___149;

struct pipe_buffer___149 {
	struct page___469 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___149 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___149 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___149 *, struct pipe_buffer___149 *);
	void (*release)(struct pipe_inode_info___149 *, struct pipe_buffer___149 *);
	int (*steal)(struct pipe_inode_info___149 *, struct pipe_buffer___149 *);
	union {
		bool (*get)(struct pipe_inode_info___149 *, struct pipe_buffer___149 *);
		struct {
			void (*get)(struct pipe_inode_info___149 *, struct pipe_buffer___149 *);
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
};

struct nf_bridge_info___113 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___113 = 0,
		BRNF_PROTO_8021Q___113 = 1,
		BRNF_PROTO_PPPOE___113 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___113 *physindev;
	struct net_device___113 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___113(struct sk_buff___114 **);

struct net_device_ops___113;

struct ethtool_ops___113;

struct l3mdev_ops___93;

struct ndisc_ops___63;

struct xfrmdev_ops___113;

struct tlsdev_ops___113;

struct header_ops___113;

struct inet6_dev___63;

struct netdev_rx_queue___113;

struct mini_Qdisc___105;

struct netdev_queue___113;

struct Qdisc___105;

struct rtnl_link_ops___105;

struct dcbnl_rtnl_ops___113;

struct net_device___113 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___113 *netdev_ops;
	const struct ethtool_ops___113 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___93 *l3mdev_ops;
	const struct ndisc_ops___63 *ndisc_ops;
	const struct xfrmdev_ops___113 *xfrmdev_ops;
	const struct tlsdev_ops___113 *tlsdev_ops;
	const struct header_ops___113 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___455 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___63 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___113 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___103 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___113 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___105 *miniq_ingress;
	struct netdev_queue___113 *ingress_queue;
	struct nf_hook_entries___21 *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___113 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___105 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___105 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___113 = 0,
		NETREG_REGISTERED___113 = 1,
		NETREG_UNREGISTERING___113 = 2,
		NETREG_UNREGISTERED___113 = 3,
		NETREG_RELEASED___113 = 4,
		NETREG_DUMMY___113 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___113 = 0,
		RTNL_LINK_INITIALIZING___113 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___113 *);
	struct netpoll_info *npinfo;
	possible_net_t___115 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___436 dev;
	const struct attribute_group___433 *sysfs_groups[4];
	const struct attribute_group___433 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___105 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___113 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide35;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct skb_frag_struct___31 {
	struct {
		struct page___469 *p;
	} page;
	__u32 page_offset;
	__u32 size;
};

typedef struct skb_frag_struct___31 skb_frag_t___31;

struct skb_shared_info___31 {
	__u8 __unused;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___114 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___31 frags[16];
};

struct xfrm_state___26;

struct sec_path___26 {
	refcount_t refcnt;
	int len;
	int olen;
	struct xfrm_state___26 *xvec[6];
	struct xfrm_offload ovec[1];
};

struct kernel_param_ops___394 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___394 *);
	int (*get)(char *, const struct kernel_param___394 *);
	void (*free)(void *);
};

struct kparam_array___394;

struct kernel_param___394 {
	const char *name;
	struct module___394 *mod;
	const struct kernel_param_ops___394 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___394 *arr;
	};
};

struct kparam_array___394 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___394 *ops;
	void *elem;
};

struct module_attribute___394 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___394 *, struct module_kobject___394 *, char *);
	ssize_t (*store)(struct module_attribute___394 *, struct module_kobject___394 *, const char *, size_t);
	void (*setup)(struct module___394 *, const char *);
	int (*test)(struct module___394 *);
	void (*free)(struct module___394 *);
};

struct ethtool_ops___113 {
	int (*get_settings)(struct net_device___113 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___113 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___113 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___113 *);
	void (*get_regs)(struct net_device___113 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___113 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___113 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___113 *);
	void (*set_msglevel)(struct net_device___113 *, u32);
	int (*nway_reset)(struct net_device___113 *);
	u32 (*get_link)(struct net_device___113 *);
	int (*get_eeprom_len)(struct net_device___113 *);
	int (*get_eeprom)(struct net_device___113 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___113 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___113 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___113 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___113 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___113 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___113 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___113 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___113 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___113 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___113 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___113 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___113 *);
	void (*complete)(struct net_device___113 *);
	u32 (*get_priv_flags)(struct net_device___113 *);
	int (*set_priv_flags)(struct net_device___113 *, u32);
	int (*get_sset_count)(struct net_device___113 *, int);
	int (*get_rxnfc)(struct net_device___113 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___113 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___113 *, struct ethtool_flash *);
	int (*reset)(struct net_device___113 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___113 *);
	u32 (*get_rxfh_indir_size)(struct net_device___113 *);
	int (*get_rxfh)(struct net_device___113 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___113 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___113 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___113 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___113 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___113 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___113 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___113 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___113 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___113 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___113 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___113 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___113 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___113 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___113 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___113 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___113 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___113 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___113 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___113 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___113 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___113 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	int (*get_fecparam)(struct net_device___113 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___113 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___113 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___113 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___113 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___113;

struct inet_frags___113 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___113 *, const void *);
	void (*destructor)(struct inet_frag_queue___113 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___113 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___114 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___114 *fragments_tail;
	struct sk_buff___114 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___113 *net;
	struct callback_head rcu;
};

struct ip_ra_chain___57 {
	struct ip_ra_chain___57 *next;
	struct sock___93 *sk;
	union {
		void (*destructor)(struct sock___93 *);
		struct sock___93 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___93;

struct fib_lookup_arg___93;

struct fib_rules_ops___93 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___93 *, struct flowi *, int, struct fib_lookup_arg___93 *);
	bool (*suppress)(struct fib_rule___93 *, struct fib_lookup_arg___93 *);
	int (*match)(struct fib_rule___93 *, struct flowi *, int);
	int (*configure)(struct fib_rule___93 *, struct sk_buff___114 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___93 *);
	int (*compare)(struct fib_rule___93 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___93 *, struct sk_buff___114 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___93 *);
	void (*flush_cache)(struct fib_rules_ops___93 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___394 *owner;
	struct net___124 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___94 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___124 *);
	int (*fib_dump)(struct net___124 *, struct notifier_block *);
	struct module___394 *owner;
	struct callback_head rcu;
};

struct lwtunnel_state___17;

struct dst_entry___93 {
	struct net_device___113 *dev;
	struct dst_ops___124 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state___26 *xfrm;
	int (*input)(struct sk_buff___114 *);
	int (*output)(struct net___124 *, struct sock___93 *, struct sk_buff___114 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___17 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___93;

struct neigh_parms___93;

struct neigh_ops___93;

struct neighbour___93 {
	struct neighbour___93 *next;
	struct neigh_table___93 *tbl;
	struct neigh_parms___93 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___113 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___93 *, struct sk_buff___114 *);
	const struct neigh_ops___93 *ops;
	struct callback_head rcu;
	struct net_device___113 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct fib6_nh___34 {
	struct in6_addr nh_gw;
	struct net_device___113 *nh_dev;
	struct lwtunnel_state___17 *nh_lwtstate;
	unsigned int nh_flags;
	atomic_t nh_upper_bound;
	int nh_weight;
};

struct fib6_node___34;

struct fib6_info___34 {
	struct fib6_table___34 *fib6_table;
	struct fib6_info___34 *fib6_next;
	struct fib6_node___34 *fib6_node;
	struct list_head fib6_siblings;
	unsigned int fib6_nsiblings;
	atomic_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	struct rt6_info___34 **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
	long unsigned int last_probe;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 exception_bucket_flushed: 1;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 dst_host: 1;
	u8 fib6_destroying: 1;
	u8 unused: 2;
	struct fib6_nh___34 fib6_nh;
	struct callback_head rcu;
};

struct rt6_info___34 {
	struct dst_entry___93 dst;
	struct fib6_info___34 *from;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___63 *rt6i_idev;
	u32 rt6i_flags;
	struct rt6key rt6i_prefsrc;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct fib6_node___34 {
	struct fib6_node___34 *parent;
	struct fib6_node___34 *left;
	struct fib6_node___34 *right;
	struct fib6_info___34 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info___34 *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table___34 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node___34 tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

struct nf_hook_state___21;

typedef unsigned int nf_hookfn___21(void *, struct sk_buff___114 *, const struct nf_hook_state___21 *);

struct nf_hook_entry___21 {
	nf_hookfn___21 *hook;
	void *priv;
};

struct nf_hook_entries___21 {
	u16 num_hook_entries;
	struct nf_hook_entry___21 hooks[0];
};

struct ucounts___333 {
	struct hlist_node node;
	struct user_namespace___333 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_prog_aux___106;

struct bpf_prog___103 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___106 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

typedef int (*key_restrict_link_func_t___437)(struct key___436 *, const struct key_type *, const union key_payload *, struct key___436 *);

struct key_restriction___436;

struct key___436 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___470 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___436 *restrict_link;
};

struct key_restriction___436 {
	key_restrict_link_func_t___437 check;
	struct key___436 *key;
	struct key_type *keytype;
};

struct seq_operations___407 {
	void * (*start)(struct seq_file___407 *, loff_t *);
	void (*stop)(struct seq_file___407 *, void *);
	void * (*next)(struct seq_file___407 *, void *, loff_t *);
	int (*show)(struct seq_file___407 *, void *);
};

struct pernet_operations___114 {
	struct list_head list;
	int (*init)(struct net___124 *);
	void (*exit)(struct net___124 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___113 {
	int (*ieee_getets)(struct net_device___113 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___113 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___113 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___113 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___113 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___113 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___113 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___113 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___113 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___113 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___113 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___113 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___113 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___113 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___113 *);
	u8 (*setstate)(struct net_device___113 *, u8);
	void (*getpermhwaddr)(struct net_device___113 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___113 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___113 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___113 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___113 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___113 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___113 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___113 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___113 *, int, u8 *);
	void (*setpfccfg)(struct net_device___113 *, int, u8);
	void (*getpfccfg)(struct net_device___113 *, int, u8 *);
	u8 (*setall)(struct net_device___113 *);
	u8 (*getcap)(struct net_device___113 *, int, u8 *);
	int (*getnumtcs)(struct net_device___113 *, int, u8 *);
	int (*setnumtcs)(struct net_device___113 *, int, u8);
	u8 (*getpfcstate)(struct net_device___113 *);
	void (*setpfcstate)(struct net_device___113 *, u8);
	void (*getbcncfg)(struct net_device___113 *, int, u32 *);
	void (*setbcncfg)(struct net_device___113 *, int, u32);
	void (*getbcnrp)(struct net_device___113 *, int, u8 *);
	void (*setbcnrp)(struct net_device___113 *, int, u8);
	int (*setapp)(struct net_device___113 *, u8, u16, u8);
	int (*getapp)(struct net_device___113 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___113 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___113 *, int, u8);
	u8 (*getdcbx)(struct net_device___113 *);
	u8 (*setdcbx)(struct net_device___113 *, u8);
	int (*peer_getappinfo)(struct net_device___113 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___113 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___113 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___113 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___113 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___113 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___317 {
	refcount_t count;
	struct ns_common___29 ns;
	struct user_namespace___333 *user_ns;
	struct ucounts___333 *ucounts;
	struct css_set___317 *root_cset;
};

struct bpf_map___318;

struct bpf_map_ops___317 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___318 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___318 *, struct file___468 *);
	void (*map_free)(struct bpf_map___318 *);
	int (*map_get_next_key)(struct bpf_map___318 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___318 *);
	void * (*map_lookup_elem)(struct bpf_map___318 *, void *);
	int (*map_update_elem)(struct bpf_map___318 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___318 *, void *);
	int (*map_push_elem)(struct bpf_map___318 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___318 *, void *);
	int (*map_peek_elem)(struct bpf_map___318 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___318 *, struct file___468 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___318 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___318 *, void *, struct seq_file___407 *);
	int (*map_check_btf)(const struct bpf_map___318 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___318 {
	const struct bpf_map_ops___317 *ops;
	struct bpf_map___318 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___436 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___113;

struct bpf_map_dev_ops___113 {
	int (*map_get_next_key)(struct bpf_offloaded_map___113 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___113 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___113 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___113 *, void *);
};

struct bpf_offloaded_map___113 {
	struct bpf_map___318 map;
	struct net_device___113 *netdev;
	const struct bpf_map_dev_ops___113 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___103 {
	int (*test_run)(struct bpf_prog___103 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___103 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___103 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___103 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___103 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___103 *, u32 *);
};

struct bpf_prog_offload_ops___103 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___103 *);
	int (*translate)(struct bpf_prog___103 *);
	void (*destroy)(struct bpf_prog___103 *);
};

struct bpf_prog_offload___103 {
	struct bpf_prog___103 *prog;
	struct net_device___113 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___103 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___106 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___103 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___103 *ops;
	struct bpf_map___318 **used_maps;
	struct bpf_prog___103 *prog;
	struct user_struct___436 *user;
	u64 load_time;
	struct bpf_map___318 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___103 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___103 {
	struct bpf_prog___103 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___103 {
	struct callback_head rcu;
	struct bpf_prog_array_item___103 items[0];
};

struct cgroup_bpf___103 {
	struct bpf_prog_array___103 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___103 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___318;

typedef void (*kthread_work_func_t___318)(struct kthread_work___318 *);

struct kthread_worker___318;

struct kthread_work___318 {
	struct list_head node;
	kthread_work_func_t___318 func;
	struct kthread_worker___318 *worker;
	int canceling;
};

struct kthread_worker___318 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___470 *task;
	struct kthread_work___318 *current_work;
};

struct kthread_delayed_work___317 {
	struct kthread_work___318 work;
	struct timer_list timer;
};

struct psi_group___317 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___318 *poll_kworker;
	struct kthread_delayed_work___317 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___317;

struct cgroup_rstat_cpu___317;

struct cgroup___317 {
	struct cgroup_subsys_state___317 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___463 *kn;
	struct cgroup_file___317 procs_file;
	struct cgroup_file___317 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___317 *subsys[13];
	struct cgroup_root___317 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___317 *dom_cgrp;
	struct cgroup_rstat_cpu___317 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___103 bpf;
	atomic_t congestion_count;
	struct cgroup___317 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___317 psi;
	int ancestor_ids[0];
};

struct cftype___317;

struct cgroup_subsys___317 {
	struct cgroup_subsys_state___317 * (*css_alloc)(struct cgroup_subsys_state___317 *);
	int (*css_online)(struct cgroup_subsys_state___317 *);
	void (*css_offline)(struct cgroup_subsys_state___317 *);
	void (*css_released)(struct cgroup_subsys_state___317 *);
	void (*css_free)(struct cgroup_subsys_state___317 *);
	void (*css_reset)(struct cgroup_subsys_state___317 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___317 *, int);
	int (*css_extra_stat_show)(struct seq_file___407 *, struct cgroup_subsys_state___317 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___470 *);
	void (*cancel_fork)(struct task_struct___470 *);
	void (*fork)(struct task_struct___470 *);
	void (*exit)(struct task_struct___470 *);
	void (*free)(struct task_struct___470 *);
	void (*bind)(struct cgroup_subsys_state___317 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___317 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___317 *dfl_cftypes;
	struct cftype___317 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___317 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___317 *updated_children;
	struct cgroup___317 *updated_next;
};

struct cgroup_root___317 {
	struct kernfs_root___462 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___317 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___317 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___317 *ss;
	struct list_head node;
	struct kernfs_ops___462 *kf_ops;
	int (*open)(struct kernfs_open_file___462 *);
	void (*release)(struct kernfs_open_file___462 *);
	u64 (*read_u64)(struct cgroup_subsys_state___317 *, struct cftype___317 *);
	s64 (*read_s64)(struct cgroup_subsys_state___317 *, struct cftype___317 *);
	int (*seq_show)(struct seq_file___407 *, void *);
	void * (*seq_start)(struct seq_file___407 *, loff_t *);
	void * (*seq_next)(struct seq_file___407 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___407 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___317 *, struct cftype___317 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___317 *, struct cftype___317 *, s64);
	ssize_t (*write)(struct kernfs_open_file___462 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___462 *, struct poll_table_struct___307 *);
};

struct xdp_rxq_info___113 {
	struct net_device___113 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___113 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___113 *dev_rx;
};

struct netlink_callback___115 {
	struct sk_buff___114 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___115 *);
	int (*dump)(struct sk_buff___114 *, struct netlink_callback___115 *);
	int (*done)(struct netlink_callback___115 *);
	void *data;
	struct module___394 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___113 {
	int (*create)(struct sk_buff___114 *, struct net_device___113 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___114 *, unsigned char *);
	int (*cache)(const struct neighbour___93 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___113 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___113 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___113 *, int);
	int poll_owner;
	struct net_device___113 *dev;
	struct sk_buff___114 *gro_list;
	struct sk_buff___114 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___113 {
	struct net_device___113 *dev;
	struct Qdisc___105 *qdisc;
	struct Qdisc___105 *qdisc_sleeping;
	struct kobject___456 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___113 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem___3 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___105 {
	struct sk_buff___114 *head;
	struct sk_buff___114 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___105;

struct Qdisc___105 {
	int (*enqueue)(struct sk_buff___114 *, struct Qdisc___105 *, struct sk_buff___114 **);
	struct sk_buff___114 * (*dequeue)(struct Qdisc___105 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___105 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___113 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___113 gso_skb;
	struct qdisc_skb_head___105 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___105 *next_sched;
	struct sk_buff_head___113 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___113 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___456 kobj;
	struct net_device___113 *dev;
	long: 64;
	struct xdp_rxq_info___113 xdp_rxq;
	union {
		struct xdp_umem___3 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___113)(struct net_device___113 *, struct sk_buff___114 *, struct net_device___113 *);

struct netdev_bpf___113 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___103 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___103 *prog;
			const struct bpf_prog_offload_ops___103 *ops;
		} verifier;
		struct {
			struct bpf_prog___103 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___113 *offmap;
		};
		struct {
			struct xdp_umem___3 *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___113 {
	int (*xdo_dev_state_add)(struct xfrm_state___26 *);
	void (*xdo_dev_state_delete)(struct xfrm_state___26 *);
	void (*xdo_dev_state_free)(struct xfrm_state___26 *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___114 *, struct xfrm_state___26 *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state___26 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct xfrm_state_offload___26 {
	struct net_device___113 *dev;
	long unsigned int offload_handle;
	unsigned int num_exthdrs;
	u8 flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct xfrm_replay___26;

struct xfrm_type___26;

struct xfrm_mode___26;

struct xfrm_type_offload___26;

struct xfrm_state___26 {
	possible_net_t___115 xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	refcount_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
		u32 output_mark;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	const char *geniv;
	struct xfrm_encap_tmpl *encap;
	xfrm_address_t *coaddr;
	struct xfrm_state___26 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	const struct xfrm_replay___26 *repl;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct tasklet_hrtimer mtimer;
	struct xfrm_state_offload___26 xso;
	long int saved_tmo;
	long unsigned int lastused;
	struct page_frag___469 xfrag;
	const struct xfrm_type___26 *type;
	struct xfrm_mode___26 *inner_mode;
	struct xfrm_mode___26 *inner_mode_iaf;
	struct xfrm_mode___26 *outer_mode;
	const struct xfrm_type_offload___26 *type_offload;
	struct xfrm_sec_ctx___2 *security;
	void *data;
	u32 output_mark_mask;
	u32 if_id;
};

struct tlsdev_ops___113 {
	int (*tls_dev_add)(struct net_device___113 *, struct sock___93 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___113 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___113 *, struct sock___93 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___113 {
	int (*ndo_init)(struct net_device___113 *);
	void (*ndo_uninit)(struct net_device___113 *);
	int (*ndo_open)(struct net_device___113 *);
	int (*ndo_stop)(struct net_device___113 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___114 *, struct net_device___113 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___114 *, struct net_device___113 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___113 *, struct sk_buff___114 *, struct net_device___113 *, select_queue_fallback_t___113);
	void (*ndo_change_rx_flags)(struct net_device___113 *, int);
	void (*ndo_set_rx_mode)(struct net_device___113 *);
	int (*ndo_set_mac_address)(struct net_device___113 *, void *);
	int (*ndo_validate_addr)(struct net_device___113 *);
	int (*ndo_do_ioctl)(struct net_device___113 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___113 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___113 *, int);
	int (*ndo_neigh_setup)(struct net_device___113 *, struct neigh_parms___93 *);
	void (*ndo_tx_timeout)(struct net_device___113 *);
	void (*ndo_get_stats64)(struct net_device___113 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___113 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___113 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___113 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___113 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___113 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___113 *);
	int (*ndo_netpoll_setup)(struct net_device___113 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___113 *);
	int (*ndo_set_vf_mac)(struct net_device___113 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___113 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___113 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___113 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___113 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___113 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___113 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___113 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___113 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___113 *, int, struct sk_buff___114 *);
	int (*ndo_set_vf_guid)(struct net_device___113 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___113 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___113 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___113 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___113 *, const struct sk_buff___114 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___113 *, struct net_device___113 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___113 *, struct net_device___113 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___113 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___113 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___113 *, struct neighbour___93 *);
	void (*ndo_neigh_destroy)(struct net_device___113 *, struct neighbour___93 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___113 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___113 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___113 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___114 *, struct netlink_callback___115 *, struct net_device___113 *, struct net_device___113 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___113 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___113 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___114 *, u32, u32, struct net_device___113 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___113 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___113 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___113 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___113 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___113 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___113 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___113 *, struct net_device___113 *);
	void (*ndo_dfwd_del_station)(struct net_device___113 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___113 *);
	int (*ndo_set_tx_maxrate)(struct net_device___113 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___113 *);
	int (*ndo_change_proto_down)(struct net_device___113 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___113 *, struct sk_buff___114 *);
	void (*ndo_set_rx_headroom)(struct net_device___113 *, int);
	int (*ndo_bpf)(struct net_device___113 *, struct netdev_bpf___113 *);
	int (*ndo_xdp_xmit)(struct net_device___113 *, int, struct xdp_frame___113 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___113 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___113 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___93 {
	possible_net_t___115 net;
	struct net_device___113 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___93 *);
	void (*neigh_cleanup)(struct neighbour___93 *);
	struct neigh_table___93 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___93 {
	u32 (*l3mdev_fib_table)(const struct net_device___113 *);
	struct sk_buff___114 * (*l3mdev_l3_rcv)(struct net_device___113 *, struct sk_buff___114 *, u16);
	struct sk_buff___114 * (*l3mdev_l3_out)(struct net_device___113 *, struct sock___93 *, struct sk_buff___114 *, u16);
	struct dst_entry___93 * (*l3mdev_link_scope_lookup)(const struct net_device___113 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct ndisc_ops___63 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___113 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___113 *, struct neighbour___93 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___113 *, u8, struct neighbour___93 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___113 *, struct sk_buff___114 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___124 *, struct net_device___113 *, const struct prefix_info *, struct inet6_dev___63 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___63;

struct ifacaddr6___34;

struct inet6_dev___63 {
	struct net_device___113 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___63 *mc_list;
	struct ifmcaddr6___63 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___34 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	u8 rndid[8];
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___93 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
};

struct tcf_proto___105;

struct mini_Qdisc___105 {
	struct tcf_proto___105 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___105 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___113 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___124 *, struct net_device___113 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___113 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___113 *, struct list_head *);
	size_t (*get_size)(const struct net_device___113 *);
	int (*fill_info)(struct sk_buff___114 *, const struct net_device___113 *);
	size_t (*get_xstats_size)(const struct net_device___113 *);
	int (*fill_xstats)(struct sk_buff___114 *, const struct net_device___113 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___113 *, struct net_device___113 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___113 *, const struct net_device___113 *);
	int (*fill_slave_info)(struct sk_buff___114 *, const struct net_device___113 *, const struct net_device___113 *);
	struct net___124 * (*get_link_net)(const struct net_device___113 *);
	size_t (*get_linkxstats_size)(const struct net_device___113 *, int);
	int (*fill_linkxstats)(struct sk_buff___114 *, const struct net_device___113 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___113 {
	struct list_head poll_list;
	struct sk_buff_head___113 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___113 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___105 *output_queue;
	struct Qdisc___105 **output_queue_tailp;
	struct sk_buff___114 *completion_queue;
	struct sk_buff_head___113 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___113 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___113 input_pkt_queue;
	struct napi_struct___113 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct nf_hook_state___21 {
	unsigned int hook;
	u_int8_t pf;
	struct net_device___113 *in;
	struct net_device___113 *out;
	struct sock___93 *sk;
	struct net___124 *net;
	int (*okfn)(struct net___124 *, struct sock___93 *, struct sk_buff___114 *);
};

struct nf_nat_hook___21 {
	int (*parse_nat_setup)(struct nf_conn *, enum nf_nat_manip_type, const struct nlattr *);
	void (*decode_session)(struct sk_buff___114 *, struct flowi *);
	unsigned int (*manip_pkt)(struct sk_buff___114 *, struct nf_conn *, enum nf_nat_manip_type, enum ip_conntrack_dir);
};

struct nf_ct_hook___21 {
	int (*update)(struct net___124 *, struct sk_buff___114 *);
	void (*destroy)(struct nf_conntrack *);
	bool (*get_tuple_skb)(struct nf_conntrack_tuple *, const struct sk_buff___114 *);
};

struct nfnl_ct_hook___21 {
	struct nf_conn * (*get_ct)(const struct sk_buff___114 *, enum ip_conntrack_info *);
	size_t (*build_size)(const struct nf_conn *);
	int (*build)(struct sk_buff___114 *, struct nf_conn *, enum ip_conntrack_info, u_int16_t, u_int16_t);
	int (*parse)(const struct nlattr *, struct nf_conn *);
	int (*attach_expect)(const struct nlattr *, struct nf_conn *, u32, u32);
	void (*seq_adjust)(struct sk_buff___114 *, struct nf_conn *, enum ip_conntrack_info, s32);
};

struct nf_ipv6_ops___12 {
	int (*chk_addr)(struct net___124 *, const struct in6_addr *, const struct net_device___113 *, int);
	void (*route_input)(struct sk_buff___114 *);
	int (*fragment)(struct net___124 *, struct sock___93 *, struct sk_buff___114 *, int (*)(struct net___124 *, struct sock___93 *, struct sk_buff___114 *));
	__sum16 (*checksum)(struct sk_buff___114 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___114 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___124 *, struct dst_entry___93 **, struct flowi *, bool);
	int (*reroute)(struct sk_buff___114 *, const struct nf_queue_entry___2 *);
};

struct pneigh_entry___93;

struct neigh_hash_table___93;

struct neigh_table___93 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___113 *, __u32 *);
	bool (*key_eq)(const struct neighbour___93 *, const void *);
	int (*constructor)(struct neighbour___93 *);
	int (*pconstructor)(struct pneigh_entry___93 *);
	void (*pdestructor)(struct pneigh_entry___93 *);
	void (*proxy_redo)(struct sk_buff___114 *);
	char *id;
	struct neigh_parms___93 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___113 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___93 *nht;
	struct pneigh_entry___93 **phash_buckets;
};

struct neigh_ops___93 {
	int family;
	void (*solicit)(struct neighbour___93 *, struct sk_buff___114 *);
	void (*error_report)(struct neighbour___93 *, struct sk_buff___114 *);
	int (*output)(struct neighbour___93 *, struct sk_buff___114 *);
	int (*connected_output)(struct neighbour___93 *, struct sk_buff___114 *);
};

struct pneigh_entry___93 {
	struct pneigh_entry___93 *next;
	possible_net_t___115 net;
	struct net_device___113 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___93 {
	struct neighbour___93 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___17 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___124 *, struct sock___93 *, struct sk_buff___114 *);
	int (*orig_input)(struct sk_buff___114 *);
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	__u8 data[0];
};

struct bdi_writeback_congested___258 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___258 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___258 {
	struct bio___258 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___260 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___260 bip_inline_vecs[0];
};

struct bio_set___258 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___258 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___201 {
	struct mem_cgroup___201 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___201 {
	struct lruvec___469 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___201 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___201 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct gnet_dump___105 {
	spinlock_t *lock;
	struct sk_buff___114 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___105;

struct Qdisc_ops___105 {
	struct Qdisc_ops___105 *next;
	const struct Qdisc_class_ops___105 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___114 *, struct Qdisc___105 *, struct sk_buff___114 **);
	struct sk_buff___114 * (*dequeue)(struct Qdisc___105 *);
	struct sk_buff___114 * (*peek)(struct Qdisc___105 *);
	int (*init)(struct Qdisc___105 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___105 *);
	void (*destroy)(struct Qdisc___105 *);
	int (*change)(struct Qdisc___105 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___105 *);
	int (*change_tx_queue_len)(struct Qdisc___105 *, unsigned int);
	int (*dump)(struct Qdisc___105 *, struct sk_buff___114 *);
	int (*dump_stats)(struct Qdisc___105 *, struct gnet_dump___105 *);
	void (*ingress_block_set)(struct Qdisc___105 *, u32);
	void (*egress_block_set)(struct Qdisc___105 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___105 *);
	u32 (*egress_block_get)(struct Qdisc___105 *);
	struct module___394 *owner;
};

struct tcf_block___105;

struct Qdisc_class_ops___105 {
	unsigned int flags;
	struct netdev_queue___113 * (*select_queue)(struct Qdisc___105 *, struct tcmsg *);
	int (*graft)(struct Qdisc___105 *, long unsigned int, struct Qdisc___105 *, struct Qdisc___105 **, struct netlink_ext_ack *);
	struct Qdisc___105 * (*leaf)(struct Qdisc___105 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___105 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___105 *, u32);
	int (*change)(struct Qdisc___105 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___105 *, long unsigned int);
	void (*walk)(struct Qdisc___105 *, struct qdisc_walker *);
	struct tcf_block___105 * (*tcf_block)(struct Qdisc___105 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___105 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___105 *, long unsigned int);
	int (*dump)(struct Qdisc___105 *, long unsigned int, struct sk_buff___114 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___105 *, long unsigned int, struct gnet_dump___105 *);
};

struct tcf_chain___105;

struct tcf_block___105 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___124 *net;
	struct Qdisc___105 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___105 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___105;

struct tcf_proto_ops___105;

struct tcf_proto___105 {
	struct tcf_proto___105 *next;
	void *root;
	int (*classify)(struct sk_buff___114 *, const struct tcf_proto___105 *, struct tcf_result___105 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___105 *ops;
	struct tcf_chain___105 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___105 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___105 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___105 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___114 *, const struct tcf_proto___105 *, struct tcf_result___105 *);
	int (*init)(struct tcf_proto___105 *);
	void (*destroy)(struct tcf_proto___105 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___105 *, u32);
	void (*put)(struct tcf_proto___105 *, void *);
	int (*change)(struct net___124 *, struct sk_buff___114 *, struct tcf_proto___105 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___105 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___105 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___105 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___124 *, struct tcf_chain___105 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___124 *, struct tcf_proto___105 *, void *, struct sk_buff___114 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___114 *, struct net___124 *, void *);
	struct module___394 *owner;
	int flags;
};

struct tcf_chain___105 {
	struct mutex filter_chain_lock;
	struct tcf_proto___105 *filter_chain;
	struct list_head list;
	struct tcf_block___105 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___105 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___93 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___103 *prog;
};

struct bpf_redirect_info___103 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___318 *map;
	struct bpf_map___318 *map_to_flush;
	u32 kern_flags;
};

struct fib_rule___93 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___93 *ctarget;
	struct net___124 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___93 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___93 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___75;

struct timewait_sock_ops___71;

struct proto___93 {
	void (*close)(struct sock___93 *, long int);
	int (*pre_connect)(struct sock___93 *, struct sockaddr *, int);
	int (*connect)(struct sock___93 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___93 *, int);
	struct sock___93 * (*accept)(struct sock___93 *, int, int *, bool);
	int (*ioctl)(struct sock___93 *, int, long unsigned int);
	int (*init)(struct sock___93 *);
	void (*destroy)(struct sock___93 *);
	void (*shutdown)(struct sock___93 *, int);
	int (*setsockopt)(struct sock___93 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___93 *, int, int, char *, int *);
	void (*keepalive)(struct sock___93 *, int);
	int (*sendmsg)(struct sock___93 *, struct msghdr___96 *, size_t);
	int (*recvmsg)(struct sock___93 *, struct msghdr___96 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___93 *, struct page___469 *, int, size_t, int);
	int (*bind)(struct sock___93 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___93 *, struct sk_buff___114 *);
	void (*release_cb)(struct sock___93 *);
	int (*hash)(struct sock___93 *);
	void (*unhash)(struct sock___93 *);
	void (*rehash)(struct sock___93 *);
	int (*get_port)(struct sock___93 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___93 *);
	bool (*stream_memory_read)(const struct sock___93 *);
	void (*enter_memory_pressure)(struct sock___93 *);
	void (*leave_memory_pressure)(struct sock___93 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___75 *rsk_prot;
	struct timewait_sock_ops___71 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___394 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___93 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct xfrm_policy_queue___26 {
	struct sk_buff_head___113 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___26 {
	possible_net_t___115 xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	refcount_t refcnt;
	struct timer_list timer;
	atomic_t genid;
	u32 priority;
	u32 index;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___26 polq;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx___2 *security;
	struct xfrm_tmpl xfrm_vec[6];
	struct callback_head rcu;
	u32 if_id;
};

struct request_sock___76;

struct request_sock_ops___75 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___93 *, struct request_sock___76 *);
	void (*send_ack)(const struct sock___93 *, struct sk_buff___114 *, struct request_sock___76 *);
	void (*send_reset)(const struct sock___93 *, struct sk_buff___114 *);
	void (*destructor)(struct request_sock___76 *);
	void (*syn_ack_timeout)(const struct request_sock___76 *);
};

struct timewait_sock_ops___71 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___93 *, struct sock___93 *, void *);
	void (*twsk_destructor)(struct sock___93 *);
};

struct request_sock___76 {
	struct sock_common___93 __req_common;
	struct request_sock___76 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___75 *rsk_ops;
	struct sock___93 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct inet_cork___28 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___93 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
	__u16 gso_size;
	u64 transmit_time;
};

struct inet_cork_full___28 {
	struct inet_cork___28 base;
	struct flowi fl;
};

struct ipv6_pinfo___28;

struct inet_sock___28 {
	struct sock___93 sk;
	struct ipv6_pinfo___28 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	__be16 inet_sport;
	__u16 inet_id;
	struct ip_options_rcu *inet_opt;
	int rx_dst_ifindex;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 bind_address_no_port: 1;
	__u8 defer_connect: 1;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___28 cork;
};

struct ipv6_fl_socklist___27;

struct ipv6_pinfo___28 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
			__u16 recvfragsize: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 repflow: 1;
	__u16 pmtudisc: 3;
	__u16 padding: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u16 autoflowlabel: 1;
	__u16 autoflowlabel_set: 1;
	__u8 min_hopcount;
	__u8 tclass;
	__be32 rcv_flowinfo;
	__u32 dst_cookie;
	__u32 rx_dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___27 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___114 *pktoptions;
	struct sk_buff___114 *rxpmtu;
	struct inet6_cork cork;
};

struct ip6_flowlabel___27;

struct ipv6_fl_socklist___27 {
	struct ipv6_fl_socklist___27 *next;
	struct ip6_flowlabel___27 *fl;
	struct callback_head rcu;
};

struct ifmcaddr6___63 {
	struct in6_addr mca_addr;
	struct inet6_dev___63 *idev;
	struct ifmcaddr6___63 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___34 {
	struct in6_addr aca_addr;
	struct fib6_info___34 *aca_rt;
	struct ifacaddr6___34 *aca_next;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct ip6_ra_chain___63 {
	struct ip6_ra_chain___63 *next;
	struct sock___93 *sk;
	int sel;
	void (*destructor)(struct sock___93 *);
};

struct ip6_flowlabel___27 {
	struct ip6_flowlabel___27 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___262 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___124 *fl_net;
};

struct ipv6_stub___23 {
	int (*ipv6_sock_mc_join)(struct sock___93 *, int, const struct in6_addr *);
	int (*ipv6_sock_mc_drop)(struct sock___93 *, int, const struct in6_addr *);
	int (*ipv6_dst_lookup)(struct net___124 *, struct sock___93 *, struct dst_entry___93 **, struct flowi6 *);
	struct fib6_table___34 * (*fib6_get_table)(struct net___124 *, u32);
	struct fib6_info___34 * (*fib6_lookup)(struct net___124 *, int, struct flowi6 *, int);
	struct fib6_info___34 * (*fib6_table_lookup)(struct net___124 *, struct fib6_table___34 *, int, struct flowi6 *, int);
	struct fib6_info___34 * (*fib6_multipath_select)(const struct net___124 *, struct fib6_info___34 *, struct flowi6 *, int, const struct sk_buff___114 *, int);
	u32 (*ip6_mtu_from_fib6)(struct fib6_info___34 *, struct in6_addr *, struct in6_addr *);
	void (*udpv6_encap_enable)();
	void (*ndisc_send_na)(struct net_device___113 *, const struct in6_addr *, const struct in6_addr *, bool, bool, bool, bool);
	struct neigh_table___93 *nd_tbl;
};

struct ipv6_bpf_stub___23 {
	int (*inet6_bind)(struct sock___93 *, struct sockaddr *, int, bool, bool);
	struct sock___93 * (*udp6_lib_lookup)(struct net___124 *, const struct in6_addr *, __be16, const struct in6_addr *, __be16, int, int, struct udp_table *, struct sk_buff___114 *);
};

struct xfrm_replay___26 {
	void (*advance)(struct xfrm_state___26 *, __be32);
	int (*check)(struct xfrm_state___26 *, struct sk_buff___114 *, __be32);
	int (*recheck)(struct xfrm_state___26 *, struct sk_buff___114 *, __be32);
	void (*notify)(struct xfrm_state___26 *, int);
	int (*overflow)(struct xfrm_state___26 *, struct sk_buff___114 *);
};

struct xfrm_type___26 {
	char *description;
	struct module___394 *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___26 *);
	void (*destructor)(struct xfrm_state___26 *);
	int (*input)(struct xfrm_state___26 *, struct sk_buff___114 *);
	int (*output)(struct xfrm_state___26 *, struct sk_buff___114 *);
	int (*reject)(struct xfrm_state___26 *, struct sk_buff___114 *, const struct flowi *);
	int (*hdr_offset)(struct xfrm_state___26 *, struct sk_buff___114 *, u8 **);
	u32 (*get_mtu)(struct xfrm_state___26 *, int);
};

struct xfrm_state_afinfo___26;

struct xfrm_mode___26 {
	int (*input2)(struct xfrm_state___26 *, struct sk_buff___114 *);
	int (*input)(struct xfrm_state___26 *, struct sk_buff___114 *);
	int (*output2)(struct xfrm_state___26 *, struct sk_buff___114 *);
	int (*output)(struct xfrm_state___26 *, struct sk_buff___114 *);
	struct sk_buff___114 * (*gso_segment)(struct xfrm_state___26 *, struct sk_buff___114 *, netdev_features_t);
	void (*xmit)(struct xfrm_state___26 *, struct sk_buff___114 *);
	struct xfrm_state_afinfo___26 *afinfo;
	struct module___394 *owner;
	unsigned int encap;
	int flags;
};

struct xfrm_type_offload___26 {
	char *description;
	struct module___394 *owner;
	u8 proto;
	void (*encap)(struct xfrm_state___26 *, struct sk_buff___114 *);
	int (*input_tail)(struct xfrm_state___26 *, struct sk_buff___114 *);
	int (*xmit)(struct xfrm_state___26 *, struct sk_buff___114 *, netdev_features_t);
};

struct xfrm_state_afinfo___26 {
	unsigned int family;
	unsigned int proto;
	__be16 eth_proto;
	struct module___394 *owner;
	const struct xfrm_type___26 *type_map[256];
	const struct xfrm_type_offload___26 *type_offload_map[256];
	struct xfrm_mode___26 *mode_map[5];
	int (*init_flags)(struct xfrm_state___26 *);
	void (*init_tempsel)(struct xfrm_selector *, const struct flowi *);
	void (*init_temprop)(struct xfrm_state___26 *, const struct xfrm_tmpl *, const xfrm_address_t *, const xfrm_address_t *);
	int (*tmpl_sort)(struct xfrm_tmpl **, struct xfrm_tmpl **, int);
	int (*state_sort)(struct xfrm_state___26 **, struct xfrm_state___26 **, int);
	int (*output)(struct net___124 *, struct sock___93 *, struct sk_buff___114 *);
	int (*output_finish)(struct sock___93 *, struct sk_buff___114 *);
	int (*extract_input)(struct xfrm_state___26 *, struct sk_buff___114 *);
	int (*extract_output)(struct xfrm_state___26 *, struct sk_buff___114 *);
	int (*transport_finish)(struct sk_buff___114 *, int);
	void (*local_error)(struct sk_buff___114 *, u32);
};

struct xfrm6_protocol {
	int (*handler)(struct sk_buff___111 *);
	int (*cb_handler)(struct sk_buff___111 *, int);
	int (*err_handler)(struct sk_buff___111 *, struct inet6_skb_parm *, u8, u8, int, __be32);
	struct xfrm6_protocol *next;
	int priority;
};

struct module___395;

struct file___469;

struct kiocb___469;

struct iov_iter___236;

struct poll_table_struct___308;

struct vm_area_struct___470;

struct inode___469;

struct file_lock___469;

struct page___470;

struct pipe_inode_info___150;

struct seq_file___408;

struct file_operations___469 {
	struct module___395 *owner;
	loff_t (*llseek)(struct file___469 *, loff_t, int);
	ssize_t (*read)(struct file___469 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___469 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___469 *, struct iov_iter___236 *);
	ssize_t (*write_iter)(struct kiocb___469 *, struct iov_iter___236 *);
	int (*iopoll)(struct kiocb___469 *, bool);
	int (*iterate)(struct file___469 *, struct dir_context *);
	int (*iterate_shared)(struct file___469 *, struct dir_context *);
	__poll_t (*poll)(struct file___469 *, struct poll_table_struct___308 *);
	long int (*unlocked_ioctl)(struct file___469 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___469 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___469 *, struct vm_area_struct___470 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___469 *, struct file___469 *);
	int (*flush)(struct file___469 *, fl_owner_t);
	int (*release)(struct inode___469 *, struct file___469 *);
	int (*fsync)(struct file___469 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___469 *, int);
	int (*lock)(struct file___469 *, int, struct file_lock___469 *);
	ssize_t (*sendpage)(struct file___469 *, struct page___470 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___469 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___469 *, int, struct file_lock___469 *);
	ssize_t (*splice_write)(struct pipe_inode_info___150 *, struct file___469 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___469 *, loff_t *, struct pipe_inode_info___150 *, size_t, unsigned int);
	int (*setlease)(struct file___469 *, long int, struct file_lock___469 **, void **);
	long int (*fallocate)(struct file___469 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___408 *, struct file___469 *);
	ssize_t (*copy_file_range)(struct file___469 *, loff_t, struct file___469 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___469 *, loff_t, struct file___469 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___469 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___470 {
	u64 seqnum;
	struct vm_area_struct___470 *vmas[4];
};

struct page_frag___470 {
	struct page___470 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___470;

struct mem_cgroup___202;

struct pid___263;

struct cred___437;

struct nsproxy___364;

struct signal_struct___344;

struct bio_list___259;

struct backing_dev_info___259;

struct css_set___318;

struct vm_struct___373;

struct task_struct___471 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___471 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___470 *mm;
	struct mm_struct___470 *active_mm;
	struct vmacache___470 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___471 *real_parent;
	struct task_struct___471 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___471 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___202 *active_memcg;
	long int rh_reserved2;
	struct pid___263 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___263 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___263 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___437 *ptracer_cred;
	const struct cred___437 *real_cred;
	const struct cred___437 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___364 *nsproxy;
	struct signal_struct___344 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___471 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___259 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___259 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___318 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___150 *splice_pipe;
	struct page_frag___470 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___202 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___471 *oom_reaper_list;
	struct vm_struct___373 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___157 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___470 *pgtable_t___470;

struct address_space___469;

struct dev_pagemap___457;

struct page___470 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___469 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___470 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___470 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___470 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___457 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___202 *mem_cgroup;
};

struct pglist_data___470;

struct lruvec___470 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___470 *pgdat;
};

struct zone___470 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___470 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___470 {
	struct zone___470 *zone;
	int zone_idx;
};

struct zonelist___470 {
	struct zoneref___470 _zonerefs[25];
};

struct pglist_data___470 {
	struct zone___470 node_zones[3];
	struct zonelist___470 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___471 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___471 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___470 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___471 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___471 *owner;
};

struct secondary_data___471 {
	void *stack;
	struct task_struct___471 *task;
	long int status;
};

struct blocking_notifier_head___470 {
	struct rw_semaphore___471 rwsem;
	struct notifier_block *head;
};

struct cgroup___318;

struct cgroup_subsys___318;

struct cgroup_subsys_state___318 {
	struct cgroup___318 *cgroup;
	struct cgroup_subsys___318 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___318 *parent;
};

struct kernfs_node___464;

struct cgroup_file___318 {
	struct kernfs_node___464 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___202;

struct mem_cgroup___202 {
	struct cgroup_subsys_state___318 css;
	struct mem_cgroup_id___16 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___318 events_file;
	struct cgroup_file___318 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___471 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___202 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___263;

struct upid___263 {
	int nr;
	struct pid_namespace___263 *ns;
};

struct dentry___469;

struct user_namespace___334;

struct ucounts___334;

struct pid_namespace___263 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___471 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___263 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___469 *proc_self;
	struct dentry___469 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___334 *user_ns;
	struct ucounts___334 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___29 ns;
};

struct pid___263 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___263 numbers[1];
};

struct key___437;

struct user_namespace___334 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___334 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___29 ns;
	long unsigned int flags;
	struct key___437 *persistent_keyring_register;
	struct rw_semaphore___471 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___334 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct user_struct___437 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___437 *uid_keyring;
	struct key___437 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___457;

struct vm_area_struct___470 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___470 *vm_next;
	struct vm_area_struct___470 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___470 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___457 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___469 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___470;

struct mm_struct___470 {
	struct {
		struct vm_area_struct___470 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___469 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___471 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___470 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___471 *owner;
		struct user_namespace___334 *user_ns;
		struct file___469 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___470 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___437 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___437 *session_keyring;
	struct key___437 *process_keyring;
	struct key___437 *thread_keyring;
	struct key___437 *request_key_auth;
	void *security;
	struct user_struct___437 *user;
	struct user_namespace___334 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___125;

struct cgroup_namespace___318;

struct nsproxy___364 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___263 *pid_ns_for_children;
	struct net___125 *net_ns;
	struct cgroup_namespace___318 *cgroup_ns;
};

struct signal_struct___344 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___471 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___471 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___263 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___263 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___470 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___263 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___259;

struct bio_list___259 {
	struct bio___259 *head;
	struct bio___259 *tail;
};

struct bdi_writeback_congested___259;

struct bdi_writeback___259 {
	struct backing_dev_info___259 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___259 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___318 *memcg_css;
	struct cgroup_subsys_state___318 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___437;

struct backing_dev_info___259 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___259 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___437 *dev;
	struct device___437 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___469 *debug_dir;
	struct dentry___469 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___318 {
	struct cgroup_subsys_state___318 *subsys[13];
	refcount_t refcount;
	struct css_set___318 *dom_cset;
	struct cgroup___318 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___318 *mg_src_cgrp;
	struct cgroup___318 *mg_dst_cgrp;
	struct css_set___318 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___469;

struct pipe_buffer___150;

struct pipe_inode_info___150 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___470 *tmp_page;
	struct fasync_struct___469 *fasync_readers;
	struct fasync_struct___469 *fasync_writers;
	struct pipe_buffer___150 *bufs;
	struct user_struct___437 *user;
};

struct vm_struct___373 {
	struct vm_struct___373 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___470 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___356 {
	struct task_struct___471 task;
	long unsigned int stack[8192];
};

struct address_space_operations___469;

struct address_space___469 {
	struct inode___469 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___471 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___469 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___457)(struct vm_area_struct___470 *, long unsigned int, const struct page___470 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___457)(struct page___470 *, void *);

struct dev_pagemap___457 {
	dev_page_fault_t___457 page_fault;
	dev_page_free_t___457 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___437 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___470 {
	struct vfsmount *mnt;
	struct dentry___469 *dentry;
};

struct fown_struct___263 {
	rwlock_t lock;
	struct pid___263 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___469 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___470 f_path;
	struct inode___469 *f_inode;
	const struct file_operations___469 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___263 f_owner;
	const struct cred___437 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___469 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___457;

struct vm_operations_struct___457 {
	void (*open)(struct vm_area_struct___470 *);
	void (*close)(struct vm_area_struct___470 *);
	int (*split)(struct vm_area_struct___470 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___470 *);
	vm_fault_t (*fault)(struct vm_fault___457 *);
	vm_fault_t (*huge_fault)(struct vm_fault___457 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___457 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___470 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___457 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___457 *);
	int (*access)(struct vm_area_struct___470 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___470 *);
	int (*set_policy)(struct vm_area_struct___470 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___470 *, long unsigned int);
	struct page___470 * (*find_special_page)(struct vm_area_struct___470 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___470 {
	struct task_struct___471 *task;
	struct core_thread___470 *next;
};

struct core_state___470 {
	atomic_t nr_threads;
	struct core_thread___470 dumper;
	struct completion startup;
};

struct vm_fault___457 {
	struct vm_area_struct___470 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___470 *cow_page;
	struct mem_cgroup___202 *memcg;
	struct page___470 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___470 prealloc_pte;
};

struct kset___456;

struct kobj_type___456;

struct kobject___457 {
	const char *name;
	struct list_head entry;
	struct kobject___457 *parent;
	struct kset___456 *kset;
	struct kobj_type___456 *ktype;
	struct kernfs_node___464 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___395 {
	struct kobject___457 kobj;
	struct module___395 *mod;
	struct kobject___457 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___395 {
	struct module___395 *mod;
	struct latch_tree_node node;
};

struct module_layout___395 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___395 mtn;
};

struct module_attribute___395;

struct kernel_param___395;

struct module___395 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___395 mkobj;
	struct module_attribute___395 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___457 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___395 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___395 core_layout;
	struct module_layout___395 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide53;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide54;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bio_vec___261 {
	struct page___470 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___236 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___261 *bvec;
		struct pipe_inode_info___150 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct msghdr___97 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___236 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___469 *msg_iocb;
};

struct kiocb___469 {
	struct file___469 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___469 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dentry_operations___469;

struct super_block___469;

struct dentry___469 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___469 *d_parent;
	struct qstr d_name;
	struct inode___469 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___469 *d_op;
	struct super_block___469 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___469;

struct block_device___469;

struct inode___469 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___469 *i_op;
	struct super_block___469 *i_sb;
	struct address_space___469 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___471 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___259 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___469 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___469 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___150 *i_pipe;
		struct block_device___469 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___469 {
	int (*d_revalidate)(struct dentry___469 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___469 *, unsigned int);
	int (*d_hash)(const struct dentry___469 *, struct qstr *);
	int (*d_compare)(const struct dentry___469 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___469 *);
	int (*d_init)(struct dentry___469 *);
	void (*d_release)(struct dentry___469 *);
	void (*d_prune)(struct dentry___469 *);
	void (*d_iput)(struct dentry___469 *, struct inode___469 *);
	char * (*d_dname)(struct dentry___469 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___470 *);
	int (*d_manage)(const struct path___470 *, bool);
	struct dentry___469 * (*d_real)(struct dentry___469 *, const struct inode___469 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___469;

struct mem_dqinfo___469 {
	struct quota_format_type___469 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___469;

struct quota_info___469 {
	unsigned int flags;
	struct rw_semaphore___471 dqio_sem;
	struct inode___469 *files[3];
	struct mem_dqinfo___469 info[3];
	const struct quota_format_ops___469 *ops[3];
};

struct rcuwait___469 {
	struct task_struct___471 *task;
};

struct percpu_rw_semaphore___469 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___471 rw_sem;
	struct rcuwait___469 writer;
	int readers_block;
};

struct sb_writers___469 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___469 rw_sem[3];
};

struct shrink_control___202;

struct shrinker___202 {
	long unsigned int (*count_objects)(struct shrinker___202 *, struct shrink_control___202 *);
	long unsigned int (*scan_objects)(struct shrinker___202 *, struct shrink_control___202 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___469;

struct super_operations___469;

struct dquot_operations___469;

struct quotactl_ops___469;

struct super_block___469 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___469 *s_type;
	const struct super_operations___469 *s_op;
	const struct dquot_operations___469 *dq_op;
	const struct quotactl_ops___469 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___469 *s_root;
	struct rw_semaphore___471 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___469 *s_bdev;
	struct backing_dev_info___259 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___469 s_dquot;
	struct sb_writers___469 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___469 *s_d_op;
	int cleancache_poolid;
	struct shrinker___202 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___334 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___202 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___202 *memcg;
};

struct iattr___469 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___469 *ia_file;
};

struct dquot___469 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___469 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___469 {
	int qf_fmt_id;
	const struct quota_format_ops___469 *qf_ops;
	struct module___395 *qf_owner;
	struct quota_format_type___469 *qf_next;
};

struct quota_format_ops___469 {
	int (*check_quota_file)(struct super_block___469 *, int);
	int (*read_file_info)(struct super_block___469 *, int);
	int (*write_file_info)(struct super_block___469 *, int);
	int (*free_file_info)(struct super_block___469 *, int);
	int (*read_dqblk)(struct dquot___469 *);
	int (*commit_dqblk)(struct dquot___469 *);
	int (*release_dqblk)(struct dquot___469 *);
	int (*get_next_id)(struct super_block___469 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___469 {
	int (*write_dquot)(struct dquot___469 *);
	struct dquot___469 * (*alloc_dquot)(struct super_block___469 *, int);
	void (*destroy_dquot)(struct dquot___469 *);
	int (*acquire_dquot)(struct dquot___469 *);
	int (*release_dquot)(struct dquot___469 *);
	int (*mark_dirty)(struct dquot___469 *);
	int (*write_info)(struct super_block___469 *, int);
	qsize_t * (*get_reserved_space)(struct inode___469 *);
	int (*get_projid)(struct inode___469 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___469 *, qsize_t *);
	int (*get_next_id)(struct super_block___469 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___469 {
	int (*quota_on)(struct super_block___469 *, int, int, const struct path___470 *);
	int (*quota_off)(struct super_block___469 *, int);
	int (*quota_enable)(struct super_block___469 *, unsigned int);
	int (*quota_disable)(struct super_block___469 *, unsigned int);
	int (*quota_sync)(struct super_block___469 *, int);
	int (*set_info)(struct super_block___469 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___469 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___469 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___469 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___469 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___469 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___222;

struct address_space_operations___469 {
	int (*writepage)(struct page___470 *, struct writeback_control___222 *);
	int (*readpage)(struct file___469 *, struct page___470 *);
	int (*writepages)(struct address_space___469 *, struct writeback_control___222 *);
	int (*set_page_dirty)(struct page___470 *);
	int (*readpages)(struct file___469 *, struct address_space___469 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___469 *, struct address_space___469 *, loff_t, unsigned int, unsigned int, struct page___470 **, void **);
	int (*write_end)(struct file___469 *, struct address_space___469 *, loff_t, unsigned int, unsigned int, struct page___470 *, void *);
	sector_t (*bmap)(struct address_space___469 *, sector_t);
	void (*invalidatepage)(struct page___470 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___470 *, gfp_t);
	void (*freepage)(struct page___470 *);
	ssize_t (*direct_IO)(struct kiocb___469 *, struct iov_iter___236 *);
	int (*migratepage)(struct address_space___469 *, struct page___470 *, struct page___470 *, enum migrate_mode);
	bool (*isolate_page)(struct page___470 *, isolate_mode_t);
	void (*putback_page)(struct page___470 *);
	int (*launder_page)(struct page___470 *);
	int (*is_partially_uptodate)(struct page___470 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___470 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___469 *, struct page___470 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___469 *, sector_t *);
	void (*swap_deactivate)(struct file___469 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___222 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___259 *wb;
	struct inode___469 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___469 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___469 *bd_inode;
	struct super_block___469 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___469 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___259 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___469 {
	struct dentry___469 * (*lookup)(struct inode___469 *, struct dentry___469 *, unsigned int);
	const char * (*get_link)(struct dentry___469 *, struct inode___469 *, struct delayed_call *);
	int (*permission)(struct inode___469 *, int);
	struct posix_acl * (*get_acl)(struct inode___469 *, int);
	int (*readlink)(struct dentry___469 *, char *, int);
	int (*create)(struct inode___469 *, struct dentry___469 *, umode_t, bool);
	int (*link)(struct dentry___469 *, struct inode___469 *, struct dentry___469 *);
	int (*unlink)(struct inode___469 *, struct dentry___469 *);
	int (*symlink)(struct inode___469 *, struct dentry___469 *, const char *);
	int (*mkdir)(struct inode___469 *, struct dentry___469 *, umode_t);
	int (*rmdir)(struct inode___469 *, struct dentry___469 *);
	int (*mknod)(struct inode___469 *, struct dentry___469 *, umode_t, dev_t);
	int (*rename)(struct inode___469 *, struct dentry___469 *, struct inode___469 *, struct dentry___469 *, unsigned int);
	int (*setattr)(struct dentry___469 *, struct iattr___469 *);
	int (*getattr)(const struct path___470 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___469 *, char *, size_t);
	int (*fiemap)(struct inode___469 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___469 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___469 *, struct dentry___469 *, struct file___469 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___469 *, struct dentry___469 *, umode_t);
	int (*set_acl)(struct inode___469 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___469 {
	void (*fl_copy_lock)(struct file_lock___469 *, struct file_lock___469 *);
	void (*fl_release_private)(struct file_lock___469 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___469;

struct file_lock___469 {
	struct file_lock___469 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___469 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___469 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___469 *fl_ops;
	const struct lock_manager_operations___469 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___469 {
	int (*lm_compare_owner)(struct file_lock___469 *, struct file_lock___469 *);
	long unsigned int (*lm_owner_key)(struct file_lock___469 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___469 *);
	int (*lm_grant)(struct file_lock___469 *, int);
	bool (*lm_break)(struct file_lock___469 *);
	int (*lm_change)(struct file_lock___469 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___469 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___469 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___469 *fa_next;
	struct file___469 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___469 {
	const char *name;
	int fs_flags;
	struct dentry___469 * (*mount)(struct file_system_type___469 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___469 *);
	struct module___395 *owner;
	struct file_system_type___469 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___469 {
	struct inode___469 * (*alloc_inode)(struct super_block___469 *);
	void (*destroy_inode)(struct inode___469 *);
	void (*dirty_inode)(struct inode___469 *, int);
	int (*write_inode)(struct inode___469 *, struct writeback_control___222 *);
	int (*drop_inode)(struct inode___469 *);
	void (*evict_inode)(struct inode___469 *);
	void (*put_super)(struct super_block___469 *);
	int (*sync_fs)(struct super_block___469 *, int);
	int (*freeze_super)(struct super_block___469 *);
	int (*freeze_fs)(struct super_block___469 *);
	int (*thaw_super)(struct super_block___469 *);
	int (*unfreeze_fs)(struct super_block___469 *);
	int (*statfs)(struct dentry___469 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___469 *, int *, char *);
	void (*umount_begin)(struct super_block___469 *);
	int (*show_options)(struct seq_file___408 *, struct dentry___469 *);
	int (*show_devname)(struct seq_file___408 *, struct dentry___469 *);
	int (*show_path)(struct seq_file___408 *, struct dentry___469 *);
	int (*show_stats)(struct seq_file___408 *, struct dentry___469 *);
	ssize_t (*quota_read)(struct super_block___469 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___469 *, int, const char *, size_t, loff_t);
	struct dquot___469 ** (*get_dquots)(struct inode___469 *);
	int (*bdev_try_to_free_page)(struct super_block___469 *, struct page___470 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___469 *, struct shrink_control___202 *);
	long int (*free_cached_objects)(struct super_block___469 *, struct shrink_control___202 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___318)(struct file___469 *, wait_queue_head_t *, struct poll_table_struct___308 *);

struct poll_table_struct___308 {
	poll_queue_proc___318 _qproc;
	__poll_t _key;
};

struct seq_operations___408;

struct seq_file___408 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___408 *op;
	int poll_event;
	const struct file___469 *file;
	void *private;
};

typedef void bio_end_io_t___259(struct bio___259 *);

struct bio_integrity_payload___259;

struct bio_set___259;

struct bio___259 {
	struct bio___259 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___259 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___259 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___261 *bi_io_vec;
	struct bio_set___259 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___261 bi_inline_vecs[0];
};

struct socket_wq___95 {
	wait_queue_head_t wait;
	struct fasync_struct___469 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct sock___94;

struct proto_ops___95;

struct socket___96 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___95 *wq;
	struct file___469 *file;
	struct sock___94 *sk;
	const struct proto_ops___95 *ops;
};

typedef struct {
	struct net___125 *net;
} possible_net_t___116;

struct proto___94;

struct sock_common___94 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___94 *skc_prot;
	possible_net_t___116 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___94 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___115;

struct sk_buff_head___114 {
	struct sk_buff___115 *next;
	struct sk_buff___115 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___94;

struct xfrm_policy___27;

struct dst_entry___94;

struct net_device___114;

struct sock___94 {
	struct sock_common___94 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___114 sk_error_queue;
	struct sk_buff_head___114 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___115 *head;
		struct sk_buff___115 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___94 *sk_filter;
	union {
		struct socket_wq___95 *sk_wq;
		struct socket_wq___95 *sk_wq_raw;
	};
	struct xfrm_policy___27 *sk_policy[2];
	struct dst_entry___94 *sk_rx_dst;
	struct dst_entry___94 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___115 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___114 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___470 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___94 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___263 *sk_peer_pid;
	const struct cred___437 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___96 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___202 *sk_memcg;
	void (*sk_state_change)(struct sock___94 *);
	void (*sk_data_ready)(struct sock___94 *);
	void (*sk_write_space)(struct sock___94 *);
	void (*sk_error_report)(struct sock___94 *);
	int (*sk_backlog_rcv)(struct sock___94 *, struct sk_buff___115 *);
	struct sk_buff___115 * (*sk_validate_xmit_skb)(struct sock___94 *, struct net_device___114 *, struct sk_buff___115 *);
	void (*sk_destruct)(struct sock___94 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

typedef int (*sk_read_actor_t___94)(read_descriptor_t *, struct sk_buff___115 *, unsigned int, size_t);

struct proto_ops___95 {
	int family;
	struct module___395 *owner;
	int (*release)(struct socket___96 *);
	int (*bind)(struct socket___96 *, struct sockaddr *, int);
	int (*connect)(struct socket___96 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___96 *, struct socket___96 *);
	int (*accept)(struct socket___96 *, struct socket___96 *, int, bool);
	int (*getname)(struct socket___96 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___469 *, struct socket___96 *, struct poll_table_struct___308 *);
	int (*ioctl)(struct socket___96 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___96 *, int);
	int (*shutdown)(struct socket___96 *, int);
	int (*setsockopt)(struct socket___96 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___96 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___96 *, struct msghdr___97 *, size_t);
	int (*recvmsg)(struct socket___96 *, struct msghdr___97 *, size_t, int);
	int (*mmap)(struct file___469 *, struct socket___96 *, struct vm_area_struct___470 *);
	ssize_t (*sendpage)(struct socket___96 *, struct page___470 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___96 *, loff_t *, struct pipe_inode_info___150 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___94 *, int);
	int (*peek_len)(struct socket___96 *);
	int (*read_sock)(struct sock___94 *, read_descriptor_t *, sk_read_actor_t___94);
	int (*sendpage_locked)(struct sock___94 *, struct page___470 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___94 *, struct msghdr___97 *, size_t);
	int (*set_rcvlowat)(struct sock___94 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct sec_path___27;

struct nf_bridge_info___114;

struct sk_buff___115 {
	union {
		struct {
			struct sk_buff___115 *next;
			struct sk_buff___115 *prev;
			union {
				struct net_device___114 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___94 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___115 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path___27 *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___114 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___114;

struct netns_frags___114 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___114 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ip_ra_chain___58;

struct fib_rules_ops___94;

struct fib_notifier_ops___95;

struct netns_ipv4___114 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___58 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___94 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___94 *fibnl;
	struct sock___94 **icmp_sk;
	struct sock___94 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___94 **tcp_sk;
	struct netns_frags___114 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___94 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___95 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___95 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___94;

struct dst_ops___125 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___125 *);
	struct dst_entry___94 * (*check)(struct dst_entry___94 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___94 *);
	unsigned int (*mtu)(const struct dst_entry___94 *);
	u32 * (*cow_metrics)(struct dst_entry___94 *, long unsigned int);
	void (*destroy)(struct dst_entry___94 *);
	void (*ifdown)(struct dst_entry___94 *, struct net_device___114 *, int);
	struct dst_entry___94 * (*negative_advice)(struct dst_entry___94 *);
	void (*link_failure)(struct sk_buff___115 *);
	void (*update_pmtu)(struct dst_entry___94 *, struct sock___94 *, struct sk_buff___115 *, u32);
	void (*redirect)(struct dst_entry___94 *, struct sock___94 *, struct sk_buff___115 *);
	int (*local_out)(struct net___125 *, struct sock___94 *, struct sk_buff___115 *);
	struct neighbour___94 * (*neigh_lookup)(const struct dst_entry___94 *, struct sk_buff___115 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___94 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_info___35;

struct rt6_info___35;

struct fib6_table___35;

struct netns_ipv6___125 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___114 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info___35 *fib6_null_entry;
	struct rt6_info___35 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___35 *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___125 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info___35 *ip6_prohibit_entry;
	struct rt6_info___35 *ip6_blk_hole_entry;
	struct fib6_table___35 *fib6_local_tbl;
	struct fib_rules_ops___94 *fib6_rules_ops;
	struct sock___94 **icmp_sk;
	struct sock___94 *ndisc_sk;
	struct sock___94 *tcp_sk;
	struct sock___94 *igmp_sk;
	struct sock___94 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___94 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___95 *notifier_ops;
	struct fib_notifier_ops___95 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___95 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___94 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct nf_queue_handler___4;

struct nf_hook_entries___22;

struct netns_nf___23 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_queue_handler___4 *queue_handler;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header *nf_log_dir_header;
	struct nf_hook_entries___22 *hooks_ipv4[5];
	struct nf_hook_entries___22 *hooks_ipv6[5];
	struct nf_hook_entries___22 *hooks_arp[3];
	struct nf_hook_entries___22 *hooks_bridge[5];
	bool defrag_ipv4;
	bool defrag_ipv6;
};

struct netns_nf_frag___114 {
	struct netns_frags___114 frags;
};

struct netns_xfrm___125 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___94 *nlsk;
	struct sock___94 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___125 xfrm4_dst_ops;
	struct dst_ops___125 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___104;

struct net___125 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___334 *user_ns;
	struct ucounts___334 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___29 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___94 *rtnl;
	struct sock___94 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___114 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___114 ipv4;
	struct netns_ipv6___125 ipv6;
	struct netns_sctp___95 sctp;
	struct netns_nf___23 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___114 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___94 *nfnl;
	struct sock___94 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___125 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___94 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___104 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kernfs_root___463;

struct kernfs_elem_dir___463 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___463 *root;
};

struct kernfs_syscall_ops___463;

struct kernfs_root___463 {
	struct kernfs_node___464 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___463 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___463 {
	struct kernfs_node___464 *target_kn;
};

struct kernfs_ops___463;

struct kernfs_elem_attr___463 {
	const struct kernfs_ops___463 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___464 *notify_next;
};

struct kernfs_node___464 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___464 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___463 dir;
		struct kernfs_elem_symlink___463 symlink;
		struct kernfs_elem_attr___463 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___463;

struct kernfs_ops___463 {
	int (*open)(struct kernfs_open_file___463 *);
	void (*release)(struct kernfs_open_file___463 *);
	int (*seq_show)(struct seq_file___408 *, void *);
	void * (*seq_start)(struct seq_file___408 *, loff_t *);
	void * (*seq_next)(struct seq_file___408 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___408 *, void *);
	ssize_t (*read)(struct kernfs_open_file___463 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___463 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___463 *, struct vm_area_struct___470 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___463 *, struct poll_table_struct___308 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___463 {
	int (*remount_fs)(struct kernfs_root___463 *, int *, char *);
	int (*show_options)(struct seq_file___408 *, struct kernfs_root___463 *);
	int (*mkdir)(struct kernfs_node___464 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___464 *);
	int (*rename)(struct kernfs_node___464 *, struct kernfs_node___464 *, const char *);
	int (*show_path)(struct seq_file___408 *, struct kernfs_node___464 *, struct kernfs_root___463 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___463 {
	struct kernfs_node___464 *kn;
	struct file___469 *file;
	struct seq_file___408 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___457 *vm_ops;
};

struct kobj_ns_type_operations___94 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___94 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___433;

struct attribute_group___434 {
	const char *name;
	umode_t (*is_visible)(struct kobject___457 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___457 *, struct bin_attribute___433 *, int);
	struct attribute **attrs;
	struct bin_attribute___433 **bin_attrs;
};

struct bin_attribute___433 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___469 *, struct kobject___457 *, struct bin_attribute___433 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___469 *, struct kobject___457 *, struct bin_attribute___433 *, char *, loff_t, size_t);
	int (*mmap)(struct file___469 *, struct kobject___457 *, struct bin_attribute___433 *, struct vm_area_struct___470 *);
};

struct sysfs_ops___456 {
	ssize_t (*show)(struct kobject___457 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___457 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___456;

struct kset___456 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___457 kobj;
	const struct kset_uevent_ops___456 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___456 {
	void (*release)(struct kobject___457 *);
	const struct sysfs_ops___456 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___94 * (*child_ns_type)(struct kobject___457 *);
	const void * (*namespace)(struct kobject___457 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___456 {
	int (* const filter)(struct kset___456 *, struct kobject___457 *);
	const char * (* const name)(struct kset___456 *, struct kobject___457 *);
	int (* const uevent)(struct kset___456 *, struct kobject___457 *, struct kobj_uevent_env *);
};

struct kobj_attribute___447 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___457 *, struct kobj_attribute___447 *, char *);
	ssize_t (*store)(struct kobject___457 *, struct kobj_attribute___447 *, const char *, size_t);
};

struct dev_pm_ops___437 {
	int (*prepare)(struct device___437 *);
	void (*complete)(struct device___437 *);
	int (*suspend)(struct device___437 *);
	int (*resume)(struct device___437 *);
	int (*freeze)(struct device___437 *);
	int (*thaw)(struct device___437 *);
	int (*poweroff)(struct device___437 *);
	int (*restore)(struct device___437 *);
	int (*suspend_late)(struct device___437 *);
	int (*resume_early)(struct device___437 *);
	int (*freeze_late)(struct device___437 *);
	int (*thaw_early)(struct device___437 *);
	int (*poweroff_late)(struct device___437 *);
	int (*restore_early)(struct device___437 *);
	int (*suspend_noirq)(struct device___437 *);
	int (*resume_noirq)(struct device___437 *);
	int (*freeze_noirq)(struct device___437 *);
	int (*thaw_noirq)(struct device___437 *);
	int (*poweroff_noirq)(struct device___437 *);
	int (*restore_noirq)(struct device___437 *);
	int (*runtime_suspend)(struct device___437 *);
	int (*runtime_resume)(struct device___437 *);
	int (*runtime_idle)(struct device___437 *);
};

struct dev_pm_info___437 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___437 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___437;

struct bus_type___437;

struct device_driver___437;

struct dev_pm_domain___437;

struct dma_map_ops___209;

struct fwnode_handle___357;

struct class___437;

struct device___437 {
	struct device___437 *parent;
	struct device_private *p;
	struct kobject___457 kobj;
	const char *init_name;
	const struct device_type___437 *type;
	struct mutex mutex;
	struct bus_type___437 *bus;
	struct device_driver___437 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___437 power;
	struct dev_pm_domain___437 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___209 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___357 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___437 *class;
	const struct attribute_group___434 **groups;
	void (*release)(struct device___437 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___437 {
	struct dev_pm_ops___437 ops;
	void (*detach)(struct device___437 *, bool);
	int (*activate)(struct device___437 *);
	void (*sync)(struct device___437 *);
	void (*dismiss)(struct device___437 *);
};

struct bus_type___437 {
	const char *name;
	const char *dev_name;
	struct device___437 *dev_root;
	const struct attribute_group___434 **bus_groups;
	const struct attribute_group___434 **dev_groups;
	const struct attribute_group___434 **drv_groups;
	int (*match)(struct device___437 *, struct device_driver___437 *);
	int (*uevent)(struct device___437 *, struct kobj_uevent_env *);
	int (*probe)(struct device___437 *);
	int (*remove)(struct device___437 *);
	void (*shutdown)(struct device___437 *);
	int (*online)(struct device___437 *);
	int (*offline)(struct device___437 *);
	int (*suspend)(struct device___437 *, pm_message_t);
	int (*resume)(struct device___437 *);
	int (*num_vf)(struct device___437 *);
	int (*dma_configure)(struct device___437 *);
	const struct dev_pm_ops___437 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___437 {
	const char *name;
	struct bus_type___437 *bus;
	struct module___395 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___437 *);
	int (*remove)(struct device___437 *);
	void (*shutdown)(struct device___437 *);
	int (*suspend)(struct device___437 *, pm_message_t);
	int (*resume)(struct device___437 *);
	const struct attribute_group___434 **groups;
	const struct dev_pm_ops___437 *pm;
	void (*coredump)(struct device___437 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___437 {
	const char *name;
	const struct attribute_group___434 **groups;
	int (*uevent)(struct device___437 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___437 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___437 *);
	const struct dev_pm_ops___437 *pm;
};

struct class___437 {
	const char *name;
	struct module___395 *owner;
	const struct attribute_group___434 **class_groups;
	const struct attribute_group___434 **dev_groups;
	struct kobject___457 *dev_kobj;
	int (*dev_uevent)(struct device___437 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___437 *, umode_t *);
	void (*class_release)(struct class___437 *);
	void (*dev_release)(struct device___437 *);
	int (*shutdown_pre)(struct device___437 *);
	const struct kobj_ns_type_operations___94 *ns_type;
	const void * (*namespace)(struct device___437 *);
	const struct dev_pm_ops___437 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___209 {
	void * (*alloc)(struct device___437 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___437 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___437 *, struct vm_area_struct___470 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___437 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___437 *, struct page___470 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___437 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___437 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___437 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___437 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___437 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___437 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___437 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___437 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___437 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___437 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___437 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___437 *, u64);
	u64 (*get_required_mask)(struct device___437 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___357;

struct fwnode_handle___357 {
	struct fwnode_handle___357 *secondary;
	const struct fwnode_operations___357 *ops;
};

typedef void compound_page_dtor___457(struct page___470 *);

struct fwnode_reference_args___357;

struct fwnode_endpoint___357;

struct fwnode_operations___357 {
	struct fwnode_handle___357 * (*get)(struct fwnode_handle___357 *);
	void (*put)(struct fwnode_handle___357 *);
	bool (*device_is_available)(const struct fwnode_handle___357 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___357 *, const struct device___437 *);
	bool (*property_present)(const struct fwnode_handle___357 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___357 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___357 *, const char *, const char **, size_t);
	struct fwnode_handle___357 * (*get_parent)(const struct fwnode_handle___357 *);
	struct fwnode_handle___357 * (*get_next_child_node)(const struct fwnode_handle___357 *, struct fwnode_handle___357 *);
	struct fwnode_handle___357 * (*get_named_child_node)(const struct fwnode_handle___357 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___357 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___357 *);
	struct fwnode_handle___357 * (*graph_get_next_endpoint)(const struct fwnode_handle___357 *, struct fwnode_handle___357 *);
	struct fwnode_handle___357 * (*graph_get_remote_endpoint)(const struct fwnode_handle___357 *);
	struct fwnode_handle___357 * (*graph_get_port_parent)(struct fwnode_handle___357 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___357 *, struct fwnode_endpoint___357 *);
};

struct fwnode_endpoint___357 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___357 *local_fwnode;
};

struct fwnode_reference_args___357 {
	struct fwnode_handle___357 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___150;

struct pipe_buffer___150 {
	struct page___470 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___150 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___150 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___150 *, struct pipe_buffer___150 *);
	void (*release)(struct pipe_inode_info___150 *, struct pipe_buffer___150 *);
	int (*steal)(struct pipe_inode_info___150 *, struct pipe_buffer___150 *);
	union {
		bool (*get)(struct pipe_inode_info___150 *, struct pipe_buffer___150 *);
		struct {
			void (*get)(struct pipe_inode_info___150 *, struct pipe_buffer___150 *);
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
};

struct nf_bridge_info___114 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___114 = 0,
		BRNF_PROTO_8021Q___114 = 1,
		BRNF_PROTO_PPPOE___114 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___114 *physindev;
	struct net_device___114 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___114(struct sk_buff___115 **);

struct net_device_ops___114;

struct ethtool_ops___114;

struct l3mdev_ops___94;

struct ndisc_ops___64;

struct xfrmdev_ops___114;

struct tlsdev_ops___114;

struct header_ops___114;

struct inet6_dev___64;

struct netdev_rx_queue___114;

struct mini_Qdisc___106;

struct netdev_queue___114;

struct Qdisc___106;

struct rtnl_link_ops___106;

struct dcbnl_rtnl_ops___114;

struct net_device___114 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___114 *netdev_ops;
	const struct ethtool_ops___114 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___94 *l3mdev_ops;
	const struct ndisc_ops___64 *ndisc_ops;
	const struct xfrmdev_ops___114 *xfrmdev_ops;
	const struct tlsdev_ops___114 *tlsdev_ops;
	const struct header_ops___114 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___456 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___64 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___114 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___104 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___114 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___106 *miniq_ingress;
	struct netdev_queue___114 *ingress_queue;
	struct nf_hook_entries___22 *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___114 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___106 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___106 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___114 = 0,
		NETREG_REGISTERED___114 = 1,
		NETREG_UNREGISTERING___114 = 2,
		NETREG_UNREGISTERED___114 = 3,
		NETREG_RELEASED___114 = 4,
		NETREG_DUMMY___114 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___114 = 0,
		RTNL_LINK_INITIALIZING___114 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___114 *);
	struct netpoll_info *npinfo;
	possible_net_t___116 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___437 dev;
	const struct attribute_group___434 *sysfs_groups[4];
	const struct attribute_group___434 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___106 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___114 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct xfrm_state___27;

struct sec_path___27 {
	refcount_t refcnt;
	int len;
	int olen;
	struct xfrm_state___27 *xvec[6];
	struct xfrm_offload ovec[1];
};

struct ethtool_ops___114 {
	int (*get_settings)(struct net_device___114 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___114 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___114 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___114 *);
	void (*get_regs)(struct net_device___114 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___114 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___114 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___114 *);
	void (*set_msglevel)(struct net_device___114 *, u32);
	int (*nway_reset)(struct net_device___114 *);
	u32 (*get_link)(struct net_device___114 *);
	int (*get_eeprom_len)(struct net_device___114 *);
	int (*get_eeprom)(struct net_device___114 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___114 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___114 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___114 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___114 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___114 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___114 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___114 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___114 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___114 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___114 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___114 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___114 *);
	void (*complete)(struct net_device___114 *);
	u32 (*get_priv_flags)(struct net_device___114 *);
	int (*set_priv_flags)(struct net_device___114 *, u32);
	int (*get_sset_count)(struct net_device___114 *, int);
	int (*get_rxnfc)(struct net_device___114 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___114 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___114 *, struct ethtool_flash *);
	int (*reset)(struct net_device___114 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___114 *);
	u32 (*get_rxfh_indir_size)(struct net_device___114 *);
	int (*get_rxfh)(struct net_device___114 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___114 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___114 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___114 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___114 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___114 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___114 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___114 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___114 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___114 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___114 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___114 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___114 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___114 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___114 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___114 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___114 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___114 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___114 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___114 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___114 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___114 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	int (*get_fecparam)(struct net_device___114 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___114 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___114 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___114 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___114 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___114;

struct inet_frags___114 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___114 *, const void *);
	void (*destructor)(struct inet_frag_queue___114 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___114 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___115 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___115 *fragments_tail;
	struct sk_buff___115 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___114 *net;
	struct callback_head rcu;
};

struct ip_ra_chain___58 {
	struct ip_ra_chain___58 *next;
	struct sock___94 *sk;
	union {
		void (*destructor)(struct sock___94 *);
		struct sock___94 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___94;

struct fib_lookup_arg___94;

struct fib_rules_ops___94 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___94 *, struct flowi *, int, struct fib_lookup_arg___94 *);
	bool (*suppress)(struct fib_rule___94 *, struct fib_lookup_arg___94 *);
	int (*match)(struct fib_rule___94 *, struct flowi *, int);
	int (*configure)(struct fib_rule___94 *, struct sk_buff___115 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___94 *);
	int (*compare)(struct fib_rule___94 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___94 *, struct sk_buff___115 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___94 *);
	void (*flush_cache)(struct fib_rules_ops___94 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___395 *owner;
	struct net___125 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___95 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___125 *);
	int (*fib_dump)(struct net___125 *, struct notifier_block *);
	struct module___395 *owner;
	struct callback_head rcu;
};

struct lwtunnel_state___18;

struct dst_entry___94 {
	struct net_device___114 *dev;
	struct dst_ops___125 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state___27 *xfrm;
	int (*input)(struct sk_buff___115 *);
	int (*output)(struct net___125 *, struct sock___94 *, struct sk_buff___115 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___18 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___94;

struct neigh_parms___94;

struct neigh_ops___94;

struct neighbour___94 {
	struct neighbour___94 *next;
	struct neigh_table___94 *tbl;
	struct neigh_parms___94 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___114 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___94 *, struct sk_buff___115 *);
	const struct neigh_ops___94 *ops;
	struct callback_head rcu;
	struct net_device___114 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct fib6_nh___35 {
	struct in6_addr nh_gw;
	struct net_device___114 *nh_dev;
	struct lwtunnel_state___18 *nh_lwtstate;
	unsigned int nh_flags;
	atomic_t nh_upper_bound;
	int nh_weight;
};

struct fib6_node___35;

struct fib6_info___35 {
	struct fib6_table___35 *fib6_table;
	struct fib6_info___35 *fib6_next;
	struct fib6_node___35 *fib6_node;
	struct list_head fib6_siblings;
	unsigned int fib6_nsiblings;
	atomic_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	struct rt6_info___35 **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
	long unsigned int last_probe;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 exception_bucket_flushed: 1;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 dst_host: 1;
	u8 fib6_destroying: 1;
	u8 unused: 2;
	struct fib6_nh___35 fib6_nh;
	struct callback_head rcu;
};

struct rt6_info___35 {
	struct dst_entry___94 dst;
	struct fib6_info___35 *from;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___64 *rt6i_idev;
	u32 rt6i_flags;
	struct rt6key rt6i_prefsrc;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct fib6_node___35 {
	struct fib6_node___35 *parent;
	struct fib6_node___35 *left;
	struct fib6_node___35 *right;
	struct fib6_info___35 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info___35 *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table___35 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node___35 tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

struct nf_queue_entry___5;

struct nf_queue_handler___4 {
	int (*outfn)(struct nf_queue_entry___5 *, unsigned int);
	void (*nf_hook_drop)(struct net___125 *);
};

struct nf_hook_state___22;

typedef unsigned int nf_hookfn___22(void *, struct sk_buff___115 *, const struct nf_hook_state___22 *);

struct nf_hook_entry___22 {
	nf_hookfn___22 *hook;
	void *priv;
};

struct nf_hook_entries___22 {
	u16 num_hook_entries;
	struct nf_hook_entry___22 hooks[0];
};

struct ucounts___334 {
	struct hlist_node node;
	struct user_namespace___334 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_prog_aux___107;

struct bpf_prog___104 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___107 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

typedef int (*key_restrict_link_func_t___438)(struct key___437 *, const struct key_type *, const union key_payload *, struct key___437 *);

struct key_restriction___437;

struct key___437 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___471 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___437 *restrict_link;
};

struct key_restriction___437 {
	key_restrict_link_func_t___438 check;
	struct key___437 *key;
	struct key_type *keytype;
};

struct seq_operations___408 {
	void * (*start)(struct seq_file___408 *, loff_t *);
	void (*stop)(struct seq_file___408 *, void *);
	void * (*next)(struct seq_file___408 *, void *, loff_t *);
	int (*show)(struct seq_file___408 *, void *);
};

struct pernet_operations___115 {
	struct list_head list;
	int (*init)(struct net___125 *);
	void (*exit)(struct net___125 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___114 {
	int (*ieee_getets)(struct net_device___114 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___114 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___114 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___114 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___114 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___114 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___114 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___114 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___114 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___114 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___114 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___114 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___114 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___114 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___114 *);
	u8 (*setstate)(struct net_device___114 *, u8);
	void (*getpermhwaddr)(struct net_device___114 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___114 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___114 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___114 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___114 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___114 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___114 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___114 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___114 *, int, u8 *);
	void (*setpfccfg)(struct net_device___114 *, int, u8);
	void (*getpfccfg)(struct net_device___114 *, int, u8 *);
	u8 (*setall)(struct net_device___114 *);
	u8 (*getcap)(struct net_device___114 *, int, u8 *);
	int (*getnumtcs)(struct net_device___114 *, int, u8 *);
	int (*setnumtcs)(struct net_device___114 *, int, u8);
	u8 (*getpfcstate)(struct net_device___114 *);
	void (*setpfcstate)(struct net_device___114 *, u8);
	void (*getbcncfg)(struct net_device___114 *, int, u32 *);
	void (*setbcncfg)(struct net_device___114 *, int, u32);
	void (*getbcnrp)(struct net_device___114 *, int, u8 *);
	void (*setbcnrp)(struct net_device___114 *, int, u8);
	int (*setapp)(struct net_device___114 *, u8, u16, u8);
	int (*getapp)(struct net_device___114 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___114 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___114 *, int, u8);
	u8 (*getdcbx)(struct net_device___114 *);
	u8 (*setdcbx)(struct net_device___114 *, u8);
	int (*peer_getappinfo)(struct net_device___114 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___114 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___114 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___114 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___114 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___114 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___318 {
	refcount_t count;
	struct ns_common___29 ns;
	struct user_namespace___334 *user_ns;
	struct ucounts___334 *ucounts;
	struct css_set___318 *root_cset;
};

struct bpf_map___319;

struct bpf_map_ops___318 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___319 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___319 *, struct file___469 *);
	void (*map_free)(struct bpf_map___319 *);
	int (*map_get_next_key)(struct bpf_map___319 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___319 *);
	void * (*map_lookup_elem)(struct bpf_map___319 *, void *);
	int (*map_update_elem)(struct bpf_map___319 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___319 *, void *);
	int (*map_push_elem)(struct bpf_map___319 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___319 *, void *);
	int (*map_peek_elem)(struct bpf_map___319 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___319 *, struct file___469 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___319 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___319 *, void *, struct seq_file___408 *);
	int (*map_check_btf)(const struct bpf_map___319 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___319 {
	const struct bpf_map_ops___318 *ops;
	struct bpf_map___319 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___437 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___114;

struct bpf_map_dev_ops___114 {
	int (*map_get_next_key)(struct bpf_offloaded_map___114 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___114 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___114 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___114 *, void *);
};

struct bpf_offloaded_map___114 {
	struct bpf_map___319 map;
	struct net_device___114 *netdev;
	const struct bpf_map_dev_ops___114 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___104 {
	int (*test_run)(struct bpf_prog___104 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___104 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___104 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___104 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___104 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___104 *, u32 *);
};

struct bpf_prog_offload_ops___104 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___104 *);
	int (*translate)(struct bpf_prog___104 *);
	void (*destroy)(struct bpf_prog___104 *);
};

struct bpf_prog_offload___104 {
	struct bpf_prog___104 *prog;
	struct net_device___114 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___104 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___107 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___104 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___104 *ops;
	struct bpf_map___319 **used_maps;
	struct bpf_prog___104 *prog;
	struct user_struct___437 *user;
	u64 load_time;
	struct bpf_map___319 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___104 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___104 {
	struct bpf_prog___104 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___104 {
	struct callback_head rcu;
	struct bpf_prog_array_item___104 items[0];
};

struct cgroup_bpf___104 {
	struct bpf_prog_array___104 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___104 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___319;

typedef void (*kthread_work_func_t___319)(struct kthread_work___319 *);

struct kthread_worker___319;

struct kthread_work___319 {
	struct list_head node;
	kthread_work_func_t___319 func;
	struct kthread_worker___319 *worker;
	int canceling;
};

struct kthread_worker___319 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___471 *task;
	struct kthread_work___319 *current_work;
};

struct kthread_delayed_work___318 {
	struct kthread_work___319 work;
	struct timer_list timer;
};

struct psi_group___318 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___319 *poll_kworker;
	struct kthread_delayed_work___318 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___318;

struct cgroup_rstat_cpu___318;

struct cgroup___318 {
	struct cgroup_subsys_state___318 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___464 *kn;
	struct cgroup_file___318 procs_file;
	struct cgroup_file___318 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___318 *subsys[13];
	struct cgroup_root___318 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___318 *dom_cgrp;
	struct cgroup_rstat_cpu___318 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___104 bpf;
	atomic_t congestion_count;
	struct cgroup___318 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___318 psi;
	int ancestor_ids[0];
};

struct cftype___318;

struct cgroup_subsys___318 {
	struct cgroup_subsys_state___318 * (*css_alloc)(struct cgroup_subsys_state___318 *);
	int (*css_online)(struct cgroup_subsys_state___318 *);
	void (*css_offline)(struct cgroup_subsys_state___318 *);
	void (*css_released)(struct cgroup_subsys_state___318 *);
	void (*css_free)(struct cgroup_subsys_state___318 *);
	void (*css_reset)(struct cgroup_subsys_state___318 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___318 *, int);
	int (*css_extra_stat_show)(struct seq_file___408 *, struct cgroup_subsys_state___318 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___471 *);
	void (*cancel_fork)(struct task_struct___471 *);
	void (*fork)(struct task_struct___471 *);
	void (*exit)(struct task_struct___471 *);
	void (*free)(struct task_struct___471 *);
	void (*bind)(struct cgroup_subsys_state___318 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___318 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___318 *dfl_cftypes;
	struct cftype___318 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___318 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___318 *updated_children;
	struct cgroup___318 *updated_next;
};

struct cgroup_root___318 {
	struct kernfs_root___463 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___318 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___318 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___318 *ss;
	struct list_head node;
	struct kernfs_ops___463 *kf_ops;
	int (*open)(struct kernfs_open_file___463 *);
	void (*release)(struct kernfs_open_file___463 *);
	u64 (*read_u64)(struct cgroup_subsys_state___318 *, struct cftype___318 *);
	s64 (*read_s64)(struct cgroup_subsys_state___318 *, struct cftype___318 *);
	int (*seq_show)(struct seq_file___408 *, void *);
	void * (*seq_start)(struct seq_file___408 *, loff_t *);
	void * (*seq_next)(struct seq_file___408 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___408 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___318 *, struct cftype___318 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___318 *, struct cftype___318 *, s64);
	ssize_t (*write)(struct kernfs_open_file___463 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___463 *, struct poll_table_struct___308 *);
};

struct xdp_rxq_info___114 {
	struct net_device___114 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___114 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___114 *dev_rx;
};

struct netlink_callback___116 {
	struct sk_buff___115 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___116 *);
	int (*dump)(struct sk_buff___115 *, struct netlink_callback___116 *);
	int (*done)(struct netlink_callback___116 *);
	void *data;
	struct module___395 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___114 {
	int (*create)(struct sk_buff___115 *, struct net_device___114 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___115 *, unsigned char *);
	int (*cache)(const struct neighbour___94 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___114 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___114 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___114 *, int);
	int poll_owner;
	struct net_device___114 *dev;
	struct sk_buff___115 *gro_list;
	struct sk_buff___115 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___114 {
	struct net_device___114 *dev;
	struct Qdisc___106 *qdisc;
	struct Qdisc___106 *qdisc_sleeping;
	struct kobject___457 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___114 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___106 {
	struct sk_buff___115 *head;
	struct sk_buff___115 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___106;

struct Qdisc___106 {
	int (*enqueue)(struct sk_buff___115 *, struct Qdisc___106 *, struct sk_buff___115 **);
	struct sk_buff___115 * (*dequeue)(struct Qdisc___106 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___106 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___114 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___114 gso_skb;
	struct qdisc_skb_head___106 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___106 *next_sched;
	struct sk_buff_head___114 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___114 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___457 kobj;
	struct net_device___114 *dev;
	long: 64;
	struct xdp_rxq_info___114 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___114)(struct net_device___114 *, struct sk_buff___115 *, struct net_device___114 *);

struct netdev_bpf___114 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___104 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___104 *prog;
			const struct bpf_prog_offload_ops___104 *ops;
		} verifier;
		struct {
			struct bpf_prog___104 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___114 *offmap;
		};
		struct {
			struct xdp_umem___3 *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___114 {
	int (*xdo_dev_state_add)(struct xfrm_state___27 *);
	void (*xdo_dev_state_delete)(struct xfrm_state___27 *);
	void (*xdo_dev_state_free)(struct xfrm_state___27 *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___115 *, struct xfrm_state___27 *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state___27 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct xfrm_state_offload___27 {
	struct net_device___114 *dev;
	long unsigned int offload_handle;
	unsigned int num_exthdrs;
	u8 flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct xfrm_replay___27;

struct xfrm_type___27;

struct xfrm_mode___27;

struct xfrm_type_offload___27;

struct xfrm_state___27 {
	possible_net_t___116 xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	refcount_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
		u32 output_mark;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	const char *geniv;
	struct xfrm_encap_tmpl *encap;
	xfrm_address_t *coaddr;
	struct xfrm_state___27 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	const struct xfrm_replay___27 *repl;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct tasklet_hrtimer mtimer;
	struct xfrm_state_offload___27 xso;
	long int saved_tmo;
	long unsigned int lastused;
	struct page_frag___470 xfrag;
	const struct xfrm_type___27 *type;
	struct xfrm_mode___27 *inner_mode;
	struct xfrm_mode___27 *inner_mode_iaf;
	struct xfrm_mode___27 *outer_mode;
	const struct xfrm_type_offload___27 *type_offload;
	struct xfrm_sec_ctx___2 *security;
	void *data;
	u32 output_mark_mask;
	u32 if_id;
};

struct tlsdev_ops___114 {
	int (*tls_dev_add)(struct net_device___114 *, struct sock___94 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___114 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___114 *, struct sock___94 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___114 {
	int (*ndo_init)(struct net_device___114 *);
	void (*ndo_uninit)(struct net_device___114 *);
	int (*ndo_open)(struct net_device___114 *);
	int (*ndo_stop)(struct net_device___114 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___115 *, struct net_device___114 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___115 *, struct net_device___114 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___114 *, struct sk_buff___115 *, struct net_device___114 *, select_queue_fallback_t___114);
	void (*ndo_change_rx_flags)(struct net_device___114 *, int);
	void (*ndo_set_rx_mode)(struct net_device___114 *);
	int (*ndo_set_mac_address)(struct net_device___114 *, void *);
	int (*ndo_validate_addr)(struct net_device___114 *);
	int (*ndo_do_ioctl)(struct net_device___114 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___114 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___114 *, int);
	int (*ndo_neigh_setup)(struct net_device___114 *, struct neigh_parms___94 *);
	void (*ndo_tx_timeout)(struct net_device___114 *);
	void (*ndo_get_stats64)(struct net_device___114 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___114 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___114 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___114 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___114 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___114 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___114 *);
	int (*ndo_netpoll_setup)(struct net_device___114 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___114 *);
	int (*ndo_set_vf_mac)(struct net_device___114 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___114 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___114 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___114 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___114 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___114 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___114 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___114 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___114 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___114 *, int, struct sk_buff___115 *);
	int (*ndo_set_vf_guid)(struct net_device___114 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___114 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___114 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___114 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___114 *, const struct sk_buff___115 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___114 *, struct net_device___114 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___114 *, struct net_device___114 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___114 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___114 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___114 *, struct neighbour___94 *);
	void (*ndo_neigh_destroy)(struct net_device___114 *, struct neighbour___94 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___114 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___114 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___114 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___115 *, struct netlink_callback___116 *, struct net_device___114 *, struct net_device___114 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___114 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___114 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___115 *, u32, u32, struct net_device___114 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___114 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___114 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___114 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___114 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___114 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___114 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___114 *, struct net_device___114 *);
	void (*ndo_dfwd_del_station)(struct net_device___114 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___114 *);
	int (*ndo_set_tx_maxrate)(struct net_device___114 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___114 *);
	int (*ndo_change_proto_down)(struct net_device___114 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___114 *, struct sk_buff___115 *);
	void (*ndo_set_rx_headroom)(struct net_device___114 *, int);
	int (*ndo_bpf)(struct net_device___114 *, struct netdev_bpf___114 *);
	int (*ndo_xdp_xmit)(struct net_device___114 *, int, struct xdp_frame___114 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___114 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___114 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___94 {
	possible_net_t___116 net;
	struct net_device___114 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___94 *);
	void (*neigh_cleanup)(struct neighbour___94 *);
	struct neigh_table___94 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___94 {
	u32 (*l3mdev_fib_table)(const struct net_device___114 *);
	struct sk_buff___115 * (*l3mdev_l3_rcv)(struct net_device___114 *, struct sk_buff___115 *, u16);
	struct sk_buff___115 * (*l3mdev_l3_out)(struct net_device___114 *, struct sock___94 *, struct sk_buff___115 *, u16);
	struct dst_entry___94 * (*l3mdev_link_scope_lookup)(const struct net_device___114 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct ndisc_ops___64 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___114 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___114 *, struct neighbour___94 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___114 *, u8, struct neighbour___94 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___114 *, struct sk_buff___115 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___125 *, struct net_device___114 *, const struct prefix_info *, struct inet6_dev___64 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___64;

struct ifacaddr6___35;

struct inet6_dev___64 {
	struct net_device___114 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___64 *mc_list;
	struct ifmcaddr6___64 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___35 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	u8 rndid[8];
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___94 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
};

struct tcf_proto___106;

struct mini_Qdisc___106 {
	struct tcf_proto___106 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___106 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___114 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___125 *, struct net_device___114 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___114 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___114 *, struct list_head *);
	size_t (*get_size)(const struct net_device___114 *);
	int (*fill_info)(struct sk_buff___115 *, const struct net_device___114 *);
	size_t (*get_xstats_size)(const struct net_device___114 *);
	int (*fill_xstats)(struct sk_buff___115 *, const struct net_device___114 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___114 *, struct net_device___114 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___114 *, const struct net_device___114 *);
	int (*fill_slave_info)(struct sk_buff___115 *, const struct net_device___114 *, const struct net_device___114 *);
	struct net___125 * (*get_link_net)(const struct net_device___114 *);
	size_t (*get_linkxstats_size)(const struct net_device___114 *, int);
	int (*fill_linkxstats)(struct sk_buff___115 *, const struct net_device___114 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___114 {
	struct list_head poll_list;
	struct sk_buff_head___114 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___114 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___106 *output_queue;
	struct Qdisc___106 **output_queue_tailp;
	struct sk_buff___115 *completion_queue;
	struct sk_buff_head___114 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___114 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___114 input_pkt_queue;
	struct napi_struct___114 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bdi_writeback_congested___259 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___259 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___259 {
	struct bio___259 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___261 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___261 bip_inline_vecs[0];
};

struct bio_set___259 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___259 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___202 {
	struct mem_cgroup___202 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___202 {
	struct lruvec___470 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___202 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___202 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct kernel_param_ops___395 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___395 *);
	int (*get)(char *, const struct kernel_param___395 *);
	void (*free)(void *);
};

struct kparam_array___395;

struct kernel_param___395 {
	const char *name;
	struct module___395 *mod;
	const struct kernel_param_ops___395 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___395 *arr;
	};
};

struct kparam_array___395 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___395 *ops;
	void *elem;
};

struct module_attribute___395 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___395 *, struct module_kobject___395 *, char *);
	ssize_t (*store)(struct module_attribute___395 *, struct module_kobject___395 *, const char *, size_t);
	void (*setup)(struct module___395 *, const char *);
	int (*test)(struct module___395 *);
	void (*free)(struct module___395 *);
};

struct gnet_dump___106 {
	spinlock_t *lock;
	struct sk_buff___115 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___106;

struct Qdisc_ops___106 {
	struct Qdisc_ops___106 *next;
	const struct Qdisc_class_ops___106 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___115 *, struct Qdisc___106 *, struct sk_buff___115 **);
	struct sk_buff___115 * (*dequeue)(struct Qdisc___106 *);
	struct sk_buff___115 * (*peek)(struct Qdisc___106 *);
	int (*init)(struct Qdisc___106 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___106 *);
	void (*destroy)(struct Qdisc___106 *);
	int (*change)(struct Qdisc___106 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___106 *);
	int (*change_tx_queue_len)(struct Qdisc___106 *, unsigned int);
	int (*dump)(struct Qdisc___106 *, struct sk_buff___115 *);
	int (*dump_stats)(struct Qdisc___106 *, struct gnet_dump___106 *);
	void (*ingress_block_set)(struct Qdisc___106 *, u32);
	void (*egress_block_set)(struct Qdisc___106 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___106 *);
	u32 (*egress_block_get)(struct Qdisc___106 *);
	struct module___395 *owner;
};

struct tcf_block___106;

struct Qdisc_class_ops___106 {
	unsigned int flags;
	struct netdev_queue___114 * (*select_queue)(struct Qdisc___106 *, struct tcmsg *);
	int (*graft)(struct Qdisc___106 *, long unsigned int, struct Qdisc___106 *, struct Qdisc___106 **, struct netlink_ext_ack *);
	struct Qdisc___106 * (*leaf)(struct Qdisc___106 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___106 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___106 *, u32);
	int (*change)(struct Qdisc___106 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___106 *, long unsigned int);
	void (*walk)(struct Qdisc___106 *, struct qdisc_walker *);
	struct tcf_block___106 * (*tcf_block)(struct Qdisc___106 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___106 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___106 *, long unsigned int);
	int (*dump)(struct Qdisc___106 *, long unsigned int, struct sk_buff___115 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___106 *, long unsigned int, struct gnet_dump___106 *);
};

struct tcf_chain___106;

struct tcf_block___106 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___125 *net;
	struct Qdisc___106 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___106 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___106;

struct tcf_proto_ops___106;

struct tcf_proto___106 {
	struct tcf_proto___106 *next;
	void *root;
	int (*classify)(struct sk_buff___115 *, const struct tcf_proto___106 *, struct tcf_result___106 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___106 *ops;
	struct tcf_chain___106 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___106 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___106 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___106 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___115 *, const struct tcf_proto___106 *, struct tcf_result___106 *);
	int (*init)(struct tcf_proto___106 *);
	void (*destroy)(struct tcf_proto___106 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___106 *, u32);
	void (*put)(struct tcf_proto___106 *, void *);
	int (*change)(struct net___125 *, struct sk_buff___115 *, struct tcf_proto___106 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___106 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___106 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___106 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___125 *, struct tcf_chain___106 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___125 *, struct tcf_proto___106 *, void *, struct sk_buff___115 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___115 *, struct net___125 *, void *);
	struct module___395 *owner;
	int flags;
};

struct tcf_chain___106 {
	struct mutex filter_chain_lock;
	struct tcf_proto___106 *filter_chain;
	struct list_head list;
	struct tcf_block___106 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___106 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___94 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___104 *prog;
};

struct bpf_redirect_info___104 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___319 *map;
	struct bpf_map___319 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___94;

struct neigh_hash_table___94;

struct neigh_table___94 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___114 *, __u32 *);
	bool (*key_eq)(const struct neighbour___94 *, const void *);
	int (*constructor)(struct neighbour___94 *);
	int (*pconstructor)(struct pneigh_entry___94 *);
	void (*pdestructor)(struct pneigh_entry___94 *);
	void (*proxy_redo)(struct sk_buff___115 *);
	char *id;
	struct neigh_parms___94 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___114 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___94 *nht;
	struct pneigh_entry___94 **phash_buckets;
};

struct neigh_ops___94 {
	int family;
	void (*solicit)(struct neighbour___94 *, struct sk_buff___115 *);
	void (*error_report)(struct neighbour___94 *, struct sk_buff___115 *);
	int (*output)(struct neighbour___94 *, struct sk_buff___115 *);
	int (*connected_output)(struct neighbour___94 *, struct sk_buff___115 *);
};

struct pneigh_entry___94 {
	struct pneigh_entry___94 *next;
	possible_net_t___116 net;
	struct net_device___114 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___94 {
	struct neighbour___94 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___18 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___125 *, struct sock___94 *, struct sk_buff___115 *);
	int (*orig_input)(struct sk_buff___115 *);
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	__u8 data[0];
};

struct fib_rule___94 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___94 *ctarget;
	struct net___125 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___94 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___94 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___76;

struct timewait_sock_ops___72;

struct proto___94 {
	void (*close)(struct sock___94 *, long int);
	int (*pre_connect)(struct sock___94 *, struct sockaddr *, int);
	int (*connect)(struct sock___94 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___94 *, int);
	struct sock___94 * (*accept)(struct sock___94 *, int, int *, bool);
	int (*ioctl)(struct sock___94 *, int, long unsigned int);
	int (*init)(struct sock___94 *);
	void (*destroy)(struct sock___94 *);
	void (*shutdown)(struct sock___94 *, int);
	int (*setsockopt)(struct sock___94 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___94 *, int, int, char *, int *);
	void (*keepalive)(struct sock___94 *, int);
	int (*sendmsg)(struct sock___94 *, struct msghdr___97 *, size_t);
	int (*recvmsg)(struct sock___94 *, struct msghdr___97 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___94 *, struct page___470 *, int, size_t, int);
	int (*bind)(struct sock___94 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___94 *, struct sk_buff___115 *);
	void (*release_cb)(struct sock___94 *);
	int (*hash)(struct sock___94 *);
	void (*unhash)(struct sock___94 *);
	void (*rehash)(struct sock___94 *);
	int (*get_port)(struct sock___94 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___94 *);
	bool (*stream_memory_read)(const struct sock___94 *);
	void (*enter_memory_pressure)(struct sock___94 *);
	void (*leave_memory_pressure)(struct sock___94 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___76 *rsk_prot;
	struct timewait_sock_ops___72 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___395 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___94 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct xfrm_policy_queue___27 {
	struct sk_buff_head___114 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___27 {
	possible_net_t___116 xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	refcount_t refcnt;
	struct timer_list timer;
	atomic_t genid;
	u32 priority;
	u32 index;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___27 polq;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx___2 *security;
	struct xfrm_tmpl xfrm_vec[6];
	struct callback_head rcu;
	u32 if_id;
};

struct request_sock___77;

struct request_sock_ops___76 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___94 *, struct request_sock___77 *);
	void (*send_ack)(const struct sock___94 *, struct sk_buff___115 *, struct request_sock___77 *);
	void (*send_reset)(const struct sock___94 *, struct sk_buff___115 *);
	void (*destructor)(struct request_sock___77 *);
	void (*syn_ack_timeout)(const struct request_sock___77 *);
};

struct timewait_sock_ops___72 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___94 *, struct sock___94 *, void *);
	void (*twsk_destructor)(struct sock___94 *);
};

struct request_sock___77 {
	struct sock_common___94 __req_common;
	struct request_sock___77 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___76 *rsk_ops;
	struct sock___94 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct inet_cork___29 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___94 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
	__u16 gso_size;
	u64 transmit_time;
};

struct inet_cork_full___29 {
	struct inet_cork___29 base;
	struct flowi fl;
};

struct ipv6_pinfo___29;

struct inet_sock___29 {
	struct sock___94 sk;
	struct ipv6_pinfo___29 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	__be16 inet_sport;
	__u16 inet_id;
	struct ip_options_rcu *inet_opt;
	int rx_dst_ifindex;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 bind_address_no_port: 1;
	__u8 defer_connect: 1;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___29 cork;
};

struct ipv6_fl_socklist___28;

struct ipv6_pinfo___29 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
			__u16 recvfragsize: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 repflow: 1;
	__u16 pmtudisc: 3;
	__u16 padding: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u16 autoflowlabel: 1;
	__u16 autoflowlabel_set: 1;
	__u8 min_hopcount;
	__u8 tclass;
	__be32 rcv_flowinfo;
	__u32 dst_cookie;
	__u32 rx_dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___28 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___115 *pktoptions;
	struct sk_buff___115 *rxpmtu;
	struct inet6_cork cork;
};

struct ip6_flowlabel___28;

struct ipv6_fl_socklist___28 {
	struct ipv6_fl_socklist___28 *next;
	struct ip6_flowlabel___28 *fl;
	struct callback_head rcu;
};

struct nf_hook_state___22 {
	unsigned int hook;
	u_int8_t pf;
	struct net_device___114 *in;
	struct net_device___114 *out;
	struct sock___94 *sk;
	struct net___125 *net;
	int (*okfn)(struct net___125 *, struct sock___94 *, struct sk_buff___115 *);
};

struct nf_nat_hook___22 {
	int (*parse_nat_setup)(struct nf_conn *, enum nf_nat_manip_type, const struct nlattr *);
	void (*decode_session)(struct sk_buff___115 *, struct flowi *);
	unsigned int (*manip_pkt)(struct sk_buff___115 *, struct nf_conn *, enum nf_nat_manip_type, enum ip_conntrack_dir);
};

struct nf_ct_hook___22 {
	int (*update)(struct net___125 *, struct sk_buff___115 *);
	void (*destroy)(struct nf_conntrack *);
	bool (*get_tuple_skb)(struct nf_conntrack_tuple *, const struct sk_buff___115 *);
};

struct nfnl_ct_hook___22 {
	struct nf_conn * (*get_ct)(const struct sk_buff___115 *, enum ip_conntrack_info *);
	size_t (*build_size)(const struct nf_conn *);
	int (*build)(struct sk_buff___115 *, struct nf_conn *, enum ip_conntrack_info, u_int16_t, u_int16_t);
	int (*parse)(const struct nlattr *, struct nf_conn *);
	int (*attach_expect)(const struct nlattr *, struct nf_conn *, u32, u32);
	void (*seq_adjust)(struct sk_buff___115 *, struct nf_conn *, enum ip_conntrack_info, s32);
};

struct nf_ipv6_ops___13 {
	int (*chk_addr)(struct net___125 *, const struct in6_addr *, const struct net_device___114 *, int);
	void (*route_input)(struct sk_buff___115 *);
	int (*fragment)(struct net___125 *, struct sock___94 *, struct sk_buff___115 *, int (*)(struct net___125 *, struct sock___94 *, struct sk_buff___115 *));
	__sum16 (*checksum)(struct sk_buff___115 *, unsigned int, unsigned int, u_int8_t);
	__sum16 (*checksum_partial)(struct sk_buff___115 *, unsigned int, unsigned int, unsigned int, u_int8_t);
	int (*route)(struct net___125 *, struct dst_entry___94 **, struct flowi *, bool);
	int (*reroute)(struct sk_buff___115 *, const struct nf_queue_entry___5 *);
};

struct nf_queue_entry___5 {
	struct list_head list;
	struct sk_buff___115 *skb;
	unsigned int id;
	unsigned int hook_index;
	struct nf_hook_state___22 state;
	u16 size;
};

struct ifmcaddr6___64 {
	struct in6_addr mca_addr;
	struct inet6_dev___64 *idev;
	struct ifmcaddr6___64 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ifacaddr6___35 {
	struct in6_addr aca_addr;
	struct fib6_info___35 *aca_rt;
	struct ifacaddr6___35 *aca_next;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
};

struct ip6_ra_chain___64 {
	struct ip6_ra_chain___64 *next;
	struct sock___94 *sk;
	int sel;
	void (*destructor)(struct sock___94 *);
};

struct ip6_flowlabel___28 {
	struct ip6_flowlabel___28 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___263 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___125 *fl_net;
};

struct ipv6_stub___24 {
	int (*ipv6_sock_mc_join)(struct sock___94 *, int, const struct in6_addr *);
	int (*ipv6_sock_mc_drop)(struct sock___94 *, int, const struct in6_addr *);
	int (*ipv6_dst_lookup)(struct net___125 *, struct sock___94 *, struct dst_entry___94 **, struct flowi6 *);
	struct fib6_table___35 * (*fib6_get_table)(struct net___125 *, u32);
	struct fib6_info___35 * (*fib6_lookup)(struct net___125 *, int, struct flowi6 *, int);
	struct fib6_info___35 * (*fib6_table_lookup)(struct net___125 *, struct fib6_table___35 *, int, struct flowi6 *, int);
	struct fib6_info___35 * (*fib6_multipath_select)(const struct net___125 *, struct fib6_info___35 *, struct flowi6 *, int, const struct sk_buff___115 *, int);
	u32 (*ip6_mtu_from_fib6)(struct fib6_info___35 *, struct in6_addr *, struct in6_addr *);
	void (*udpv6_encap_enable)();
	void (*ndisc_send_na)(struct net_device___114 *, const struct in6_addr *, const struct in6_addr *, bool, bool, bool, bool);
	struct neigh_table___94 *nd_tbl;
};

struct ipv6_bpf_stub___24 {
	int (*inet6_bind)(struct sock___94 *, struct sockaddr *, int, bool, bool);
	struct sock___94 * (*udp6_lib_lookup)(struct net___125 *, const struct in6_addr *, __be16, const struct in6_addr *, __be16, int, int, struct udp_table *, struct sk_buff___115 *);
};

struct xfrm_replay___27 {
	void (*advance)(struct xfrm_state___27 *, __be32);
	int (*check)(struct xfrm_state___27 *, struct sk_buff___115 *, __be32);
	int (*recheck)(struct xfrm_state___27 *, struct sk_buff___115 *, __be32);
	void (*notify)(struct xfrm_state___27 *, int);
	int (*overflow)(struct xfrm_state___27 *, struct sk_buff___115 *);
};

struct xfrm_type___27 {
	char *description;
	struct module___395 *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___27 *);
	void (*destructor)(struct xfrm_state___27 *);
	int (*input)(struct xfrm_state___27 *, struct sk_buff___115 *);
	int (*output)(struct xfrm_state___27 *, struct sk_buff___115 *);
	int (*reject)(struct xfrm_state___27 *, struct sk_buff___115 *, const struct flowi *);
	int (*hdr_offset)(struct xfrm_state___27 *, struct sk_buff___115 *, u8 **);
	u32 (*get_mtu)(struct xfrm_state___27 *, int);
};

struct xfrm_state_afinfo___27;

struct xfrm_mode___27 {
	int (*input2)(struct xfrm_state___27 *, struct sk_buff___115 *);
	int (*input)(struct xfrm_state___27 *, struct sk_buff___115 *);
	int (*output2)(struct xfrm_state___27 *, struct sk_buff___115 *);
	int (*output)(struct xfrm_state___27 *, struct sk_buff___115 *);
	struct sk_buff___115 * (*gso_segment)(struct xfrm_state___27 *, struct sk_buff___115 *, netdev_features_t);
	void (*xmit)(struct xfrm_state___27 *, struct sk_buff___115 *);
	struct xfrm_state_afinfo___27 *afinfo;
	struct module___395 *owner;
	unsigned int encap;
	int flags;
};

struct xfrm_type_offload___27 {
	char *description;
	struct module___395 *owner;
	u8 proto;
	void (*encap)(struct xfrm_state___27 *, struct sk_buff___115 *);
	int (*input_tail)(struct xfrm_state___27 *, struct sk_buff___115 *);
	int (*xmit)(struct xfrm_state___27 *, struct sk_buff___115 *, netdev_features_t);
};

struct xfrm_state_afinfo___27 {
	unsigned int family;
	unsigned int proto;
	__be16 eth_proto;
	struct module___395 *owner;
	const struct xfrm_type___27 *type_map[256];
	const struct xfrm_type_offload___27 *type_offload_map[256];
	struct xfrm_mode___27 *mode_map[5];
	int (*init_flags)(struct xfrm_state___27 *);
	void (*init_tempsel)(struct xfrm_selector *, const struct flowi *);
	void (*init_temprop)(struct xfrm_state___27 *, const struct xfrm_tmpl *, const xfrm_address_t *, const xfrm_address_t *);
	int (*tmpl_sort)(struct xfrm_tmpl **, struct xfrm_tmpl **, int);
	int (*state_sort)(struct xfrm_state___27 **, struct xfrm_state___27 **, int);
	int (*output)(struct net___125 *, struct sock___94 *, struct sk_buff___115 *);
	int (*output_finish)(struct sock___94 *, struct sk_buff___115 *);
	int (*extract_input)(struct xfrm_state___27 *, struct sk_buff___115 *);
	int (*extract_output)(struct xfrm_state___27 *, struct sk_buff___115 *);
	int (*transport_finish)(struct sk_buff___115 *, int);
	void (*local_error)(struct sk_buff___115 *, u32);
};

typedef struct rt6_info___35 * (*pol_lookup_t)(struct net___125 *, struct fib6_table___35 *, struct flowi6 *, const struct sk_buff___115 *, int);

struct fib6_rule {
	struct fib_rule___94 common;
	struct rt6key src;
	struct rt6key dst;
	u8 tclass;
};

struct calipso_doi;

struct netlbl_calipso_ops {
	int (*doi_add)(struct calipso_doi *, struct netlbl_audit *);
	void (*doi_free)(struct calipso_doi *);
	int (*doi_remove)(u32, struct netlbl_audit *);
	struct calipso_doi * (*doi_getdef)(u32);
	void (*doi_putdef)(struct calipso_doi *);
	int (*doi_walk)(u32 *, int (*)(struct calipso_doi *, void *), void *);
	int (*sock_getattr)(struct sock___81 *, struct netlbl_lsm_secattr *);
	int (*sock_setattr)(struct sock___81 *, const struct calipso_doi *, const struct netlbl_lsm_secattr *);
	void (*sock_delattr)(struct sock___81 *);
	int (*req_setattr)(struct request_sock___65 *, const struct calipso_doi *, const struct netlbl_lsm_secattr *);
	void (*req_delattr)(struct request_sock___65 *);
	int (*opt_getattr)(const unsigned char *, struct netlbl_lsm_secattr *);
	unsigned char * (*skbuff_optptr)(const struct sk_buff___102 *);
	int (*skbuff_setattr)(struct sk_buff___102 *, const struct calipso_doi *, const struct netlbl_lsm_secattr *);
	int (*skbuff_delattr)(struct sk_buff___102 *);
	void (*cache_invalidate)();
	int (*cache_add)(const unsigned char *, const struct netlbl_lsm_secattr *);
};

struct calipso_doi {
	u32 doi;
	u32 type;
	refcount_t refcount;
	struct list_head list;
	struct callback_head rcu;
};

struct calipso_map_cache_bkt {
	spinlock_t lock;
	u32 size;
	struct list_head list;
};

struct calipso_map_cache_entry {
	u32 hash;
	unsigned char *key;
	size_t key_len;
	struct netlbl_lsm_cache *lsm_data;
	u32 activity;
	struct list_head list;
};

enum {
	IP6_FH_F_FRAG = 1,
	IP6_FH_F_AUTH = 2,
	IP6_FH_F_SKIP_RH = 4,
};

typedef void ip6_icmp_send_t(struct sk_buff___115 *, u8, u8, __u32, const struct in6_addr *);

struct sockaddr_pkt {
	short unsigned int spkt_family;
	unsigned char spkt_device[14];
	__be16 spkt_protocol;
};

struct sockaddr_ll {
	short unsigned int sll_family;
	__be16 sll_protocol;
	int sll_ifindex;
	short unsigned int sll_hatype;
	unsigned char sll_pkttype;
	unsigned char sll_halen;
	unsigned char sll_addr[8];
};

struct tpacket_stats {
	unsigned int tp_packets;
	unsigned int tp_drops;
};

struct tpacket_stats_v3 {
	unsigned int tp_packets;
	unsigned int tp_drops;
	unsigned int tp_freeze_q_cnt;
};

struct tpacket_rollover_stats {
	__u64 tp_all;
	__u64 tp_huge;
	__u64 tp_failed;
};

union tpacket_stats_u {
	struct tpacket_stats stats1;
	struct tpacket_stats_v3 stats3;
};

struct tpacket_auxdata {
	__u32 tp_status;
	__u32 tp_len;
	__u32 tp_snaplen;
	__u16 tp_mac;
	__u16 tp_net;
	__u16 tp_vlan_tci;
	__u16 tp_vlan_tpid;
};

struct tpacket_hdr {
	long unsigned int tp_status;
	unsigned int tp_len;
	unsigned int tp_snaplen;
	short unsigned int tp_mac;
	short unsigned int tp_net;
	unsigned int tp_sec;
	unsigned int tp_usec;
};

struct tpacket2_hdr {
	__u32 tp_status;
	__u32 tp_len;
	__u32 tp_snaplen;
	__u16 tp_mac;
	__u16 tp_net;
	__u32 tp_sec;
	__u32 tp_nsec;
	__u16 tp_vlan_tci;
	__u16 tp_vlan_tpid;
	__u8 tp_padding[4];
};

struct tpacket_hdr_variant1 {
	__u32 tp_rxhash;
	__u32 tp_vlan_tci;
	__u16 tp_vlan_tpid;
	__u16 tp_padding;
};

struct tpacket3_hdr {
	__u32 tp_next_offset;
	__u32 tp_sec;
	__u32 tp_nsec;
	__u32 tp_snaplen;
	__u32 tp_len;
	__u32 tp_status;
	__u16 tp_mac;
	__u16 tp_net;
	union {
		struct tpacket_hdr_variant1 hv1;
	};
	__u8 tp_padding[8];
};

struct tpacket_bd_ts {
	unsigned int ts_sec;
	union {
		unsigned int ts_usec;
		unsigned int ts_nsec;
	};
};

struct tpacket_hdr_v1 {
	__u32 block_status;
	__u32 num_pkts;
	__u32 offset_to_first_pkt;
	__u32 blk_len;
	__u64 seq_num;
	struct tpacket_bd_ts ts_first_pkt;
	struct tpacket_bd_ts ts_last_pkt;
};

union tpacket_bd_header_u {
	struct tpacket_hdr_v1 bh1;
};

struct tpacket_block_desc {
	__u32 version;
	__u32 offset_to_priv;
	union tpacket_bd_header_u hdr;
};

enum tpacket_versions {
	TPACKET_V1 = 0,
	TPACKET_V2 = 1,
	TPACKET_V3 = 2,
};

struct tpacket_req {
	unsigned int tp_block_size;
	unsigned int tp_block_nr;
	unsigned int tp_frame_size;
	unsigned int tp_frame_nr;
};

struct tpacket_req3 {
	unsigned int tp_block_size;
	unsigned int tp_block_nr;
	unsigned int tp_frame_size;
	unsigned int tp_frame_nr;
	unsigned int tp_retire_blk_tov;
	unsigned int tp_sizeof_priv;
	unsigned int tp_feature_req_word;
};

union tpacket_req_u {
	struct tpacket_req req;
	struct tpacket_req3 req3;
};

typedef struct poll_table_struct___293 poll_table___46;

struct virtio_net_hdr {
	__u8 flags;
	__u8 gso_type;
	__virtio16 hdr_len;
	__virtio16 gso_size;
	__virtio16 csum_start;
	__virtio16 csum_offset;
};

struct packet_mclist {
	struct packet_mclist *next;
	int ifindex;
	int count;
	short unsigned int type;
	short unsigned int alen;
	unsigned char addr[32];
};

struct pgv;

struct tpacket_kbdq_core {
	struct pgv *pkbdq;
	unsigned int feature_req_word;
	unsigned int hdrlen;
	unsigned char reset_pending_on_curr_blk;
	unsigned char delete_blk_timer;
	short unsigned int kactive_blk_num;
	short unsigned int blk_sizeof_priv;
	short unsigned int last_kactive_blk_num;
	char *pkblk_start;
	char *pkblk_end;
	int kblk_size;
	unsigned int max_frame_len;
	unsigned int knum_blocks;
	uint64_t knxt_seq_num;
	char *prev;
	char *nxt_offset;
	struct sk_buff___100 *skb;
	atomic_t blk_fill_in_prog;
	short unsigned int retire_blk_tov;
	short unsigned int version;
	long unsigned int tov_in_jiffies;
	struct timer_list retire_blk_timer;
};

struct pgv {
	char *buffer;
};

struct packet_ring_buffer {
	struct pgv *pg_vec;
	unsigned int head;
	unsigned int frames_per_block;
	unsigned int frame_size;
	unsigned int frame_max;
	unsigned int pg_vec_order;
	unsigned int pg_vec_pages;
	unsigned int pg_vec_len;
	unsigned int *pending_refcnt;
	struct tpacket_kbdq_core prb_bdqc;
};

struct packet_fanout {
	possible_net_t___101 net;
	unsigned int num_members;
	u16 id;
	u8 type;
	u8 flags;
	union {
		atomic_t rr_cur;
		struct bpf_prog___89 *bpf_prog;
	};
	struct list_head list;
	struct sock___79 *arr[256];
	spinlock_t lock;
	refcount_t sk_ref;
	long: 64;
	long: 64;
	struct packet_type___4 prot_hook;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct packet_rollover {
	int sock;
	atomic_long_t num;
	atomic_long_t num_huge;
	atomic_long_t num_failed;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 history[16];
};

struct packet_sock {
	struct sock___79 sk;
	struct packet_fanout *fanout;
	union tpacket_stats_u stats;
	struct packet_ring_buffer rx_ring;
	struct packet_ring_buffer tx_ring;
	int copy_thresh;
	spinlock_t bind_lock;
	struct mutex pg_vec_lock;
	unsigned int running;
	unsigned int auxdata: 1;
	unsigned int origdev: 1;
	unsigned int has_vnet_hdr: 1;
	unsigned int tp_loss: 1;
	unsigned int tp_tx_has_off: 1;
	int pressure;
	int ifindex;
	__be16 num;
	struct packet_rollover *rollover;
	struct packet_mclist *mclist;
	atomic_t mapped;
	enum tpacket_versions tp_version;
	unsigned int tp_hdrlen;
	unsigned int tp_reserve;
	unsigned int tp_tstamp;
	struct net_device___99 *cached_dev;
	int (*xmit)(struct sk_buff___100 *);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct packet_type___4 prot_hook;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct packet_mreq_max {
	int mr_ifindex;
	short unsigned int mr_type;
	short unsigned int mr_alen;
	unsigned char mr_address[32];
};

union tpacket_uhdr {
	struct tpacket_hdr *h1;
	struct tpacket2_hdr *h2;
	struct tpacket3_hdr *h3;
	void *raw;
};

struct packet_skb_cb {
	union {
		struct sockaddr_pkt pkt;
		union {
			unsigned int origlen;
			struct sockaddr_ll ll;
		};
	} sa;
};

struct strparser___2;

struct strp_callbacks___2 {
	int (*parse_msg)(struct strparser___2 *, struct sk_buff___115 *);
	void (*rcv_msg)(struct strparser___2 *, struct sk_buff___115 *);
	int (*read_sock_done)(struct strparser___2 *, int);
	void (*abort_parser)(struct strparser___2 *, int);
	void (*lock)(struct strparser___2 *);
	void (*unlock)(struct strparser___2 *);
};

struct strparser___2 {
	struct sock___94 *sk;
	u32 stopped: 1;
	u32 paused: 1;
	u32 aborted: 1;
	u32 interrupted: 1;
	u32 unrecov_intr: 1;
	struct sk_buff___115 **skb_nextp;
	struct sk_buff___115 *skb_head;
	unsigned int need_bytes;
	struct delayed_work msg_timer_work;
	struct work_struct work;
	struct strp_stats stats;
	struct strp_callbacks___2 cb;
};

struct strp_msg {
	int full_len;
	int offset;
};

struct _strp_msg {
	struct strp_msg strp;
	int accum_len;
};

struct vlan_group {
	unsigned int nr_vlan_devs;
	struct hlist_node hlist;
	struct net_device___114 **vlan_devices_arrays[16];
};

struct vlan_info {
	struct net_device___114 *real_dev;
	struct vlan_group grp;
	struct list_head vid_list;
	unsigned int nr_vids;
	struct callback_head rcu;
};

typedef struct sk_buff___115 ** (*gro_receive_t___3)(struct sk_buff___115 **, struct sk_buff___115 *);

enum vlan_flags {
	VLAN_FLAG_REORDER_HDR = 1,
	VLAN_FLAG_GVRP = 2,
	VLAN_FLAG_LOOSE_BINDING = 4,
	VLAN_FLAG_MVRP = 8,
};

struct vlan_priority_tci_mapping {
	u32 priority;
	u16 vlan_qos;
	struct vlan_priority_tci_mapping *next;
};

struct vlan_dev_priv {
	unsigned int nr_ingress_mappings;
	u32 ingress_priority_map[8];
	unsigned int nr_egress_mappings;
	struct vlan_priority_tci_mapping *egress_priority_map[16];
	__be16 vlan_proto;
	u16 vlan_id;
	u16 flags;
	struct net_device___114 *real_dev;
	unsigned char real_dev_addr[6];
	struct proc_dir_entry *dent;
	struct vlan_pcpu_stats *vlan_pcpu_stats;
	struct netpoll___4 *netpoll;
	unsigned int nest_level;
};

enum vlan_protos {
	VLAN_PROTO_8021Q = 0,
	VLAN_PROTO_8021AD = 1,
	VLAN_PROTO_NUM = 2,
};

struct vlan_vid_info {
	struct list_head list;
	__be16 proto;
	u16 vid;
	int refcount;
};

struct module___396;

struct file___470;

struct kiocb___470;

struct iov_iter___237;

struct poll_table_struct___309;

struct vm_area_struct___471;

struct inode___470;

struct file_lock___470;

struct page___471;

struct pipe_inode_info___151;

struct seq_file___409;

struct file_operations___470 {
	struct module___396 *owner;
	loff_t (*llseek)(struct file___470 *, loff_t, int);
	ssize_t (*read)(struct file___470 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___470 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___470 *, struct iov_iter___237 *);
	ssize_t (*write_iter)(struct kiocb___470 *, struct iov_iter___237 *);
	int (*iopoll)(struct kiocb___470 *, bool);
	int (*iterate)(struct file___470 *, struct dir_context *);
	int (*iterate_shared)(struct file___470 *, struct dir_context *);
	__poll_t (*poll)(struct file___470 *, struct poll_table_struct___309 *);
	long int (*unlocked_ioctl)(struct file___470 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___470 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___470 *, struct vm_area_struct___471 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___470 *, struct file___470 *);
	int (*flush)(struct file___470 *, fl_owner_t);
	int (*release)(struct inode___470 *, struct file___470 *);
	int (*fsync)(struct file___470 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___470 *, int);
	int (*lock)(struct file___470 *, int, struct file_lock___470 *);
	ssize_t (*sendpage)(struct file___470 *, struct page___471 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___470 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___470 *, int, struct file_lock___470 *);
	ssize_t (*splice_write)(struct pipe_inode_info___151 *, struct file___470 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___470 *, loff_t *, struct pipe_inode_info___151 *, size_t, unsigned int);
	int (*setlease)(struct file___470 *, long int, struct file_lock___470 **, void **);
	long int (*fallocate)(struct file___470 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___409 *, struct file___470 *);
	ssize_t (*copy_file_range)(struct file___470 *, loff_t, struct file___470 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___470 *, loff_t, struct file___470 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___470 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___471 {
	u64 seqnum;
	struct vm_area_struct___471 *vmas[4];
};

struct page_frag___471 {
	struct page___471 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___471;

struct mem_cgroup___203;

struct pid___264;

struct cred___438;

struct nsproxy___365;

struct signal_struct___345;

struct bio_list___260;

struct backing_dev_info___260;

struct css_set___319;

struct vm_struct___374;

struct task_struct___472 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___472 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___471 *mm;
	struct mm_struct___471 *active_mm;
	struct vmacache___471 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___472 *real_parent;
	struct task_struct___472 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___472 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___203 *active_memcg;
	long int rh_reserved2;
	struct pid___264 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___264 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___264 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___438 *ptracer_cred;
	const struct cred___438 *real_cred;
	const struct cred___438 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___365 *nsproxy;
	struct signal_struct___345 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___472 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___260 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___260 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___319 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___151 *splice_pipe;
	struct page_frag___471 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___203 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___472 *oom_reaper_list;
	struct vm_struct___374 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___157 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___471 *pgtable_t___471;

struct address_space___470;

struct dev_pagemap___458;

struct page___471 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___470 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___471 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___471 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___471 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___458 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___203 *mem_cgroup;
};

struct pglist_data___471;

struct lruvec___471 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___471 *pgdat;
};

struct zone___471 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___471 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___471 {
	struct zone___471 *zone;
	int zone_idx;
};

struct zonelist___471 {
	struct zoneref___471 _zonerefs[25];
};

struct pglist_data___471 {
	struct zone___471 node_zones[3];
	struct zonelist___471 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___472 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___472 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___471 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___472 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___472 *owner;
};

struct secondary_data___472 {
	void *stack;
	struct task_struct___472 *task;
	long int status;
};

struct blocking_notifier_head___471 {
	struct rw_semaphore___472 rwsem;
	struct notifier_block *head;
};

struct cgroup___319;

struct cgroup_subsys___319;

struct cgroup_subsys_state___319 {
	struct cgroup___319 *cgroup;
	struct cgroup_subsys___319 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___319 *parent;
};

struct kernfs_node___465;

struct cgroup_file___319 {
	struct kernfs_node___465 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___203;

struct mem_cgroup___203 {
	struct cgroup_subsys_state___319 css;
	struct mem_cgroup_id___16 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___319 events_file;
	struct cgroup_file___319 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___472 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___203 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___264;

struct upid___264 {
	int nr;
	struct pid_namespace___264 *ns;
};

struct dentry___470;

struct user_namespace___335;

struct ucounts___335;

struct pid_namespace___264 {
	struct kref kref;
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___472 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___264 *parent;
	struct vfsmount *proc_mnt;
	struct dentry___470 *proc_self;
	struct dentry___470 *proc_thread_self;
	struct fs_pin *bacct;
	struct user_namespace___335 *user_ns;
	struct ucounts___335 *ucounts;
	struct work_struct proc_work;
	kgid_t pid_gid;
	int hide_pid;
	int reboot;
	struct ns_common___29 ns;
};

struct pid___264 {
	atomic_t count;
	unsigned int level;
	struct hlist_head tasks[4];
	struct callback_head rcu;
	struct upid___264 numbers[1];
};

struct key___438;

struct user_namespace___335 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___335 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___29 ns;
	long unsigned int flags;
	struct key___438 *persistent_keyring_register;
	struct rw_semaphore___472 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___335 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct user_struct___438 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___438 *uid_keyring;
	struct key___438 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___458;

struct vm_area_struct___471 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___471 *vm_next;
	struct vm_area_struct___471 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___471 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___458 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___470 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___471;

struct mm_struct___471 {
	struct {
		struct vm_area_struct___471 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___470 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___472 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___471 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___472 *owner;
		struct user_namespace___335 *user_ns;
		struct file___470 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___471 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cred___438 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___438 *session_keyring;
	struct key___438 *process_keyring;
	struct key___438 *thread_keyring;
	struct key___438 *request_key_auth;
	void *security;
	struct user_struct___438 *user;
	struct user_namespace___335 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___126;

struct cgroup_namespace___319;

struct nsproxy___365 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___264 *pid_ns_for_children;
	struct net___126 *net_ns;
	struct cgroup_namespace___319 *cgroup_ns;
};

struct tty_struct___38;

struct signal_struct___345 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___472 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___472 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___264 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___264 *tty_old_pgrp;
	int leader;
	struct tty_struct___38 *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___471 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___264 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___260;

struct bio_list___260 {
	struct bio___260 *head;
	struct bio___260 *tail;
};

struct bdi_writeback_congested___260;

struct bdi_writeback___260 {
	struct backing_dev_info___260 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___260 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___319 *memcg_css;
	struct cgroup_subsys_state___319 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___438;

struct backing_dev_info___260 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___260 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___438 *dev;
	struct device___438 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___470 *debug_dir;
	struct dentry___470 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___319 {
	struct cgroup_subsys_state___319 *subsys[13];
	refcount_t refcount;
	struct css_set___319 *dom_cset;
	struct cgroup___319 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___319 *mg_src_cgrp;
	struct cgroup___319 *mg_dst_cgrp;
	struct css_set___319 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___470;

struct pipe_buffer___151;

struct pipe_inode_info___151 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___471 *tmp_page;
	struct fasync_struct___470 *fasync_readers;
	struct fasync_struct___470 *fasync_writers;
	struct pipe_buffer___151 *bufs;
	struct user_struct___438 *user;
};

struct vm_struct___374 {
	struct vm_struct___374 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___471 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___357 {
	struct task_struct___472 task;
	long unsigned int stack[8192];
};

struct address_space_operations___470;

struct address_space___470 {
	struct inode___470 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___472 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___470 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___458)(struct vm_area_struct___471 *, long unsigned int, const struct page___471 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___458)(struct page___471 *, void *);

struct dev_pagemap___458 {
	dev_page_fault_t___458 page_fault;
	dev_page_free_t___458 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___438 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___471 {
	struct vfsmount *mnt;
	struct dentry___470 *dentry;
};

struct fown_struct___264 {
	rwlock_t lock;
	struct pid___264 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___470 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___471 f_path;
	struct inode___470 *f_inode;
	const struct file_operations___470 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___264 f_owner;
	const struct cred___438 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___470 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___458;

struct vm_operations_struct___458 {
	void (*open)(struct vm_area_struct___471 *);
	void (*close)(struct vm_area_struct___471 *);
	int (*split)(struct vm_area_struct___471 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___471 *);
	vm_fault_t (*fault)(struct vm_fault___458 *);
	vm_fault_t (*huge_fault)(struct vm_fault___458 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___458 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___471 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___458 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___458 *);
	int (*access)(struct vm_area_struct___471 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___471 *);
	int (*set_policy)(struct vm_area_struct___471 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___471 *, long unsigned int);
	struct page___471 * (*find_special_page)(struct vm_area_struct___471 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___471 {
	struct task_struct___472 *task;
	struct core_thread___471 *next;
};

struct core_state___471 {
	atomic_t nr_threads;
	struct core_thread___471 dumper;
	struct completion startup;
};

struct vm_fault___458 {
	struct vm_area_struct___471 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___471 *cow_page;
	struct mem_cgroup___203 *memcg;
	struct page___471 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___471 prealloc_pte;
};

struct kset___457;

struct kobj_type___457;

struct kobject___458 {
	const char *name;
	struct list_head entry;
	struct kobject___458 *parent;
	struct kset___457 *kset;
	struct kobj_type___457 *ktype;
	struct kernfs_node___465 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___396 {
	struct kobject___458 kobj;
	struct module___396 *mod;
	struct kobject___458 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___396 {
	struct module___396 *mod;
	struct latch_tree_node node;
};

struct module_layout___396 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___396 mtn;
};

struct module_attribute___396;

struct kernel_param___396;

struct module___396 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___396 mkobj;
	struct module_attribute___396 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___458 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___396 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___396 core_layout;
	struct module_layout___396 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide53;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide54;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bio_vec___262 {
	struct page___471 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___237 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___262 *bvec;
		struct pipe_inode_info___151 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct msghdr___98 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___237 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___470 *msg_iocb;
};

struct kiocb___470 {
	struct file___470 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___470 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

typedef int (*key_restrict_link_func_t___439)(struct key___438 *, const struct key_type *, const union key_payload *, struct key___438 *);

struct key_restriction___438;

struct key___438 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___472 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___438 *restrict_link;
};

struct key_restriction___438 {
	key_restrict_link_func_t___439 check;
	struct key___438 *key;
	struct key_type *keytype;
};

struct tty_driver___38;

struct tty_operations___38;

struct tty_ldisc___38;

struct tty_port___38;

struct tty_struct___38 {
	int magic;
	struct kref kref;
	struct device___438 *dev;
	struct tty_driver___38 *driver;
	const struct tty_operations___38 *ops;
	int index;
	struct ld_semaphore ldisc_sem;
	struct tty_ldisc___38 *ldisc;
	struct mutex atomic_write_lock;
	struct mutex legacy_mutex;
	struct mutex throttle_mutex;
	struct rw_semaphore___472 termios_rwsem;
	struct mutex winsize_mutex;
	spinlock_t ctrl_lock;
	spinlock_t flow_lock;
	struct ktermios termios;
	struct ktermios termios_locked;
	struct termiox *termiox;
	char name[64];
	struct pid___264 *pgrp;
	struct pid___264 *session;
	long unsigned int flags;
	int count;
	struct winsize winsize;
	long unsigned int stopped: 1;
	long unsigned int flow_stopped: 1;
	int: 30;
	long unsigned int unused: 62;
	int hw_stopped;
	long unsigned int ctrl_status: 8;
	long unsigned int packet: 1;
	int: 23;
	long unsigned int unused_ctrl: 55;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___38 *link;
	struct fasync_struct___470 *fasync;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	spinlock_t files_lock;
	struct list_head tty_files;
	int closing;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___38 *port;
};

struct shrink_control___203 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___203 *memcg;
};

struct shrinker___203 {
	long unsigned int (*count_objects)(struct shrinker___203 *, struct shrink_control___203 *);
	long unsigned int (*scan_objects)(struct shrinker___203 *, struct shrink_control___203 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct dev_pm_info___438 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___438 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___438;

struct bus_type___438;

struct device_driver___438;

struct dev_pm_domain___438;

struct dma_map_ops___210;

struct fwnode_handle___358;

struct class___438;

struct attribute_group___435;

struct device___438 {
	struct device___438 *parent;
	struct device_private *p;
	struct kobject___458 kobj;
	const char *init_name;
	const struct device_type___438 *type;
	struct mutex mutex;
	struct bus_type___438 *bus;
	struct device_driver___438 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___438 power;
	struct dev_pm_domain___438 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___210 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___358 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___438 *class;
	const struct attribute_group___435 **groups;
	void (*release)(struct device___438 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dentry_operations___470;

struct super_block___470;

struct dentry___470 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___470 *d_parent;
	struct qstr d_name;
	struct inode___470 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___470 *d_op;
	struct super_block___470 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___470;

struct block_device___470;

struct cdev___101;

struct inode___470 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___470 *i_op;
	struct super_block___470 *i_sb;
	struct address_space___470 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___472 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___260 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___470 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___470 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___151 *i_pipe;
		struct block_device___470 *i_bdev;
		struct cdev___101 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___470 {
	int (*d_revalidate)(struct dentry___470 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___470 *, unsigned int);
	int (*d_hash)(const struct dentry___470 *, struct qstr *);
	int (*d_compare)(const struct dentry___470 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___470 *);
	int (*d_init)(struct dentry___470 *);
	void (*d_release)(struct dentry___470 *);
	void (*d_prune)(struct dentry___470 *);
	void (*d_iput)(struct dentry___470 *, struct inode___470 *);
	char * (*d_dname)(struct dentry___470 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___471 *);
	int (*d_manage)(const struct path___471 *, bool);
	struct dentry___470 * (*d_real)(struct dentry___470 *, const struct inode___470 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___470;

struct mem_dqinfo___470 {
	struct quota_format_type___470 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___470;

struct quota_info___470 {
	unsigned int flags;
	struct rw_semaphore___472 dqio_sem;
	struct inode___470 *files[3];
	struct mem_dqinfo___470 info[3];
	const struct quota_format_ops___470 *ops[3];
};

struct rcuwait___470 {
	struct task_struct___472 *task;
};

struct percpu_rw_semaphore___470 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___472 rw_sem;
	struct rcuwait___470 writer;
	int readers_block;
};

struct sb_writers___470 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___470 rw_sem[3];
};

struct file_system_type___470;

struct super_operations___470;

struct dquot_operations___470;

struct quotactl_ops___470;

struct super_block___470 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___470 *s_type;
	const struct super_operations___470 *s_op;
	const struct dquot_operations___470 *dq_op;
	const struct quotactl_ops___470 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___470 *s_root;
	struct rw_semaphore___472 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___470 *s_bdev;
	struct backing_dev_info___260 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___470 s_dquot;
	struct sb_writers___470 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___470 *s_d_op;
	int cleancache_poolid;
	struct shrinker___203 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___335 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct iattr___470 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___470 *ia_file;
};

struct dquot___470 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___470 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___470 {
	int qf_fmt_id;
	const struct quota_format_ops___470 *qf_ops;
	struct module___396 *qf_owner;
	struct quota_format_type___470 *qf_next;
};

struct quota_format_ops___470 {
	int (*check_quota_file)(struct super_block___470 *, int);
	int (*read_file_info)(struct super_block___470 *, int);
	int (*write_file_info)(struct super_block___470 *, int);
	int (*free_file_info)(struct super_block___470 *, int);
	int (*read_dqblk)(struct dquot___470 *);
	int (*commit_dqblk)(struct dquot___470 *);
	int (*release_dqblk)(struct dquot___470 *);
	int (*get_next_id)(struct super_block___470 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___470 {
	int (*write_dquot)(struct dquot___470 *);
	struct dquot___470 * (*alloc_dquot)(struct super_block___470 *, int);
	void (*destroy_dquot)(struct dquot___470 *);
	int (*acquire_dquot)(struct dquot___470 *);
	int (*release_dquot)(struct dquot___470 *);
	int (*mark_dirty)(struct dquot___470 *);
	int (*write_info)(struct super_block___470 *, int);
	qsize_t * (*get_reserved_space)(struct inode___470 *);
	int (*get_projid)(struct inode___470 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___470 *, qsize_t *);
	int (*get_next_id)(struct super_block___470 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___470 {
	int (*quota_on)(struct super_block___470 *, int, int, const struct path___471 *);
	int (*quota_off)(struct super_block___470 *, int);
	int (*quota_enable)(struct super_block___470 *, unsigned int);
	int (*quota_disable)(struct super_block___470 *, unsigned int);
	int (*quota_sync)(struct super_block___470 *, int);
	int (*set_info)(struct super_block___470 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___470 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___470 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___470 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___470 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___470 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___223;

struct address_space_operations___470 {
	int (*writepage)(struct page___471 *, struct writeback_control___223 *);
	int (*readpage)(struct file___470 *, struct page___471 *);
	int (*writepages)(struct address_space___470 *, struct writeback_control___223 *);
	int (*set_page_dirty)(struct page___471 *);
	int (*readpages)(struct file___470 *, struct address_space___470 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___470 *, struct address_space___470 *, loff_t, unsigned int, unsigned int, struct page___471 **, void **);
	int (*write_end)(struct file___470 *, struct address_space___470 *, loff_t, unsigned int, unsigned int, struct page___471 *, void *);
	sector_t (*bmap)(struct address_space___470 *, sector_t);
	void (*invalidatepage)(struct page___471 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___471 *, gfp_t);
	void (*freepage)(struct page___471 *);
	ssize_t (*direct_IO)(struct kiocb___470 *, struct iov_iter___237 *);
	int (*migratepage)(struct address_space___470 *, struct page___471 *, struct page___471 *, enum migrate_mode);
	bool (*isolate_page)(struct page___471 *, isolate_mode_t);
	void (*putback_page)(struct page___471 *);
	int (*launder_page)(struct page___471 *);
	int (*is_partially_uptodate)(struct page___471 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___471 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___470 *, struct page___471 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___470 *, sector_t *);
	void (*swap_deactivate)(struct file___470 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___223 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___260 *wb;
	struct inode___470 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___470 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___470 *bd_inode;
	struct super_block___470 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___470 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___260 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct cdev___101 {
	struct kobject___458 kobj;
	struct module___396 *owner;
	const struct file_operations___470 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___470 {
	struct dentry___470 * (*lookup)(struct inode___470 *, struct dentry___470 *, unsigned int);
	const char * (*get_link)(struct dentry___470 *, struct inode___470 *, struct delayed_call *);
	int (*permission)(struct inode___470 *, int);
	struct posix_acl * (*get_acl)(struct inode___470 *, int);
	int (*readlink)(struct dentry___470 *, char *, int);
	int (*create)(struct inode___470 *, struct dentry___470 *, umode_t, bool);
	int (*link)(struct dentry___470 *, struct inode___470 *, struct dentry___470 *);
	int (*unlink)(struct inode___470 *, struct dentry___470 *);
	int (*symlink)(struct inode___470 *, struct dentry___470 *, const char *);
	int (*mkdir)(struct inode___470 *, struct dentry___470 *, umode_t);
	int (*rmdir)(struct inode___470 *, struct dentry___470 *);
	int (*mknod)(struct inode___470 *, struct dentry___470 *, umode_t, dev_t);
	int (*rename)(struct inode___470 *, struct dentry___470 *, struct inode___470 *, struct dentry___470 *, unsigned int);
	int (*setattr)(struct dentry___470 *, struct iattr___470 *);
	int (*getattr)(const struct path___471 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___470 *, char *, size_t);
	int (*fiemap)(struct inode___470 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___470 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___470 *, struct dentry___470 *, struct file___470 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___470 *, struct dentry___470 *, umode_t);
	int (*set_acl)(struct inode___470 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___470 {
	void (*fl_copy_lock)(struct file_lock___470 *, struct file_lock___470 *);
	void (*fl_release_private)(struct file_lock___470 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___470;

struct file_lock___470 {
	struct file_lock___470 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___470 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___470 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___470 *fl_ops;
	const struct lock_manager_operations___470 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___470 {
	int (*lm_compare_owner)(struct file_lock___470 *, struct file_lock___470 *);
	long unsigned int (*lm_owner_key)(struct file_lock___470 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___470 *);
	int (*lm_grant)(struct file_lock___470 *, int);
	bool (*lm_break)(struct file_lock___470 *);
	int (*lm_change)(struct file_lock___470 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___470 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___470 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___470 *fa_next;
	struct file___470 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___470 {
	const char *name;
	int fs_flags;
	struct dentry___470 * (*mount)(struct file_system_type___470 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___470 *);
	struct module___396 *owner;
	struct file_system_type___470 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___470 {
	struct inode___470 * (*alloc_inode)(struct super_block___470 *);
	void (*destroy_inode)(struct inode___470 *);
	void (*dirty_inode)(struct inode___470 *, int);
	int (*write_inode)(struct inode___470 *, struct writeback_control___223 *);
	int (*drop_inode)(struct inode___470 *);
	void (*evict_inode)(struct inode___470 *);
	void (*put_super)(struct super_block___470 *);
	int (*sync_fs)(struct super_block___470 *, int);
	int (*freeze_super)(struct super_block___470 *);
	int (*freeze_fs)(struct super_block___470 *);
	int (*thaw_super)(struct super_block___470 *);
	int (*unfreeze_fs)(struct super_block___470 *);
	int (*statfs)(struct dentry___470 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___470 *, int *, char *);
	void (*umount_begin)(struct super_block___470 *);
	int (*show_options)(struct seq_file___409 *, struct dentry___470 *);
	int (*show_devname)(struct seq_file___409 *, struct dentry___470 *);
	int (*show_path)(struct seq_file___409 *, struct dentry___470 *);
	int (*show_stats)(struct seq_file___409 *, struct dentry___470 *);
	ssize_t (*quota_read)(struct super_block___470 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___470 *, int, const char *, size_t, loff_t);
	struct dquot___470 ** (*get_dquots)(struct inode___470 *);
	int (*bdev_try_to_free_page)(struct super_block___470 *, struct page___471 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___470 *, struct shrink_control___203 *);
	long int (*free_cached_objects)(struct super_block___470 *, struct shrink_control___203 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___319)(struct file___470 *, wait_queue_head_t *, struct poll_table_struct___309 *);

struct poll_table_struct___309 {
	poll_queue_proc___319 _qproc;
	__poll_t _key;
};

struct seq_operations___409;

struct seq_file___409 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___409 *op;
	int poll_event;
	const struct file___470 *file;
	void *private;
};

typedef void bio_end_io_t___260(struct bio___260 *);

struct bio_integrity_payload___260;

struct bio_set___260;

struct bio___260 {
	struct bio___260 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___260 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___260 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___262 *bi_io_vec;
	struct bio_set___260 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___262 bi_inline_vecs[0];
};

struct kobj_attribute___448 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___458 *, struct kobj_attribute___448 *, char *);
	ssize_t (*store)(struct kobject___458 *, struct kobj_attribute___448 *, const char *, size_t);
};

typedef void compound_page_dtor___458(struct page___471 *);

struct inet_frags___115;

struct netns_frags___115 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___115 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_rules_ops___95;

struct sock___95;

struct fib_notifier_ops___96;

struct netns_ipv4___115 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___95 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___95 *fibnl;
	struct sock___95 **icmp_sk;
	struct sock___95 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___95 **tcp_sk;
	struct netns_frags___115 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___95 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___96 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___96 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct dst_entry___95;

struct net_device___115;

struct sk_buff___116;

struct neighbour___95;

struct dst_ops___126 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___126 *);
	struct dst_entry___95 * (*check)(struct dst_entry___95 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___95 *);
	unsigned int (*mtu)(const struct dst_entry___95 *);
	u32 * (*cow_metrics)(struct dst_entry___95 *, long unsigned int);
	void (*destroy)(struct dst_entry___95 *);
	void (*ifdown)(struct dst_entry___95 *, struct net_device___115 *, int);
	struct dst_entry___95 * (*negative_advice)(struct dst_entry___95 *);
	void (*link_failure)(struct sk_buff___116 *);
	void (*update_pmtu)(struct dst_entry___95 *, struct sock___95 *, struct sk_buff___116 *, u32);
	void (*redirect)(struct dst_entry___95 *, struct sock___95 *, struct sk_buff___116 *);
	int (*local_out)(struct net___126 *, struct sock___95 *, struct sk_buff___116 *);
	struct neighbour___95 * (*neigh_lookup)(const struct dst_entry___95 *, struct sk_buff___116 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___95 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___126 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___115 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___126 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___95 *fib6_rules_ops;
	struct sock___95 **icmp_sk;
	struct sock___95 *ndisc_sk;
	struct sock___95 *tcp_sk;
	struct sock___95 *igmp_sk;
	struct sock___95 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___95 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___96 *notifier_ops;
	struct fib_notifier_ops___96 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___96 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___95 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___115 {
	struct netns_frags___115 frags;
};

struct netns_xfrm___126 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___95 *nlsk;
	struct sock___95 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___126 xfrm4_dst_ops;
	struct dst_ops___126 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___105;

struct net___126 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___335 *user_ns;
	struct ucounts___335 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___29 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___95 *rtnl;
	struct sock___95 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___115 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___115 ipv4;
	struct netns_ipv6___126 ipv6;
	struct netns_sctp___96 sctp;
	struct netns_nf___23 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___115 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___95 *nfnl;
	struct sock___95 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___126 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___95 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___105 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cgroup_namespace___319 {
	refcount_t count;
	struct ns_common___29 ns;
	struct user_namespace___335 *user_ns;
	struct ucounts___335 *ucounts;
	struct css_set___319 *root_cset;
};

struct ucounts___335 {
	struct hlist_node node;
	struct user_namespace___335 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct kernfs_root___464;

struct kernfs_elem_dir___464 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___464 *root;
};

struct kernfs_syscall_ops___464;

struct kernfs_root___464 {
	struct kernfs_node___465 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___464 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___464 {
	struct kernfs_node___465 *target_kn;
};

struct kernfs_ops___464;

struct kernfs_elem_attr___464 {
	const struct kernfs_ops___464 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___465 *notify_next;
};

struct kernfs_node___465 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___465 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___464 dir;
		struct kernfs_elem_symlink___464 symlink;
		struct kernfs_elem_attr___464 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___464;

struct kernfs_ops___464 {
	int (*open)(struct kernfs_open_file___464 *);
	void (*release)(struct kernfs_open_file___464 *);
	int (*seq_show)(struct seq_file___409 *, void *);
	void * (*seq_start)(struct seq_file___409 *, loff_t *);
	void * (*seq_next)(struct seq_file___409 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___409 *, void *);
	ssize_t (*read)(struct kernfs_open_file___464 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___464 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___464 *, struct vm_area_struct___471 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___464 *, struct poll_table_struct___309 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___464 {
	int (*remount_fs)(struct kernfs_root___464 *, int *, char *);
	int (*show_options)(struct seq_file___409 *, struct kernfs_root___464 *);
	int (*mkdir)(struct kernfs_node___465 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___465 *);
	int (*rename)(struct kernfs_node___465 *, struct kernfs_node___465 *, const char *);
	int (*show_path)(struct seq_file___409 *, struct kernfs_node___465 *, struct kernfs_root___464 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___464 {
	struct kernfs_node___465 *kn;
	struct file___470 *file;
	struct seq_file___409 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___458 *vm_ops;
};

struct kobj_ns_type_operations___95 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___95 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___126 *net;
} possible_net_t___117;

struct proto___95;

struct sock_common___95 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___95 *skc_prot;
	possible_net_t___117 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___95 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff_head___115 {
	struct sk_buff___116 *next;
	struct sk_buff___116 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___95;

struct socket_wq___96;

struct socket___97;

struct sock___95 {
	struct sock_common___95 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___115 sk_error_queue;
	struct sk_buff_head___115 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___116 *head;
		struct sk_buff___116 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___95 *sk_filter;
	union {
		struct socket_wq___96 *sk_wq;
		struct socket_wq___96 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___95 *sk_rx_dst;
	struct dst_entry___95 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___116 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___115 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___471 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___95 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___264 *sk_peer_pid;
	const struct cred___438 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___97 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___203 *sk_memcg;
	void (*sk_state_change)(struct sock___95 *);
	void (*sk_data_ready)(struct sock___95 *);
	void (*sk_write_space)(struct sock___95 *);
	void (*sk_error_report)(struct sock___95 *);
	int (*sk_backlog_rcv)(struct sock___95 *, struct sk_buff___116 *);
	struct sk_buff___116 * (*sk_validate_xmit_skb)(struct sock___95 *, struct net_device___115 *, struct sk_buff___116 *);
	void (*sk_destruct)(struct sock___95 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct bin_attribute___434;

struct attribute_group___435 {
	const char *name;
	umode_t (*is_visible)(struct kobject___458 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___458 *, struct bin_attribute___434 *, int);
	struct attribute **attrs;
	struct bin_attribute___434 **bin_attrs;
};

struct bin_attribute___434 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___470 *, struct kobject___458 *, struct bin_attribute___434 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___470 *, struct kobject___458 *, struct bin_attribute___434 *, char *, loff_t, size_t);
	int (*mmap)(struct file___470 *, struct kobject___458 *, struct bin_attribute___434 *, struct vm_area_struct___471 *);
};

struct sysfs_ops___457 {
	ssize_t (*show)(struct kobject___458 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___458 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___457;

struct kset___457 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___458 kobj;
	const struct kset_uevent_ops___457 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___457 {
	void (*release)(struct kobject___458 *);
	const struct sysfs_ops___457 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___95 * (*child_ns_type)(struct kobject___458 *);
	const void * (*namespace)(struct kobject___458 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___457 {
	int (* const filter)(struct kset___457 *, struct kobject___458 *);
	const char * (* const name)(struct kset___457 *, struct kobject___458 *);
	int (* const uevent)(struct kset___457 *, struct kobject___458 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___438 {
	int (*prepare)(struct device___438 *);
	void (*complete)(struct device___438 *);
	int (*suspend)(struct device___438 *);
	int (*resume)(struct device___438 *);
	int (*freeze)(struct device___438 *);
	int (*thaw)(struct device___438 *);
	int (*poweroff)(struct device___438 *);
	int (*restore)(struct device___438 *);
	int (*suspend_late)(struct device___438 *);
	int (*resume_early)(struct device___438 *);
	int (*freeze_late)(struct device___438 *);
	int (*thaw_early)(struct device___438 *);
	int (*poweroff_late)(struct device___438 *);
	int (*restore_early)(struct device___438 *);
	int (*suspend_noirq)(struct device___438 *);
	int (*resume_noirq)(struct device___438 *);
	int (*freeze_noirq)(struct device___438 *);
	int (*thaw_noirq)(struct device___438 *);
	int (*poweroff_noirq)(struct device___438 *);
	int (*restore_noirq)(struct device___438 *);
	int (*runtime_suspend)(struct device___438 *);
	int (*runtime_resume)(struct device___438 *);
	int (*runtime_idle)(struct device___438 *);
};

struct dev_pm_domain___438 {
	struct dev_pm_ops___438 ops;
	void (*detach)(struct device___438 *, bool);
	int (*activate)(struct device___438 *);
	void (*sync)(struct device___438 *);
	void (*dismiss)(struct device___438 *);
};

struct bus_type___438 {
	const char *name;
	const char *dev_name;
	struct device___438 *dev_root;
	const struct attribute_group___435 **bus_groups;
	const struct attribute_group___435 **dev_groups;
	const struct attribute_group___435 **drv_groups;
	int (*match)(struct device___438 *, struct device_driver___438 *);
	int (*uevent)(struct device___438 *, struct kobj_uevent_env *);
	int (*probe)(struct device___438 *);
	int (*remove)(struct device___438 *);
	void (*shutdown)(struct device___438 *);
	int (*online)(struct device___438 *);
	int (*offline)(struct device___438 *);
	int (*suspend)(struct device___438 *, pm_message_t);
	int (*resume)(struct device___438 *);
	int (*num_vf)(struct device___438 *);
	int (*dma_configure)(struct device___438 *);
	const struct dev_pm_ops___438 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___438 {
	const char *name;
	struct bus_type___438 *bus;
	struct module___396 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___438 *);
	int (*remove)(struct device___438 *);
	void (*shutdown)(struct device___438 *);
	int (*suspend)(struct device___438 *, pm_message_t);
	int (*resume)(struct device___438 *);
	const struct attribute_group___435 **groups;
	const struct dev_pm_ops___438 *pm;
	void (*coredump)(struct device___438 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___438 {
	const char *name;
	const struct attribute_group___435 **groups;
	int (*uevent)(struct device___438 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___438 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___438 *);
	const struct dev_pm_ops___438 *pm;
};

struct class___438 {
	const char *name;
	struct module___396 *owner;
	const struct attribute_group___435 **class_groups;
	const struct attribute_group___435 **dev_groups;
	struct kobject___458 *dev_kobj;
	int (*dev_uevent)(struct device___438 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___438 *, umode_t *);
	void (*class_release)(struct class___438 *);
	void (*dev_release)(struct device___438 *);
	int (*shutdown_pre)(struct device___438 *);
	const struct kobj_ns_type_operations___95 *ns_type;
	const void * (*namespace)(struct device___438 *);
	const struct dev_pm_ops___438 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___210 {
	void * (*alloc)(struct device___438 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___438 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___438 *, struct vm_area_struct___471 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___438 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___438 *, struct page___471 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___438 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___438 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___438 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___438 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___438 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___438 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___438 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___438 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___438 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___438 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___438 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___438 *, u64);
	u64 (*get_required_mask)(struct device___438 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___358;

struct fwnode_handle___358 {
	struct fwnode_handle___358 *secondary;
	const struct fwnode_operations___358 *ops;
};

struct seq_operations___409 {
	void * (*start)(struct seq_file___409 *, loff_t *);
	void (*stop)(struct seq_file___409 *, void *);
	void * (*next)(struct seq_file___409 *, void *, loff_t *);
	int (*show)(struct seq_file___409 *, void *);
};

struct tty_operations___38 {
	struct tty_struct___38 * (*lookup)(struct tty_driver___38 *, struct file___470 *, int);
	int (*install)(struct tty_driver___38 *, struct tty_struct___38 *);
	void (*remove)(struct tty_driver___38 *, struct tty_struct___38 *);
	int (*open)(struct tty_struct___38 *, struct file___470 *);
	void (*close)(struct tty_struct___38 *, struct file___470 *);
	void (*shutdown)(struct tty_struct___38 *);
	void (*cleanup)(struct tty_struct___38 *);
	int (*write)(struct tty_struct___38 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___38 *, unsigned char);
	void (*flush_chars)(struct tty_struct___38 *);
	int (*write_room)(struct tty_struct___38 *);
	int (*chars_in_buffer)(struct tty_struct___38 *);
	int (*ioctl)(struct tty_struct___38 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___38 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___38 *, struct ktermios *);
	void (*throttle)(struct tty_struct___38 *);
	void (*unthrottle)(struct tty_struct___38 *);
	void (*stop)(struct tty_struct___38 *);
	void (*start)(struct tty_struct___38 *);
	void (*hangup)(struct tty_struct___38 *);
	int (*break_ctl)(struct tty_struct___38 *, int);
	void (*flush_buffer)(struct tty_struct___38 *);
	void (*set_ldisc)(struct tty_struct___38 *);
	void (*wait_until_sent)(struct tty_struct___38 *, int);
	void (*send_xchar)(struct tty_struct___38 *, char);
	int (*tiocmget)(struct tty_struct___38 *);
	int (*tiocmset)(struct tty_struct___38 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___38 *, struct winsize *);
	int (*set_termiox)(struct tty_struct___38 *, struct termiox *);
	int (*get_icount)(struct tty_struct___38 *, struct serial_icounter_struct *);
	void (*show_fdinfo)(struct tty_struct___38 *, struct seq_file___409 *);
	int (*poll_init)(struct tty_driver___38 *, int, char *);
	int (*poll_get_char)(struct tty_driver___38 *, int);
	void (*poll_put_char)(struct tty_driver___38 *, int, char);
	int (*proc_show)(struct seq_file___409 *, void *);
};

struct tty_driver___38 {
	int magic;
	struct kref kref;
	struct cdev___101 **cdevs;
	struct module___396 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___38 *other;
	struct tty_struct___38 **ttys;
	struct tty_port___38 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___38 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___38;

struct tty_port_client_operations___38;

struct tty_port___38 {
	struct tty_bufhead buf;
	struct tty_struct___38 *tty;
	struct tty_struct___38 *itty;
	const struct tty_port_operations___38 *ops;
	const struct tty_port_client_operations___38 *client_ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	unsigned char low_latency: 1;
	struct mutex mutex;
	struct mutex buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
	void *client_data;
};

struct tty_ldisc_ops___38 {
	int magic;
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___38 *);
	void (*close)(struct tty_struct___38 *);
	void (*flush_buffer)(struct tty_struct___38 *);
	ssize_t (*read)(struct tty_struct___38 *, struct file___470 *, unsigned char *, size_t);
	ssize_t (*write)(struct tty_struct___38 *, struct file___470 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___38 *, struct file___470 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___38 *, struct file___470 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___38 *, struct ktermios *);
	__poll_t (*poll)(struct tty_struct___38 *, struct file___470 *, struct poll_table_struct___309 *);
	int (*hangup)(struct tty_struct___38 *);
	void (*receive_buf)(struct tty_struct___38 *, const unsigned char *, char *, int);
	void (*write_wakeup)(struct tty_struct___38 *);
	void (*dcd_change)(struct tty_struct___38 *, unsigned int);
	int (*receive_buf2)(struct tty_struct___38 *, const unsigned char *, char *, int);
	struct module___396 *owner;
	int refcount;
};

struct tty_ldisc___38 {
	struct tty_ldisc_ops___38 *ops;
	struct tty_struct___38 *tty;
};

struct tty_port_operations___38 {
	int (*carrier_raised)(struct tty_port___38 *);
	void (*dtr_rts)(struct tty_port___38 *, int);
	void (*shutdown)(struct tty_port___38 *);
	int (*activate)(struct tty_port___38 *, struct tty_struct___38 *);
	void (*destruct)(struct tty_port___38 *);
};

struct tty_port_client_operations___38 {
	int (*receive_buf)(struct tty_port___38 *, const unsigned char *, const unsigned char *, size_t);
	void (*write_wakeup)(struct tty_port___38 *);
};

struct socket_wq___96 {
	wait_queue_head_t wait;
	struct fasync_struct___470 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___96;

struct socket___97 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___96 *wq;
	struct file___470 *file;
	struct sock___95 *sk;
	const struct proto_ops___96 *ops;
};

typedef int (*sk_read_actor_t___95)(read_descriptor_t *, struct sk_buff___116 *, unsigned int, size_t);

struct proto_ops___96 {
	int family;
	struct module___396 *owner;
	int (*release)(struct socket___97 *);
	int (*bind)(struct socket___97 *, struct sockaddr *, int);
	int (*connect)(struct socket___97 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___97 *, struct socket___97 *);
	int (*accept)(struct socket___97 *, struct socket___97 *, int, bool);
	int (*getname)(struct socket___97 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___470 *, struct socket___97 *, struct poll_table_struct___309 *);
	int (*ioctl)(struct socket___97 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___97 *, int);
	int (*shutdown)(struct socket___97 *, int);
	int (*setsockopt)(struct socket___97 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___97 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___97 *, struct msghdr___98 *, size_t);
	int (*recvmsg)(struct socket___97 *, struct msghdr___98 *, size_t, int);
	int (*mmap)(struct file___470 *, struct socket___97 *, struct vm_area_struct___471 *);
	ssize_t (*sendpage)(struct socket___97 *, struct page___471 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___97 *, loff_t *, struct pipe_inode_info___151 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___95 *, int);
	int (*peek_len)(struct socket___97 *);
	int (*read_sock)(struct sock___95 *, read_descriptor_t *, sk_read_actor_t___95);
	int (*sendpage_locked)(struct sock___95 *, struct page___471 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___95 *, struct msghdr___98 *, size_t);
	int (*set_rcvlowat)(struct sock___95 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct nf_bridge_info___115;

struct sk_buff___116 {
	union {
		struct {
			struct sk_buff___116 *next;
			struct sk_buff___116 *prev;
			union {
				struct net_device___115 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___95 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___116 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___115 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct fwnode_reference_args___358;

struct fwnode_endpoint___358;

struct fwnode_operations___358 {
	struct fwnode_handle___358 * (*get)(struct fwnode_handle___358 *);
	void (*put)(struct fwnode_handle___358 *);
	bool (*device_is_available)(const struct fwnode_handle___358 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___358 *, const struct device___438 *);
	bool (*property_present)(const struct fwnode_handle___358 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___358 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___358 *, const char *, const char **, size_t);
	struct fwnode_handle___358 * (*get_parent)(const struct fwnode_handle___358 *);
	struct fwnode_handle___358 * (*get_next_child_node)(const struct fwnode_handle___358 *, struct fwnode_handle___358 *);
	struct fwnode_handle___358 * (*get_named_child_node)(const struct fwnode_handle___358 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___358 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___358 *);
	struct fwnode_handle___358 * (*graph_get_next_endpoint)(const struct fwnode_handle___358 *, struct fwnode_handle___358 *);
	struct fwnode_handle___358 * (*graph_get_remote_endpoint)(const struct fwnode_handle___358 *);
	struct fwnode_handle___358 * (*graph_get_port_parent)(struct fwnode_handle___358 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___358 *, struct fwnode_endpoint___358 *);
};

struct fwnode_endpoint___358 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___358 *local_fwnode;
};

struct fwnode_reference_args___358 {
	struct fwnode_handle___358 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___151;

struct pipe_buffer___151 {
	struct page___471 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___151 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___151 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___151 *, struct pipe_buffer___151 *);
	void (*release)(struct pipe_inode_info___151 *, struct pipe_buffer___151 *);
	int (*steal)(struct pipe_inode_info___151 *, struct pipe_buffer___151 *);
	union {
		bool (*get)(struct pipe_inode_info___151 *, struct pipe_buffer___151 *);
		struct {
			void (*get)(struct pipe_inode_info___151 *, struct pipe_buffer___151 *);
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
};

struct nf_bridge_info___115 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___115 = 0,
		BRNF_PROTO_8021Q___115 = 1,
		BRNF_PROTO_PPPOE___115 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___115 *physindev;
	struct net_device___115 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___115(struct sk_buff___116 **);

struct net_device_ops___115;

struct ethtool_ops___115;

struct l3mdev_ops___95;

struct xfrmdev_ops___115;

struct tlsdev_ops___115;

struct header_ops___115;

struct netdev_rx_queue___115;

struct mini_Qdisc___107;

struct netdev_queue___115;

struct Qdisc___107;

struct rtnl_link_ops___107;

struct dcbnl_rtnl_ops___115;

struct net_device___115 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___115 *netdev_ops;
	const struct ethtool_ops___115 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___95 *l3mdev_ops;
	const struct ndisc_ops___2 *ndisc_ops;
	const struct xfrmdev_ops___115 *xfrmdev_ops;
	const struct tlsdev_ops___115 *tlsdev_ops;
	const struct header_ops___115 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___457 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___2 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___115 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___105 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___115 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___107 *miniq_ingress;
	struct netdev_queue___115 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___115 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___107 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___107 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___115 = 0,
		NETREG_REGISTERED___115 = 1,
		NETREG_UNREGISTERING___115 = 2,
		NETREG_UNREGISTERED___115 = 3,
		NETREG_RELEASED___115 = 4,
		NETREG_DUMMY___115 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___115 = 0,
		RTNL_LINK_INITIALIZING___115 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___115 *);
	struct netpoll_info *npinfo;
	possible_net_t___117 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___438 dev;
	const struct attribute_group___435 *sysfs_groups[4];
	const struct attribute_group___435 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___107 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___115 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct ethtool_ops___115 {
	int (*get_settings)(struct net_device___115 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___115 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___115 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___115 *);
	void (*get_regs)(struct net_device___115 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___115 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___115 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___115 *);
	void (*set_msglevel)(struct net_device___115 *, u32);
	int (*nway_reset)(struct net_device___115 *);
	u32 (*get_link)(struct net_device___115 *);
	int (*get_eeprom_len)(struct net_device___115 *);
	int (*get_eeprom)(struct net_device___115 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___115 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___115 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___115 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___115 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___115 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___115 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___115 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___115 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___115 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___115 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___115 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___115 *);
	void (*complete)(struct net_device___115 *);
	u32 (*get_priv_flags)(struct net_device___115 *);
	int (*set_priv_flags)(struct net_device___115 *, u32);
	int (*get_sset_count)(struct net_device___115 *, int);
	int (*get_rxnfc)(struct net_device___115 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___115 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___115 *, struct ethtool_flash *);
	int (*reset)(struct net_device___115 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___115 *);
	u32 (*get_rxfh_indir_size)(struct net_device___115 *);
	int (*get_rxfh)(struct net_device___115 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___115 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___115 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___115 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___115 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___115 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___115 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___115 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___115 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___115 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___115 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___115 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___115 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___115 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___115 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___115 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___115 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___115 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___115 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___115 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___115 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___115 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	int (*get_fecparam)(struct net_device___115 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___115 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___115 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___115 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___115 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___115;

struct inet_frags___115 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___115 *, const void *);
	void (*destructor)(struct inet_frag_queue___115 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___115 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___116 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___116 *fragments_tail;
	struct sk_buff___116 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___115 *net;
	struct callback_head rcu;
};

struct fib_rule___95;

struct fib_lookup_arg___95;

struct fib_rules_ops___95 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___95 *, struct flowi *, int, struct fib_lookup_arg___95 *);
	bool (*suppress)(struct fib_rule___95 *, struct fib_lookup_arg___95 *);
	int (*match)(struct fib_rule___95 *, struct flowi *, int);
	int (*configure)(struct fib_rule___95 *, struct sk_buff___116 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___95 *);
	int (*compare)(struct fib_rule___95 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___95 *, struct sk_buff___116 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___95 *);
	void (*flush_cache)(struct fib_rules_ops___95 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___396 *owner;
	struct net___126 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___96 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___126 *);
	int (*fib_dump)(struct net___126 *, struct notifier_block *);
	struct module___396 *owner;
	struct callback_head rcu;
};

struct dst_entry___95 {
	struct net_device___115 *dev;
	struct dst_ops___126 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___116 *);
	int (*output)(struct net___126 *, struct sock___95 *, struct sk_buff___116 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___95;

struct neigh_parms___95;

struct neigh_ops___95;

struct neighbour___95 {
	struct neighbour___95 *next;
	struct neigh_table___95 *tbl;
	struct neigh_parms___95 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___115 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___95 *, struct sk_buff___116 *);
	const struct neigh_ops___95 *ops;
	struct callback_head rcu;
	struct net_device___115 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct bpf_prog_aux___108;

struct bpf_prog___105 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___108 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

struct pernet_operations___116 {
	struct list_head list;
	int (*init)(struct net___126 *);
	void (*exit)(struct net___126 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___115 {
	int (*ieee_getets)(struct net_device___115 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___115 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___115 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___115 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___115 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___115 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___115 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___115 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___115 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___115 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___115 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___115 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___115 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___115 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___115 *);
	u8 (*setstate)(struct net_device___115 *, u8);
	void (*getpermhwaddr)(struct net_device___115 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___115 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___115 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___115 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___115 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___115 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___115 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___115 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___115 *, int, u8 *);
	void (*setpfccfg)(struct net_device___115 *, int, u8);
	void (*getpfccfg)(struct net_device___115 *, int, u8 *);
	u8 (*setall)(struct net_device___115 *);
	u8 (*getcap)(struct net_device___115 *, int, u8 *);
	int (*getnumtcs)(struct net_device___115 *, int, u8 *);
	int (*setnumtcs)(struct net_device___115 *, int, u8);
	u8 (*getpfcstate)(struct net_device___115 *);
	void (*setpfcstate)(struct net_device___115 *, u8);
	void (*getbcncfg)(struct net_device___115 *, int, u32 *);
	void (*setbcncfg)(struct net_device___115 *, int, u32);
	void (*getbcnrp)(struct net_device___115 *, int, u8 *);
	void (*setbcnrp)(struct net_device___115 *, int, u8);
	int (*setapp)(struct net_device___115 *, u8, u16, u8);
	int (*getapp)(struct net_device___115 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___115 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___115 *, int, u8);
	u8 (*getdcbx)(struct net_device___115 *);
	u8 (*setdcbx)(struct net_device___115 *, u8);
	int (*peer_getappinfo)(struct net_device___115 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___115 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___115 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___115 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___115 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___115 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct bpf_map___320;

struct bpf_map_ops___319 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___320 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___320 *, struct file___470 *);
	void (*map_free)(struct bpf_map___320 *);
	int (*map_get_next_key)(struct bpf_map___320 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___320 *);
	void * (*map_lookup_elem)(struct bpf_map___320 *, void *);
	int (*map_update_elem)(struct bpf_map___320 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___320 *, void *);
	int (*map_push_elem)(struct bpf_map___320 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___320 *, void *);
	int (*map_peek_elem)(struct bpf_map___320 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___320 *, struct file___470 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___320 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___320 *, void *, struct seq_file___409 *);
	int (*map_check_btf)(const struct bpf_map___320 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___320 {
	const struct bpf_map_ops___319 *ops;
	struct bpf_map___320 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___438 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___115;

struct bpf_map_dev_ops___115 {
	int (*map_get_next_key)(struct bpf_offloaded_map___115 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___115 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___115 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___115 *, void *);
};

struct bpf_offloaded_map___115 {
	struct bpf_map___320 map;
	struct net_device___115 *netdev;
	const struct bpf_map_dev_ops___115 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___105 {
	int (*test_run)(struct bpf_prog___105 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___105 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___105 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___105 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___105 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___105 *, u32 *);
};

struct bpf_prog_offload_ops___105 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___105 *);
	int (*translate)(struct bpf_prog___105 *);
	void (*destroy)(struct bpf_prog___105 *);
};

struct bpf_prog_offload___105 {
	struct bpf_prog___105 *prog;
	struct net_device___115 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___105 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___108 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___105 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___105 *ops;
	struct bpf_map___320 **used_maps;
	struct bpf_prog___105 *prog;
	struct user_struct___438 *user;
	u64 load_time;
	struct bpf_map___320 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___105 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___105 {
	struct bpf_prog___105 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___105 {
	struct callback_head rcu;
	struct bpf_prog_array_item___105 items[0];
};

struct cgroup_bpf___105 {
	struct bpf_prog_array___105 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___105 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___320;

typedef void (*kthread_work_func_t___320)(struct kthread_work___320 *);

struct kthread_worker___320;

struct kthread_work___320 {
	struct list_head node;
	kthread_work_func_t___320 func;
	struct kthread_worker___320 *worker;
	int canceling;
};

struct kthread_worker___320 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___472 *task;
	struct kthread_work___320 *current_work;
};

struct kthread_delayed_work___319 {
	struct kthread_work___320 work;
	struct timer_list timer;
};

struct psi_group___319 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___320 *poll_kworker;
	struct kthread_delayed_work___319 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___319;

struct cgroup_rstat_cpu___319;

struct cgroup___319 {
	struct cgroup_subsys_state___319 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___465 *kn;
	struct cgroup_file___319 procs_file;
	struct cgroup_file___319 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___319 *subsys[13];
	struct cgroup_root___319 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___319 *dom_cgrp;
	struct cgroup_rstat_cpu___319 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___105 bpf;
	atomic_t congestion_count;
	struct cgroup___319 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___319 psi;
	int ancestor_ids[0];
};

struct cftype___319;

struct cgroup_subsys___319 {
	struct cgroup_subsys_state___319 * (*css_alloc)(struct cgroup_subsys_state___319 *);
	int (*css_online)(struct cgroup_subsys_state___319 *);
	void (*css_offline)(struct cgroup_subsys_state___319 *);
	void (*css_released)(struct cgroup_subsys_state___319 *);
	void (*css_free)(struct cgroup_subsys_state___319 *);
	void (*css_reset)(struct cgroup_subsys_state___319 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___319 *, int);
	int (*css_extra_stat_show)(struct seq_file___409 *, struct cgroup_subsys_state___319 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___472 *);
	void (*cancel_fork)(struct task_struct___472 *);
	void (*fork)(struct task_struct___472 *);
	void (*exit)(struct task_struct___472 *);
	void (*free)(struct task_struct___472 *);
	void (*bind)(struct cgroup_subsys_state___319 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___319 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___319 *dfl_cftypes;
	struct cftype___319 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___319 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___319 *updated_children;
	struct cgroup___319 *updated_next;
};

struct cgroup_root___319 {
	struct kernfs_root___464 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___319 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___319 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___319 *ss;
	struct list_head node;
	struct kernfs_ops___464 *kf_ops;
	int (*open)(struct kernfs_open_file___464 *);
	void (*release)(struct kernfs_open_file___464 *);
	u64 (*read_u64)(struct cgroup_subsys_state___319 *, struct cftype___319 *);
	s64 (*read_s64)(struct cgroup_subsys_state___319 *, struct cftype___319 *);
	int (*seq_show)(struct seq_file___409 *, void *);
	void * (*seq_start)(struct seq_file___409 *, loff_t *);
	void * (*seq_next)(struct seq_file___409 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___409 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___319 *, struct cftype___319 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___319 *, struct cftype___319 *, s64);
	ssize_t (*write)(struct kernfs_open_file___464 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___464 *, struct poll_table_struct___309 *);
};

struct xdp_rxq_info___115 {
	struct net_device___115 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___115 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___115 *dev_rx;
};

struct netlink_callback___117 {
	struct sk_buff___116 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___117 *);
	int (*dump)(struct sk_buff___116 *, struct netlink_callback___117 *);
	int (*done)(struct netlink_callback___117 *);
	void *data;
	struct module___396 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___115 {
	int (*create)(struct sk_buff___116 *, struct net_device___115 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___116 *, unsigned char *);
	int (*cache)(const struct neighbour___95 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___115 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___115 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___115 *, int);
	int poll_owner;
	struct net_device___115 *dev;
	struct sk_buff___116 *gro_list;
	struct sk_buff___116 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___115 {
	struct net_device___115 *dev;
	struct Qdisc___107 *qdisc;
	struct Qdisc___107 *qdisc_sleeping;
	struct kobject___458 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___115 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___107 {
	struct sk_buff___116 *head;
	struct sk_buff___116 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___107;

struct Qdisc___107 {
	int (*enqueue)(struct sk_buff___116 *, struct Qdisc___107 *, struct sk_buff___116 **);
	struct sk_buff___116 * (*dequeue)(struct Qdisc___107 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___107 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___115 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___115 gso_skb;
	struct qdisc_skb_head___107 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___107 *next_sched;
	struct sk_buff_head___115 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___115 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___458 kobj;
	struct net_device___115 *dev;
	long: 64;
	struct xdp_rxq_info___115 xdp_rxq;
	union {
		struct xdp_umem *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___115)(struct net_device___115 *, struct sk_buff___116 *, struct net_device___115 *);

struct netdev_bpf___115 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___105 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___105 *prog;
			const struct bpf_prog_offload_ops___105 *ops;
		} verifier;
		struct {
			struct bpf_prog___105 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___115 *offmap;
		};
		struct {
			struct xdp_umem___3 *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___115 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___116 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___115 {
	int (*tls_dev_add)(struct net_device___115 *, struct sock___95 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___115 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___115 *, struct sock___95 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___115 {
	int (*ndo_init)(struct net_device___115 *);
	void (*ndo_uninit)(struct net_device___115 *);
	int (*ndo_open)(struct net_device___115 *);
	int (*ndo_stop)(struct net_device___115 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___116 *, struct net_device___115 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___116 *, struct net_device___115 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___115 *, struct sk_buff___116 *, struct net_device___115 *, select_queue_fallback_t___115);
	void (*ndo_change_rx_flags)(struct net_device___115 *, int);
	void (*ndo_set_rx_mode)(struct net_device___115 *);
	int (*ndo_set_mac_address)(struct net_device___115 *, void *);
	int (*ndo_validate_addr)(struct net_device___115 *);
	int (*ndo_do_ioctl)(struct net_device___115 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___115 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___115 *, int);
	int (*ndo_neigh_setup)(struct net_device___115 *, struct neigh_parms___95 *);
	void (*ndo_tx_timeout)(struct net_device___115 *);
	void (*ndo_get_stats64)(struct net_device___115 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___115 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___115 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___115 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___115 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___115 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___115 *);
	int (*ndo_netpoll_setup)(struct net_device___115 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___115 *);
	int (*ndo_set_vf_mac)(struct net_device___115 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___115 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___115 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___115 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___115 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___115 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___115 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___115 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___115 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___115 *, int, struct sk_buff___116 *);
	int (*ndo_set_vf_guid)(struct net_device___115 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___115 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___115 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___115 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___115 *, const struct sk_buff___116 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___115 *, struct net_device___115 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___115 *, struct net_device___115 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___115 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___115 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___115 *, struct neighbour___95 *);
	void (*ndo_neigh_destroy)(struct net_device___115 *, struct neighbour___95 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___115 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___115 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___115 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___116 *, struct netlink_callback___117 *, struct net_device___115 *, struct net_device___115 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___115 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___115 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___116 *, u32, u32, struct net_device___115 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___115 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___115 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___115 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___115 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___115 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___115 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___115 *, struct net_device___115 *);
	void (*ndo_dfwd_del_station)(struct net_device___115 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___115 *);
	int (*ndo_set_tx_maxrate)(struct net_device___115 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___115 *);
	int (*ndo_change_proto_down)(struct net_device___115 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___115 *, struct sk_buff___116 *);
	void (*ndo_set_rx_headroom)(struct net_device___115 *, int);
	int (*ndo_bpf)(struct net_device___115 *, struct netdev_bpf___115 *);
	int (*ndo_xdp_xmit)(struct net_device___115 *, int, struct xdp_frame___115 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___115 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___115 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___95 {
	possible_net_t___117 net;
	struct net_device___115 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___95 *);
	void (*neigh_cleanup)(struct neighbour___95 *);
	struct neigh_table___95 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___95 {
	u32 (*l3mdev_fib_table)(const struct net_device___115 *);
	struct sk_buff___116 * (*l3mdev_l3_rcv)(struct net_device___115 *, struct sk_buff___116 *, u16);
	struct sk_buff___116 * (*l3mdev_l3_out)(struct net_device___115 *, struct sock___95 *, struct sk_buff___116 *, u16);
	struct dst_entry___95 * (*l3mdev_link_scope_lookup)(const struct net_device___115 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct tcf_proto___107;

struct mini_Qdisc___107 {
	struct tcf_proto___107 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___107 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___115 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___126 *, struct net_device___115 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___115 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___115 *, struct list_head *);
	size_t (*get_size)(const struct net_device___115 *);
	int (*fill_info)(struct sk_buff___116 *, const struct net_device___115 *);
	size_t (*get_xstats_size)(const struct net_device___115 *);
	int (*fill_xstats)(struct sk_buff___116 *, const struct net_device___115 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___115 *, struct net_device___115 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___115 *, const struct net_device___115 *);
	int (*fill_slave_info)(struct sk_buff___116 *, const struct net_device___115 *, const struct net_device___115 *);
	struct net___126 * (*get_link_net)(const struct net_device___115 *);
	size_t (*get_linkxstats_size)(const struct net_device___115 *, int);
	int (*fill_linkxstats)(struct sk_buff___116 *, const struct net_device___115 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___115 {
	struct list_head poll_list;
	struct sk_buff_head___115 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___115 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___107 *output_queue;
	struct Qdisc___107 **output_queue_tailp;
	struct sk_buff___116 *completion_queue;
	struct sk_buff_head___115 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___115 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___115 input_pkt_queue;
	struct napi_struct___115 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bdi_writeback_congested___260 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___260 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___260 {
	struct bio___260 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___262 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___262 bip_inline_vecs[0];
};

struct bio_set___260 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___260 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___203 {
	struct mem_cgroup___203 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___203 {
	struct lruvec___471 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___203 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___203 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct kernel_param_ops___396 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___396 *);
	int (*get)(char *, const struct kernel_param___396 *);
	void (*free)(void *);
};

struct kparam_array___396;

struct kernel_param___396 {
	const char *name;
	struct module___396 *mod;
	const struct kernel_param_ops___396 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___396 *arr;
	};
};

struct kparam_array___396 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___396 *ops;
	void *elem;
};

struct module_attribute___396 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___396 *, struct module_kobject___396 *, char *);
	ssize_t (*store)(struct module_attribute___396 *, struct module_kobject___396 *, const char *, size_t);
	void (*setup)(struct module___396 *, const char *);
	int (*test)(struct module___396 *);
	void (*free)(struct module___396 *);
};

struct gnet_dump___107 {
	spinlock_t *lock;
	struct sk_buff___116 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___107;

struct Qdisc_ops___107 {
	struct Qdisc_ops___107 *next;
	const struct Qdisc_class_ops___107 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___116 *, struct Qdisc___107 *, struct sk_buff___116 **);
	struct sk_buff___116 * (*dequeue)(struct Qdisc___107 *);
	struct sk_buff___116 * (*peek)(struct Qdisc___107 *);
	int (*init)(struct Qdisc___107 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___107 *);
	void (*destroy)(struct Qdisc___107 *);
	int (*change)(struct Qdisc___107 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___107 *);
	int (*change_tx_queue_len)(struct Qdisc___107 *, unsigned int);
	int (*dump)(struct Qdisc___107 *, struct sk_buff___116 *);
	int (*dump_stats)(struct Qdisc___107 *, struct gnet_dump___107 *);
	void (*ingress_block_set)(struct Qdisc___107 *, u32);
	void (*egress_block_set)(struct Qdisc___107 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___107 *);
	u32 (*egress_block_get)(struct Qdisc___107 *);
	struct module___396 *owner;
};

struct tcf_block___107;

struct Qdisc_class_ops___107 {
	unsigned int flags;
	struct netdev_queue___115 * (*select_queue)(struct Qdisc___107 *, struct tcmsg *);
	int (*graft)(struct Qdisc___107 *, long unsigned int, struct Qdisc___107 *, struct Qdisc___107 **, struct netlink_ext_ack *);
	struct Qdisc___107 * (*leaf)(struct Qdisc___107 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___107 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___107 *, u32);
	int (*change)(struct Qdisc___107 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___107 *, long unsigned int);
	void (*walk)(struct Qdisc___107 *, struct qdisc_walker *);
	struct tcf_block___107 * (*tcf_block)(struct Qdisc___107 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___107 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___107 *, long unsigned int);
	int (*dump)(struct Qdisc___107 *, long unsigned int, struct sk_buff___116 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___107 *, long unsigned int, struct gnet_dump___107 *);
};

struct tcf_chain___107;

struct tcf_block___107 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___126 *net;
	struct Qdisc___107 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___107 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___107;

struct tcf_proto_ops___107;

struct tcf_proto___107 {
	struct tcf_proto___107 *next;
	void *root;
	int (*classify)(struct sk_buff___116 *, const struct tcf_proto___107 *, struct tcf_result___107 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___107 *ops;
	struct tcf_chain___107 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___107 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___107 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___107 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___116 *, const struct tcf_proto___107 *, struct tcf_result___107 *);
	int (*init)(struct tcf_proto___107 *);
	void (*destroy)(struct tcf_proto___107 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___107 *, u32);
	void (*put)(struct tcf_proto___107 *, void *);
	int (*change)(struct net___126 *, struct sk_buff___116 *, struct tcf_proto___107 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___107 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___107 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___107 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___126 *, struct tcf_chain___107 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___126 *, struct tcf_proto___107 *, void *, struct sk_buff___116 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___116 *, struct net___126 *, void *);
	struct module___396 *owner;
	int flags;
};

struct tcf_chain___107 {
	struct mutex filter_chain_lock;
	struct tcf_proto___107 *filter_chain;
	struct list_head list;
	struct tcf_block___107 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___107 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___95 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___105 *prog;
};

struct bpf_redirect_info___105 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___320 *map;
	struct bpf_map___320 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___95;

struct neigh_hash_table___95;

struct neigh_table___95 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___115 *, __u32 *);
	bool (*key_eq)(const struct neighbour___95 *, const void *);
	int (*constructor)(struct neighbour___95 *);
	int (*pconstructor)(struct pneigh_entry___95 *);
	void (*pdestructor)(struct pneigh_entry___95 *);
	void (*proxy_redo)(struct sk_buff___116 *);
	char *id;
	struct neigh_parms___95 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___115 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___95 *nht;
	struct pneigh_entry___95 **phash_buckets;
};

struct neigh_ops___95 {
	int family;
	void (*solicit)(struct neighbour___95 *, struct sk_buff___116 *);
	void (*error_report)(struct neighbour___95 *, struct sk_buff___116 *);
	int (*output)(struct neighbour___95 *, struct sk_buff___116 *);
	int (*connected_output)(struct neighbour___95 *, struct sk_buff___116 *);
};

struct pneigh_entry___95 {
	struct pneigh_entry___95 *next;
	possible_net_t___117 net;
	struct net_device___115 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___95 {
	struct neighbour___95 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___95 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___95 *ctarget;
	struct net___126 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___95 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___95 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___77;

struct proto___95 {
	void (*close)(struct sock___95 *, long int);
	int (*pre_connect)(struct sock___95 *, struct sockaddr *, int);
	int (*connect)(struct sock___95 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___95 *, int);
	struct sock___95 * (*accept)(struct sock___95 *, int, int *, bool);
	int (*ioctl)(struct sock___95 *, int, long unsigned int);
	int (*init)(struct sock___95 *);
	void (*destroy)(struct sock___95 *);
	void (*shutdown)(struct sock___95 *, int);
	int (*setsockopt)(struct sock___95 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___95 *, int, int, char *, int *);
	void (*keepalive)(struct sock___95 *, int);
	int (*sendmsg)(struct sock___95 *, struct msghdr___98 *, size_t);
	int (*recvmsg)(struct sock___95 *, struct msghdr___98 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___95 *, struct page___471 *, int, size_t, int);
	int (*bind)(struct sock___95 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___95 *, struct sk_buff___116 *);
	void (*release_cb)(struct sock___95 *);
	int (*hash)(struct sock___95 *);
	void (*unhash)(struct sock___95 *);
	void (*rehash)(struct sock___95 *);
	int (*get_port)(struct sock___95 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___95 *);
	bool (*stream_memory_read)(const struct sock___95 *);
	void (*enter_memory_pressure)(struct sock___95 *);
	void (*leave_memory_pressure)(struct sock___95 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___77 *rsk_prot;
	struct timewait_sock_ops___3 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___396 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___95 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct request_sock___78;

struct request_sock_ops___77 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___95 *, struct request_sock___78 *);
	void (*send_ack)(const struct sock___95 *, struct sk_buff___116 *, struct request_sock___78 *);
	void (*send_reset)(const struct sock___95 *, struct sk_buff___116 *);
	void (*destructor)(struct request_sock___78 *);
	void (*syn_ack_timeout)(const struct request_sock___78 *);
};

struct request_sock___78 {
	struct sock_common___95 __req_common;
	struct request_sock___78 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___77 *rsk_ops;
	struct sock___95 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct netlbl_af4list {
	__be32 addr;
	__be32 mask;
	u32 valid;
	struct list_head list;
};

struct netlbl_af6list {
	struct in6_addr addr;
	struct in6_addr mask;
	u32 valid;
	struct list_head list;
};

struct netlbl_domaddr_map {
	struct list_head list4;
	struct list_head list6;
};

struct netlbl_dommap_def {
	u32 type;
	union {
		struct netlbl_domaddr_map *addrsel;
		struct cipso_v4_doi *cipso;
		struct calipso_doi *calipso;
	};
};

struct netlbl_domaddr4_map {
	struct netlbl_dommap_def def;
	struct netlbl_af4list list;
};

struct netlbl_domaddr6_map {
	struct netlbl_dommap_def def;
	struct netlbl_af6list list;
};

struct netlbl_dom_map {
	char *domain;
	u16 family;
	struct netlbl_dommap_def def;
	u32 valid;
	struct list_head list;
	struct callback_head rcu;
};

struct netlbl_domhsh_tbl {
	struct list_head *tbl;
	u32 size;
};

struct genl_ops___7;

struct genl_info___6;

struct genl_family___7 {
	int id;
	unsigned int hdrsize;
	char name[16];
	unsigned int version;
	unsigned int maxattr;
	bool netnsok;
	bool parallel_ops;
	int (*pre_doit)(const struct genl_ops___7 *, struct sk_buff___115 *, struct genl_info___6 *);
	void (*post_doit)(const struct genl_ops___7 *, struct sk_buff___115 *, struct genl_info___6 *);
	int (*mcast_bind)(struct net___125 *, int);
	void (*mcast_unbind)(struct net___125 *, int);
	struct nlattr **attrbuf;
	const struct genl_ops___7 *ops;
	const struct genl_multicast_group *mcgrps;
	unsigned int n_ops;
	unsigned int n_mcgrps;
	unsigned int mcgrp_offset;
	struct module___395 *module;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct genl_ops___7 {
	const struct nla_policy *policy;
	int (*doit)(struct sk_buff___115 *, struct genl_info___6 *);
	int (*start)(struct netlink_callback___116 *);
	int (*dumpit)(struct sk_buff___115 *, struct netlink_callback___116 *);
	int (*done)(struct netlink_callback___116 *);
	u8 cmd;
	u8 internal_flags;
	u8 flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t genl_ops_extended_size_rh;
	struct genl_ops_extended_rh genl_ops_extended_rh;
};

struct genl_info___6 {
	u32 snd_seq;
	u32 snd_portid;
	struct nlmsghdr *nlhdr;
	struct genlmsghdr *genlhdr;
	void *userhdr;
	struct nlattr **attrs;
	possible_net_t___116 _net;
	void *user_ptr[2];
	struct netlink_ext_ack *extack;
};

enum {
	NLBL_MGMT_C_UNSPEC = 0,
	NLBL_MGMT_C_ADD = 1,
	NLBL_MGMT_C_REMOVE = 2,
	NLBL_MGMT_C_LISTALL = 3,
	NLBL_MGMT_C_ADDDEF = 4,
	NLBL_MGMT_C_REMOVEDEF = 5,
	NLBL_MGMT_C_LISTDEF = 6,
	NLBL_MGMT_C_PROTOCOLS = 7,
	NLBL_MGMT_C_VERSION = 8,
	__NLBL_MGMT_C_MAX = 9,
};

enum {
	NLBL_MGMT_A_UNSPEC = 0,
	NLBL_MGMT_A_DOMAIN = 1,
	NLBL_MGMT_A_PROTOCOL = 2,
	NLBL_MGMT_A_VERSION = 3,
	NLBL_MGMT_A_CV4DOI = 4,
	NLBL_MGMT_A_IPV6ADDR = 5,
	NLBL_MGMT_A_IPV6MASK = 6,
	NLBL_MGMT_A_IPV4ADDR = 7,
	NLBL_MGMT_A_IPV4MASK = 8,
	NLBL_MGMT_A_ADDRSELECTOR = 9,
	NLBL_MGMT_A_SELECTORLIST = 10,
	NLBL_MGMT_A_FAMILY = 11,
	NLBL_MGMT_A_CLPDOI = 12,
	__NLBL_MGMT_A_MAX = 13,
};

struct netlbl_domhsh_walk_arg {
	struct netlink_callback___116 *nl_cb;
	struct sk_buff___115 *skb;
	u32 seq;
};

struct netlink_skb_parms___22 {
	struct scm_creds creds;
	__u32 portid;
	__u32 dst_group;
	__u32 flags;
	struct sock___92 *sk;
	bool nsid_is_set;
	int nsid;
};

struct netdev_notifier_info___15 {
	struct net_device___112 *dev;
	struct netlink_ext_ack *extack;
};

struct genl_ops___8;

struct genl_info___7;

struct genl_family___8 {
	int id;
	unsigned int hdrsize;
	char name[16];
	unsigned int version;
	unsigned int maxattr;
	bool netnsok;
	bool parallel_ops;
	int (*pre_doit)(const struct genl_ops___8 *, struct sk_buff___113 *, struct genl_info___7 *);
	void (*post_doit)(const struct genl_ops___8 *, struct sk_buff___113 *, struct genl_info___7 *);
	int (*mcast_bind)(struct net___123 *, int);
	void (*mcast_unbind)(struct net___123 *, int);
	struct nlattr **attrbuf;
	const struct genl_ops___8 *ops;
	const struct genl_multicast_group *mcgrps;
	unsigned int n_ops;
	unsigned int n_mcgrps;
	unsigned int mcgrp_offset;
	struct module___393 *module;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct genl_ops___8 {
	const struct nla_policy *policy;
	int (*doit)(struct sk_buff___113 *, struct genl_info___7 *);
	int (*start)(struct netlink_callback___114 *);
	int (*dumpit)(struct sk_buff___113 *, struct netlink_callback___114 *);
	int (*done)(struct netlink_callback___114 *);
	u8 cmd;
	u8 internal_flags;
	u8 flags;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t genl_ops_extended_size_rh;
	struct genl_ops_extended_rh genl_ops_extended_rh;
};

struct genl_info___7 {
	u32 snd_seq;
	u32 snd_portid;
	struct nlmsghdr *nlhdr;
	struct genlmsghdr *genlhdr;
	void *userhdr;
	struct nlattr **attrs;
	possible_net_t___114 _net;
	void *user_ptr[2];
	struct netlink_ext_ack *extack;
};

enum {
	NLBL_UNLABEL_C_UNSPEC = 0,
	NLBL_UNLABEL_C_ACCEPT = 1,
	NLBL_UNLABEL_C_LIST = 2,
	NLBL_UNLABEL_C_STATICADD = 3,
	NLBL_UNLABEL_C_STATICREMOVE = 4,
	NLBL_UNLABEL_C_STATICLIST = 5,
	NLBL_UNLABEL_C_STATICADDDEF = 6,
	NLBL_UNLABEL_C_STATICREMOVEDEF = 7,
	NLBL_UNLABEL_C_STATICLISTDEF = 8,
	__NLBL_UNLABEL_C_MAX = 9,
};

enum {
	NLBL_UNLABEL_A_UNSPEC = 0,
	NLBL_UNLABEL_A_ACPTFLG = 1,
	NLBL_UNLABEL_A_IPV6ADDR = 2,
	NLBL_UNLABEL_A_IPV6MASK = 3,
	NLBL_UNLABEL_A_IPV4ADDR = 4,
	NLBL_UNLABEL_A_IPV4MASK = 5,
	NLBL_UNLABEL_A_IFACE = 6,
	NLBL_UNLABEL_A_SECCTX = 7,
	__NLBL_UNLABEL_A_MAX = 8,
};

struct netlbl_unlhsh_tbl {
	struct list_head *tbl;
	u32 size;
};

struct netlbl_unlhsh_addr4 {
	u32 secid;
	struct netlbl_af4list list;
	struct callback_head rcu;
};

struct netlbl_unlhsh_addr6 {
	u32 secid;
	struct netlbl_af6list list;
	struct callback_head rcu;
};

struct netlbl_unlhsh_iface {
	int ifindex;
	struct list_head addr4_list;
	struct list_head addr6_list;
	u32 valid;
	struct list_head list;
	struct callback_head rcu;
};

struct netlbl_unlhsh_walk_arg {
	struct netlink_callback___114 *nl_cb;
	struct sk_buff___113 *skb;
	u32 seq;
};

enum {
	NLBL_CIPSOV4_C_UNSPEC = 0,
	NLBL_CIPSOV4_C_ADD = 1,
	NLBL_CIPSOV4_C_REMOVE = 2,
	NLBL_CIPSOV4_C_LIST = 3,
	NLBL_CIPSOV4_C_LISTALL = 4,
	__NLBL_CIPSOV4_C_MAX = 5,
};

enum {
	NLBL_CIPSOV4_A_UNSPEC = 0,
	NLBL_CIPSOV4_A_DOI = 1,
	NLBL_CIPSOV4_A_MTYPE = 2,
	NLBL_CIPSOV4_A_TAG = 3,
	NLBL_CIPSOV4_A_TAGLST = 4,
	NLBL_CIPSOV4_A_MLSLVLLOC = 5,
	NLBL_CIPSOV4_A_MLSLVLREM = 6,
	NLBL_CIPSOV4_A_MLSLVL = 7,
	NLBL_CIPSOV4_A_MLSLVLLST = 8,
	NLBL_CIPSOV4_A_MLSCATLOC = 9,
	NLBL_CIPSOV4_A_MLSCATREM = 10,
	NLBL_CIPSOV4_A_MLSCAT = 11,
	NLBL_CIPSOV4_A_MLSCATLST = 12,
	__NLBL_CIPSOV4_A_MAX = 13,
};

struct netlbl_cipsov4_doiwalk_arg {
	struct netlink_callback___114 *nl_cb;
	struct sk_buff___113 *skb;
	u32 seq;
};

struct netlbl_domhsh_walk_arg___2 {
	struct netlbl_audit *audit_info;
	u32 doi;
};

struct netlbl_calipso_ops___2 {
	int (*doi_add)(struct calipso_doi *, struct netlbl_audit *);
	void (*doi_free)(struct calipso_doi *);
	int (*doi_remove)(u32, struct netlbl_audit *);
	struct calipso_doi * (*doi_getdef)(u32);
	void (*doi_putdef)(struct calipso_doi *);
	int (*doi_walk)(u32 *, int (*)(struct calipso_doi *, void *), void *);
	int (*sock_getattr)(struct sock___92 *, struct netlbl_lsm_secattr *);
	int (*sock_setattr)(struct sock___92 *, const struct calipso_doi *, const struct netlbl_lsm_secattr *);
	void (*sock_delattr)(struct sock___92 *);
	int (*req_setattr)(struct request_sock___75 *, const struct calipso_doi *, const struct netlbl_lsm_secattr *);
	void (*req_delattr)(struct request_sock___75 *);
	int (*opt_getattr)(const unsigned char *, struct netlbl_lsm_secattr *);
	unsigned char * (*skbuff_optptr)(const struct sk_buff___113 *);
	int (*skbuff_setattr)(struct sk_buff___113 *, const struct calipso_doi *, const struct netlbl_lsm_secattr *);
	int (*skbuff_delattr)(struct sk_buff___113 *);
	void (*cache_invalidate)();
	int (*cache_add)(const unsigned char *, const struct netlbl_lsm_secattr *);
};

enum {
	NLBL_CALIPSO_C_UNSPEC = 0,
	NLBL_CALIPSO_C_ADD = 1,
	NLBL_CALIPSO_C_REMOVE = 2,
	NLBL_CALIPSO_C_LIST = 3,
	NLBL_CALIPSO_C_LISTALL = 4,
	__NLBL_CALIPSO_C_MAX = 5,
};

enum {
	NLBL_CALIPSO_A_UNSPEC = 0,
	NLBL_CALIPSO_A_DOI = 1,
	NLBL_CALIPSO_A_MTYPE = 2,
	__NLBL_CALIPSO_A_MAX = 3,
};

struct netlbl_calipso_doiwalk_arg {
	struct netlink_callback___114 *nl_cb;
	struct sk_buff___113 *skb;
	u32 seq;
};

struct dcbmsg {
	__u8 dcb_family;
	__u8 cmd;
	__u16 dcb_pad;
};

enum dcbnl_commands {
	DCB_CMD_UNDEFINED = 0,
	DCB_CMD_GSTATE = 1,
	DCB_CMD_SSTATE = 2,
	DCB_CMD_PGTX_GCFG = 3,
	DCB_CMD_PGTX_SCFG = 4,
	DCB_CMD_PGRX_GCFG = 5,
	DCB_CMD_PGRX_SCFG = 6,
	DCB_CMD_PFC_GCFG = 7,
	DCB_CMD_PFC_SCFG = 8,
	DCB_CMD_SET_ALL = 9,
	DCB_CMD_GPERM_HWADDR = 10,
	DCB_CMD_GCAP = 11,
	DCB_CMD_GNUMTCS = 12,
	DCB_CMD_SNUMTCS = 13,
	DCB_CMD_PFC_GSTATE = 14,
	DCB_CMD_PFC_SSTATE = 15,
	DCB_CMD_BCN_GCFG = 16,
	DCB_CMD_BCN_SCFG = 17,
	DCB_CMD_GAPP = 18,
	DCB_CMD_SAPP = 19,
	DCB_CMD_IEEE_SET = 20,
	DCB_CMD_IEEE_GET = 21,
	DCB_CMD_GDCBX = 22,
	DCB_CMD_SDCBX = 23,
	DCB_CMD_GFEATCFG = 24,
	DCB_CMD_SFEATCFG = 25,
	DCB_CMD_CEE_GET = 26,
	DCB_CMD_IEEE_DEL = 27,
	__DCB_CMD_ENUM_MAX = 28,
	DCB_CMD_MAX = 27,
};

enum dcbnl_attrs {
	DCB_ATTR_UNDEFINED = 0,
	DCB_ATTR_IFNAME = 1,
	DCB_ATTR_STATE = 2,
	DCB_ATTR_PFC_STATE = 3,
	DCB_ATTR_PFC_CFG = 4,
	DCB_ATTR_NUM_TC = 5,
	DCB_ATTR_PG_CFG = 6,
	DCB_ATTR_SET_ALL = 7,
	DCB_ATTR_PERM_HWADDR = 8,
	DCB_ATTR_CAP = 9,
	DCB_ATTR_NUMTCS = 10,
	DCB_ATTR_BCN = 11,
	DCB_ATTR_APP = 12,
	DCB_ATTR_IEEE = 13,
	DCB_ATTR_DCBX = 14,
	DCB_ATTR_FEATCFG = 15,
	DCB_ATTR_CEE = 16,
	__DCB_ATTR_ENUM_MAX = 17,
	DCB_ATTR_MAX = 16,
};

enum ieee_attrs {
	DCB_ATTR_IEEE_UNSPEC = 0,
	DCB_ATTR_IEEE_ETS = 1,
	DCB_ATTR_IEEE_PFC = 2,
	DCB_ATTR_IEEE_APP_TABLE = 3,
	DCB_ATTR_IEEE_PEER_ETS = 4,
	DCB_ATTR_IEEE_PEER_PFC = 5,
	DCB_ATTR_IEEE_PEER_APP = 6,
	DCB_ATTR_IEEE_MAXRATE = 7,
	DCB_ATTR_IEEE_QCN = 8,
	DCB_ATTR_IEEE_QCN_STATS = 9,
	DCB_ATTR_DCB_BUFFER = 10,
	__DCB_ATTR_IEEE_MAX = 11,
};

enum ieee_attrs_app {
	DCB_ATTR_IEEE_APP_UNSPEC = 0,
	DCB_ATTR_IEEE_APP = 1,
	__DCB_ATTR_IEEE_APP_MAX = 2,
};

enum cee_attrs {
	DCB_ATTR_CEE_UNSPEC = 0,
	DCB_ATTR_CEE_PEER_PG = 1,
	DCB_ATTR_CEE_PEER_PFC = 2,
	DCB_ATTR_CEE_PEER_APP_TABLE = 3,
	DCB_ATTR_CEE_TX_PG = 4,
	DCB_ATTR_CEE_RX_PG = 5,
	DCB_ATTR_CEE_PFC = 6,
	DCB_ATTR_CEE_APP_TABLE = 7,
	DCB_ATTR_CEE_FEAT = 8,
	__DCB_ATTR_CEE_MAX = 9,
};

enum peer_app_attr {
	DCB_ATTR_CEE_PEER_APP_UNSPEC = 0,
	DCB_ATTR_CEE_PEER_APP_INFO = 1,
	DCB_ATTR_CEE_PEER_APP = 2,
	__DCB_ATTR_CEE_PEER_APP_MAX = 3,
};

enum dcbnl_pfc_up_attrs {
	DCB_PFC_UP_ATTR_UNDEFINED = 0,
	DCB_PFC_UP_ATTR_0 = 1,
	DCB_PFC_UP_ATTR_1 = 2,
	DCB_PFC_UP_ATTR_2 = 3,
	DCB_PFC_UP_ATTR_3 = 4,
	DCB_PFC_UP_ATTR_4 = 5,
	DCB_PFC_UP_ATTR_5 = 6,
	DCB_PFC_UP_ATTR_6 = 7,
	DCB_PFC_UP_ATTR_7 = 8,
	DCB_PFC_UP_ATTR_ALL = 9,
	__DCB_PFC_UP_ATTR_ENUM_MAX = 10,
	DCB_PFC_UP_ATTR_MAX = 9,
};

enum dcbnl_pg_attrs {
	DCB_PG_ATTR_UNDEFINED = 0,
	DCB_PG_ATTR_TC_0 = 1,
	DCB_PG_ATTR_TC_1 = 2,
	DCB_PG_ATTR_TC_2 = 3,
	DCB_PG_ATTR_TC_3 = 4,
	DCB_PG_ATTR_TC_4 = 5,
	DCB_PG_ATTR_TC_5 = 6,
	DCB_PG_ATTR_TC_6 = 7,
	DCB_PG_ATTR_TC_7 = 8,
	DCB_PG_ATTR_TC_MAX = 9,
	DCB_PG_ATTR_TC_ALL = 10,
	DCB_PG_ATTR_BW_ID_0 = 11,
	DCB_PG_ATTR_BW_ID_1 = 12,
	DCB_PG_ATTR_BW_ID_2 = 13,
	DCB_PG_ATTR_BW_ID_3 = 14,
	DCB_PG_ATTR_BW_ID_4 = 15,
	DCB_PG_ATTR_BW_ID_5 = 16,
	DCB_PG_ATTR_BW_ID_6 = 17,
	DCB_PG_ATTR_BW_ID_7 = 18,
	DCB_PG_ATTR_BW_ID_MAX = 19,
	DCB_PG_ATTR_BW_ID_ALL = 20,
	__DCB_PG_ATTR_ENUM_MAX = 21,
	DCB_PG_ATTR_MAX = 20,
};

enum dcbnl_tc_attrs {
	DCB_TC_ATTR_PARAM_UNDEFINED = 0,
	DCB_TC_ATTR_PARAM_PGID = 1,
	DCB_TC_ATTR_PARAM_UP_MAPPING = 2,
	DCB_TC_ATTR_PARAM_STRICT_PRIO = 3,
	DCB_TC_ATTR_PARAM_BW_PCT = 4,
	DCB_TC_ATTR_PARAM_ALL = 5,
	__DCB_TC_ATTR_PARAM_ENUM_MAX = 6,
	DCB_TC_ATTR_PARAM_MAX = 5,
};

enum dcbnl_cap_attrs {
	DCB_CAP_ATTR_UNDEFINED = 0,
	DCB_CAP_ATTR_ALL = 1,
	DCB_CAP_ATTR_PG = 2,
	DCB_CAP_ATTR_PFC = 3,
	DCB_CAP_ATTR_UP2TC = 4,
	DCB_CAP_ATTR_PG_TCS = 5,
	DCB_CAP_ATTR_PFC_TCS = 6,
	DCB_CAP_ATTR_GSP = 7,
	DCB_CAP_ATTR_BCN = 8,
	DCB_CAP_ATTR_DCBX = 9,
	__DCB_CAP_ATTR_ENUM_MAX = 10,
	DCB_CAP_ATTR_MAX = 9,
};

enum dcbnl_numtcs_attrs {
	DCB_NUMTCS_ATTR_UNDEFINED = 0,
	DCB_NUMTCS_ATTR_ALL = 1,
	DCB_NUMTCS_ATTR_PG = 2,
	DCB_NUMTCS_ATTR_PFC = 3,
	__DCB_NUMTCS_ATTR_ENUM_MAX = 4,
	DCB_NUMTCS_ATTR_MAX = 3,
};

enum dcbnl_bcn_attrs {
	DCB_BCN_ATTR_UNDEFINED = 0,
	DCB_BCN_ATTR_RP_0 = 1,
	DCB_BCN_ATTR_RP_1 = 2,
	DCB_BCN_ATTR_RP_2 = 3,
	DCB_BCN_ATTR_RP_3 = 4,
	DCB_BCN_ATTR_RP_4 = 5,
	DCB_BCN_ATTR_RP_5 = 6,
	DCB_BCN_ATTR_RP_6 = 7,
	DCB_BCN_ATTR_RP_7 = 8,
	DCB_BCN_ATTR_RP_ALL = 9,
	DCB_BCN_ATTR_BCNA_0 = 10,
	DCB_BCN_ATTR_BCNA_1 = 11,
	DCB_BCN_ATTR_ALPHA = 12,
	DCB_BCN_ATTR_BETA = 13,
	DCB_BCN_ATTR_GD = 14,
	DCB_BCN_ATTR_GI = 15,
	DCB_BCN_ATTR_TMAX = 16,
	DCB_BCN_ATTR_TD = 17,
	DCB_BCN_ATTR_RMIN = 18,
	DCB_BCN_ATTR_W = 19,
	DCB_BCN_ATTR_RD = 20,
	DCB_BCN_ATTR_RU = 21,
	DCB_BCN_ATTR_WRTT = 22,
	DCB_BCN_ATTR_RI = 23,
	DCB_BCN_ATTR_C = 24,
	DCB_BCN_ATTR_ALL = 25,
	__DCB_BCN_ATTR_ENUM_MAX = 26,
	DCB_BCN_ATTR_MAX = 25,
};

enum dcb_general_attr_values {
	DCB_ATTR_VALUE_UNDEFINED = 255,
};

enum dcbnl_app_attrs {
	DCB_APP_ATTR_UNDEFINED = 0,
	DCB_APP_ATTR_IDTYPE = 1,
	DCB_APP_ATTR_ID = 2,
	DCB_APP_ATTR_PRIORITY = 3,
	__DCB_APP_ATTR_ENUM_MAX = 4,
	DCB_APP_ATTR_MAX = 3,
};

enum dcbnl_featcfg_attrs {
	DCB_FEATCFG_ATTR_UNDEFINED = 0,
	DCB_FEATCFG_ATTR_ALL = 1,
	DCB_FEATCFG_ATTR_PG = 2,
	DCB_FEATCFG_ATTR_PFC = 3,
	DCB_FEATCFG_ATTR_APP = 4,
	__DCB_FEATCFG_ATTR_ENUM_MAX = 5,
	DCB_FEATCFG_ATTR_MAX = 4,
};

struct dcb_app_type {
	int ifindex;
	struct dcb_app app;
	struct list_head list;
	u8 dcbx;
};

struct dcb_ieee_app_prio_map {
	u64 map[8];
};

struct dcb_ieee_app_dscp_map {
	u8 map[64];
};

enum dcbevent_notif_type {
	DCB_APP_EVENT = 1,
};

struct reply_func {
	int type;
	int (*cb)(struct net_device___114 *, struct nlmsghdr *, u32, struct nlattr **, struct sk_buff___115 *);
};

struct nsh_md1_ctx {
	__be32 context[4];
};

struct nsh_md2_tlv {
	__be16 md_class;
	u8 type;
	u8 length;
	u8 md_value[0];
};

struct nshhdr {
	__be16 ver_flags_ttl_len;
	u8 mdtype;
	u8 np;
	__be32 path_hdr;
	union {
		struct nsh_md1_ctx md1;
		struct nsh_md2_tlv md2;
	};
};

typedef int br_should_route_hook_t___4(struct sk_buff___115 *);

struct switchdev_trans_item {
	struct list_head list;
	void *data;
	void (*destructor)(const void *);
};

enum switchdev_notifier_type {
	SWITCHDEV_FDB_ADD_TO_BRIDGE = 1,
	SWITCHDEV_FDB_DEL_TO_BRIDGE = 2,
	SWITCHDEV_FDB_ADD_TO_DEVICE = 3,
	SWITCHDEV_FDB_DEL_TO_DEVICE = 4,
	SWITCHDEV_FDB_OFFLOADED = 5,
	SWITCHDEV_PORT_OBJ_ADD = 6,
	SWITCHDEV_PORT_OBJ_DEL = 7,
	SWITCHDEV_PORT_ATTR_SET = 8,
	SWITCHDEV_VXLAN_FDB_ADD_TO_BRIDGE = 9,
	SWITCHDEV_VXLAN_FDB_DEL_TO_BRIDGE = 10,
	SWITCHDEV_VXLAN_FDB_ADD_TO_DEVICE = 11,
	SWITCHDEV_VXLAN_FDB_DEL_TO_DEVICE = 12,
	SWITCHDEV_VXLAN_FDB_OFFLOADED = 13,
};

struct switchdev_notifier_info {
	struct net_device___114 *dev;
	struct netlink_ext_ack *extack;
};

struct switchdev_notifier_port_obj_info {
	struct switchdev_notifier_info info;
	const struct switchdev_obj *obj;
	struct switchdev_trans *trans;
	bool handled;
};

struct switchdev_notifier_port_attr_info {
	struct switchdev_notifier_info info;
	const struct switchdev_attr *attr;
	struct switchdev_trans *trans;
	bool handled;
};

typedef void switchdev_deferred_func_t(struct net_device___114 *, const void *);

struct switchdev_deferred_item {
	struct list_head list;
	struct net_device___114 *dev;
	switchdev_deferred_func_t *func;
	long unsigned int data[0];
};

struct sockaddr_xdp {
	__u16 sxdp_family;
	__u16 sxdp_flags;
	__u32 sxdp_ifindex;
	__u32 sxdp_queue_id;
	__u32 sxdp_shared_umem_fd;
};

struct xdp_ring_offset {
	__u64 producer;
	__u64 consumer;
	__u64 desc;
};

struct xdp_mmap_offsets {
	struct xdp_ring_offset rx;
	struct xdp_ring_offset tx;
	struct xdp_ring_offset fr;
	struct xdp_ring_offset cr;
};

struct xdp_umem_reg {
	__u64 addr;
	__u64 len;
	__u32 chunk_size;
	__u32 headroom;
};

struct xdp_statistics {
	__u64 rx_dropped;
	__u64 rx_invalid_descs;
	__u64 tx_invalid_descs;
};

struct xdp_desc {
	__u64 addr;
	__u32 len;
	__u32 options;
};

struct module___397;

struct file___471;

struct kiocb___471;

struct iov_iter___238;

struct poll_table_struct___310;

struct vm_area_struct___472;

struct inode___471;

struct file_lock___471;

struct page___472;

struct pipe_inode_info___152;

struct seq_file___410;

struct file_operations___471 {
	struct module___397 *owner;
	loff_t (*llseek)(struct file___471 *, loff_t, int);
	ssize_t (*read)(struct file___471 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___471 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___471 *, struct iov_iter___238 *);
	ssize_t (*write_iter)(struct kiocb___471 *, struct iov_iter___238 *);
	int (*iopoll)(struct kiocb___471 *, bool);
	int (*iterate)(struct file___471 *, struct dir_context *);
	int (*iterate_shared)(struct file___471 *, struct dir_context *);
	__poll_t (*poll)(struct file___471 *, struct poll_table_struct___310 *);
	long int (*unlocked_ioctl)(struct file___471 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___471 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___471 *, struct vm_area_struct___472 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___471 *, struct file___471 *);
	int (*flush)(struct file___471 *, fl_owner_t);
	int (*release)(struct inode___471 *, struct file___471 *);
	int (*fsync)(struct file___471 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___471 *, int);
	int (*lock)(struct file___471 *, int, struct file_lock___471 *);
	ssize_t (*sendpage)(struct file___471 *, struct page___472 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___471 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___471 *, int, struct file_lock___471 *);
	ssize_t (*splice_write)(struct pipe_inode_info___152 *, struct file___471 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___471 *, loff_t *, struct pipe_inode_info___152 *, size_t, unsigned int);
	int (*setlease)(struct file___471 *, long int, struct file_lock___471 **, void **);
	long int (*fallocate)(struct file___471 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___410 *, struct file___471 *);
	ssize_t (*copy_file_range)(struct file___471 *, loff_t, struct file___471 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___471 *, loff_t, struct file___471 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___471 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___472 {
	u64 seqnum;
	struct vm_area_struct___472 *vmas[4];
};

struct page_frag___472 {
	struct page___472 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___472;

struct mem_cgroup___204;

struct cred___439;

struct nsproxy___366;

struct signal_struct___346;

struct bio_list___261;

struct backing_dev_info___261;

struct css_set___320;

struct vm_struct___375;

struct task_struct___473 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___473 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___472 *mm;
	struct mm_struct___472 *active_mm;
	struct vmacache___472 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___473 *real_parent;
	struct task_struct___473 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___473 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___204 *active_memcg;
	long int rh_reserved2;
	struct pid___264 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___264 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___264 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___439 *ptracer_cred;
	const struct cred___439 *real_cred;
	const struct cred___439 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___366 *nsproxy;
	struct signal_struct___346 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___473 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___261 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___261 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___320 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___152 *splice_pipe;
	struct page_frag___472 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___204 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___473 *oom_reaper_list;
	struct vm_struct___375 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___157 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rw_semaphore___473 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___473 *owner;
};

struct key___439;

struct ucounts___336;

struct user_namespace___336 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___336 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___29 ns;
	long unsigned int flags;
	struct key___439 *persistent_keyring_register;
	struct rw_semaphore___473 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___336 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct secondary_data___473 {
	void *stack;
	struct task_struct___473 *task;
	long int status;
};

typedef struct page___472 *pgtable_t___472;

struct address_space___471;

struct dev_pagemap___459;

struct page___472 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___471 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___472 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___472 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___472 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___459 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___204 *mem_cgroup;
};

struct user_struct___439 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___439 *uid_keyring;
	struct key___439 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___459;

struct vm_area_struct___472 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___472 *vm_next;
	struct vm_area_struct___472 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___472 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___459 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___471 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___472;

struct mm_struct___472 {
	struct {
		struct vm_area_struct___472 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___471 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___473 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___472 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___473 *owner;
		struct user_namespace___336 *user_ns;
		struct file___471 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___472 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup___320;

struct cgroup_subsys___320;

struct cgroup_subsys_state___320 {
	struct cgroup___320 *cgroup;
	struct cgroup_subsys___320 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___320 *parent;
};

struct kernfs_node___466;

struct cgroup_file___320 {
	struct kernfs_node___466 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___204;

struct mem_cgroup___204 {
	struct cgroup_subsys_state___320 css;
	struct mem_cgroup_id___16 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___320 events_file;
	struct cgroup_file___320 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___473 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___204 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cred___439 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___439 *session_keyring;
	struct key___439 *process_keyring;
	struct key___439 *thread_keyring;
	struct key___439 *request_key_auth;
	void *security;
	struct user_struct___439 *user;
	struct user_namespace___336 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___127;

struct cgroup_namespace___320;

struct nsproxy___366 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net___127 *net_ns;
	struct cgroup_namespace___320 *cgroup_ns;
};

struct signal_struct___346 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___473 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___473 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___264 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___264 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___472 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___264 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___261;

struct bio_list___261 {
	struct bio___261 *head;
	struct bio___261 *tail;
};

struct bdi_writeback_congested___261;

struct bdi_writeback___261 {
	struct backing_dev_info___261 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___261 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___320 *memcg_css;
	struct cgroup_subsys_state___320 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___439;

struct dentry___471;

struct backing_dev_info___261 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___261 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___439 *dev;
	struct device___439 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___471 *debug_dir;
	struct dentry___471 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___320 {
	struct cgroup_subsys_state___320 *subsys[13];
	refcount_t refcount;
	struct css_set___320 *dom_cset;
	struct cgroup___320 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___320 *mg_src_cgrp;
	struct cgroup___320 *mg_dst_cgrp;
	struct css_set___320 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___471;

struct pipe_buffer___152;

struct pipe_inode_info___152 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___472 *tmp_page;
	struct fasync_struct___471 *fasync_readers;
	struct fasync_struct___471 *fasync_writers;
	struct pipe_buffer___152 *bufs;
	struct user_struct___439 *user;
};

struct vm_struct___375 {
	struct vm_struct___375 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___472 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___358 {
	struct task_struct___473 task;
	long unsigned int stack[8192];
};

struct address_space_operations___471;

struct address_space___471 {
	struct inode___471 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___473 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___471 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___459)(struct vm_area_struct___472 *, long unsigned int, const struct page___472 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___459)(struct page___472 *, void *);

struct dev_pagemap___459 {
	dev_page_fault_t___459 page_fault;
	dev_page_free_t___459 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___439 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___472 {
	struct vfsmount *mnt;
	struct dentry___471 *dentry;
};

struct file___471 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___472 f_path;
	struct inode___471 *f_inode;
	const struct file_operations___471 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___264 f_owner;
	const struct cred___439 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___471 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___459;

struct vm_operations_struct___459 {
	void (*open)(struct vm_area_struct___472 *);
	void (*close)(struct vm_area_struct___472 *);
	int (*split)(struct vm_area_struct___472 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___472 *);
	vm_fault_t (*fault)(struct vm_fault___459 *);
	vm_fault_t (*huge_fault)(struct vm_fault___459 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___459 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___472 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___459 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___459 *);
	int (*access)(struct vm_area_struct___472 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___472 *);
	int (*set_policy)(struct vm_area_struct___472 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___472 *, long unsigned int);
	struct page___472 * (*find_special_page)(struct vm_area_struct___472 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___472 {
	struct task_struct___473 *task;
	struct core_thread___472 *next;
};

struct core_state___472 {
	atomic_t nr_threads;
	struct core_thread___472 dumper;
	struct completion startup;
};

struct vm_fault___459 {
	struct vm_area_struct___472 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___472 *cow_page;
	struct mem_cgroup___204 *memcg;
	struct page___472 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___472 prealloc_pte;
};

struct pglist_data___472;

struct lruvec___472 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___472 *pgdat;
};

struct zone___472 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___472 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___472 {
	struct zone___472 *zone;
	int zone_idx;
};

struct zonelist___472 {
	struct zoneref___472 _zonerefs[25];
};

struct pglist_data___472 {
	struct zone___472 node_zones[3];
	struct zonelist___472 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___473 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___473 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___472 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___472 {
	struct rw_semaphore___473 rwsem;
	struct notifier_block *head;
};

typedef int (*key_restrict_link_func_t___440)(struct key___439 *, const struct key_type *, const union key_payload *, struct key___439 *);

struct key_restriction___439;

struct key___439 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___473 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___439 *restrict_link;
};

struct key_restriction___439 {
	key_restrict_link_func_t___440 check;
	struct key___439 *key;
	struct key_type *keytype;
};

struct kset___458;

struct kobj_type___458;

struct kobject___459 {
	const char *name;
	struct list_head entry;
	struct kobject___459 *parent;
	struct kset___458 *kset;
	struct kobj_type___458 *ktype;
	struct kernfs_node___466 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___397 {
	struct kobject___459 kobj;
	struct module___397 *mod;
	struct kobject___459 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___397 {
	struct module___397 *mod;
	struct latch_tree_node node;
};

struct module_layout___397 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___397 mtn;
};

struct module_attribute___397;

struct kernel_param___397;

struct module___397 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___397 mkobj;
	struct module_attribute___397 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___459 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___397 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___397 core_layout;
	struct module_layout___397 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide53;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide54;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bio_vec___263 {
	struct page___472 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___238 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___263 *bvec;
		struct pipe_inode_info___152 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct msghdr___99 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___238 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___471 *msg_iocb;
};

struct kiocb___471 {
	struct file___471 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___471 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dentry_operations___471;

struct super_block___471;

struct dentry___471 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___471 *d_parent;
	struct qstr d_name;
	struct inode___471 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___471 *d_op;
	struct super_block___471 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___471;

struct block_device___471;

struct inode___471 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___471 *i_op;
	struct super_block___471 *i_sb;
	struct address_space___471 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___473 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___261 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___471 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___471 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___152 *i_pipe;
		struct block_device___471 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___471 {
	int (*d_revalidate)(struct dentry___471 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___471 *, unsigned int);
	int (*d_hash)(const struct dentry___471 *, struct qstr *);
	int (*d_compare)(const struct dentry___471 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___471 *);
	int (*d_init)(struct dentry___471 *);
	void (*d_release)(struct dentry___471 *);
	void (*d_prune)(struct dentry___471 *);
	void (*d_iput)(struct dentry___471 *, struct inode___471 *);
	char * (*d_dname)(struct dentry___471 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___472 *);
	int (*d_manage)(const struct path___472 *, bool);
	struct dentry___471 * (*d_real)(struct dentry___471 *, const struct inode___471 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___471;

struct mem_dqinfo___471 {
	struct quota_format_type___471 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___471;

struct quota_info___471 {
	unsigned int flags;
	struct rw_semaphore___473 dqio_sem;
	struct inode___471 *files[3];
	struct mem_dqinfo___471 info[3];
	const struct quota_format_ops___471 *ops[3];
};

struct rcuwait___471 {
	struct task_struct___473 *task;
};

struct percpu_rw_semaphore___471 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___473 rw_sem;
	struct rcuwait___471 writer;
	int readers_block;
};

struct sb_writers___471 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___471 rw_sem[3];
};

struct shrink_control___204;

struct shrinker___204 {
	long unsigned int (*count_objects)(struct shrinker___204 *, struct shrink_control___204 *);
	long unsigned int (*scan_objects)(struct shrinker___204 *, struct shrink_control___204 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___471;

struct super_operations___471;

struct dquot_operations___471;

struct quotactl_ops___471;

struct super_block___471 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___471 *s_type;
	const struct super_operations___471 *s_op;
	const struct dquot_operations___471 *dq_op;
	const struct quotactl_ops___471 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___471 *s_root;
	struct rw_semaphore___473 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___471 *s_bdev;
	struct backing_dev_info___261 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___471 s_dquot;
	struct sb_writers___471 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___471 *s_d_op;
	int cleancache_poolid;
	struct shrinker___204 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___336 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___204 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___204 *memcg;
};

struct iattr___471 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___471 *ia_file;
};

struct dquot___471 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___471 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___471 {
	int qf_fmt_id;
	const struct quota_format_ops___471 *qf_ops;
	struct module___397 *qf_owner;
	struct quota_format_type___471 *qf_next;
};

struct quota_format_ops___471 {
	int (*check_quota_file)(struct super_block___471 *, int);
	int (*read_file_info)(struct super_block___471 *, int);
	int (*write_file_info)(struct super_block___471 *, int);
	int (*free_file_info)(struct super_block___471 *, int);
	int (*read_dqblk)(struct dquot___471 *);
	int (*commit_dqblk)(struct dquot___471 *);
	int (*release_dqblk)(struct dquot___471 *);
	int (*get_next_id)(struct super_block___471 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___471 {
	int (*write_dquot)(struct dquot___471 *);
	struct dquot___471 * (*alloc_dquot)(struct super_block___471 *, int);
	void (*destroy_dquot)(struct dquot___471 *);
	int (*acquire_dquot)(struct dquot___471 *);
	int (*release_dquot)(struct dquot___471 *);
	int (*mark_dirty)(struct dquot___471 *);
	int (*write_info)(struct super_block___471 *, int);
	qsize_t * (*get_reserved_space)(struct inode___471 *);
	int (*get_projid)(struct inode___471 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___471 *, qsize_t *);
	int (*get_next_id)(struct super_block___471 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___471 {
	int (*quota_on)(struct super_block___471 *, int, int, const struct path___472 *);
	int (*quota_off)(struct super_block___471 *, int);
	int (*quota_enable)(struct super_block___471 *, unsigned int);
	int (*quota_disable)(struct super_block___471 *, unsigned int);
	int (*quota_sync)(struct super_block___471 *, int);
	int (*set_info)(struct super_block___471 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___471 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___471 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___471 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___471 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___471 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___224;

struct address_space_operations___471 {
	int (*writepage)(struct page___472 *, struct writeback_control___224 *);
	int (*readpage)(struct file___471 *, struct page___472 *);
	int (*writepages)(struct address_space___471 *, struct writeback_control___224 *);
	int (*set_page_dirty)(struct page___472 *);
	int (*readpages)(struct file___471 *, struct address_space___471 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___471 *, struct address_space___471 *, loff_t, unsigned int, unsigned int, struct page___472 **, void **);
	int (*write_end)(struct file___471 *, struct address_space___471 *, loff_t, unsigned int, unsigned int, struct page___472 *, void *);
	sector_t (*bmap)(struct address_space___471 *, sector_t);
	void (*invalidatepage)(struct page___472 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___472 *, gfp_t);
	void (*freepage)(struct page___472 *);
	ssize_t (*direct_IO)(struct kiocb___471 *, struct iov_iter___238 *);
	int (*migratepage)(struct address_space___471 *, struct page___472 *, struct page___472 *, enum migrate_mode);
	bool (*isolate_page)(struct page___472 *, isolate_mode_t);
	void (*putback_page)(struct page___472 *);
	int (*launder_page)(struct page___472 *);
	int (*is_partially_uptodate)(struct page___472 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___472 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___471 *, struct page___472 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___471 *, sector_t *);
	void (*swap_deactivate)(struct file___471 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___224 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___261 *wb;
	struct inode___471 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___471 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___471 *bd_inode;
	struct super_block___471 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___471 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___261 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___471 {
	struct dentry___471 * (*lookup)(struct inode___471 *, struct dentry___471 *, unsigned int);
	const char * (*get_link)(struct dentry___471 *, struct inode___471 *, struct delayed_call *);
	int (*permission)(struct inode___471 *, int);
	struct posix_acl * (*get_acl)(struct inode___471 *, int);
	int (*readlink)(struct dentry___471 *, char *, int);
	int (*create)(struct inode___471 *, struct dentry___471 *, umode_t, bool);
	int (*link)(struct dentry___471 *, struct inode___471 *, struct dentry___471 *);
	int (*unlink)(struct inode___471 *, struct dentry___471 *);
	int (*symlink)(struct inode___471 *, struct dentry___471 *, const char *);
	int (*mkdir)(struct inode___471 *, struct dentry___471 *, umode_t);
	int (*rmdir)(struct inode___471 *, struct dentry___471 *);
	int (*mknod)(struct inode___471 *, struct dentry___471 *, umode_t, dev_t);
	int (*rename)(struct inode___471 *, struct dentry___471 *, struct inode___471 *, struct dentry___471 *, unsigned int);
	int (*setattr)(struct dentry___471 *, struct iattr___471 *);
	int (*getattr)(const struct path___472 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___471 *, char *, size_t);
	int (*fiemap)(struct inode___471 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___471 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___471 *, struct dentry___471 *, struct file___471 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___471 *, struct dentry___471 *, umode_t);
	int (*set_acl)(struct inode___471 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___471 {
	void (*fl_copy_lock)(struct file_lock___471 *, struct file_lock___471 *);
	void (*fl_release_private)(struct file_lock___471 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___471;

struct file_lock___471 {
	struct file_lock___471 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___471 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___471 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___471 *fl_ops;
	const struct lock_manager_operations___471 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___471 {
	int (*lm_compare_owner)(struct file_lock___471 *, struct file_lock___471 *);
	long unsigned int (*lm_owner_key)(struct file_lock___471 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___471 *);
	int (*lm_grant)(struct file_lock___471 *, int);
	bool (*lm_break)(struct file_lock___471 *);
	int (*lm_change)(struct file_lock___471 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___471 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___471 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___471 *fa_next;
	struct file___471 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___471 {
	const char *name;
	int fs_flags;
	struct dentry___471 * (*mount)(struct file_system_type___471 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___471 *);
	struct module___397 *owner;
	struct file_system_type___471 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___471 {
	struct inode___471 * (*alloc_inode)(struct super_block___471 *);
	void (*destroy_inode)(struct inode___471 *);
	void (*dirty_inode)(struct inode___471 *, int);
	int (*write_inode)(struct inode___471 *, struct writeback_control___224 *);
	int (*drop_inode)(struct inode___471 *);
	void (*evict_inode)(struct inode___471 *);
	void (*put_super)(struct super_block___471 *);
	int (*sync_fs)(struct super_block___471 *, int);
	int (*freeze_super)(struct super_block___471 *);
	int (*freeze_fs)(struct super_block___471 *);
	int (*thaw_super)(struct super_block___471 *);
	int (*unfreeze_fs)(struct super_block___471 *);
	int (*statfs)(struct dentry___471 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___471 *, int *, char *);
	void (*umount_begin)(struct super_block___471 *);
	int (*show_options)(struct seq_file___410 *, struct dentry___471 *);
	int (*show_devname)(struct seq_file___410 *, struct dentry___471 *);
	int (*show_path)(struct seq_file___410 *, struct dentry___471 *);
	int (*show_stats)(struct seq_file___410 *, struct dentry___471 *);
	ssize_t (*quota_read)(struct super_block___471 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___471 *, int, const char *, size_t, loff_t);
	struct dquot___471 ** (*get_dquots)(struct inode___471 *);
	int (*bdev_try_to_free_page)(struct super_block___471 *, struct page___472 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___471 *, struct shrink_control___204 *);
	long int (*free_cached_objects)(struct super_block___471 *, struct shrink_control___204 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___320)(struct file___471 *, wait_queue_head_t *, struct poll_table_struct___310 *);

struct poll_table_struct___310 {
	poll_queue_proc___320 _qproc;
	__poll_t _key;
};

struct seq_operations___410;

struct seq_file___410 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___410 *op;
	int poll_event;
	const struct file___471 *file;
	void *private;
};

typedef void bio_end_io_t___261(struct bio___261 *);

struct bio_integrity_payload___261;

struct bio_set___261;

struct bio___261 {
	struct bio___261 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___261 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___261 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___263 *bi_io_vec;
	struct bio_set___261 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___263 bi_inline_vecs[0];
};

struct socket_wq___97 {
	wait_queue_head_t wait;
	struct fasync_struct___471 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct sock___96;

struct proto_ops___97;

struct socket___98 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___97 *wq;
	struct file___471 *file;
	struct sock___96 *sk;
	const struct proto_ops___97 *ops;
};

typedef struct {
	struct net___127 *net;
} possible_net_t___118;

struct proto___96;

struct sock_common___96 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___96 *skc_prot;
	possible_net_t___118 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___96 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___117;

struct sk_buff_head___116 {
	struct sk_buff___117 *next;
	struct sk_buff___117 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___96;

struct dst_entry___96;

struct net_device___116;

struct sock___96 {
	struct sock_common___96 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___116 sk_error_queue;
	struct sk_buff_head___116 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___117 *head;
		struct sk_buff___117 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___96 *sk_filter;
	union {
		struct socket_wq___97 *sk_wq;
		struct socket_wq___97 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___96 *sk_rx_dst;
	struct dst_entry___96 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___117 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___116 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___472 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___96 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___264 *sk_peer_pid;
	const struct cred___439 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___98 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___204 *sk_memcg;
	void (*sk_state_change)(struct sock___96 *);
	void (*sk_data_ready)(struct sock___96 *);
	void (*sk_write_space)(struct sock___96 *);
	void (*sk_error_report)(struct sock___96 *);
	int (*sk_backlog_rcv)(struct sock___96 *, struct sk_buff___117 *);
	struct sk_buff___117 * (*sk_validate_xmit_skb)(struct sock___96 *, struct net_device___116 *, struct sk_buff___117 *);
	void (*sk_destruct)(struct sock___96 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

typedef int (*sk_read_actor_t___96)(read_descriptor_t *, struct sk_buff___117 *, unsigned int, size_t);

struct proto_ops___97 {
	int family;
	struct module___397 *owner;
	int (*release)(struct socket___98 *);
	int (*bind)(struct socket___98 *, struct sockaddr *, int);
	int (*connect)(struct socket___98 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___98 *, struct socket___98 *);
	int (*accept)(struct socket___98 *, struct socket___98 *, int, bool);
	int (*getname)(struct socket___98 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___471 *, struct socket___98 *, struct poll_table_struct___310 *);
	int (*ioctl)(struct socket___98 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___98 *, int);
	int (*shutdown)(struct socket___98 *, int);
	int (*setsockopt)(struct socket___98 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___98 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___98 *, struct msghdr___99 *, size_t);
	int (*recvmsg)(struct socket___98 *, struct msghdr___99 *, size_t, int);
	int (*mmap)(struct file___471 *, struct socket___98 *, struct vm_area_struct___472 *);
	ssize_t (*sendpage)(struct socket___98 *, struct page___472 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___98 *, loff_t *, struct pipe_inode_info___152 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___96 *, int);
	int (*peek_len)(struct socket___98 *);
	int (*read_sock)(struct sock___96 *, read_descriptor_t *, sk_read_actor_t___96);
	int (*sendpage_locked)(struct sock___96 *, struct page___472 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___96 *, struct msghdr___99 *, size_t);
	int (*set_rcvlowat)(struct sock___96 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct nf_bridge_info___116;

struct sk_buff___117 {
	union {
		struct {
			struct sk_buff___117 *next;
			struct sk_buff___117 *prev;
			union {
				struct net_device___116 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___96 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___117 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___116 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct net_proto_family___7 {
	int family;
	int (*create)(struct net___127 *, struct socket___98 *, int, int);
	struct module___397 *owner;
};

struct inet_frags___116;

struct netns_frags___116 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___116 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_rules_ops___96;

struct fib_notifier_ops___97;

struct netns_ipv4___116 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___96 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___96 *fibnl;
	struct sock___96 **icmp_sk;
	struct sock___96 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___96 **tcp_sk;
	struct netns_frags___116 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___96 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___97 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___97 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___96;

struct dst_ops___127 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___127 *);
	struct dst_entry___96 * (*check)(struct dst_entry___96 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___96 *);
	unsigned int (*mtu)(const struct dst_entry___96 *);
	u32 * (*cow_metrics)(struct dst_entry___96 *, long unsigned int);
	void (*destroy)(struct dst_entry___96 *);
	void (*ifdown)(struct dst_entry___96 *, struct net_device___116 *, int);
	struct dst_entry___96 * (*negative_advice)(struct dst_entry___96 *);
	void (*link_failure)(struct sk_buff___117 *);
	void (*update_pmtu)(struct dst_entry___96 *, struct sock___96 *, struct sk_buff___117 *, u32);
	void (*redirect)(struct dst_entry___96 *, struct sock___96 *, struct sk_buff___117 *);
	int (*local_out)(struct net___127 *, struct sock___96 *, struct sk_buff___117 *);
	struct neighbour___96 * (*neigh_lookup)(const struct dst_entry___96 *, struct sk_buff___117 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___96 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___127 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___116 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___127 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___96 *fib6_rules_ops;
	struct sock___96 **icmp_sk;
	struct sock___96 *ndisc_sk;
	struct sock___96 *tcp_sk;
	struct sock___96 *igmp_sk;
	struct sock___96 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___96 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___97 *notifier_ops;
	struct fib_notifier_ops___97 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___97 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___96 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___116 {
	struct netns_frags___116 frags;
};

struct netns_xfrm___127 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___96 *nlsk;
	struct sock___96 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___127 xfrm4_dst_ops;
	struct dst_ops___127 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___106;

struct net___127 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___336 *user_ns;
	struct ucounts___336 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___29 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___96 *rtnl;
	struct sock___96 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___116 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___116 ipv4;
	struct netns_ipv6___127 ipv6;
	struct netns_sctp___97 sctp;
	struct netns_nf___23 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___116 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___96 *nfnl;
	struct sock___96 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___127 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___96 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___106 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kernfs_root___465;

struct kernfs_elem_dir___465 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___465 *root;
};

struct kernfs_syscall_ops___465;

struct kernfs_root___465 {
	struct kernfs_node___466 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___465 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___465 {
	struct kernfs_node___466 *target_kn;
};

struct kernfs_ops___465;

struct kernfs_elem_attr___465 {
	const struct kernfs_ops___465 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___466 *notify_next;
};

struct kernfs_node___466 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___466 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___465 dir;
		struct kernfs_elem_symlink___465 symlink;
		struct kernfs_elem_attr___465 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___465;

struct kernfs_ops___465 {
	int (*open)(struct kernfs_open_file___465 *);
	void (*release)(struct kernfs_open_file___465 *);
	int (*seq_show)(struct seq_file___410 *, void *);
	void * (*seq_start)(struct seq_file___410 *, loff_t *);
	void * (*seq_next)(struct seq_file___410 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___410 *, void *);
	ssize_t (*read)(struct kernfs_open_file___465 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___465 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___465 *, struct vm_area_struct___472 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___465 *, struct poll_table_struct___310 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide12;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___465 {
	int (*remount_fs)(struct kernfs_root___465 *, int *, char *);
	int (*show_options)(struct seq_file___410 *, struct kernfs_root___465 *);
	int (*mkdir)(struct kernfs_node___466 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___466 *);
	int (*rename)(struct kernfs_node___466 *, struct kernfs_node___466 *, const char *);
	int (*show_path)(struct seq_file___410 *, struct kernfs_node___466 *, struct kernfs_root___465 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___465 {
	struct kernfs_node___466 *kn;
	struct file___471 *file;
	struct seq_file___410 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___459 *vm_ops;
};

struct kobj_ns_type_operations___96 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___96 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___435;

struct attribute_group___436 {
	const char *name;
	umode_t (*is_visible)(struct kobject___459 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___459 *, struct bin_attribute___435 *, int);
	struct attribute **attrs;
	struct bin_attribute___435 **bin_attrs;
};

struct bin_attribute___435 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___471 *, struct kobject___459 *, struct bin_attribute___435 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___471 *, struct kobject___459 *, struct bin_attribute___435 *, char *, loff_t, size_t);
	int (*mmap)(struct file___471 *, struct kobject___459 *, struct bin_attribute___435 *, struct vm_area_struct___472 *);
};

struct sysfs_ops___458 {
	ssize_t (*show)(struct kobject___459 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___459 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___458;

struct kset___458 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___459 kobj;
	const struct kset_uevent_ops___458 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___458 {
	void (*release)(struct kobject___459 *);
	const struct sysfs_ops___458 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___96 * (*child_ns_type)(struct kobject___459 *);
	const void * (*namespace)(struct kobject___459 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___458 {
	int (* const filter)(struct kset___458 *, struct kobject___459 *);
	const char * (* const name)(struct kset___458 *, struct kobject___459 *);
	int (* const uevent)(struct kset___458 *, struct kobject___459 *, struct kobj_uevent_env *);
};

struct kobj_attribute___449 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___459 *, struct kobj_attribute___449 *, char *);
	ssize_t (*store)(struct kobject___459 *, struct kobj_attribute___449 *, const char *, size_t);
};

struct dev_pm_ops___439 {
	int (*prepare)(struct device___439 *);
	void (*complete)(struct device___439 *);
	int (*suspend)(struct device___439 *);
	int (*resume)(struct device___439 *);
	int (*freeze)(struct device___439 *);
	int (*thaw)(struct device___439 *);
	int (*poweroff)(struct device___439 *);
	int (*restore)(struct device___439 *);
	int (*suspend_late)(struct device___439 *);
	int (*resume_early)(struct device___439 *);
	int (*freeze_late)(struct device___439 *);
	int (*thaw_early)(struct device___439 *);
	int (*poweroff_late)(struct device___439 *);
	int (*restore_early)(struct device___439 *);
	int (*suspend_noirq)(struct device___439 *);
	int (*resume_noirq)(struct device___439 *);
	int (*freeze_noirq)(struct device___439 *);
	int (*thaw_noirq)(struct device___439 *);
	int (*poweroff_noirq)(struct device___439 *);
	int (*restore_noirq)(struct device___439 *);
	int (*runtime_suspend)(struct device___439 *);
	int (*runtime_resume)(struct device___439 *);
	int (*runtime_idle)(struct device___439 *);
};

struct dev_pm_info___439 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___439 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___439;

struct bus_type___439;

struct device_driver___439;

struct dev_pm_domain___439;

struct dma_map_ops___211;

struct fwnode_handle___359;

struct class___439;

struct device___439 {
	struct device___439 *parent;
	struct device_private *p;
	struct kobject___459 kobj;
	const char *init_name;
	const struct device_type___439 *type;
	struct mutex mutex;
	struct bus_type___439 *bus;
	struct device_driver___439 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___439 power;
	struct dev_pm_domain___439 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___211 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___359 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___439 *class;
	const struct attribute_group___436 **groups;
	void (*release)(struct device___439 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___439 {
	struct dev_pm_ops___439 ops;
	void (*detach)(struct device___439 *, bool);
	int (*activate)(struct device___439 *);
	void (*sync)(struct device___439 *);
	void (*dismiss)(struct device___439 *);
};

struct bus_type___439 {
	const char *name;
	const char *dev_name;
	struct device___439 *dev_root;
	const struct attribute_group___436 **bus_groups;
	const struct attribute_group___436 **dev_groups;
	const struct attribute_group___436 **drv_groups;
	int (*match)(struct device___439 *, struct device_driver___439 *);
	int (*uevent)(struct device___439 *, struct kobj_uevent_env *);
	int (*probe)(struct device___439 *);
	int (*remove)(struct device___439 *);
	void (*shutdown)(struct device___439 *);
	int (*online)(struct device___439 *);
	int (*offline)(struct device___439 *);
	int (*suspend)(struct device___439 *, pm_message_t);
	int (*resume)(struct device___439 *);
	int (*num_vf)(struct device___439 *);
	int (*dma_configure)(struct device___439 *);
	const struct dev_pm_ops___439 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___439 {
	const char *name;
	struct bus_type___439 *bus;
	struct module___397 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___439 *);
	int (*remove)(struct device___439 *);
	void (*shutdown)(struct device___439 *);
	int (*suspend)(struct device___439 *, pm_message_t);
	int (*resume)(struct device___439 *);
	const struct attribute_group___436 **groups;
	const struct dev_pm_ops___439 *pm;
	void (*coredump)(struct device___439 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___439 {
	const char *name;
	const struct attribute_group___436 **groups;
	int (*uevent)(struct device___439 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___439 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___439 *);
	const struct dev_pm_ops___439 *pm;
};

struct class___439 {
	const char *name;
	struct module___397 *owner;
	const struct attribute_group___436 **class_groups;
	const struct attribute_group___436 **dev_groups;
	struct kobject___459 *dev_kobj;
	int (*dev_uevent)(struct device___439 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___439 *, umode_t *);
	void (*class_release)(struct class___439 *);
	void (*dev_release)(struct device___439 *);
	int (*shutdown_pre)(struct device___439 *);
	const struct kobj_ns_type_operations___96 *ns_type;
	const void * (*namespace)(struct device___439 *);
	const struct dev_pm_ops___439 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___211 {
	void * (*alloc)(struct device___439 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___439 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___439 *, struct vm_area_struct___472 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___439 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___439 *, struct page___472 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___439 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___439 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___439 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___439 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___439 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___439 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___439 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___439 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___439 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___439 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___439 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___439 *, u64);
	u64 (*get_required_mask)(struct device___439 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___359;

struct fwnode_handle___359 {
	struct fwnode_handle___359 *secondary;
	const struct fwnode_operations___359 *ops;
};

typedef void compound_page_dtor___459(struct page___472 *);

struct fwnode_reference_args___359;

struct fwnode_endpoint___359;

struct fwnode_operations___359 {
	struct fwnode_handle___359 * (*get)(struct fwnode_handle___359 *);
	void (*put)(struct fwnode_handle___359 *);
	bool (*device_is_available)(const struct fwnode_handle___359 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___359 *, const struct device___439 *);
	bool (*property_present)(const struct fwnode_handle___359 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___359 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___359 *, const char *, const char **, size_t);
	struct fwnode_handle___359 * (*get_parent)(const struct fwnode_handle___359 *);
	struct fwnode_handle___359 * (*get_next_child_node)(const struct fwnode_handle___359 *, struct fwnode_handle___359 *);
	struct fwnode_handle___359 * (*get_named_child_node)(const struct fwnode_handle___359 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___359 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___359 *);
	struct fwnode_handle___359 * (*graph_get_next_endpoint)(const struct fwnode_handle___359 *, struct fwnode_handle___359 *);
	struct fwnode_handle___359 * (*graph_get_remote_endpoint)(const struct fwnode_handle___359 *);
	struct fwnode_handle___359 * (*graph_get_port_parent)(struct fwnode_handle___359 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___359 *, struct fwnode_endpoint___359 *);
};

struct fwnode_endpoint___359 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___359 *local_fwnode;
};

struct fwnode_reference_args___359 {
	struct fwnode_handle___359 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___152;

struct pipe_buffer___152 {
	struct page___472 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___152 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___152 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___152 *, struct pipe_buffer___152 *);
	void (*release)(struct pipe_inode_info___152 *, struct pipe_buffer___152 *);
	int (*steal)(struct pipe_inode_info___152 *, struct pipe_buffer___152 *);
	union {
		bool (*get)(struct pipe_inode_info___152 *, struct pipe_buffer___152 *);
		struct {
			void (*get)(struct pipe_inode_info___152 *, struct pipe_buffer___152 *);
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
};

struct nf_bridge_info___116 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___116 = 0,
		BRNF_PROTO_8021Q___116 = 1,
		BRNF_PROTO_PPPOE___116 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___116 *physindev;
	struct net_device___116 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___116(struct sk_buff___117 **);

struct net_device_ops___116;

struct ethtool_ops___116;

struct l3mdev_ops___96;

struct xfrmdev_ops___116;

struct tlsdev_ops___116;

struct header_ops___116;

struct netdev_rx_queue___116;

struct mini_Qdisc___108;

struct netdev_queue___116;

struct Qdisc___108;

struct rtnl_link_ops___108;

struct dcbnl_rtnl_ops___116;

struct net_device___116 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___116 *netdev_ops;
	const struct ethtool_ops___116 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___96 *l3mdev_ops;
	const struct ndisc_ops___2 *ndisc_ops;
	const struct xfrmdev_ops___116 *xfrmdev_ops;
	const struct tlsdev_ops___116 *tlsdev_ops;
	const struct header_ops___116 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___458 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___2 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___116 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___106 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___116 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___108 *miniq_ingress;
	struct netdev_queue___116 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___116 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___108 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___108 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___116 = 0,
		NETREG_REGISTERED___116 = 1,
		NETREG_UNREGISTERING___116 = 2,
		NETREG_UNREGISTERED___116 = 3,
		NETREG_RELEASED___116 = 4,
		NETREG_DUMMY___116 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___116 = 0,
		RTNL_LINK_INITIALIZING___116 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___116 *);
	struct netpoll_info *npinfo;
	possible_net_t___118 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___439 dev;
	const struct attribute_group___436 *sysfs_groups[4];
	const struct attribute_group___436 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___108 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___116 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct skb_frag_struct___32 {
	struct {
		struct page___472 *p;
	} page;
	__u32 page_offset;
	__u32 size;
};

typedef struct skb_frag_struct___32 skb_frag_t___32;

struct skb_shared_info___32 {
	__u8 __unused;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___117 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___32 frags[16];
};

struct ethtool_ops___116 {
	int (*get_settings)(struct net_device___116 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___116 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___116 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___116 *);
	void (*get_regs)(struct net_device___116 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___116 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___116 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___116 *);
	void (*set_msglevel)(struct net_device___116 *, u32);
	int (*nway_reset)(struct net_device___116 *);
	u32 (*get_link)(struct net_device___116 *);
	int (*get_eeprom_len)(struct net_device___116 *);
	int (*get_eeprom)(struct net_device___116 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___116 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___116 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___116 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___116 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___116 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___116 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___116 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___116 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___116 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___116 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___116 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___116 *);
	void (*complete)(struct net_device___116 *);
	u32 (*get_priv_flags)(struct net_device___116 *);
	int (*set_priv_flags)(struct net_device___116 *, u32);
	int (*get_sset_count)(struct net_device___116 *, int);
	int (*get_rxnfc)(struct net_device___116 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___116 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___116 *, struct ethtool_flash *);
	int (*reset)(struct net_device___116 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___116 *);
	u32 (*get_rxfh_indir_size)(struct net_device___116 *);
	int (*get_rxfh)(struct net_device___116 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___116 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___116 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___116 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___116 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___116 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___116 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___116 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___116 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___116 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___116 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___116 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___116 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___116 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___116 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___116 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___116 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___116 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___116 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___116 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___116 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___116 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	int (*get_fecparam)(struct net_device___116 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___116 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___116 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___116 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___116 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___116;

struct inet_frags___116 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___116 *, const void *);
	void (*destructor)(struct inet_frag_queue___116 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___116 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___117 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___117 *fragments_tail;
	struct sk_buff___117 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___116 *net;
	struct callback_head rcu;
};

struct fib_rule___96;

struct fib_lookup_arg___96;

struct fib_rules_ops___96 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___96 *, struct flowi *, int, struct fib_lookup_arg___96 *);
	bool (*suppress)(struct fib_rule___96 *, struct fib_lookup_arg___96 *);
	int (*match)(struct fib_rule___96 *, struct flowi *, int);
	int (*configure)(struct fib_rule___96 *, struct sk_buff___117 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___96 *);
	int (*compare)(struct fib_rule___96 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___96 *, struct sk_buff___117 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___96 *);
	void (*flush_cache)(struct fib_rules_ops___96 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___397 *owner;
	struct net___127 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___97 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___127 *);
	int (*fib_dump)(struct net___127 *, struct notifier_block *);
	struct module___397 *owner;
	struct callback_head rcu;
};

struct dst_entry___96 {
	struct net_device___116 *dev;
	struct dst_ops___127 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___117 *);
	int (*output)(struct net___127 *, struct sock___96 *, struct sk_buff___117 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___96;

struct neigh_parms___96;

struct neigh_ops___96;

struct neighbour___96 {
	struct neighbour___96 *next;
	struct neigh_table___96 *tbl;
	struct neigh_parms___96 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___116 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___96 *, struct sk_buff___117 *);
	const struct neigh_ops___96 *ops;
	struct callback_head rcu;
	struct net_device___116 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct ucounts___336 {
	struct hlist_node node;
	struct user_namespace___336 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_prog_aux___109;

struct bpf_prog___106 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___109 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

struct seq_operations___410 {
	void * (*start)(struct seq_file___410 *, loff_t *);
	void (*stop)(struct seq_file___410 *, void *);
	void * (*next)(struct seq_file___410 *, void *, loff_t *);
	int (*show)(struct seq_file___410 *, void *);
};

struct pernet_operations___117 {
	struct list_head list;
	int (*init)(struct net___127 *);
	void (*exit)(struct net___127 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___116 {
	int (*ieee_getets)(struct net_device___116 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___116 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___116 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___116 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___116 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___116 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___116 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___116 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___116 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___116 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___116 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___116 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___116 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___116 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___116 *);
	u8 (*setstate)(struct net_device___116 *, u8);
	void (*getpermhwaddr)(struct net_device___116 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___116 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___116 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___116 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___116 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___116 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___116 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___116 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___116 *, int, u8 *);
	void (*setpfccfg)(struct net_device___116 *, int, u8);
	void (*getpfccfg)(struct net_device___116 *, int, u8 *);
	u8 (*setall)(struct net_device___116 *);
	u8 (*getcap)(struct net_device___116 *, int, u8 *);
	int (*getnumtcs)(struct net_device___116 *, int, u8 *);
	int (*setnumtcs)(struct net_device___116 *, int, u8);
	u8 (*getpfcstate)(struct net_device___116 *);
	void (*setpfcstate)(struct net_device___116 *, u8);
	void (*getbcncfg)(struct net_device___116 *, int, u32 *);
	void (*setbcncfg)(struct net_device___116 *, int, u32);
	void (*getbcnrp)(struct net_device___116 *, int, u8 *);
	void (*setbcnrp)(struct net_device___116 *, int, u8);
	int (*setapp)(struct net_device___116 *, u8, u16, u8);
	int (*getapp)(struct net_device___116 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___116 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___116 *, int, u8);
	u8 (*getdcbx)(struct net_device___116 *);
	u8 (*setdcbx)(struct net_device___116 *, u8);
	int (*peer_getappinfo)(struct net_device___116 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___116 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___116 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___116 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___116 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___116 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___320 {
	refcount_t count;
	struct ns_common___29 ns;
	struct user_namespace___336 *user_ns;
	struct ucounts___336 *ucounts;
	struct css_set___320 *root_cset;
};

struct bpf_map___321;

struct bpf_map_ops___320 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___321 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___321 *, struct file___471 *);
	void (*map_free)(struct bpf_map___321 *);
	int (*map_get_next_key)(struct bpf_map___321 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___321 *);
	void * (*map_lookup_elem)(struct bpf_map___321 *, void *);
	int (*map_update_elem)(struct bpf_map___321 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___321 *, void *);
	int (*map_push_elem)(struct bpf_map___321 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___321 *, void *);
	int (*map_peek_elem)(struct bpf_map___321 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___321 *, struct file___471 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___321 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___321 *, void *, struct seq_file___410 *);
	int (*map_check_btf)(const struct bpf_map___321 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___321 {
	const struct bpf_map_ops___320 *ops;
	struct bpf_map___321 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___439 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___116;

struct bpf_map_dev_ops___116 {
	int (*map_get_next_key)(struct bpf_offloaded_map___116 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___116 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___116 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___116 *, void *);
};

struct bpf_offloaded_map___116 {
	struct bpf_map___321 map;
	struct net_device___116 *netdev;
	const struct bpf_map_dev_ops___116 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___106 {
	int (*test_run)(struct bpf_prog___106 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___106 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___106 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___106 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___106 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___106 *, u32 *);
};

struct bpf_prog_offload_ops___106 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___106 *);
	int (*translate)(struct bpf_prog___106 *);
	void (*destroy)(struct bpf_prog___106 *);
};

struct bpf_prog_offload___106 {
	struct bpf_prog___106 *prog;
	struct net_device___116 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___106 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___109 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___106 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___106 *ops;
	struct bpf_map___321 **used_maps;
	struct bpf_prog___106 *prog;
	struct user_struct___439 *user;
	u64 load_time;
	struct bpf_map___321 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___106 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___106 {
	struct bpf_prog___106 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___106 {
	struct callback_head rcu;
	struct bpf_prog_array_item___106 items[0];
};

struct cgroup_bpf___106 {
	struct bpf_prog_array___106 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___106 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___321;

typedef void (*kthread_work_func_t___321)(struct kthread_work___321 *);

struct kthread_worker___321;

struct kthread_work___321 {
	struct list_head node;
	kthread_work_func_t___321 func;
	struct kthread_worker___321 *worker;
	int canceling;
};

struct kthread_worker___321 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___473 *task;
	struct kthread_work___321 *current_work;
};

struct kthread_delayed_work___320 {
	struct kthread_work___321 work;
	struct timer_list timer;
};

struct psi_group___320 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___321 *poll_kworker;
	struct kthread_delayed_work___320 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___320;

struct cgroup_rstat_cpu___320;

struct cgroup___320 {
	struct cgroup_subsys_state___320 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___466 *kn;
	struct cgroup_file___320 procs_file;
	struct cgroup_file___320 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___320 *subsys[13];
	struct cgroup_root___320 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___320 *dom_cgrp;
	struct cgroup_rstat_cpu___320 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___106 bpf;
	atomic_t congestion_count;
	struct cgroup___320 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___320 psi;
	int ancestor_ids[0];
};

struct cftype___320;

struct cgroup_subsys___320 {
	struct cgroup_subsys_state___320 * (*css_alloc)(struct cgroup_subsys_state___320 *);
	int (*css_online)(struct cgroup_subsys_state___320 *);
	void (*css_offline)(struct cgroup_subsys_state___320 *);
	void (*css_released)(struct cgroup_subsys_state___320 *);
	void (*css_free)(struct cgroup_subsys_state___320 *);
	void (*css_reset)(struct cgroup_subsys_state___320 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___320 *, int);
	int (*css_extra_stat_show)(struct seq_file___410 *, struct cgroup_subsys_state___320 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___473 *);
	void (*cancel_fork)(struct task_struct___473 *);
	void (*fork)(struct task_struct___473 *);
	void (*exit)(struct task_struct___473 *);
	void (*free)(struct task_struct___473 *);
	void (*bind)(struct cgroup_subsys_state___320 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___320 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___320 *dfl_cftypes;
	struct cftype___320 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___320 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___320 *updated_children;
	struct cgroup___320 *updated_next;
};

struct cgroup_root___320 {
	struct kernfs_root___465 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___320 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___320 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___320 *ss;
	struct list_head node;
	struct kernfs_ops___465 *kf_ops;
	int (*open)(struct kernfs_open_file___465 *);
	void (*release)(struct kernfs_open_file___465 *);
	u64 (*read_u64)(struct cgroup_subsys_state___320 *, struct cftype___320 *);
	s64 (*read_s64)(struct cgroup_subsys_state___320 *, struct cftype___320 *);
	int (*seq_show)(struct seq_file___410 *, void *);
	void * (*seq_start)(struct seq_file___410 *, loff_t *);
	void * (*seq_next)(struct seq_file___410 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___410 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___320 *, struct cftype___320 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___320 *, struct cftype___320 *, s64);
	ssize_t (*write)(struct kernfs_open_file___465 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___465 *, struct poll_table_struct___310 *);
};

struct xdp_rxq_info___116 {
	struct net_device___116 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_buff___6 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	long unsigned int handle;
	struct xdp_rxq_info___116 *rxq;
};

struct xdp_frame___116 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___116 *dev_rx;
};

struct netlink_callback___118 {
	struct sk_buff___117 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___118 *);
	int (*dump)(struct sk_buff___117 *, struct netlink_callback___118 *);
	int (*done)(struct netlink_callback___118 *);
	void *data;
	struct module___397 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___116 {
	int (*create)(struct sk_buff___117 *, struct net_device___116 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___117 *, unsigned char *);
	int (*cache)(const struct neighbour___96 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___116 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___116 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___116 *, int);
	int poll_owner;
	struct net_device___116 *dev;
	struct sk_buff___117 *gro_list;
	struct sk_buff___117 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct xdp_umem___4 {
	struct xsk_queue *fq;
	struct xsk_queue *cq;
	struct xdp_umem_page *pages;
	u64 chunk_mask;
	u64 size;
	u32 headroom;
	u32 chunk_size_nohr;
	struct user_struct___439 *user;
	struct pid___264 *pid;
	long unsigned int address;
	refcount_t users;
	struct work_struct work;
	struct page___472 **pgs;
	u32 npgs;
	struct net_device___116 *dev;
	struct xdp_umem_fq_reuse *fq_reuse;
	u16 queue_id;
	bool zc;
	spinlock_t xsk_list_lock;
	struct list_head xsk_list;
};

struct netdev_queue___116 {
	struct net_device___116 *dev;
	struct Qdisc___108 *qdisc;
	struct Qdisc___108 *qdisc_sleeping;
	struct kobject___459 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___116 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem___4 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___108 {
	struct sk_buff___117 *head;
	struct sk_buff___117 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___108;

struct Qdisc___108 {
	int (*enqueue)(struct sk_buff___117 *, struct Qdisc___108 *, struct sk_buff___117 **);
	struct sk_buff___117 * (*dequeue)(struct Qdisc___108 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___108 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___116 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___116 gso_skb;
	struct qdisc_skb_head___108 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___108 *next_sched;
	struct sk_buff_head___116 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___116 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___459 kobj;
	struct net_device___116 *dev;
	long: 64;
	struct xdp_rxq_info___116 xdp_rxq;
	union {
		struct xdp_umem___4 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___116)(struct net_device___116 *, struct sk_buff___117 *, struct net_device___116 *);

struct netdev_bpf___116 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___106 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___106 *prog;
			const struct bpf_prog_offload_ops___106 *ops;
		} verifier;
		struct {
			struct bpf_prog___106 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___116 *offmap;
		};
		struct {
			struct xdp_umem___4 *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___116 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___117 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___116 {
	int (*tls_dev_add)(struct net_device___116 *, struct sock___96 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___116 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___116 *, struct sock___96 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___116 {
	int (*ndo_init)(struct net_device___116 *);
	void (*ndo_uninit)(struct net_device___116 *);
	int (*ndo_open)(struct net_device___116 *);
	int (*ndo_stop)(struct net_device___116 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___117 *, struct net_device___116 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___117 *, struct net_device___116 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___116 *, struct sk_buff___117 *, struct net_device___116 *, select_queue_fallback_t___116);
	void (*ndo_change_rx_flags)(struct net_device___116 *, int);
	void (*ndo_set_rx_mode)(struct net_device___116 *);
	int (*ndo_set_mac_address)(struct net_device___116 *, void *);
	int (*ndo_validate_addr)(struct net_device___116 *);
	int (*ndo_do_ioctl)(struct net_device___116 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___116 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___116 *, int);
	int (*ndo_neigh_setup)(struct net_device___116 *, struct neigh_parms___96 *);
	void (*ndo_tx_timeout)(struct net_device___116 *);
	void (*ndo_get_stats64)(struct net_device___116 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___116 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___116 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___116 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___116 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___116 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___116 *);
	int (*ndo_netpoll_setup)(struct net_device___116 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___116 *);
	int (*ndo_set_vf_mac)(struct net_device___116 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___116 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___116 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___116 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___116 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___116 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___116 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___116 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___116 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___116 *, int, struct sk_buff___117 *);
	int (*ndo_set_vf_guid)(struct net_device___116 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___116 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___116 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___116 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___116 *, const struct sk_buff___117 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___116 *, struct net_device___116 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___116 *, struct net_device___116 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___116 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___116 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___116 *, struct neighbour___96 *);
	void (*ndo_neigh_destroy)(struct net_device___116 *, struct neighbour___96 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___116 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___116 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___116 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___117 *, struct netlink_callback___118 *, struct net_device___116 *, struct net_device___116 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___116 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___116 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___117 *, u32, u32, struct net_device___116 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___116 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___116 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___116 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___116 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___116 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___116 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___116 *, struct net_device___116 *);
	void (*ndo_dfwd_del_station)(struct net_device___116 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___116 *);
	int (*ndo_set_tx_maxrate)(struct net_device___116 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___116 *);
	int (*ndo_change_proto_down)(struct net_device___116 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___116 *, struct sk_buff___117 *);
	void (*ndo_set_rx_headroom)(struct net_device___116 *, int);
	int (*ndo_bpf)(struct net_device___116 *, struct netdev_bpf___116 *);
	int (*ndo_xdp_xmit)(struct net_device___116 *, int, struct xdp_frame___116 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___116 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___116 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___96 {
	possible_net_t___118 net;
	struct net_device___116 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___96 *);
	void (*neigh_cleanup)(struct neighbour___96 *);
	struct neigh_table___96 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___96 {
	u32 (*l3mdev_fib_table)(const struct net_device___116 *);
	struct sk_buff___117 * (*l3mdev_l3_rcv)(struct net_device___116 *, struct sk_buff___117 *, u16);
	struct sk_buff___117 * (*l3mdev_l3_out)(struct net_device___116 *, struct sock___96 *, struct sk_buff___117 *, u16);
	struct dst_entry___96 * (*l3mdev_link_scope_lookup)(const struct net_device___116 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct tcf_proto___108;

struct mini_Qdisc___108 {
	struct tcf_proto___108 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___108 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___116 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___127 *, struct net_device___116 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___116 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___116 *, struct list_head *);
	size_t (*get_size)(const struct net_device___116 *);
	int (*fill_info)(struct sk_buff___117 *, const struct net_device___116 *);
	size_t (*get_xstats_size)(const struct net_device___116 *);
	int (*fill_xstats)(struct sk_buff___117 *, const struct net_device___116 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___116 *, struct net_device___116 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___116 *, const struct net_device___116 *);
	int (*fill_slave_info)(struct sk_buff___117 *, const struct net_device___116 *, const struct net_device___116 *);
	struct net___127 * (*get_link_net)(const struct net_device___116 *);
	size_t (*get_linkxstats_size)(const struct net_device___116 *, int);
	int (*fill_linkxstats)(struct sk_buff___117 *, const struct net_device___116 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___116 {
	struct list_head poll_list;
	struct sk_buff_head___116 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___116 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___108 *output_queue;
	struct Qdisc___108 **output_queue_tailp;
	struct sk_buff___117 *completion_queue;
	struct sk_buff_head___116 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___116 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___116 input_pkt_queue;
	struct napi_struct___116 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bdi_writeback_congested___261 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___261 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___261 {
	struct bio___261 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___263 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___263 bip_inline_vecs[0];
};

struct bio_set___261 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___261 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___204 {
	struct mem_cgroup___204 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___204 {
	struct lruvec___472 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___204 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___204 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct kernel_param_ops___397 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___397 *);
	int (*get)(char *, const struct kernel_param___397 *);
	void (*free)(void *);
};

struct kparam_array___397;

struct kernel_param___397 {
	const char *name;
	struct module___397 *mod;
	const struct kernel_param_ops___397 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___397 *arr;
	};
};

struct kparam_array___397 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___397 *ops;
	void *elem;
};

struct module_attribute___397 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___397 *, struct module_kobject___397 *, char *);
	ssize_t (*store)(struct module_attribute___397 *, struct module_kobject___397 *, const char *, size_t);
	void (*setup)(struct module___397 *, const char *);
	int (*test)(struct module___397 *);
	void (*free)(struct module___397 *);
};

struct gnet_dump___108 {
	spinlock_t *lock;
	struct sk_buff___117 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___108;

struct Qdisc_ops___108 {
	struct Qdisc_ops___108 *next;
	const struct Qdisc_class_ops___108 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___117 *, struct Qdisc___108 *, struct sk_buff___117 **);
	struct sk_buff___117 * (*dequeue)(struct Qdisc___108 *);
	struct sk_buff___117 * (*peek)(struct Qdisc___108 *);
	int (*init)(struct Qdisc___108 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___108 *);
	void (*destroy)(struct Qdisc___108 *);
	int (*change)(struct Qdisc___108 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___108 *);
	int (*change_tx_queue_len)(struct Qdisc___108 *, unsigned int);
	int (*dump)(struct Qdisc___108 *, struct sk_buff___117 *);
	int (*dump_stats)(struct Qdisc___108 *, struct gnet_dump___108 *);
	void (*ingress_block_set)(struct Qdisc___108 *, u32);
	void (*egress_block_set)(struct Qdisc___108 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___108 *);
	u32 (*egress_block_get)(struct Qdisc___108 *);
	struct module___397 *owner;
};

struct tcf_block___108;

struct Qdisc_class_ops___108 {
	unsigned int flags;
	struct netdev_queue___116 * (*select_queue)(struct Qdisc___108 *, struct tcmsg *);
	int (*graft)(struct Qdisc___108 *, long unsigned int, struct Qdisc___108 *, struct Qdisc___108 **, struct netlink_ext_ack *);
	struct Qdisc___108 * (*leaf)(struct Qdisc___108 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___108 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___108 *, u32);
	int (*change)(struct Qdisc___108 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___108 *, long unsigned int);
	void (*walk)(struct Qdisc___108 *, struct qdisc_walker *);
	struct tcf_block___108 * (*tcf_block)(struct Qdisc___108 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___108 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___108 *, long unsigned int);
	int (*dump)(struct Qdisc___108 *, long unsigned int, struct sk_buff___117 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___108 *, long unsigned int, struct gnet_dump___108 *);
};

struct tcf_chain___108;

struct tcf_block___108 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___127 *net;
	struct Qdisc___108 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___108 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___108;

struct tcf_proto_ops___108;

struct tcf_proto___108 {
	struct tcf_proto___108 *next;
	void *root;
	int (*classify)(struct sk_buff___117 *, const struct tcf_proto___108 *, struct tcf_result___108 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___108 *ops;
	struct tcf_chain___108 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___108 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___108 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___108 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___117 *, const struct tcf_proto___108 *, struct tcf_result___108 *);
	int (*init)(struct tcf_proto___108 *);
	void (*destroy)(struct tcf_proto___108 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___108 *, u32);
	void (*put)(struct tcf_proto___108 *, void *);
	int (*change)(struct net___127 *, struct sk_buff___117 *, struct tcf_proto___108 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___108 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___108 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___108 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___127 *, struct tcf_chain___108 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___127 *, struct tcf_proto___108 *, void *, struct sk_buff___117 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___117 *, struct net___127 *, void *);
	struct module___397 *owner;
	int flags;
};

struct tcf_chain___108 {
	struct mutex filter_chain_lock;
	struct tcf_proto___108 *filter_chain;
	struct list_head list;
	struct tcf_block___108 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___108 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___96 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___106 *prog;
};

struct bpf_redirect_info___106 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___321 *map;
	struct bpf_map___321 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___96;

struct neigh_hash_table___96;

struct neigh_table___96 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___116 *, __u32 *);
	bool (*key_eq)(const struct neighbour___96 *, const void *);
	int (*constructor)(struct neighbour___96 *);
	int (*pconstructor)(struct pneigh_entry___96 *);
	void (*pdestructor)(struct pneigh_entry___96 *);
	void (*proxy_redo)(struct sk_buff___117 *);
	char *id;
	struct neigh_parms___96 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___116 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___96 *nht;
	struct pneigh_entry___96 **phash_buckets;
};

struct neigh_ops___96 {
	int family;
	void (*solicit)(struct neighbour___96 *, struct sk_buff___117 *);
	void (*error_report)(struct neighbour___96 *, struct sk_buff___117 *);
	int (*output)(struct neighbour___96 *, struct sk_buff___117 *);
	int (*connected_output)(struct neighbour___96 *, struct sk_buff___117 *);
};

struct pneigh_entry___96 {
	struct pneigh_entry___96 *next;
	possible_net_t___118 net;
	struct net_device___116 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___96 {
	struct neighbour___96 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___96 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___96 *ctarget;
	struct net___127 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___96 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___96 *rule;
	u32 table;
	int flags;
};

struct proto___96 {
	void (*close)(struct sock___96 *, long int);
	int (*pre_connect)(struct sock___96 *, struct sockaddr *, int);
	int (*connect)(struct sock___96 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___96 *, int);
	struct sock___96 * (*accept)(struct sock___96 *, int, int *, bool);
	int (*ioctl)(struct sock___96 *, int, long unsigned int);
	int (*init)(struct sock___96 *);
	void (*destroy)(struct sock___96 *);
	void (*shutdown)(struct sock___96 *, int);
	int (*setsockopt)(struct sock___96 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___96 *, int, int, char *, int *);
	void (*keepalive)(struct sock___96 *, int);
	int (*sendmsg)(struct sock___96 *, struct msghdr___99 *, size_t);
	int (*recvmsg)(struct sock___96 *, struct msghdr___99 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___96 *, struct page___472 *, int, size_t, int);
	int (*bind)(struct sock___96 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___96 *, struct sk_buff___117 *);
	void (*release_cb)(struct sock___96 *);
	int (*hash)(struct sock___96 *);
	void (*unhash)(struct sock___96 *);
	void (*rehash)(struct sock___96 *);
	int (*get_port)(struct sock___96 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___96 *);
	bool (*stream_memory_read)(const struct sock___96 *);
	void (*enter_memory_pressure)(struct sock___96 *);
	void (*leave_memory_pressure)(struct sock___96 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___3 *rsk_prot;
	struct timewait_sock_ops___3 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___397 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___96 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct xdp_ring;

struct xsk_queue {
	u64 chunk_mask;
	u64 size;
	u32 ring_mask;
	u32 nentries;
	u32 prod_head;
	u32 prod_tail;
	u32 cons_head;
	u32 cons_tail;
	struct xdp_ring *ring;
	u64 invalid_descs;
};

struct xdp_sock___3 {
	struct sock___96 sk;
	struct xsk_queue *rx;
	struct net_device___116 *dev;
	struct xdp_umem___4 *umem;
	struct list_head flush_node;
	u16 queue_id;
	long: 48;
	long: 64;
	long: 64;
	long: 64;
	struct xsk_queue *tx;
	struct list_head list;
	bool zc;
	struct mutex mutex;
	spinlock_t tx_completion_lock;
	u64 rx_dropped;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_ring {
	u32 producer;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 consumer;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_rxtx_ring {
	struct xdp_ring ptrs;
	struct xdp_desc desc[0];
};

struct xdp_umem_ring {
	struct xdp_ring ptrs;
	u64 desc[0];
};

struct module___398;

struct file___472;

struct kiocb___472;

struct iov_iter___239;

struct poll_table_struct___311;

struct vm_area_struct___473;

struct inode___472;

struct file_lock___472;

struct page___473;

struct pipe_inode_info___153;

struct seq_file___411;

struct file_operations___472 {
	struct module___398 *owner;
	loff_t (*llseek)(struct file___472 *, loff_t, int);
	ssize_t (*read)(struct file___472 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___472 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___472 *, struct iov_iter___239 *);
	ssize_t (*write_iter)(struct kiocb___472 *, struct iov_iter___239 *);
	int (*iopoll)(struct kiocb___472 *, bool);
	int (*iterate)(struct file___472 *, struct dir_context *);
	int (*iterate_shared)(struct file___472 *, struct dir_context *);
	__poll_t (*poll)(struct file___472 *, struct poll_table_struct___311 *);
	long int (*unlocked_ioctl)(struct file___472 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___472 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___472 *, struct vm_area_struct___473 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___472 *, struct file___472 *);
	int (*flush)(struct file___472 *, fl_owner_t);
	int (*release)(struct inode___472 *, struct file___472 *);
	int (*fsync)(struct file___472 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___472 *, int);
	int (*lock)(struct file___472 *, int, struct file_lock___472 *);
	ssize_t (*sendpage)(struct file___472 *, struct page___473 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___472 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___472 *, int, struct file_lock___472 *);
	ssize_t (*splice_write)(struct pipe_inode_info___153 *, struct file___472 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___472 *, loff_t *, struct pipe_inode_info___153 *, size_t, unsigned int);
	int (*setlease)(struct file___472 *, long int, struct file_lock___472 **, void **);
	long int (*fallocate)(struct file___472 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___411 *, struct file___472 *);
	ssize_t (*copy_file_range)(struct file___472 *, loff_t, struct file___472 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___472 *, loff_t, struct file___472 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___472 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___473 {
	u64 seqnum;
	struct vm_area_struct___473 *vmas[4];
};

struct page_frag___473 {
	struct page___473 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___473;

struct mem_cgroup___205;

struct cred___440;

struct nsproxy___367;

struct signal_struct___347;

struct bio_list___262;

struct backing_dev_info___262;

struct css_set___321;

struct vm_struct___376;

struct task_struct___474 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___474 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___473 *mm;
	struct mm_struct___473 *active_mm;
	struct vmacache___473 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___474 *real_parent;
	struct task_struct___474 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___474 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___205 *active_memcg;
	long int rh_reserved2;
	struct pid___264 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___264 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___264 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___440 *ptracer_cred;
	const struct cred___440 *real_cred;
	const struct cred___440 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___367 *nsproxy;
	struct signal_struct___347 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___474 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___262 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___262 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___321 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___153 *splice_pipe;
	struct page_frag___473 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___205 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___474 *oom_reaper_list;
	struct vm_struct___376 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___157 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rw_semaphore___474 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___474 *owner;
};

struct key___440;

struct ucounts___337;

struct user_namespace___337 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___337 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___29 ns;
	long unsigned int flags;
	struct key___440 *persistent_keyring_register;
	struct rw_semaphore___474 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___337 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct secondary_data___474 {
	void *stack;
	struct task_struct___474 *task;
	long int status;
};

typedef struct page___473 *pgtable_t___473;

struct address_space___472;

struct dev_pagemap___460;

struct page___473 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___472 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___473 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___473 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___473 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___460 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___205 *mem_cgroup;
};

struct user_struct___440 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___440 *uid_keyring;
	struct key___440 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct vm_operations_struct___460;

struct vm_area_struct___473 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___473 *vm_next;
	struct vm_area_struct___473 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___473 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___460 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___472 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___473;

struct mm_struct___473 {
	struct {
		struct vm_area_struct___473 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___472 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___474 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___473 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___474 *owner;
		struct user_namespace___337 *user_ns;
		struct file___472 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___473 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup___321;

struct cgroup_subsys___321;

struct cgroup_subsys_state___321 {
	struct cgroup___321 *cgroup;
	struct cgroup_subsys___321 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___321 *parent;
};

struct kernfs_node___467;

struct cgroup_file___321 {
	struct kernfs_node___467 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___205;

struct mem_cgroup___205 {
	struct cgroup_subsys_state___321 css;
	struct mem_cgroup_id___16 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___321 events_file;
	struct cgroup_file___321 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___474 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___205 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cred___440 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___440 *session_keyring;
	struct key___440 *process_keyring;
	struct key___440 *thread_keyring;
	struct key___440 *request_key_auth;
	void *security;
	struct user_struct___440 *user;
	struct user_namespace___337 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___128;

struct cgroup_namespace___321;

struct nsproxy___367 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net___128 *net_ns;
	struct cgroup_namespace___321 *cgroup_ns;
};

struct signal_struct___347 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___474 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___474 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___264 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___264 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___473 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___264 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___262;

struct bio_list___262 {
	struct bio___262 *head;
	struct bio___262 *tail;
};

struct bdi_writeback_congested___262;

struct bdi_writeback___262 {
	struct backing_dev_info___262 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___262 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___321 *memcg_css;
	struct cgroup_subsys_state___321 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___440;

struct dentry___472;

struct backing_dev_info___262 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___262 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___440 *dev;
	struct device___440 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___472 *debug_dir;
	struct dentry___472 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___321 {
	struct cgroup_subsys_state___321 *subsys[13];
	refcount_t refcount;
	struct css_set___321 *dom_cset;
	struct cgroup___321 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___321 *mg_src_cgrp;
	struct cgroup___321 *mg_dst_cgrp;
	struct css_set___321 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___472;

struct pipe_buffer___153;

struct pipe_inode_info___153 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___473 *tmp_page;
	struct fasync_struct___472 *fasync_readers;
	struct fasync_struct___472 *fasync_writers;
	struct pipe_buffer___153 *bufs;
	struct user_struct___440 *user;
};

struct vm_struct___376 {
	struct vm_struct___376 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___473 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___359 {
	struct task_struct___474 task;
	long unsigned int stack[8192];
};

struct address_space_operations___472;

struct address_space___472 {
	struct inode___472 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___474 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___472 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___460)(struct vm_area_struct___473 *, long unsigned int, const struct page___473 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___460)(struct page___473 *, void *);

struct dev_pagemap___460 {
	dev_page_fault_t___460 page_fault;
	dev_page_free_t___460 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___440 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct path___473 {
	struct vfsmount *mnt;
	struct dentry___472 *dentry;
};

struct file___472 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___473 f_path;
	struct inode___472 *f_inode;
	const struct file_operations___472 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___264 f_owner;
	const struct cred___440 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___472 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___460;

struct vm_operations_struct___460 {
	void (*open)(struct vm_area_struct___473 *);
	void (*close)(struct vm_area_struct___473 *);
	int (*split)(struct vm_area_struct___473 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___473 *);
	vm_fault_t (*fault)(struct vm_fault___460 *);
	vm_fault_t (*huge_fault)(struct vm_fault___460 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___460 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___473 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___460 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___460 *);
	int (*access)(struct vm_area_struct___473 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___473 *);
	int (*set_policy)(struct vm_area_struct___473 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___473 *, long unsigned int);
	struct page___473 * (*find_special_page)(struct vm_area_struct___473 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___473 {
	struct task_struct___474 *task;
	struct core_thread___473 *next;
};

struct core_state___473 {
	atomic_t nr_threads;
	struct core_thread___473 dumper;
	struct completion startup;
};

struct vm_fault___460 {
	struct vm_area_struct___473 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___473 *cow_page;
	struct mem_cgroup___205 *memcg;
	struct page___473 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___473 prealloc_pte;
};

struct pglist_data___473;

struct lruvec___473 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___473 *pgdat;
};

struct zone___473 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___473 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___473 {
	struct zone___473 *zone;
	int zone_idx;
};

struct zonelist___473 {
	struct zoneref___473 _zonerefs[25];
};

struct pglist_data___473 {
	struct zone___473 node_zones[3];
	struct zonelist___473 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___474 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___474 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___473 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct blocking_notifier_head___473 {
	struct rw_semaphore___474 rwsem;
	struct notifier_block *head;
};

typedef int (*key_restrict_link_func_t___441)(struct key___440 *, const struct key_type *, const union key_payload *, struct key___440 *);

struct key_restriction___440;

struct key___440 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___474 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___440 *restrict_link;
};

struct key_restriction___440 {
	key_restrict_link_func_t___441 check;
	struct key___440 *key;
	struct key_type *keytype;
};

struct bpf_map___322;

struct bpf_map_ops___321 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___322 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___322 *, struct file___472 *);
	void (*map_free)(struct bpf_map___322 *);
	int (*map_get_next_key)(struct bpf_map___322 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___322 *);
	void * (*map_lookup_elem)(struct bpf_map___322 *, void *);
	int (*map_update_elem)(struct bpf_map___322 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___322 *, void *);
	int (*map_push_elem)(struct bpf_map___322 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___322 *, void *);
	int (*map_peek_elem)(struct bpf_map___322 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___322 *, struct file___472 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___322 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___322 *, void *, struct seq_file___411 *);
	int (*map_check_btf)(const struct bpf_map___322 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___322 {
	const struct bpf_map_ops___321 *ops;
	struct bpf_map___322 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___440 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct seq_operations___411;

struct seq_file___411 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___411 *op;
	int poll_event;
	const struct file___472 *file;
	void *private;
};

struct bpf_offloaded_map___117;

struct bpf_map_dev_ops___117 {
	int (*map_get_next_key)(struct bpf_offloaded_map___117 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___117 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___117 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___117 *, void *);
};

struct net_device___117;

struct bpf_offloaded_map___117 {
	struct bpf_map___322 map;
	struct net_device___117 *netdev;
	const struct bpf_map_dev_ops___117 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___118;

typedef rx_handler_result_t rx_handler_func_t___117(struct sk_buff___118 **);

typedef struct {
	struct net___128 *net;
} possible_net_t___119;

struct kset___459;

struct kobj_type___459;

struct kobject___460 {
	const char *name;
	struct list_head entry;
	struct kobject___460 *parent;
	struct kset___459 *kset;
	struct kobj_type___459 *ktype;
	struct kernfs_node___467 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct dev_pm_info___440 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___440 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___440;

struct bus_type___440;

struct device_driver___440;

struct dev_pm_domain___440;

struct dma_map_ops___212;

struct fwnode_handle___360;

struct class___440;

struct attribute_group___437;

struct device___440 {
	struct device___440 *parent;
	struct device_private *p;
	struct kobject___460 kobj;
	const char *init_name;
	const struct device_type___440 *type;
	struct mutex mutex;
	struct bus_type___440 *bus;
	struct device_driver___440 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___440 power;
	struct dev_pm_domain___440 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___212 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___360 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___440 *class;
	const struct attribute_group___437 **groups;
	void (*release)(struct device___440 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct net_device_ops___117;

struct ethtool_ops___117;

struct l3mdev_ops___97;

struct xfrmdev_ops___117;

struct tlsdev_ops___117;

struct header_ops___117;

struct netdev_rx_queue___117;

struct bpf_prog___107;

struct mini_Qdisc___109;

struct netdev_queue___117;

struct Qdisc___109;

struct rtnl_link_ops___109;

struct dcbnl_rtnl_ops___117;

struct net_device___117 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___117 *netdev_ops;
	const struct ethtool_ops___117 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___97 *l3mdev_ops;
	const struct ndisc_ops___2 *ndisc_ops;
	const struct xfrmdev_ops___117 *xfrmdev_ops;
	const struct tlsdev_ops___117 *tlsdev_ops;
	const struct header_ops___117 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___459 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___2 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___117 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___107 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___117 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___109 *miniq_ingress;
	struct netdev_queue___117 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___117 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___109 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___109 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___117 = 0,
		NETREG_REGISTERED___117 = 1,
		NETREG_UNREGISTERING___117 = 2,
		NETREG_UNREGISTERED___117 = 3,
		NETREG_RELEASED___117 = 4,
		NETREG_DUMMY___117 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___117 = 0,
		RTNL_LINK_INITIALIZING___117 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___117 *);
	struct netpoll_info *npinfo;
	possible_net_t___119 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___440 dev;
	const struct attribute_group___437 *sysfs_groups[4];
	const struct attribute_group___437 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___109 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___117 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct bpf_prog_ops___107 {
	int (*test_run)(struct bpf_prog___107 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_aux___110;

struct bpf_prog___107 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___110 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

struct bpf_verifier_ops___107 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___107 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___107 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___107 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___107 *, u32 *);
};

struct bpf_prog_offload_ops___107 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___107 *);
	int (*translate)(struct bpf_prog___107 *);
	void (*destroy)(struct bpf_prog___107 *);
};

struct bpf_prog_offload___107 {
	struct bpf_prog___107 *prog;
	struct net_device___117 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___107 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___110 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___107 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___107 *ops;
	struct bpf_map___322 **used_maps;
	struct bpf_prog___107 *prog;
	struct user_struct___440 *user;
	u64 load_time;
	struct bpf_map___322 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___107 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___107 {
	struct bpf_prog___107 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___107 {
	struct callback_head rcu;
	struct bpf_prog_array_item___107 items[0];
};

struct shrink_control___205 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___205 *memcg;
};

struct shrinker___205 {
	long unsigned int (*count_objects)(struct shrinker___205 *, struct shrink_control___205 *);
	long unsigned int (*scan_objects)(struct shrinker___205 *, struct shrink_control___205 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct dentry_operations___472;

struct super_block___472;

struct dentry___472 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___472 *d_parent;
	struct qstr d_name;
	struct inode___472 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___472 *d_op;
	struct super_block___472 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___472;

struct block_device___472;

struct inode___472 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___472 *i_op;
	struct super_block___472 *i_sb;
	struct address_space___472 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___474 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___262 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___472 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___472 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___153 *i_pipe;
		struct block_device___472 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___472 {
	int (*d_revalidate)(struct dentry___472 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___472 *, unsigned int);
	int (*d_hash)(const struct dentry___472 *, struct qstr *);
	int (*d_compare)(const struct dentry___472 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___472 *);
	int (*d_init)(struct dentry___472 *);
	void (*d_release)(struct dentry___472 *);
	void (*d_prune)(struct dentry___472 *);
	void (*d_iput)(struct dentry___472 *, struct inode___472 *);
	char * (*d_dname)(struct dentry___472 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___473 *);
	int (*d_manage)(const struct path___473 *, bool);
	struct dentry___472 * (*d_real)(struct dentry___472 *, const struct inode___472 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___472;

struct mem_dqinfo___472 {
	struct quota_format_type___472 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___472;

struct quota_info___472 {
	unsigned int flags;
	struct rw_semaphore___474 dqio_sem;
	struct inode___472 *files[3];
	struct mem_dqinfo___472 info[3];
	const struct quota_format_ops___472 *ops[3];
};

struct rcuwait___472 {
	struct task_struct___474 *task;
};

struct percpu_rw_semaphore___472 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___474 rw_sem;
	struct rcuwait___472 writer;
	int readers_block;
};

struct sb_writers___472 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___472 rw_sem[3];
};

struct file_system_type___472;

struct super_operations___472;

struct dquot_operations___472;

struct quotactl_ops___472;

struct super_block___472 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___472 *s_type;
	const struct super_operations___472 *s_op;
	const struct dquot_operations___472 *dq_op;
	const struct quotactl_ops___472 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___472 *s_root;
	struct rw_semaphore___474 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___472 *s_bdev;
	struct backing_dev_info___262 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___472 s_dquot;
	struct sb_writers___472 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___472 *s_d_op;
	int cleancache_poolid;
	struct shrinker___205 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___337 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___472 {
	struct file___472 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___472 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___472 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___472 *ia_file;
};

struct dquot___472 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___472 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___472 {
	int qf_fmt_id;
	const struct quota_format_ops___472 *qf_ops;
	struct module___398 *qf_owner;
	struct quota_format_type___472 *qf_next;
};

struct quota_format_ops___472 {
	int (*check_quota_file)(struct super_block___472 *, int);
	int (*read_file_info)(struct super_block___472 *, int);
	int (*write_file_info)(struct super_block___472 *, int);
	int (*free_file_info)(struct super_block___472 *, int);
	int (*read_dqblk)(struct dquot___472 *);
	int (*commit_dqblk)(struct dquot___472 *);
	int (*release_dqblk)(struct dquot___472 *);
	int (*get_next_id)(struct super_block___472 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___472 {
	int (*write_dquot)(struct dquot___472 *);
	struct dquot___472 * (*alloc_dquot)(struct super_block___472 *, int);
	void (*destroy_dquot)(struct dquot___472 *);
	int (*acquire_dquot)(struct dquot___472 *);
	int (*release_dquot)(struct dquot___472 *);
	int (*mark_dirty)(struct dquot___472 *);
	int (*write_info)(struct super_block___472 *, int);
	qsize_t * (*get_reserved_space)(struct inode___472 *);
	int (*get_projid)(struct inode___472 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___472 *, qsize_t *);
	int (*get_next_id)(struct super_block___472 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___472 {
	int (*quota_on)(struct super_block___472 *, int, int, const struct path___473 *);
	int (*quota_off)(struct super_block___472 *, int);
	int (*quota_enable)(struct super_block___472 *, unsigned int);
	int (*quota_disable)(struct super_block___472 *, unsigned int);
	int (*quota_sync)(struct super_block___472 *, int);
	int (*set_info)(struct super_block___472 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___472 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___472 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___472 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___472 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___472 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct module_kobject___398 {
	struct kobject___460 kobj;
	struct module___398 *mod;
	struct kobject___460 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___398 {
	struct module___398 *mod;
	struct latch_tree_node node;
};

struct module_layout___398 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___398 mtn;
};

struct module_attribute___398;

struct kernel_param___398;

struct module___398 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___398 mkobj;
	struct module_attribute___398 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___460 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___398 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___398 core_layout;
	struct module_layout___398 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide53;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide54;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___225;

struct address_space_operations___472 {
	int (*writepage)(struct page___473 *, struct writeback_control___225 *);
	int (*readpage)(struct file___472 *, struct page___473 *);
	int (*writepages)(struct address_space___472 *, struct writeback_control___225 *);
	int (*set_page_dirty)(struct page___473 *);
	int (*readpages)(struct file___472 *, struct address_space___472 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___472 *, struct address_space___472 *, loff_t, unsigned int, unsigned int, struct page___473 **, void **);
	int (*write_end)(struct file___472 *, struct address_space___472 *, loff_t, unsigned int, unsigned int, struct page___473 *, void *);
	sector_t (*bmap)(struct address_space___472 *, sector_t);
	void (*invalidatepage)(struct page___473 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___473 *, gfp_t);
	void (*freepage)(struct page___473 *);
	ssize_t (*direct_IO)(struct kiocb___472 *, struct iov_iter___239 *);
	int (*migratepage)(struct address_space___472 *, struct page___473 *, struct page___473 *, enum migrate_mode);
	bool (*isolate_page)(struct page___473 *, isolate_mode_t);
	void (*putback_page)(struct page___473 *);
	int (*launder_page)(struct page___473 *);
	int (*is_partially_uptodate)(struct page___473 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___473 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___472 *, struct page___473 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___472 *, sector_t *);
	void (*swap_deactivate)(struct file___472 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___225 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___262 *wb;
	struct inode___472 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___264;

struct iov_iter___239 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___264 *bvec;
		struct pipe_inode_info___153 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct block_device___472 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___472 *bd_inode;
	struct super_block___472 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___472 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___262 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___472 {
	struct dentry___472 * (*lookup)(struct inode___472 *, struct dentry___472 *, unsigned int);
	const char * (*get_link)(struct dentry___472 *, struct inode___472 *, struct delayed_call *);
	int (*permission)(struct inode___472 *, int);
	struct posix_acl * (*get_acl)(struct inode___472 *, int);
	int (*readlink)(struct dentry___472 *, char *, int);
	int (*create)(struct inode___472 *, struct dentry___472 *, umode_t, bool);
	int (*link)(struct dentry___472 *, struct inode___472 *, struct dentry___472 *);
	int (*unlink)(struct inode___472 *, struct dentry___472 *);
	int (*symlink)(struct inode___472 *, struct dentry___472 *, const char *);
	int (*mkdir)(struct inode___472 *, struct dentry___472 *, umode_t);
	int (*rmdir)(struct inode___472 *, struct dentry___472 *);
	int (*mknod)(struct inode___472 *, struct dentry___472 *, umode_t, dev_t);
	int (*rename)(struct inode___472 *, struct dentry___472 *, struct inode___472 *, struct dentry___472 *, unsigned int);
	int (*setattr)(struct dentry___472 *, struct iattr___472 *);
	int (*getattr)(const struct path___473 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___472 *, char *, size_t);
	int (*fiemap)(struct inode___472 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___472 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___472 *, struct dentry___472 *, struct file___472 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___472 *, struct dentry___472 *, umode_t);
	int (*set_acl)(struct inode___472 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___472 {
	void (*fl_copy_lock)(struct file_lock___472 *, struct file_lock___472 *);
	void (*fl_release_private)(struct file_lock___472 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___472;

struct file_lock___472 {
	struct file_lock___472 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___472 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___472 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___472 *fl_ops;
	const struct lock_manager_operations___472 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___472 {
	int (*lm_compare_owner)(struct file_lock___472 *, struct file_lock___472 *);
	long unsigned int (*lm_owner_key)(struct file_lock___472 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___472 *);
	int (*lm_grant)(struct file_lock___472 *, int);
	bool (*lm_break)(struct file_lock___472 *);
	int (*lm_change)(struct file_lock___472 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___472 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___472 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___472 *fa_next;
	struct file___472 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___472 {
	const char *name;
	int fs_flags;
	struct dentry___472 * (*mount)(struct file_system_type___472 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___472 *);
	struct module___398 *owner;
	struct file_system_type___472 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___472 {
	struct inode___472 * (*alloc_inode)(struct super_block___472 *);
	void (*destroy_inode)(struct inode___472 *);
	void (*dirty_inode)(struct inode___472 *, int);
	int (*write_inode)(struct inode___472 *, struct writeback_control___225 *);
	int (*drop_inode)(struct inode___472 *);
	void (*evict_inode)(struct inode___472 *);
	void (*put_super)(struct super_block___472 *);
	int (*sync_fs)(struct super_block___472 *, int);
	int (*freeze_super)(struct super_block___472 *);
	int (*freeze_fs)(struct super_block___472 *);
	int (*thaw_super)(struct super_block___472 *);
	int (*unfreeze_fs)(struct super_block___472 *);
	int (*statfs)(struct dentry___472 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___472 *, int *, char *);
	void (*umount_begin)(struct super_block___472 *);
	int (*show_options)(struct seq_file___411 *, struct dentry___472 *);
	int (*show_devname)(struct seq_file___411 *, struct dentry___472 *);
	int (*show_path)(struct seq_file___411 *, struct dentry___472 *);
	int (*show_stats)(struct seq_file___411 *, struct dentry___472 *);
	ssize_t (*quota_read)(struct super_block___472 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___472 *, int, const char *, size_t, loff_t);
	struct dquot___472 ** (*get_dquots)(struct inode___472 *);
	int (*bdev_try_to_free_page)(struct super_block___472 *, struct page___473 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___472 *, struct shrink_control___205 *);
	long int (*free_cached_objects)(struct super_block___472 *, struct shrink_control___205 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___321)(struct file___472 *, wait_queue_head_t *, struct poll_table_struct___311 *);

struct poll_table_struct___311 {
	poll_queue_proc___321 _qproc;
	__poll_t _key;
};

typedef void bio_end_io_t___262(struct bio___262 *);

struct bio_vec___264 {
	struct page___473 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___262;

struct bio_set___262;

struct bio___262 {
	struct bio___262 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___262 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___262 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___264 *bi_io_vec;
	struct bio_set___262 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___264 bi_inline_vecs[0];
};

struct kobj_attribute___450 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___460 *, struct kobj_attribute___450 *, char *);
	ssize_t (*store)(struct kobject___460 *, struct kobj_attribute___450 *, const char *, size_t);
};

typedef void compound_page_dtor___460(struct page___473 *);

struct msghdr___100 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___239 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___472 *msg_iocb;
};

struct socket_wq___98 {
	wait_queue_head_t wait;
	struct fasync_struct___472 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct sock___97;

struct proto_ops___98;

struct socket___99 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___98 *wq;
	struct file___472 *file;
	struct sock___97 *sk;
	const struct proto_ops___98 *ops;
};

struct proto___97;

struct sock_common___97 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___97 *skc_prot;
	possible_net_t___119 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___97 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff_head___117 {
	struct sk_buff___118 *next;
	struct sk_buff___118 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___97;

struct dst_entry___97;

struct sock___97 {
	struct sock_common___97 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___117 sk_error_queue;
	struct sk_buff_head___117 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___118 *head;
		struct sk_buff___118 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___97 *sk_filter;
	union {
		struct socket_wq___98 *sk_wq;
		struct socket_wq___98 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___97 *sk_rx_dst;
	struct dst_entry___97 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___118 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___117 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___473 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___97 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___264 *sk_peer_pid;
	const struct cred___440 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___99 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___205 *sk_memcg;
	void (*sk_state_change)(struct sock___97 *);
	void (*sk_data_ready)(struct sock___97 *);
	void (*sk_write_space)(struct sock___97 *);
	void (*sk_error_report)(struct sock___97 *);
	int (*sk_backlog_rcv)(struct sock___97 *, struct sk_buff___118 *);
	struct sk_buff___118 * (*sk_validate_xmit_skb)(struct sock___97 *, struct net_device___117 *, struct sk_buff___118 *);
	void (*sk_destruct)(struct sock___97 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

typedef int (*sk_read_actor_t___97)(read_descriptor_t *, struct sk_buff___118 *, unsigned int, size_t);

struct proto_ops___98 {
	int family;
	struct module___398 *owner;
	int (*release)(struct socket___99 *);
	int (*bind)(struct socket___99 *, struct sockaddr *, int);
	int (*connect)(struct socket___99 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___99 *, struct socket___99 *);
	int (*accept)(struct socket___99 *, struct socket___99 *, int, bool);
	int (*getname)(struct socket___99 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___472 *, struct socket___99 *, struct poll_table_struct___311 *);
	int (*ioctl)(struct socket___99 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___99 *, int);
	int (*shutdown)(struct socket___99 *, int);
	int (*setsockopt)(struct socket___99 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___99 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___99 *, struct msghdr___100 *, size_t);
	int (*recvmsg)(struct socket___99 *, struct msghdr___100 *, size_t, int);
	int (*mmap)(struct file___472 *, struct socket___99 *, struct vm_area_struct___473 *);
	ssize_t (*sendpage)(struct socket___99 *, struct page___473 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___99 *, loff_t *, struct pipe_inode_info___153 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___97 *, int);
	int (*peek_len)(struct socket___99 *);
	int (*read_sock)(struct sock___97 *, read_descriptor_t *, sk_read_actor_t___97);
	int (*sendpage_locked)(struct sock___97 *, struct page___473 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___97 *, struct msghdr___100 *, size_t);
	int (*set_rcvlowat)(struct sock___97 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct nf_bridge_info___117;

struct sk_buff___118 {
	union {
		struct {
			struct sk_buff___118 *next;
			struct sk_buff___118 *prev;
			union {
				struct net_device___117 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___97 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___118 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___117 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___117;

struct netns_frags___117 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___117 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_rules_ops___97;

struct fib_notifier_ops___98;

struct netns_ipv4___117 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___97 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___97 *fibnl;
	struct sock___97 **icmp_sk;
	struct sock___97 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___97 **tcp_sk;
	struct netns_frags___117 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___97 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___98 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___98 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___97;

struct dst_ops___128 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___128 *);
	struct dst_entry___97 * (*check)(struct dst_entry___97 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___97 *);
	unsigned int (*mtu)(const struct dst_entry___97 *);
	u32 * (*cow_metrics)(struct dst_entry___97 *, long unsigned int);
	void (*destroy)(struct dst_entry___97 *);
	void (*ifdown)(struct dst_entry___97 *, struct net_device___117 *, int);
	struct dst_entry___97 * (*negative_advice)(struct dst_entry___97 *);
	void (*link_failure)(struct sk_buff___118 *);
	void (*update_pmtu)(struct dst_entry___97 *, struct sock___97 *, struct sk_buff___118 *, u32);
	void (*redirect)(struct dst_entry___97 *, struct sock___97 *, struct sk_buff___118 *);
	int (*local_out)(struct net___128 *, struct sock___97 *, struct sk_buff___118 *);
	struct neighbour___97 * (*neigh_lookup)(const struct dst_entry___97 *, struct sk_buff___118 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___97 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___128 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___117 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___128 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___97 *fib6_rules_ops;
	struct sock___97 **icmp_sk;
	struct sock___97 *ndisc_sk;
	struct sock___97 *tcp_sk;
	struct sock___97 *igmp_sk;
	struct sock___97 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___97 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___98 *notifier_ops;
	struct fib_notifier_ops___98 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___98 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___97 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___117 {
	struct netns_frags___117 frags;
};

struct netns_xfrm___128 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___97 *nlsk;
	struct sock___97 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___128 xfrm4_dst_ops;
	struct dst_ops___128 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct net___128 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___337 *user_ns;
	struct ucounts___337 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___29 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___97 *rtnl;
	struct sock___97 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___117 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___117 ipv4;
	struct netns_ipv6___128 ipv6;
	struct netns_sctp___98 sctp;
	struct netns_nf___23 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___117 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___97 *nfnl;
	struct sock___97 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___128 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___97 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___107 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kernfs_root___466;

struct kernfs_elem_dir___466 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___466 *root;
};

struct kernfs_syscall_ops___466;

struct kernfs_root___466 {
	struct kernfs_node___467 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___466 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___466 {
	struct kernfs_node___467 *target_kn;
};

struct kernfs_ops___466;

struct kernfs_elem_attr___466 {
	const struct kernfs_ops___466 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___467 *notify_next;
};

struct kernfs_node___467 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___467 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___466 dir;
		struct kernfs_elem_symlink___466 symlink;
		struct kernfs_elem_attr___466 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___466;

struct kernfs_ops___466 {
	int (*open)(struct kernfs_open_file___466 *);
	void (*release)(struct kernfs_open_file___466 *);
	int (*seq_show)(struct seq_file___411 *, void *);
	void * (*seq_start)(struct seq_file___411 *, loff_t *);
	void * (*seq_next)(struct seq_file___411 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___411 *, void *);
	ssize_t (*read)(struct kernfs_open_file___466 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___466 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___466 *, struct vm_area_struct___473 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___466 *, struct poll_table_struct___311 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___466 {
	int (*remount_fs)(struct kernfs_root___466 *, int *, char *);
	int (*show_options)(struct seq_file___411 *, struct kernfs_root___466 *);
	int (*mkdir)(struct kernfs_node___467 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___467 *);
	int (*rename)(struct kernfs_node___467 *, struct kernfs_node___467 *, const char *);
	int (*show_path)(struct seq_file___411 *, struct kernfs_node___467 *, struct kernfs_root___466 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_open_file___466 {
	struct kernfs_node___467 *kn;
	struct file___472 *file;
	struct seq_file___411 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___460 *vm_ops;
};

struct kobj_ns_type_operations___97 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___97 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___436;

struct attribute_group___437 {
	const char *name;
	umode_t (*is_visible)(struct kobject___460 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___460 *, struct bin_attribute___436 *, int);
	struct attribute **attrs;
	struct bin_attribute___436 **bin_attrs;
};

struct bin_attribute___436 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___472 *, struct kobject___460 *, struct bin_attribute___436 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___472 *, struct kobject___460 *, struct bin_attribute___436 *, char *, loff_t, size_t);
	int (*mmap)(struct file___472 *, struct kobject___460 *, struct bin_attribute___436 *, struct vm_area_struct___473 *);
};

struct sysfs_ops___459 {
	ssize_t (*show)(struct kobject___460 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___460 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___459;

struct kset___459 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___460 kobj;
	const struct kset_uevent_ops___459 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___459 {
	void (*release)(struct kobject___460 *);
	const struct sysfs_ops___459 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___97 * (*child_ns_type)(struct kobject___460 *);
	const void * (*namespace)(struct kobject___460 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___459 {
	int (* const filter)(struct kset___459 *, struct kobject___460 *);
	const char * (* const name)(struct kset___459 *, struct kobject___460 *);
	int (* const uevent)(struct kset___459 *, struct kobject___460 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___440 {
	int (*prepare)(struct device___440 *);
	void (*complete)(struct device___440 *);
	int (*suspend)(struct device___440 *);
	int (*resume)(struct device___440 *);
	int (*freeze)(struct device___440 *);
	int (*thaw)(struct device___440 *);
	int (*poweroff)(struct device___440 *);
	int (*restore)(struct device___440 *);
	int (*suspend_late)(struct device___440 *);
	int (*resume_early)(struct device___440 *);
	int (*freeze_late)(struct device___440 *);
	int (*thaw_early)(struct device___440 *);
	int (*poweroff_late)(struct device___440 *);
	int (*restore_early)(struct device___440 *);
	int (*suspend_noirq)(struct device___440 *);
	int (*resume_noirq)(struct device___440 *);
	int (*freeze_noirq)(struct device___440 *);
	int (*thaw_noirq)(struct device___440 *);
	int (*poweroff_noirq)(struct device___440 *);
	int (*restore_noirq)(struct device___440 *);
	int (*runtime_suspend)(struct device___440 *);
	int (*runtime_resume)(struct device___440 *);
	int (*runtime_idle)(struct device___440 *);
};

struct dev_pm_domain___440 {
	struct dev_pm_ops___440 ops;
	void (*detach)(struct device___440 *, bool);
	int (*activate)(struct device___440 *);
	void (*sync)(struct device___440 *);
	void (*dismiss)(struct device___440 *);
};

struct bus_type___440 {
	const char *name;
	const char *dev_name;
	struct device___440 *dev_root;
	const struct attribute_group___437 **bus_groups;
	const struct attribute_group___437 **dev_groups;
	const struct attribute_group___437 **drv_groups;
	int (*match)(struct device___440 *, struct device_driver___440 *);
	int (*uevent)(struct device___440 *, struct kobj_uevent_env *);
	int (*probe)(struct device___440 *);
	int (*remove)(struct device___440 *);
	void (*shutdown)(struct device___440 *);
	int (*online)(struct device___440 *);
	int (*offline)(struct device___440 *);
	int (*suspend)(struct device___440 *, pm_message_t);
	int (*resume)(struct device___440 *);
	int (*num_vf)(struct device___440 *);
	int (*dma_configure)(struct device___440 *);
	const struct dev_pm_ops___440 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___440 {
	const char *name;
	struct bus_type___440 *bus;
	struct module___398 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___440 *);
	int (*remove)(struct device___440 *);
	void (*shutdown)(struct device___440 *);
	int (*suspend)(struct device___440 *, pm_message_t);
	int (*resume)(struct device___440 *);
	const struct attribute_group___437 **groups;
	const struct dev_pm_ops___440 *pm;
	void (*coredump)(struct device___440 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___440 {
	const char *name;
	const struct attribute_group___437 **groups;
	int (*uevent)(struct device___440 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___440 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___440 *);
	const struct dev_pm_ops___440 *pm;
};

struct class___440 {
	const char *name;
	struct module___398 *owner;
	const struct attribute_group___437 **class_groups;
	const struct attribute_group___437 **dev_groups;
	struct kobject___460 *dev_kobj;
	int (*dev_uevent)(struct device___440 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___440 *, umode_t *);
	void (*class_release)(struct class___440 *);
	void (*dev_release)(struct device___440 *);
	int (*shutdown_pre)(struct device___440 *);
	const struct kobj_ns_type_operations___97 *ns_type;
	const void * (*namespace)(struct device___440 *);
	const struct dev_pm_ops___440 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___212 {
	void * (*alloc)(struct device___440 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___440 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___440 *, struct vm_area_struct___473 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___440 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___440 *, struct page___473 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___440 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___440 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___440 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___440 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___440 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___440 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide17;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___440 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___440 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___440 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___440 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___440 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___440 *, u64);
	u64 (*get_required_mask)(struct device___440 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___360;

struct fwnode_handle___360 {
	struct fwnode_handle___360 *secondary;
	const struct fwnode_operations___360 *ops;
};

struct fwnode_reference_args___360;

struct fwnode_endpoint___360;

struct fwnode_operations___360 {
	struct fwnode_handle___360 * (*get)(struct fwnode_handle___360 *);
	void (*put)(struct fwnode_handle___360 *);
	bool (*device_is_available)(const struct fwnode_handle___360 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___360 *, const struct device___440 *);
	bool (*property_present)(const struct fwnode_handle___360 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___360 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___360 *, const char *, const char **, size_t);
	struct fwnode_handle___360 * (*get_parent)(const struct fwnode_handle___360 *);
	struct fwnode_handle___360 * (*get_next_child_node)(const struct fwnode_handle___360 *, struct fwnode_handle___360 *);
	struct fwnode_handle___360 * (*get_named_child_node)(const struct fwnode_handle___360 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___360 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___360 *);
	struct fwnode_handle___360 * (*graph_get_next_endpoint)(const struct fwnode_handle___360 *, struct fwnode_handle___360 *);
	struct fwnode_handle___360 * (*graph_get_remote_endpoint)(const struct fwnode_handle___360 *);
	struct fwnode_handle___360 * (*graph_get_port_parent)(struct fwnode_handle___360 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___360 *, struct fwnode_endpoint___360 *);
};

struct fwnode_endpoint___360 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___360 *local_fwnode;
};

struct fwnode_reference_args___360 {
	struct fwnode_handle___360 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___153;

struct pipe_buffer___153 {
	struct page___473 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___153 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___153 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___153 *, struct pipe_buffer___153 *);
	void (*release)(struct pipe_inode_info___153 *, struct pipe_buffer___153 *);
	int (*steal)(struct pipe_inode_info___153 *, struct pipe_buffer___153 *);
	union {
		bool (*get)(struct pipe_inode_info___153 *, struct pipe_buffer___153 *);
		struct {
			void (*get)(struct pipe_inode_info___153 *, struct pipe_buffer___153 *);
		} __UNIQUE_ID_rh_kabi_hide20;
		union {		};
	};
};

struct nf_bridge_info___117 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___117 = 0,
		BRNF_PROTO_8021Q___117 = 1,
		BRNF_PROTO_PPPOE___117 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___117 *physindev;
	struct net_device___117 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

struct ethtool_ops___117 {
	int (*get_settings)(struct net_device___117 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___117 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___117 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___117 *);
	void (*get_regs)(struct net_device___117 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___117 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___117 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___117 *);
	void (*set_msglevel)(struct net_device___117 *, u32);
	int (*nway_reset)(struct net_device___117 *);
	u32 (*get_link)(struct net_device___117 *);
	int (*get_eeprom_len)(struct net_device___117 *);
	int (*get_eeprom)(struct net_device___117 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___117 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___117 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___117 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___117 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___117 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___117 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___117 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___117 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___117 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___117 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___117 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___117 *);
	void (*complete)(struct net_device___117 *);
	u32 (*get_priv_flags)(struct net_device___117 *);
	int (*set_priv_flags)(struct net_device___117 *, u32);
	int (*get_sset_count)(struct net_device___117 *, int);
	int (*get_rxnfc)(struct net_device___117 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___117 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___117 *, struct ethtool_flash *);
	int (*reset)(struct net_device___117 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___117 *);
	u32 (*get_rxfh_indir_size)(struct net_device___117 *);
	int (*get_rxfh)(struct net_device___117 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___117 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___117 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___117 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___117 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___117 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___117 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___117 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___117 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___117 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___117 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___117 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___117 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___117 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___117 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___117 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___117 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___117 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___117 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___117 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___117 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___117 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	int (*get_fecparam)(struct net_device___117 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___117 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___117 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___117 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___117 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___117;

struct inet_frags___117 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___117 *, const void *);
	void (*destructor)(struct inet_frag_queue___117 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___117 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___118 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___118 *fragments_tail;
	struct sk_buff___118 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___117 *net;
	struct callback_head rcu;
};

struct fib_rule___97;

struct fib_lookup_arg___97;

struct fib_rules_ops___97 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___97 *, struct flowi *, int, struct fib_lookup_arg___97 *);
	bool (*suppress)(struct fib_rule___97 *, struct fib_lookup_arg___97 *);
	int (*match)(struct fib_rule___97 *, struct flowi *, int);
	int (*configure)(struct fib_rule___97 *, struct sk_buff___118 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___97 *);
	int (*compare)(struct fib_rule___97 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___97 *, struct sk_buff___118 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___97 *);
	void (*flush_cache)(struct fib_rules_ops___97 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___398 *owner;
	struct net___128 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___98 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___128 *);
	int (*fib_dump)(struct net___128 *, struct notifier_block *);
	struct module___398 *owner;
	struct callback_head rcu;
};

struct dst_entry___97 {
	struct net_device___117 *dev;
	struct dst_ops___128 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___118 *);
	int (*output)(struct net___128 *, struct sock___97 *, struct sk_buff___118 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___97;

struct neigh_parms___97;

struct neigh_ops___97;

struct neighbour___97 {
	struct neighbour___97 *next;
	struct neigh_table___97 *tbl;
	struct neigh_parms___97 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___117 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___97 *, struct sk_buff___118 *);
	const struct neigh_ops___97 *ops;
	struct callback_head rcu;
	struct net_device___117 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct ucounts___337 {
	struct hlist_node node;
	struct user_namespace___337 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct seq_operations___411 {
	void * (*start)(struct seq_file___411 *, loff_t *);
	void (*stop)(struct seq_file___411 *, void *);
	void * (*next)(struct seq_file___411 *, void *, loff_t *);
	int (*show)(struct seq_file___411 *, void *);
};

struct pernet_operations___118 {
	struct list_head list;
	int (*init)(struct net___128 *);
	void (*exit)(struct net___128 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___117 {
	int (*ieee_getets)(struct net_device___117 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___117 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___117 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___117 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___117 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___117 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___117 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___117 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___117 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___117 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___117 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___117 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___117 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___117 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___117 *);
	u8 (*setstate)(struct net_device___117 *, u8);
	void (*getpermhwaddr)(struct net_device___117 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___117 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___117 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___117 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___117 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___117 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___117 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___117 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___117 *, int, u8 *);
	void (*setpfccfg)(struct net_device___117 *, int, u8);
	void (*getpfccfg)(struct net_device___117 *, int, u8 *);
	u8 (*setall)(struct net_device___117 *);
	u8 (*getcap)(struct net_device___117 *, int, u8 *);
	int (*getnumtcs)(struct net_device___117 *, int, u8 *);
	int (*setnumtcs)(struct net_device___117 *, int, u8);
	u8 (*getpfcstate)(struct net_device___117 *);
	void (*setpfcstate)(struct net_device___117 *, u8);
	void (*getbcncfg)(struct net_device___117 *, int, u32 *);
	void (*setbcncfg)(struct net_device___117 *, int, u32);
	void (*getbcnrp)(struct net_device___117 *, int, u8 *);
	void (*setbcnrp)(struct net_device___117 *, int, u8);
	int (*setapp)(struct net_device___117 *, u8, u16, u8);
	int (*getapp)(struct net_device___117 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___117 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___117 *, int, u8);
	u8 (*getdcbx)(struct net_device___117 *);
	u8 (*setdcbx)(struct net_device___117 *, u8);
	int (*peer_getappinfo)(struct net_device___117 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___117 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___117 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___117 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___117 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___117 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___321 {
	refcount_t count;
	struct ns_common___29 ns;
	struct user_namespace___337 *user_ns;
	struct ucounts___337 *ucounts;
	struct css_set___321 *root_cset;
};

struct cgroup_bpf___107 {
	struct bpf_prog_array___107 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___107 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___322;

typedef void (*kthread_work_func_t___322)(struct kthread_work___322 *);

struct kthread_worker___322;

struct kthread_work___322 {
	struct list_head node;
	kthread_work_func_t___322 func;
	struct kthread_worker___322 *worker;
	int canceling;
};

struct kthread_worker___322 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___474 *task;
	struct kthread_work___322 *current_work;
};

struct kthread_delayed_work___321 {
	struct kthread_work___322 work;
	struct timer_list timer;
};

struct psi_group___321 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___322 *poll_kworker;
	struct kthread_delayed_work___321 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___321;

struct cgroup_rstat_cpu___321;

struct cgroup___321 {
	struct cgroup_subsys_state___321 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___467 *kn;
	struct cgroup_file___321 procs_file;
	struct cgroup_file___321 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___321 *subsys[13];
	struct cgroup_root___321 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___321 *dom_cgrp;
	struct cgroup_rstat_cpu___321 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___107 bpf;
	atomic_t congestion_count;
	struct cgroup___321 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___321 psi;
	int ancestor_ids[0];
};

struct cftype___321;

struct cgroup_subsys___321 {
	struct cgroup_subsys_state___321 * (*css_alloc)(struct cgroup_subsys_state___321 *);
	int (*css_online)(struct cgroup_subsys_state___321 *);
	void (*css_offline)(struct cgroup_subsys_state___321 *);
	void (*css_released)(struct cgroup_subsys_state___321 *);
	void (*css_free)(struct cgroup_subsys_state___321 *);
	void (*css_reset)(struct cgroup_subsys_state___321 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___321 *, int);
	int (*css_extra_stat_show)(struct seq_file___411 *, struct cgroup_subsys_state___321 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___474 *);
	void (*cancel_fork)(struct task_struct___474 *);
	void (*fork)(struct task_struct___474 *);
	void (*exit)(struct task_struct___474 *);
	void (*free)(struct task_struct___474 *);
	void (*bind)(struct cgroup_subsys_state___321 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___321 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___321 *dfl_cftypes;
	struct cftype___321 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___321 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___321 *updated_children;
	struct cgroup___321 *updated_next;
};

struct cgroup_root___321 {
	struct kernfs_root___466 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___321 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___321 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___321 *ss;
	struct list_head node;
	struct kernfs_ops___466 *kf_ops;
	int (*open)(struct kernfs_open_file___466 *);
	void (*release)(struct kernfs_open_file___466 *);
	u64 (*read_u64)(struct cgroup_subsys_state___321 *, struct cftype___321 *);
	s64 (*read_s64)(struct cgroup_subsys_state___321 *, struct cftype___321 *);
	int (*seq_show)(struct seq_file___411 *, void *);
	void * (*seq_start)(struct seq_file___411 *, loff_t *);
	void * (*seq_next)(struct seq_file___411 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___411 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___321 *, struct cftype___321 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___321 *, struct cftype___321 *, s64);
	ssize_t (*write)(struct kernfs_open_file___466 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___466 *, struct poll_table_struct___311 *);
};

struct xdp_rxq_info___117 {
	struct net_device___117 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___117 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___117 *dev_rx;
};

struct netlink_callback___119 {
	struct sk_buff___118 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___119 *);
	int (*dump)(struct sk_buff___118 *, struct netlink_callback___119 *);
	int (*done)(struct netlink_callback___119 *);
	void *data;
	struct module___398 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___117 {
	int (*create)(struct sk_buff___118 *, struct net_device___117 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___118 *, unsigned char *);
	int (*cache)(const struct neighbour___97 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___117 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___117 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___117 *, int);
	int poll_owner;
	struct net_device___117 *dev;
	struct sk_buff___118 *gro_list;
	struct sk_buff___118 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct xdp_umem___5 {
	struct xsk_queue *fq;
	struct xsk_queue *cq;
	struct xdp_umem_page *pages;
	u64 chunk_mask;
	u64 size;
	u32 headroom;
	u32 chunk_size_nohr;
	struct user_struct___440 *user;
	struct pid___264 *pid;
	long unsigned int address;
	refcount_t users;
	struct work_struct work;
	struct page___473 **pgs;
	u32 npgs;
	struct net_device___117 *dev;
	struct xdp_umem_fq_reuse *fq_reuse;
	u16 queue_id;
	bool zc;
	spinlock_t xsk_list_lock;
	struct list_head xsk_list;
};

struct netdev_queue___117 {
	struct net_device___117 *dev;
	struct Qdisc___109 *qdisc;
	struct Qdisc___109 *qdisc_sleeping;
	struct kobject___460 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___117 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem___5 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___109 {
	struct sk_buff___118 *head;
	struct sk_buff___118 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___109;

struct Qdisc___109 {
	int (*enqueue)(struct sk_buff___118 *, struct Qdisc___109 *, struct sk_buff___118 **);
	struct sk_buff___118 * (*dequeue)(struct Qdisc___109 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___109 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___117 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___117 gso_skb;
	struct qdisc_skb_head___109 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___109 *next_sched;
	struct sk_buff_head___117 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___117 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___460 kobj;
	struct net_device___117 *dev;
	long: 64;
	struct xdp_rxq_info___117 xdp_rxq;
	union {
		struct xdp_umem___5 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___117)(struct net_device___117 *, struct sk_buff___118 *, struct net_device___117 *);

struct netdev_bpf___117 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___107 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___107 *prog;
			const struct bpf_prog_offload_ops___107 *ops;
		} verifier;
		struct {
			struct bpf_prog___107 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___117 *offmap;
		};
		struct {
			struct xdp_umem___5 *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___117 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___118 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___117 {
	int (*tls_dev_add)(struct net_device___117 *, struct sock___97 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___117 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___117 *, struct sock___97 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___117 {
	int (*ndo_init)(struct net_device___117 *);
	void (*ndo_uninit)(struct net_device___117 *);
	int (*ndo_open)(struct net_device___117 *);
	int (*ndo_stop)(struct net_device___117 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___118 *, struct net_device___117 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___118 *, struct net_device___117 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___117 *, struct sk_buff___118 *, struct net_device___117 *, select_queue_fallback_t___117);
	void (*ndo_change_rx_flags)(struct net_device___117 *, int);
	void (*ndo_set_rx_mode)(struct net_device___117 *);
	int (*ndo_set_mac_address)(struct net_device___117 *, void *);
	int (*ndo_validate_addr)(struct net_device___117 *);
	int (*ndo_do_ioctl)(struct net_device___117 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___117 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___117 *, int);
	int (*ndo_neigh_setup)(struct net_device___117 *, struct neigh_parms___97 *);
	void (*ndo_tx_timeout)(struct net_device___117 *);
	void (*ndo_get_stats64)(struct net_device___117 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___117 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___117 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___117 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___117 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___117 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___117 *);
	int (*ndo_netpoll_setup)(struct net_device___117 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___117 *);
	int (*ndo_set_vf_mac)(struct net_device___117 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___117 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___117 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___117 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___117 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___117 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___117 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___117 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___117 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___117 *, int, struct sk_buff___118 *);
	int (*ndo_set_vf_guid)(struct net_device___117 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___117 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___117 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___117 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___117 *, const struct sk_buff___118 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___117 *, struct net_device___117 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___117 *, struct net_device___117 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___117 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___117 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___117 *, struct neighbour___97 *);
	void (*ndo_neigh_destroy)(struct net_device___117 *, struct neighbour___97 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___117 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___117 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___117 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___118 *, struct netlink_callback___119 *, struct net_device___117 *, struct net_device___117 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___117 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___117 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___118 *, u32, u32, struct net_device___117 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___117 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___117 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___117 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___117 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___117 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___117 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___117 *, struct net_device___117 *);
	void (*ndo_dfwd_del_station)(struct net_device___117 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___117 *);
	int (*ndo_set_tx_maxrate)(struct net_device___117 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___117 *);
	int (*ndo_change_proto_down)(struct net_device___117 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___117 *, struct sk_buff___118 *);
	void (*ndo_set_rx_headroom)(struct net_device___117 *, int);
	int (*ndo_bpf)(struct net_device___117 *, struct netdev_bpf___117 *);
	int (*ndo_xdp_xmit)(struct net_device___117 *, int, struct xdp_frame___117 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___117 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___117 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___97 {
	possible_net_t___119 net;
	struct net_device___117 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___97 *);
	void (*neigh_cleanup)(struct neighbour___97 *);
	struct neigh_table___97 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___97 {
	u32 (*l3mdev_fib_table)(const struct net_device___117 *);
	struct sk_buff___118 * (*l3mdev_l3_rcv)(struct net_device___117 *, struct sk_buff___118 *, u16);
	struct sk_buff___118 * (*l3mdev_l3_out)(struct net_device___117 *, struct sock___97 *, struct sk_buff___118 *, u16);
	struct dst_entry___97 * (*l3mdev_link_scope_lookup)(const struct net_device___117 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct tcf_proto___109;

struct mini_Qdisc___109 {
	struct tcf_proto___109 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___109 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___117 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___128 *, struct net_device___117 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___117 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___117 *, struct list_head *);
	size_t (*get_size)(const struct net_device___117 *);
	int (*fill_info)(struct sk_buff___118 *, const struct net_device___117 *);
	size_t (*get_xstats_size)(const struct net_device___117 *);
	int (*fill_xstats)(struct sk_buff___118 *, const struct net_device___117 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___117 *, struct net_device___117 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___117 *, const struct net_device___117 *);
	int (*fill_slave_info)(struct sk_buff___118 *, const struct net_device___117 *, const struct net_device___117 *);
	struct net___128 * (*get_link_net)(const struct net_device___117 *);
	size_t (*get_linkxstats_size)(const struct net_device___117 *, int);
	int (*fill_linkxstats)(struct sk_buff___118 *, const struct net_device___117 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___117 {
	struct list_head poll_list;
	struct sk_buff_head___117 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___117 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___109 *output_queue;
	struct Qdisc___109 **output_queue_tailp;
	struct sk_buff___118 *completion_queue;
	struct sk_buff_head___117 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___117 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___117 input_pkt_queue;
	struct napi_struct___117 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bdi_writeback_congested___262 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___262 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___262 {
	struct bio___262 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___264 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___264 bip_inline_vecs[0];
};

struct bio_set___262 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___262 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___205 {
	struct mem_cgroup___205 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___205 {
	struct lruvec___473 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___205 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___205 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct kernel_param_ops___398 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___398 *);
	int (*get)(char *, const struct kernel_param___398 *);
	void (*free)(void *);
};

struct kparam_array___398;

struct kernel_param___398 {
	const char *name;
	struct module___398 *mod;
	const struct kernel_param_ops___398 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___398 *arr;
	};
};

struct kparam_array___398 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___398 *ops;
	void *elem;
};

struct module_attribute___398 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___398 *, struct module_kobject___398 *, char *);
	ssize_t (*store)(struct module_attribute___398 *, struct module_kobject___398 *, const char *, size_t);
	void (*setup)(struct module___398 *, const char *);
	int (*test)(struct module___398 *);
	void (*free)(struct module___398 *);
};

struct gnet_dump___109 {
	spinlock_t *lock;
	struct sk_buff___118 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___109;

struct Qdisc_ops___109 {
	struct Qdisc_ops___109 *next;
	const struct Qdisc_class_ops___109 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___118 *, struct Qdisc___109 *, struct sk_buff___118 **);
	struct sk_buff___118 * (*dequeue)(struct Qdisc___109 *);
	struct sk_buff___118 * (*peek)(struct Qdisc___109 *);
	int (*init)(struct Qdisc___109 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___109 *);
	void (*destroy)(struct Qdisc___109 *);
	int (*change)(struct Qdisc___109 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___109 *);
	int (*change_tx_queue_len)(struct Qdisc___109 *, unsigned int);
	int (*dump)(struct Qdisc___109 *, struct sk_buff___118 *);
	int (*dump_stats)(struct Qdisc___109 *, struct gnet_dump___109 *);
	void (*ingress_block_set)(struct Qdisc___109 *, u32);
	void (*egress_block_set)(struct Qdisc___109 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___109 *);
	u32 (*egress_block_get)(struct Qdisc___109 *);
	struct module___398 *owner;
};

struct tcf_block___109;

struct Qdisc_class_ops___109 {
	unsigned int flags;
	struct netdev_queue___117 * (*select_queue)(struct Qdisc___109 *, struct tcmsg *);
	int (*graft)(struct Qdisc___109 *, long unsigned int, struct Qdisc___109 *, struct Qdisc___109 **, struct netlink_ext_ack *);
	struct Qdisc___109 * (*leaf)(struct Qdisc___109 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___109 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___109 *, u32);
	int (*change)(struct Qdisc___109 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___109 *, long unsigned int);
	void (*walk)(struct Qdisc___109 *, struct qdisc_walker *);
	struct tcf_block___109 * (*tcf_block)(struct Qdisc___109 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___109 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___109 *, long unsigned int);
	int (*dump)(struct Qdisc___109 *, long unsigned int, struct sk_buff___118 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___109 *, long unsigned int, struct gnet_dump___109 *);
};

struct tcf_chain___109;

struct tcf_block___109 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___128 *net;
	struct Qdisc___109 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___109 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___109;

struct tcf_proto_ops___109;

struct tcf_proto___109 {
	struct tcf_proto___109 *next;
	void *root;
	int (*classify)(struct sk_buff___118 *, const struct tcf_proto___109 *, struct tcf_result___109 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___109 *ops;
	struct tcf_chain___109 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___109 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___109 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___109 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___118 *, const struct tcf_proto___109 *, struct tcf_result___109 *);
	int (*init)(struct tcf_proto___109 *);
	void (*destroy)(struct tcf_proto___109 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___109 *, u32);
	void (*put)(struct tcf_proto___109 *, void *);
	int (*change)(struct net___128 *, struct sk_buff___118 *, struct tcf_proto___109 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___109 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___109 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___109 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___128 *, struct tcf_chain___109 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___128 *, struct tcf_proto___109 *, void *, struct sk_buff___118 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___118 *, struct net___128 *, void *);
	struct module___398 *owner;
	int flags;
};

struct tcf_chain___109 {
	struct mutex filter_chain_lock;
	struct tcf_proto___109 *filter_chain;
	struct list_head list;
	struct tcf_block___109 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___109 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___97 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___107 *prog;
};

struct bpf_redirect_info___107 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___322 *map;
	struct bpf_map___322 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___97;

struct neigh_hash_table___97;

struct neigh_table___97 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___117 *, __u32 *);
	bool (*key_eq)(const struct neighbour___97 *, const void *);
	int (*constructor)(struct neighbour___97 *);
	int (*pconstructor)(struct pneigh_entry___97 *);
	void (*pdestructor)(struct pneigh_entry___97 *);
	void (*proxy_redo)(struct sk_buff___118 *);
	char *id;
	struct neigh_parms___97 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___117 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___97 *nht;
	struct pneigh_entry___97 **phash_buckets;
};

struct neigh_ops___97 {
	int family;
	void (*solicit)(struct neighbour___97 *, struct sk_buff___118 *);
	void (*error_report)(struct neighbour___97 *, struct sk_buff___118 *);
	int (*output)(struct neighbour___97 *, struct sk_buff___118 *);
	int (*connected_output)(struct neighbour___97 *, struct sk_buff___118 *);
};

struct pneigh_entry___97 {
	struct pneigh_entry___97 *next;
	possible_net_t___119 net;
	struct net_device___117 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___97 {
	struct neighbour___97 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___97 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___97 *ctarget;
	struct net___128 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___97 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___97 *rule;
	u32 table;
	int flags;
};

struct proto___97 {
	void (*close)(struct sock___97 *, long int);
	int (*pre_connect)(struct sock___97 *, struct sockaddr *, int);
	int (*connect)(struct sock___97 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___97 *, int);
	struct sock___97 * (*accept)(struct sock___97 *, int, int *, bool);
	int (*ioctl)(struct sock___97 *, int, long unsigned int);
	int (*init)(struct sock___97 *);
	void (*destroy)(struct sock___97 *);
	void (*shutdown)(struct sock___97 *, int);
	int (*setsockopt)(struct sock___97 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___97 *, int, int, char *, int *);
	void (*keepalive)(struct sock___97 *, int);
	int (*sendmsg)(struct sock___97 *, struct msghdr___100 *, size_t);
	int (*recvmsg)(struct sock___97 *, struct msghdr___100 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___97 *, struct page___473 *, int, size_t, int);
	int (*bind)(struct sock___97 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___97 *, struct sk_buff___118 *);
	void (*release_cb)(struct sock___97 *);
	int (*hash)(struct sock___97 *);
	void (*unhash)(struct sock___97 *);
	void (*rehash)(struct sock___97 *);
	int (*get_port)(struct sock___97 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___97 *);
	bool (*stream_memory_read)(const struct sock___97 *);
	void (*enter_memory_pressure)(struct sock___97 *);
	void (*leave_memory_pressure)(struct sock___97 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___3 *rsk_prot;
	struct timewait_sock_ops___3 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___398 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___97 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct xdp_sock___4 {
	struct sock___97 sk;
	struct xsk_queue *rx;
	struct net_device___117 *dev;
	struct xdp_umem___5 *umem;
	struct list_head flush_node;
	u16 queue_id;
	long: 48;
	long: 64;
	long: 64;
	long: 64;
	struct xsk_queue *tx;
	struct list_head list;
	bool zc;
	struct mutex mutex;
	spinlock_t tx_completion_lock;
	u64 rx_dropped;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct compress_format {
	unsigned char magic[2];
	const char *name;
	decompress_fn decompressor;
};

struct group_data {
	int limit[21];
	int base[20];
	int permute[258];
	int minLen;
	int maxLen;
};

struct bunzip_data {
	int writeCopies;
	int writePos;
	int writeRunCountdown;
	int writeCount;
	int writeCurrent;
	long int (*fill)(void *, long unsigned int);
	long int inbufCount;
	long int inbufPos;
	unsigned char *inbuf;
	unsigned int inbufBitCount;
	unsigned int inbufBits;
	unsigned int crc32Table[256];
	unsigned int headerCRC;
	unsigned int totalCRC;
	unsigned int writeCRC;
	unsigned int *dbuf;
	unsigned int dbufSize;
	unsigned char selectors[32768];
	struct group_data groups[6];
	int io_error;
	int byteCount[256];
	unsigned char symToByte[256];
	unsigned char mtfSymbol[256];
};

struct rc {
	long int (*fill)(void *, long unsigned int);
	uint8_t *ptr;
	uint8_t *buffer;
	uint8_t *buffer_end;
	long int buffer_size;
	uint32_t code;
	uint32_t range;
	uint32_t bound;
	void (*error)(char *);
};

struct lzma_header {
	uint8_t pos;
	uint32_t dict_size;
	uint64_t dst_size;
} __attribute__((packed));

struct writer {
	uint8_t *buffer;
	uint8_t previous_byte;
	size_t buffer_pos;
	int bufsize;
	size_t global_pos;
	long int (*flush)(void *, long unsigned int);
	struct lzma_header *header;
};

struct cstate {
	int state;
	uint32_t rep0;
	uint32_t rep1;
	uint32_t rep2;
	uint32_t rep3;
};

struct xz_dec___2;

enum cpio_fields {
	C_MAGIC = 0,
	C_INO = 1,
	C_MODE = 2,
	C_UID = 3,
	C_GID = 4,
	C_NLINK = 5,
	C_MTIME = 6,
	C_FILESIZE = 7,
	C_MAJ = 8,
	C_MIN = 9,
	C_RMAJ = 10,
	C_RMIN = 11,
	C_NAMESIZE = 12,
	C_CHKSUM = 13,
	C_NFIELDS = 14,
};

struct fprop_local_single {
	long unsigned int events;
	unsigned int period;
	raw_spinlock_t lock;
};

typedef void (*xa_update_node_t)(struct xa_node *);

struct xa_state {
	struct xarray *xa;
	long unsigned int xa_index;
	unsigned char xa_shift;
	unsigned char xa_sibs;
	unsigned char xa_offset;
	unsigned char xa_pad;
	struct xa_node *xa_node;
	struct xa_node *xa_alloc;
	xa_update_node_t xa_update;
};

struct ida_bitmap {
	long unsigned int bitmap[16];
};

struct pt_regs___2;

struct klist_waiter {
	struct list_head list;
	struct klist_node *node;
	struct task_struct___474 *process;
	int woken;
};

struct module___399;

struct file___473;

struct kiocb___473;

struct iov_iter___240;

struct poll_table_struct___312;

struct vm_area_struct___474;

struct inode___473;

struct file_lock___473;

struct page___474;

struct pipe_inode_info___154;

struct seq_file___412;

struct file_operations___473 {
	struct module___399 *owner;
	loff_t (*llseek)(struct file___473 *, loff_t, int);
	ssize_t (*read)(struct file___473 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___473 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___473 *, struct iov_iter___240 *);
	ssize_t (*write_iter)(struct kiocb___473 *, struct iov_iter___240 *);
	int (*iopoll)(struct kiocb___473 *, bool);
	int (*iterate)(struct file___473 *, struct dir_context *);
	int (*iterate_shared)(struct file___473 *, struct dir_context *);
	__poll_t (*poll)(struct file___473 *, struct poll_table_struct___312 *);
	long int (*unlocked_ioctl)(struct file___473 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___473 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___473 *, struct vm_area_struct___474 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___473 *, struct file___473 *);
	int (*flush)(struct file___473 *, fl_owner_t);
	int (*release)(struct inode___473 *, struct file___473 *);
	int (*fsync)(struct file___473 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___473 *, int);
	int (*lock)(struct file___473 *, int, struct file_lock___473 *);
	ssize_t (*sendpage)(struct file___473 *, struct page___474 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___473 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___473 *, int, struct file_lock___473 *);
	ssize_t (*splice_write)(struct pipe_inode_info___154 *, struct file___473 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___473 *, loff_t *, struct pipe_inode_info___154 *, size_t, unsigned int);
	int (*setlease)(struct file___473 *, long int, struct file_lock___473 **, void **);
	long int (*fallocate)(struct file___473 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___412 *, struct file___473 *);
	ssize_t (*copy_file_range)(struct file___473 *, loff_t, struct file___473 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___473 *, loff_t, struct file___473 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___473 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___474 {
	u64 seqnum;
	struct vm_area_struct___474 *vmas[4];
};

struct page_frag___474 {
	struct page___474 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___474;

struct mem_cgroup___206;

struct cred___441;

struct nsproxy___368;

struct signal_struct___348;

struct bio_list___263;

struct backing_dev_info___263;

struct css_set___322;

struct vm_struct___377;

struct task_struct___475 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___475 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___474 *mm;
	struct mm_struct___474 *active_mm;
	struct vmacache___474 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___475 *real_parent;
	struct task_struct___475 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___475 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___206 *active_memcg;
	long int rh_reserved2;
	struct pid___264 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___264 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___264 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___441 *ptracer_cred;
	const struct cred___441 *real_cred;
	const struct cred___441 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___368 *nsproxy;
	struct signal_struct___348 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___475 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___263 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___263 *backing_dev_info;
	struct io_context___110 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___322 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___154 *splice_pipe;
	struct page_frag___474 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___206 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___475 *oom_reaper_list;
	struct vm_struct___377 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___157 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___474 *pgtable_t___474;

struct address_space___473;

struct dev_pagemap___461;

struct page___474 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___473 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___474 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___474 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___474 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___461 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___206 *mem_cgroup;
};

struct pglist_data___474;

struct lruvec___474 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___474 *pgdat;
};

struct zone___474 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___474 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___474 {
	struct zone___474 *zone;
	int zone_idx;
};

struct zonelist___474 {
	struct zoneref___474 _zonerefs[25];
};

struct pglist_data___474 {
	struct zone___474 node_zones[3];
	struct zonelist___474 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___475 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___475 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___474 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct rw_semaphore___475 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___475 *owner;
};

struct secondary_data___475 {
	void *stack;
	struct task_struct___475 *task;
	long int status;
};

struct blocking_notifier_head___474 {
	struct rw_semaphore___475 rwsem;
	struct notifier_block *head;
};

struct key___441;

struct ucounts___338;

struct user_namespace___338 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___338 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___29 ns;
	long unsigned int flags;
	struct key___441 *persistent_keyring_register;
	struct rw_semaphore___475 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___338 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kernfs_root___467;

struct kernfs_elem_dir___467 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___467 *root;
};

struct kernfs_node___468;

struct kernfs_syscall_ops___467;

struct kernfs_root___467 {
	struct kernfs_node___468 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___467 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___467 {
	struct kernfs_node___468 *target_kn;
};

struct kernfs_ops___467;

struct kernfs_elem_attr___467 {
	const struct kernfs_ops___467 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___468 *notify_next;
};

struct kernfs_node___468 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___468 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___467 dir;
		struct kernfs_elem_symlink___467 symlink;
		struct kernfs_elem_attr___467 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___467;

struct kernfs_ops___467 {
	int (*open)(struct kernfs_open_file___467 *);
	void (*release)(struct kernfs_open_file___467 *);
	int (*seq_show)(struct seq_file___412 *, void *);
	void * (*seq_start)(struct seq_file___412 *, loff_t *);
	void * (*seq_next)(struct seq_file___412 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___412 *, void *);
	ssize_t (*read)(struct kernfs_open_file___467 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___467 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___467 *, struct vm_area_struct___474 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___467 *, struct poll_table_struct___312 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___467 {
	int (*remount_fs)(struct kernfs_root___467 *, int *, char *);
	int (*show_options)(struct seq_file___412 *, struct kernfs_root___467 *);
	int (*mkdir)(struct kernfs_node___468 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___468 *);
	int (*rename)(struct kernfs_node___468 *, struct kernfs_node___468 *, const char *);
	int (*show_path)(struct seq_file___412 *, struct kernfs_node___468 *, struct kernfs_root___467 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___412;

struct seq_file___412 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___412 *op;
	int poll_event;
	const struct file___473 *file;
	void *private;
};

struct vm_operations_struct___461;

struct kernfs_open_file___467 {
	struct kernfs_node___468 *kn;
	struct file___473 *file;
	struct seq_file___412 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___461 *vm_ops;
};

struct dentry___473;

struct path___474 {
	struct vfsmount *mnt;
	struct dentry___473 *dentry;
};

struct file___473 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___474 f_path;
	struct inode___473 *f_inode;
	const struct file_operations___473 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___264 f_owner;
	const struct cred___441 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___473 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___461;

struct vm_operations_struct___461 {
	void (*open)(struct vm_area_struct___474 *);
	void (*close)(struct vm_area_struct___474 *);
	int (*split)(struct vm_area_struct___474 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___474 *);
	vm_fault_t (*fault)(struct vm_fault___461 *);
	vm_fault_t (*huge_fault)(struct vm_fault___461 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___461 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___474 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___461 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___461 *);
	int (*access)(struct vm_area_struct___474 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___474 *);
	int (*set_policy)(struct vm_area_struct___474 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___474 *, long unsigned int);
	struct page___474 * (*find_special_page)(struct vm_area_struct___474 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void (*poll_queue_proc___322)(struct file___473 *, wait_queue_head_t *, struct poll_table_struct___312 *);

struct poll_table_struct___312 {
	poll_queue_proc___322 _qproc;
	__poll_t _key;
};

struct vm_area_struct___474 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___474 *vm_next;
	struct vm_area_struct___474 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___474 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___461 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___473 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct sock___98;

struct kobj_ns_type_operations___98 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___98 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct net___129;

typedef struct {
	struct net___129 *net;
} possible_net_t___120;

struct proto___98;

struct sock_common___98 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___98 *skc_prot;
	possible_net_t___120 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___98 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___119;

struct sk_buff_head___118 {
	struct sk_buff___119 *next;
	struct sk_buff___119 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___98;

struct socket_wq___99;

struct dst_entry___98;

struct socket___100;

struct net_device___118;

struct sock___98 {
	struct sock_common___98 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___118 sk_error_queue;
	struct sk_buff_head___118 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___119 *head;
		struct sk_buff___119 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___98 *sk_filter;
	union {
		struct socket_wq___99 *sk_wq;
		struct socket_wq___99 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___98 *sk_rx_dst;
	struct dst_entry___98 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___119 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___118 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___474 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___98 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___264 *sk_peer_pid;
	const struct cred___441 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___100 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___206 *sk_memcg;
	void (*sk_state_change)(struct sock___98 *);
	void (*sk_data_ready)(struct sock___98 *);
	void (*sk_write_space)(struct sock___98 *);
	void (*sk_error_report)(struct sock___98 *);
	int (*sk_backlog_rcv)(struct sock___98 *, struct sk_buff___119 *);
	struct sk_buff___119 * (*sk_validate_xmit_skb)(struct sock___98 *, struct net_device___118 *, struct sk_buff___119 *);
	void (*sk_destruct)(struct sock___98 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kobject___461;

struct bin_attribute___437;

struct attribute_group___438 {
	const char *name;
	umode_t (*is_visible)(struct kobject___461 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___461 *, struct bin_attribute___437 *, int);
	struct attribute **attrs;
	struct bin_attribute___437 **bin_attrs;
};

struct kset___460;

struct kobj_type___460;

struct kobject___461 {
	const char *name;
	struct list_head entry;
	struct kobject___461 *parent;
	struct kset___460 *kset;
	struct kobj_type___460 *ktype;
	struct kernfs_node___468 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bin_attribute___437 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___473 *, struct kobject___461 *, struct bin_attribute___437 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___473 *, struct kobject___461 *, struct bin_attribute___437 *, char *, loff_t, size_t);
	int (*mmap)(struct file___473 *, struct kobject___461 *, struct bin_attribute___437 *, struct vm_area_struct___474 *);
};

struct sysfs_ops___460 {
	ssize_t (*show)(struct kobject___461 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___461 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___460;

struct kset___460 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___461 kobj;
	const struct kset_uevent_ops___460 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___460 {
	void (*release)(struct kobject___461 *);
	const struct sysfs_ops___460 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___98 * (*child_ns_type)(struct kobject___461 *);
	const void * (*namespace)(struct kobject___461 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___460 {
	int (* const filter)(struct kset___460 *, struct kobject___461 *);
	const char * (* const name)(struct kset___460 *, struct kobject___461 *);
	int (* const uevent)(struct kset___460 *, struct kobject___461 *, struct kobj_uevent_env *);
};

struct kobj_attribute___451 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___461 *, struct kobj_attribute___451 *, char *);
	ssize_t (*store)(struct kobject___461 *, struct kobj_attribute___451 *, const char *, size_t);
};

struct user_struct___441;

struct cred___441 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___441 *session_keyring;
	struct key___441 *process_keyring;
	struct key___441 *thread_keyring;
	struct key___441 *request_key_auth;
	void *security;
	struct user_struct___441 *user;
	struct user_namespace___338 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct cgroup___322;

struct cgroup_subsys___322;

struct cgroup_subsys_state___322 {
	struct cgroup___322 *cgroup;
	struct cgroup_subsys___322 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___322 *parent;
};

struct cgroup_file___322 {
	struct kernfs_node___468 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___206;

struct mem_cgroup___206 {
	struct cgroup_subsys_state___322 css;
	struct mem_cgroup_id___16 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___322 events_file;
	struct cgroup_file___322 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___475 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___206 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct user_struct___441 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___441 *uid_keyring;
	struct key___441 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct core_state___474;

struct mm_struct___474 {
	struct {
		struct vm_area_struct___474 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___473 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___475 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___474 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___475 *owner;
		struct user_namespace___338 *user_ns;
		struct file___473 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___474 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___322;

struct nsproxy___368 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net___129 *net_ns;
	struct cgroup_namespace___322 *cgroup_ns;
};

struct signal_struct___348 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___475 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___475 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___264 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___264 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___474 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___264 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide22;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___263;

struct bio_list___263 {
	struct bio___263 *head;
	struct bio___263 *tail;
};

struct bdi_writeback_congested___263;

struct bdi_writeback___263 {
	struct backing_dev_info___263 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___263 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___322 *memcg_css;
	struct cgroup_subsys_state___322 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct device___441;

struct backing_dev_info___263 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___263 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___441 *dev;
	struct device___441 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___473 *debug_dir;
	struct dentry___473 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct css_set___322 {
	struct cgroup_subsys_state___322 *subsys[13];
	refcount_t refcount;
	struct css_set___322 *dom_cset;
	struct cgroup___322 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___322 *mg_src_cgrp;
	struct cgroup___322 *mg_dst_cgrp;
	struct css_set___322 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___473;

struct pipe_buffer___154;

struct pipe_inode_info___154 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___474 *tmp_page;
	struct fasync_struct___473 *fasync_readers;
	struct fasync_struct___473 *fasync_writers;
	struct pipe_buffer___154 *bufs;
	struct user_struct___441 *user;
};

struct vm_struct___377 {
	struct vm_struct___377 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___474 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___360 {
	struct task_struct___475 task;
	long unsigned int stack[8192];
};

struct address_space_operations___473;

struct address_space___473 {
	struct inode___473 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___475 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___473 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___461)(struct vm_area_struct___474 *, long unsigned int, const struct page___474 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___461)(struct page___474 *, void *);

struct dev_pagemap___461 {
	dev_page_fault_t___461 page_fault;
	dev_page_free_t___461 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___441 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct core_thread___474 {
	struct task_struct___475 *task;
	struct core_thread___474 *next;
};

struct core_state___474 {
	atomic_t nr_threads;
	struct core_thread___474 dumper;
	struct completion startup;
};

struct vm_fault___461 {
	struct vm_area_struct___474 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___474 *cow_page;
	struct mem_cgroup___206 *memcg;
	struct page___474 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___474 prealloc_pte;
};

struct module_kobject___399 {
	struct kobject___461 kobj;
	struct module___399 *mod;
	struct kobject___461 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___399 {
	struct module___399 *mod;
	struct latch_tree_node node;
};

struct module_layout___399 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___399 mtn;
};

struct module_attribute___399;

struct kernel_param___399;

struct module___399 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___399 mkobj;
	struct module_attribute___399 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___461 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___399 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___399 core_layout;
	struct module_layout___399 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide53;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide54;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bio_vec___265 {
	struct page___474 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___240 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___265 *bvec;
		struct pipe_inode_info___154 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct msghdr___101 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___240 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___473 *msg_iocb;
};

struct kiocb___473 {
	struct file___473 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___473 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct dentry_operations___473;

struct super_block___473;

struct dentry___473 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___473 *d_parent;
	struct qstr d_name;
	struct inode___473 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___473 *d_op;
	struct super_block___473 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___473;

struct block_device___473;

struct inode___473 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___473 *i_op;
	struct super_block___473 *i_sb;
	struct address_space___473 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___475 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___263 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___473 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___473 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___154 *i_pipe;
		struct block_device___473 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___473 {
	int (*d_revalidate)(struct dentry___473 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___473 *, unsigned int);
	int (*d_hash)(const struct dentry___473 *, struct qstr *);
	int (*d_compare)(const struct dentry___473 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___473 *);
	int (*d_init)(struct dentry___473 *);
	void (*d_release)(struct dentry___473 *);
	void (*d_prune)(struct dentry___473 *);
	void (*d_iput)(struct dentry___473 *, struct inode___473 *);
	char * (*d_dname)(struct dentry___473 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___474 *);
	int (*d_manage)(const struct path___474 *, bool);
	struct dentry___473 * (*d_real)(struct dentry___473 *, const struct inode___473 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___473;

struct mem_dqinfo___473 {
	struct quota_format_type___473 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___473;

struct quota_info___473 {
	unsigned int flags;
	struct rw_semaphore___475 dqio_sem;
	struct inode___473 *files[3];
	struct mem_dqinfo___473 info[3];
	const struct quota_format_ops___473 *ops[3];
};

struct rcuwait___473 {
	struct task_struct___475 *task;
};

struct percpu_rw_semaphore___473 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___475 rw_sem;
	struct rcuwait___473 writer;
	int readers_block;
};

struct sb_writers___473 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___473 rw_sem[3];
};

struct shrink_control___206;

struct shrinker___206 {
	long unsigned int (*count_objects)(struct shrinker___206 *, struct shrink_control___206 *);
	long unsigned int (*scan_objects)(struct shrinker___206 *, struct shrink_control___206 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct file_system_type___473;

struct super_operations___473;

struct dquot_operations___473;

struct quotactl_ops___473;

struct super_block___473 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___473 *s_type;
	const struct super_operations___473 *s_op;
	const struct dquot_operations___473 *dq_op;
	const struct quotactl_ops___473 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___473 *s_root;
	struct rw_semaphore___475 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___473 *s_bdev;
	struct backing_dev_info___263 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___473 s_dquot;
	struct sb_writers___473 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___473 *s_d_op;
	int cleancache_poolid;
	struct shrinker___206 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___338 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct shrink_control___206 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___206 *memcg;
};

struct iattr___473 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___473 *ia_file;
};

struct dquot___473 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___473 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___473 {
	int qf_fmt_id;
	const struct quota_format_ops___473 *qf_ops;
	struct module___399 *qf_owner;
	struct quota_format_type___473 *qf_next;
};

struct quota_format_ops___473 {
	int (*check_quota_file)(struct super_block___473 *, int);
	int (*read_file_info)(struct super_block___473 *, int);
	int (*write_file_info)(struct super_block___473 *, int);
	int (*free_file_info)(struct super_block___473 *, int);
	int (*read_dqblk)(struct dquot___473 *);
	int (*commit_dqblk)(struct dquot___473 *);
	int (*release_dqblk)(struct dquot___473 *);
	int (*get_next_id)(struct super_block___473 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___473 {
	int (*write_dquot)(struct dquot___473 *);
	struct dquot___473 * (*alloc_dquot)(struct super_block___473 *, int);
	void (*destroy_dquot)(struct dquot___473 *);
	int (*acquire_dquot)(struct dquot___473 *);
	int (*release_dquot)(struct dquot___473 *);
	int (*mark_dirty)(struct dquot___473 *);
	int (*write_info)(struct super_block___473 *, int);
	qsize_t * (*get_reserved_space)(struct inode___473 *);
	int (*get_projid)(struct inode___473 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___473 *, qsize_t *);
	int (*get_next_id)(struct super_block___473 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___473 {
	int (*quota_on)(struct super_block___473 *, int, int, const struct path___474 *);
	int (*quota_off)(struct super_block___473 *, int);
	int (*quota_enable)(struct super_block___473 *, unsigned int);
	int (*quota_disable)(struct super_block___473 *, unsigned int);
	int (*quota_sync)(struct super_block___473 *, int);
	int (*set_info)(struct super_block___473 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___473 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___473 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___473 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___473 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___473 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___226;

struct address_space_operations___473 {
	int (*writepage)(struct page___474 *, struct writeback_control___226 *);
	int (*readpage)(struct file___473 *, struct page___474 *);
	int (*writepages)(struct address_space___473 *, struct writeback_control___226 *);
	int (*set_page_dirty)(struct page___474 *);
	int (*readpages)(struct file___473 *, struct address_space___473 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___473 *, struct address_space___473 *, loff_t, unsigned int, unsigned int, struct page___474 **, void **);
	int (*write_end)(struct file___473 *, struct address_space___473 *, loff_t, unsigned int, unsigned int, struct page___474 *, void *);
	sector_t (*bmap)(struct address_space___473 *, sector_t);
	void (*invalidatepage)(struct page___474 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___474 *, gfp_t);
	void (*freepage)(struct page___474 *);
	ssize_t (*direct_IO)(struct kiocb___473 *, struct iov_iter___240 *);
	int (*migratepage)(struct address_space___473 *, struct page___474 *, struct page___474 *, enum migrate_mode);
	bool (*isolate_page)(struct page___474 *, isolate_mode_t);
	void (*putback_page)(struct page___474 *);
	int (*launder_page)(struct page___474 *);
	int (*is_partially_uptodate)(struct page___474 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___474 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___473 *, struct page___474 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___473 *, sector_t *);
	void (*swap_deactivate)(struct file___473 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___226 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___263 *wb;
	struct inode___473 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct block_device___473 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___473 *bd_inode;
	struct super_block___473 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___473 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___4 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___4 *bd_disk;
	struct request_queue___3 *bd_queue;
	struct backing_dev_info___263 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___473 {
	struct dentry___473 * (*lookup)(struct inode___473 *, struct dentry___473 *, unsigned int);
	const char * (*get_link)(struct dentry___473 *, struct inode___473 *, struct delayed_call *);
	int (*permission)(struct inode___473 *, int);
	struct posix_acl * (*get_acl)(struct inode___473 *, int);
	int (*readlink)(struct dentry___473 *, char *, int);
	int (*create)(struct inode___473 *, struct dentry___473 *, umode_t, bool);
	int (*link)(struct dentry___473 *, struct inode___473 *, struct dentry___473 *);
	int (*unlink)(struct inode___473 *, struct dentry___473 *);
	int (*symlink)(struct inode___473 *, struct dentry___473 *, const char *);
	int (*mkdir)(struct inode___473 *, struct dentry___473 *, umode_t);
	int (*rmdir)(struct inode___473 *, struct dentry___473 *);
	int (*mknod)(struct inode___473 *, struct dentry___473 *, umode_t, dev_t);
	int (*rename)(struct inode___473 *, struct dentry___473 *, struct inode___473 *, struct dentry___473 *, unsigned int);
	int (*setattr)(struct dentry___473 *, struct iattr___473 *);
	int (*getattr)(const struct path___474 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___473 *, char *, size_t);
	int (*fiemap)(struct inode___473 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___473 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___473 *, struct dentry___473 *, struct file___473 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___473 *, struct dentry___473 *, umode_t);
	int (*set_acl)(struct inode___473 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___473 {
	void (*fl_copy_lock)(struct file_lock___473 *, struct file_lock___473 *);
	void (*fl_release_private)(struct file_lock___473 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___473;

struct file_lock___473 {
	struct file_lock___473 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___473 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___473 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___473 *fl_ops;
	const struct lock_manager_operations___473 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___473 {
	int (*lm_compare_owner)(struct file_lock___473 *, struct file_lock___473 *);
	long unsigned int (*lm_owner_key)(struct file_lock___473 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___473 *);
	int (*lm_grant)(struct file_lock___473 *, int);
	bool (*lm_break)(struct file_lock___473 *);
	int (*lm_change)(struct file_lock___473 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___473 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___473 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___473 *fa_next;
	struct file___473 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___473 {
	const char *name;
	int fs_flags;
	struct dentry___473 * (*mount)(struct file_system_type___473 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___473 *);
	struct module___399 *owner;
	struct file_system_type___473 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___473 {
	struct inode___473 * (*alloc_inode)(struct super_block___473 *);
	void (*destroy_inode)(struct inode___473 *);
	void (*dirty_inode)(struct inode___473 *, int);
	int (*write_inode)(struct inode___473 *, struct writeback_control___226 *);
	int (*drop_inode)(struct inode___473 *);
	void (*evict_inode)(struct inode___473 *);
	void (*put_super)(struct super_block___473 *);
	int (*sync_fs)(struct super_block___473 *, int);
	int (*freeze_super)(struct super_block___473 *);
	int (*freeze_fs)(struct super_block___473 *);
	int (*thaw_super)(struct super_block___473 *);
	int (*unfreeze_fs)(struct super_block___473 *);
	int (*statfs)(struct dentry___473 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___473 *, int *, char *);
	void (*umount_begin)(struct super_block___473 *);
	int (*show_options)(struct seq_file___412 *, struct dentry___473 *);
	int (*show_devname)(struct seq_file___412 *, struct dentry___473 *);
	int (*show_path)(struct seq_file___412 *, struct dentry___473 *);
	int (*show_stats)(struct seq_file___412 *, struct dentry___473 *);
	ssize_t (*quota_read)(struct super_block___473 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___473 *, int, const char *, size_t, loff_t);
	struct dquot___473 ** (*get_dquots)(struct inode___473 *);
	int (*bdev_try_to_free_page)(struct super_block___473 *, struct page___474 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___473 *, struct shrink_control___206 *);
	long int (*free_cached_objects)(struct super_block___473 *, struct shrink_control___206 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___263(struct bio___263 *);

struct bio_integrity_payload___263;

struct bio_set___263;

struct bio___263 {
	struct bio___263 *bi_next;
	struct gendisk___4 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___263 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___263 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___265 *bi_io_vec;
	struct bio_set___263 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___265 bi_inline_vecs[0];
};

struct socket_wq___99 {
	wait_queue_head_t wait;
	struct fasync_struct___473 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___99;

struct socket___100 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___99 *wq;
	struct file___473 *file;
	struct sock___98 *sk;
	const struct proto_ops___99 *ops;
};

typedef int (*sk_read_actor_t___98)(read_descriptor_t *, struct sk_buff___119 *, unsigned int, size_t);

struct proto_ops___99 {
	int family;
	struct module___399 *owner;
	int (*release)(struct socket___100 *);
	int (*bind)(struct socket___100 *, struct sockaddr *, int);
	int (*connect)(struct socket___100 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___100 *, struct socket___100 *);
	int (*accept)(struct socket___100 *, struct socket___100 *, int, bool);
	int (*getname)(struct socket___100 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___473 *, struct socket___100 *, struct poll_table_struct___312 *);
	int (*ioctl)(struct socket___100 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___100 *, int);
	int (*shutdown)(struct socket___100 *, int);
	int (*setsockopt)(struct socket___100 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___100 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___100 *, struct msghdr___101 *, size_t);
	int (*recvmsg)(struct socket___100 *, struct msghdr___101 *, size_t, int);
	int (*mmap)(struct file___473 *, struct socket___100 *, struct vm_area_struct___474 *);
	ssize_t (*sendpage)(struct socket___100 *, struct page___474 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___100 *, loff_t *, struct pipe_inode_info___154 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___98 *, int);
	int (*peek_len)(struct socket___100 *);
	int (*read_sock)(struct sock___98 *, read_descriptor_t *, sk_read_actor_t___98);
	int (*sendpage_locked)(struct sock___98 *, struct page___474 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___98 *, struct msghdr___101 *, size_t);
	int (*set_rcvlowat)(struct sock___98 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct nf_bridge_info___118;

struct sk_buff___119 {
	union {
		struct {
			struct sk_buff___119 *next;
			struct sk_buff___119 *prev;
			union {
				struct net_device___118 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___98 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___119 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___118 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___118;

struct netns_frags___118 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___118 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_rules_ops___98;

struct fib_notifier_ops___99;

struct netns_ipv4___118 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___98 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___98 *fibnl;
	struct sock___98 **icmp_sk;
	struct sock___98 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___98 **tcp_sk;
	struct netns_frags___118 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___98 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___99 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___99 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___98;

struct dst_ops___129 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___129 *);
	struct dst_entry___98 * (*check)(struct dst_entry___98 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___98 *);
	unsigned int (*mtu)(const struct dst_entry___98 *);
	u32 * (*cow_metrics)(struct dst_entry___98 *, long unsigned int);
	void (*destroy)(struct dst_entry___98 *);
	void (*ifdown)(struct dst_entry___98 *, struct net_device___118 *, int);
	struct dst_entry___98 * (*negative_advice)(struct dst_entry___98 *);
	void (*link_failure)(struct sk_buff___119 *);
	void (*update_pmtu)(struct dst_entry___98 *, struct sock___98 *, struct sk_buff___119 *, u32);
	void (*redirect)(struct dst_entry___98 *, struct sock___98 *, struct sk_buff___119 *);
	int (*local_out)(struct net___129 *, struct sock___98 *, struct sk_buff___119 *);
	struct neighbour___98 * (*neigh_lookup)(const struct dst_entry___98 *, struct sk_buff___119 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___98 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___129 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___118 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___129 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___98 *fib6_rules_ops;
	struct sock___98 **icmp_sk;
	struct sock___98 *ndisc_sk;
	struct sock___98 *tcp_sk;
	struct sock___98 *igmp_sk;
	struct sock___98 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___98 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___99 *notifier_ops;
	struct fib_notifier_ops___99 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___99 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___98 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___118 {
	struct netns_frags___118 frags;
};

struct netns_xfrm___129 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___98 *nlsk;
	struct sock___98 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___129 xfrm4_dst_ops;
	struct dst_ops___129 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct uevent_sock___2;

struct bpf_prog___108;

struct net___129 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___338 *user_ns;
	struct ucounts___338 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___29 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___98 *rtnl;
	struct sock___98 *genl_sock;
	struct uevent_sock___2 *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___118 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___118 ipv4;
	struct netns_ipv6___129 ipv6;
	struct netns_sctp___99 sctp;
	struct netns_nf___23 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___118 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___98 *nfnl;
	struct sock___98 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___129 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___98 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___108 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___441 {
	int (*prepare)(struct device___441 *);
	void (*complete)(struct device___441 *);
	int (*suspend)(struct device___441 *);
	int (*resume)(struct device___441 *);
	int (*freeze)(struct device___441 *);
	int (*thaw)(struct device___441 *);
	int (*poweroff)(struct device___441 *);
	int (*restore)(struct device___441 *);
	int (*suspend_late)(struct device___441 *);
	int (*resume_early)(struct device___441 *);
	int (*freeze_late)(struct device___441 *);
	int (*thaw_early)(struct device___441 *);
	int (*poweroff_late)(struct device___441 *);
	int (*restore_early)(struct device___441 *);
	int (*suspend_noirq)(struct device___441 *);
	int (*resume_noirq)(struct device___441 *);
	int (*freeze_noirq)(struct device___441 *);
	int (*thaw_noirq)(struct device___441 *);
	int (*poweroff_noirq)(struct device___441 *);
	int (*restore_noirq)(struct device___441 *);
	int (*runtime_suspend)(struct device___441 *);
	int (*runtime_resume)(struct device___441 *);
	int (*runtime_idle)(struct device___441 *);
};

struct dev_pm_info___441 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___441 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___441;

struct bus_type___441;

struct device_driver___441;

struct dev_pm_domain___441;

struct dma_map_ops___213;

struct fwnode_handle___361;

struct class___441;

struct device___441 {
	struct device___441 *parent;
	struct device_private *p;
	struct kobject___461 kobj;
	const char *init_name;
	const struct device_type___441 *type;
	struct mutex mutex;
	struct bus_type___441 *bus;
	struct device_driver___441 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___441 power;
	struct dev_pm_domain___441 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___213 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___361 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___441 *class;
	const struct attribute_group___438 **groups;
	void (*release)(struct device___441 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct dev_pm_domain___441 {
	struct dev_pm_ops___441 ops;
	void (*detach)(struct device___441 *, bool);
	int (*activate)(struct device___441 *);
	void (*sync)(struct device___441 *);
	void (*dismiss)(struct device___441 *);
};

struct bus_type___441 {
	const char *name;
	const char *dev_name;
	struct device___441 *dev_root;
	const struct attribute_group___438 **bus_groups;
	const struct attribute_group___438 **dev_groups;
	const struct attribute_group___438 **drv_groups;
	int (*match)(struct device___441 *, struct device_driver___441 *);
	int (*uevent)(struct device___441 *, struct kobj_uevent_env *);
	int (*probe)(struct device___441 *);
	int (*remove)(struct device___441 *);
	void (*shutdown)(struct device___441 *);
	int (*online)(struct device___441 *);
	int (*offline)(struct device___441 *);
	int (*suspend)(struct device___441 *, pm_message_t);
	int (*resume)(struct device___441 *);
	int (*num_vf)(struct device___441 *);
	int (*dma_configure)(struct device___441 *);
	const struct dev_pm_ops___441 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___441 {
	const char *name;
	struct bus_type___441 *bus;
	struct module___399 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___441 *);
	int (*remove)(struct device___441 *);
	void (*shutdown)(struct device___441 *);
	int (*suspend)(struct device___441 *, pm_message_t);
	int (*resume)(struct device___441 *);
	const struct attribute_group___438 **groups;
	const struct dev_pm_ops___441 *pm;
	void (*coredump)(struct device___441 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___441 {
	const char *name;
	const struct attribute_group___438 **groups;
	int (*uevent)(struct device___441 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___441 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___441 *);
	const struct dev_pm_ops___441 *pm;
};

struct class___441 {
	const char *name;
	struct module___399 *owner;
	const struct attribute_group___438 **class_groups;
	const struct attribute_group___438 **dev_groups;
	struct kobject___461 *dev_kobj;
	int (*dev_uevent)(struct device___441 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___441 *, umode_t *);
	void (*class_release)(struct class___441 *);
	void (*dev_release)(struct device___441 *);
	int (*shutdown_pre)(struct device___441 *);
	const struct kobj_ns_type_operations___98 *ns_type;
	const void * (*namespace)(struct device___441 *);
	const struct dev_pm_ops___441 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___213 {
	void * (*alloc)(struct device___441 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___441 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___441 *, struct vm_area_struct___474 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___441 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___441 *, struct page___474 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___441 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___441 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___441 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___441 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___441 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___441 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide16;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___441 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___441 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___441 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___441 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___441 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___441 *, u64);
	u64 (*get_required_mask)(struct device___441 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct fwnode_operations___361;

struct fwnode_handle___361 {
	struct fwnode_handle___361 *secondary;
	const struct fwnode_operations___361 *ops;
};

typedef void compound_page_dtor___461(struct page___474 *);

struct fwnode_reference_args___361;

struct fwnode_endpoint___361;

struct fwnode_operations___361 {
	struct fwnode_handle___361 * (*get)(struct fwnode_handle___361 *);
	void (*put)(struct fwnode_handle___361 *);
	bool (*device_is_available)(const struct fwnode_handle___361 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___361 *, const struct device___441 *);
	bool (*property_present)(const struct fwnode_handle___361 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___361 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___361 *, const char *, const char **, size_t);
	struct fwnode_handle___361 * (*get_parent)(const struct fwnode_handle___361 *);
	struct fwnode_handle___361 * (*get_next_child_node)(const struct fwnode_handle___361 *, struct fwnode_handle___361 *);
	struct fwnode_handle___361 * (*get_named_child_node)(const struct fwnode_handle___361 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___361 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___361 *);
	struct fwnode_handle___361 * (*graph_get_next_endpoint)(const struct fwnode_handle___361 *, struct fwnode_handle___361 *);
	struct fwnode_handle___361 * (*graph_get_remote_endpoint)(const struct fwnode_handle___361 *);
	struct fwnode_handle___361 * (*graph_get_port_parent)(struct fwnode_handle___361 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___361 *, struct fwnode_endpoint___361 *);
};

struct fwnode_endpoint___361 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___361 *local_fwnode;
};

struct fwnode_reference_args___361 {
	struct fwnode_handle___361 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct pipe_buf_operations___154;

struct pipe_buffer___154 {
	struct page___474 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___154 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___154 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___154 *, struct pipe_buffer___154 *);
	void (*release)(struct pipe_inode_info___154 *, struct pipe_buffer___154 *);
	int (*steal)(struct pipe_inode_info___154 *, struct pipe_buffer___154 *);
	union {
		bool (*get)(struct pipe_inode_info___154 *, struct pipe_buffer___154 *);
		struct {
			void (*get)(struct pipe_inode_info___154 *, struct pipe_buffer___154 *);
		} __UNIQUE_ID_rh_kabi_hide19;
		union {		};
	};
};

struct nf_bridge_info___118 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___118 = 0,
		BRNF_PROTO_8021Q___118 = 1,
		BRNF_PROTO_PPPOE___118 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___118 *physindev;
	struct net_device___118 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___118(struct sk_buff___119 **);

struct net_device_ops___118;

struct ethtool_ops___118;

struct l3mdev_ops___98;

struct xfrmdev_ops___118;

struct tlsdev_ops___118;

struct header_ops___118;

struct netdev_rx_queue___118;

struct mini_Qdisc___110;

struct netdev_queue___118;

struct Qdisc___110;

struct rtnl_link_ops___110;

struct dcbnl_rtnl_ops___118;

struct net_device___118 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___118 *netdev_ops;
	const struct ethtool_ops___118 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___98 *l3mdev_ops;
	const struct ndisc_ops___2 *ndisc_ops;
	const struct xfrmdev_ops___118 *xfrmdev_ops;
	const struct tlsdev_ops___118 *tlsdev_ops;
	const struct header_ops___118 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___460 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___2 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___118 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___108 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___118 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___110 *miniq_ingress;
	struct netdev_queue___118 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___118 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___110 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___110 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___118 = 0,
		NETREG_REGISTERED___118 = 1,
		NETREG_UNREGISTERING___118 = 2,
		NETREG_UNREGISTERED___118 = 3,
		NETREG_RELEASED___118 = 4,
		NETREG_DUMMY___118 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___118 = 0,
		RTNL_LINK_INITIALIZING___118 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___118 *);
	struct netpoll_info *npinfo;
	possible_net_t___120 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___441 dev;
	const struct attribute_group___438 *sysfs_groups[4];
	const struct attribute_group___438 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___110 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___118 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

typedef int (*key_restrict_link_func_t___442)(struct key___441 *, const struct key_type *, const union key_payload *, struct key___441 *);

struct key_restriction___441;

struct key___441 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___475 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___441 *restrict_link;
};

struct key_restriction___441 {
	key_restrict_link_func_t___442 check;
	struct key___441 *key;
	struct key_type *keytype;
};

struct cgroup_namespace___322 {
	refcount_t count;
	struct ns_common___29 ns;
	struct user_namespace___338 *user_ns;
	struct ucounts___338 *ucounts;
	struct css_set___322 *root_cset;
};

struct netlink_skb_parms___23 {
	struct scm_creds creds;
	__u32 portid;
	__u32 dst_group;
	__u32 flags;
	struct sock___98 *sk;
	bool nsid_is_set;
	int nsid;
};

struct netlink_kernel_cfg___9 {
	unsigned int groups;
	unsigned int flags;
	void (*input)(struct sk_buff___119 *);
	struct mutex *cb_mutex;
	int (*bind)(struct net___129 *, int);
	void (*unbind)(struct net___129 *, int);
	bool (*compare)(struct net___129 *, struct sock___98 *);
};

struct netlink_callback___120 {
	struct sk_buff___119 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___120 *);
	int (*dump)(struct sk_buff___119 *, struct netlink_callback___120 *);
	int (*done)(struct netlink_callback___120 *);
	void *data;
	struct module___399 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct ethtool_ops___118 {
	int (*get_settings)(struct net_device___118 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___118 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___118 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___118 *);
	void (*get_regs)(struct net_device___118 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___118 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___118 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___118 *);
	void (*set_msglevel)(struct net_device___118 *, u32);
	int (*nway_reset)(struct net_device___118 *);
	u32 (*get_link)(struct net_device___118 *);
	int (*get_eeprom_len)(struct net_device___118 *);
	int (*get_eeprom)(struct net_device___118 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___118 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___118 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___118 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___118 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___118 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___118 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___118 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___118 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___118 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___118 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___118 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___118 *);
	void (*complete)(struct net_device___118 *);
	u32 (*get_priv_flags)(struct net_device___118 *);
	int (*set_priv_flags)(struct net_device___118 *, u32);
	int (*get_sset_count)(struct net_device___118 *, int);
	int (*get_rxnfc)(struct net_device___118 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___118 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___118 *, struct ethtool_flash *);
	int (*reset)(struct net_device___118 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___118 *);
	u32 (*get_rxfh_indir_size)(struct net_device___118 *);
	int (*get_rxfh)(struct net_device___118 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___118 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___118 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___118 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___118 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___118 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___118 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___118 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___118 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___118 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___118 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___118 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___118 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___118 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___118 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___118 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___118 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___118 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___118 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___118 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide23;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___118 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___118 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	int (*get_fecparam)(struct net_device___118 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___118 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___118 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___118 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___118 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___118;

struct inet_frags___118 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___118 *, const void *);
	void (*destructor)(struct inet_frag_queue___118 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___118 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___119 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___119 *fragments_tail;
	struct sk_buff___119 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___118 *net;
	struct callback_head rcu;
};

struct fib_rule___98;

struct fib_lookup_arg___98;

struct fib_rules_ops___98 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___98 *, struct flowi *, int, struct fib_lookup_arg___98 *);
	bool (*suppress)(struct fib_rule___98 *, struct fib_lookup_arg___98 *);
	int (*match)(struct fib_rule___98 *, struct flowi *, int);
	int (*configure)(struct fib_rule___98 *, struct sk_buff___119 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___98 *);
	int (*compare)(struct fib_rule___98 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___98 *, struct sk_buff___119 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___98 *);
	void (*flush_cache)(struct fib_rules_ops___98 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___399 *owner;
	struct net___129 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___99 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___129 *);
	int (*fib_dump)(struct net___129 *, struct notifier_block *);
	struct module___399 *owner;
	struct callback_head rcu;
};

struct dst_entry___98 {
	struct net_device___118 *dev;
	struct dst_ops___129 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___119 *);
	int (*output)(struct net___129 *, struct sock___98 *, struct sk_buff___119 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___98;

struct neigh_parms___98;

struct neigh_ops___98;

struct neighbour___98 {
	struct neighbour___98 *next;
	struct neigh_table___98 *tbl;
	struct neigh_parms___98 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___118 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___98 *, struct sk_buff___119 *);
	const struct neigh_ops___98 *ops;
	struct callback_head rcu;
	struct net_device___118 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct ucounts___338 {
	struct hlist_node node;
	struct user_namespace___338 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct uevent_sock___2 {
	struct list_head list;
	struct sock___98 *sk;
};

struct bpf_prog_aux___111;

struct bpf_prog___108 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___111 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

struct seq_operations___412 {
	void * (*start)(struct seq_file___412 *, loff_t *);
	void (*stop)(struct seq_file___412 *, void *);
	void * (*next)(struct seq_file___412 *, void *, loff_t *);
	int (*show)(struct seq_file___412 *, void *);
};

struct pernet_operations___119 {
	struct list_head list;
	int (*init)(struct net___129 *);
	void (*exit)(struct net___129 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___118 {
	int (*ieee_getets)(struct net_device___118 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___118 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___118 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___118 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___118 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___118 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___118 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___118 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___118 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___118 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___118 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___118 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___118 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___118 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___118 *);
	u8 (*setstate)(struct net_device___118 *, u8);
	void (*getpermhwaddr)(struct net_device___118 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___118 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___118 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___118 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___118 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___118 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___118 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___118 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___118 *, int, u8 *);
	void (*setpfccfg)(struct net_device___118 *, int, u8);
	void (*getpfccfg)(struct net_device___118 *, int, u8 *);
	u8 (*setall)(struct net_device___118 *);
	u8 (*getcap)(struct net_device___118 *, int, u8 *);
	int (*getnumtcs)(struct net_device___118 *, int, u8 *);
	int (*setnumtcs)(struct net_device___118 *, int, u8);
	u8 (*getpfcstate)(struct net_device___118 *);
	void (*setpfcstate)(struct net_device___118 *, u8);
	void (*getbcncfg)(struct net_device___118 *, int, u32 *);
	void (*setbcncfg)(struct net_device___118 *, int, u32);
	void (*getbcnrp)(struct net_device___118 *, int, u8 *);
	void (*setbcnrp)(struct net_device___118 *, int, u8);
	int (*setapp)(struct net_device___118 *, u8, u16, u8);
	int (*getapp)(struct net_device___118 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___118 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___118 *, int, u8);
	u8 (*getdcbx)(struct net_device___118 *);
	u8 (*setdcbx)(struct net_device___118 *, u8);
	int (*peer_getappinfo)(struct net_device___118 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___118 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___118 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___118 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___118 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___118 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct bpf_map___323;

struct bpf_map_ops___322 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___323 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___323 *, struct file___473 *);
	void (*map_free)(struct bpf_map___323 *);
	int (*map_get_next_key)(struct bpf_map___323 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___323 *);
	void * (*map_lookup_elem)(struct bpf_map___323 *, void *);
	int (*map_update_elem)(struct bpf_map___323 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___323 *, void *);
	int (*map_push_elem)(struct bpf_map___323 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___323 *, void *);
	int (*map_peek_elem)(struct bpf_map___323 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___323 *, struct file___473 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___323 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___323 *, void *, struct seq_file___412 *);
	int (*map_check_btf)(const struct bpf_map___323 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___323 {
	const struct bpf_map_ops___322 *ops;
	struct bpf_map___323 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___441 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___118;

struct bpf_map_dev_ops___118 {
	int (*map_get_next_key)(struct bpf_offloaded_map___118 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___118 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___118 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___118 *, void *);
};

struct bpf_offloaded_map___118 {
	struct bpf_map___323 map;
	struct net_device___118 *netdev;
	const struct bpf_map_dev_ops___118 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___108 {
	int (*test_run)(struct bpf_prog___108 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___108 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___108 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___108 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___108 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___108 *, u32 *);
};

struct bpf_prog_offload_ops___108 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___108 *);
	int (*translate)(struct bpf_prog___108 *);
	void (*destroy)(struct bpf_prog___108 *);
};

struct bpf_prog_offload___108 {
	struct bpf_prog___108 *prog;
	struct net_device___118 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___108 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___111 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___108 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___108 *ops;
	struct bpf_map___323 **used_maps;
	struct bpf_prog___108 *prog;
	struct user_struct___441 *user;
	u64 load_time;
	struct bpf_map___323 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___108 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___108 {
	struct bpf_prog___108 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___108 {
	struct callback_head rcu;
	struct bpf_prog_array_item___108 items[0];
};

struct cgroup_bpf___108 {
	struct bpf_prog_array___108 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___108 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___323;

typedef void (*kthread_work_func_t___323)(struct kthread_work___323 *);

struct kthread_worker___323;

struct kthread_work___323 {
	struct list_head node;
	kthread_work_func_t___323 func;
	struct kthread_worker___323 *worker;
	int canceling;
};

struct kthread_worker___323 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___475 *task;
	struct kthread_work___323 *current_work;
};

struct kthread_delayed_work___322 {
	struct kthread_work___323 work;
	struct timer_list timer;
};

struct psi_group___322 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___323 *poll_kworker;
	struct kthread_delayed_work___322 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___322;

struct cgroup_rstat_cpu___322;

struct cgroup___322 {
	struct cgroup_subsys_state___322 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___468 *kn;
	struct cgroup_file___322 procs_file;
	struct cgroup_file___322 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___322 *subsys[13];
	struct cgroup_root___322 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___322 *dom_cgrp;
	struct cgroup_rstat_cpu___322 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___108 bpf;
	atomic_t congestion_count;
	struct cgroup___322 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___322 psi;
	int ancestor_ids[0];
};

struct cftype___322;

struct cgroup_subsys___322 {
	struct cgroup_subsys_state___322 * (*css_alloc)(struct cgroup_subsys_state___322 *);
	int (*css_online)(struct cgroup_subsys_state___322 *);
	void (*css_offline)(struct cgroup_subsys_state___322 *);
	void (*css_released)(struct cgroup_subsys_state___322 *);
	void (*css_free)(struct cgroup_subsys_state___322 *);
	void (*css_reset)(struct cgroup_subsys_state___322 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___322 *, int);
	int (*css_extra_stat_show)(struct seq_file___412 *, struct cgroup_subsys_state___322 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___475 *);
	void (*cancel_fork)(struct task_struct___475 *);
	void (*fork)(struct task_struct___475 *);
	void (*exit)(struct task_struct___475 *);
	void (*free)(struct task_struct___475 *);
	void (*bind)(struct cgroup_subsys_state___322 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___322 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___322 *dfl_cftypes;
	struct cftype___322 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___322 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___322 *updated_children;
	struct cgroup___322 *updated_next;
};

struct cgroup_root___322 {
	struct kernfs_root___467 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___322 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___322 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___322 *ss;
	struct list_head node;
	struct kernfs_ops___467 *kf_ops;
	int (*open)(struct kernfs_open_file___467 *);
	void (*release)(struct kernfs_open_file___467 *);
	u64 (*read_u64)(struct cgroup_subsys_state___322 *, struct cftype___322 *);
	s64 (*read_s64)(struct cgroup_subsys_state___322 *, struct cftype___322 *);
	int (*seq_show)(struct seq_file___412 *, void *);
	void * (*seq_start)(struct seq_file___412 *, loff_t *);
	void * (*seq_next)(struct seq_file___412 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___412 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___322 *, struct cftype___322 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___322 *, struct cftype___322 *, s64);
	ssize_t (*write)(struct kernfs_open_file___467 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___467 *, struct poll_table_struct___312 *);
};

struct xdp_rxq_info___118 {
	struct net_device___118 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___118 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___118 *dev_rx;
};

struct header_ops___118 {
	int (*create)(struct sk_buff___119 *, struct net_device___118 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___119 *, unsigned char *);
	int (*cache)(const struct neighbour___98 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___118 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___118 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___118 *, int);
	int poll_owner;
	struct net_device___118 *dev;
	struct sk_buff___119 *gro_list;
	struct sk_buff___119 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___118 {
	struct net_device___118 *dev;
	struct Qdisc___110 *qdisc;
	struct Qdisc___110 *qdisc_sleeping;
	struct kobject___461 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___118 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem___5 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___110 {
	struct sk_buff___119 *head;
	struct sk_buff___119 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___110;

struct Qdisc___110 {
	int (*enqueue)(struct sk_buff___119 *, struct Qdisc___110 *, struct sk_buff___119 **);
	struct sk_buff___119 * (*dequeue)(struct Qdisc___110 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___110 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___118 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___118 gso_skb;
	struct qdisc_skb_head___110 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___110 *next_sched;
	struct sk_buff_head___118 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___118 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___461 kobj;
	struct net_device___118 *dev;
	long: 64;
	struct xdp_rxq_info___118 xdp_rxq;
	union {
		struct xdp_umem___5 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___118)(struct net_device___118 *, struct sk_buff___119 *, struct net_device___118 *);

struct netdev_bpf___118 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___108 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___108 *prog;
			const struct bpf_prog_offload_ops___108 *ops;
		} verifier;
		struct {
			struct bpf_prog___108 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___118 *offmap;
		};
		struct {
			struct xdp_umem___5 *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___118 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___119 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___118 {
	int (*tls_dev_add)(struct net_device___118 *, struct sock___98 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___118 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___118 *, struct sock___98 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___118 {
	int (*ndo_init)(struct net_device___118 *);
	void (*ndo_uninit)(struct net_device___118 *);
	int (*ndo_open)(struct net_device___118 *);
	int (*ndo_stop)(struct net_device___118 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___119 *, struct net_device___118 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___119 *, struct net_device___118 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___118 *, struct sk_buff___119 *, struct net_device___118 *, select_queue_fallback_t___118);
	void (*ndo_change_rx_flags)(struct net_device___118 *, int);
	void (*ndo_set_rx_mode)(struct net_device___118 *);
	int (*ndo_set_mac_address)(struct net_device___118 *, void *);
	int (*ndo_validate_addr)(struct net_device___118 *);
	int (*ndo_do_ioctl)(struct net_device___118 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___118 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___118 *, int);
	int (*ndo_neigh_setup)(struct net_device___118 *, struct neigh_parms___98 *);
	void (*ndo_tx_timeout)(struct net_device___118 *);
	void (*ndo_get_stats64)(struct net_device___118 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___118 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___118 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___118 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___118 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___118 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___118 *);
	int (*ndo_netpoll_setup)(struct net_device___118 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___118 *);
	int (*ndo_set_vf_mac)(struct net_device___118 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___118 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___118 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___118 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___118 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___118 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___118 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___118 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___118 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___118 *, int, struct sk_buff___119 *);
	int (*ndo_set_vf_guid)(struct net_device___118 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___118 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___118 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___118 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___118 *, const struct sk_buff___119 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___118 *, struct net_device___118 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___118 *, struct net_device___118 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___118 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___118 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___118 *, struct neighbour___98 *);
	void (*ndo_neigh_destroy)(struct net_device___118 *, struct neighbour___98 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___118 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___118 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___118 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___119 *, struct netlink_callback___120 *, struct net_device___118 *, struct net_device___118 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___118 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___118 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___119 *, u32, u32, struct net_device___118 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___118 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___118 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___118 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___118 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___118 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___118 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___118 *, struct net_device___118 *);
	void (*ndo_dfwd_del_station)(struct net_device___118 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___118 *);
	int (*ndo_set_tx_maxrate)(struct net_device___118 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___118 *);
	int (*ndo_change_proto_down)(struct net_device___118 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___118 *, struct sk_buff___119 *);
	void (*ndo_set_rx_headroom)(struct net_device___118 *, int);
	int (*ndo_bpf)(struct net_device___118 *, struct netdev_bpf___118 *);
	int (*ndo_xdp_xmit)(struct net_device___118 *, int, struct xdp_frame___118 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___118 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___118 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___98 {
	possible_net_t___120 net;
	struct net_device___118 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___98 *);
	void (*neigh_cleanup)(struct neighbour___98 *);
	struct neigh_table___98 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___98 {
	u32 (*l3mdev_fib_table)(const struct net_device___118 *);
	struct sk_buff___119 * (*l3mdev_l3_rcv)(struct net_device___118 *, struct sk_buff___119 *, u16);
	struct sk_buff___119 * (*l3mdev_l3_out)(struct net_device___118 *, struct sock___98 *, struct sk_buff___119 *, u16);
	struct dst_entry___98 * (*l3mdev_link_scope_lookup)(const struct net_device___118 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct tcf_proto___110;

struct mini_Qdisc___110 {
	struct tcf_proto___110 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___110 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___118 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___129 *, struct net_device___118 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___118 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___118 *, struct list_head *);
	size_t (*get_size)(const struct net_device___118 *);
	int (*fill_info)(struct sk_buff___119 *, const struct net_device___118 *);
	size_t (*get_xstats_size)(const struct net_device___118 *);
	int (*fill_xstats)(struct sk_buff___119 *, const struct net_device___118 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___118 *, struct net_device___118 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___118 *, const struct net_device___118 *);
	int (*fill_slave_info)(struct sk_buff___119 *, const struct net_device___118 *, const struct net_device___118 *);
	struct net___129 * (*get_link_net)(const struct net_device___118 *);
	size_t (*get_linkxstats_size)(const struct net_device___118 *, int);
	int (*fill_linkxstats)(struct sk_buff___119 *, const struct net_device___118 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___118 {
	struct list_head poll_list;
	struct sk_buff_head___118 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___118 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___110 *output_queue;
	struct Qdisc___110 **output_queue_tailp;
	struct sk_buff___119 *completion_queue;
	struct sk_buff_head___118 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___118 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___118 input_pkt_queue;
	struct napi_struct___118 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bdi_writeback_congested___263 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___263 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___263 {
	struct bio___263 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___265 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___265 bip_inline_vecs[0];
};

struct bio_set___263 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___263 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct mem_cgroup_reclaim_iter___206 {
	struct mem_cgroup___206 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___206 {
	struct lruvec___474 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___206 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___206 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct kernel_param_ops___399 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___399 *);
	int (*get)(char *, const struct kernel_param___399 *);
	void (*free)(void *);
};

struct kparam_array___399;

struct kernel_param___399 {
	const char *name;
	struct module___399 *mod;
	const struct kernel_param_ops___399 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___399 *arr;
	};
};

struct kparam_array___399 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___399 *ops;
	void *elem;
};

struct module_attribute___399 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___399 *, struct module_kobject___399 *, char *);
	ssize_t (*store)(struct module_attribute___399 *, struct module_kobject___399 *, const char *, size_t);
	void (*setup)(struct module___399 *, const char *);
	int (*test)(struct module___399 *);
	void (*free)(struct module___399 *);
};

struct gnet_dump___110 {
	spinlock_t *lock;
	struct sk_buff___119 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___110;

struct Qdisc_ops___110 {
	struct Qdisc_ops___110 *next;
	const struct Qdisc_class_ops___110 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___119 *, struct Qdisc___110 *, struct sk_buff___119 **);
	struct sk_buff___119 * (*dequeue)(struct Qdisc___110 *);
	struct sk_buff___119 * (*peek)(struct Qdisc___110 *);
	int (*init)(struct Qdisc___110 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___110 *);
	void (*destroy)(struct Qdisc___110 *);
	int (*change)(struct Qdisc___110 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___110 *);
	int (*change_tx_queue_len)(struct Qdisc___110 *, unsigned int);
	int (*dump)(struct Qdisc___110 *, struct sk_buff___119 *);
	int (*dump_stats)(struct Qdisc___110 *, struct gnet_dump___110 *);
	void (*ingress_block_set)(struct Qdisc___110 *, u32);
	void (*egress_block_set)(struct Qdisc___110 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___110 *);
	u32 (*egress_block_get)(struct Qdisc___110 *);
	struct module___399 *owner;
};

struct tcf_block___110;

struct Qdisc_class_ops___110 {
	unsigned int flags;
	struct netdev_queue___118 * (*select_queue)(struct Qdisc___110 *, struct tcmsg *);
	int (*graft)(struct Qdisc___110 *, long unsigned int, struct Qdisc___110 *, struct Qdisc___110 **, struct netlink_ext_ack *);
	struct Qdisc___110 * (*leaf)(struct Qdisc___110 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___110 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___110 *, u32);
	int (*change)(struct Qdisc___110 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___110 *, long unsigned int);
	void (*walk)(struct Qdisc___110 *, struct qdisc_walker *);
	struct tcf_block___110 * (*tcf_block)(struct Qdisc___110 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___110 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___110 *, long unsigned int);
	int (*dump)(struct Qdisc___110 *, long unsigned int, struct sk_buff___119 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___110 *, long unsigned int, struct gnet_dump___110 *);
};

struct tcf_chain___110;

struct tcf_block___110 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___129 *net;
	struct Qdisc___110 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___110 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___110;

struct tcf_proto_ops___110;

struct tcf_proto___110 {
	struct tcf_proto___110 *next;
	void *root;
	int (*classify)(struct sk_buff___119 *, const struct tcf_proto___110 *, struct tcf_result___110 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___110 *ops;
	struct tcf_chain___110 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___110 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___110 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___110 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___119 *, const struct tcf_proto___110 *, struct tcf_result___110 *);
	int (*init)(struct tcf_proto___110 *);
	void (*destroy)(struct tcf_proto___110 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___110 *, u32);
	void (*put)(struct tcf_proto___110 *, void *);
	int (*change)(struct net___129 *, struct sk_buff___119 *, struct tcf_proto___110 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___110 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___110 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___110 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___129 *, struct tcf_chain___110 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___129 *, struct tcf_proto___110 *, void *, struct sk_buff___119 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___119 *, struct net___129 *, void *);
	struct module___399 *owner;
	int flags;
};

struct tcf_chain___110 {
	struct mutex filter_chain_lock;
	struct tcf_proto___110 *filter_chain;
	struct list_head list;
	struct tcf_block___110 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___110 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___98 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___108 *prog;
};

struct bpf_redirect_info___108 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___323 *map;
	struct bpf_map___323 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___98;

struct neigh_hash_table___98;

struct neigh_table___98 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___118 *, __u32 *);
	bool (*key_eq)(const struct neighbour___98 *, const void *);
	int (*constructor)(struct neighbour___98 *);
	int (*pconstructor)(struct pneigh_entry___98 *);
	void (*pdestructor)(struct pneigh_entry___98 *);
	void (*proxy_redo)(struct sk_buff___119 *);
	char *id;
	struct neigh_parms___98 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___118 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___98 *nht;
	struct pneigh_entry___98 **phash_buckets;
};

struct neigh_ops___98 {
	int family;
	void (*solicit)(struct neighbour___98 *, struct sk_buff___119 *);
	void (*error_report)(struct neighbour___98 *, struct sk_buff___119 *);
	int (*output)(struct neighbour___98 *, struct sk_buff___119 *);
	int (*connected_output)(struct neighbour___98 *, struct sk_buff___119 *);
};

struct pneigh_entry___98 {
	struct pneigh_entry___98 *next;
	possible_net_t___120 net;
	struct net_device___118 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___98 {
	struct neighbour___98 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___98 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___98 *ctarget;
	struct net___129 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___98 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___98 *rule;
	u32 table;
	int flags;
};

struct proto___98 {
	void (*close)(struct sock___98 *, long int);
	int (*pre_connect)(struct sock___98 *, struct sockaddr *, int);
	int (*connect)(struct sock___98 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___98 *, int);
	struct sock___98 * (*accept)(struct sock___98 *, int, int *, bool);
	int (*ioctl)(struct sock___98 *, int, long unsigned int);
	int (*init)(struct sock___98 *);
	void (*destroy)(struct sock___98 *);
	void (*shutdown)(struct sock___98 *, int);
	int (*setsockopt)(struct sock___98 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___98 *, int, int, char *, int *);
	void (*keepalive)(struct sock___98 *, int);
	int (*sendmsg)(struct sock___98 *, struct msghdr___101 *, size_t);
	int (*recvmsg)(struct sock___98 *, struct msghdr___101 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___98 *, struct page___474 *, int, size_t, int);
	int (*bind)(struct sock___98 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___98 *, struct sk_buff___119 *);
	void (*release_cb)(struct sock___98 *);
	int (*hash)(struct sock___98 *);
	void (*unhash)(struct sock___98 *);
	void (*rehash)(struct sock___98 *);
	int (*get_port)(struct sock___98 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___98 *);
	bool (*stream_memory_read)(const struct sock___98 *);
	void (*enter_memory_pressure)(struct sock___98 *);
	void (*leave_memory_pressure)(struct sock___98 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___3 *rsk_prot;
	struct timewait_sock_ops___3 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___399 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___98 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct radix_tree_preload {
	unsigned int nr;
	struct xa_node *nodes;
};

typedef struct pglist_data___473 pg_data_t___16;

typedef struct {
	long unsigned int key[2];
} hsiphash_key_t;

struct module___400;

struct file___474;

struct kiocb___474;

struct iov_iter___241;

struct poll_table_struct___313;

struct vm_area_struct___475;

struct inode___474;

struct file_lock___474;

struct page___475;

struct pipe_inode_info___155;

struct seq_file___413;

struct file_operations___474 {
	struct module___400 *owner;
	loff_t (*llseek)(struct file___474 *, loff_t, int);
	ssize_t (*read)(struct file___474 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___474 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___474 *, struct iov_iter___241 *);
	ssize_t (*write_iter)(struct kiocb___474 *, struct iov_iter___241 *);
	int (*iopoll)(struct kiocb___474 *, bool);
	int (*iterate)(struct file___474 *, struct dir_context *);
	int (*iterate_shared)(struct file___474 *, struct dir_context *);
	__poll_t (*poll)(struct file___474 *, struct poll_table_struct___313 *);
	long int (*unlocked_ioctl)(struct file___474 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___474 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___474 *, struct vm_area_struct___475 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___474 *, struct file___474 *);
	int (*flush)(struct file___474 *, fl_owner_t);
	int (*release)(struct inode___474 *, struct file___474 *);
	int (*fsync)(struct file___474 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___474 *, int);
	int (*lock)(struct file___474 *, int, struct file_lock___474 *);
	ssize_t (*sendpage)(struct file___474 *, struct page___475 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___474 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*flock)(struct file___474 *, int, struct file_lock___474 *);
	ssize_t (*splice_write)(struct pipe_inode_info___155 *, struct file___474 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___474 *, loff_t *, struct pipe_inode_info___155 *, size_t, unsigned int);
	int (*setlease)(struct file___474 *, long int, struct file_lock___474 **, void **);
	long int (*fallocate)(struct file___474 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___413 *, struct file___474 *);
	ssize_t (*copy_file_range)(struct file___474 *, loff_t, struct file___474 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___474 *, loff_t, struct file___474 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___474 *, loff_t, loff_t, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vmacache___475 {
	u64 seqnum;
	struct vm_area_struct___475 *vmas[4];
};

struct page_frag___475 {
	struct page___475 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___475;

struct mem_cgroup___207;

struct cred___442;

struct nsproxy___369;

struct signal_struct___349;

struct bio_list___264;

struct backing_dev_info___264;

struct io_context___111;

struct css_set___323;

struct request_queue___107;

struct vm_struct___378;

struct task_struct___476 {
	struct thread_info thread_info;
	volatile long int state;
	void *stack;
	atomic_t usage;
	unsigned int flags;
	unsigned int ptrace;
	struct llist_node wake_entry;
	int on_cpu;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___476 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct task_group *sched_task_group;
	struct sched_dl_entity dl;
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	cpumask_t cpus_allowed;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___475 *mm;
	struct mm_struct___475 *active_mm;
	struct vmacache___475 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int sched_psi_wake_requeue: 1;
	int: 27;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int rh_reserved_memcg_kmem_skip_account: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int use_memdelay: 1;
	unsigned int frozen: 1;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___476 *real_parent;
	struct task_struct___476 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___476 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct mem_cgroup___207 *active_memcg;
	long int rh_reserved2;
	struct pid___264 *thread_pid;
	long int rh_reserved3;
	long int rh_reserved4;
	struct pid___264 *rh_pgid;
	long int rh_reserved5;
	long int rh_reserved6;
	struct pid___264 *rh_sid;
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	struct vtime vtime;
	atomic_t tick_dep_mask;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 real_start_time;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	const struct cred___442 *ptracer_cred;
	const struct cred___442 *real_cred;
	const struct cred___442 *cred;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	struct fs_struct *fs;
	struct files_struct *files;
	struct nsproxy___369 *nsproxy;
	struct signal_struct___349 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	u32 parent_exec_id;
	u32 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___476 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	void *journal_info;
	struct bio_list___264 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___264 *backing_dev_info;
	struct io_context___111 *io_context;
	long unsigned int ptrace_message;
	union {
		kernel_siginfo_t *last_siginfo;
		struct {
			siginfo_t *last_siginfo;
		} __UNIQUE_ID_rh_kabi_hide8;
		union {		};
	};
	struct task_io_accounting ioac;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	unsigned int psi_flags;
	struct css_set___323 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct list_head numa_entry;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_len;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	struct callback_head rcu;
	struct pipe_inode_info___155 *splice_pipe;
	struct page_frag___475 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___207 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct request_queue___107 *throttle_queue;
	struct uprobe_task *utask;
	int pagefault_disabled;
	struct task_struct___476 *oom_reaper_list;
	struct vm_struct___378 *stack_vm_area;
	atomic_t stack_refcount;
	void *security;
	struct hlist_node pid_links[4];
	long: 64;
	struct thread_struct___157 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rw_semaphore___476 {
	atomic_long_t count;
	struct list_head wait_list;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct task_struct___476 *owner;
};

struct secondary_data___476 {
	void *stack;
	struct task_struct___476 *task;
	long int status;
};

struct blocking_notifier_head___475 {
	struct rw_semaphore___476 rwsem;
	struct notifier_block *head;
};

typedef struct page___475 *pgtable_t___475;

struct address_space___474;

struct dev_pagemap___462;

struct page___475 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___474 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___475 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
		};
		struct {
			long unsigned int _compound_pad_1;
			long unsigned int _compound_pad_2;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___475 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			struct mm_struct___475 *pt_mm;
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___462 *pgmap;
			long unsigned int hmm_data;
			long unsigned int _zd_pad_1;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	struct mem_cgroup___207 *mem_cgroup;
};

struct vm_operations_struct___462;

struct vm_area_struct___475 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___475 *vm_next;
	struct vm_area_struct___475 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___475 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___462 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___474 *vm_file;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_state___475;

struct user_namespace___339;

struct mm_struct___475 {
	struct {
		struct vm_area_struct___475 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___474 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore___476 mmap_sem;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		long unsigned int pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___475 *core_state;
		atomic_t membarrier_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___476 *owner;
		struct user_namespace___339 *user_ns;
		struct file___474 *exe_file;
		struct mmu_notifier_mm *mmu_notifier_mm;
		pgtable_t___475 pmd_huge_pte;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___474;

struct address_space___474 {
	struct inode___474 *host;
	struct xarray i_pages;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore___476 i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int nrexceptional;
	long unsigned int writeback_index;
	const struct address_space_operations___474 *a_ops;
	long unsigned int flags;
	spinlock_t private_lock;
	gfp_t gfp_mask;
	struct list_head private_list;
	void *private_data;
	errseq_t wb_err;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef int (*dev_page_fault_t___462)(struct vm_area_struct___475 *, long unsigned int, const struct page___475 *, unsigned int, pmd_t *);

typedef void (*dev_page_free_t___462)(struct page___475 *, void *);

struct device___442;

struct dev_pagemap___462 {
	dev_page_fault_t___462 page_fault;
	dev_page_free_t___462 page_free;
	struct vmem_altmap altmap;
	bool altmap_valid;
	struct resource res;
	struct percpu_ref *ref;
	struct device___442 *dev;
	void *data;
	enum memory_type type;
	u64 pci_p2pdma_bus_offset;
	void (*kill)(struct percpu_ref *);
};

struct cgroup___323;

struct cgroup_subsys___323;

struct cgroup_subsys_state___323 {
	struct cgroup___323 *cgroup;
	struct cgroup_subsys___323 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___323 *parent;
};

struct kernfs_node___469;

struct cgroup_file___323 {
	struct kernfs_node___469 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_per_node___207;

struct mem_cgroup___207 {
	struct cgroup_subsys_state___323 css;
	struct mem_cgroup_id___13 id;
	struct page_counter memory;
	struct page_counter swap;
	struct page_counter memsw;
	struct page_counter kmem;
	struct page_counter tcpmem;
	long unsigned int high;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool use_hierarchy;
	bool oom_lock;
	bool oom_group;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___323 events_file;
	struct cgroup_file___323 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	atomic_t moving_account;
	struct task_struct___476 *move_lock_task;
	struct mem_cgroup_stat_cpu *stat_cpu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_long_t stat[35];
	atomic_long_t events[81];
	atomic_long_t memory_events[7];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct list_head kmem_caches;
	int last_scanned_node;
	nodemask_t scan_nodes;
	atomic_t numainfo_events;
	atomic_t numainfo_updating;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct mem_cgroup_per_node___207 *nodeinfo[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry___474;

struct path___475 {
	struct vfsmount *mnt;
	struct dentry___474 *dentry;
};

struct file___474 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___475 f_path;
	struct inode___474 *f_inode;
	const struct file_operations___474 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___264 f_owner;
	const struct cred___442 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct list_head f_ep_links;
	struct list_head f_tfile_llink;
	struct address_space___474 *f_mapping;
	errseq_t f_wb_err;
};

struct vm_fault___462;

struct vm_operations_struct___462 {
	void (*open)(struct vm_area_struct___475 *);
	void (*close)(struct vm_area_struct___475 *);
	int (*split)(struct vm_area_struct___475 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___475 *);
	vm_fault_t (*fault)(struct vm_fault___462 *);
	vm_fault_t (*huge_fault)(struct vm_fault___462 *, enum page_entry_size);
	void (*map_pages)(struct vm_fault___462 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___475 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___462 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___462 *);
	int (*access)(struct vm_area_struct___475 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___475 *);
	int (*set_policy)(struct vm_area_struct___475 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___475 *, long unsigned int);
	struct page___475 * (*find_special_page)(struct vm_area_struct___475 *, long unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct core_thread___475 {
	struct task_struct___476 *task;
	struct core_thread___475 *next;
};

struct core_state___475 {
	atomic_t nr_threads;
	struct core_thread___475 dumper;
	struct completion startup;
};

struct key___442;

struct ucounts___339;

struct user_namespace___339 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	atomic_t count;
	struct user_namespace___339 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___29 ns;
	long unsigned int flags;
	struct key___442 *persistent_keyring_register;
	struct rw_semaphore___476 persistent_keyring_register_sem;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___339 *ucounts;
	int ucount_max[24];
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct vm_fault___462 {
	struct vm_area_struct___475 *vma;
	unsigned int flags;
	gfp_t gfp_mask;
	long unsigned int pgoff;
	long unsigned int address;
	pmd_t *pmd;
	pud_t *pud;
	pte_t orig_pte;
	struct page___475 *cow_page;
	struct mem_cgroup___207 *memcg;
	struct page___475 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___475 prealloc_pte;
};

struct user_struct___442 {
	atomic_t __count;
	atomic_t processes;
	atomic_t sigpending;
	atomic_t fanotify_listeners;
	atomic_long_t epoll_watches;
	long unsigned int mq_bytes;
	long unsigned int locked_shm;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct key___442 *uid_keyring;
	struct key___442 *session_keyring;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	struct ratelimit_state ratelimit;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct cred___442 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___442 *session_keyring;
	struct key___442 *process_keyring;
	struct key___442 *thread_keyring;
	struct key___442 *request_key_auth;
	void *security;
	struct user_struct___442 *user;
	struct user_namespace___339 *user_ns;
	struct group_info *group_info;
	struct callback_head rcu;
};

struct net___130;

struct cgroup_namespace___323;

struct nsproxy___369 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net___130 *net_ns;
	struct cgroup_namespace___323 *cgroup_ns;
};

struct signal_struct___349 {
	atomic_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___476 *curr_target;
	struct sigpending shared_pending;
	int group_exit_code;
	int notify_count;
	struct task_struct___476 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct task_cputime cputime_expires;
	struct list_head cpu_timers[3];
	struct pid___264 *rh_reserved_leader_pid;
	atomic_t tick_dep_mask;
	struct pid___264 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___475 *oom_mm;
	struct mutex cred_guard_mutex;
	struct pid___264 *pids[4];
	union {
		struct hlist_head multiprocess;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide28;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bio___264;

struct bio_list___264 {
	struct bio___264 *head;
	struct bio___264 *tail;
};

struct bdi_writeback_congested___264;

struct bdi_writeback___264 {
	struct backing_dev_info___264 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	struct percpu_counter stat[4];
	struct bdi_writeback_congested___264 *congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___323 *memcg_css;
	struct cgroup_subsys_state___323 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct backing_dev_info___264 {
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	congested_fn *congested_fn;
	void *congested_data;
	const char *name;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___264 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct rb_root cgwb_congested_tree;
	struct mutex cgwb_release_mutex;
	wait_queue_head_t wb_waitq;
	struct device___442 *dev;
	struct device___442 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___474 *debug_dir;
	struct dentry___474 *debug_stats;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct io_cq___111;

struct io_context___111 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	int nr_batch_requests;
	long unsigned int last_waited;
	struct xarray icq_tree;
	struct io_cq___111 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___323 {
	struct cgroup_subsys_state___323 *subsys[13];
	refcount_t refcount;
	struct css_set___323 *dom_cset;
	struct cgroup___323 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[13];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___323 *mg_src_cgrp;
	struct cgroup___323 *mg_dst_cgrp;
	struct css_set___323 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___474;

struct pipe_buffer___155;

struct pipe_inode_info___155 {
	struct mutex mutex;
	wait_queue_head_t wait;
	unsigned int nrbufs;
	unsigned int curbuf;
	unsigned int buffers;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int waiting_writers;
	unsigned int r_counter;
	unsigned int w_counter;
	struct page___475 *tmp_page;
	struct fasync_struct___474 *fasync_readers;
	struct fasync_struct___474 *fasync_writers;
	struct pipe_buffer___155 *bufs;
	struct user_struct___442 *user;
};

typedef blk_qc_t make_request_fn___107(struct request_queue___107 *, struct bio___264 *);

struct request___107;

typedef int dma_drain_needed_fn___107(struct request___107 *);

struct kset___461;

struct kobj_type___461;

struct kobject___462 {
	const char *name;
	struct list_head entry;
	struct kobject___462 *parent;
	struct kset___461 *kset;
	struct kobj_type___461 *ktype;
	struct kernfs_node___469 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___107;

struct bsg_class_device___107 {
	struct device___442 *class_dev;
	int minor;
	struct request_queue___107 *queue;
	const struct bsg_ops___107 *ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_set___264 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	spinlock_t rescue_lock;
	struct bio_list___264 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___107;

struct request_queue___107 {
	struct list_head queue_head;
	struct request___107 *last_merge;
	struct elevator_queue___107 *elevator;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	make_request_fn___107 *make_request_fn;
	dma_drain_needed_fn___107 *dma_drain_needed;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int nr_queues;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	struct backing_dev_info___264 *backing_dev_info;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	gfp_t bounce_gfp;
	spinlock_t queue_lock;
	struct kobject___462 kobj;
	struct kobject___462 *mq_kobj;
	struct blk_integrity integrity;
	struct device___442 *dev;
	int rpm_status;
	unsigned int nr_pending;
	long unsigned int nr_requests;
	unsigned int dma_drain_size;
	void *dma_drain_buffer;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int nr_zones;
	long unsigned int *seq_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	int node;
	struct blk_trace *blk_trace;
	struct mutex blk_trace_mutex;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	union {
		int mq_freeze_depth;
		struct {
			atomic_t mq_freeze_depth;
		} __UNIQUE_ID_rh_kabi_hide74;
		union {		};
	};
	struct bsg_class_device___107 bsg_dev;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct percpu_ref q_usage_counter;
	struct list_head rh_reserved_all_q_node;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___264 bio_split;
	struct dentry___474 *debugfs_dir;
	struct dentry___474 *sched_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	struct work_struct release_work;
	u64 write_hints[5];
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	struct mutex mq_freeze_lock;
};

struct vm_struct___378 {
	struct vm_struct___378 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___475 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

union thread_union___361 {
	struct task_struct___476 task;
	long unsigned int stack[8192];
};

struct fwnode_operations___362;

struct fwnode_handle___362 {
	struct fwnode_handle___362 *secondary;
	const struct fwnode_operations___362 *ops;
};

struct fwnode_reference_args___362;

struct fwnode_endpoint___362;

struct fwnode_operations___362 {
	struct fwnode_handle___362 * (*get)(struct fwnode_handle___362 *);
	void (*put)(struct fwnode_handle___362 *);
	bool (*device_is_available)(const struct fwnode_handle___362 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___362 *, const struct device___442 *);
	bool (*property_present)(const struct fwnode_handle___362 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___362 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___362 *, const char *, const char **, size_t);
	struct fwnode_handle___362 * (*get_parent)(const struct fwnode_handle___362 *);
	struct fwnode_handle___362 * (*get_next_child_node)(const struct fwnode_handle___362 *, struct fwnode_handle___362 *);
	struct fwnode_handle___362 * (*get_named_child_node)(const struct fwnode_handle___362 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___362 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___362 *);
	struct fwnode_handle___362 * (*graph_get_next_endpoint)(const struct fwnode_handle___362 *, struct fwnode_handle___362 *);
	struct fwnode_handle___362 * (*graph_get_remote_endpoint)(const struct fwnode_handle___362 *);
	struct fwnode_handle___362 * (*graph_get_port_parent)(struct fwnode_handle___362 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___362 *, struct fwnode_endpoint___362 *);
};

struct fwnode_endpoint___362 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___362 *local_fwnode;
};

struct fwnode_reference_args___362 {
	struct fwnode_handle___362 *fwnode;
	unsigned int nargs;
	unsigned int args[8];
};

struct dev_pm_info___442 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	struct timer_list suspend_timer;
	long unsigned int timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	long unsigned int last_busy;
	long unsigned int active_jiffies;
	long unsigned int suspended_jiffies;
	long unsigned int accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___442 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___442;

struct bus_type___442;

struct device_driver___442;

struct dev_pm_domain___442;

struct dma_map_ops___214;

struct device_node___101;

struct class___442;

struct attribute_group___439;

struct device___442 {
	struct device___442 *parent;
	struct device_private *p;
	struct kobject___462 kobj;
	const char *init_name;
	const struct device_type___442 *type;
	struct mutex mutex;
	struct bus_type___442 *bus;
	struct device_driver___442 *driver;
	void *platform_data;
	void *driver_data;
	struct dev_links_info links;
	struct dev_pm_info___442 power;
	struct dev_pm_domain___442 *pm_domain;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	struct list_head msi_list;
	int numa_node;
	const struct dma_map_ops___214 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_mask;
	long unsigned int dma_pfn_offset;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct dev_archdata archdata;
	struct device_node___101 *of_node;
	struct fwnode_handle___362 *fwnode;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct klist_node knode_class;
	struct class___442 *class;
	const struct attribute_group___439 **groups;
	void (*release)(struct device___442 *);
	struct iommu_group *iommu_group;
	struct iommu_fwspec *iommu_fwspec;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool dma_coherent: 1;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	size_t device_extended_size_rh;
	struct device_extended_rh *device_extended_rh;
};

struct pglist_data___475;

struct lruvec___475 {
	struct list_head lists[5];
	struct zone_reclaim_stat reclaim_stat;
	atomic_long_t inactive_age;
	long unsigned int refaults;
	struct pglist_data___475 *pgdat;
};

struct zone___475 {
	long unsigned int watermark[3];
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[3];
	int node;
	struct pglist_data___475 *zone_pgdat;
	struct per_cpu_pageset *pageset;
	long unsigned int zone_start_pfn;
	long unsigned int managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[14];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	long: 16;
	long: 64;
	long: 64;
	struct zone_padding _pad3_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	atomic_long_t vm_stat[13];
	atomic_long_t vm_numa_stat[6];
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___475 {
	struct zone___475 *zone;
	int zone_idx;
};

struct zonelist___475 {
	struct zoneref___475 _zonerefs[25];
};

struct pglist_data___475 {
	struct zone___475 node_zones[3];
	struct zonelist___475 node_zonelists[2];
	int nr_zones;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___476 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_classzone_idx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_classzone_idx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___476 *kcompactd;
	spinlock_t rh_reserved_numabalancing_migrate_lock;
	long unsigned int rh_reserved_numabalancing_migrate_next_window;
	long unsigned int rh_reserved_numabalancing_migrate_nr_pages;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	spinlock_t lru_lock;
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
	struct lruvec___475 lruvec;
	long unsigned int flags;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[29];
};

struct kernfs_root___468;

struct kernfs_elem_dir___468 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___468 *root;
};

struct kernfs_syscall_ops___468;

struct kernfs_root___468 {
	struct kernfs_node___469 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 next_generation;
	struct kernfs_syscall_ops___468 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___468 {
	struct kernfs_node___469 *target_kn;
};

struct kernfs_ops___468;

struct kernfs_elem_attr___468 {
	const struct kernfs_ops___468 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___469 *notify_next;
};

struct kernfs_node___469 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___469 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___468 dir;
		struct kernfs_elem_symlink___468 symlink;
		struct kernfs_elem_attr___468 attr;
	};
	void *priv;
	union kernfs_node_id id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___468;

struct kernfs_ops___468 {
	int (*open)(struct kernfs_open_file___468 *);
	void (*release)(struct kernfs_open_file___468 *);
	int (*seq_show)(struct seq_file___413 *, void *);
	void * (*seq_start)(struct seq_file___413 *, loff_t *);
	void * (*seq_next)(struct seq_file___413 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___413 *, void *);
	ssize_t (*read)(struct kernfs_open_file___468 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___468 *, char *, size_t, loff_t);
	int (*mmap)(struct kernfs_open_file___468 *, struct vm_area_struct___475 *);
	union {
		__poll_t (*poll)(struct kernfs_open_file___468 *, struct poll_table_struct___313 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide9;
		union {		};
	};
	long unsigned int rh_reserved2;
};

struct kernfs_syscall_ops___468 {
	int (*remount_fs)(struct kernfs_root___468 *, int *, char *);
	int (*show_options)(struct seq_file___413 *, struct kernfs_root___468 *);
	int (*mkdir)(struct kernfs_node___469 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___469 *);
	int (*rename)(struct kernfs_node___469 *, struct kernfs_node___469 *, const char *);
	int (*show_path)(struct seq_file___413 *, struct kernfs_node___469 *, struct kernfs_root___468 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct seq_operations___413;

struct seq_file___413 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	u64 version;
	struct mutex lock;
	const struct seq_operations___413 *op;
	int poll_event;
	const struct file___474 *file;
	void *private;
};

struct kernfs_open_file___468 {
	struct kernfs_node___469 *kn;
	struct file___474 *file;
	struct seq_file___413 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	const struct vm_operations_struct___462 *vm_ops;
};

typedef void (*poll_queue_proc___323)(struct file___474 *, wait_queue_head_t *, struct poll_table_struct___313 *);

struct poll_table_struct___313 {
	poll_queue_proc___323 _qproc;
	__poll_t _key;
};

struct sock___99;

struct kobj_ns_type_operations___99 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___99 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___130 *net;
} possible_net_t___121;

struct proto___99;

struct sock_common___99 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___99 *skc_prot;
	possible_net_t___121 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___99 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___120;

struct sk_buff_head___119 {
	struct sk_buff___120 *next;
	struct sk_buff___120 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sk_filter___99;

struct socket_wq___100;

struct dst_entry___99;

struct socket___101;

struct net_device___119;

struct sock___99 {
	struct sock_common___99 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___119 sk_error_queue;
	struct sk_buff_head___119 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___120 *head;
		struct sk_buff___120 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___99 *sk_filter;
	union {
		struct socket_wq___100 *sk_wq;
		struct socket_wq___100 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___99 *sk_rx_dst;
	struct dst_entry___99 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___120 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff_head___119 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	u32 sk_pacing_rate;
	u32 sk_max_pacing_rate;
	struct page_frag___475 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	unsigned int __sk_flags_offset[0];
	unsigned int sk_padding: 1;
	unsigned int sk_kern_sock: 1;
	unsigned int sk_no_check_tx: 1;
	unsigned int sk_no_check_rx: 1;
	unsigned int sk_userlocks: 4;
	unsigned int sk_protocol: 8;
	unsigned int sk_type: 16;
	u16 sk_gso_max_segs;
	u8 sk_pacing_shift;
	long unsigned int sk_lingertime;
	struct proto___99 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	struct pid___264 *sk_peer_pid;
	const struct cred___442 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	u8 sk_shutdown;
	u32 sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	struct socket___101 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___207 *sk_memcg;
	void (*sk_state_change)(struct sock___99 *);
	void (*sk_data_ready)(struct sock___99 *);
	void (*sk_write_space)(struct sock___99 *);
	void (*sk_error_report)(struct sock___99 *);
	int (*sk_backlog_rcv)(struct sock___99 *, struct sk_buff___120 *);
	struct sk_buff___120 * (*sk_validate_xmit_skb)(struct sock___99 *, struct net_device___119 *, struct sk_buff___120 *);
	void (*sk_destruct)(struct sock___99 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct callback_head sk_rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct bin_attribute___438;

struct attribute_group___439 {
	const char *name;
	umode_t (*is_visible)(struct kobject___462 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___462 *, struct bin_attribute___438 *, int);
	struct attribute **attrs;
	struct bin_attribute___438 **bin_attrs;
};

struct bin_attribute___438 {
	struct attribute attr;
	size_t size;
	void *private;
	ssize_t (*read)(struct file___474 *, struct kobject___462 *, struct bin_attribute___438 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___474 *, struct kobject___462 *, struct bin_attribute___438 *, char *, loff_t, size_t);
	int (*mmap)(struct file___474 *, struct kobject___462 *, struct bin_attribute___438 *, struct vm_area_struct___475 *);
};

struct sysfs_ops___461 {
	ssize_t (*show)(struct kobject___462 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___462 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___461;

struct kset___461 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___462 kobj;
	const struct kset_uevent_ops___461 *uevent_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kobj_type___461 {
	void (*release)(struct kobject___462 *);
	const struct sysfs_ops___461 *sysfs_ops;
	struct attribute **default_attrs;
	const struct kobj_ns_type_operations___99 * (*child_ns_type)(struct kobject___462 *);
	const void * (*namespace)(struct kobject___462 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct kset_uevent_ops___461 {
	int (* const filter)(struct kset___461 *, struct kobject___462 *);
	const char * (* const name)(struct kset___461 *, struct kobject___462 *);
	int (* const uevent)(struct kset___461 *, struct kobject___462 *, struct kobj_uevent_env *);
};

struct kobj_attribute___452 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___462 *, struct kobj_attribute___452 *, char *);
	ssize_t (*store)(struct kobject___462 *, struct kobj_attribute___452 *, const char *, size_t);
};

struct property___97 {
	char *name;
	int length;
	void *value;
	struct property___97 *next;
	long unsigned int _flags;
	struct bin_attribute___438 attr;
};

struct device_node___101 {
	const char *name;
	const char *type;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___362 fwnode;
	struct property___97 *properties;
	struct property___97 *deadprops;
	struct device_node___101 *parent;
	struct device_node___101 *child;
	struct device_node___101 *sibling;
	struct kobject___462 kobj;
	long unsigned int _flags;
	void *data;
};

struct clk_hw___6;

struct clk_rate_request___6 {
	long unsigned int rate;
	long unsigned int min_rate;
	long unsigned int max_rate;
	long unsigned int best_parent_rate;
	struct clk_hw___6 *best_parent_hw;
};

struct clk_init_data___6;

struct clk_hw___6 {
	struct clk_core *core;
	struct clk *clk;
	const struct clk_init_data___6 *init;
};

struct clk_ops___6 {
	int (*prepare)(struct clk_hw___6 *);
	void (*unprepare)(struct clk_hw___6 *);
	int (*is_prepared)(struct clk_hw___6 *);
	void (*unprepare_unused)(struct clk_hw___6 *);
	int (*enable)(struct clk_hw___6 *);
	void (*disable)(struct clk_hw___6 *);
	int (*is_enabled)(struct clk_hw___6 *);
	void (*disable_unused)(struct clk_hw___6 *);
	long unsigned int (*recalc_rate)(struct clk_hw___6 *, long unsigned int);
	long int (*round_rate)(struct clk_hw___6 *, long unsigned int, long unsigned int *);
	int (*determine_rate)(struct clk_hw___6 *, struct clk_rate_request___6 *);
	int (*set_parent)(struct clk_hw___6 *, u8);
	u8 (*get_parent)(struct clk_hw___6 *);
	int (*set_rate)(struct clk_hw___6 *, long unsigned int, long unsigned int);
	int (*set_rate_and_parent)(struct clk_hw___6 *, long unsigned int, long unsigned int, u8);
	long unsigned int (*recalc_accuracy)(struct clk_hw___6 *, long unsigned int);
	int (*get_phase)(struct clk_hw___6 *);
	int (*set_phase)(struct clk_hw___6 *, int);
	void (*init)(struct clk_hw___6 *);
	void (*debug_init)(struct clk_hw___6 *, struct dentry___474 *);
};

struct dentry_operations___474;

struct super_block___474;

struct dentry___474 {
	unsigned int d_flags;
	seqcount_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___474 *d_parent;
	struct qstr d_name;
	struct inode___474 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___474 *d_op;
	struct super_block___474 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct clk_init_data___6 {
	const char *name;
	const struct clk_ops___6 *ops;
	const char * const *parent_names;
	u8 num_parents;
	long unsigned int flags;
};

struct kernel_param___400;

struct kernel_param_ops___400 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___400 *);
	int (*get)(char *, const struct kernel_param___400 *);
	void (*free)(void *);
};

struct kparam_array___400;

struct kernel_param___400 {
	const char *name;
	struct module___400 *mod;
	const struct kernel_param_ops___400 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___400 *arr;
	};
};

struct kparam_array___400 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___400 *ops;
	void *elem;
};

struct module_kobject___400 {
	struct kobject___462 kobj;
	struct module___400 *mod;
	struct kobject___462 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___400 {
	struct module___400 *mod;
	struct latch_tree_node node;
};

struct module_layout___400 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___400 mtn;
};

struct module_attribute___400;

struct module___400 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___400 mkobj;
	struct module_attribute___400 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	const char *rhelversion;
	struct kobject___462 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___400 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool sig_ok;
	bool async_probe_requested;
	const struct kernel_symbol *gpl_future_syms;
	const s32 *gpl_future_crcs;
	unsigned int num_gpl_future_syms;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___400 core_layout;
	struct module_layout___400 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	unsigned int num_tracepoints;
	struct tracepoint * const *tracepoints_ptrs;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	union {
		unsigned int num_bpf_raw_events;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide10;
		union {		};
	};
	union {
		struct bpf_raw_event_map *bpf_raw_events;
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide11;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___400 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___400 *, struct module_kobject___400 *, char *);
	ssize_t (*store)(struct module_attribute___400 *, struct module_kobject___400 *, const char *, size_t);
	void (*setup)(struct module___400 *, const char *);
	int (*test)(struct module___400 *);
	void (*free)(struct module___400 *);
};

struct shrink_control___207 {
	gfp_t gfp_mask;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	int nid;
	struct mem_cgroup___207 *memcg;
};

struct shrinker___207 {
	long unsigned int (*count_objects)(struct shrinker___207 *, struct shrink_control___207 *);
	long unsigned int (*scan_objects)(struct shrinker___207 *, struct shrink_control___207 *);
	int seeks;
	int id;
	long int batch;
	long unsigned int flags;
	struct list_head list;
	atomic_long_t *nr_deferred;
};

struct inode_operations___474;

struct block_device___474;

struct inode___474 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___474 *i_op;
	struct super_block___474 *i_sb;
	struct address_space___474 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	unsigned int i_blkbits;
	enum rw_hint i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore___476 i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___264 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	const struct file_operations___474 *i_fop;
	struct file_lock_context *i_flctx;
	struct address_space___474 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___155 *i_pipe;
		struct block_device___474 *i_bdev;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	void *i_private;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dentry_operations___474 {
	int (*d_revalidate)(struct dentry___474 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___474 *, unsigned int);
	int (*d_hash)(const struct dentry___474 *, struct qstr *);
	int (*d_compare)(const struct dentry___474 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___474 *);
	int (*d_init)(struct dentry___474 *);
	void (*d_release)(struct dentry___474 *);
	void (*d_prune)(struct dentry___474 *);
	void (*d_iput)(struct dentry___474 *, struct inode___474 *);
	char * (*d_dname)(struct dentry___474 *, char *, int);
	struct vfsmount * (*d_automount)(struct path___475 *);
	int (*d_manage)(const struct path___475 *, bool);
	struct dentry___474 * (*d_real)(struct dentry___474 *, const struct inode___474 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___474;

struct mem_dqinfo___474 {
	struct quota_format_type___474 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___474;

struct quota_info___474 {
	unsigned int flags;
	struct rw_semaphore___476 dqio_sem;
	struct inode___474 *files[3];
	struct mem_dqinfo___474 info[3];
	const struct quota_format_ops___474 *ops[3];
};

struct rcuwait___474 {
	struct task_struct___476 *task;
};

struct percpu_rw_semaphore___474 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rw_semaphore___476 rw_sem;
	struct rcuwait___474 writer;
	int readers_block;
};

struct sb_writers___474 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___474 rw_sem[3];
};

struct file_system_type___474;

struct super_operations___474;

struct dquot_operations___474;

struct quotactl_ops___474;

struct super_block___474 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___474 *s_type;
	const struct super_operations___474 *s_op;
	const struct dquot_operations___474 *dq_op;
	const struct quotactl_ops___474 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___474 *s_root;
	struct rw_semaphore___476 s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___474 *s_bdev;
	struct backing_dev_info___264 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___474 s_dquot;
	struct sb_writers___474 s_writers;
	char s_id[32];
	uuid_t s_uuid;
	void *s_fs_info;
	unsigned int s_max_links;
	fmode_t s_mode;
	u32 s_time_gran;
	struct mutex s_vfs_rename_mutex;
	char *s_subtype;
	const struct dentry_operations___474 *s_d_op;
	int cleancache_poolid;
	struct shrinker___207 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_inode_refs;
	int s_readonly_remount;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___339 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	long int rh_reserve_1;
	long int rh_reserve_2;
	long int rh_reserve_3;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct io_cq___111 {
	struct request_queue___107 *q;
	struct io_context___111 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___474 {
	struct file___474 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___474 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	unsigned int ki_cookie;
};

struct iattr___474 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___474 *ia_file;
};

struct dquot___474 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___474 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___474 {
	int qf_fmt_id;
	const struct quota_format_ops___474 *qf_ops;
	struct module___400 *qf_owner;
	struct quota_format_type___474 *qf_next;
};

struct quota_format_ops___474 {
	int (*check_quota_file)(struct super_block___474 *, int);
	int (*read_file_info)(struct super_block___474 *, int);
	int (*write_file_info)(struct super_block___474 *, int);
	int (*free_file_info)(struct super_block___474 *, int);
	int (*read_dqblk)(struct dquot___474 *);
	int (*commit_dqblk)(struct dquot___474 *);
	int (*release_dqblk)(struct dquot___474 *);
	int (*get_next_id)(struct super_block___474 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct dquot_operations___474 {
	int (*write_dquot)(struct dquot___474 *);
	struct dquot___474 * (*alloc_dquot)(struct super_block___474 *, int);
	void (*destroy_dquot)(struct dquot___474 *);
	int (*acquire_dquot)(struct dquot___474 *);
	int (*release_dquot)(struct dquot___474 *);
	int (*mark_dirty)(struct dquot___474 *);
	int (*write_info)(struct super_block___474 *, int);
	qsize_t * (*get_reserved_space)(struct inode___474 *);
	int (*get_projid)(struct inode___474 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___474 *, qsize_t *);
	int (*get_next_id)(struct super_block___474 *, struct kqid *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct quotactl_ops___474 {
	int (*quota_on)(struct super_block___474 *, int, int, const struct path___475 *);
	int (*quota_off)(struct super_block___474 *, int);
	int (*quota_enable)(struct super_block___474 *, unsigned int);
	int (*quota_disable)(struct super_block___474 *, unsigned int);
	int (*quota_sync)(struct super_block___474 *, int);
	int (*set_info)(struct super_block___474 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___474 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___474 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___474 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___474 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___474 *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___227;

struct address_space_operations___474 {
	int (*writepage)(struct page___475 *, struct writeback_control___227 *);
	int (*readpage)(struct file___474 *, struct page___475 *);
	int (*writepages)(struct address_space___474 *, struct writeback_control___227 *);
	int (*set_page_dirty)(struct page___475 *);
	int (*readpages)(struct file___474 *, struct address_space___474 *, struct list_head *, unsigned int);
	int (*write_begin)(struct file___474 *, struct address_space___474 *, loff_t, unsigned int, unsigned int, struct page___475 **, void **);
	int (*write_end)(struct file___474 *, struct address_space___474 *, loff_t, unsigned int, unsigned int, struct page___475 *, void *);
	sector_t (*bmap)(struct address_space___474 *, sector_t);
	void (*invalidatepage)(struct page___475 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___475 *, gfp_t);
	void (*freepage)(struct page___475 *);
	ssize_t (*direct_IO)(struct kiocb___474 *, struct iov_iter___241 *);
	int (*migratepage)(struct address_space___474 *, struct page___475 *, struct page___475 *, enum migrate_mode);
	bool (*isolate_page)(struct page___475 *, isolate_mode_t);
	void (*putback_page)(struct page___475 *);
	int (*launder_page)(struct page___475 *);
	int (*is_partially_uptodate)(struct page___475 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___475 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___474 *, struct page___475 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___474 *, sector_t *);
	void (*swap_deactivate)(struct file___474 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct writeback_control___227 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	struct bdi_writeback___264 *wb;
	struct inode___474 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct bio_vec___266;

struct iov_iter___241 {
	int type;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___266 *bvec;
		struct pipe_inode_info___155 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			int idx;
			int start_idx;
		};
	};
};

struct hd_struct___111;

struct gendisk___111;

struct block_device___474 {
	dev_t bd_dev;
	int bd_openers;
	struct inode___474 *bd_inode;
	struct super_block___474 *bd_super;
	struct mutex bd_mutex;
	void *bd_claiming;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct list_head bd_holder_disks;
	struct block_device___474 *bd_contains;
	unsigned int bd_block_size;
	u8 bd_partno;
	struct hd_struct___111 *bd_part;
	unsigned int bd_part_count;
	int bd_invalidated;
	struct gendisk___111 *bd_disk;
	struct request_queue___107 *bd_queue;
	struct backing_dev_info___264 *bd_bdi;
	struct list_head bd_list;
	long unsigned int bd_private;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct hd_struct___111 {
	sector_t start_sect;
	sector_t nr_sects;
	seqcount_t nr_sects_seq;
	sector_t alignment_offset;
	unsigned int discard_alignment;
	struct device___442 __dev;
	struct kobject___462 *holder_dir;
	int policy;
	int partno;
	struct partition_meta_info *info;
	long unsigned int stamp;
	struct disk_stats *dkstats;
	struct percpu_ref ref;
	struct rcu_work rcu_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct disk_part_tbl___111;

struct block_device_operations___108;

struct gendisk___111 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	char * (*devnode)(struct gendisk___111 *, umode_t *);
	unsigned int events;
	unsigned int async_events;
	struct disk_part_tbl___111 *part_tbl;
	struct hd_struct___111 part0;
	const struct block_device_operations___108 *fops;
	struct request_queue___107 *queue;
	void *private_data;
	int flags;
	struct rw_semaphore___476 lookup_sem;
	struct kobject___462 *slave_dir;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___462 integrity_kobj;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct inode_operations___474 {
	struct dentry___474 * (*lookup)(struct inode___474 *, struct dentry___474 *, unsigned int);
	const char * (*get_link)(struct dentry___474 *, struct inode___474 *, struct delayed_call *);
	int (*permission)(struct inode___474 *, int);
	struct posix_acl * (*get_acl)(struct inode___474 *, int);
	int (*readlink)(struct dentry___474 *, char *, int);
	int (*create)(struct inode___474 *, struct dentry___474 *, umode_t, bool);
	int (*link)(struct dentry___474 *, struct inode___474 *, struct dentry___474 *);
	int (*unlink)(struct inode___474 *, struct dentry___474 *);
	int (*symlink)(struct inode___474 *, struct dentry___474 *, const char *);
	int (*mkdir)(struct inode___474 *, struct dentry___474 *, umode_t);
	int (*rmdir)(struct inode___474 *, struct dentry___474 *);
	int (*mknod)(struct inode___474 *, struct dentry___474 *, umode_t, dev_t);
	int (*rename)(struct inode___474 *, struct dentry___474 *, struct inode___474 *, struct dentry___474 *, unsigned int);
	int (*setattr)(struct dentry___474 *, struct iattr___474 *);
	int (*getattr)(const struct path___475 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___474 *, char *, size_t);
	int (*fiemap)(struct inode___474 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___474 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___474 *, struct dentry___474 *, struct file___474 *, unsigned int, umode_t, int *);
	int (*tmpfile)(struct inode___474 *, struct dentry___474 *, umode_t);
	int (*set_acl)(struct inode___474 *, struct posix_acl *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct file_lock_operations___474 {
	void (*fl_copy_lock)(struct file_lock___474 *, struct file_lock___474 *);
	void (*fl_release_private)(struct file_lock___474 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct lock_manager_operations___474;

struct file_lock___474 {
	struct file_lock___474 *fl_next;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_block;
	struct list_head rh_reserved1;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___474 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___474 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___474 *fl_ops;
	const struct lock_manager_operations___474 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
		} afs;
	} fl_u;
};

struct lock_manager_operations___474 {
	int (*lm_compare_owner)(struct file_lock___474 *, struct file_lock___474 *);
	long unsigned int (*lm_owner_key)(struct file_lock___474 *);
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___474 *);
	int (*lm_grant)(struct file_lock___474 *, int);
	bool (*lm_break)(struct file_lock___474 *);
	int (*lm_change)(struct file_lock___474 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___474 *, void **);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

struct fasync_struct___474 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___474 *fa_next;
	struct file___474 *fa_file;
	struct callback_head fa_rcu;
};

struct file_system_type___474 {
	const char *name;
	int fs_flags;
	struct dentry___474 * (*mount)(struct file_system_type___474 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___474 *);
	struct module___400 *owner;
	struct file_system_type___474 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key i_mutex_dir_key;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct super_operations___474 {
	struct inode___474 * (*alloc_inode)(struct super_block___474 *);
	void (*destroy_inode)(struct inode___474 *);
	void (*dirty_inode)(struct inode___474 *, int);
	int (*write_inode)(struct inode___474 *, struct writeback_control___227 *);
	int (*drop_inode)(struct inode___474 *);
	void (*evict_inode)(struct inode___474 *);
	void (*put_super)(struct super_block___474 *);
	int (*sync_fs)(struct super_block___474 *, int);
	int (*freeze_super)(struct super_block___474 *);
	int (*freeze_fs)(struct super_block___474 *);
	int (*thaw_super)(struct super_block___474 *);
	int (*unfreeze_fs)(struct super_block___474 *);
	int (*statfs)(struct dentry___474 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___474 *, int *, char *);
	void (*umount_begin)(struct super_block___474 *);
	int (*show_options)(struct seq_file___413 *, struct dentry___474 *);
	int (*show_devname)(struct seq_file___413 *, struct dentry___474 *);
	int (*show_path)(struct seq_file___413 *, struct dentry___474 *);
	int (*show_stats)(struct seq_file___413 *, struct dentry___474 *);
	ssize_t (*quota_read)(struct super_block___474 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___474 *, int, const char *, size_t, loff_t);
	struct dquot___474 ** (*get_dquots)(struct inode___474 *);
	int (*bdev_try_to_free_page)(struct super_block___474 *, struct page___475 *, gfp_t);
	long int (*nr_cached_objects)(struct super_block___474 *, struct shrink_control___207 *);
	long int (*free_cached_objects)(struct super_block___474 *, struct shrink_control___207 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

typedef void bio_end_io_t___264(struct bio___264 *);

struct bio_vec___266 {
	struct page___475 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___264;

struct bio___264 {
	struct bio___264 *bi_next;
	struct gendisk___111 *bi_disk;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	u8 bi_partno;
	unsigned int bi_phys_segments;
	unsigned int bi_seg_front_size;
	unsigned int bi_seg_back_size;
	struct bvec_iter bi_iter;
	atomic_t __bi_remaining;
	bio_end_io_t___264 *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	union {
		struct bio_integrity_payload___264 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___266 *bi_io_vec;
	struct bio_set___264 *bi_pool;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	struct bio_vec___266 bi_inline_vecs[0];
};

typedef void compound_page_dtor___462(struct page___475 *);

typedef int (*key_restrict_link_func_t___443)(struct key___442 *, const struct key_type *, const union key_payload *, struct key___442 *);

struct key_restriction___442;

struct key___442 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct rw_semaphore___476 sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			struct key_type *type;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___442 *restrict_link;
};

struct key_restriction___442 {
	key_restrict_link_func_t___443 check;
	struct key___442 *key;
	struct key_type *keytype;
};

struct msghdr___102 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___241 msg_iter;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___474 *msg_iocb;
};

struct random_ready_callback___3 {
	struct list_head list;
	void (*func)(struct random_ready_callback___3 *);
	struct module___400 *owner;
};

struct socket_wq___100 {
	wait_queue_head_t wait;
	struct fasync_struct___474 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___100;

struct socket___101 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct socket_wq___100 *wq;
	struct file___474 *file;
	struct sock___99 *sk;
	const struct proto_ops___100 *ops;
};

typedef int (*sk_read_actor_t___99)(read_descriptor_t *, struct sk_buff___120 *, unsigned int, size_t);

struct proto_ops___100 {
	int family;
	struct module___400 *owner;
	int (*release)(struct socket___101 *);
	int (*bind)(struct socket___101 *, struct sockaddr *, int);
	int (*connect)(struct socket___101 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___101 *, struct socket___101 *);
	int (*accept)(struct socket___101 *, struct socket___101 *, int, bool);
	int (*getname)(struct socket___101 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___474 *, struct socket___101 *, struct poll_table_struct___313 *);
	int (*ioctl)(struct socket___101 *, unsigned int, long unsigned int);
	int (*listen)(struct socket___101 *, int);
	int (*shutdown)(struct socket___101 *, int);
	int (*setsockopt)(struct socket___101 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct socket___101 *, int, int, char *, int *);
	int (*sendmsg)(struct socket___101 *, struct msghdr___102 *, size_t);
	int (*recvmsg)(struct socket___101 *, struct msghdr___102 *, size_t, int);
	int (*mmap)(struct file___474 *, struct socket___101 *, struct vm_area_struct___475 *);
	ssize_t (*sendpage)(struct socket___101 *, struct page___475 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___101 *, loff_t *, struct pipe_inode_info___155 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___99 *, int);
	int (*peek_len)(struct socket___101 *);
	int (*read_sock)(struct sock___99 *, read_descriptor_t *, sk_read_actor_t___99);
	int (*sendpage_locked)(struct sock___99 *, struct page___475 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___99 *, struct msghdr___102 *, size_t);
	int (*set_rcvlowat)(struct sock___99 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t proto_ops_extended_size_rh;
	struct proto_ops_extended_rh proto_ops_extended_rh;
};

struct nf_bridge_info___119;

struct sk_buff___120 {
	union {
		struct {
			struct sk_buff___120 *next;
			struct sk_buff___120 *prev;
			union {
				struct net_device___119 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
	};
	union {
		struct sock___99 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___120 *);
		};
		struct list_head tcp_tsorted_anchor;
	};
	struct sec_path *sp;
	long unsigned int _nfct;
	struct nf_bridge_info___119 *nf_bridge;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 xmit_more: 1;
	__u8 pfmemalloc: 1;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 tc_redirected: 1;
	__u8 tc_from_ingress: 1;
	__u16 tc_index;
	__u8 decrypted: 1;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	char rh_reserved_start[0];
	__u32 headers_end[0];
	char rh_reserved[16];
	char rh_reserved_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
};

struct inet_frags___119;

struct netns_frags___119 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___119 *f;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	atomic_long_t mem;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_rules_ops___99;

struct fib_notifier_ops___100;

struct netns_ipv4___119 {
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___99 *rules_ops;
	bool fib_has_custom_rules;
	unsigned int fib_rules_require_fldissect;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	bool fib_has_custom_local_routes;
	int fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	bool fib_offload_disabled;
	struct sock___99 *fibnl;
	struct sock___99 **icmp_sk;
	struct sock___99 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___99 **tcp_sk;
	struct netns_frags___119 frags;
	struct xt_table *iptable_filter;
	struct xt_table *iptable_mangle;
	struct xt_table *iptable_raw;
	struct xt_table *arptable_filter;
	struct xt_table *iptable_security;
	struct xt_table *nat_table;
	int sysctl_icmp_echo_ignore_all;
	int sysctl_icmp_echo_ignore_broadcasts;
	int sysctl_icmp_ignore_bogus_error_responses;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	int sysctl_icmp_errors_use_inbound_ifaddr;
	struct local_ports ip_local_ports;
	int sysctl_tcp_ecn;
	int sysctl_tcp_ecn_fallback;
	int sysctl_ip_default_ttl;
	int sysctl_ip_no_pmtu_disc;
	int sysctl_ip_fwd_use_pmtu;
	int sysctl_ip_nonlocal_bind;
	int sysctl_ip_dynaddr;
	int sysctl_ip_early_demux;
	int sysctl_tcp_early_demux;
	int sysctl_udp_early_demux;
	int sysctl_fwmark_reflect;
	int sysctl_tcp_fwmark_accept;
	int sysctl_tcp_l3mdev_accept;
	int sysctl_tcp_mtu_probing;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_probes;
	int sysctl_tcp_keepalive_intvl;
	int sysctl_tcp_syn_retries;
	int sysctl_tcp_synack_retries;
	int sysctl_tcp_syncookies;
	int sysctl_tcp_reordering;
	int sysctl_tcp_retries1;
	int sysctl_tcp_retries2;
	int sysctl_tcp_orphan_retries;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	int sysctl_tcp_tw_reuse;
	int sysctl_tcp_sack;
	int sysctl_tcp_window_scaling;
	int sysctl_tcp_timestamps;
	int sysctl_tcp_early_retrans;
	int sysctl_tcp_recovery;
	int sysctl_tcp_thin_linear_timeouts;
	int sysctl_tcp_slow_start_after_idle;
	int sysctl_tcp_retrans_collapse;
	int sysctl_tcp_stdurg;
	int sysctl_tcp_rfc1337;
	int sysctl_tcp_abort_on_overflow;
	int sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_dsack;
	int sysctl_tcp_app_win;
	int sysctl_tcp_adv_win_scale;
	int sysctl_tcp_frto;
	int sysctl_tcp_nometrics_save;
	int sysctl_tcp_moderate_rcvbuf;
	int sysctl_tcp_tso_win_divisor;
	int sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_tso_segs;
	int sysctl_tcp_min_rtt_wlen;
	int sysctl_tcp_autocorking;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	int sysctl_tcp_comp_sack_nr;
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long: 64;
	long: 64;
	struct inet_timewait_death_row tcp_death_row;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	spinlock_t tcp_fastopen_ctx_lock;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	int sysctl_udp_l3mdev_accept;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_llm_reports;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___99 *mr_rules_ops;
	int sysctl_fib_multipath_use_neigh;
	int sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___100 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___100 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	long: 64;
	long: 64;
};

struct neighbour___99;

struct dst_ops___130 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___130 *);
	struct dst_entry___99 * (*check)(struct dst_entry___99 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___99 *);
	unsigned int (*mtu)(const struct dst_entry___99 *);
	u32 * (*cow_metrics)(struct dst_entry___99 *, long unsigned int);
	void (*destroy)(struct dst_entry___99 *);
	void (*ifdown)(struct dst_entry___99 *, struct net_device___119 *, int);
	struct dst_entry___99 * (*negative_advice)(struct dst_entry___99 *);
	void (*link_failure)(struct sk_buff___120 *);
	void (*update_pmtu)(struct dst_entry___99 *, struct sock___99 *, struct sk_buff___120 *, u32);
	void (*redirect)(struct dst_entry___99 *, struct sock___99 *, struct sk_buff___120 *);
	int (*local_out)(struct net___130 *, struct sock___99 *, struct sk_buff___120 *);
	struct neighbour___99 * (*neigh_lookup)(const struct dst_entry___99 *, struct sk_buff___120 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___99 *, const void *);
	struct kmem_cache *kmem_cachep;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___130 {
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	long: 64;
	long: 64;
	long: 64;
	struct netns_frags___119 frags;
	struct xt_table *ip6table_filter;
	struct xt_table *ip6table_mangle;
	struct xt_table *ip6table_raw;
	struct xt_table *ip6table_security;
	struct xt_table *ip6table_nat;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___130 ip6_dst_ops;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned int fib6_rules_require_fldissect;
	bool fib6_has_custom_rules;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___99 *fib6_rules_ops;
	struct sock___99 **icmp_sk;
	struct sock___99 *ndisc_sk;
	struct sock___99 *tcp_sk;
	struct sock___99 *igmp_sk;
	struct sock___99 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___99 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___100 *notifier_ops;
	struct fib_notifier_ops___100 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
};

struct netns_sctp___100 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___99 *ctl_sock;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int pf_enable;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_nf_frag___119 {
	struct netns_frags___119 frags;
};

struct netns_xfrm___130 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct sock___99 *nlsk;
	struct sock___99 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___130 xfrm4_dst_ops;
	struct dst_ops___130 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___109;

struct net___130 {
	refcount_t passive;
	refcount_t count;
	spinlock_t rules_mod_lock;
	atomic64_t cookie_gen;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct user_namespace___339 *user_ns;
	struct ucounts___339 *ucounts;
	spinlock_t nsid_lock;
	struct idr netns_ids;
	struct ns_common___29 ns;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___99 *rtnl;
	struct sock___99 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct list_head dev_base_head;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	unsigned int dev_base_seq;
	int ifindex;
	unsigned int dev_unreg_count;
	struct list_head rules_ops;
	struct list_head fib_notifier_ops;
	struct net_device___119 *loopback_dev;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	long: 64;
	struct netns_ipv4___119 ipv4;
	struct netns_ipv6___130 ipv6;
	struct netns_sctp___100 sctp;
	struct netns_nf___23 nf;
	struct netns_xt xt;
	struct netns_ct ct;
	struct netns_nftables nft;
	long: 64;
	long: 64;
	struct netns_nf_frag___119 nf_frag;
	struct ctl_table_header *nf_frag_frags_hdr;
	struct sock___99 *nfnl;
	struct sock___99 *nfnl_stash;
	struct list_head nfct_timeout_list;
	struct net_generic *gen;
	long: 64;
	long: 64;
	struct netns_xfrm___130 xfrm;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct sock___99 *diag_nlsk;
	atomic_t fnhe_genid;
	int ipv4_sysctl_ip_fwd_update_priority;
	int ipv4_sysctl_tcp_min_snd_mss;
	struct bpf_prog___109 *flow_dissector_prog;
	siphash_key_t ipv4_ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___442 {
	int (*prepare)(struct device___442 *);
	void (*complete)(struct device___442 *);
	int (*suspend)(struct device___442 *);
	int (*resume)(struct device___442 *);
	int (*freeze)(struct device___442 *);
	int (*thaw)(struct device___442 *);
	int (*poweroff)(struct device___442 *);
	int (*restore)(struct device___442 *);
	int (*suspend_late)(struct device___442 *);
	int (*resume_early)(struct device___442 *);
	int (*freeze_late)(struct device___442 *);
	int (*thaw_early)(struct device___442 *);
	int (*poweroff_late)(struct device___442 *);
	int (*restore_early)(struct device___442 *);
	int (*suspend_noirq)(struct device___442 *);
	int (*resume_noirq)(struct device___442 *);
	int (*freeze_noirq)(struct device___442 *);
	int (*thaw_noirq)(struct device___442 *);
	int (*poweroff_noirq)(struct device___442 *);
	int (*restore_noirq)(struct device___442 *);
	int (*runtime_suspend)(struct device___442 *);
	int (*runtime_resume)(struct device___442 *);
	int (*runtime_idle)(struct device___442 *);
};

struct dev_pm_domain___442 {
	struct dev_pm_ops___442 ops;
	void (*detach)(struct device___442 *, bool);
	int (*activate)(struct device___442 *);
	void (*sync)(struct device___442 *);
	void (*dismiss)(struct device___442 *);
};

struct bus_type___442 {
	const char *name;
	const char *dev_name;
	struct device___442 *dev_root;
	const struct attribute_group___439 **bus_groups;
	const struct attribute_group___439 **dev_groups;
	const struct attribute_group___439 **drv_groups;
	int (*match)(struct device___442 *, struct device_driver___442 *);
	int (*uevent)(struct device___442 *, struct kobj_uevent_env *);
	int (*probe)(struct device___442 *);
	int (*remove)(struct device___442 *);
	void (*shutdown)(struct device___442 *);
	int (*online)(struct device___442 *);
	int (*offline)(struct device___442 *);
	int (*suspend)(struct device___442 *, pm_message_t);
	int (*resume)(struct device___442 *);
	int (*num_vf)(struct device___442 *);
	int (*dma_configure)(struct device___442 *);
	const struct dev_pm_ops___442 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___442 {
	const char *name;
	struct bus_type___442 *bus;
	struct module___400 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___442 *);
	int (*remove)(struct device___442 *);
	void (*shutdown)(struct device___442 *);
	int (*suspend)(struct device___442 *, pm_message_t);
	int (*resume)(struct device___442 *);
	const struct attribute_group___439 **groups;
	const struct dev_pm_ops___442 *pm;
	void (*coredump)(struct device___442 *);
	struct driver_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t device_driver_size_rh;
	struct device_driver_rh *device_driver_rh;
};

struct device_type___442 {
	const char *name;
	const struct attribute_group___439 **groups;
	int (*uevent)(struct device___442 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___442 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___442 *);
	const struct dev_pm_ops___442 *pm;
};

struct class___442 {
	const char *name;
	struct module___400 *owner;
	const struct attribute_group___439 **class_groups;
	const struct attribute_group___439 **dev_groups;
	struct kobject___462 *dev_kobj;
	int (*dev_uevent)(struct device___442 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___442 *, umode_t *);
	void (*class_release)(struct class___442 *);
	void (*dev_release)(struct device___442 *);
	int (*shutdown_pre)(struct device___442 *);
	const struct kobj_ns_type_operations___99 *ns_type;
	const void * (*namespace)(struct device___442 *);
	const struct dev_pm_ops___442 *pm;
	struct subsys_private *p;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	size_t class_size_rh;
	struct class_rh *class_rh;
};

struct dma_map_ops___214 {
	void * (*alloc)(struct device___442 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___442 *, size_t, void *, dma_addr_t, long unsigned int);
	int (*mmap)(struct device___442 *, struct vm_area_struct___475 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___442 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___442 *, struct page___475 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___442 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___442 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___442 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___442 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___442 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	union {
		size_t (*max_mapping_size)(struct device___442 *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide18;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	void (*sync_single_for_cpu)(struct device___442 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___442 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___442 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___442 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___442 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___442 *, u64);
	u64 (*get_required_mask)(struct device___442 *);
	size_t dma_map_ops_extended_size_rh;
	struct dma_map_ops_extended_rh dma_map_ops_extended_rh;
};

struct pipe_buf_operations___155;

struct pipe_buffer___155 {
	struct page___475 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___155 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___155 {
	int can_merge;
	int (*confirm)(struct pipe_inode_info___155 *, struct pipe_buffer___155 *);
	void (*release)(struct pipe_inode_info___155 *, struct pipe_buffer___155 *);
	int (*steal)(struct pipe_inode_info___155 *, struct pipe_buffer___155 *);
	union {
		bool (*get)(struct pipe_inode_info___155 *, struct pipe_buffer___155 *);
		struct {
			void (*get)(struct pipe_inode_info___155 *, struct pipe_buffer___155 *);
		} __UNIQUE_ID_rh_kabi_hide21;
		union {		};
	};
};

struct nf_bridge_info___119 {
	refcount_t use;
	enum {
		BRNF_PROTO_UNCHANGED___119 = 0,
		BRNF_PROTO_8021Q___119 = 1,
		BRNF_PROTO_PPPOE___119 = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___119 *physindev;
	struct net_device___119 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

typedef rx_handler_result_t rx_handler_func_t___119(struct sk_buff___120 **);

struct net_device_ops___119;

struct ethtool_ops___119;

struct l3mdev_ops___99;

struct ndisc_ops___65;

struct xfrmdev_ops___119;

struct tlsdev_ops___119;

struct header_ops___119;

struct inet6_dev___65;

struct netdev_rx_queue___119;

struct mini_Qdisc___111;

struct netdev_queue___119;

struct Qdisc___111;

struct rtnl_link_ops___111;

struct dcbnl_rtnl_ops___119;

struct net_device___119 {
	char name[16];
	struct hlist_node name_hlist;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	int irq;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	int ifindex;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct net_device_ops___119 *netdev_ops;
	const struct ethtool_ops___119 *ethtool_ops;
	const struct switchdev_ops *switchdev_ops;
	const struct l3mdev_ops___99 *l3mdev_ops;
	const struct ndisc_ops___65 *ndisc_ops;
	const struct xfrmdev_ops___119 *xfrmdev_ops;
	const struct tlsdev_ops___119 *tlsdev_ops;
	const struct header_ops___119 *header_ops;
	unsigned int flags;
	unsigned int priv_flags;
	short unsigned int gflags;
	short unsigned int padded;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned int mtu;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	short unsigned int hard_header_len;
	unsigned char min_header_len;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	spinlock_t addr_list_lock;
	unsigned char name_assign_type;
	bool uc_promisc;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___461 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	struct vlan_info *vlan_info;
	struct tipc_bearer *tipc_ptr;
	struct in_device *ip_ptr;
	struct inet6_dev___65 *ip6_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___119 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___109 *xdp_prog;
	long unsigned int gro_flush_timeout;
	rx_handler_func_t___119 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___111 *miniq_ingress;
	struct netdev_queue___119 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___119 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___111 *qdisc;
	struct hlist_head qdisc_hash[16];
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	int watchdog_timeo;
	struct xps_dev_maps *xps_cpus_map;
	struct xps_dev_maps *xps_rxqs_map;
	struct mini_Qdisc___111 *miniq_egress;
	struct timer_list watchdog_timer;
	int *pcpu_refcnt;
	struct list_head todo_list;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___119 = 0,
		NETREG_REGISTERED___119 = 1,
		NETREG_UNREGISTERING___119 = 2,
		NETREG_UNREGISTERED___119 = 3,
		NETREG_RELEASED___119 = 4,
		NETREG_DUMMY___119 = 5,
	} reg_state: 8;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___119 = 0,
		RTNL_LINK_INITIALIZING___119 = 1,
	} rtnl_link_state: 16;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___119 *);
	struct netpoll_info *npinfo;
	possible_net_t___121 nd_net;
	union {
		void *ml_priv;
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
		struct pcpu_vstats *rh_reserved_vstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___442 dev;
	const struct attribute_group___439 *sysfs_groups[4];
	const struct attribute_group___439 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___111 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___119 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	union {
		struct mpls_dev *mpls_ptr;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide35;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	size_t net_device_extended_size_rh;
	struct net_device_extended_rh *net_device_extended_rh;
};

struct ethtool_ops___119 {
	int (*get_settings)(struct net_device___119 *, struct ethtool_cmd *);
	int (*set_settings)(struct net_device___119 *, struct ethtool_cmd *);
	void (*get_drvinfo)(struct net_device___119 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___119 *);
	void (*get_regs)(struct net_device___119 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___119 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___119 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___119 *);
	void (*set_msglevel)(struct net_device___119 *, u32);
	int (*nway_reset)(struct net_device___119 *);
	u32 (*get_link)(struct net_device___119 *);
	int (*get_eeprom_len)(struct net_device___119 *);
	int (*get_eeprom)(struct net_device___119 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___119 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___119 *, struct ethtool_coalesce *);
	int (*set_coalesce)(struct net_device___119 *, struct ethtool_coalesce *);
	void (*get_ringparam)(struct net_device___119 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___119 *, struct ethtool_ringparam *);
	void (*get_pauseparam)(struct net_device___119 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___119 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___119 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___119 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___119 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___119 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___119 *);
	void (*complete)(struct net_device___119 *);
	u32 (*get_priv_flags)(struct net_device___119 *);
	int (*set_priv_flags)(struct net_device___119 *, u32);
	int (*get_sset_count)(struct net_device___119 *, int);
	int (*get_rxnfc)(struct net_device___119 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___119 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___119 *, struct ethtool_flash *);
	int (*reset)(struct net_device___119 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___119 *);
	u32 (*get_rxfh_indir_size)(struct net_device___119 *);
	int (*get_rxfh)(struct net_device___119 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___119 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___119 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___119 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___119 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___119 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___119 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___119 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___119 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___119 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___119 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___119 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___119 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___119 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___119 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___119 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___119 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___119 *, u32, struct ethtool_coalesce *);
	union {
		int (*get_link_ksettings_rh80)(struct net_device___119 *, struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*get_link_ksettings)(struct net_device___119 *, struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide24;
		union {		};
	};
	union {
		int (*set_link_ksettings_rh80)(struct net_device___119 *, const struct ethtool_link_ksettings_rh80 *);
		struct {
			int (*set_link_ksettings)(struct net_device___119 *, const struct ethtool_link_ksettings *);
		} __UNIQUE_ID_rh_kabi_hide25;
		union {		};
	};
	int (*get_fecparam)(struct net_device___119 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___119 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___119 *, struct ethtool_stats *, u64 *);
	union {
		int (*get_link_ksettings)(struct net_device___119 *, struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide26;
		union {		};
	};
	union {
		int (*set_link_ksettings)(struct net_device___119 *, const struct ethtool_link_ksettings *);
		struct {
			long unsigned int rh_reserved2;
		} __UNIQUE_ID_rh_kabi_hide27;
		union {		};
	};
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	size_t ethtool_ops_extended_size_rh;
	struct ethtool_ops_extended_rh ethtool_ops_extended_rh;
};

struct inet_frag_queue___119;

struct inet_frags___119 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___119 *, const void *);
	void (*destructor)(struct inet_frag_queue___119 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
};

struct inet_frag_queue___119 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct sk_buff___120 *fragments;
	struct rb_root rb_fragments;
	struct sk_buff___120 *fragments_tail;
	struct sk_buff___120 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct netns_frags___119 *net;
	struct callback_head rcu;
};

struct fib_rule___99;

struct fib_lookup_arg___99;

struct fib_rules_ops___99 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___99 *, struct flowi *, int, struct fib_lookup_arg___99 *);
	bool (*suppress)(struct fib_rule___99 *, struct fib_lookup_arg___99 *);
	int (*match)(struct fib_rule___99 *, struct flowi *, int);
	int (*configure)(struct fib_rule___99 *, struct sk_buff___120 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___99 *);
	int (*compare)(struct fib_rule___99 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___99 *, struct sk_buff___120 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___99 *);
	void (*flush_cache)(struct fib_rules_ops___99 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___400 *owner;
	struct net___130 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___100 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___130 *);
	int (*fib_dump)(struct net___130 *, struct notifier_block *);
	struct module___400 *owner;
	struct callback_head rcu;
};

struct dst_entry___99 {
	struct net_device___119 *dev;
	struct dst_ops___130 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___120 *);
	int (*output)(struct net___130 *, struct sock___99 *, struct sk_buff___120 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
};

struct neigh_table___99;

struct neigh_parms___99;

struct neigh_ops___99;

struct neighbour___99 {
	struct neighbour___99 *next;
	struct neigh_table___99 *tbl;
	struct neigh_parms___99 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	struct sk_buff_head___119 arp_queue;
	unsigned int arp_queue_len_bytes;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	seqlock_t ha_lock;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___99 *, struct sk_buff___120 *);
	const struct neigh_ops___99 *ops;
	struct callback_head rcu;
	struct net_device___119 *dev;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	u8 primary_key[0];
};

struct ucounts___339 {
	struct hlist_node node;
	struct user_namespace___339 *ns;
	kuid_t uid;
	int count;
	atomic_t ucount[24];
};

struct bpf_prog_aux___112;

struct bpf_prog___109 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 undo_set_mem: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_aux___112 *aux;
	struct sock_fprog_kern *orig_prog;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	union {
		struct sock_filter insns[0];
		struct bpf_insn insnsi[0];
	};
};

struct seq_operations___413 {
	void * (*start)(struct seq_file___413 *, loff_t *);
	void (*stop)(struct seq_file___413 *, void *);
	void * (*next)(struct seq_file___413 *, void *, loff_t *);
	int (*show)(struct seq_file___413 *, void *);
};

struct pernet_operations___120 {
	struct list_head list;
	int (*init)(struct net___130 *);
	void (*exit)(struct net___130 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___119 {
	int (*ieee_getets)(struct net_device___119 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___119 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___119 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___119 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___119 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___119 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___119 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___119 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___119 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___119 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___119 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___119 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___119 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___119 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___119 *);
	u8 (*setstate)(struct net_device___119 *, u8);
	void (*getpermhwaddr)(struct net_device___119 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___119 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___119 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___119 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___119 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___119 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___119 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___119 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___119 *, int, u8 *);
	void (*setpfccfg)(struct net_device___119 *, int, u8);
	void (*getpfccfg)(struct net_device___119 *, int, u8 *);
	u8 (*setall)(struct net_device___119 *);
	u8 (*getcap)(struct net_device___119 *, int, u8 *);
	int (*getnumtcs)(struct net_device___119 *, int, u8 *);
	int (*setnumtcs)(struct net_device___119 *, int, u8);
	u8 (*getpfcstate)(struct net_device___119 *);
	void (*setpfcstate)(struct net_device___119 *, u8);
	void (*getbcncfg)(struct net_device___119 *, int, u32 *);
	void (*setbcncfg)(struct net_device___119 *, int, u32);
	void (*getbcnrp)(struct net_device___119 *, int, u8 *);
	void (*setbcnrp)(struct net_device___119 *, int, u8);
	int (*setapp)(struct net_device___119 *, u8, u16, u8);
	int (*getapp)(struct net_device___119 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___119 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___119 *, int, u8);
	u8 (*getdcbx)(struct net_device___119 *);
	u8 (*setdcbx)(struct net_device___119 *, u8);
	int (*peer_getappinfo)(struct net_device___119 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___119 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___119 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___119 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___119 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___119 *, struct dcbnl_buffer *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t dcbnl_rtnl_ops_extended_size_rh;
	struct dcbnl_rtnl_ops_extended_rh dcbnl_rtnl_ops_extended_rh;
};

struct cgroup_namespace___323 {
	refcount_t count;
	struct ns_common___29 ns;
	struct user_namespace___339 *user_ns;
	struct ucounts___339 *ucounts;
	struct css_set___323 *root_cset;
};

struct bpf_map___324;

struct bpf_map_ops___323 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___324 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___324 *, struct file___474 *);
	void (*map_free)(struct bpf_map___324 *);
	int (*map_get_next_key)(struct bpf_map___324 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___324 *);
	void * (*map_lookup_elem)(struct bpf_map___324 *, void *);
	int (*map_update_elem)(struct bpf_map___324 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___324 *, void *);
	int (*map_push_elem)(struct bpf_map___324 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___324 *, void *);
	int (*map_peek_elem)(struct bpf_map___324 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___324 *, struct file___474 *, int);
	void (*map_fd_put_ptr)(void *);
	u32 (*map_gen_lookup)(struct bpf_map___324 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___324 *, void *, struct seq_file___413 *);
	int (*map_check_btf)(const struct bpf_map___324 *, const struct btf *, const struct btf_type *, const struct btf_type *);
};

struct bpf_map___324 {
	const struct bpf_map_ops___323 *ops;
	struct bpf_map___324 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	u32 pages;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	bool unpriv_array;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct user_struct___442 *user;
	atomic_t refcnt;
	atomic_t usercnt;
	struct work_struct work;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___119;

struct bpf_map_dev_ops___119 {
	int (*map_get_next_key)(struct bpf_offloaded_map___119 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___119 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___119 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___119 *, void *);
};

struct bpf_offloaded_map___119 {
	struct bpf_map___324 map;
	struct net_device___119 *netdev;
	const struct bpf_map_dev_ops___119 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___109 {
	int (*test_run)(struct bpf_prog___109 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___109 {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___109 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___109 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___109 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___109 *, u32 *);
};

struct bpf_prog_offload_ops___109 {
	int (*insn_hook)(struct bpf_verifier_env *, int, int);
	int (*finalize)(struct bpf_verifier_env *);
	int (*prepare)(struct bpf_prog___109 *);
	int (*translate)(struct bpf_prog___109 *);
	void (*destroy)(struct bpf_prog___109 *);
};

struct bpf_prog_offload___109 {
	struct bpf_prog___109 *prog;
	struct net_device___119 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	const struct bpf_prog_offload_ops___109 *dev_ops;
	void *jited_image;
	u32 jited_len;
};

struct bpf_prog_aux___112 {
	atomic_t refcnt;
	u32 used_map_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	bool offload_requested;
	struct bpf_prog___109 **func;
	void *jit_data;
	struct latch_tree_node ksym_tnode;
	struct list_head ksym_lnode;
	const struct bpf_prog_ops___109 *ops;
	struct bpf_map___324 **used_maps;
	struct bpf_prog___109 *prog;
	struct user_struct___442 *user;
	u64 load_time;
	struct bpf_map___324 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___109 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog_array_item___109 {
	struct bpf_prog___109 *prog;
	struct bpf_cgroup_storage *cgroup_storage[2];
};

struct bpf_prog_array___109 {
	struct callback_head rcu;
	struct bpf_prog_array_item___109 items[0];
};

struct cgroup_bpf___109 {
	struct bpf_prog_array___109 *effective[64];
	struct list_head progs[64];
	u32 flags[64];
	struct bpf_prog_array___109 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct kthread_work___324;

typedef void (*kthread_work_func_t___324)(struct kthread_work___324 *);

struct kthread_worker___324;

struct kthread_work___324 {
	struct list_head node;
	kthread_work_func_t___324 func;
	struct kthread_worker___324 *worker;
	int canceling;
};

struct kthread_worker___324 {
	unsigned int flags;
	spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___476 *task;
	struct kthread_work___324 *current_work;
};

struct kthread_delayed_work___323 {
	struct kthread_work___324 work;
	struct timer_list timer;
};

struct psi_group___323 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[5];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[10];
	long unsigned int avg[15];
	atomic_t poll_scheduled;
	struct kthread_worker___324 *poll_kworker;
	struct kthread_delayed_work___323 poll_work;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[5];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[5];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___323;

struct cgroup_rstat_cpu___323;

struct cgroup___323 {
	struct cgroup_subsys_state___323 self;
	long unsigned int flags;
	int id;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___469 *kn;
	struct cgroup_file___323 procs_file;
	struct cgroup_file___323 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___323 *subsys[13];
	struct cgroup_root___323 *root;
	struct list_head cset_links;
	struct list_head e_csets[13];
	struct cgroup___323 *dom_cgrp;
	struct cgroup_rstat_cpu___323 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat pending_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct cgroup_bpf___109 bpf;
	atomic_t congestion_count;
	struct cgroup___323 *old_dom_cgrp;
	struct cgroup_freezer_state freezer;
	struct psi_group___323 psi;
	int ancestor_ids[0];
};

struct cftype___323;

struct cgroup_subsys___323 {
	struct cgroup_subsys_state___323 * (*css_alloc)(struct cgroup_subsys_state___323 *);
	int (*css_online)(struct cgroup_subsys_state___323 *);
	void (*css_offline)(struct cgroup_subsys_state___323 *);
	void (*css_released)(struct cgroup_subsys_state___323 *);
	void (*css_free)(struct cgroup_subsys_state___323 *);
	void (*css_reset)(struct cgroup_subsys_state___323 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___323 *, int);
	int (*css_extra_stat_show)(struct seq_file___413 *, struct cgroup_subsys_state___323 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___476 *);
	void (*cancel_fork)(struct task_struct___476 *);
	void (*fork)(struct task_struct___476 *);
	void (*exit)(struct task_struct___476 *);
	void (*free)(struct task_struct___476 *);
	void (*bind)(struct cgroup_subsys_state___323 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	bool broken_hierarchy: 1;
	bool warned_broken_hierarchy: 1;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___323 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___323 *dfl_cftypes;
	struct cftype___323 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___323 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___323 *updated_children;
	struct cgroup___323 *updated_next;
};

struct cgroup_root___323 {
	struct kernfs_root___468 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___323 cgrp;
	int cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	struct idr cgroup_idr;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___323 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___323 *ss;
	struct list_head node;
	struct kernfs_ops___468 *kf_ops;
	int (*open)(struct kernfs_open_file___468 *);
	void (*release)(struct kernfs_open_file___468 *);
	u64 (*read_u64)(struct cgroup_subsys_state___323 *, struct cftype___323 *);
	s64 (*read_s64)(struct cgroup_subsys_state___323 *, struct cftype___323 *);
	int (*seq_show)(struct seq_file___413 *, void *);
	void * (*seq_start)(struct seq_file___413 *, loff_t *);
	void * (*seq_next)(struct seq_file___413 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___413 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___323 *, struct cftype___323 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___323 *, struct cftype___323 *, s64);
	ssize_t (*write)(struct kernfs_open_file___468 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___468 *, struct poll_table_struct___313 *);
};

struct xdp_rxq_info___119 {
	struct net_device___119 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_frame___119 {
	void *data;
	u16 len;
	u16 headroom;
	u16 metasize;
	struct xdp_mem_info mem;
	struct net_device___119 *dev_rx;
};

struct netlink_callback___121 {
	struct sk_buff___120 *skb;
	const struct nlmsghdr *nlh;
	int (*start)(struct netlink_callback___121 *);
	int (*dump)(struct sk_buff___120 *, struct netlink_callback___121 *);
	int (*done)(struct netlink_callback___121 *);
	void *data;
	struct module___400 *module;
	u16 family;
	u16 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	long int args[6];
	struct netlink_ext_ack *extack;
	bool strict_check;
	u16 answer_flags;
};

struct header_ops___119 {
	int (*create)(struct sk_buff___120 *, struct net_device___119 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___120 *, unsigned char *);
	int (*cache)(const struct neighbour___99 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___119 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
};

struct napi_struct___119 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	unsigned int gro_count;
	int (*poll)(struct napi_struct___119 *, int);
	int poll_owner;
	struct net_device___119 *dev;
	struct sk_buff___120 *gro_list;
	struct sk_buff___120 *skb;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t napi_struct_extended_size_rh;
	struct napi_struct_extended_rh napi_struct_extended_rh;
};

struct netdev_queue___119 {
	struct net_device___119 *dev;
	struct Qdisc___111 *qdisc;
	struct Qdisc___111 *qdisc_sleeping;
	struct kobject___462 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___119 *sb_dev;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
	union {
		struct xdp_umem___3 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide29;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct qdisc_skb_head___111 {
	struct sk_buff___120 *head;
	struct sk_buff___120 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___111;

struct Qdisc___111 {
	int (*enqueue)(struct sk_buff___120 *, struct Qdisc___111 *, struct sk_buff___120 **);
	struct sk_buff___120 * (*dequeue)(struct Qdisc___111 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___111 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___119 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int padded;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___119 gso_skb;
	struct qdisc_skb_head___111 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___111 *next_sched;
	struct sk_buff_head___119 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	bool empty;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___119 {
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___462 kobj;
	struct net_device___119 *dev;
	long: 64;
	struct xdp_rxq_info___119 xdp_rxq;
	union {
		struct xdp_umem___3 *umem;
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide30;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

typedef u16 (*select_queue_fallback_t___119)(struct net_device___119 *, struct sk_buff___120 *, struct net_device___119 *);

struct netdev_bpf___119 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___109 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			u32 prog_id;
			u32 prog_flags;
		};
		struct {
			struct bpf_prog___109 *prog;
			const struct bpf_prog_offload_ops___109 *ops;
		} verifier;
		struct {
			struct bpf_prog___109 *prog;
		} offload;
		struct {
			struct bpf_offloaded_map___119 *offmap;
		};
		struct {
			struct xdp_umem___5 *umem;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___119 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___120 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t xfrmdev_ops_extended_size_rh;
	struct xfrmdev_ops_extended_rh xfrmdev_ops_extended_rh;
};

struct tlsdev_ops___119 {
	int (*tls_dev_add)(struct net_device___119 *, struct sock___99 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___119 *, struct tls_context *, enum tls_offload_ctx_dir);
	union {
		void (*tls_dev_resync_rx)(struct net_device___119 *, struct sock___99 *, u32, u64);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide31;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t tlsdev_ops_extended_size_rh;
	struct tlsdev_ops_extended_rh tlsdev_ops_extended_rh;
};

struct net_device_ops___119 {
	int (*ndo_init)(struct net_device___119 *);
	void (*ndo_uninit)(struct net_device___119 *);
	int (*ndo_open)(struct net_device___119 *);
	int (*ndo_stop)(struct net_device___119 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___120 *, struct net_device___119 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___120 *, struct net_device___119 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___119 *, struct sk_buff___120 *, struct net_device___119 *, select_queue_fallback_t___119);
	void (*ndo_change_rx_flags)(struct net_device___119 *, int);
	void (*ndo_set_rx_mode)(struct net_device___119 *);
	int (*ndo_set_mac_address)(struct net_device___119 *, void *);
	int (*ndo_validate_addr)(struct net_device___119 *);
	int (*ndo_do_ioctl)(struct net_device___119 *, struct ifreq *, int);
	int (*ndo_set_config)(struct net_device___119 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___119 *, int);
	int (*ndo_neigh_setup)(struct net_device___119 *, struct neigh_parms___99 *);
	void (*ndo_tx_timeout)(struct net_device___119 *);
	void (*ndo_get_stats64)(struct net_device___119 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___119 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___119 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___119 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___119 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___119 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___119 *);
	int (*ndo_netpoll_setup)(struct net_device___119 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___119 *);
	int (*ndo_set_vf_mac)(struct net_device___119 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___119 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___119 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___119 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___119 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___119 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___119 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___119 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___119 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___119 *, int, struct sk_buff___120 *);
	int (*ndo_set_vf_guid)(struct net_device___119 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___119 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___119 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_get_wwn)(struct net_device___119 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___119 *, const struct sk_buff___120 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___119 *, struct net_device___119 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___119 *, struct net_device___119 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___119 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___119 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___119 *, struct neighbour___99 *);
	void (*ndo_neigh_destroy)(struct net_device___119 *, struct neighbour___99 *);
	union {
		int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___119 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___119 *, const unsigned char *, u16, u16);
		} __UNIQUE_ID_rh_kabi_hide32;
		union {		};
	};
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___119 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___120 *, struct netlink_callback___121 *, struct net_device___119 *, struct net_device___119 *, int *);
	union {
		int (*ndo_bridge_setlink)(struct net_device___119 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
		struct {
			int (*ndo_bridge_setlink)(struct net_device___119 *, struct nlmsghdr *, u16);
		} __UNIQUE_ID_rh_kabi_hide33;
		union {		};
	};
	int (*ndo_bridge_getlink)(struct sk_buff___120 *, u32, u32, struct net_device___119 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___119 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___119 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___119 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___119 *, char *, size_t);
	void (*ndo_udp_tunnel_add)(struct net_device___119 *, struct udp_tunnel_info *);
	void (*ndo_udp_tunnel_del)(struct net_device___119 *, struct udp_tunnel_info *);
	void * (*ndo_dfwd_add_station)(struct net_device___119 *, struct net_device___119 *);
	void (*ndo_dfwd_del_station)(struct net_device___119 *, void *);
	int (*ndo_get_lock_subclass)(struct net_device___119 *);
	int (*ndo_set_tx_maxrate)(struct net_device___119 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___119 *);
	int (*ndo_change_proto_down)(struct net_device___119 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___119 *, struct sk_buff___120 *);
	void (*ndo_set_rx_headroom)(struct net_device___119 *, int);
	int (*ndo_bpf)(struct net_device___119 *, struct netdev_bpf___119 *);
	int (*ndo_xdp_xmit)(struct net_device___119 *, int, struct xdp_frame___119 **, u32);
	int (*ndo_xsk_async_xmit)(struct net_device___119 *, u32);
	union {
		int (*ndo_get_port_parent_id)(struct net_device___119 *, struct netdev_phys_item_id *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide34;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
	long unsigned int rh_reserved17;
	long unsigned int rh_reserved18;
	long unsigned int rh_reserved19;
	long unsigned int rh_reserved20;
	long unsigned int rh_reserved21;
	long unsigned int rh_reserved22;
	long unsigned int rh_reserved23;
	long unsigned int rh_reserved24;
	long unsigned int rh_reserved25;
	long unsigned int rh_reserved26;
	long unsigned int rh_reserved27;
	long unsigned int rh_reserved28;
	long unsigned int rh_reserved29;
	long unsigned int rh_reserved30;
	long unsigned int rh_reserved31;
	long unsigned int rh_reserved32;
	long unsigned int rh_reserved33;
	long unsigned int rh_reserved34;
	long unsigned int rh_reserved35;
	long unsigned int rh_reserved36;
	long unsigned int rh_reserved37;
	long unsigned int rh_reserved38;
	long unsigned int rh_reserved39;
	long unsigned int rh_reserved40;
	long unsigned int rh_reserved41;
	long unsigned int rh_reserved42;
	long unsigned int rh_reserved43;
	long unsigned int rh_reserved44;
	long unsigned int rh_reserved45;
	long unsigned int rh_reserved46;
	long unsigned int rh_reserved47;
	size_t net_device_ops_extended_size_rh;
	struct net_device_ops_extended_rh net_device_ops_extended_rh;
};

struct neigh_parms___99 {
	possible_net_t___121 net;
	struct net_device___119 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___99 *);
	void (*neigh_cleanup)(struct neighbour___99 *);
	struct neigh_table___99 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___99 {
	u32 (*l3mdev_fib_table)(const struct net_device___119 *);
	struct sk_buff___120 * (*l3mdev_l3_rcv)(struct net_device___119 *, struct sk_buff___120 *, u16);
	struct sk_buff___120 * (*l3mdev_l3_out)(struct net_device___119 *, struct sock___99 *, struct sk_buff___120 *, u16);
	struct dst_entry___99 * (*l3mdev_link_scope_lookup)(const struct net_device___119 *, struct flowi6 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	size_t l3mdev_ops_extended_size_rh;
	struct l3mdev_ops_extended_rh l3mdev_ops_extended_rh;
};

struct ndisc_ops___65 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___119 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___119 *, struct neighbour___99 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___119 *, u8, struct neighbour___99 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___119 *, struct sk_buff___120 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___130 *, struct net_device___119 *, const struct prefix_info *, struct inet6_dev___65 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___65;

struct inet6_dev___65 {
	struct net_device___119 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___65 *mc_list;
	struct ifmcaddr6___65 *mc_tomb;
	spinlock_t mc_lock;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct timer_list mc_gq_timer;
	struct timer_list mc_ifc_timer;
	struct timer_list mc_dad_timer;
	struct ifacaddr6___35 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	u8 rndid[8];
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___99 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
};

struct tcf_proto___111;

struct mini_Qdisc___111 {
	struct tcf_proto___111 *filter_list;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___111 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	void (*setup)(struct net_device___119 *);
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___130 *, struct net_device___119 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___119 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___119 *, struct list_head *);
	size_t (*get_size)(const struct net_device___119 *);
	int (*fill_info)(struct sk_buff___120 *, const struct net_device___119 *);
	size_t (*get_xstats_size)(const struct net_device___119 *);
	int (*fill_xstats)(struct sk_buff___120 *, const struct net_device___119 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___119 *, struct net_device___119 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___119 *, const struct net_device___119 *);
	int (*fill_slave_info)(struct sk_buff___120 *, const struct net_device___119 *, const struct net_device___119 *);
	struct net___130 * (*get_link_net)(const struct net_device___119 *);
	size_t (*get_linkxstats_size)(const struct net_device___119 *, int);
	int (*fill_linkxstats)(struct sk_buff___120 *, const struct net_device___119 *, int *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	size_t rtnl_link_ops_extended_size_rh;
	struct rtnl_link_ops_extended_rh rtnl_link_ops_extended_rh;
};

struct softnet_data___119 {
	struct list_head poll_list;
	struct sk_buff_head___119 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___119 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___111 *output_queue;
	struct Qdisc___111 **output_queue_tailp;
	struct sk_buff___120 *completion_queue;
	struct sk_buff_head___119 xfrm_backlog;
	long: 64;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___119 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___119 input_pkt_queue;
	struct napi_struct___119 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bdi_writeback_congested___264 {
	long unsigned int state;
	atomic_t refcnt;
	struct backing_dev_info___264 *__bdi;
	int blkcg_id;
	struct rb_node rb_node;
};

struct bio_integrity_payload___264 {
	struct bio___264 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_slab;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___266 *bip_vec;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	struct bio_vec___266 bip_inline_vecs[0];
};

struct mem_cgroup_reclaim_iter___207 {
	struct mem_cgroup___207 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___207 {
	struct lruvec___475 lruvec;
	struct lruvec_stat *lruvec_stat_cpu;
	atomic_long_t lruvec_stat[29];
	long unsigned int lru_zone_size[15];
	struct mem_cgroup_reclaim_iter___207 iter[13];
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	bool congested;
	struct mem_cgroup___207 *memcg;
	struct memcg_shrinker_map *shrinker_map;
};

struct gnet_dump___111 {
	spinlock_t *lock;
	struct sk_buff___120 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___111;

struct Qdisc_ops___111 {
	struct Qdisc_ops___111 *next;
	const struct Qdisc_class_ops___111 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___120 *, struct Qdisc___111 *, struct sk_buff___120 **);
	struct sk_buff___120 * (*dequeue)(struct Qdisc___111 *);
	struct sk_buff___120 * (*peek)(struct Qdisc___111 *);
	int (*init)(struct Qdisc___111 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___111 *);
	void (*destroy)(struct Qdisc___111 *);
	int (*change)(struct Qdisc___111 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___111 *);
	int (*change_tx_queue_len)(struct Qdisc___111 *, unsigned int);
	int (*dump)(struct Qdisc___111 *, struct sk_buff___120 *);
	int (*dump_stats)(struct Qdisc___111 *, struct gnet_dump___111 *);
	void (*ingress_block_set)(struct Qdisc___111 *, u32);
	void (*egress_block_set)(struct Qdisc___111 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___111 *);
	u32 (*egress_block_get)(struct Qdisc___111 *);
	struct module___400 *owner;
};

struct tcf_block___111;

struct Qdisc_class_ops___111 {
	unsigned int flags;
	struct netdev_queue___119 * (*select_queue)(struct Qdisc___111 *, struct tcmsg *);
	int (*graft)(struct Qdisc___111 *, long unsigned int, struct Qdisc___111 *, struct Qdisc___111 **, struct netlink_ext_ack *);
	struct Qdisc___111 * (*leaf)(struct Qdisc___111 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___111 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___111 *, u32);
	int (*change)(struct Qdisc___111 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___111 *, long unsigned int);
	void (*walk)(struct Qdisc___111 *, struct qdisc_walker *);
	struct tcf_block___111 * (*tcf_block)(struct Qdisc___111 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___111 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___111 *, long unsigned int);
	int (*dump)(struct Qdisc___111 *, long unsigned int, struct sk_buff___120 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___111 *, long unsigned int, struct gnet_dump___111 *);
};

struct tcf_chain___111;

struct tcf_block___111 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	refcount_t refcnt;
	struct net___130 *net;
	struct Qdisc___111 *q;
	struct list_head cb_list;
	struct list_head owner_list;
	bool keep_dst;
	unsigned int offloadcnt;
	unsigned int nooffloaddevcnt;
	struct {
		struct tcf_chain___111 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
};

struct tcf_result___111;

struct tcf_proto_ops___111;

struct tcf_proto___111 {
	struct tcf_proto___111 *next;
	void *root;
	int (*classify)(struct sk_buff___120 *, const struct tcf_proto___111 *, struct tcf_result___111 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___111 *ops;
	struct tcf_chain___111 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
};

struct tcf_result___111 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___111 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___111 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___120 *, const struct tcf_proto___111 *, struct tcf_result___111 *);
	int (*init)(struct tcf_proto___111 *);
	void (*destroy)(struct tcf_proto___111 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___111 *, u32);
	void (*put)(struct tcf_proto___111 *, void *);
	int (*change)(struct net___130 *, struct sk_buff___120 *, struct tcf_proto___111 *, long unsigned int, u32, struct nlattr **, void **, bool, bool, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___111 *, void *, bool *, bool, struct netlink_ext_ack *);
	void (*walk)(struct tcf_proto___111 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___111 *, bool, tc_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*bind_class)(void *, u32, long unsigned int);
	void * (*tmplt_create)(struct net___130 *, struct tcf_chain___111 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___130 *, struct tcf_proto___111 *, void *, struct sk_buff___120 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___120 *, struct net___130 *, void *);
	struct module___400 *owner;
	int flags;
};

struct tcf_chain___111 {
	struct mutex filter_chain_lock;
	struct tcf_proto___111 *filter_chain;
	struct list_head list;
	struct tcf_block___111 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___111 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___99 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___109 *prog;
};

struct bpf_redirect_info___109 {
	u32 ifindex;
	u32 flags;
	struct bpf_map___324 *map;
	struct bpf_map___324 *map_to_flush;
	u32 kern_flags;
};

struct pneigh_entry___99;

struct neigh_hash_table___99;

struct neigh_table___99 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___119 *, __u32 *);
	bool (*key_eq)(const struct neighbour___99 *, const void *);
	int (*constructor)(struct neighbour___99 *);
	int (*pconstructor)(struct pneigh_entry___99 *);
	void (*pdestructor)(struct pneigh_entry___99 *);
	void (*proxy_redo)(struct sk_buff___120 *);
	char *id;
	struct neigh_parms___99 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___119 proxy_queue;
	atomic_t entries;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___99 *nht;
	struct pneigh_entry___99 **phash_buckets;
};

struct neigh_ops___99 {
	int family;
	void (*solicit)(struct neighbour___99 *, struct sk_buff___120 *);
	void (*error_report)(struct neighbour___99 *, struct sk_buff___120 *);
	int (*output)(struct neighbour___99 *, struct sk_buff___120 *);
	int (*connected_output)(struct neighbour___99 *, struct sk_buff___120 *);
};

struct pneigh_entry___99 {
	struct pneigh_entry___99 *next;
	possible_net_t___121 net;
	struct net_device___119 *dev;
	u8 flags;
	u8 key[0];
};

struct neigh_hash_table___99 {
	struct neighbour___99 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___99 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___99 *ctarget;
	struct net___130 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct fib_lookup_arg___99 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___99 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___78;

struct timewait_sock_ops___73;

struct proto___99 {
	void (*close)(struct sock___99 *, long int);
	int (*pre_connect)(struct sock___99 *, struct sockaddr *, int);
	int (*connect)(struct sock___99 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___99 *, int);
	struct sock___99 * (*accept)(struct sock___99 *, int, int *, bool);
	int (*ioctl)(struct sock___99 *, int, long unsigned int);
	int (*init)(struct sock___99 *);
	void (*destroy)(struct sock___99 *);
	void (*shutdown)(struct sock___99 *, int);
	int (*setsockopt)(struct sock___99 *, int, int, char *, unsigned int);
	int (*getsockopt)(struct sock___99 *, int, int, char *, int *);
	void (*keepalive)(struct sock___99 *, int);
	int (*sendmsg)(struct sock___99 *, struct msghdr___102 *, size_t);
	int (*recvmsg)(struct sock___99 *, struct msghdr___102 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___99 *, struct page___475 *, int, size_t, int);
	int (*bind)(struct sock___99 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___99 *, struct sk_buff___120 *);
	void (*release_cb)(struct sock___99 *);
	int (*hash)(struct sock___99 *);
	void (*unhash)(struct sock___99 *);
	void (*rehash)(struct sock___99 *);
	int (*get_port)(struct sock___99 *, short unsigned int);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___99 *);
	bool (*stream_memory_read)(const struct sock___99 *);
	void (*enter_memory_pressure)(struct sock___99 *);
	void (*leave_memory_pressure)(struct sock___99 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	struct percpu_counter *orphan_count;
	struct request_sock_ops___78 *rsk_prot;
	struct timewait_sock_ops___73 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___400 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___99 *, int);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
	long unsigned int rh_reserved9;
	long unsigned int rh_reserved10;
	long unsigned int rh_reserved11;
	long unsigned int rh_reserved12;
	long unsigned int rh_reserved13;
	long unsigned int rh_reserved14;
	long unsigned int rh_reserved15;
	long unsigned int rh_reserved16;
};

struct request_sock___79;

struct request_sock_ops___78 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___99 *, struct request_sock___79 *);
	void (*send_ack)(const struct sock___99 *, struct sk_buff___120 *, struct request_sock___79 *);
	void (*send_reset)(const struct sock___99 *, struct sk_buff___120 *);
	void (*destructor)(struct request_sock___79 *);
	void (*syn_ack_timeout)(const struct request_sock___79 *);
};

struct timewait_sock_ops___73 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___99 *, struct sock___99 *, void *);
	void (*twsk_destructor)(struct sock___99 *);
};

struct request_sock___79 {
	struct sock_common___99 __req_common;
	struct request_sock___79 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 cookie_ts: 1;
	u8 num_timeout: 7;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___78 *rsk_ops;
	struct sock___99 *sk;
	u32 *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___65 {
	struct in6_addr mca_addr;
	struct inet6_dev___65 *idev;
	struct ifmcaddr6___65 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct timer_list mca_timer;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	spinlock_t mca_lock;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
};

struct ip6_ra_chain___65 {
	struct ip6_ra_chain___65 *next;
	struct sock___99 *sk;
	int sel;
	void (*destructor)(struct sock___99 *);
};

struct ipv6_stub___25 {
	int (*ipv6_sock_mc_join)(struct sock___99 *, int, const struct in6_addr *);
	int (*ipv6_sock_mc_drop)(struct sock___99 *, int, const struct in6_addr *);
	int (*ipv6_dst_lookup)(struct net___130 *, struct sock___99 *, struct dst_entry___99 **, struct flowi6 *);
	struct fib6_table * (*fib6_get_table)(struct net___130 *, u32);
	struct fib6_info * (*fib6_lookup)(struct net___130 *, int, struct flowi6 *, int);
	struct fib6_info * (*fib6_table_lookup)(struct net___130 *, struct fib6_table *, int, struct flowi6 *, int);
	struct fib6_info * (*fib6_multipath_select)(const struct net___130 *, struct fib6_info *, struct flowi6 *, int, const struct sk_buff___120 *, int);
	u32 (*ip6_mtu_from_fib6)(struct fib6_info *, struct in6_addr *, struct in6_addr *);
	void (*udpv6_encap_enable)();
	void (*ndisc_send_na)(struct net_device___119 *, const struct in6_addr *, const struct in6_addr *, bool, bool, bool, bool);
	struct neigh_table___99 *nd_tbl;
};

struct ipv6_bpf_stub___25 {
	int (*inet6_bind)(struct sock___99 *, struct sockaddr *, int, bool, bool);
	struct sock___99 * (*udp6_lib_lookup)(struct net___130 *, const struct in6_addr *, __be16, const struct in6_addr *, __be16, int, int, struct udp_table *, struct sk_buff___120 *);
};

struct disk_part_tbl___111 {
	struct callback_head callback_head;
	int len;
	struct hd_struct___111 *last_lookup;
	struct hd_struct___111 *part[0];
};

struct block_device_operations___108 {
	int (*open)(struct block_device___474 *, fmode_t);
	void (*release)(struct gendisk___111 *, fmode_t);
	int (*rw_page)(struct block_device___474 *, sector_t, struct page___475 *, unsigned int);
	int (*ioctl)(struct block_device___474 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___474 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___111 *, unsigned int);
	int (*media_changed)(struct gendisk___111 *);
	void (*unlock_native_capacity)(struct gendisk___111 *);
	int (*revalidate_disk)(struct gendisk___111 *);
	int (*getgeo)(struct block_device___474 *, struct hd_geometry *);
	void (*swap_slot_free_notify)(struct block_device___474 *, long unsigned int);
	int (*report_zones)(struct gendisk___111 *, sector_t, struct blk_zone *, unsigned int *, gfp_t);
	struct module___400 *owner;
	const struct pr_ops *pr_ops;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct bsg_ops___107 {
	int (*check_proto)(struct sg_io_v4 *);
	int (*fill_hdr)(struct request___107 *, struct sg_io_v4 *, fmode_t);
	int (*complete_rq)(struct request___107 *, struct sg_io_v4 *);
	void (*free_rq)(struct request___107 *);
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
};

typedef void rq_end_io_fn___107(struct request___107 *, blk_status_t);

struct request___107 {
	struct request_queue___107 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int internal_tag;
	unsigned int __data_len;
	int tag;
	sector_t __sector;
	struct bio___264 *bio;
	struct bio___264 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct list_head ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___266 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___111 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___107 *saved_end_io;
		} flush;
	};
	struct gendisk___111 *rq_disk;
	struct hd_struct___111 *part;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	short unsigned int write_hint;
	short unsigned int ioprio;
	void *special;
	unsigned int extra_len;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___107 *end_io;
	void *end_io_data;
	struct request___107 *next_rq;
};

struct elevator_type___107;

struct elevator_mq_ops___107 {
	int (*init_sched)(struct request_queue___107 *, struct elevator_type___107 *);
	void (*exit_sched)(struct elevator_queue___107 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	bool (*allow_merge)(struct request_queue___107 *, struct request___107 *, struct bio___264 *);
	bool (*bio_merge)(struct blk_mq_hw_ctx *, struct bio___264 *);
	int (*request_merge)(struct request_queue___107 *, struct request___107 **, struct bio___264 *);
	void (*request_merged)(struct request_queue___107 *, struct request___107 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___107 *, struct request___107 *, struct request___107 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___107 *, struct bio___264 *);
	void (*finish_request)(struct request___107 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___107 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___107 *, u64);
	void (*started_request)(struct request___107 *);
	void (*requeue_request)(struct request___107 *);
	struct request___107 * (*former_request)(struct request_queue___107 *, struct request___107 *);
	struct request___107 * (*next_request)(struct request_queue___107 *, struct request___107 *);
	void (*init_icq)(struct io_cq___111 *);
	void (*exit_icq)(struct io_cq___111 *);
	union {
		void (*depth_updated)(struct blk_mq_hw_ctx *);
		struct {
			long unsigned int rh_reserved1;
		} __UNIQUE_ID_rh_kabi_hide73;
		union {		};
	};
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
	long unsigned int rh_reserved5;
	long unsigned int rh_reserved6;
	long unsigned int rh_reserved7;
	long unsigned int rh_reserved8;
};

struct elv_fs_entry___107;

struct elevator_type___107 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___107 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___107 *elevator_attrs;
	char elevator_name[16];
	const char *elevator_alias;
	struct module___400 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
	long unsigned int rh_reserved1;
	long unsigned int rh_reserved2;
	long unsigned int rh_reserved3;
	long unsigned int rh_reserved4;
};

struct elevator_queue___107 {
	struct elevator_type___107 *type;
	void *elevator_data;
	struct kobject___462 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	struct hlist_head hash[64];
};

struct elv_fs_entry___107 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___107 *, char *);
	ssize_t (*store)(struct elevator_queue___107 *, const char *, size_t);
};

enum format_type {
	FORMAT_TYPE_NONE = 0,
	FORMAT_TYPE_WIDTH = 1,
	FORMAT_TYPE_PRECISION = 2,
	FORMAT_TYPE_CHAR = 3,
	FORMAT_TYPE_STR = 4,
	FORMAT_TYPE_PTR = 5,
	FORMAT_TYPE_PERCENT_CHAR = 6,
	FORMAT_TYPE_INVALID = 7,
	FORMAT_TYPE_LONG_LONG = 8,
	FORMAT_TYPE_ULONG = 9,
	FORMAT_TYPE_LONG = 10,
	FORMAT_TYPE_UBYTE = 11,
	FORMAT_TYPE_BYTE = 12,
	FORMAT_TYPE_USHORT = 13,
	FORMAT_TYPE_SHORT = 14,
	FORMAT_TYPE_UINT = 15,
	FORMAT_TYPE_INT = 16,
	FORMAT_TYPE_SIZE_T = 17,
	FORMAT_TYPE_PTRDIFF = 18,
};

struct printf_spec {
	unsigned int type: 8;
	int field_width: 24;
	unsigned int flags: 8;
	unsigned int base: 8;
	int precision: 16;
};

struct xa_limit {
	u32 max;
	u32 min;
};

#ifndef BPF_NO_PRESERVE_ACCESS_INDEX
#pragma clang attribute pop
#endif

#endif /* __VMLINUX_H__ */
